(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  21932904,    1369516]*)
(*NotebookOutlinePosition[  21933800,    1369547]*)
(*  CellTagsIndexPosition[  21933756,    1369543]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
SEE: a tool for the visualization and analysis 
of rodent exploratory behavior\
\>", "Text",
  FontSize->36,
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
Dan Drai and Ilan Golani

Department of Zoology, George S. Wise Faculty of Life Sciences, Tel-Aviv \
University
Correspondence: 
Dan Drai
Dept. of Zoology,
George S. Wise Faculty of Life Sciences,
Tel-Aviv, Israel
FAX: (972) 3-6409403
E-mail: ddrai@post.tau.ac.il  ;  ilan99@post.tau.ac.il
Phone: (972) 3-6409391\
\>", "Text",
  FontSize->17],

Cell["\<\
Abstract 
The complexity of exploratory behavior creates a need for a visualization and \
analysis tool that will highlight regularities and help generating new \
hypotheses about the structure of this behavior. The hypotheses can then be \
formulated as algorithms that capture the patterns and quantify them. SEE is \
a Mathematica based Software developed by us for the Exploration of \
Exploratory Behavior. The raw data for SEE are a time series of the animal 's \
coordinates in space, sampled at a rate that allows a meaningful computation \
of velocities..SEE permits i) a visualization of the path of the animal and a \
computation of the dynamics of activity; ii) a visualization of the \
decomposition of the path into several modes of motion (1st gear, 2nd gear, \
etc.,) and a computation of the typical speed, the spatial spread, and the \
proportion of each of these modes. iii) a visualization of the location in \
the environment of stopping episodes, along with a representation of the \
duration of each episode. These visualizations highlight the presence of \
preferred places, including the animal's so-called home base, and permits a \
computation of the spatio-temporal diversity in the location of stopping \
episodes. The software also iv) decomposes the animal's path into \
\"excursions\", and computes the number of stops per excursion; it v) \
generates a visualization of the phase space (path + velocity, traced in a \
three dimensional graph) of any progression segment or list of such segments; \
and it produces vi) a visualization of the way places in the animal's \
operational world are connected one to the other.
SEE also permits the definition and computation of behavioral endpoints \
across any section of any database of raw data. The range of applicability of \
SEE to various experimental setups, tracking procedures, species, and \
preparations is addressed in the discussion.
1. Introduction
The view that rat open field behavior is largely stochastic (e.g., File, \
1985) gave way recently to the realization that it is quite patterned. A \
series of studies have shown that this behavior includes several \
ethologically-relevant precisely definable and measurable patterns: when \
placed in a novel environment a rat establishes a home base from which it \
performs round-trips (excursions) into the environment (Eilam and Golani, \
1989). These excursions gradually grow in amplitude, having a slow and \
intermittent outbound portion and a fast and continuous inbound portion. With \
extended exposure, this velocity profile changes in a predictable manner \
(Tchernichovski et al., 1998). The rat's trajectory in the environment \
consists of several modes of motion (1st , 2nd and 3rd gears); progression \
without leaving 1st gear (lingering; Drai et al., 2000) defines what has been \
previously labeled \"stopping behavior\", and the number of stops per \
excursion is constrained by an upper bound (Golani et al., 1993).  (
Aspects of this structure have been uncovered in long-term studies of tame \
wild rats, hooded laboratory rats in a variety of environments and contexts ( \
), and drug-treated preparations (). To establish a comparative study of this \
complex structure it was necessary to develop a special tool of visualization \
and analysis. This tool would highlight regularities, help generating new \
hypotheses, and allow statistical inferences about the structure of the \
behavior.
Recent studies demonstrating the vulnerability of behavioral measures to \
environmental manipulations (    ), have aroused an interest in ethologically \
relevant parameters of rodent behavior. This is because such parameters might \
be more resistant to environmental manipulations. The interest in ethological \
parameters (e.g.,   ), and the need for high throughput phenotyping of mouse \
behavior (e.g., Nolan ), coincides with our own interest in developing an \
algorithmic approach to the ethological study of rodent behavior. The present \
study is one in a series introducing this approach. As such, it is motivated \
by a search for intrinsic constraints, which should hopefully show relative \
stability across experimental protocols and thus provide more reliable \
measures in the study of the genome/behavior interface.  Being ethologically \
motivated, this study does not assume a priori constructs such as fear, \
anxiety, learning, or even investigation (although our software can readily \
be used within paradigms involving these constructs). Rather, it lets these \
and other constructs emerge as by-products of lower level movement processes. \
In the first paper in this series (Drai et al., 2000) we established the \
algorithmic definition and the subsequent classification of rodent locomotor \
behavior into 3 modes of motion. In the present paper we use this \
classification to present some of the visualization tools developed by us, \
describe their software implementation, which we call SEE (a Software for the \
Exploration of Exploration), and show how this low level classification \
generates hypotheses about how the animal occupies the environment, how it \
connects its various parts, how it distinguishes between inbound and outbound \
trips, etc. The third paper in this series is dedicated to the use of \
statistical inference for the establishment of behavioral endpoints that \
differentiate between two mouse strains. (  ).   
The level at which the behavior is analyzed is that of the whole animal \
considered as a moving point. The primary data are a time series of the rat's \
coordinates in space, sampled at a rate that permits a meaningful computation \
of velocities. These data, obtained by an automatic tracking system, are the \
input of our software environment. 
The first section of this paper is devoted to a review of some of the already \
established patterns of rat exploratory behaviorThe second section \
illustrates how these patterns and others can be visualized, then formalized, \
and finally measured with the help of SEE. The statistical tools for \
comparing these measurements across strains, species, or preparations are \
described elsewhere (Drai et al., in preparation).
In the third section of the paper we discuss the potential use of this \
approach in behavioral neuroscience and behavior genetics. An appendix \
provides a formal description of the software (specification of data objects \
and operators). The full implementation is available on request from the \
authors.
2. Background on the structure of exploratory behavior

2.1. Stops
The alternation between progression and stopping episodes in rat exploratory \
behavior is obvious even to an untrained observer. Until recently stopping \
was defined as a classical behavior pattern based on the observer's \
subjective judgement. In some studies the definition of a stop was based on \
an arrest of the hind legs (Golani et al., 1993), a criterion that is \
difficult to measure automatically. In other studies it was based on an \
arbitrary (though reasonable) threshold value for velocity (Cools et al 1997, \
Gingras and Cools 1997), e.g., if velocity is lower than 2 cm/s call it a \
stop.
The problem is that a stop does not necessarily imply complete arrest: during \
a so-called stop the rat may perform scanning movements, rearing, sideways \
and/or backward steps, and even a few forward steps of all four legs (for a \
video clip illustrating this behavior see http\\\\www.tau.ac.il~ilan99). \
Because so called stopping often involves low speed motion, and because we \
try to avoid ad hoc distinctions based on subjective judgement, we establish \
the distinction between stopping and progression on intrinsic statistical \
properties  of the behavior. (Drai et al, 2000). This is accomplished by the \
following steps: i) we establish the noise level of the system; ii) we define \
\"sub-noise\" periods as periods of  \"arrest\". iii)  We use arrest periods \
to segment the velocity time series into \"motion segments\" \
(\"inter-arrest\" intervals). iv) We establish the speed maxima (or a \
corresponding measure of the local spread of motion called \"local movement\" \
\"locmov\"-see Drai et al., 2000) of each of the motion segments. v) For each \
rat-session we plot the frequency distribution of the speed maxima (or \
\"locmov\") of all its motion segments. vi) We use a Gaussian mixture model \
to analyze the distribution of these maxima. This model is commonly used in \
electrophoresis, for example, for recognizing distinct components within a \
mixture (see section 1.3.3. in Appendix) vii) We estimate the parameters of \
the Gaussian model by using the Expectation-Maximization (EM) algorithm \
(Everitt, 1981). This algorithm estimates the maximum likelihood parameters \
(proportions, means, and standard deviations) of a mixture with a given \
number of Gaussians (section 1.3.3 in Appendix). Having the Gaussians at \
hand, we can finally establish the thresholds that distinguish between them; \
most important, the threshold that distinguishes between the leftmost \
Gaussian,  representing the progression mode with the lowest maximal \
velocities, previously termed \"stopping\" and now termed \"lingering\", \
\"staying in place behavior\", or \"1st gear mode\". Bouts in which the \
animal alternates between full arrest and lingering episodes are joined into \
a single episode of lingering behavior. In the hooded rat whose behavior is \
illustrated in this paper the threshold velocity distinguishing between \
lingering and progression segments was 16 + 1.99 (SD) cm/sec (based on 8 \
successive daily 1/2h sessions in a 6.5m diameter arena; the corresponding \
values for mice in a 3.2m diameter arena were, e.g., for Balbs \
\[Ellipsis]..and for c57s\[Ellipsis]\[Ellipsis]\[Ellipsis]\[Ellipsis]\
\[Ellipsis]..Drai, submitted). 

2.2. Movement segments
From the categorization of modes of motion described above, one can obtain a \
segmentation of the behavior into periods of stopping (lingering, staying in \
place, etc.,) and progression episodes or movement segments.   Peak \
velocities of movement segments range in the presently analyzed rat-sessions \
between a mean of 16+ 1.99 (SD) cm/sec and a mean of 286 + 50 (SD) cm/sec. 
 
2.3. The home base 
The rat's preference for one (or in some cases two) places can be shown by \
considering the spatial distribution of stops in the arena. In the preferred  \
place, the cumulative duration of staying in place (whether we consider \
cumulative dwell time of stops or total cumulative time including both \
progression and stopping) is of a higher order of magnitude compared to the \
values scored in all the other places. The number of stops is also the \
highest, and the incidence of grooming episodes is significantly higher than \
expected by the higher proportion of time spent in that place. This place is \
termed the rat's home base (Eilam and Golani, 1989).
In an arena devoid of any objects or places that suggest shelter, each rat \
establishes its own home base in a different place, early in the session \
(Eilam and Golani, 1989). This suggests that home base location involves the \
use of spatial memory, and is not selected de novo each time the rat returns \
to it. If, however, one object that is clearly more familiar is present, most \
rats establish their home base in that place. This property has been used to \
standardize home base location, thus simplifying the comparison across \
animals (Tchernichovski et al., 1995, 1998). Interestingly, home base \
location relative to the edge of the arena has been used by Cools and \
co-workers (Cools et al., 1989) as one of the features distinguishing between \
Apomorphine-Susceptible and Apomorphine-Unsusceptible selected \
sub-populations of hooded rats. 
2.4. The excursion
 Using the location of the home base as a reference point, it is readily seen \
that Exploratory Behavior, at least in its initial stages, can be viewed as \
consisting of roundtrips (excursions) performed from the home base. Home base \
behavior (including excursions) was reported in the Exploratory Behavior of \
several species of mammals (Barnett and Cowan, 1976; Chance and Mead, 1955; \
Menzel, 1978; Geyer, 1982; Van de Rijt-Plooij and Plooij, 1987). The \
excursion was defined as a round-trip that starts at the home base and ends, \
usually after the performance of one to several stops, also at the home base. \
Only the number of stops per excursions were scored (ignoring excursion \
mileage or duration). Using two robust statistical methods - density \
estimators and quantile plots - it has been shown that the number of stops \
per excursion fits a model of uniform distribution with an upper bound, \
rather than a model of normal or a geometric distribution (Golani et \
al.,1993). This means that the probability of returning to the home base \
increases after each additional stop until it equals 1 at the upper bound. \
This supports the hypothesis that home base location depends on memory, and \
returning to it is not elicited de novo at the end of each excursion. \
Moreover, by increasing the size of the arena from 2x2m to 8x8 m, this upper \
bound of stops could not be increased.  Instead, the rats cover the larger \
arena by scaling up the inter-stop distances. The distribution of the rate of \
stopping per time and/or distance unit  may account for many of the measured \
properties of Exploratory Behavior. For example, Whishaw et al (1994) have \
shown that the hyperactivity attributed to rats with Fimbria-Fornix lesions \
is not due to travel distance and speed but rather due to the presence of \
significantly more stops of shorter duration (and thus more movement \
episodes). The distribution of the number of stops per excursion can be \
modified by the psycho-stimulant drug d-amphetamine (Eilam and Golani, 1990), \
and has also been used to differentiate between the response of two strains \
of rats to amphetamine (Gingras and Cools, 1997; Cools et al., 1997).
2.5. Velocity profiles
 The velocity profile of the excursion undergoes a typical change in the \
course of Exploratory Behavior: initially, the outward part is slow and \
intermittent while the inward is fast and ballistic, without stopping \
(Tchernichovski and Golani, 1995), as if the home base exerts an attraction \
on the rat. With increasing exposure, and particularly in the course of \
several sessions, the proximal portion of the excursions becomes repulsive \
(low velocity in the outbound portion, high velocity in the inbound portion). \
It  retains its attractive character (low velocity outbound, high velocity \
inbound) only at the distal portion of the excursion (Tchernichovski et al., \
1998). These properties can be used to calculate a measure of familiarity for \
each place in the environment, and can be simulated by a simple dynamical \
model (Tchernichovski and Benjamini, 1998).
3. Illustrations of the capabilities of SEE 
3.1. The programming environment
The Mathematica software (Wolfram, 1996) mediates the interaction with SEE.  \
Mathematica is both a programming language and a graphical display tool. One \
can write and save function definitions, and use them afterwards in \
interactive Mathematica sessions. SEE is thus nothing but a collection of \
function definitions, written in the Mathematica programming language. A \
prerequisite to the use of SEE is the smoothing of the data, the computation \
of velocities and the computation of the segmentation of the behavior into \
modes of motion (Drai et al., 2000); all these must be saved in a format and \
under naming conventions described in the appendix.
 \tUsing SEE consists, therefore, in loading the appropriate function \
definitions and data, and then interactively visualizing the data or \
computing numerical attributes of the data by invoking a pre-defined \
function. In a more advanced mode, the user can also add new function \
definitions as the need arises. This is the main advantage of working in such \
an environment: it enables an easy and unlimited extension of the capacities \
of SEE, as new ideas about the structure of the data (exploratory behavior) \
emerge. 
Rather than start with a formal definition of the functions in SEE, we will \
present selected examples of how queries can be formed during a commentated \
typical session of Mathematica in which the functions are used. We will focus \
on one session of an animal (rat #3, fifth session) from an experiment with \
hooded rats in which the animals were exposed repeatedly to a large arena \
(6.5m diameter) for sessions of half an hour (Tchernichovsky et al., 1998). A \
few  computations or graphics pertain to all the 8 daily sessions of that \
animal. 
\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
Before starting to work with this notebook, evaluate  the See package \
notebook you downloaded with  this notebook \
\>", "Text",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The following series of commands defines the files that will be visualized \
and analyzed in this notebook:\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetDirectory["\<C:\See Data\>"]\n\n\), "\n", 
    \(c57files = FileNames["\<*C57*3*.dat\>"]\n\n\), "\n", 
    \(balbfiles = FileNames["\<*BalbMale*4*.dat\>"]\n\n\), "\n", 
    \(ratfiles = FileNames["\<*ofer*01*s5*.dat\>"]\n\n\), "\n", 
    \(twofiles = Join[c57files, balbfiles]\n\n\), "\n", 
    \(threefiles = Join[c57files, balbfiles, ratfiles]\)}], "Input"],

Cell[BoxData[
    StyleBox[\(C : \\\\  See\ Data\),
      "Output"]], "Output"],

Cell[BoxData[
    \({"mice NIH proposal_C57Male#3_1.dat"}\)], "Output"],

Cell[BoxData[
    \({"mice NIH proposal_BalbMale#4_1.dat"}\)], "Output"],

Cell[BoxData[
    \({}\)], "Output"],

Cell[BoxData[
    \({"mice NIH proposal_C57Male#3_1.dat", 
      "mice NIH proposal_BalbMale#4_1.dat"}\)], "Output"],

Cell[BoxData[
    \({"mice NIH proposal_C57Male#3_1.dat", 
      "mice NIH proposal_BalbMale#4_1.dat"}\)], "Output"]
}, Open  ]],

Cell["\<\
3.2. Visualizing and quantifying exploratory behavior with SEE
Mathematica having been launched, and the Notebook that contains the \
definitions of the SEE functions evaluated, one is in a position to ask the \
system to perform calculations and display graphics. As a first step the \
files pertaining to a specific session are loaded: the time series of \
positions and velocities, the segmentation of the data into episodes of \
motion, and the categorization of the segments into lingering, mid speed and \
high speed segments (see Appendix 1.3). All the SEE functions now refer \
implicitly to these data. We can start looking at the animal's behavior by \
evaluating the command\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Load",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["balbfiles",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["1",
                FontWeight->"Bold",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            StyleBox["]",
              FontWeight->"Bold"]}], 
          StyleBox["]",
            FontWeight->"Bold"]}], 
        StyleBox[";",
          FontWeight->"Bold"]}], 
      StyleBox[" ",
        FontWeight->"Bold"]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(See[PathPlot[{1, Length[data]}], 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
Mistroke
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
Mistroke
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
Mistroke
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
Mistroke
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
Mistroke
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
Mistroke
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
Mistroke
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
Mistroke
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
Mistroke
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
Mistroke
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
Mistroke
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
Mistroke
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
Mistroke
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
Mistroke
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
Mistroke
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
Mistroke
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
Mistroke
.07393 .49306 L
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
Mistroke
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
Mistroke
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
Mistroke
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
Mistroke
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
Mistroke
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
Mistroke
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
Mistroke
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
Mistroke
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
Mistroke
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
Mistroke
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
Mistroke
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
Mistroke
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
Mistroke
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
Mistroke
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
Mistroke
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
Mistroke
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
Mistroke
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mistroke
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
.08376 .46683 L
Mistroke
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
Mistroke
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
Mistroke
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
Mistroke
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
Mistroke
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
Mistroke
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
Mistroke
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
Mistroke
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
Mistroke
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
Mistroke
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
Mistroke
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
Mistroke
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
Mistroke
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
Mistroke
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
Mistroke
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
Mistroke
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
Mistroke
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
Mistroke
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
Mistroke
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
Mistroke
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
Mistroke
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
Mistroke
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
Mistroke
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
Mistroke
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
Mistroke
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
Mistroke
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
Mistroke
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
Mistroke
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
Mistroke
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
Mistroke
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
Mistroke
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
Mistroke
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
Mistroke
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
Mistroke
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
Mistroke
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
Mistroke
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
Mistroke
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
Mistroke
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
Mistroke
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
Mistroke
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
Mistroke
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
Mistroke
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
Mistroke
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
Mistroke
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
Mistroke
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
Mistroke
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
Mistroke
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
Mistroke
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
Mistroke
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
Mistroke
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
Mistroke
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
Mistroke
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
Mistroke
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
Mistroke
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
Mistroke
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
Mistroke
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
Mistroke
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
Mistroke
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
Mistroke
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
Mistroke
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
Mistroke
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
Mistroke
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
Mistroke
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
Mistroke
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
Mistroke
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
Mistroke
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
Mistroke
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
Mistroke
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
Mistroke
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
Mistroke
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
Mistroke
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
Mistroke
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
Mistroke
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
Mistroke
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
Mistroke
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
Mistroke
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
Mistroke
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
Mistroke
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
Mistroke
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
Mistroke
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
Mistroke
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
Mistroke
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
Mistroke
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
Mistroke
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
Mistroke
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
Mistroke
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
Mistroke
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
Mistroke
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
Mistroke
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
Mistroke
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
Mistroke
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
Mistroke
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mistroke
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
Mistroke
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
Mistroke
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
.09393 .45432 L
Mistroke
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
Mistroke
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
Mistroke
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
Mistroke
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
Mistroke
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
Mistroke
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
Mistroke
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
Mistroke
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
Mistroke
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
Mistroke
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
Mistroke
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
Mistroke
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
Mistroke
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
Mistroke
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
Mistroke
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
Mistroke
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
Mistroke
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
Mistroke
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
Mistroke
.08428 .40668 L
.08427 .40697 L
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
Mistroke
.08421 .41107 L
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
Mistroke
.09066 .41137 L
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
Mistroke
.08437 .41135 L
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
Mistroke
.08681 .41124 L
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
Mistroke
.0895 .41368 L
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
Mistroke
.0854 .41367 L
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
Mistroke
.08582 .40999 L
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
Mistroke
.08465 .4004 L
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
Mistroke
.08419 .41151 L
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
Mistroke
.08939 .41368 L
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
Mistroke
.08705 .41367 L
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
Mistroke
.08679 .41367 L
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
Mistroke
.08687 .41379 L
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
Mistroke
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
Mistroke
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
Mistroke
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
Mistroke
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
Mistroke
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
Mistroke
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
Mistroke
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
Mistroke
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
Mistroke
.08659 .41123 L
.08664 .41128 L
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
Mistroke
.09321 .45392 L
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
Mistroke
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
Mistroke
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
Mistroke
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
Mistroke
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
Mistroke
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
Mistroke
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
Mistroke
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
Mistroke
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
Mistroke
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
Mistroke
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
Mistroke
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
Mistroke
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
Mistroke
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
Mistroke
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
Mistroke
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
Mistroke
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
Mistroke
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
Mistroke
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
Mistroke
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mistroke
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
Mistroke
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
Mistroke
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
Mistroke
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
Mistroke
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
Mistroke
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
Mistroke
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
Mistroke
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
Mistroke
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
Mistroke
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
Mistroke
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
Mistroke
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
Mistroke
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
Mistroke
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
Mistroke
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
Mistroke
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
Mistroke
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
Mistroke
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
Mistroke
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
Mistroke
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
Mistroke
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
Mistroke
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
Mistroke
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
Mistroke
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
Mistroke
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
Mistroke
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
Mistroke
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
Mistroke
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
Mistroke
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
Mistroke
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
Mistroke
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
Mistroke
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
Mistroke
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
Mistroke
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
Mistroke
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
Mistroke
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
Mistroke
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
Mistroke
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
Mistroke
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
Mistroke
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
Mistroke
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
Mistroke
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
Mistroke
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
Mistroke
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
Mistroke
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
Mistroke
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
Mistroke
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
Mistroke
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
Mistroke
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
Mistroke
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
.37468 .03856 L
Mistroke
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
.34922 .0546 L
Mistroke
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
.30139 .08594 L
.30082 .08671 L
Mistroke
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
Mistroke
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
Mistroke
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
Mistroke
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
Mistroke
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
Mistroke
.20691 .16282 L
.20713 .16263 L
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
Mistroke
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
.24049 .12506 L
.24062 .12497 L
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
Mistroke
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
Mistroke
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
Mistroke
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
Mistroke
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
Mistroke
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
Mistroke
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
Mistroke
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
Mistroke
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
Mistroke
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
Mistroke
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
Mistroke
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
Mistroke
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
Mistroke
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
Mistroke
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
.38497 .03476 L
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
Mistroke
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
Mistroke
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
Mistroke
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
Mistroke
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
Mistroke
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
.29017 .08361 L
.29021 .08358 L
Mistroke
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
Mistroke
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
Mistroke
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
Mistroke
.18524 .17179 L
.18368 .17374 L
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
Mistroke
.13419 .25132 L
.13266 .25432 L
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
Mistroke
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
Mistroke
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
Mistroke
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
Mistroke
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
Mistroke
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
Mistroke
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
Mistroke
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
Mistroke
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
Mistroke
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
Mistroke
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
Mistroke
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
Mistroke
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
Mistroke
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
Mistroke
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
Mistroke
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
Mistroke
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
Mistroke
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
Mistroke
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
Mistroke
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
Mistroke
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
Mistroke
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
Mistroke
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
.09956 .71632 L
Mistroke
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
Mistroke
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
Mistroke
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
Mistroke
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
Mistroke
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
.07148 .49316 L
.07151 .49313 L
Mistroke
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
Mistroke
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
Mistroke
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
Mistroke
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
Mistroke
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
Mistroke
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
Mistroke
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
Mistroke
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
.08023 .60563 L
.08022 .60606 L
Mistroke
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
Mistroke
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
Mistroke
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
Mistroke
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
Mistroke
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
Mistroke
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
Mistroke
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
Mistroke
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
Mistroke
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
Mistroke
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
Mistroke
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
Mistroke
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
Mistroke
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
Mistroke
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
Mistroke
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
Mistroke
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
Mistroke
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
Mistroke
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
Mistroke
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
Mistroke
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
Mistroke
.687 .92341 L
.68712 .92334 L
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
Mistroke
.6875 .92598 L
.68731 .92601 L
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
Mistroke
.67651 .93258 L
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
Mistroke
.67402 .93246 L
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
Mistroke
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
Mistroke
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
Mistroke
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
Mistroke
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
Mistroke
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
Mistroke
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
Mistroke
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
Mistroke
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
Mistroke
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
Mistroke
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
Mistroke
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
Mistroke
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
Mistroke
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
Mistroke
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
Mistroke
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
Mistroke
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
Mistroke
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
Mistroke
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
Mistroke
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
Mistroke
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
Mistroke
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
Mistroke
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
Mistroke
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
Mistroke
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
Mistroke
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
Mistroke
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
Mistroke
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
Mistroke
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
Mistroke
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
Mistroke
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
Mistroke
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
Mistroke
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
Mistroke
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
Mistroke
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
Mistroke
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
Mistroke
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
Mistroke
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
Mistroke
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
Mistroke
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
Mistroke
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
Mistroke
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
Mistroke
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
Mistroke
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
Mistroke
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
Mistroke
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
Mistroke
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
Mistroke
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
Mistroke
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
Mistroke
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
Mistroke
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
Mistroke
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
Mistroke
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
Mistroke
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
Mistroke
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
Mistroke
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
Mistroke
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
Mistroke
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
Mistroke
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
Mistroke
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
Mistroke
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
Mistroke
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
Mistroke
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
Mistroke
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
Mistroke
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
Mistroke
.67231 .93392 L
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
Mistroke
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
Mistroke
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
Mistroke
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
Mistroke
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
Mistroke
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
Mistroke
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
Mistroke
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
.85306 .80019 L
.85302 .80022 L
Mistroke
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
Mistroke
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
Mistroke
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
.8538 .79278 L
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
Mistroke
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
Mistroke
.8738 .75155 L
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
Mistroke
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
Mistroke
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
Mistroke
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
Mistroke
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
Mistroke
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
Mistroke
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
Mistroke
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
Mistroke
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
Mistroke
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
Mistroke
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
Mistroke
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
Mistroke
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
Mistroke
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
Mistroke
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
Mistroke
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
Mistroke
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
Mistroke
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
Mistroke
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
Mistroke
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
Mistroke
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
Mistroke
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
Mistroke
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
Mistroke
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
Mistroke
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
Mistroke
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
Mistroke
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
Mistroke
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
Mistroke
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
Mistroke
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
Mistroke
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
.08937 .41149 L
.08908 .41118 L
.08868 .41073 L
.08821 .41015 L
.08771 .40943 L
.0872 .4086 L
.08671 .4078 L
.08625 .40694 L
.08578 .40606 L
.0853 .40516 L
.08486 .40443 L
.0845 .4038 L
.08425 .40328 L
.08409 .40289 L
.084 .40259 L
.08399 .40236 L
.08407 .40215 L
.0842 .40189 L
.08434 .40146 L
.0845 .40079 L
.08468 .39986 L
.08488 .39859 L
.08512 .39692 L
.08539 .39515 L
.08568 .39276 L
.08601 .39019 L
.08637 .3874 L
.08678 .38417 L
.08722 .38054 L
.08769 .37667 L
.08815 .37239 L
.08863 .36874 L
.08911 .36398 L
.08963 .36015 L
.0902 .35568 L
.09085 .351 L
.09157 .34648 L
.09229 .34188 L
Mistroke
.09304 .33794 L
.09381 .33363 L
.09457 .33014 L
.09523 .32673 L
.09598 .32352 L
.09662 .32057 L
.09724 .31839 L
.09785 .31632 L
.09843 .31466 L
.09894 .31324 L
.09937 .31212 L
.09972 .31147 L
.09999 .31095 L
.1002 .31061 L
.10036 .3104 L
.10049 .31032 L
.10059 .31026 L
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
.10062 .30982 L
.10056 .30963 L
.10053 .30937 L
.10055 .30906 L
.10063 .30868 L
.10078 .30827 L
.10096 .30785 L
.10118 .30744 L
.1014 .30709 L
.10158 .3068 L
.10172 .30662 L
.10187 .30646 L
.10204 .30632 L
.10227 .3062 L
.10255 .30602 L
.1029 .30572 L
.10333 .30524 L
.10386 .30449 L
.10454 .30339 L
.10539 .3019 L
.10643 .30015 L
.10752 .29802 L
.10892 .29582 L
.11039 .29324 L
.11209 .2902 L
.11384 .28711 L
.11574 .28413 L
.11752 .28085 L
.11941 .2775 L
.12129 .27414 L
Mistroke
.12307 .27098 L
.1249 .26778 L
.12671 .2647 L
.12853 .26157 L
.13049 .25844 L
.1324 .25523 L
.13444 .25188 L
.13649 .24866 L
.1386 .24501 L
.14076 .24164 L
.14299 .23805 L
.14531 .23434 L
.1475 .23089 L
.14976 .22731 L
.15224 .22351 L
.15436 .22016 L
.15671 .21649 L
.15906 .21276 L
.16165 .20913 L
.1639 .20533 L
.16633 .2017 L
.16879 .1981 L
.17113 .19446 L
.17346 .19099 L
.17579 .18749 L
.17798 .18398 L
.17999 .18071 L
.18202 .17732 L
.18397 .1738 L
.18584 .17083 L
.18755 .16781 L
.18925 .16488 L
.19079 .16256 L
.19232 .16023 L
.19363 .15828 L
.19484 .15646 L
.19604 .15493 L
.197 .15367 L
.19786 .15264 L
.19859 .15187 L
.19917 .15136 L
.19957 .1511 L
.19978 .15106 L
.19982 .15116 L
.19975 .15133 L
.19964 .15145 L
.19956 .15143 L
.1996 .15123 L
.19979 .1508 L
.20016 .15014 L
Mistroke
.20073 .14926 L
.20149 .14819 L
.20247 .14694 L
.20371 .1455 L
.20515 .14393 L
.20678 .14223 L
.20874 .14038 L
.21096 .13837 L
.21312 .13637 L
.2157 .13425 L
.21838 .13218 L
.22103 .13014 L
.22393 .12818 L
.22664 .1263 L
.22936 .12468 L
.23195 .12312 L
.2343 .12185 L
.23642 .12069 L
.23828 .11976 L
.23985 .11901 L
.24105 .11846 L
.242 .11811 L
.24272 .11794 L
.24322 .1179 L
.24355 .11796 L
.24375 .11809 L
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
.24425 .11881 L
.24447 .11856 L
.24481 .11814 L
.24533 .11754 L
.24608 .11676 L
.2471 .1158 L
.24843 .11478 L
.24997 .11356 L
.25179 .11211 L
.25405 .11064 L
.25651 .10894 L
.25932 .10708 L
.2627 .10514 L
.26561 .10319 L
.26893 .10107 L
.27257 .09909 L
.27569 .09696 L
Mistroke
.27906 .09495 L
.28232 .09285 L
.28565 .09059 L
.28874 .08849 L
.29197 .08615 L
.2954 .08397 L
.29875 .08165 L
.30248 .0792 L
.30607 .07692 L
.30991 .07448 L
.31399 .07207 L
.318 .06956 L
.32208 .06703 L
.32671 .06433 L
.33062 .06172 L
.33505 .05898 L
.33922 .0563 L
.34365 .0536 L
.34758 .05118 L
.35139 .04886 L
.35495 .04663 L
.35829 .04472 L
.36117 .04318 L
.36375 .0418 L
.36607 .04063 L
.36783 .03972 L
.36939 .03905 L
.37057 .03862 L
.37147 .0384 L
.37209 .03831 L
.37245 .03834 L
.37259 .03844 L
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
Mistroke
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
.37178 .03891 L
.37207 .03897 L
.37251 .03905 L
.37313 .03913 L
.37392 .03919 L
.37491 .0392 L
.3761 .03914 L
.3775 .03901 L
.37906 .0388 L
.38089 .03852 L
.38273 .03818 L
.38483 .03781 L
.38699 .03742 L
.38932 .03704 L
.39142 .03666 L
.39365 .03628 L
.39576 .03594 L
.39777 .03564 L
.39958 .03541 L
.40122 .03526 L
.40265 .03519 L
.40388 .03519 L
.40483 .03524 L
.40557 .03533 L
.40612 .03542 L
.40648 .03549 L
.40666 .03552 L
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
Mistroke
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
.40813 .03792 L
.4081 .03768 L
.40811 .03738 L
.40821 .03705 L
.40842 .03673 L
.40879 .03646 L
.40934 .03633 L
.41011 .0364 L
.41111 .03666 L
.41241 .03706 L
.41393 .03753 L
.4158 .03803 L
.41784 .03852 L
.4202 .03894 L
.42281 .03923 L
.42581 .03939 L
.42851 .03942 L
.43164 .03934 L
.435 .03915 L
Mistroke
.43803 .03889 L
.44126 .0386 L
.44449 .03828 L
.44801 .03803 L
.4509 .03779 L
.45414 .03762 L
.45758 .0375 L
.46068 .0374 L
.46394 .03726 L
.46717 .03704 L
.47057 .03673 L
.47423 .03637 L
.47754 .03598 L
.48106 .03559 L
.48474 .03528 L
.48809 .03504 L
.49179 .03489 L
.49522 .03485 L
.49887 .03495 L
.50249 .03524 L
.50586 .03571 L
.50943 .03633 L
.51277 .03706 L
.51608 .03792 L
.51945 .03887 L
.52288 .03985 L
.52618 .04078 L
.52948 .0416 L
.53279 .04234 L
.53611 .04304 L
.53938 .04371 L
.54263 .04441 L
.54579 .04515 L
.54897 .04595 L
.55192 .04682 L
.55474 .04777 L
.5574 .04875 L
.55975 .04973 L
.56187 .05057 L
.5637 .05148 L
.56524 .05242 L
.5664 .05323 L
.56725 .05396 L
.56783 .0546 L
.56816 .05512 L
.56829 .0555 L
.56832 .05573 L
.56836 .05583 L
.56851 .05583 L
.56884 .05579 L
Mistroke
.56941 .05577 L
.57029 .05578 L
.57153 .0558 L
.57308 .05584 L
.57513 .05588 L
.57758 .05586 L
.58033 .05577 L
.58339 .0556 L
.5867 .05534 L
.58988 .055 L
.59311 .05459 L
.59606 .05415 L
.59896 .05374 L
.60141 .05336 L
.60382 .05304 L
.60608 .05283 L
.608 .05277 L
.60989 .0529 L
.61179 .05325 L
.61374 .05382 L
.61579 .05462 L
.61783 .05558 L
.62 .05673 L
.62215 .05807 L
.62451 .05946 L
.62708 .06095 L
.63 .06241 L
.63257 .06381 L
.63533 .06515 L
.63805 .06633 L
.6409 .06734 L
.64344 .06823 L
.64607 .06899 L
.64869 .06963 L
.65132 .0702 L
.6542 .07073 L
.65707 .07125 L
.66011 .07179 L
.66342 .0724 L
.66668 .07308 L
.67012 .07385 L
.67371 .07464 L
.6771 .07557 L
.68062 .07666 L
.68395 .07793 L
.68741 .07922 L
.69048 .08062 L
.69368 .08213 L
.69688 .08364 L
.69977 .08512 L
Mistroke
.70295 .08662 L
.70566 .0879 L
.70825 .08922 L
.71068 .09037 L
.71285 .09144 L
.71491 .09237 L
.7164 .09311 L
.71767 .09366 L
.7187 .09397 L
.71942 .09407 L
.71984 .09398 L
.71998 .09373 L
.71989 .09338 L
.71965 .09302 L
.71935 .09273 L
.71907 .09253 L
.7188 .09243 L
.71862 .09244 L
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
.71997 .09534 L
.71983 .09519 L
.71969 .095 L
.71961 .09475 L
.71967 .09454 L
.71992 .09443 L
.72042 .09447 L
.7212 .09469 L
.72227 .09511 L
.72366 .09572 L
.72525 .09651 L
.72702 .0974 L
.72906 .09839 L
.73131 .09949 L
.73377 .10061 L
.73614 .10165 L
.7384 .10261 L
.74059 .10348 L
.74258 .10421 L
.74426 .10479 L
.7457 .10522 L
.74687 .1055 L
Mistroke
.74775 .10567 L
.74843 .10575 L
.74895 .10577 L
.74936 .10577 L
.74965 .10573 L
.74986 .1057 L
.75002 .10567 L
.75013 .10563 L
.75023 .10561 L
.75033 .10558 L
.75045 .10555 L
.75057 .10551 L
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
.75054 .10576 L
.75039 .10589 L
.75026 .10607 L
.75018 .10632 L
.75019 .10666 L
.75032 .10707 L
.75061 .10755 L
.75109 .10811 L
.7518 .10871 L
.75274 .10942 L
.75389 .11023 L
.75538 .11118 L
.75705 .11227 L
.75895 .11349 L
.76111 .11487 L
.76346 .11636 L
.76585 .11795 L
.76824 .11961 L
.77057 .12111 L
.77271 .12261 L
.77456 .12388 L
.77625 .12505 L
.77777 .12618 L
.77895 .12714 L
.77995 .12799 L
.78078 .12878 L
.78146 .12961 L
.78204 .13052 L
.78253 .13147 L
.78295 .13248 L
.78334 .13351 L
.78372 .13467 L
Mistroke
.78404 .1357 L
.78429 .13685 L
.78451 .13788 L
.78474 .13891 L
.785 .14004 L
.78531 .14095 L
.78573 .14184 L
.78629 .14271 L
.7871 .14361 L
.7882 .1445 L
.7896 .14547 L
.79116 .14649 L
.79296 .14787 L
.79495 .14946 L
.79702 .15126 L
.79939 .15325 L
.80206 .15544 L
.80438 .15771 L
.80677 .16011 L
.80905 .16251 L
.8111 .16499 L
.81293 .16729 L
.81464 .16968 L
.81613 .17194 L
.8175 .17423 L
.81883 .17656 L
.8201 .17879 L
.82136 .18079 L
.82263 .18278 L
.82387 .18466 L
.82514 .1865 L
.82644 .18818 L
.82771 .18985 L
.82905 .19145 L
.83039 .19303 L
.8317 .19457 L
.83308 .19619 L
.83449 .19798 L
.83592 .19981 L
.8375 .20194 L
.83922 .20411 L
.84081 .2066 L
.84256 .20898 L
.8443 .21164 L
.84609 .21425 L
.84792 .21689 L
.84954 .21937 L
.85111 .22168 L
.85248 .22379 L
.85364 .22535 L
Mistroke
.85451 .22663 L
.85516 .2276 L
.85557 .22825 L
.8557 .22855 L
.8556 .22852 L
.85533 .22823 L
.85492 .22775 L
.85442 .22716 L
.8539 .22655 L
.85338 .22594 L
.85289 .22538 L
.85249 .22496 L
.85219 .22467 L
.852 .22448 L
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
.8518 .2244 L
.85206 .22475 L
.85247 .22526 L
.85305 .22596 L
.8538 .22684 L
.85467 .22788 L
.85571 .22917 L
.85693 .23063 L
.85824 .23236 L
.85977 .23429 L
.86154 .23655 L
.86315 .23888 L
.86487 .24155 L
.86681 .24426 L
.86891 .24721 L
.87071 .25019 L
.87266 .25337 L
.8746 .25667 L
.87647 .25971 L
.8783 .2629 L
.88015 .26622 L
.88189 .26916 L
.8835 .27198 L
.88513 .27497 L
.88668 .27778 L
.88814 .28035 L
.88958 .28294 L
Mistroke
.89089 .28552 L
.89216 .28784 L
.89342 .29021 L
.89455 .29226 L
.89563 .29432 L
.89663 .29603 L
.89753 .29764 L
.89835 .29907 L
.89901 .3002 L
.89954 .3011 L
.89994 .30176 L
.90019 .30219 L
.90031 .30241 L
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
Mistroke
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
.89967 .30148 L
.89971 .30188 L
.89986 .30248 L
.90011 .30327 L
.9005 .30425 L
.901 .30543 L
Mistroke
.90161 .30667 L
.9023 .30815 L
.90301 .30987 L
.90382 .31174 L
.90459 .31371 L
.90536 .31588 L
.9061 .31802 L
.90678 .32055 L
.90735 .3225 L
.90782 .32486 L
.9082 .32728 L
.90851 .32942 L
.90876 .33159 L
.90898 .3339 L
.90918 .33618 L
.90941 .33834 L
.90962 .34036 L
.90981 .34222 L
.90993 .34377 L
.91 .345 L
.91005 .34605 L
.91008 .34692 L
.91008 .34761 L
.91007 .34811 L
.91006 .34847 L
.91004 .34869 L
.91002 .34885 L
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
.91079 .34958 L
.91068 .34937 L
.9105 .34902 L
.91028 .34851 L
.91007 .34786 L
.90987 .34712 L
.90968 .34635 L
.90949 .34562 L
.9093 .345 L
.90911 .34453 L
.9089 .34427 L
.90868 .34425 L
.90843 .34449 L
.90815 .345 L
Mistroke
.90784 .34578 L
.90751 .34677 L
.90718 .3478 L
.90684 .34891 L
.9065 .35002 L
.90621 .35107 L
.90599 .35188 L
.90586 .35246 L
.90585 .35276 L
.90597 .35281 L
.90621 .35264 L
.90654 .35228 L
.90691 .35176 L
.9073 .3511 L
.90767 .35035 L
.90798 .34955 L
.90821 .3488 L
.90836 .34807 L
.90845 .3474 L
.90848 .34679 L
.90845 .34621 L
.90837 .34564 L
.90826 .34511 L
.90816 .34457 L
.90807 .34401 L
.90802 .34339 L
.90804 .34274 L
.90812 .34204 L
.90828 .3413 L
.90852 .34051 L
.90881 .33964 L
.90911 .33868 L
.90942 .33764 L
.90971 .33658 L
.90996 .33542 L
.91015 .33426 L
.91029 .33308 L
.91036 .3319 L
.91036 .33076 L
.91031 .32962 L
.91019 .32853 L
.91002 .32744 L
.90981 .32637 L
.90956 .32537 L
.90931 .32447 L
.90906 .32369 L
.90884 .32295 L
.90865 .32223 L
.90848 .32151 L
.90833 .32077 L
Mistroke
.9082 .32001 L
.90808 .31922 L
.90796 .31839 L
.90784 .31757 L
.90772 .31679 L
.90758 .31606 L
.90743 .31542 L
.90725 .31479 L
.90704 .31421 L
.90683 .31367 L
.90663 .31321 L
.90642 .3128 L
.90624 .31246 L
.90608 .31222 L
.90595 .31206 L
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
Mistroke
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
.90599 .31404 L
.90598 .31389 L
.90598 .31373 L
.90597 .31359 L
.90597 .31343 L
.90596 .31325 L
.90598 .31304 L
.90603 .31281 L
.90608 .31254 L
.90613 .31224 L
.90615 .31188 L
.90615 .31147 L
.90608 .311 L
.90592 .31043 L
.90564 .30975 L
.90524 .30896 L
.90474 .30811 L
.90415 .3072 L
.9035 .30627 L
.90289 .30542 L
.90222 .30462 L
.90151 .3039 L
.90073 .30327 L
.9001 .30276 L
.89954 .30236 L
.89905 .30205 L
.89866 .30187 L
.89847 .3018 L
.89848 .30184 L
.89861 .30206 L
.89884 .30231 L
.8991 .30254 L
.89931 .30274 L
.89943 .30292 L
.89943 .30311 L
.8993 .30332 L
.89903 .30357 L
.89858 .3039 L
.89795 .30429 L
.89717 .30474 L
.89638 .30525 L
.89554 .30576 L
.89464 .30625 L
.89372 .30667 L
Mistroke
.89291 .30703 L
.8925 .30728 L
.89224 .30737 L
.89221 .30731 L
.8924 .30712 L
.89273 .3068 L
.89313 .30643 L
.89367 .30604 L
.89439 .30573 L
.89503 .30555 L
.89571 .3056 L
.89643 .30593 L
.89706 .30659 L
.89763 .30759 L
.8982 .30887 L
.89881 .31045 L
.89948 .31243 L
.90021 .31473 L
.90097 .31725 L
.90189 .31999 L
.90294 .3227 L
.90395 .32564 L
.90517 .32869 L
.90647 .33192 L
.9077 .33535 L
.90902 .33876 L
.9103 .34242 L
.9115 .34636 L
.91257 .34999 L
.91354 .35378 L
.9144 .35802 L
.91517 .36144 L
.91589 .36549 L
.91653 .36902 L
.91714 .37285 L
.9177 .37674 L
.9182 .38039 L
.91864 .38415 L
.91901 .38805 L
.91933 .39178 L
.91962 .39544 L
.91988 .3993 L
.92012 .40302 L
.92033 .40693 L
.92052 .41056 L
.92071 .41421 L
.92088 .41765 L
.92105 .42099 L
.92122 .42426 L
.92141 .42729 L
Mistroke
.92163 .43041 L
.92187 .43319 L
.92214 .4359 L
.92243 .43866 L
.92271 .44108 L
.92298 .44347 L
.92324 .44559 L
.92348 .44739 L
.92368 .44893 L
.92384 .45003 L
.92395 .45079 L
.92401 .45119 L
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
.92083 .44535 L
.9209 .4452 L
.92105 .44508 L
.92123 .44504 L
.92139 .44512 L
.92151 .44541 L
.92155 .44597 L
.92145 .44683 L
.92122 .448 L
.92087 .44953 L
Mistroke
.92045 .45121 L
.91996 .45322 L
.91941 .45552 L
.91884 .45789 L
.91832 .46022 L
.91784 .46281 L
.91743 .46585 L
.91712 .46843 L
.91694 .47107 L
.91691 .47382 L
.91702 .47667 L
.9173 .47923 L
.91769 .48205 L
.91815 .48482 L
.9187 .48774 L
.91929 .49088 L
.9199 .49384 L
.92054 .49694 L
.92119 .49974 L
.92183 .50242 L
.92249 .50482 L
.92311 .50683 L
.92373 .50853 L
.92432 .51001 L
.9249 .51133 L
.92546 .51245 L
.92601 .51355 L
.92658 .51469 L
.92716 .51583 L
.92775 .51719 L
.92836 .51881 L
.92899 .52058 L
.92962 .52279 L
.93024 .52526 L
.93081 .52817 L
.9313 .53113 L
.93168 .53453 L
.93196 .53753 L
.93211 .5407 L
.93215 .54386 L
.93209 .54678 L
.93193 .54963 L
.93171 .55209 L
.93146 .55436 L
.9312 .55628 L
.93093 .55798 L
.93069 .55938 L
.9305 .56045 L
.93037 .56124 L
.9303 .56176 L
Mistroke
.9303 .56203 L
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
.93141 .56043 L
.93121 .56074 L
.93093 .56128 L
.93058 .5621 L
.93015 .56321 L
.92965 .56464 L
.92909 .56627 L
.92845 .56815 L
.92773 .57031 L
.92693 .57259 L
.92607 .57519 L
.92524 .57772 L
.92438 .58051 L
.92362 .58335 L
.92287 .5864 L
.92223 .58928 L
.92161 .59236 L
.92101 .59535 L
.92042 .59841 L
.91983 .60138 L
.91923 .60431 L
.91861 .60715 L
.91803 .60974 L
.91746 .61212 L
.91694 .61425 L
.91648 .61606 L
.91608 .61766 L
.91573 .61886 L
.91544 .61978 L
.91524 .62043 L
.91514 .62081 L
.91516 .62094 L
.91527 .62087 L
.91547 .62067 L
.91571 .62042 L
.91597 .62021 L
.9162 .6201 L
.91638 .62013 L
.91644 .62031 L
.91636 .62067 L
.91612 .62121 L
Mistroke
.91567 .62194 L
.91503 .62288 L
.91422 .62402 L
.91328 .62533 L
.91215 .62684 L
.9108 .62849 L
.90954 .63015 L
.90812 .63184 L
.90667 .63357 L
.90556 .63524 L
.90426 .63714 L
.90325 .63887 L
.90234 .64068 L
.90152 .6426 L
.90084 .64465 L
.90036 .64683 L
.90005 .64891 L
.89986 .65121 L
.89972 .65378 L
.89958 .6563 L
.89944 .65912 L
.89926 .66214 L
.89895 .66521 L
.89854 .66856 L
.89805 .67156 L
.89759 .67446 L
.89714 .67711 L
.89672 .67944 L
.89635 .68152 L
.89603 .6832 L
.89578 .68463 L
.8956 .68578 L
.89548 .68661 L
.89542 .68711 L
.8954 .68734 L
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
.89542 .68653 L
.89515 .68679 L
.89483 .68709 L
.89451 .68741 L
.89421 .68774 L
.89395 .68805 L
.89371 .68835 L
Mistroke
.89349 .68867 L
.89329 .68905 L
.8931 .68952 L
.89295 .69011 L
.89285 .69084 L
.8928 .69176 L
.89275 .69298 L
.89267 .69459 L
.89251 .69652 L
.89222 .69888 L
.89177 .70178 L
.89112 .70498 L
.89027 .70847 L
.88923 .71261 L
.8881 .71663 L
.88687 .72084 L
.8856 .72542 L
.8843 .72946 L
.88295 .73409 L
.88157 .7381 L
.88015 .74245 L
.87874 .74658 L
.87731 .75081 L
.8759 .75486 L
.87453 .75907 L
.87325 .76258 L
.87202 .76618 L
.87086 .76967 L
.86974 .77273 L
.86868 .77583 L
.86768 .77844 L
.86672 .78094 L
.86579 .7833 L
.86496 .78527 L
.86416 .78708 L
.86344 .78861 L
.86285 .78981 L
.86241 .79066 L
.86204 .7914 L
.8617 .79203 L
.86134 .79265 L
.86105 .79316 L
.86074 .79366 L
.86046 .79413 L
.86026 .79451 L
.86012 .79482 L
.86002 .79504 L
.85993 .79518 L
.8598 .79528 L
.85962 .79544 L
Mistroke
.85931 .79569 L
.85889 .79603 L
.85841 .79643 L
.8579 .79685 L
.8574 .79722 L
.85697 .79751 L
.85662 .7977 L
.85636 .7978 L
.85619 .79785 L
.85603 .79789 L
.85593 .79794 L
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
.85437 .79941 L
.8541 .79961 L
.85373 .79993 L
.85324 .80039 L
.85262 .80097 L
.85187 .80169 L
.85099 .80255 L
.85003 .80351 L
.849 .80455 L
.848 .80559 L
.8469 .80647 L
.84567 .8077 L
Mistroke
.84438 .80899 L
.84309 .81021 L
.84189 .81126 L
.8408 .81211 L
.83987 .81278 L
.83905 .81331 L
.83832 .81375 L
.83764 .81412 L
.83703 .81444 L
.83641 .81477 L
.83587 .81504 L
.83546 .81522 L
.8352 .81526 L
.83509 .81517 L
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
.83583 .81428 L
.83577 .81451 L
.83565 .81484 L
.83544 .8153 L
.83513 .81586 L
.83474 .81646 L
.83435 .81689 L
.83395 .81724 L
.83353 .81751 L
.83303 .81776 L
.83259 .81797 L
.83209 .81819 L
.83161 .81841 L
.83112 .81861 L
.83063 .81884 L
.83014 .81909 L
.82967 .81936 L
.82917 .81967 L
.82856 .82007 L
.82794 .82058 L
.82731 .8212 L
.82651 .822 L
.82566 .82294 L
.82476 .82394 L
.82394 .82487 L
.82305 .82575 L
.82217 .82655 L
Mistroke
.82136 .82725 L
.82055 .82789 L
.81995 .82848 L
.8194 .82903 L
.819 .82948 L
.81878 .8298 L
.81872 .82997 L
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
.81963 .82919 L
.81952 .82892 L
.81933 .82861 L
.81907 .82826 L
.81874 .82789 L
.81836 .82751 L
.81801 .82715 L
.81773 .82678 L
.81755 .82642 L
.81752 .82608 L
.81764 .82577 L
.81787 .82552 L
.81818 .82533 L
.81856 .8252 L
.81902 .82514 L
.81952 .82515 L
.82005 .82519 L
.82059 .8252 L
.82115 .82516 L
.82172 .82501 L
.8223 .82476 L
.82291 .82439 L
.82352 .8239 L
.82416 .82325 L
.82492 .82243 L
.82588 .82142 L
.82705 .82025 L
.82852 .81895 L
.83023 .8175 L
.83218 .81592 L
.83442 .81426 L
.83674 .81254 L
.83926 .81076 L
.84192 .80896 L
.84449 .80712 L
.84703 .80535 L
Mistroke
.84965 .80356 L
.85191 .80177 L
.85418 .80012 L
.85622 .79847 L
.85806 .79687 L
.85969 .79526 L
.86114 .79372 L
.86228 .79223 L
.86327 .79077 L
.86411 .78941 L
.86478 .78815 L
.86533 .78697 L
.86575 .78586 L
.86605 .78486 L
.86624 .78385 L
.86634 .78292 L
.86635 .78193 L
.86627 .78105 L
.86613 .78016 L
.86597 .77932 L
.86579 .77854 L
.86562 .77788 L
.86546 .7773 L
.86533 .77683 L
.86523 .77644 L
.86519 .77615 L
.86519 .77598 L
.86524 .77593 L
.86535 .77602 L
.86554 .77619 L
.86579 .77644 L
.86612 .77669 L
.86657 .77685 L
.867 .77687 L
.86753 .77666 L
.86814 .77615 L
.86883 .77528 L
.86963 .77402 L
.8705 .77239 L
.8715 .77032 L
.87255 .76784 L
.87371 .76473 L
.87487 .76187 L
.87611 .75815 L
.8773 .75491 L
.87855 .75096 L
.87983 .74688 L
.88105 .74316 L
.88231 .73938 L
.8835 .73559 L
Mistroke
.88465 .73191 L
.88573 .72837 L
.88673 .72506 L
.88757 .72201 L
.88832 .71933 L
.88899 .71676 L
.88953 .71471 L
.88998 .71287 L
.89032 .71131 L
.89057 .71013 L
.89074 .70927 L
.89085 .70871 L
.89089 .70838 L
.89087 .70824 L
.8908 .70822 L
.89066 .70825 L
.89046 .70824 L
.89018 .70813 L
.88982 .7079 L
.88938 .70753 L
.88887 .70706 L
.88828 .70649 L
.8877 .70588 L
.88709 .70525 L
.88648 .70466 L
.8859 .70412 L
.88542 .70367 L
.88506 .7033 L
.88484 .70304 L
.88478 .70287 L
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
Mistroke
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
.88236 .70926 L
.88242 .70908 L
.88257 .70876 L
.8828 .70828 L
.88307 .70767 L
.88343 .7069 L
.88388 .70597 L
.88438 .70484 L
.885 .70346 L
.8857 .70182 L
.88649 .6999 L
.8874 .69781 L
.88837 .69538 L
.88944 .69276 L
.8905 .68991 L
.89158 .68674 L
.89268 .68371 L
.89372 .68038 L
.89479 .67707 L
.89578 .67363 L
.89684 .67025 L
.8978 .66675 L
.89892 .66323 L
.89997 .65976 L
.90113 .65614 L
.90243 .65252 L
.90366 .64886 L
.90496 .64507 L
.90646 .64134 L
.90765 .63756 L
.90917 .63368 L
.91063 .62977 L
.91198 .62593 L
.9135 .62196 L
Mistroke
.91497 .61798 L
.91631 .61402 L
.91757 .61014 L
.91874 .60634 L
.91974 .60253 L
.92073 .59875 L
.92165 .59506 L
.92252 .59134 L
.92346 .58749 L
.92438 .58402 L
.92537 .58032 L
.9263 .57664 L
.92723 .57272 L
.92804 .56919 L
.9288 .56542 L
.92944 .56144 L
.92995 .55776 L
.93037 .55379 L
.93069 .5498 L
.93092 .54546 L
.93103 .54157 L
.93104 .5373 L
.93094 .53288 L
.93076 .52856 L
.93053 .52417 L
.93028 .51978 L
.93003 .51521 L
.92979 .51104 L
.92957 .50655 L
.92937 .50205 L
.92916 .49767 L
.92891 .49345 L
.92862 .48895 L
.9283 .48449 L
.92795 .47991 L
.92759 .47562 L
.92724 .47162 L
.9269 .46781 L
.92658 .46399 L
.92627 .46065 L
.92598 .45747 L
.92566 .45408 L
.92535 .45148 L
.92503 .44905 L
.92471 .44671 L
.92438 .44446 L
.92405 .44232 L
.92371 .44037 L
.92335 .43836 L
.92297 .43618 L
Mistroke
.9226 .43384 L
.92223 .43135 L
.92188 .4286 L
.92155 .42567 L
.92125 .42253 L
.92099 .41919 L
.92078 .41569 L
.9206 .4123 L
.92041 .40862 L
.92019 .40483 L
.91992 .40103 L
.91957 .39691 L
.91916 .39279 L
.91868 .38851 L
.91811 .3838 L
.91749 .37957 L
.91681 .37503 L
.91611 .37042 L
.9154 .36583 L
.91469 .36124 L
.914 .35683 L
.91334 .35265 L
.91271 .34864 L
.91211 .34488 L
.91155 .34142 L
.91102 .33832 L
.91054 .33556 L
.9101 .33322 L
.90971 .3312 L
.90937 .32955 L
.90909 .3282 L
.90884 .32715 L
.90864 .32635 L
.90848 .32572 L
.90836 .32521 L
.90829 .32473 L
.90825 .32426 L
.90822 .32377 L
.90821 .32326 L
.9082 .32262 L
.90819 .32183 L
.90816 .32087 L
.90808 .31977 L
.90793 .31851 L
.90768 .31704 L
.90733 .31545 L
.90688 .31365 L
.90632 .31172 L
.90565 .30963 L
.90487 .30753 L
Mistroke
.90399 .30528 L
.90297 .3029 L
.90182 .30036 L
.90043 .29758 L
.89902 .29481 L
.89741 .29175 L
.89565 .28849 L
.89375 .28507 L
.89163 .28156 L
.88962 .27792 L
.88745 .27435 L
.88504 .27063 L
.88294 .26712 L
.88062 .26341 L
.87813 .25957 L
.87581 .25592 L
.87339 .2522 L
.87101 .24853 L
.86849 .24499 L
.86629 .24171 L
.86402 .23833 L
.86184 .2351 L
.85951 .23176 L
.85736 .22866 L
.85514 .22543 L
.85295 .22217 L
.8508 .21895 L
.84871 .21584 L
.8467 .21267 L
.84462 .20944 L
.84267 .20656 L
.84061 .20332 L
.83847 .20003 L
.83642 .19699 L
.83422 .194 L
.83188 .19062 L
.82975 .18749 L
.82742 .1843 L
.82513 .18109 L
.82279 .17797 L
.82039 .17474 L
.81814 .17172 L
.81586 .16864 L
.81365 .16557 L
.81149 .16266 L
.80948 .15978 L
.80751 .15706 L
.80555 .15425 L
.80366 .15173 L
.80169 .14907 L
Mistroke
.79972 .1465 L
.79777 .14387 L
.79578 .14132 L
.79385 .13882 L
.79195 .13633 L
.79017 .13422 L
.78852 .13228 L
.787 .13048 L
.78567 .12885 L
.78459 .12758 L
.78373 .12653 L
.78313 .12573 L
.78279 .1252 L
.78268 .1249 L
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
Mistroke
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
.78498 .12519 L
.78479 .12517 L
.78451 .12515 L
.78411 .12516 L
.78358 .12522 L
.78292 .12534 L
.78212 .12555 L
.78121 .12585 L
.78022 .12623 L
.77917 .12671 L
.77812 .12726 L
.77717 .12787 L
.77623 .12853 L
.77543 .1292 L
.77476 .12986 L
.77422 .13042 L
.77381 .13087 L
.77354 .13113 L
.77341 .1312 L
.77338 .13105 L
.77343 .13067 L
.7735 .13009 L
.77353 .12932 L
.7734 .12832 L
.77305 .12708 L
.77246 .12573 L
.77161 .12414 L
.77054 .1224 L
.76922 .12062 L
.76764 .11865 L
.76591 .11687 L
.76406 .11503 L
.76205 .11325 L
.76001 .11162 L
.75752 .1099 L
.75539 .10851 L
.75322 .10716 L
.75084 .10583 L
Mistroke
.74828 .10455 L
.74552 .10329 L
.74241 .10199 L
.73956 .10063 L
.73628 .09934 L
.73284 .09788 L
.72919 .09629 L
.72534 .09477 L
.72125 .09303 L
.71657 .09115 L
.71253 .0892 L
.70763 .08704 L
.70333 .08521 L
.6996 .08335 L
.69515 .08142 L
.69123 .0797 L
.68712 .07795 L
.68341 .0765 L
.67955 .07491 L
.67612 .07358 L
.67254 .07228 L
.66967 .07101 L
.66683 .06983 L
.66404 .06875 L
.6619 .06779 L
.65999 .06697 L
.65838 .06633 L
.65716 .06581 L
.65623 .06539 L
.65558 .06505 L
.65518 .06476 L
.65501 .06455 L
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
Mistroke
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
.65572 .06477 L
.65532 .06459 L
.65476 .06433 L
.65406 .06399 L
.65321 .06358 L
.65223 .06314 L
.65124 .06267 L
.6501 .0622 L
.64899 .06174 L
.64785 .06128 L
.64673 .06085 L
.64572 .06047 L
.6449 .06016 L
.64429 .05995 L
.64386 .05982 L
.64359 .05978 L
.64339 .05979 L
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
Mistroke
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
Mistroke
.63692 .05734 L
.63684 .05739 L
.6367 .05755 L
.63649 .05785 L
.63621 .05828 L
.63584 .0588 L
.63539 .0594 L
.63485 .06009 L
.63428 .06077 L
.63368 .0615 L
.63311 .06212 L
.6326 .06264 L
.63219 .06304 L
.6319 .06332 L
.63175 .06345 L
.63174 .06346 L
.63183 .06335 L
.63198 .06315 L
.63213 .0629 L
.63234 .06264 L
.63259 .06244 L
.63292 .06234 L
.63336 .06237 L
.63398 .06264 L
.63482 .0629 L
.63588 .06327 L
.63717 .06378 L
.63863 .06441 L
.64037 .0651 L
.64224 .0658 L
.64419 .06648 L
.64648 .06712 L
.64877 .06768 L
.65142 .06817 L
.65379 .06863 L
.65625 .0691 L
.65864 .06957 L
.66092 .07005 L
.66303 .07054 L
.665 .07105 L
.66682 .07157 L
.66854 .07212 L
.6701 .0727 L
.67152 .0733 L
.67283 .07387 L
.67399 .07439 L
.67496 .07485 L
.67574 .07526 L
.67632 .07559 L
.67672 .07584 L
Mistroke
.67697 .07601 L
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
.67668 .07597 L
.67685 .07627 L
.67707 .07666 L
.67733 .07707 L
.67762 .07747 L
.67791 .07782 L
.67822 .07812 L
.67854 .07836 L
.67888 .07854 L
.67918 .07865 L
.67943 .07868 L
.67959 .0786 L
.67965 .0784 L
.67959 .07806 L
.67942 .07758 L
.67911 .077 L
.67865 .07634 L
.67799 .07566 L
.67711 .07496 L
.67598 .07423 L
.67457 .07346 L
.67294 .07265 L
.67098 .07173 L
.66864 .0707 L
.6663 .06958 L
.66339 .06832 L
.66041 .0669 L
.65722 .06555 L
.6533 .06383 L
.64998 .06238 L
.64613 .06087 L
.64215 .05919 L
.63772 .05739 L
.63365 .0558 L
.62937 .05425 L
.62459 .05238 L
.62057 .05088 L
.61573 .04936 L
Mistroke
.61158 .04774 L
.6065 .04618 L
.60254 .04458 L
.59804 .04301 L
.59401 .04179 L
.59 .04058 L
.5864 .03946 L
.58317 .03859 L
.58025 .0378 L
.57763 .03713 L
.57526 .03659 L
.57365 .03623 L
.57224 .03602 L
.57115 .03591 L
.57035 .03591 L
.56984 .03597 L
.56957 .03605 L
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
.57246 .03635 L
.57223 .03635 L
Mistroke
.57191 .03634 L
.57148 .03632 L
.57095 .0363 L
.57031 .03628 L
.56958 .03626 L
.56877 .03623 L
.56788 .0362 L
.56689 .03617 L
.56581 .03613 L
.56465 .03609 L
.56346 .03605 L
.56222 .036 L
.56096 .03596 L
.55969 .03592 L
.55849 .03588 L
.55728 .03584 L
.55605 .0358 L
.55472 .03576 L
.55344 .03572 L
.55209 .03567 L
.55065 .03563 L
.54914 .03558 L
.54757 .03553 L
.54604 .03548 L
.54482 .03543 L
.54358 .03539 L
.54242 .03536 L
.54154 .03533 L
.5407 .03533 L
.53992 .03534 L
.53921 .03535 L
.53856 .03533 L
.53787 .03528 L
.53704 .03517 L
.53597 .03503 L
.53457 .03485 L
.53286 .03466 L
.53052 .03445 L
.52755 .03425 L
.52476 .03406 L
.52105 .03386 L
.51654 .0337 L
.51267 .03355 L
.50794 .03343 L
.5033 .03333 L
.4993 .03327 L
.49487 .03325 L
.49121 .03327 L
.48752 .03331 L
.4847 .03336 L
Mistroke
.48218 .03341 L
.4801 .03344 L
.47858 .03344 L
.47734 .0334 L
.47639 .03334 L
.47572 .03329 L
.4752 .03325 L
.47473 .03322 L
.47427 .0332 L
.4738 .03319 L
.4733 .03318 L
.47276 .03316 L
.47221 .03314 L
.47164 .03312 L
.47103 .0331 L
.47042 .03308 L
.46989 .03307 L
.46947 .03306 L
.46917 .03305 L
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
.46966 .03306 L
.46939 .03305 L
.4689 .03304 L
.46815 .03302 L
.46712 .03299 L
.46584 .03295 L
.46431 .0329 L
.46253 .03285 L
.46054 .03279 L
.45868 .03272 L
.45662 .03266 L
.45473 .0326 L
.45288 .03254 L
.45115 .03249 L
.44977 .03244 L
.44865 .03238 L
.44779 .03231 L
.4472 .03222 L
Mistroke
.44682 .03214 L
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
.44046 .03656 L
.44008 .03649 L
.43947 .03641 L
.43857 .03632 L
.43733 .03622 L
.43574 .03612 L
.43377 .03602 L
.43133 .03593 L
.42862 .03582 L
.4254 .03573 L
.42215 .03563 L
.41865 .03551 L
.41497 .03538 L
.41097 .03525 L
.4075 .03512 L
.40366 .03502 L
.40003 .03496 L
.3964 .03494 L
.39311 .03499 L
.38963 .03512 L
.38645 .03534 L
.3832 .03567 L
.38012 .03614 L
.37691 .03676 L
.37412 .03746 L
.37144 .03824 L
.36879 .03907 L
Mistroke
.36651 .03996 L
.36426 .04087 L
.36238 .04181 L
.36063 .04275 L
.35914 .04363 L
.35786 .04447 L
.35679 .04527 L
.35593 .046 L
.35529 .04667 L
.35481 .04727 L
.35445 .04778 L
.35416 .04824 L
.35393 .04862 L
.35371 .04895 L
.3535 .04921 L
.35334 .04942 L
.35324 .04958 L
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
.354 .04888 L
.35369 .04881 L
.35315 .04884 L
Mistroke
.35232 .04902 L
.35115 .04942 L
.34964 .05007 L
.3477 .05101 L
.34527 .05223 L
.34269 .05361 L
.33959 .05519 L
.3363 .05708 L
.33265 .05912 L
.32896 .06132 L
.32485 .06377 L
.3211 .06601 L
.31713 .06847 L
.31302 .07078 L
.30937 .07299 L
.30547 .07529 L
.30211 .07726 L
.29864 .07928 L
.29567 .08109 L
.29277 .08291 L
.29025 .08456 L
.28803 .08611 L
.28616 .08746 L
.28458 .08868 L
.28336 .08971 L
.28245 .09049 L
.28177 .09112 L
.28127 .09163 L
.28087 .09207 L
.28049 .09246 L
.28007 .09287 L
.2796 .0933 L
.27909 .09379 L
.27851 .09432 L
.27787 .09488 L
.27725 .09542 L
.27662 .09604 L
.27609 .09662 L
.27563 .09719 L
.27524 .09772 L
.27492 .09816 L
.27468 .09848 L
.27446 .09864 L
.27415 .0987 L
.27367 .09873 L
.27293 .09876 L
.27185 .09889 L
.27033 .09922 L
.26834 .09983 L
.2663 .10078 L
Mistroke
.26346 .10196 L
.26065 .10344 L
.2572 .1053 L
.25351 .10746 L
.24949 .10981 L
.24575 .11216 L
.24106 .1148 L
.23718 .11756 L
.2324 .1206 L
.22875 .12339 L
.22455 .12638 L
.22062 .1293 L
.21651 .13231 L
.21297 .13501 L
.20922 .13773 L
.20633 .14018 L
.20353 .14255 L
.20112 .14463 L
.1991 .14645 L
.19746 .14808 L
.19625 .14936 L
.19535 .15037 L
.19474 .15111 L
.19436 .15159 L
.19418 .15185 L
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
.19471 .15121 L
.19443 .15165 L
.19406 .15228 L
.19363 .15307 L
.19315 .15401 L
Mistroke
.19265 .15507 L
.19215 .15611 L
.19166 .15722 L
.19118 .15834 L
.19073 .15945 L
.19034 .16043 L
.19002 .1613 L
.1898 .16202 L
.18969 .16254 L
.18969 .16283 L
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
.19037 .16208 L
.19013 .1624 L
.18972 .163 L
.18908 .16393 L
.18817 .16523 L
.18696 .16696 L
.18559 .16886 L
.1839 .17132 L
.182 .17398 L
.17981 .17718 L
.17758 .18036 L
.17527 .1839 L
.17277 .18781 L
.17036 .1914 L
.16782 .19534 L
.16535 .19956 L
.16295 .20341 L
.16052 .2075 L
.15802 .2119 L
.15562 .21601 L
.15325 .22006 L
.15074 .22467 L
.14837 .22852 L
.14581 .233 L
.14335 .2369 L
.1408 .24113 L
.13817 .24544 L
.13566 .24941 L
.13314 .2534 L
.13068 .25729 L
.12822 .26124 L
.12592 .26485 L
.12363 .26855 L
.12132 .27246 L
Mistroke
.11904 .27624 L
.11688 .27975 L
.11461 .2837 L
.11236 .28755 L
.11015 .29105 L
.10791 .29492 L
.10592 .2984 L
.10397 .30193 L
.10217 .30535 L
.10057 .30841 L
.09909 .31131 L
.09791 .31373 L
.09692 .31593 L
.09611 .3178 L
.09552 .31925 L
.09513 .32038 L
.09495 .32117 L
.09493 .32164 L
.09503 .32184 L
.09518 .32181 L
.09535 .32164 L
.09549 .32138 L
.09557 .32112 L
.09557 .32091 L
.09548 .32084 L
.09532 .32098 L
.09508 .32138 L
.09478 .32211 L
.09438 .32326 L
.09389 .32488 L
.0933 .32698 L
.09261 .32974 L
.09183 .3328 L
.091 .33662 L
.09014 .34117 L
.08926 .34566 L
.08842 .35113 L
.08762 .35606 L
.08689 .36169 L
.08625 .36762 L
.08569 .37342 L
.08521 .37823 L
.08483 .38335 L
.08453 .38859 L
.08433 .39282 L
.08422 .39615 L
.08416 .39929 L
.08415 .40209 L
.08417 .40407 L
.0842 .4056 L
Mistroke
.08423 .40667 L
.08425 .40734 L
.08426 .40768 L
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
.08422 .41159 L
.08438 .41176 L
.08458 .41195 L
.08483 .41213 L
.08513 .41228 L
.08548 .41241 L
.08589 .41253 L
.08638 .41265 L
Mistroke
.08698 .41281 L
.08769 .41301 L
.08848 .41327 L
.08934 .41361 L
.09027 .41406 L
.09123 .41463 L
.09212 .41537 L
.09304 .41627 L
.0939 .41729 L
.09478 .41851 L
.09551 .41996 L
.09616 .42158 L
.09669 .42341 L
.09709 .42547 L
.09732 .42781 L
.09738 .43036 L
.09727 .43317 L
.09701 .43617 L
.09659 .43946 L
.09603 .44253 L
.09532 .44586 L
.09445 .44943 L
.09335 .45287 L
.092 .45647 L
.09051 .46027 L
.08874 .46404 L
.08675 .46757 L
.08434 .47139 L
.08251 .47519 L
.08008 .4793 L
.07828 .48308 L
.07594 .48713 L
.07407 .49136 L
.07243 .49569 L
.07099 .49994 L
.06969 .5043 L
.06866 .50799 L
.06793 .51165 L
.06748 .51482 L
.06726 .51758 L
.06721 .51978 L
.06725 .52145 L
.06733 .52266 L
.06743 .52348 L
.06745 .52401 L
.0674 .52433 L
.06735 .52457 L
.06735 .52489 L
.06741 .52544 L
.06753 .52631 L
Mistroke
.0677 .52755 L
.06794 .52932 L
.06824 .53177 L
.06863 .53473 L
.0691 .53839 L
.06967 .5425 L
.07035 .54705 L
.07106 .55225 L
.07183 .55708 L
.0726 .56291 L
.07331 .56802 L
.07401 .57374 L
.0747 .5799 L
.07537 .58514 L
.07608 .5915 L
.07679 .59671 L
.07753 .60276 L
.07834 .6082 L
.0792 .61357 L
.0801 .61908 L
.08099 .62433 L
.08159 .62952 L
.08248 .6353 L
.08334 .63999 L
.08422 .64523 L
.0851 .65021 L
.08591 .65472 L
.08662 .65931 L
.08718 .66295 L
.08759 .66638 L
.08789 .66968 L
.08808 .67215 L
.0882 .67436 L
.0883 .67634 L
.08841 .67798 L
.08857 .67933 L
.08877 .68044 L
.08903 .68143 L
.08933 .68241 L
.08969 .68339 L
.09008 .68452 L
.09051 .68584 L
.09097 .6874 L
.09144 .68911 L
.09187 .69097 L
.09226 .69285 L
.09259 .69466 L
.09286 .69632 L
.09306 .69774 L
.09318 .69899 L
Mistroke
.09324 .70003 L
.09324 .70085 L
.09321 .70143 L
.09316 .70178 L
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
.09321 .70088 L
.09344 .70151 L
.09375 .7025 L
.09413 .70386 L
.09458 .70556 L
.0951 .70768 L
.09571 .71018 L
.09638 .71256 L
.09708 .71564 L
.09782 .71849 L
.09856 .7216 L
.09928 .72482 L
.09995 .72775 L
.10056 .73056 L
.10111 .73293 L
.10158 .73499 L
.10197 .73663 L
.10229 .73798 L
.10254 .73906 L
.10272 .73989 L
.10282 .74053 L
.10287 .74102 L
.10289 .74136 L
.10287 .74162 L
.10283 .74185 L
.10278 .74208 L
.10274 .74234 L
.1027 .74268 L
.10267 .7431 L
.10266 .74357 L
.10265 .74401 L
.10265 .74437 L
.10264 .74468 L
.10264 .74492 L
.10264 .74509 L
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
Mistroke
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
.10247 .74294 L
.10262 .74313 L
.10287 .74344 L
.10321 .74387 L
.10368 .74441 L
.1043 .74506 L
.10509 .74585 L
.10608 .74679 L
.10724 .74791 L
.10864 .74923 L
.11017 .75064 L
.11198 .75227 L
.11392 .75419 L
.11612 .75637 L
.11846 .7589 L
.12125 .76172 L
.12417 .76481 L
.12691 .76815 L
.12995 .77172 L
.13309 .77529 L
.13626 .77909 L
.1395 .78304 L
.14289 .78682 L
.14633 .79084 L
.14996 .79486 L
.1533 .79868 L
.15706 .80255 L
.16064 .80647 L
.16442 .81051 L
.16821 .8141 L
.17204 .81798 L
.17613 .82183 L
.18001 .82589 L
.18408 .82982 L
Mistroke
.18814 .83384 L
.19236 .83795 L
.19642 .84192 L
.20051 .84582 L
.20478 .84976 L
.2088 .85366 L
.21297 .85729 L
.21701 .86104 L
.22109 .8649 L
.22497 .86829 L
.22888 .87194 L
.23236 .87509 L
.2357 .87803 L
.23855 .88073 L
.24118 .88313 L
.24338 .88526 L
.24512 .88715 L
.24647 .88853 L
.24739 .8896 L
.24791 .89036 L
.2481 .89081 L
.24802 .89097 L
.24775 .89083 L
.24735 .89055 L
.24696 .89022 L
.24668 .88994 L
.24659 .88979 L
.24677 .88983 L
.24725 .8901 L
.24804 .89057 L
.24914 .89131 L
.25057 .89221 L
.25232 .89327 L
.25419 .89441 L
.25649 .89569 L
.25898 .89714 L
.26162 .8986 L
.26462 .90022 L
.26775 .90186 L
.27116 .90357 L
.27464 .90531 L
.27862 .9069 L
.28251 .90862 L
.28619 .91029 L
.2903 .91199 L
.29485 .91374 L
.29884 .91547 L
.3036 .91719 L
.30788 .91892 L
.31246 .92056 L
Mistroke
.31702 .92218 L
.32145 .92378 L
.32583 .92536 L
.33026 .9269 L
.33471 .92847 L
.33901 .92997 L
.34341 .93151 L
.34799 .93302 L
.35218 .9346 L
.35669 .93607 L
.3612 .93771 L
.36562 .93917 L
.37015 .94067 L
.37472 .94219 L
.37928 .94376 L
.38383 .94534 L
.38824 .94683 L
.39271 .94818 L
.39712 .94957 L
.40157 .951 L
.406 .95237 L
.41005 .95371 L
.41409 .95503 L
.41824 .95639 L
.42224 .95772 L
.42609 .95899 L
.43003 .96023 L
.43382 .96141 L
.43765 .96258 L
.44139 .96361 L
.44525 .96455 L
.44895 .96536 L
.45254 .96601 L
.4561 .96653 L
.45955 .96693 L
.46266 .9672 L
.46566 .96734 L
.46827 .96735 L
.47065 .96726 L
.47275 .96708 L
.47446 .96686 L
.47588 .96665 L
.47697 .96646 L
.47774 .9663 L
.47822 .96618 L
.4785 .9661 L
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
Mistroke
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
.47597 .96608 L
.4759 .96594 L
.47585 .96579 L
.47581 .96567 L
.47581 .96558 L
.47589 .96551 L
.47617 .96544 L
.47671 .96536 L
.47757 .96527 L
.47876 .96518 L
.48039 .96509 L
.48239 .96501 L
.4849 .96496 L
.48782 .96491 L
.4911 .96482 L
.49492 .96465 L
.49912 .96435 L
.5037 .96389 L
.50854 .96325 L
.51372 .96243 L
.5191 .96147 L
.52438 .96046 L
.5301 .95941 L
.53546 .95834 L
.54136 .95728 L
.54686 .95623 L
.55274 .95518 L
Mistroke
.5582 .95417 L
.56412 .9532 L
.56989 .9523 L
.57564 .95145 L
.58143 .95066 L
.58668 .94989 L
.59227 .94911 L
.59757 .9483 L
.60304 .94742 L
.60815 .94661 L
.61344 .94568 L
.61807 .94467 L
.62294 .94368 L
.62756 .94268 L
.63235 .94168 L
.6363 .94072 L
.6402 .93983 L
.64405 .93902 L
.64765 .93828 L
.65114 .93762 L
.65468 .93699 L
.65778 .93639 L
.66071 .93577 L
.66365 .9351 L
.6665 .93433 L
.66936 .93345 L
.67199 .93244 L
.67474 .93131 L
.67757 .93006 L
.68057 .92867 L
.68376 .92707 L
.68708 .92524 L
.69067 .92333 L
.69428 .92115 L
.69824 .91882 L
.70216 .9163 L
.7061 .91381 L
.71002 .91107 L
.71401 .90846 L
.7178 .90586 L
.72179 .90298 L
.72573 .90007 L
.72959 .89751 L
.73326 .89475 L
.73699 .89202 L
.74073 .88921 L
.74445 .88644 L
.74838 .88346 L
.75192 .88079 L
.75572 .87794 L
Mistroke
.75967 .87506 L
.76346 .87216 L
.76737 .8693 L
.7713 .86638 L
.77537 .86332 L
.77909 .86047 L
.78286 .85746 L
.78667 .85456 L
.79005 .85174 L
.79354 .84897 L
.79697 .84624 L
.80046 .84354 L
.80385 .8408 L
.80736 .83809 L
.8108 .83534 L
.81423 .83253 L
.81779 .82978 L
.82121 .82696 L
.82459 .82425 L
.82794 .82159 L
.83111 .81894 L
.8342 .81641 L
.83717 .81405 L
.83978 .81178 L
.84222 .80965 L
.84433 .80769 L
.84615 .80596 L
.84769 .80445 L
.84893 .80318 L
.84995 .80215 L
.85075 .80134 L
.85142 .80071 L
.85195 .80021 L
.85237 .79981 L
.8527 .79946 L
.85294 .79914 L
.85314 .79881 L
.85325 .79846 L
.85333 .79805 L
.8534 .79757 L
.85348 .79697 L
.85359 .79627 L
.85367 .79555 L
.85371 .79488 L
.85369 .79428 L
.85363 .79379 L
.85355 .79348 L
.85345 .79336 L
.85337 .79343 L
.85333 .79366 L
Mistroke
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
.85295 .79839 L
.8533 .79833 L
.85389 .79807 L
.85452 .79766 L
.8554 .79693 L
.85646 .79586 L
.85765 .79438 L
.85911 .79246 L
.86074 .79002 L
.86257 .78714 L
.86455 .78379 L
.86664 .77986 L
.86873 .77599 L
.87084 .77154 L
.87287 .76678 L
.87479 .76219 L
.87656 .75737 L
.8782 .75268 L
.87969 .74824 L
.88099 .74412 L
.88214 .74051 L
.88312 .73704 L
.88393 .73431 L
.8846 .73169 L
.88516 .72947 L
.88564 .7274 L
.88606 .72545 L
.88643 .72362 L
.8868 .72185 L
.88724 .71996 L
.8878 .7178 L
.88849 .71533 L
.88935 .71251 L
Mistroke
.8903 .70909 L
.89144 .7054 L
.89266 .7011 L
.89399 .69669 L
.89549 .69164 L
.89694 .68691 L
.89868 .68164 L
.90036 .67572 L
.90197 .67049 L
.90378 .66468 L
.90545 .65876 L
.90721 .65249 L
.90882 .64688 L
.91043 .64093 L
.91205 .63459 L
.91341 .62926 L
.91483 .62355 L
.91628 .61783 L
.9176 .61214 L
.91898 .60648 L
.92027 .60095 L
.92151 .59586 L
.92268 .59096 L
.9238 .58634 L
.92481 .58227 L
.9257 .57866 L
.9265 .57546 L
.92716 .57271 L
.92767 .5706 L
.92805 .56901 L
.92828 .56787 L
.92839 .56718 L
.92841 .5669 L
.92835 .56694 L
.92823 .56718 L
.92808 .56752 L
.92793 .56791 L
.92779 .56827 L
.92769 .56854 L
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
.92768 .56796 L
.92766 .5678 L
Mistroke
.92765 .56762 L
.92766 .56739 L
.92771 .56705 L
.92779 .5666 L
.92791 .56603 L
.92807 .56539 L
.92826 .56468 L
.9285 .56393 L
.92876 .56316 L
.92905 .56238 L
.92936 .56161 L
.92968 .56086 L
.92998 .56014 L
.93026 .55948 L
.9305 .55888 L
.93071 .55836 L
.93087 .55799 L
.931 .55772 L
.93108 .55755 L
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
.93103 .55653 L
Mistroke
.9311 .55607 L
.93119 .55526 L
.9313 .55392 L
.93142 .55197 L
.93154 .54939 L
.93164 .54643 L
.93172 .54298 L
.93176 .53899 L
.93177 .53458 L
.93175 .52994 L
.93166 .52488 L
.9315 .52034 L
.93126 .51545 L
.93095 .51071 L
.93059 .50622 L
.93016 .50201 L
.92967 .49764 L
.92922 .49331 L
.92874 .48874 L
.92826 .48428 L
.92782 .47999 L
.92738 .47545 L
.927 .47067 L
.92666 .46666 L
.92638 .4624 L
.92613 .45846 L
.92594 .45532 L
.9258 .45227 L
.9257 .44999 L
.92562 .44807 L
.92555 .44663 L
.92546 .44568 L
.92534 .44497 L
.92516 .44425 L
.92491 .44336 L
.9246 .44216 L
.92425 .44059 L
.92386 .43845 L
.92342 .43584 L
.92297 .43266 L
.92253 .429 L
.92211 .42511 L
.92171 .42092 L
.92132 .41653 L
.92095 .41256 L
.92059 .40822 L
.92023 .40385 L
.91985 .39957 L
.91943 .39543 L
.91894 .39113 L
Mistroke
.91839 .38676 L
.9178 .38214 L
.91722 .3782 L
.91657 .37398 L
.91591 .36984 L
.91525 .36577 L
.91462 .36198 L
.91406 .3583 L
.91358 .35503 L
.91319 .35228 L
.91286 .3498 L
.91263 .34775 L
.91249 .34613 L
.91243 .34498 L
.91244 .34428 L
.91249 .34387 L
.91255 .34368 L
.91261 .34366 L
.91266 .34371 L
.91267 .34374 L
.91264 .34366 L
.91256 .34343 L
.91243 .343 L
.91226 .34235 L
.91207 .34147 L
.91185 .34035 L
.91163 .33906 L
.91139 .33757 L
.91114 .336 L
.91092 .33449 L
.9107 .33291 L
.91051 .33146 L
.91035 .33002 L
.91023 .32874 L
.91016 .32762 L
.91013 .32672 L
.91013 .32606 L
.91015 .32561 L
.91018 .3253 L
.91019 .32503 L
.91018 .32473 L
.91014 .32428 L
.91005 .32364 L
.9099 .32276 L
.90968 .32165 L
.90939 .32035 L
.90902 .31887 L
.90859 .31735 L
.90811 .31572 L
.90757 .31405 L
Mistroke
.90701 .31237 L
.90645 .3107 L
.9059 .30913 L
.90539 .30766 L
.90492 .30637 L
.90453 .30533 L
.90421 .30454 L
.90396 .304 L
.90378 .30368 L
.90366 .30353 L
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
Mistroke
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
.89591 .30151 L
.89609 .3013 L
.89632 .30095 L
.89659 .30041 L
.89681 .29963 L
.89696 .29858 L
.89695 .29722 L
.89673 .2955 L
.89631 .29358 L
.89566 .2913 L
.89472 .28869 L
.89351 .28576 L
.89202 .28266 L
.8902 .27887 L
.88834 .27559 L
.88615 .27182 L
Mistroke
.88382 .26788 L
.88147 .26375 L
.87878 .25932 L
.87638 .25527 L
.87372 .25103 L
.87084 .24635 L
.86826 .24245 L
.86549 .23818 L
.86274 .23389 L
.85979 .22991 L
.85737 .22577 L
.85479 .22212 L
.85236 .21847 L
.8499 .21506 L
.84766 .21176 L
.84546 .20852 L
.84327 .20546 L
.8411 .20236 L
.83889 .19927 L
.83666 .19611 L
.83438 .19291 L
.83197 .18941 L
.82958 .1861 L
.82701 .18252 L
.82444 .17926 L
.82153 .17544 L
.81886 .17169 L
.81617 .16786 L
.81352 .16428 L
.81069 .16038 L
.80795 .1566 L
.80518 .15285 L
.80256 .14919 L
.79999 .14574 L
.79755 .14241 L
.79539 .13934 L
.79333 .13649 L
.79146 .13388 L
.78982 .13161 L
.78841 .1297 L
.78724 .12809 L
.78635 .12689 L
.78565 .12598 L
.78514 .12535 L
.7848 .12498 L
.78461 .12481 L
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
Mistroke
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
.78487 .12528 L
.78473 .12507 L
.78458 .12482 L
.78446 .12456 L
.78435 .12428 L
.78424 .12399 L
.78407 .12367 L
.78382 .12329 L
.78348 .12286 L
.78305 .1224 L
.7825 .1219 L
.78185 .12149 L
.78112 .12107 L
.78034 .12067 L
.77955 .12028 L
.77888 .11988 L
.77812 .11947 L
.77739 .11908 L
.77662 .1187 L
.77583 .11837 L
.77507 .11816 L
.77437 .1181 L
.7737 .11816 L
.77299 .11839 L
.77219 .11874 L
.77123 .11916 L
.77005 .11963 L
.76879 .12019 L
.76728 .1208 L
.76546 .12144 L
Mistroke
.76347 .12215 L
.76143 .12289 L
.75911 .12373 L
.75679 .12465 L
.75425 .12563 L
.75199 .12667 L
.74956 .1277 L
.74708 .1288 L
.74504 .12993 L
.74297 .13111 L
.7409 .13235 L
.73896 .13357 L
.73712 .13495 L
.73542 .13624 L
.73375 .13755 L
.73225 .1388 L
.73086 .13993 L
.7296 .1409 L
.72852 .14165 L
.72769 .14214 L
.727 .1424 L
.72645 .14247 L
.72606 .1424 L
.72584 .14224 L
.7258 .142 L
.72593 .14177 L
.72624 .14153 L
.72668 .14141 L
.72725 .14145 L
.72794 .14172 L
.72872 .14231 L
.72957 .14329 L
.73053 .14456 L
.73159 .14636 L
.73282 .14836 L
.73423 .15081 L
.73565 .15344 L
.73727 .15638 L
.73899 .15916 L
.74078 .16231 L
.74268 .16522 L
.74463 .16835 L
.7466 .17146 L
.7487 .17466 L
.7508 .17797 L
.75287 .18118 L
.75505 .18458 L
.75707 .18802 L
.75915 .19152 L
.76127 .19527 L
Mistroke
.76321 .19849 L
.76515 .2018 L
.76707 .20511 L
.76876 .20786 L
.77039 .21054 L
.77182 .21286 L
.77305 .21495 L
.77406 .21652 L
.77484 .21785 L
.7754 .2187 L
.77577 .2193 L
.77601 .2196 L
.77612 .21965 L
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
.77541 .21886 L
.77552 .21916 L
.77579 .21962 L
.77624 .22027 L
.7769 .22112 L
.77778 .22211 L
.77887 .22326 L
.78015 .22456 L
.78137 .22591 L
.78295 .22728 L
.78442 .2286 L
.78594 .22975 L
.78744 .23079 L
.7888 .23162 L
.78998 .23233 L
.79104 .23298 L
.79188 .23344 L
.79264 .23388 L
.79334 .23428 L
.79403 .23469 L
.79478 .23515 L
.79566 .23571 L
.79672 .23642 L
.79794 .23727 L
.7994 .2384 L
.80114 .23973 L
.80316 .24134 L
.80549 .24318 L
.80817 .24516 L
.81094 .24736 L
.81401 .24946 L
Mistroke
.81702 .25162 L
.82028 .25389 L
.82364 .25606 L
.82685 .25806 L
.83032 .26008 L
.83374 .26199 L
.83725 .26378 L
.8408 .26531 L
.8447 .26664 L
.84788 .26776 L
.85135 .26862 L
.8549 .26929 L
.85797 .2698 L
.86101 .27017 L
.86384 .27041 L
.86644 .27055 L
.86861 .27063 L
.87061 .27065 L
.87232 .27063 L
.87377 .27058 L
.87508 .27055 L
.87625 .27056 L
.87737 .27064 L
.87846 .27083 L
.87949 .27113 L
.88055 .27151 L
.88154 .27195 L
.88257 .27244 L
.88358 .27295 L
.88457 .27349 L
.88546 .27406 L
.88625 .27465 L
.88689 .27524 L
.88739 .27586 L
.88776 .2765 L
.88802 .27716 L
.88819 .27782 L
.88831 .27849 L
.88843 .27916 L
.88857 .2798 L
.88872 .28042 L
.88887 .281 L
.88905 .2815 L
.88923 .2819 L
.88939 .2822 L
.8895 .28239 L
.88953 .28248 L
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
Mistroke
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
.88668 .28544 L
.88683 .28543 L
.88704 .28527 L
.88725 .28494 L
.88744 .28451 L
.88753 .28394 L
.88749 .28325 L
.88731 .28242 L
.88697 .2814 L
.88648 .28012 L
.88586 .27853 L
.88511 .27673 L
.88415 .27449 L
.88293 .27195 L
.88149 .26902 L
.87983 .26586 L
.87791 .26238 L
.87595 .25887 L
.87381 .25531 L
.87177 .25184 L
.86986 .24844 L
.86813 .24552 L
.86655 .24283 L
.86513 .24032 L
.86405 .23849 L
.86318 .23694 L
.86253 .23566 L
.86213 .23485 L
.86196 .23433 L
.86199 .23411 L
.86218 .23412 L
.86247 .23427 L
.8628 .2345 L
.86312 .23473 L
.86341 .23494 L
.86365 .2351 L
.86384 .23518 L
.86399 .23519 L
.86414 .23519 L
Mistroke
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
.86385 .23539 L
.86348 .23536 L
.86298 .23526 L
.86237 .23508 L
.86167 .23483 L
.86092 .2345 L
.86019 .23412 L
.85943 .2337 L
.85867 .23325 L
.85793 .23281 L
.85727 .23236 L
.85671 .23191 L
.85628 .23147 L
.85599 .23107 L
.85582 .23074 L
.85576 .23052 L
.8558 .23044 L
.85588 .2305 L
.85597 .2307 L
.85605 .23101 L
.85613 .23139 L
.8562 .23184 L
.85625 .23233 L
.85627 .23283 L
.85626 .23333 L
.85624 .23381 L
.85622 .23428 L
.85619 .23469 L
.85613 .23502 L
.85603 .2352 L
.85588 .23522 L
.85563 .23503 L
.85534 .2346 L
.8549 .23391 L
.85417 .23297 L
.85351 .23181 L
.85274 .23037 L
.85187 .22861 L
.85091 .22661 L
.84979 .22419 L
.84854 .22175 L
.84713 .21887 L
.84556 .21584 L
.84382 .21247 L
.84194 .20909 L
.83992 .2055 L
Mistroke
.83777 .20165 L
.83546 .19768 L
.83291 .19358 L
.83025 .18899 L
.82742 .18487 L
.82438 .18022 L
.82116 .17544 L
.81791 .17086 L
.81461 .16597 L
.81118 .16103 L
.80779 .15616 L
.80444 .15158 L
.80091 .14651 L
.79763 .14232 L
.79419 .13795 L
.79078 .13393 L
.78725 .13026 L
.78406 .12706 L
.78077 .12414 L
.77764 .12145 L
.77466 .11935 L
.77169 .1174 L
.76854 .11561 L
.7658 .11398 L
.76293 .11242 L
.7599 .11099 L
.75695 .10952 L
.75375 .10797 L
.75062 .10639 L
.74706 .10468 L
.74354 .10287 L
.73949 .10087 L
.73545 .0989 L
.73103 .09673 L
.7259 .09457 L
.72143 .09248 L
.71609 .09028 L
.71118 .08818 L
.70575 .08596 L
.70078 .0839 L
.69564 .08179 L
.69063 .07974 L
.68597 .07769 L
.68151 .07588 L
.6773 .07406 L
.67317 .07241 L
.66971 .07083 L
.66631 .06938 L
.66298 .06802 L
.66022 .06686 L
Mistroke
.65754 .06578 L
.65495 .06478 L
.65262 .06383 L
.65028 .06292 L
.64786 .062 L
.64552 .06108 L
.64283 .06004 L
.64019 .05891 L
.63723 .05773 L
.63396 .05646 L
.63066 .05513 L
.62697 .05374 L
.62336 .05225 L
.61938 .05071 L
.61566 .04921 L
.61178 .04768 L
.60789 .04618 L
.60399 .0447 L
.60037 .04326 L
.59674 .042 L
.59316 .04081 L
.58992 .03972 L
.58679 .0388 L
.58372 .03798 L
.58088 .03728 L
.57796 .03671 L
.57523 .03629 L
.5724 .03601 L
.56944 .03586 L
.56659 .0358 L
.56341 .0358 L
.56019 .03581 L
.55691 .03581 L
.55316 .03575 L
.54972 .03561 L
.54595 .03541 L
.54162 .03517 L
.53797 .0349 L
.53379 .03463 L
.52953 .03436 L
.52515 .03411 L
.5207 .03389 L
.51631 .03369 L
.51153 .03353 L
.50736 .03339 L
.50264 .03328 L
.49839 .0332 L
.49461 .03316 L
.49059 .03316 L
.48731 .03318 L
Mistroke
.48399 .03323 L
.48158 .03328 L
.47948 .03333 L
.47767 .03336 L
.47628 .03335 L
.47511 .03332 L
.4741 .03327 L
.4732 .03321 L
.47225 .03316 L
.4711 .03311 L
.46959 .03307 L
.46781 .03301 L
.46549 .03294 L
.46255 .03286 L
.45948 .03275 L
.45581 .03264 L
.45192 .03251 L
.44795 .03237 L
.44401 .03222 L
.4402 .03207 L
.43661 .03196 L
.43372 .03187 L
.43073 .03183 L
.4285 .03181 L
.42657 .03179 L
.425 .03177 L
.42385 .03174 L
.42311 .03173 L
.42266 .03174 L
.42244 .0318 L
.42238 .03192 L
.4224 .03209 L
.42244 .0323 L
.42241 .03255 L
.4223 .03282 L
.42214 .0331 L
.42196 .0334 L
.42177 .03371 L
.42156 .03404 L
.42128 .03437 L
.42091 .03472 L
.42039 .035 L
.41971 .0353 L
.41886 .03557 L
.41789 .0357 L
.41684 .03575 L
.41573 .03571 L
.41461 .03562 L
.41353 .0355 L
.41247 .03537 L
Mistroke
.41144 .03527 L
.41045 .03517 L
.40955 .03509 L
.40875 .03502 L
.40806 .03497 L
.40752 .03495 L
.40712 .03495 L
.40684 .03496 L
.40664 .03502 L
.40651 .0351 L
.4064 .03519 L
.4063 .03529 L
.4062 .03538 L
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
.40694 .03536 L
.40664 .03526 L
.40604 .03518 L
.40505 .03514 L
.40361 .03515 L
.40162 .03523 L
.39931 .0354 L
.39654 .03565 L
.39312 .03599 L
.3897 .03645 L
.38557 .03704 L
.38185 .03774 L
.37767 .03858 L
.37372 .03958 L
.37024 .04064 L
.36679 .0418 L
.36397 .04301 L
.36131 .04412 L
.35931 .0452 L
.35775 .04619 L
.35662 .04707 L
Mistroke
.35588 .04781 L
.35545 .04843 L
.35524 .04895 L
.35518 .04936 L
.35521 .04965 L
.35529 .04982 L
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
.35571 .04931 L
.35534 .04924 L
.35486 .04921 L
.35428 .04925 L
.35362 .04938 L
.35289 .04961 L
.35212 .04996 L
.35134 .0504 L
.35053 .05094 L
.34971 .05152 L
.34893 .05216 L
.34823 .05282 L
.34763 .05349 L
.34717 .05412 L
.34682 .05475 L
.3466 .05532 L
.34649 .0558 L
.34648 .05613 L
.34653 .05628 L
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
Mistroke
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
.34666 .05386 L
.34629 .05392 L
.34581 .05407 L
.34514 .05437 L
.34428 .05481 L
.34321 .05535 L
.34193 .05598 L
.34047 .05667 L
.33893 .0574 L
.33721 .05817 L
.33532 .05897 L
.33346 .05979 L
.33153 .06063 L
.32957 .06148 L
.32776 .06229 L
.32602 .06313 L
.32435 .06394 L
.32283 .06469 L
.32143 .06541 L
.32029 .06611 L
.31934 .06678 L
.3186 .06747 L
.31807 .06805 L
.31774 .0686 L
.31759 .06907 L
.31759 .06941 L
.31767 .06974 L
.31781 .07004 L
.31798 .07032 L
.31816 .07056 L
.31833 .07075 L
.31848 .07088 L
.3186 .07096 L
.3187 .07095 L
Mistroke
.31879 .07085 L
.31885 .07063 L
.31891 .07037 L
.31896 .07003 L
.31901 .06968 L
.31906 .06934 L
.31915 .06902 L
.31925 .06871 L
.31932 .06845 L
.3193 .06828 L
.31913 .06821 L
.31878 .06828 L
.31819 .06851 L
.3173 .06901 L
.31604 .06971 L
.31432 .07073 L
.31218 .07206 L
.30952 .07368 L
.30614 .07567 L
.30307 .0777 L
.29929 .08004 L
.29484 .08244 L
.29103 .08495 L
.28657 .08742 L
.28236 .09004 L
.27752 .09253 L
.27389 .095 L
.26981 .09743 L
.26584 .09993 L
.26231 .10211 L
.25849 .10436 L
.2553 .10653 L
.25194 .10861 L
.24872 .11072 L
.2456 .11274 L
.24235 .11472 L
.23942 .11669 L
.23634 .11858 L
.23328 .12046 L
.2301 .12235 L
.2273 .12414 L
.22434 .12595 L
.2215 .1277 L
.21892 .12938 L
.21635 .13102 L
.21394 .13259 L
.21202 .13398 L
.2103 .13526 L
.20877 .13642 L
.20744 .13745 L
Mistroke
.20638 .1383 L
.2055 .13902 L
.20482 .1396 L
.20433 .14005 L
.20397 .14038 L
.20373 .14061 L
.20355 .14077 L
.20342 .14089 L
.20326 .14103 L
.20306 .14123 L
.20282 .14149 L
.20256 .14182 L
.20223 .14226 L
.20184 .14279 L
.20144 .14342 L
.20101 .1441 L
.20059 .14485 L
.20018 .14562 L
.19978 .14645 L
.1994 .14728 L
.19903 .14809 L
.19868 .14883 L
.19834 .14946 L
.19801 .14998 L
.19772 .15034 L
.19748 .15055 L
.1973 .15061 L
.19717 .15051 L
.19713 .15027 L
.19718 .14994 L
.1973 .14957 L
.19744 .14923 L
.19755 .14894 L
.19758 .14878 L
.19749 .1488 L
.19725 .14904 L
.19683 .14956 L
.19624 .15032 L
.19549 .15135 L
.1946 .15262 L
.1936 .15412 L
.19259 .15569 L
.19159 .15729 L
.19057 .15887 L
.18954 .1604 L
.1886 .16183 L
.18774 .16321 L
.18697 .16461 L
.18628 .16588 L
.18558 .16722 L
Mistroke
.18483 .16866 L
.18396 .17029 L
.18294 .17216 L
.18166 .17434 L
.18024 .17663 L
.17847 .17933 L
.17643 .18242 L
.1742 .18578 L
.17176 .18956 L
.16904 .19359 L
.16644 .19778 L
.16367 .20211 L
.16085 .20645 L
.15814 .2109 L
.15554 .21502 L
.15289 .21921 L
.15033 .22385 L
.14779 .22768 L
.1451 .23198 L
.14257 .23625 L
.13994 .24068 L
.13727 .24545 L
.13459 .24977 L
.13192 .25431 L
.12919 .25922 L
.12661 .26337 L
.1239 .26793 L
.12116 .27263 L
.11836 .27717 L
.11573 .28162 L
.1131 .28608 L
.11058 .29056 L
.1081 .29521 L
.10591 .29943 L
.10377 .30384 L
.10167 .30872 L
.09984 .31276 L
.09806 .31744 L
.09638 .32198 L
.09482 .32629 L
.0934 .3308 L
.09209 .33521 L
.09092 .3395 L
.0899 .3437 L
.08896 .34797 L
.08812 .35248 L
.08734 .35665 L
.08663 .3615 L
.08599 .36571 L
.08548 .37044 L
Mistroke
.08507 .37492 L
.08475 .37942 L
.08452 .38355 L
.08438 .38778 L
.0843 .39114 L
.08426 .3943 L
.08425 .39716 L
.08426 .39943 L
.08427 .4012 L
.0843 .40239 L
.08433 .40305 L
.08433 .4033 L
.08432 .40327 L
.08429 .40308 L
.08423 .40289 L
.08414 .40274 L
.08405 .40274 L
.08396 .40291 L
.08391 .4032 L
.08394 .40361 L
.08413 .40415 L
.08448 .40483 L
.085 .40569 L
.08574 .40675 L
.08672 .40803 L
.08777 .40948 L
.08906 .41116 L
.09025 .41305 L
.09145 .4152 L
.09278 .41747 L
.09377 .42008 L
.09465 .42291 L
.09537 .42611 L
.09586 .42939 L
.0961 .43303 L
.09607 .43668 L
.09574 .44058 L
.09516 .44419 L
.0944 .44796 L
.0934 .45178 L
.09235 .4552 L
.09114 .45866 L
.0898 .46202 L
.08829 .46525 L
.08678 .46844 L
.08496 .47167 L
.08331 .47488 L
.0814 .47826 L
.07955 .48173 L
.0775 .48562 L
Mistroke
.0755 .4896 L
.07386 .49374 L
.07227 .4985 L
.07078 .50315 L
.06959 .50823 L
.0687 .51338 L
.0681 .51858 L
.06779 .5238 L
.06771 .52895 L
.06781 .53383 L
.06806 .53836 L
.06843 .54243 L
.0689 .54626 L
.0694 .54933 L
.06992 .5523 L
.07043 .5548 L
.07094 .55719 L
.07145 .55967 L
.07194 .56227 L
.07244 .56479 L
.07292 .56762 L
.07341 .57082 L
.07391 .57386 L
.07442 .57733 L
.07494 .58102 L
.07543 .58402 L
.07593 .58745 L
.0764 .59065 L
.07681 .59315 L
.07715 .59534 L
.07741 .59715 L
.07761 .59847 L
.07777 .59927 L
.07789 .59962 L
.07799 .59966 L
.07807 .59954 L
.07814 .59937 L
.07824 .5992 L
.07838 .59912 L
.07857 .59919 L
.07884 .59941 L
.07916 .59969 L
.07954 .59992 L
.07996 .60008 L
.0804 .60015 L
.08084 .60018 L
.08126 .60016 L
.08164 .60011 L
.08195 .60009 L
.0822 .60014 L
Mistroke
.08238 .60034 L
.0825 .60074 L
.08257 .60142 L
.08263 .60245 L
.08266 .60389 L
.08267 .60571 L
.08265 .60805 L
.08263 .61079 L
.08262 .61409 L
.08267 .61763 L
.0828 .62172 L
.08302 .62593 L
.08333 .63046 L
.0837 .63521 L
.08414 .6401 L
.08463 .64522 L
.08519 .65058 L
.08579 .65595 L
.08646 .66132 L
.0872 .66705 L
.08797 .67244 L
.0888 .6776 L
.08967 .68325 L
.09053 .68798 L
.09142 .69295 L
.09229 .69773 L
.09313 .70177 L
.09396 .7058 L
.09474 .7094 L
.09551 .7127 L
.09627 .71541 L
.09699 .71784 L
.09764 .71983 L
.09818 .72153 L
.09861 .72296 L
.09893 .72412 L
.09915 .72503 L
.09931 .72574 L
.0994 .72625 L
.09947 .72657 L
.09954 .72674 L
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
Mistroke
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
.10294 .72838 L
.10292 .72867 L
.10291 .72911 L
.1029 .72974 L
.10288 .73038 L
.10287 .73118 L
.10285 .732 L
.10284 .73291 L
.10281 .73385 L
.10276 .73477 L
.10271 .73561 L
.10265 .73638 L
.10262 .73705 L
.10263 .73761 L
.10268 .73805 L
.10278 .73835 L
.10293 .73851 L
.10312 .73854 L
.10336 .73851 L
.10361 .73844 L
.10389 .73834 L
.10416 .73825 L
.10443 .73817 L
.10468 .7381 L
.10487 .73806 L
.10501 .73804 L
.1051 .73803 L
.10514 .73802 L
.10516 .73802 L
.10518 .73803 L
.10527 .73805 L
.10547 .73808 L
.10579 .73816 L
.10623 .73831 L
.10681 .73853 L
.10751 .73882 L
.10825 .7392 L
.10908 .7396 L
.10989 .74005 L
Mistroke
.11073 .74049 L
.11155 .74088 L
.1124 .74123 L
.11319 .74152 L
.114 .74172 L
.11486 .74187 L
.11577 .74193 L
.11675 .74187 L
.11786 .74164 L
.11903 .74128 L
.12046 .74072 L
.12192 .73999 L
.12351 .73913 L
.12536 .7382 L
.12699 .73724 L
.12874 .73631 L
.13053 .73536 L
.13211 .73447 L
.13346 .73365 L
.13462 .73294 L
.1355 .73236 L
.13609 .73197 L
.13637 .73177 L
.13632 .73173 L
.13596 .73185 L
.13539 .73214 L
.1348 .73258 L
.13431 .73319 L
.13392 .73398 L
.13366 .7349 L
.13352 .73596 L
.13351 .73715 L
.13369 .73848 L
.13417 .73987 L
.13481 .7411 L
.13585 .74243 L
.13694 .74385 L
.13822 .74546 L
.1395 .7472 L
.14082 .74902 L
.14207 .75109 L
.14314 .75351 L
.14409 .75622 L
.145 .75929 L
.14589 .76286 L
.1468 .76659 L
.14773 .77007 L
.1488 .77373 L
.15005 .77799 L
.15144 .78255 L
Mistroke
.15298 .78705 L
.15458 .79127 L
.15626 .79552 L
.15786 .79941 L
.15942 .80275 L
.16093 .80595 L
.16229 .80851 L
.16356 .81076 L
.16462 .81238 L
.16555 .81365 L
.16631 .81459 L
.16687 .81522 L
.16722 .81556 L
.16739 .81568 L
.16741 .81563 L
.16738 .8155 L
.16737 .81532 L
.16744 .81514 L
.16762 .815 L
.16796 .81496 L
.16845 .81503 L
.16905 .81517 L
.16974 .81535 L
.17049 .81556 L
.17125 .81581 L
.17203 .81609 L
.1728 .81639 L
.1735 .81668 L
.17411 .81695 L
.17457 .81711 L
.17488 .81715 L
.17501 .81707 L
.17502 .81694 L
.17493 .81678 L
.17479 .81664 L
.17464 .8166 L
.17456 .81674 L
.17462 .81714 L
.17488 .81782 L
.1754 .8188 L
.17621 .82008 L
.1773 .82169 L
.1786 .82338 L
.18015 .82539 L
.1819 .82757 L
.18381 .82979 L
.1857 .83194 L
.18761 .83402 L
.18942 .83571 L
.191 .83715 L
Mistroke
.19245 .83829 L
.19362 .8391 L
.19454 .83957 L
.19518 .83971 L
.19556 .83963 L
.19572 .83938 L
.19575 .83907 L
.19567 .83872 L
.19553 .83839 L
.19539 .83813 L
.19527 .83797 L
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
.19462 .8378 L
.19476 .83818 L
.19506 .83875 L
.19554 .83951 L
.19623 .84044 L
.19713 .84153 L
.19822 .84286 L
.19958 .84435 L
.20113 .84617 L
.20297 .8481 L
.20498 .85033 L
.20731 .85281 L
.20988 .85549 L
.21268 .85835 L
.21579 .86152 L
.21894 .86445 L
.22226 .8677 L
.22574 .87122 L
.22955 .87459 L
.23298 .87806 L
.23668 .88154 L
.24068 .88462 L
.24397 .88765 L
.24754 .89048 L
.25125 .89325 L
Mistroke
.2544 .89566 L
.25771 .898 L
.261 .9 L
.2643 .90193 L
.26782 .90377 L
.27114 .90561 L
.27464 .90718 L
.27833 .90889 L
.28223 .91045 L
.28601 .91203 L
.29001 .91354 L
.29393 .91502 L
.29775 .91631 L
.30153 .91755 L
.30495 .91867 L
.30816 .9196 L
.31108 .92039 L
.31368 .92106 L
.31596 .92159 L
.31793 .92199 L
.31959 .92228 L
.32096 .92246 L
.32207 .92255 L
.32296 .92256 L
.32364 .92253 L
.32415 .92249 L
.32452 .92247 L
.32476 .92245 L
.32489 .92245 L
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
.32406 .92214 L
.32468 .92244 L
.32565 .92286 L
.32703 .92342 L
.32887 .92412 L
.33105 .92499 L
.33351 .92594 L
.33664 .92722 L
.33995 .92849 L
.34385 .92992 L
Mistroke
.3482 .93154 L
.35276 .93329 L
.35721 .93516 L
.36208 .93683 L
.36707 .93864 L
.3721 .94035 L
.37676 .94206 L
.38164 .94382 L
.38642 .94542 L
.39114 .94709 L
.39584 .94871 L
.40045 .95029 L
.40499 .95178 L
.40917 .95323 L
.41354 .95455 L
.4179 .95585 L
.42252 .95716 L
.42626 .95841 L
.4304 .95967 L
.43433 .96086 L
.43841 .96203 L
.44212 .96311 L
.44584 .96406 L
.44941 .96493 L
.45264 .96567 L
.45573 .96625 L
.45833 .96671 L
.46074 .96705 L
.46278 .96731 L
.46445 .96746 L
.46577 .96754 L
.46678 .96757 L
.46746 .96754 L
.46787 .96748 L
.4681 .9674 L
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
Mistroke
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
.46546 .96059 L
.46553 .96078 L
.46562 .96102 L
.46567 .96127 L
.46569 .96148 L
.4657 .96171 L
.46572 .96193 L
.46576 .96214 L
.46581 .96235 L
.4659 .96255 L
.46599 .96279 L
.46606 .96305 L
.46612 .96325 L
.46621 .96345 L
.46636 .96365 L
.46657 .96382 L
.4668 .96396 L
.46704 .96405 L
.46728 .96406 L
.46746 .96399 L
Mistroke
.46752 .96381 L
.46747 .96355 L
.46727 .96323 L
.46694 .96283 L
.46651 .96243 L
.46607 .96212 L
.4657 .96194 L
.46537 .96193 L
.46511 .96207 L
.46493 .96231 L
.46491 .96255 L
.46504 .96298 L
.4654 .96356 L
.46604 .96426 L
.46699 .96498 L
.46828 .96567 L
.46996 .96626 L
.47199 .96672 L
.47439 .96701 L
.47719 .96709 L
.48039 .96696 L
.48401 .96663 L
.48783 .96618 L
.49238 .96563 L
.49663 .96505 L
.50143 .96443 L
.50687 .96379 L
.51156 .96315 L
.51674 .96251 L
.52197 .9619 L
.52765 .96131 L
.53252 .96074 L
.53789 .96017 L
.54335 .95959 L
.5485 .95896 L
.55386 .95826 L
.55927 .95746 L
.56478 .95658 L
.5702 .9556 L
.57584 .95455 L
.58135 .95348 L
.5869 .95236 L
.59201 .95127 L
.59707 .95019 L
.60189 .94916 L
.60627 .94824 L
.61018 .94747 L
.6137 .94687 L
.61672 .94641 L
.61908 .94609 L
Mistroke
.62106 .94589 L
.62257 .94578 L
.62363 .94572 L
.62431 .94569 L
.62466 .94569 L
.62471 .94571 L
.62453 .94573 L
.62418 .94574 L
.62375 .94575 L
.6233 .94575 L
.62287 .9457 L
.62248 .9456 L
.62218 .94545 L
.62197 .94523 L
.62197 .94496 L
.62224 .94463 L
.62279 .94426 L
.62367 .94383 L
.62487 .94336 L
.62645 .94286 L
.62846 .94236 L
.63094 .94179 L
.63381 .94121 L
.63697 .94059 L
.64052 .93994 L
.64436 .93925 L
.64833 .93856 L
.65227 .93786 L
.65627 .93718 L
.65979 .93652 L
.66333 .93591 L
.66649 .93537 L
.66912 .93487 L
.67152 .9344 L
.67363 .93396 L
.67535 .93358 L
.67689 .9333 L
.67817 .93313 L
.67927 .93304 L
.68009 .93302 L
.68069 .93303 L
.68122 .93304 L
.68174 .933 L
.68229 .93285 L
.68291 .93254 L
.6835 .93209 L
.6841 .93151 L
.68463 .93081 L
.68507 .93004 L
.68549 .9292 L
Mistroke
.68585 .9283 L
.68615 .92738 L
.68641 .9265 L
.68664 .92572 L
.68683 .92513 L
.68702 .92467 L
.68714 .92442 L
.68725 .92427 L
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
.68542 .92679 L
.68555 .92666 L
.68579 .92638 L
.68607 .92596 L
.68639 .92548 L
.68669 .92501 L
.68696 .92458 L
.68718 .92425 L
.68731 .92395 L
.68735 .92362 L
.68726 .92328 L
.68705 .92297 L
.68671 .92266 L
.68626 .92228 L
.68569 .9218 L
.68501 .92118 L
.68424 .92031 L
.68336 .91937 L
.68236 .91809 L
.68128 .91671 L
.68006 .91543 L
.67872 .91379 L
.67727 .91214 L
.67571 .91042 L
Mistroke
.67423 .90875 L
.67267 .90721 L
.67109 .90575 L
.6696 .90437 L
.66808 .90308 L
.6668 .90185 L
.66559 .90075 L
.66448 .8998 L
.66351 .89895 L
.6627 .89813 L
.66206 .89737 L
.66155 .89663 L
.66113 .89591 L
.66079 .89522 L
.66051 .89456 L
.66029 .89395 L
.66007 .8934 L
.65985 .89289 L
.65965 .89245 L
.65949 .89208 L
.65939 .89177 L
.65933 .89151 L
.6593 .89128 L
.65929 .89107 L
.6593 .89088 L
.65931 .89071 L
.65931 .89055 L
.65932 .89037 L
.65934 .89017 L
.65939 .88996 L
.65946 .88977 L
.65956 .88961 L
.65967 .8895 L
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
.66007 .88978 L
.66027 .88973 L
.66053 .88961 L
.66087 .88938 L
Mistroke
.66127 .88907 L
.6617 .88868 L
.66212 .88823 L
.66253 .88773 L
.66293 .8872 L
.66331 .88667 L
.66363 .88618 L
.66387 .88573 L
.664 .88536 L
.66399 .88508 L
.66382 .8849 L
.66348 .8848 L
.66297 .88475 L
.66231 .8847 L
.66153 .88464 L
.66068 .88454 L
.65984 .88435 L
.65902 .88414 L
.65822 .88385 L
.65744 .88352 L
.65674 .8832 L
.65615 .88287 L
.6557 .88252 L
.65535 .88216 L
.65507 .88174 L
.6548 .88125 L
.65453 .88067 L
.65422 .88002 L
.65381 .87929 L
.65329 .87848 L
.65272 .87762 L
.6521 .87668 L
.65149 .87576 L
.6509 .8748 L
.65032 .87382 L
.64981 .87294 L
.64936 .87212 L
.64897 .87132 L
.64864 .87055 L
.64838 .86978 L
.64818 .86902 L
.64802 .86826 L
.64788 .86746 L
.64776 .86664 L
.64762 .86572 L
.64745 .86475 L
.64723 .86367 L
.64695 .86247 L
.64664 .86129 L
.6463 .86013 L
Mistroke
.64597 .85904 L
.64565 .85806 L
.64536 .85723 L
.64511 .85657 L
.6449 .85609 L
.64471 .85571 L
.64453 .85539 L
.64436 .8551 L
.64419 .85481 L
.64406 .85451 L
.64396 .85422 L
.6439 .85395 L
.64389 .85372 L
.6439 .85352 L
.64393 .85335 L
.64397 .85319 L
.644 .853 L
.64401 .8528 L
.64401 .85259 L
.64401 .85241 L
.64401 .85226 L
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
Mistroke
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
.64213 .84433 L
.64208 .84458 L
.64202 .84495 L
.64194 .8454 L
.64175 .84592 L
.64142 .84648 L
.64096 .84704 L
.64036 .84754 L
.63961 .84794 L
.63873 .84825 L
.63781 .84847 L
.63686 .84861 L
.63586 .84869 L
.63485 .84873 L
.63386 .84875 L
.63295 .84877 L
.63227 .84876 L
.63176 .84871 L
.63138 .84859 L
.63115 .84844 L
.63102 .84835 L
.63095 .84835 L
.63087 .84849 L
.63071 .84879 L
.63043 .84927 L
.63003 .84996 L
.6295 .85086 L
.6288 .85198 L
.62787 .85334 L
.62688 .85475 L
.62557 .85656 L
.62439 .8583 L
.62316 .86013 L
.62188 .86203 L
Mistroke
.62061 .8639 L
.61941 .86562 L
.61839 .86705 L
.61749 .86827 L
.6167 .86928 L
.61601 .87009 L
.61541 .87071 L
.61488 .87115 L
.61444 .87141 L
.61411 .87149 L
.61392 .87139 L
.61382 .87123 L
.61378 .87106 L
.61375 .87097 L
.61369 .87104 L
.61359 .87131 L
.61344 .87179 L
.61325 .87251 L
.61303 .8735 L
.61281 .87482 L
.61259 .87652 L
.61238 .87862 L
.61211 .88085 L
.6118 .88348 L
.61148 .88658 L
.61117 .88965 L
.61091 .8932 L
.61073 .89659 L
.61063 .90017 L
.61063 .9039 L
.61073 .90704 L
.61095 .91028 L
.61123 .91342 L
.61162 .91612 L
.61208 .91866 L
.61259 .92093 L
.61317 .92296 L
.61379 .92483 L
.61442 .92662 L
.61504 .92845 L
.61565 .92984 L
.61625 .93136 L
.61683 .93273 L
.61736 .93402 L
.6178 .9352 L
.61814 .93635 L
.61835 .93736 L
.61843 .93823 L
.61835 .93897 L
.61809 .93961 L
Mistroke
.61765 .94009 L
.61714 .94043 L
.61655 .94071 L
.61593 .94097 L
.61527 .94119 L
.6148 .94147 L
.61434 .94184 L
.61397 .94225 L
.61368 .94264 L
.61354 .94305 L
.61357 .94348 L
.61371 .94389 L
.61395 .94424 L
.61424 .94451 L
.61454 .94469 L
.61473 .94478 L
.61479 .94477 L
.61466 .9447 L
.61437 .94461 L
.61393 .94444 L
.61334 .94421 L
.61261 .94401 L
.6118 .94383 L
.61095 .94363 L
.61011 .94344 L
.60932 .94324 L
.60864 .94312 L
.60805 .94297 L
.6076 .94283 L
.60727 .94275 L
.60706 .94269 L
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
Mistroke
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
.61203 .94337 L
.61171 .94336 L
.61121 .94331 L
.61053 .94319 L
.60979 .94307 L
.60905 .94297 L
.60826 .94282 L
.60758 .94263 L
.60707 .94244 L
.60675 .94225 L
.60665 .94212 L
.60674 .94204 L
.607 .94202 L
.60742 .94205 L
.60794 .9421 L
.60855 .94217 L
.60922 .94227 L
.60988 .94237 L
.61053 .9424 L
.61113 .94239 L
.61176 .94235 L
.61238 .94233 L
.61306 .94232 L
.61377 .94234 L
.61454 .94241 L
.61539 .94255 L
.61629 .94276 L
.61718 .94304 L
.61802 .94336 L
.61885 .9437 L
.61964 .94402 L
.62042 .94429 L
.62114 .9445 L
.62186 .94464 L
.62263 .94468 L
.6234 .94458 L
.62423 .94435 L
.62512 .94403 L
.62606 .94367 L
.62695 .94323 L
.62794 .94279 L
.62901 .94235 L
.63014 .94196 L
Mistroke
.63131 .94165 L
.63242 .94141 L
.63343 .94122 L
.63428 .94107 L
.63494 .94092 L
.6354 .9408 L
.6357 .94069 L
.63581 .9405 L
.63581 .94022 L
.63572 .93981 L
.63557 .93926 L
.63527 .93857 L
.63484 .9377 L
.63424 .93666 L
.63347 .93545 L
.63254 .93414 L
.63146 .93274 L
.63022 .93106 L
.62897 .92969 L
.62761 .92807 L
.62622 .92642 L
.62492 .92483 L
.62359 .92326 L
.62238 .92184 L
.62124 .92054 L
.62018 .91935 L
.61928 .91843 L
.61851 .91768 L
.61791 .91716 L
.61751 .91688 L
.61731 .91684 L
.61726 .91695 L
.61735 .91712 L
.61754 .91731 L
.61783 .91748 L
.61819 .91763 L
.61867 .91777 L
.6193 .91791 L
.62009 .91812 L
.62107 .91838 L
.62225 .91868 L
.62369 .91907 L
.62541 .91958 L
.62735 .92023 L
.62951 .921 L
.63184 .92179 L
.63439 .92263 L
.63681 .92349 L
.63945 .9244 L
.64195 .92516 L
Mistroke
.64451 .92581 L
.64712 .92644 L
.6495 .92694 L
.65169 .92733 L
.65381 .92765 L
.65574 .92784 L
.65746 .92801 L
.65904 .92818 L
.6604 .92835 L
.66162 .92856 L
.6627 .92879 L
.66365 .92906 L
.66436 .92938 L
.66499 .92969 L
.6655 .92998 L
.66588 .93023 L
.66614 .93045 L
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
.66554 .93161 L
.66541 .93182 L
.66526 .93211 L
.66513 .93247 L
.66509 .93288 L
.66514 .93326 L
.66532 .93356 L
.66562 .93382 L
.666 .934 L
.66652 .93409 L
Mistroke
.66712 .93403 L
.66784 .9338 L
.66867 .93336 L
.66956 .93272 L
.6705 .93189 L
.67143 .9309 L
.67234 .92983 L
.67316 .92868 L
.67384 .92752 L
.67432 .92642 L
.67461 .92546 L
.6748 .92463 L
.67491 .92395 L
.67494 .92344 L
.67493 .92312 L
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
.67365 .92482 L
.67374 .92497 L
.67393 .92509 L
.67425 .92515 L
.67473 .92516 L
.67536 .92517 L
.67614 .92519 L
.67707 .92518 L
.67819 .92518 L
.67954 .9251 L
Mistroke
.68115 .92491 L
.68314 .92453 L
.68537 .92394 L
.68796 .92314 L
.69086 .92214 L
.69396 .92093 L
.69744 .91953 L
.7011 .91793 L
.70454 .9162 L
.70837 .9142 L
.71221 .9119 L
.71631 .90933 L
.72061 .90669 L
.72432 .90387 L
.72835 .90099 L
.7324 .89805 L
.73626 .8951 L
.73982 .89221 L
.74351 .88918 L
.74714 .88613 L
.75048 .88324 L
.75404 .88025 L
.75725 .87738 L
.76017 .87467 L
.76307 .8721 L
.76558 .8698 L
.76788 .86767 L
.76984 .8657 L
.77146 .86404 L
.77283 .86256 L
.7739 .86126 L
.77467 .86017 L
.77517 .85927 L
.7754 .85854 L
.77541 .85798 L
.77525 .85751 L
.77499 .8571 L
.77466 .85675 L
.77431 .85642 L
.77395 .8561 L
.7736 .85578 L
.77325 .85548 L
.77294 .85519 L
.7727 .85492 L
.77254 .85466 L
.77244 .85438 L
.77234 .85404 L
.77226 .85359 L
.77215 .85304 L
.77197 .8524 L
Mistroke
.77168 .85167 L
.77125 .85085 L
.77067 .84995 L
.76993 .84897 L
.76906 .84796 L
.7681 .84692 L
.76711 .84602 L
.76607 .84516 L
.76505 .84449 L
.76406 .84389 L
.76321 .84348 L
.76248 .8431 L
.7619 .84281 L
.76149 .84265 L
.76124 .8426 L
.76111 .84263 L
.76104 .84273 L
.76097 .84282 L
.76081 .84298 L
.76051 .84315 L
.76003 .84333 L
.75937 .84348 L
.75846 .8437 L
.75727 .84406 L
.7558 .84461 L
.75418 .84543 L
.75238 .84643 L
.75037 .84744 L
.7482 .8488 L
.74581 .8498 L
.74378 .85103 L
.74179 .85223 L
.73972 .85329 L
.73794 .85426 L
.73662 .85516 L
.73534 .85592 L
.73437 .85654 L
.73362 .85698 L
.73309 .85724 L
.73275 .85732 L
.73255 .85723 L
.73241 .85703 L
.73218 .8567 L
.73176 .8563 L
.73111 .85582 L
.73018 .85528 L
.7288 .85465 L
.72717 .85388 L
.72511 .85296 L
.72291 .85193 L
Mistroke
.72052 .85077 L
.71785 .84951 L
.71532 .84824 L
.71241 .84691 L
.70988 .84557 L
.70726 .84419 L
.70468 .84282 L
.70258 .8416 L
.70049 .84042 L
.69876 .83944 L
.69717 .8386 L
.69569 .8379 L
.6943 .83734 L
.69299 .83687 L
.69165 .83651 L
.69024 .83623 L
.68874 .83603 L
.68713 .83589 L
.68561 .8358 L
.6838 .83571 L
.68173 .83559 L
.67967 .83539 L
.6774 .83513 L
.67497 .83479 L
.67268 .83441 L
.67028 .83401 L
.66804 .83359 L
.66603 .8332 L
.66415 .83284 L
.66256 .83252 L
.66117 .83224 L
.66002 .83199 L
.65905 .83174 L
.65828 .83146 L
.65769 .83118 L
.65725 .83094 L
.65695 .83079 L
.65678 .8307 L
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
.65678 .83132 L
.65645 .83107 L
.65605 .83059 L
Mistroke
.6556 .82989 L
.65511 .82898 L
.65459 .82793 L
.654 .82676 L
.65333 .82558 L
.65259 .82452 L
.65179 .8234 L
.65097 .82245 L
.65015 .82159 L
.64934 .82085 L
.64852 .82023 L
.64767 .81974 L
.64678 .81937 L
.64583 .81913 L
.64473 .81896 L
.64348 .81881 L
.64211 .81862 L
.64066 .81833 L
.63917 .81789 L
.63767 .8173 L
.63634 .81657 L
.63495 .8158 L
.63365 .81501 L
.63235 .81424 L
.63106 .8135 L
.62988 .81281 L
.62877 .8122 L
.62775 .81163 L
.62684 .81111 L
.62604 .81064 L
.62537 .81022 L
.62476 .80987 L
.62418 .80958 L
.62364 .80934 L
.62314 .80913 L
.62272 .80896 L
.62235 .80882 L
.62205 .80869 L
.62183 .80856 L
.62169 .80842 L
.62161 .80828 L
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
Mistroke
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
.62185 .80852 L
.62162 .80856 L
.62131 .80856 L
.62089 .80847 L
.62035 .80827 L
.6197 .80795 L
.61896 .8075 L
.61815 .80694 L
.6173 .80628 L
.61645 .80557 L
.61561 .80481 L
.61475 .80402 L
.6139 .80323 L
.61303 .80249 L
.61217 .80182 L
.61125 .80121 L
.61026 .80064 L
.60918 .80012 L
.608 .79964 L
.60674 .79918 L
.60555 .79873 L
.60425 .79826 L
.60304 .79776 L
.60184 .79725 L
.6007 .79673 L
.59966 .79622 L
.59877 .7957 L
.59803 .7952 L
.59748 .79476 L
.59711 .79439 L
.59693 .7941 L
.59691 .79387 L
.59699 .7937 L
.59715 .79361 L
.59735 .7936 L
.59757 .79368 L
.59773 .79384 L
.59776 .79408 L
.59758 .79438 L
.59717 .79474 L
.5965 .79518 L
.59553 .79568 L
.59422 .79626 L
.59275 .79688 L
.59094 .79756 L
.58882 .79828 L
Mistroke
.58671 .79903 L
.58446 .79978 L
.58171 .8005 L
.57928 .80116 L
.57666 .80175 L
.57405 .80224 L
.57158 .80266 L
.56924 .80301 L
.56735 .80331 L
.56566 .80358 L
.56419 .80382 L
.56295 .80401 L
.56201 .80414 L
.56126 .80422 L
.56069 .80425 L
.56031 .80425 L
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
.56161 .80363 L
.56133 .80378 L
.56084 .80409 L
Mistroke
.56011 .8046 L
.55912 .80534 L
.55783 .80636 L
.55637 .80765 L
.55465 .80922 L
.55263 .81113 L
.55038 .81324 L
.54806 .81561 L
.54542 .81833 L
.54274 .82083 L
.53982 .82396 L
.53712 .82656 L
.53413 .82935 L
.53118 .83228 L
.52823 .83505 L
.52506 .83792 L
.52235 .84036 L
.51927 .84307 L
.51665 .84533 L
.51394 .84765 L
.51143 .85006 L
.50876 .85248 L
.50657 .85479 L
.5044 .85729 L
.5023 .85978 L
.50028 .86236 L
.49828 .86511 L
.49645 .86752 L
.49458 .87029 L
.49262 .8729 L
.49058 .87577 L
.48864 .87863 L
.48679 .88107 L
.48482 .88357 L
.48273 .88609 L
.4807 .88827 L
.47878 .89026 L
.47692 .8921 L
.47523 .8937 L
.47372 .89504 L
.47232 .89619 L
.47103 .89717 L
.46984 .89794 L
.46877 .89853 L
.46769 .89897 L
.46655 .89925 L
.46536 .89941 L
.46409 .89945 L
.46274 .89942 L
.46133 .89932 L
Mistroke
.46008 .89918 L
.45876 .89902 L
.45746 .89885 L
.45624 .89867 L
.45504 .8985 L
.45399 .89834 L
.45307 .8982 L
.45234 .89808 L
.45181 .89797 L
.45152 .89784 L
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
.45211 .89744 L
.45177 .89779 L
.45121 .89835 L
.4504 .89916 L
.44939 .90031 L
.44815 .90183 L
.44682 .90352 L
.4453 .90551 L
.44354 .90787 L
.44161 .91037 L
.43955 .91343 L
.43747 .91623 L
.43522 .91936 L
.43301 .92274 L
.43097 .92585 L
.42892 .9292 L
.42692 .93252 L
.42523 .93513 L
.42371 .93769 L
.42238 .94017 L
.42123 .94248 L
.42039 .94418 L
.41974 .94566 L
.41922 .94691 L
.41879 .94786 L
.41837 .94853 L
.41783 .94894 L
.41708 .94914 L
.41605 .94918 L
.41466 .94907 L
.41289 .94884 L
.41121 .94844 L
.40913 .94796 L
.40647 .94747 L
Mistroke
.40414 .94695 L
.40147 .94642 L
.39836 .94583 L
.39579 .94519 L
.3931 .94453 L
.39065 .94386 L
.3884 .94321 L
.38634 .94258 L
.38467 .94199 L
.3833 .94148 L
.38214 .94107 L
.38117 .94077 L
.38043 .94054 L
.37992 .94035 L
.37961 .94018 L
.3795 .94002 L
.37954 .93988 L
.3797 .93974 L
.37994 .9396 L
.38021 .93948 L
.3805 .9394 L
.38078 .93936 L
.38104 .93936 L
.38128 .93938 L
.38148 .9394 L
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
Mistroke
.38195 .93988 L
.38163 .93965 L
.38113 .93925 L
.38044 .93864 L
.37954 .93782 L
.37844 .93679 L
.37726 .93562 L
.37584 .93421 L
.37419 .93259 L
.37251 .93082 L
.37064 .92886 L
.36869 .92669 L
.36675 .92451 L
.3647 .92217 L
.36274 .91978 L
.36072 .91743 L
.35873 .91494 L
.35676 .91252 L
.35478 .90996 L
.35279 .90735 L
.3508 .90464 L
.34888 .90186 L
.34693 .89896 L
.3451 .89609 L
.34323 .89316 L
.34137 .89027 L
.33958 .88731 L
.33774 .88444 L
.33599 .88156 L
.3343 .87869 L
.33266 .8758 L
.33111 .873 L
.32967 .87021 L
.3282 .86746 L
.32689 .86464 L
.32555 .86188 L
.32418 .85901 L
.32285 .8562 L
.32154 .85338 L
.32027 .85043 L
.31909 .84787 L
.31794 .84538 L
.31684 .84299 L
.3159 .84098 L
.31495 .83906 L
.31411 .83754 L
.31332 .83618 L
.31264 .83497 L
.31211 .83388 L
.31177 .83284 L
Mistroke
.31162 .83183 L
.31165 .83071 L
.3118 .82934 L
.31203 .82764 L
.31228 .82562 L
.31251 .82364 L
.3127 .82128 L
.31281 .81843 L
.31296 .81559 L
.31312 .81256 L
.31329 .8099 L
.31345 .8073 L
.31359 .80504 L
.31371 .80286 L
.31379 .80113 L
.31384 .79961 L
.31391 .79835 L
.31403 .79729 L
.31421 .79634 L
.31449 .79544 L
.31486 .79456 L
.31532 .79365 L
.31584 .79275 L
.31637 .79181 L
.31685 .79083 L
.31734 .78977 L
.31782 .78865 L
.31827 .78758 L
.31869 .78666 L
.31908 .78591 L
.3194 .78533 L
.31963 .78497 L
.31981 .78482 L
.31994 .78484 L
.32 .78497 L
.32002 .78512 L
.32002 .78523 L
.32 .78524 L
.31994 .78507 L
.31981 .78465 L
.31958 .78393 L
.3192 .78285 L
.31863 .78148 L
.31785 .77972 L
.31693 .77777 L
.31573 .77542 L
.31438 .77291 L
.31271 .76997 L
.31103 .76702 L
.30904 .76373 L
Mistroke
.30693 .76026 L
.30495 .75698 L
.30271 .75348 L
.30043 .74999 L
.29806 .74641 L
.29581 .74309 L
.29357 .73975 L
.29135 .7364 L
.28931 .73334 L
.28727 .73017 L
.28529 .72699 L
.28336 .72373 L
.28158 .7206 L
.27984 .71732 L
.27816 .71402 L
.2766 .71053 L
.2751 .70721 L
.27364 .70372 L
.27229 .70023 L
.27097 .69694 L
.2698 .69352 L
.26869 .68996 L
.26775 .68706 L
.26688 .68413 L
.2661 .68125 L
.26544 .67882 L
.26487 .67652 L
.26438 .6744 L
.26396 .6726 L
.26364 .67089 L
.26338 .66927 L
.26318 .66768 L
.26303 .66616 L
.26289 .66467 L
.26275 .6632 L
.26263 .66181 L
.26252 .66053 L
.26243 .65935 L
.26237 .65829 L
.26233 .65736 L
.26232 .65654 L
.26233 .65582 L
.26237 .65518 L
.26241 .65464 L
.26245 .65419 L
.26246 .65383 L
.26247 .65353 L
.26247 .6533 L
.26247 .6531 L
.26247 .65293 L
Mistroke
.26248 .65279 L
.26248 .65266 L
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
.26247 .65286 L
.26248 .65253 L
.26248 .65199 L
.26249 .65119 L
.2625 .65013 L
.26252 .64878 L
.26253 .64738 L
.26254 .64555 L
.26253 .64372 L
.2625 .64163 L
.26246 .63942 L
.26244 .63712 L
.26244 .63489 L
.26251 .6326 L
.26265 .6304 L
.26288 .62833 L
.2632 .62621 L
.26359 .62423 L
.26405 .62231 L
.26455 .62039 L
.26504 .61868 L
.26555 .61702 L
.26604 .6155 L
.26649 .61412 L
.2669 .61292 L
.26728 .61197 L
.26762 .61123 L
.26793 .61076 L
.26823 .61057 L
.26852 .61063 L
.26881 .6109 L
.26914 .61134 L
.2695 .61189 L
.26991 .61252 L
Mistroke
.2704 .61316 L
.27095 .61382 L
.27152 .61447 L
.27207 .61505 L
.27255 .61552 L
.27289 .61584 L
.27304 .61596 L
.27297 .61587 L
.27268 .61553 L
.27217 .61495 L
.2715 .61409 L
.27069 .61295 L
.2698 .61151 L
.26893 .60996 L
.26799 .60789 L
.26712 .60567 L
.2663 .60303 L
.26555 .60005 L
.26494 .59688 L
.26444 .59361 L
.26411 .5901 L
.26388 .58613 L
.26374 .58291 L
.26365 .57915 L
.26355 .5756 L
.26342 .5718 L
.26324 .56827 L
.26303 .56452 L
.26281 .56068 L
.26255 .55739 L
.26227 .55381 L
.26197 .55024 L
.26164 .54658 L
.26129 .5429 L
.26093 .5393 L
.26056 .53548 L
.26019 .53166 L
.25983 .5283 L
.25947 .52464 L
.25908 .52092 L
.25865 .51779 L
.25817 .51447 L
.25766 .51135 L
.25716 .5084 L
.25671 .50586 L
.25635 .50361 L
.2561 .50164 L
.25592 .50001 L
.25573 .49875 L
.25547 .49767 L
Mistroke
.25509 .49673 L
.25454 .49593 L
.25379 .49524 L
.25286 .4946 L
.25177 .494 L
.25058 .49343 L
.24936 .4929 L
.24834 .49245 L
.24705 .492 L
.246 .49152 L
.24499 .49096 L
.24407 .49038 L
.24334 .48988 L
.24284 .4895 L
.24255 .48929 L
.2424 .48924 L
.24227 .48936 L
.24208 .48963 L
.2417 .49001 L
.24099 .49048 L
.23992 .49101 L
.23845 .49157 L
.23673 .49216 L
.23468 .49279 L
.23223 .49346 L
.22961 .49415 L
.22693 .49482 L
.22382 .49544 L
.22074 .49597 L
.21787 .49639 L
.21437 .49671 L
.21149 .49693 L
.20839 .49707 L
.20523 .49713 L
.202 .49711 L
.19854 .49704 L
.19566 .49688 L
.19221 .49662 L
.18918 .49623 L
.18578 .49572 L
.18254 .4951 L
.17904 .49437 L
.17587 .49355 L
.17236 .49266 L
.16926 .49169 L
.16597 .49061 L
.163 .48942 L
.15999 .48819 L
.15704 .48685 L
.15416 .48552 L
Mistroke
.15136 .48415 L
.14858 .48276 L
.14579 .48148 L
.14322 .48024 L
.14047 .47905 L
.13773 .47792 L
.13509 .47686 L
.13222 .47582 L
.12952 .47478 L
.12668 .47376 L
.12397 .4727 L
.12115 .47161 L
.1187 .47054 L
.11609 .46945 L
.11397 .4683 L
.11195 .46706 L
.11012 .46579 L
.10852 .46433 L
.10717 .46279 L
.10604 .46104 L
.10511 .45915 L
.10434 .45718 L
.10367 .45497 L
.1031 .45283 L
.10259 .45051 L
.10211 .44801 L
.10164 .44572 L
.10116 .44332 L
.10072 .44087 L
.10031 .43883 L
.0999 .43682 L
.09956 .43501 L
.09927 .43346 L
.09905 .43224 L
.09892 .43135 L
.0989 .43071 L
.09898 .43026 L
.09912 .42995 L
.09933 .42972 L
.09964 .42949 L
.10007 .42922 L
.10066 .42889 L
.1014 .42848 L
.10231 .42802 L
.10335 .42751 L
.10445 .42694 L
.10563 .42629 L
.10682 .42559 L
.10791 .42489 L
.109 .42425 L
Mistroke
.10992 .42369 L
.11073 .42325 L
.11143 .42292 L
.11201 .42273 L
.11249 .42267 L
.1129 .42276 L
.11329 .42295 L
.11367 .42325 L
.11407 .42367 L
.11452 .42421 L
.11503 .42486 L
.11565 .42561 L
.11637 .42643 L
.11715 .4273 L
.11796 .42816 L
.11873 .42901 L
.11945 .42982 L
.12009 .43057 L
.12067 .43128 L
.12118 .43187 L
.12165 .43242 L
.12214 .43301 L
.12269 .43358 L
.12334 .43423 L
.12412 .43496 L
.12503 .43583 L
.12617 .43687 L
.12755 .43816 L
.12903 .4397 L
.13079 .44123 L
.13253 .44301 L
.13451 .44483 L
.13655 .44689 L
.13857 .44868 L
.14071 .45045 L
.14253 .45208 L
.14433 .45355 L
.14596 .45478 L
.14731 .45574 L
.14849 .45648 L
.14946 .45701 L
.1502 .45734 L
.15074 .45753 L
.15109 .45762 L
.15128 .45764 L
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
Mistroke
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
.15076 .45723 L
.15102 .45723 L
.15139 .45723 L
.1519 .45723 L
.15256 .45722 L
.15336 .45722 L
.15438 .45722 L
.15557 .45721 L
.15697 .45721 L
.15844 .4572 L
.16008 .45719 L
.16171 .45718 L
.16336 .45712 L
.16497 .45701 L
.16639 .45686 L
.16767 .45667 L
.16881 .45651 L
.1697 .45641 L
.17041 .45642 L
.17095 .45661 L
.17131 .45704 L
.17151 .45776 L
.17161 .45883 L
.17165 .46031 L
.17169 .46224 L
.17176 .46409 L
.17188 .46671 L
.17208 .46961 L
.17245 .47238 L
.17298 .47567 L
.17374 .4795 L
.17461 .48256 L
.17563 .48608 L
.17682 .48924 L
.17807 .4924 L
.17945 .49505 L
.18084 .49752 L
.18231 .49974 L
.18387 .50157 L
.18545 .50324 L
.18721 .50472 L
.18916 .506 L
.19119 .50715 L
.19351 .50819 L
.19565 .50908 L
.198 .5099 L
Mistroke
.2005 .51065 L
.2028 .51131 L
.20525 .51192 L
.20784 .51244 L
.21008 .51283 L
.21257 .51308 L
.21468 .51314 L
.21689 .51307 L
.21895 .51275 L
.22091 .51224 L
.22281 .51156 L
.22467 .51077 L
.22644 .50989 L
.22819 .50899 L
.2299 .508 L
.23161 .50699 L
.2331 .50589 L
.23463 .50474 L
.2361 .50357 L
.23737 .50245 L
.23857 .50147 L
.23966 .50061 L
.24061 .49992 L
.24139 .4994 L
.24205 .49902 L
.24258 .49876 L
.24301 .49861 L
.24335 .49855 L
.24364 .49859 L
.24389 .49876 L
.24412 .49903 L
.24429 .49936 L
.2444 .4997 L
.24446 .5 L
.24446 .50024 L
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
Mistroke
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
.2438 .50047 L
.24377 .50027 L
.24385 .49994 L
.24405 .49944 L
.24441 .49876 L
.24498 .49788 L
.24579 .49681 L
.24687 .49551 L
.24812 .494 L
.24964 .49223 L
.2514 .49028 L
.25336 .48806 L
.25546 .48569 L
.25779 .48297 L
.26002 .48042 L
.26233 .47757 L
.26459 .47477 L
.26684 .47182 L
.26878 .46892 L
.2707 .46596 L
.27244 .46276 L
.27409 .45955 L
.27563 .45666 L
.27711 .45348 L
.27855 .45003 L
.27995 .44643 L
.28141 .44353 L
.28283 .44019 L
.28428 .43664 L
.28577 .43349 L
.28729 .43014 L
.28883 .42656 L
.29038 .42357 L
.29192 .4203 L
.29345 .41729 L
.29498 .41422 L
.29648 .41153 L
Mistroke
.2979 .40878 L
.29928 .40624 L
.30057 .40371 L
.30183 .40121 L
.30296 .39896 L
.30402 .39675 L
.30501 .39482 L
.30591 .39304 L
.30675 .39151 L
.30754 .39017 L
.3083 .3891 L
.30909 .38823 L
.30991 .38756 L
.31077 .38709 L
.31172 .38678 L
.31276 .38659 L
.31392 .38652 L
.31507 .3865 L
.31633 .38653 L
.31766 .38659 L
.31893 .38667 L
.32019 .3867 L
.3213 .38669 L
.32237 .38656 L
.32325 .38652 L
.32395 .38651 L
.32447 .38653 L
.32479 .38658 L
.32491 .38665 L
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
.32441 .38688 L
.32504 .3867 L
.326 .38643 L
.32728 .38607 L
.32883 .38562 L
.33065 .38511 L
.33266 .38455 L
.33488 .38396 L
.33728 .38334 L
.33979 .38268 L
.34241 .38198 L
.34501 .38123 L
.34762 .38043 L
.3502 .37957 L
.35276 .37865 L
Mistroke
.35528 .37768 L
.35784 .37667 L
.36043 .37562 L
.36307 .37458 L
.36576 .3735 L
.36845 .37242 L
.37105 .3714 L
.3735 .37047 L
.37574 .36963 L
.37773 .36891 L
.37939 .36833 L
.38074 .36791 L
.38177 .36769 L
.38247 .36766 L
.38287 .36782 L
.38297 .3681 L
.38285 .36844 L
.38255 .36876 L
.38214 .36904 L
.38167 .36927 L
.38119 .36947 L
.38074 .36966 L
.38033 .36984 L
.37997 .37002 L
.37969 .3702 L
.37956 .37035 L
.37962 .37054 L
.37992 .37075 L
.38049 .37101 L
.38132 .37133 L
.38237 .37178 L
.38359 .37237 L
.38493 .37308 L
.38629 .3739 L
.38762 .3748 L
.38883 .37569 L
.38993 .37656 L
.3909 .37732 L
.39172 .37794 L
.39244 .37839 L
.3931 .37863 L
.39379 .37863 L
.39455 .37836 L
.39547 .37776 L
.39662 .37682 L
.39804 .37555 L
.3997 .37402 L
.40161 .37229 L
.40373 .37051 L
.40596 .36868 L
Mistroke
.4082 .36678 L
.41035 .36486 L
.41234 .36291 L
.41415 .36103 L
.41572 .35912 L
.41703 .35734 L
.41818 .35562 L
.41932 .35381 L
.42062 .35183 L
.4222 .34967 L
.42415 .34722 L
.42652 .34434 L
.42922 .34084 L
.43226 .33686 L
.43556 .33218 L
.43889 .32824 L
.44227 .32366 L
.4456 .31974 L
.44862 .31609 L
.4514 .31286 L
.45383 .30981 L
.45584 .30693 L
.45737 .30463 L
.4584 .30314 L
.45898 .30236 L
.45918 .30205 L
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
.45847 .30371 L
.45876 .30382 L
.45925 .30384 L
.46007 .30373 L
.46138 .30345 L
.46327 .30298 L
.4657 .30232 L
.46873 .30149 L
.47231 .30049 L
.47639 .29939 L
.48054 .29831 L
.48486 .29721 L
.48901 .29621 L
.49324 .29523 L
.49796 .29421 L
.50243 .29321 L
.50716 .29219 L
Mistroke
.51214 .29118 L
.51732 .29014 L
.52261 .28908 L
.52746 .28802 L
.53224 .28695 L
.53677 .2859 L
.54087 .28489 L
.54437 .2839 L
.54769 .28291 L
.55093 .28195 L
.55391 .28109 L
.55634 .28037 L
.55817 .27984 L
.55948 .27948 L
.56042 .27923 L
.56123 .27907 L
.56222 .27894 L
.56353 .27876 L
.56528 .27841 L
.56791 .27782 L
.57124 .27697 L
.57537 .27589 L
.58055 .27456 L
.58704 .27301 L
.59455 .27133 L
.60315 .26954 L
.61209 .26772 L
.61954 .26593 L
.62673 .26428 L
.63349 .26281 L
.63972 .26142 L
.64615 .26014 L
.6525 .25903 L
.65733 .25818 L
.66003 .25763 L
.66113 .25736 L
.66138 .25729 L
.66118 .25737 L
.66051 .25752 L
.65976 .25766 L
.65982 .25773 L
.66052 .25771 L
.66167 .25767 L
.66321 .2577 L
.66517 .25785 L
.66753 .25811 L
.67029 .2585 L
.67346 .259 L
.67697 .25959 L
.6807 .26023 L
Mistroke
.68442 .26091 L
.68807 .26159 L
.69147 .26228 L
.69461 .26296 L
.6974 .26363 L
.69979 .26425 L
.70176 .26482 L
.70339 .26527 L
.70475 .26556 L
.7059 .26564 L
.70692 .2655 L
.70788 .26513 L
.70894 .26454 L
.71023 .26374 L
.71182 .26274 L
.71368 .26153 L
.71579 .26017 L
.71821 .25856 L
.72093 .25679 L
.72382 .2549 L
.7268 .25288 L
.7298 .25087 L
.73286 .24877 L
.73593 .24663 L
.73905 .24456 L
.74221 .24249 L
.74545 .24049 L
.74878 .23848 L
.75219 .23646 L
.75568 .23443 L
.75921 .23239 L
.76263 .23032 L
.76594 .22825 L
.76897 .22631 L
.7718 .22436 L
.77439 .22239 L
.77675 .22043 L
.77885 .21854 L
.78073 .21667 L
.78239 .21473 L
.78387 .21266 L
.78521 .21052 L
.78647 .2083 L
.78771 .20596 L
.78901 .20355 L
.79035 .20109 L
.79169 .19873 L
.79295 .19648 L
.7941 .19447 L
.79513 .19261 L
Mistroke
.79603 .19109 L
.79677 .18983 L
.79734 .18886 L
.79778 .18817 L
.79819 .18773 L
.79864 .18749 L
.79922 .18741 L
.79998 .18744 L
.80098 .18752 L
.80223 .18758 L
.80372 .18755 L
.80539 .18739 L
.80721 .1871 L
.8091 .18673 L
.811 .18633 L
.81286 .18593 L
.81462 .18558 L
.81622 .18533 L
.81762 .18518 L
.81881 .18516 L
.8198 .18531 L
.8206 .18563 L
.82123 .18608 L
.82172 .18661 L
.8221 .18718 L
.82243 .18777 L
.82275 .18836 L
.8231 .18893 L
.82346 .18945 L
.82372 .18967 L
.82402 .18993 L
.82426 .19007 L
.82443 .19011 L
.82454 .19004 L
.82458 .18987 L
.82454 .18965 L
.82446 .1894 L
.82438 .18922 L
.82429 .18905 L
.8242 .18893 L
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
.8241 .18908 L
Mistroke
.82395 .18887 L
.82374 .18851 L
.82348 .18797 L
.82319 .18723 L
.82285 .18629 L
.82252 .18517 L
.82212 .18384 L
.82168 .18232 L
.82119 .18075 L
.82069 .17911 L
.82016 .1774 L
.81962 .17571 L
.81907 .17412 L
.81855 .17269 L
.81804 .17138 L
.81758 .17023 L
.81716 .16932 L
.81675 .1686 L
.81633 .16807 L
.81587 .16774 L
.81537 .16756 L
.81481 .16749 L
.81414 .16749 L
.81353 .16752 L
.81285 .16758 L
.81215 .16762 L
.81146 .16762 L
.81076 .16758 L
.8101 .16751 L
.80944 .16743 L
.80883 .1674 L
.80832 .16744 L
.80793 .16754 L
.80768 .16769 L
.80757 .16791 L
.80758 .1682 L
.80763 .16858 L
.80769 .16906 L
.80774 .16965 L
.80774 .17033 L
.80767 .17111 L
.80757 .17196 L
.80746 .17284 L
.80738 .17373 L
.80731 .17458 L
.80725 .17532 L
.80722 .17596 L
.80721 .17647 L
.80722 .17688 L
.80725 .17719 L
Mistroke
.80732 .17741 L
.80743 .17756 L
.80759 .1777 L
.80777 .17787 L
.80796 .17815 L
.80818 .17857 L
.80846 .17919 L
.80881 .18008 L
.80925 .18127 L
.80987 .18256 L
.81071 .18416 L
.81185 .18606 L
.81323 .18801 L
.81485 .19031 L
.81679 .1926 L
.81904 .19516 L
.82094 .19757 L
.82327 .2 L
.82554 .20231 L
.82784 .20448 L
.83001 .20643 L
.83212 .20819 L
.83372 .20984 L
.83516 .21115 L
.83644 .2123 L
.83744 .21322 L
.83818 .21388 L
.83863 .21426 L
.83885 .2144 L
.83896 .21436 L
.83901 .21424 L
.839 .2141 L
.83897 .21404 L
.839 .21412 L
.83911 .21437 L
.83929 .21482 L
.8395 .21544 L
.83977 .21622 L
.84007 .21714 L
.84039 .21813 L
.84072 .21926 L
.84106 .22054 L
.84139 .22197 L
.84169 .22335 L
.84195 .22473 L
.84218 .22604 L
.84236 .2272 L
.84249 .22811 L
.8426 .22885 L
.84269 .22944 L
Mistroke
.84276 .22987 L
.84279 .23014 L
.84278 .23028 L
.84274 .23027 L
.84266 .23011 L
.84257 .22979 L
.84247 .22932 L
.84237 .22872 L
.84226 .22804 L
.84211 .22733 L
.84194 .22664 L
.84174 .22598 L
.84148 .22529 L
.84116 .22454 L
.84076 .22371 L
.84032 .22277 L
.83987 .22179 L
.83936 .22065 L
.83878 .21934 L
.83826 .21789 L
.83768 .21634 L
.83704 .21486 L
.83642 .21334 L
.83575 .21171 L
.83512 .21025 L
.8345 .20876 L
.83395 .20744 L
.8335 .20621 L
.83312 .20524 L
.83281 .20436 L
.83256 .20379 L
.83238 .20332 L
.83224 .20307 L
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
Mistroke
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
Mistroke
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
.82987 .19484 L
.82988 .19449 L
.82983 .19397 L
.8297 .19328 L
.82947 .19239 L
.82914 .19128 L
.8287 .19006 L
.82813 .18864 L
.82741 .18692 L
.82653 .18521 L
.82555 .18326 L
.82438 .18112 L
.82309 .17894 L
.82171 .17654 L
.82014 .17423 L
.81856 .17179 L
.81688 .16928 L
.81522 .16688 L
.8136 .16456 L
.81205 .16234 L
.81061 .16024 L
Mistroke
.80937 .15846 L
.80821 .15677 L
.80733 .15555 L
.80658 .15452 L
.80598 .1537 L
.80553 .15311 L
.80523 .15275 L
.80506 .15256 L
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
.80575 .15345 L
.80545 .15323 L
.80492 .15282 L
.80414 .15217 L
.80311 .15119 L
.8018 .14986 L
.80015 .14816 L
.79828 .14616 L
.7966 .14434 L
.79452 .14205 L
.79236 .1398 L
.79012 .13723 L
.78751 .13443 L
.78551 .13196 L
.78354 .12962 L
.78149 .12709 L
.77975 .1249 L
.7783 .12319 L
.77701 .1216 L
.77594 .12021 L
.77512 .11914 L
.77448 .11837 L
.77395 .1177 L
.77354 .11725 L
.77318 .11687 L
.77282 .11658 L
.77245 .11636 L
.77202 .11618 L
Mistroke
.77149 .11601 L
.77083 .11582 L
.77004 .11563 L
.76931 .11545 L
.76847 .11528 L
.7676 .11509 L
.76677 .1149 L
.76608 .11474 L
.76554 .11461 L
.76513 .1145 L
.76484 .11444 L
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
Mistroke
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
Mistroke
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
Mistroke
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
Mistroke
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
Mistroke
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
Mistroke
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
Mistroke
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
Mistroke
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
.76851 .11563 L
.76862 .11554 L
.76876 .11551 L
.76897 .11555 L
.76922 .11568 L
.76952 .11589 L
.76984 .11617 L
.7702 .11651 L
.77061 .11692 L
Mistroke
.77109 .11739 L
.77165 .11793 L
.7723 .11855 L
.77305 .11923 L
.77391 .11998 L
.77486 .12082 L
.77592 .12172 L
.77706 .12266 L
.77811 .1236 L
.77922 .12444 L
.78034 .12531 L
.78131 .12617 L
.78225 .127 L
.78313 .12771 L
.78391 .12839 L
.78456 .129 L
.78513 .1295 L
.78561 .12991 L
.78603 .13025 L
.78643 .13054 L
.78686 .13086 L
.78737 .13127 L
.78801 .13188 L
.78877 .13271 L
.78972 .13384 L
.79078 .13516 L
.79206 .1368 L
.79355 .1388 L
.79526 .14104 L
.79724 .14366 L
.79924 .14656 L
.80149 .14979 L
.80398 .15344 L
.8065 .15683 L
.80909 .16072 L
.81184 .16421 L
.81451 .16811 L
.81737 .17156 L
.82028 .17535 L
.8229 .179 L
.82536 .18235 L
.82799 .18588 L
.83057 .18947 L
.8331 .19281 L
.83582 .1966 L
.83826 .20002 L
.84112 .20427 L
.84373 .20785 L
.84634 .21216 L
.8492 .21652 L
Mistroke
.85201 .22124 L
.85528 .22665 L
.85798 .23087 L
.86098 .23564 L
.86398 .24063 L
.86659 .24445 L
.86919 .24842 L
.87164 .25218 L
.87372 .2554 L
.87545 .25792 L
.87698 .26015 L
.87821 .26193 L
.87912 .2633 L
.87976 .26427 L
.88015 .26488 L
.88034 .26522 L
.8804 .2654 L
.88038 .2655 L
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
.88164 .26609 L
.88177 .26645 L
.88203 .26701 L
.88247 .26786 L
.88312 .26906 L
.88401 .27059 L
.88504 .27225 L
.88624 .27428 L
.8876 .2764 L
.88907 .27877 L
.89051 .28111 L
.89198 .28358 L
.89336 .2857 L
.89455 .28771 L
.89567 .28949 L
.89658 .29098 L
.8973 .29215 L
Mistroke
.89781 .29304 L
.89811 .29366 L
.89824 .29403 L
.89827 .29422 L
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
.89769 .29343 L
.89775 .29376 L
.89786 .29422 L
.89804 .29481 L
.89827 .29551 L
.89855 .29627 L
.89889 .2971 L
.89925 .29796 L
.89964 .2988 L
.90004 .2996 L
.90043 .30031 L
.9008 .30093 L
.90113 .30141 L
Mistroke
.90141 .30177 L
.90164 .302 L
.90181 .30213 L
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
Mistroke
.90361 .30418 L
.90345 .30423 L
.90325 .30419 L
.90302 .30401 L
.90272 .30362 L
.90233 .30297 L
.90184 .30203 L
.90121 .3008 L
.90043 .29919 L
.89944 .29718 L
.89822 .29465 L
.89678 .29193 L
.89506 .2883 L
.89308 .28494 L
.89076 .28079 L
.88831 .27657 L
.88551 .27199 L
.88254 .2668 L
.87943 .26229 L
.87615 .25691 L
.87282 .25169 L
.86959 .24721 L
.86627 .24211 L
.86288 .23653 L
.8597 .232 L
.85648 .22691 L
.85327 .22218 L
.85011 .21742 L
.84679 .21239 L
.84358 .20782 L
.84027 .2031 L
.83683 .19806 L
.83326 .19324 L
.82969 .18808 L
.82609 .18332 L
.82224 .17786 L
.81864 .17315 L
.81487 .16799 L
.81097 .16224 L
.80736 .15763 L
.80369 .15248 L
.80006 .14716 L
.79648 .14261 L
.79314 .13806 L
.78981 .13401 L
.7865 .12999 L
.78342 .12688 L
.78026 .12376 L
.77714 .12093 L
.77414 .11865 L
Mistroke
.7711 .11657 L
.76854 .11477 L
.76605 .11332 L
.76387 .11207 L
.76175 .11101 L
.75967 .11016 L
.75778 .10923 L
.756 .10836 L
.75416 .10742 L
.75219 .10638 L
.75001 .10525 L
.74757 .10405 L
.74483 .1028 L
.74232 .10156 L
.73909 .10026 L
.73564 .09886 L
.73169 .09729 L
.72676 .09549 L
.72253 .09366 L
.71737 .09161 L
.71217 .0894 L
.70663 .08715 L
.70094 .08474 L
.69503 .08243 L
.68954 .08003 L
.68362 .07759 L
.67764 .07518 L
.672 .07277 L
.66569 .07038 L
.66051 .06801 L
.65482 .06568 L
.64916 .06331 L
.64373 .06119 L
.63887 .0591 L
.63392 .05711 L
.6292 .05517 L
.62475 .05339 L
.62023 .05163 L
.6162 .04999 L
.61205 .0484 L
.60851 .04694 L
.60486 .04552 L
.60153 .04418 L
.59841 .04296 L
.59547 .04184 L
.59297 .04084 L
.59064 .03996 L
.58867 .03923 L
.58688 .0386 L
.58529 .03809 L
Mistroke
.58391 .03762 L
.58271 .03723 L
.5817 .03692 L
.58091 .0367 L
.58033 .03656 L
.57987 .03647 L
.57952 .03641 L
.57925 .03639 L
.57903 .03641 L
.57887 .03645 L
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
.57891 .03657 L
Mistroke
.57852 .03656 L
.57803 .03654 L
.57745 .03652 L
.57681 .0365 L
.57618 .03647 L
.57556 .03645 L
.57501 .03643 L
.57444 .03641 L
.57392 .0364 L
.57346 .03638 L
.57304 .03637 L
.57263 .03636 L
.57221 .03634 L
.57172 .03633 L
.57117 .03631 L
.57055 .03629 L
.56981 .03626 L
.56898 .03623 L
.56796 .0362 L
.56683 .03616 L
.56565 .03612 L
.56449 .03608 L
.56332 .03604 L
.56219 .036 L
.56115 .03597 L
.56023 .03594 L
.55947 .03592 L
.55889 .0359 L
.55843 .03588 L
.55807 .03587 L
.55778 .03586 L
.55755 .03586 L
.55737 .03585 L
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
.5577 .03586 L
.55723 .03585 L
.55649 .03583 L
.55546 .0358 L
.55415 .03575 L
.55255 .0357 L
Mistroke
.55088 .03564 L
.54897 .03557 L
.54684 .0355 L
.54468 .03543 L
.54261 .03535 L
.54054 .03528 L
.5386 .03522 L
.53706 .03517 L
.53572 .03512 L
.53461 .03509 L
.53377 .03506 L
.53322 .03504 L
.53293 .03501 L
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
.53341 .03493 L
.53343 .03522 L
.53343 .03563 L
.53344 .03617 L
.53344 .03683 L
.53345 .0376 L
.53346 .03837 L
.5335 .03919 L
.5336 .03998 L
.53374 .04076 L
.53387 .04141 L
.53393 .04204 L
.53389 .04261 L
.53372 .04311 L
.53338 .04357 L
.53286 .04407 L
.53219 .0446 L
.5314 .04517 L
.53053 .04577 L
.5296 .0464 L
.52869 .04699 L
.52781 .04763 L
.52692 .04828 L
.52608 .04894 L
.52534 .04955 L
.52479 .0501 L
.52446 .05047 L
.52434 .05069 L
.5244 .05072 L
.52464 .05054 L
.52502 .0502 L
Mistroke
.52553 .04973 L
.52616 .04921 L
.52692 .04868 L
.52789 .04815 L
.52918 .04765 L
.53087 .04722 L
.53298 .04685 L
.53546 .04656 L
.53836 .0464 L
.54147 .04637 L
.54516 .04651 L
.54884 .0468 L
.55322 .04731 L
.55718 .04802 L
.56155 .0489 L
.5662 .04981 L
.57052 .05085 L
.57444 .05194 L
.57843 .05303 L
.58219 .05409 L
.58575 .05508 L
.58911 .05602 L
.59238 .05685 L
.59568 .05748 L
.59885 .05794 L
.60227 .05827 L
.60576 .05849 L
.60948 .05866 L
.61351 .05883 L
.61768 .05907 L
.6219 .05941 L
.62692 .0599 L
.63115 .06058 L
.63605 .0615 L
.64119 .06269 L
.6471 .064 L
.65185 .06563 L
.65755 .06748 L
.66309 .06951 L
.66875 .07159 L
.6741 .07393 L
.67954 .07609 L
.68474 .07841 L
.68914 .0805 L
.6936 .08252 L
.69779 .08446 L
.70126 .08607 L
.70411 .08751 L
.70675 .08877 L
.7087 .0898 L
Mistroke
.71025 .09059 L
.71133 .09118 L
.71195 .09158 L
.71226 .09183 L
.71236 .09197 L
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
.71245 .09177 L
.71258 .09176 L
.71275 .09175 L
.71295 .09173 L
.7132 .09172 L
.71349 .09171 L
.71382 .09172 L
.71414 .09173 L
.71446 .09174 L
.71477 .09176 L
.71507 .09181 L
.71538 .09191 L
.7157 .09208 L
.71609 .09236 L
.71658 .09275 L
.71722 .09329 L
.71806 .09402 L
.71915 .09494 L
.72049 .09608 L
.72217 .09742 L
.72409 .09874 L
.72638 .10035 L
.7291 .10194 L
.73196 .10368 L
.7352 .10546 L
.73878 .10735 L
.7425 .10917 L
.7465 .11113 L
.75035 .11289 L
.75433 .11465 L
.75843 .11637 L
.76188 .11788 L
.76527 .11928 L
.76827 .12054 L
.77091 .12165 L
.77326 .1226 L
.77515 .12335 L
.77668 .12402 L
.77796 .12461 L
Mistroke
.77897 .12513 L
.77972 .12557 L
.78028 .12597 L
.7807 .12632 L
.781 .12666 L
.78125 .12701 L
.78145 .12736 L
.78165 .12771 L
.78189 .12806 L
.7822 .12842 L
.78254 .12878 L
.78286 .12909 L
.78315 .12932 L
.78341 .12948 L
.78364 .12957 L
.78386 .12963 L
.78409 .1297 L
.78437 .12982 L
.78474 .13003 L
.78519 .13035 L
.78575 .1308 L
.78637 .13134 L
.78705 .13194 L
.78777 .13258 L
.7885 .13322 L
.78921 .13384 L
.7899 .13442 L
.79055 .13495 L
.79115 .13541 L
.7917 .13579 L
.79216 .13606 L
.79256 .13623 L
.79286 .1363 L
.79308 .13626 L
.79322 .13616 L
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
.79275 .13592 L
.79284 .13625 L
.79305 .13676 L
.79343 .13753 L
.79399 .13867 L
.79474 .14012 L
.79574 .14196 L
.79692 .14407 L
.79841 .14642 L
Mistroke
.80012 .14927 L
.80205 .15205 L
.8041 .15506 L
.80634 .15804 L
.8084 .16087 L
.81056 .16382 L
.81241 .16639 L
.81417 .16841 L
.81574 .17028 L
.81708 .17197 L
.81814 .17327 L
.81898 .17422 L
.8196 .17482 L
.81999 .17512 L
.82019 .17521 L
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
.81772 .17386 L
.81787 .17382 L
.81804 .17381 L
.81821 .17384 L
.81838 .1739 L
.81854 .17401 L
Mistroke
.81874 .17421 L
.81898 .17452 L
.81927 .17497 L
.81963 .17561 L
.82004 .17646 L
.82051 .17747 L
.82106 .17868 L
.82163 .18009 L
.82228 .18165 L
.82297 .1831 L
.82366 .18466 L
.8244 .18627 L
.82511 .18767 L
.82581 .18902 L
.82646 .1903 L
.82702 .19134 L
.82749 .19222 L
.82784 .19291 L
.82808 .19338 L
.82822 .19361 L
.82824 .19361 L
.82817 .19341 L
.82801 .19308 L
.82779 .19262 L
.82754 .19207 L
.82725 .19143 L
.82694 .19069 L
.82661 .1899 L
.82625 .18904 L
.82585 .18805 L
.82534 .18691 L
.82477 .18569 L
.82407 .18431 L
.82322 .18274 L
.82219 .18095 L
.82109 .17904 L
.81975 .17687 L
.81838 .17455 L
.81677 .17187 L
.81505 .16905 L
.81316 .16618 L
.81124 .16332 L
.80938 .16039 L
.80751 .15753 L
.80566 .15453 L
.80411 .15218 L
.80259 .14982 L
.80125 .1478 L
.79994 .14592 L
.7989 .1445 L
Mistroke
.79794 .14332 L
.79707 .1424 L
.79629 .14176 L
.79562 .14137 L
.79505 .14117 L
.79461 .14112 L
.79423 .14117 L
.79392 .14127 L
.79366 .1414 L
.79346 .14154 L
.7933 .14167 L
.79318 .14178 L
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
.79336 .14219 L
.793 .14246 L
.7925 .14284 L
.79187 .14335 L
.79115 .144 L
.79034 .14478 L
.78954 .14558 L
.78872 .14644 L
.78785 .14731 L
.78695 .14814 L
.78613 .14886 L
.78542 .14947 L
.78485 .1499 L
.78449 .15012 L
.78422 .15011 L
.78404 .14983 L
.78392 .14929 L
.78383 .14846 L
.78367 .14744 L
.78338 .14618 L
.78293 .14462 L
.78234 .14289 L
.7816 .14092 L
.78072 .13879 L
.77985 .13652 L
Mistroke
.77877 .13409 L
.7776 .13169 L
.7764 .12925 L
.77517 .12682 L
.774 .12457 L
.7728 .12244 L
.77168 .12041 L
.77059 .11883 L
.76956 .11744 L
.7686 .11627 L
.76778 .11539 L
.76698 .11476 L
.76622 .11435 L
.76552 .11412 L
.76488 .11402 L
.7643 .114 L
.76378 .11404 L
.76335 .11411 L
.76302 .11417 L
.7628 .11422 L
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
Mistroke
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
.76297 .11454 L
.76264 .11446 L
.76219 .11431 L
.76161 .1141 L
.7609 .11384 L
.76008 .11357 L
.7592 .11331 L
.75826 .11309 L
.75724 .11291 L
.75618 .11279 L
.75515 .11272 L
.75418 .11268 L
.75331 .11268 L
.7526 .1127 L
.75201 .1128 L
.75156 .11297 L
.75123 .1132 L
.751 .11347 L
.75086 .11376 L
.75079 .11403 L
.75077 .11424 L
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
Mistroke
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
.75067 .10967 L
.75076 .10987 L
.75093 .11019 L
.75121 .11062 L
.75163 .11121 L
.75223 .11195 L
.75304 .11285 L
.75406 .11395 L
.7553 .11528 L
.7567 .11677 L
.75823 .11857 L
.75998 .12051 L
.76186 .12278 L
.76385 .12502 L
.76592 .1275 L
.76799 .13005 L
.77004 .1326 L
.77201 .1353 L
.77382 .13752 L
.77549 .13991 L
.77699 .1424 L
.77829 .14486 L
.77932 .14691 L
.78014 .14895 L
.78076 .15114 L
.78124 .15348 L
.78163 .15587 L
.782 .15788 L
Mistroke
.7824 .16048 L
.78291 .16294 L
.78359 .16599 L
.78449 .16896 L
.78566 .17195 L
.78712 .17526 L
.7888 .17848 L
.79081 .18177 L
.79316 .18501 L
.79582 .18783 L
.79875 .1907 L
.80213 .1933 L
.80535 .19571 L
.80901 .19783 L
.81252 .19972 L
.81597 .20133 L
.81916 .20264 L
.82209 .20374 L
.82516 .20459 L
.82751 .20522 L
.82944 .20564 L
.83122 .20586 L
.83251 .20588 L
.83347 .20571 L
.83413 .2054 L
.83455 .20494 L
.83475 .20435 L
.8348 .20363 L
.83471 .20273 L
.83417 .20164 L
.83392 .2004 L
.83368 .19895 L
.83342 .19729 L
.83304 .19552 L
.83253 .19355 L
.83192 .19145 L
.83126 .18953 L
.83042 .18741 L
.82945 .18545 L
.82828 .18346 L
.82702 .18147 L
.82568 .17969 L
.82432 .17797 L
.82296 .17632 L
.82161 .1748 L
.82028 .17331 L
.819 .17183 L
.81778 .17041 L
.81655 .16896 L
.81533 .16743 L
Mistroke
.81408 .16582 L
.81284 .16424 L
.81166 .16262 L
.81058 .16103 L
.8096 .15948 L
.80873 .1581 L
.80798 .15685 L
.80736 .15575 L
.80687 .15487 L
.80646 .15417 L
.80611 .15364 L
.80582 .15325 L
.80559 .15301 L
.80545 .15289 L
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
.80597 .15368 L
.80553 .15323 L
.80477 .1524 L
.8037 .15116 L
.80235 .14953 L
.80065 .1474 L
.79855 .14475 L
.79633 .1421 L
.79344 .13917 L
.79056 .13611 L
.78718 .13263 L
.78356 .1285 L
.7799 .12527 L
.77585 .12208 L
.77234 .11891 L
.76835 .11605 L
.76456 .11339 L
.76036 .11102 L
.75598 .10875 L
.75199 .10675 L
.74722 .10466 L
.74262 .10251 L
.73764 .10026 L
.73205 .0979 L
.72738 .09578 L
.72249 .09357 L
.71694 .0912 L
.71264 .08924 L
.70794 .0873 L
.70359 .08546 L
Mistroke
.69942 .08384 L
.696 .08249 L
.6929 .08136 L
.6904 .08045 L
.68824 .07979 L
.68649 .07937 L
.68509 .07913 L
.68398 .079 L
.6831 .07896 L
.68243 .07899 L
.68191 .07903 L
.68153 .07911 L
.68124 .07919 L
.68099 .07925 L
.68079 .07935 L
.68066 .07948 L
.68058 .07965 L
.68055 .07983 L
.68058 .08002 L
.68064 .08018 L
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
Mistroke
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
.67716 .08038 L
.67665 .08011 L
.67587 .07963 L
.67476 .07893 L
.67327 .07797 L
.67151 .07679 L
.66925 .07537 L
.66675 .07372 L
.66375 .07185 L
.66048 .07003 L
.65695 .0678 L
.65314 .0659 L
.64935 .0638 L
.64546 .06169 L
.64141 .05966 L
.63773 .05783 L
.63389 .05602 L
.63007 .05443 L
.62628 .05299 L
.62263 .05169 L
.61899 .05055 L
.61563 .04959 L
.6122 .04872 L
.60896 .04794 L
.60561 .04721 L
.60204 .0465 L
.59853 .04576 L
.59462 .04499 L
.59069 .04416 L
.58637 .04328 L
.58241 .04236 L
.57818 .04151 L
.57428 .0406 L
Mistroke
.5706 .03967 L
.56706 .03873 L
.56365 .03793 L
.561 .03719 L
.55861 .03654 L
.55652 .03602 L
.555 .03564 L
.55381 .03541 L
.55299 .03533 L
.55245 .03536 L
.55202 .03546 L
.55156 .03558 L
.5509 .03569 L
.54993 .03577 L
.54862 .03579 L
.54684 .03576 L
.54449 .0357 L
.54169 .0356 L
.53845 .03549 L
.53467 .03538 L
.53106 .03525 L
.52725 .0351 L
.52351 .03494 L
.51997 .03477 L
.51643 .0346 L
.51372 .03445 L
.51129 .03433 L
.50915 .03423 L
.50767 .03416 L
.50661 .03414 L
.50604 .03414 L
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
.51004 .0341 L
.5097 .03418 L
.50907 .03434 L
.50807 .03456 L
.50665 .03484 L
Mistroke
.50481 .03517 L
.50273 .03552 L
.50016 .03589 L
.49735 .03624 L
.49426 .03658 L
.49122 .03691 L
.48815 .03722 L
.4855 .03749 L
.48299 .0377 L
.48115 .03784 L
.47966 .03791 L
.4786 .03792 L
.47798 .03788 L
.47776 .03781 L
.47778 .03774 L
.47791 .03767 L
.47801 .0376 L
.47801 .03753 L
.47786 .03746 L
.47752 .03741 L
.47689 .03739 L
.47601 .0374 L
.47486 .03746 L
.47359 .03758 L
.47234 .03779 L
.47109 .0381 L
.46992 .03855 L
.46888 .03913 L
.46804 .03985 L
.46736 .04067 L
.46685 .04159 L
.46647 .04262 L
.46618 .04371 L
.46595 .04477 L
.46575 .04566 L
.46558 .04638 L
.46548 .04694 L
.46546 .04733 L
.46549 .04756 L
.46559 .0476 L
.46567 .04749 L
.46562 .04729 L
.46538 .04708 L
.4649 .04689 L
.46414 .04677 L
.46306 .04666 L
.46161 .0466 L
.45984 .04663 L
.45805 .04642 L
.45586 .04654 L
Mistroke
.45351 .04663 L
.4506 .04664 L
.44804 .04655 L
.44516 .04632 L
.44205 .04594 L
.43886 .0454 L
.43602 .04473 L
.43322 .04396 L
.43069 .04316 L
.42868 .04238 L
.42687 .0417 L
.42527 .04113 L
.42401 .04069 L
.42298 .04037 L
.42227 .04018 L
.42196 .04009 L
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
.42511 .04048 L
.42455 .04046 L
.4235 .04043 L
.42196 .04039 L
.4199 .04032 L
.41757 .0402 L
.41467 .04 L
.41131 .03974 L
.40785 .03946 L
.40379 .03919 L
.39961 .03897 L
.39508 .03886 L
.39006 .03893 L
.38562 .03921 L
.38071 .03974 L
.37584 .04054 L
.37115 .04164 L
.36602 .04306 L
.36154 .04465 L
.35644 .04661 L
.35191 .04874 L
.3469 .05114 L
.34209 .05369 L
.33733 .05644 L
.33274 .05915 L
.32764 .06206 L
.32308 .06498 L
Mistroke
.31791 .06799 L
.31342 .07095 L
.30843 .07406 L
.30366 .07702 L
.29869 .08014 L
.29345 .08331 L
.28862 .08648 L
.2831 .08987 L
.27837 .09303 L
.27307 .09643 L
.26773 .09984 L
.26285 .10312 L
.25741 .10655 L
.25247 .1097 L
.24743 .11287 L
.24245 .116 L
.23751 .11907 L
.23277 .12228 L
.22788 .12562 L
.22333 .12896 L
.21868 .13255 L
.21421 .13625 L
.20985 .1401 L
.20554 .14429 L
.20165 .1483 L
.19784 .15262 L
.19409 .15738 L
.19072 .16177 L
.18736 .16668 L
.18417 .1718 L
.18105 .17661 L
.17805 .18165 L
.17511 .18664 L
.17221 .19179 L
.16936 .1964 L
.16645 .20151 L
.16364 .20611 L
.16079 .2108 L
.1578 .21535 L
.15487 .22008 L
.15181 .2251 L
.14885 .22955 L
.14576 .23461 L
.14264 .23968 L
.13961 .2442 L
.13642 .24946 L
.13326 .25456 L
.13034 .25995 L
.1271 .2654 L
.12363 .27086 L
Mistroke
.1205 .27627 L
.11703 .28193 L
.11422 .28673 L
.11118 .29154 L
.10853 .29597 L
.10615 .30008 L
.1042 .30337 L
.10246 .30645 L
.10102 .30928 L
.09993 .3116 L
.09901 .31384 L
.09821 .31611 L
.09749 .31852 L
.09679 .3212 L
.09605 .32396 L
.09527 .32737 L
.09449 .33073 L
.09357 .33469 L
.09263 .33911 L
.0916 .34388 L
.0905 .34926 L
.08946 .35431 L
.08843 .36008 L
.08748 .36509 L
.08664 .37071 L
.08596 .37535 L
.08545 .38014 L
.08508 .38446 L
.08482 .3882 L
.08463 .3916 L
.08449 .39448 L
.08437 .39691 L
.08425 .39879 L
.08415 .40024 L
.08409 .40125 L
.08405 .40189 L
.08404 .40223 L
.08404 .40236 L
.08404 .40238 L
.08409 .40237 L
.08424 .40239 L
.08452 .40251 L
.08498 .40283 L
.08563 .40338 L
.08645 .4042 L
.08744 .40524 L
.08857 .40653 L
.08981 .4081 L
.091 .40994 L
.09225 .41212 L
Mistroke
.09341 .41461 L
.09455 .41744 L
.09552 .42061 L
.09633 .42391 L
.09694 .42767 L
.0973 .43157 L
.09736 .43516 L
.09712 .43921 L
.09656 .44335 L
.09567 .44781 L
.09448 .45209 L
.09305 .45604 L
.09134 .46036 L
.08956 .46433 L
.08766 .46819 L
.08557 .47184 L
.08372 .47499 L
.08163 .47785 L
.07998 .48023 L
.07841 .48231 L
.07693 .48408 L
.07576 .48542 L
.07484 .48642 L
.0742 .48706 L
.07383 .48739 L
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
.07439 .48531 L
.07426 .48572 L
.07403 .48643 L
.07371 .48749 L
.07329 .48897 L
.07278 .49093 L
.07222 .49309 L
.07162 .49599 L
.07102 .49904 L
.07044 .50272 L
.06993 .50664 L
.06952 .51086 L
.06924 .51575 L
.06911 .52005 L
.06917 .52462 L
.06936 .52973 L
.06973 .53433 L
.07028 .5398 L
.07097 .54434 L
.07176 .54921 L
.07263 .5538 L
.07348 .55853 L
.07431 .56315 L
.07509 .56764 L
.07579 .57205 L
.07642 .57608 L
.077 .57999 L
.07752 .58361 L
.078 .58678 L
.07843 .58975 L
.07881 .59212 L
.07913 .59417 L
Mistroke
.0794 .59584 L
.07962 .59709 L
.07982 .598 L
.08001 .59862 L
.08018 .59896 L
.08033 .59909 L
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
.08068 .59837 L
.08088 .59835 L
.08113 .59829 L
.08141 .59817 L
.08172 .59799 L
.082 .59778 L
.08225 .59758 L
.08248 .59741 L
.08265 .59732 L
.08276 .59741 L
.0828 .59775 L
.08279 .59841 L
.08274 .59945 L
.08268 .60097 L
.08262 .60301 L
.08258 .60522 L
.0826 .60819 L
.08269 .61149 L
.08289 .6154 L
.08319 .61969 L
.08357 .62468 L
.08403 .629 L
.08454 .63458 L
.08511 .63956 L
.08569 .6448 L
Mistroke
.08628 .65013 L
.08689 .65494 L
.08748 .65978 L
.08804 .66432 L
.0886 .66855 L
.08919 .67279 L
.08981 .6765 L
.09042 .68021 L
.09105 .68336 L
.09169 .68649 L
.09231 .68917 L
.0929 .69169 L
.09348 .69393 L
.09402 .69558 L
.0945 .69721 L
.0949 .69848 L
.09524 .69957 L
.09549 .70047 L
.09566 .70117 L
.09576 .70164 L
.09582 .70188 L
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
Mistroke
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
.10072 .70348 L
.10087 .70392 L
.1011 .70451 L
.10143 .70524 L
.10185 .7061 L
.10238 .70702 L
.10301 .70808 L
.10376 .70925 L
.10462 .71056 L
.10555 .712 L
.10664 .7135 L
.10773 .71514 L
.10893 .71692 L
.11019 .71884 L
.11149 .7207 L
.1129 .72278 L
.11428 .72487 L
.11564 .72712 L
.11707 .72947 L
.11843 .73176 L
.11977 .73414 L
.121 .73625 L
.12216 .73827 L
.12317 .74004 L
.12407 .74157 L
.12479 .74276 L
.12537 .74367 L
.12582 .74434 L
.12614 .7448 L
.12633 .74507 L
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
Mistroke
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
.12507 .74378 L
.12509 .74422 L
.12526 .74492 L
.12563 .74595 L
.12625 .74734 L
.12716 .74914 L
.12837 .75109 L
.12993 .75366 L
.13198 .75631 L
.13408 .75952 L
.13628 .76283 L
.13892 .7666 L
.14189 .77046 L
.14486 .77447 L
.14808 .77865 L
.1512 .78287 L
.15423 .78695 L
.15727 .79113 L
.16018 .79538 L
.163 .79954 L
.1657 .80361 L
.16834 .80771 L
.17099 .81176 L
.17371 .81557 L
.17653 .81955 L
.17955 .82341 L
.18267 .82714 L
.18624 .83112 L
.1898 .8351 L
.19357 .83895 L
.19762 .84318 L
.20172 .84719 L
.20601 .85159 L
.21043 .85519 L
.21483 .85955 L
.21927 .86337 L
.22376 .86784 L
.22827 .87161 L
.23267 .87539 L
.23706 .87923 L
Mistroke
.24167 .88296 L
.24577 .88667 L
.25031 .89012 L
.25448 .89314 L
.25883 .89618 L
.26307 .89871 L
.26729 .90121 L
.27154 .90352 L
.27561 .90551 L
.27981 .90739 L
.28391 .9091 L
.28813 .91072 L
.29215 .91226 L
.29659 .9138 L
.30094 .91537 L
.30549 .91688 L
.31061 .9186 L
.31504 .92034 L
.32001 .9222 L
.32534 .92417 L
.33036 .92608 L
.33568 .92815 L
.34181 .93021 L
.34674 .93222 L
.35229 .93429 L
.35786 .93618 L
.36336 .93805 L
.36865 .93975 L
.3738 .94143 L
.3788 .94308 L
.38371 .94468 L
.38848 .94624 L
.39323 .94778 L
.39782 .94919 L
.40211 .95057 L
.40634 .9519 L
.41046 .95324 L
.41424 .95452 L
.4182 .95583 L
.42175 .95719 L
.4253 .95851 L
.42888 .95984 L
.4326 .96114 L
.43639 .96236 L
.44008 .96347 L
.44408 .96445 L
.44785 .9653 L
.45154 .96599 L
.45556 .96653 L
.45906 .96694 L
Mistroke
.46274 .96721 L
.46645 .96734 L
.47034 .96732 L
.47387 .96714 L
.47765 .96682 L
.4815 .9664 L
.48535 .96596 L
.4895 .9655 L
.49393 .96507 L
.49842 .9646 L
.50323 .9641 L
.50841 .96352 L
.5138 .96284 L
.5195 .96205 L
.52528 .96113 L
.53122 .96012 L
.53713 .95904 L
.54315 .95794 L
.5491 .95682 L
.55473 .95576 L
.56017 .95475 L
.56556 .9538 L
.57044 .95292 L
.57513 .95216 L
.57952 .9515 L
.58353 .95094 L
.58719 .95043 L
.59043 .95008 L
.59332 .94977 L
.59582 .94949 L
.59803 .94917 L
.6 .94886 L
.60174 .94845 L
.60336 .94801 L
.6049 .94752 L
.60649 .94696 L
.60822 .9464 L
.61002 .94579 L
.61206 .94511 L
.61443 .94439 L
.61697 .9436 L
.61991 .94272 L
.62301 .94168 L
.62647 .94061 L
.62975 .93964 L
.63328 .93852 L
.63717 .93736 L
.6405 .93616 L
.64396 .93484 L
.64745 .93381 L
Mistroke
.65088 .93261 L
.6542 .93132 L
.65752 .92984 L
.66052 .92842 L
.66342 .92684 L
.66638 .92534 L
.66932 .92362 L
.67232 .92172 L
.67525 .91982 L
.67841 .91789 L
.6813 .91582 L
.68426 .91384 L
.68726 .91191 L
.69022 .91009 L
.69329 .90843 L
.69628 .90698 L
.69941 .90577 L
.7026 .90474 L
.70585 .90382 L
.70925 .90292 L
.71257 .90201 L
.7161 .90099 L
.71977 .89978 L
.72363 .89834 L
.7276 .8967 L
.73172 .89479 L
.73594 .89259 L
.74024 .89018 L
.74451 .88755 L
.74881 .88464 L
.75322 .88167 L
.75754 .87856 L
.76179 .87537 L
.76605 .87209 L
.77026 .86887 L
.77462 .86551 L
.77883 .86208 L
.78338 .85861 L
.78738 .8552 L
.79163 .85174 L
.79583 .8483 L
.8002 .84476 L
.80436 .84125 L
.80854 .83783 L
.8133 .83415 L
.81729 .83074 L
.82169 .82717 L
.82609 .8237 L
.83071 .82018 L
.83488 .81698 L
Mistroke
.83901 .81369 L
.84322 .81042 L
.84707 .80709 L
.85079 .8036 L
.85442 .80007 L
.85778 .79635 L
.86078 .79217 L
.86365 .78809 L
.86622 .78372 L
.86853 .77929 L
.87059 .77456 L
.87235 .77044 L
.87393 .7662 L
.87536 .76215 L
.87658 .75838 L
.8777 .75515 L
.87868 .75221 L
.87955 .7499 L
.8803 .74804 L
.88089 .74669 L
.88134 .74581 L
.88164 .74535 L
.88183 .74523 L
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
.88195 .74656 L
.88161 .74653 L
.88111 .74642 L
.88048 .74625 L
.87975 .74606 L
.87896 .74589 L
.87816 .74578 L
.87744 .74576 L
.87675 .74583 L
.87612 .74599 L
.87564 .74621 L
.87529 .74642 L
.87511 .74654 L
.87515 .74653 L
.87546 .74632 L
.87604 .74575 L
.87689 .74472 L
.87799 .74317 L
.87939 .74117 L
.88081 .73848 L
.88234 .73514 L
Mistroke
.88406 .73086 L
.88576 .72651 L
.88742 .72141 L
.88918 .71596 L
.89092 .71038 L
.89268 .70447 L
.89451 .69913 L
.89605 .69424 L
.89757 .68898 L
.89908 .68385 L
.90045 .67909 L
.90183 .67454 L
.90319 .66957 L
.90443 .66522 L
.90575 .66046 L
.90714 .6553 L
.90854 .65038 L
.90998 .64522 L
.9114 .63981 L
.9129 .63442 L
.91433 .62856 L
.91574 .62292 L
.91705 .61796 L
.91837 .61197 L
.91962 .60705 L
.92085 .60174 L
.92207 .59617 L
.92325 .59113 L
.92443 .58606 L
.9256 .58088 L
.92671 .57576 L
.92775 .5705 L
.92873 .56516 L
.92961 .55997 L
.93038 .55463 L
.93101 .54954 L
.93147 .54456 L
.93178 .54017 L
.93195 .536 L
.93198 .53228 L
.93189 .52904 L
.93169 .52617 L
.93143 .52353 L
.93114 .5213 L
.93084 .51918 L
.93057 .51711 L
.93032 .51504 L
.9301 .51278 L
.9299 .51025 L
.92971 .50768 L
Mistroke
.92951 .50481 L
.9293 .50192 L
.92906 .49879 L
.92879 .49556 L
.92849 .49224 L
.92816 .489 L
.92779 .48581 L
.92736 .48281 L
.92687 .48011 L
.92633 .4777 L
.92573 .47556 L
.92513 .47379 L
.92452 .4723 L
.92391 .47103 L
.92334 .47 L
.92281 .46914 L
.92231 .46843 L
.92188 .46786 L
.9215 .46739 L
.92122 .46699 L
.92105 .46662 L
.92098 .46631 L
.92098 .46608 L
.92101 .46596 L
.92103 .46594 L
.92098 .46604 L
.92084 .4663 L
.92055 .46672 L
.9201 .46731 L
.91948 .4681 L
.9187 .4691 L
.91776 .47031 L
.91681 .47165 L
.91571 .47321 L
.91437 .47498 L
.91306 .47686 L
.91158 .47892 L
.90999 .48109 L
.90843 .48322 L
.9068 .48538 L
.90531 .48751 L
.90382 .48954 L
.90243 .49163 L
.90121 .49371 L
.90005 .49584 L
.89889 .49816 L
.89789 .5004 L
.89699 .50286 L
.8962 .50536 L
.89554 .50805 L
Mistroke
.895 .51067 L
.89457 .51351 L
.89423 .5162 L
.89395 .51915 L
.8937 .52193 L
.89346 .52488 L
.89318 .52788 L
.89287 .5306 L
.89254 .53355 L
.89222 .53635 L
.89194 .53912 L
.8917 .54205 L
.89149 .54476 L
.89131 .54729 L
.89116 .54996 L
.89103 .55253 L
.89092 .55509 L
.89082 .55745 L
.89074 .5596 L
.89068 .56152 L
.89064 .56308 L
.89061 .56444 L
.89061 .56567 L
.8906 .56665 L
.89062 .56751 L
.89065 .56833 L
.89067 .56911 L
.89068 .56983 L
.89066 .57047 L
.89063 .57103 L
.89061 .5715 L
.89059 .57185 L
.89059 .57212 L
.89058 .57234 L
.89055 .5725 L
.8905 .57255 L
.89046 .57243 L
.89042 .57214 L
.89039 .57168 L
.89039 .57115 L
.89044 .57064 L
.89055 .57023 L
.89072 .57004 L
.89096 .57016 L
.89127 .57063 L
.89163 .57138 L
.89201 .57235 L
.89242 .57343 L
.89283 .57458 L
.89323 .57562 L
Mistroke
.89361 .57673 L
.89398 .5777 L
.89434 .57863 L
.89468 .57945 L
.89495 .58009 L
.89514 .58049 L
.89522 .58068 L
.89518 .58075 L
.89504 .58077 L
.89479 .58081 L
.89443 .58097 L
.89393 .58133 L
.8933 .58193 L
.89252 .58279 L
.8916 .58386 L
.89055 .58524 L
.88932 .58697 L
.88792 .58905 L
.88639 .59126 L
.88475 .59385 L
.88318 .59653 L
.8816 .59952 L
.88005 .60223 L
.87865 .60509 L
.87735 .60763 L
.8762 .61016 L
.87519 .61247 L
.87437 .6143 L
.87371 .61593 L
.87322 .61731 L
.87289 .61835 L
.87271 .61902 L
.87264 .61937 L
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
Mistroke
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
.87537 .61866 L
.87503 .61876 L
.87451 .61882 L
.8738 .61884 L
.87287 .61877 L
.87174 .61855 L
.87063 .61821 L
.86937 .6178 L
.86798 .61736 L
.86654 .61692 L
.86491 .61655 L
.8633 .61637 L
.8617 .6164 L
.85997 .61669 L
.85797 .61727 L
.85573 .61817 L
.85342 .61944 L
.85133 .62086 L
.84886 .62273 L
.84595 .62481 L
.843 .62715 L
.8398 .62968 L
.83624 .63237 L
.833 .63479 L
.8295 .63727 L
.82595 .63966 L
.82272 .64188 L
.81954 .64392 L
.81665 .64579 L
.81392 .64741 L
.81164 .64882 L
.80961 .65005 L
.80795 .6511 L
.80638 .65198 L
.80513 .65273 L
.80403 .65336 L
.80305 .65387 L
.80213 .65426 L
.80119 .65454 L
.80014 .65475 L
.79892 .65495 L
Mistroke
.7975 .65517 L
.79603 .65544 L
.79426 .65581 L
.79238 .65627 L
.79019 .65686 L
.78795 .65752 L
.78557 .6582 L
.7834 .65884 L
.78151 .65939 L
.77963 .65983 L
.77827 .66014 L
.7771 .66033 L
.77625 .66041 L
.77574 .66037 L
.77549 .66025 L
.77543 .66004 L
.77548 .65976 L
.77556 .65939 L
.77557 .65899 L
.77542 .6586 L
.77508 .65826 L
.77453 .65801 L
.77378 .65787 L
.77286 .65784 L
.77193 .65788 L
.77096 .65799 L
.77002 .65816 L
.76919 .65836 L
.76848 .65852 L
.76789 .65863 L
.76737 .65867 L
.76689 .65862 L
.76643 .65845 L
.76595 .65815 L
.7654 .65771 L
.76476 .65713 L
.76406 .65643 L
.7632 .65563 L
.7622 .65472 L
.76112 .65375 L
.75996 .6527 L
.75864 .65158 L
.75718 .6504 L
.75575 .64925 L
.75438 .6481 L
.75315 .647 L
.75213 .646 L
.75128 .64508 L
.75059 .64428 L
.75004 .6436 L
Mistroke
.74962 .64302 L
.74926 .64253 L
.74896 .64213 L
.74874 .64181 L
.7486 .64158 L
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
.74936 .642 L
.74929 .64162 L
.74916 .641 L
.74898 .64012 L
.74876 .63899 L
.74851 .63762 L
.74824 .63618 L
.74794 .63449 L
.74768 .63273 L
.74748 .63095 L
.74733 .62916 L
.7472 .62759 L
.74706 .62612 L
.74689 .62477 L
.74663 .62363 L
.74624 .62262 L
.74569 .62175 L
.74493 .62101 L
.74394 .62034 L
.74271 .61968 L
.7413 .61898 L
.73998 .61827 L
.73847 .61753 L
.73699 .61676 L
.73549 .61596 L
.73399 .61512 L
.73283 .61437 L
.73181 .61364 L
.73105 .61304 L
.73053 .61254 L
.73024 .61214 L
.73015 .61185 L
.73023 .61163 L
.73039 .61152 L
.7306 .61144 L
.73085 .61138 L
.73115 .61137 L
.73146 .6114 L
Mistroke
.73176 .61149 L
.732 .61163 L
.73217 .61178 L
.73221 .61191 L
.73207 .612 L
.73171 .61204 L
.73111 .61199 L
.73024 .61179 L
.72909 .61139 L
.72771 .61079 L
.72632 .60999 L
.72475 .60901 L
.7231 .60791 L
.72143 .60672 L
.71996 .60558 L
.71856 .6045 L
.71727 .60351 L
.71619 .60256 L
.71531 .60173 L
.71465 .60094 L
.71418 .60014 L
.71388 .5993 L
.71369 .59833 L
.71357 .59713 L
.7135 .59559 L
.71345 .59365 L
.71338 .59157 L
.71329 .58905 L
.7132 .58593 L
.71312 .5826 L
.71305 .57869 L
.71301 .57432 L
.713 .56983 L
.71302 .56522 L
.71305 .56039 L
.71309 .556 L
.71312 .55138 L
.7131 .54686 L
.71304 .54236 L
.71293 .538 L
.71277 .53393 L
.71259 .52992 L
.71241 .52617 L
.71222 .5229 L
.71201 .5199 L
.7118 .51741 L
.7116 .51522 L
.71144 .51353 L
.71134 .51204 L
.71135 .51068 L
Mistroke
.71154 .50936 L
.71193 .50812 L
.71254 .50693 L
.71342 .5055 L
.71459 .50385 L
.7161 .50177 L
.71783 .49948 L
.71977 .49675 L
.72183 .49343 L
.72412 .48986 L
.72629 .48587 L
.72854 .48184 L
.73047 .47796 L
.73228 .47402 L
.73383 .47015 L
.73519 .46668 L
.73618 .46338 L
.73693 .4606 L
.73747 .45829 L
.7378 .45625 L
.73796 .45452 L
.73802 .45306 L
.73801 .45181 L
.73799 .45062 L
.73803 .44944 L
.73817 .44815 L
.73844 .44664 L
.73889 .44481 L
.73954 .44281 L
.74037 .44037 L
.74139 .4375 L
.74261 .43403 L
.74397 .43035 L
.74553 .42654 L
.74724 .4224 L
.74906 .41793 L
.75101 .41362 L
.75304 .40917 L
.75516 .40459 L
.75732 .40026 L
.75944 .39595 L
.76179 .3913 L
.76398 .3872 L
.76636 .38285 L
.76882 .37852 L
.77151 .37398 L
.77416 .37019 L
.77705 .36622 L
.7802 .3623 L
.78339 .35883 L
Mistroke
.78692 .35536 L
.79042 .35204 L
.79437 .34893 L
.798 .34591 L
.8021 .3431 L
.80618 .34042 L
.81 .33788 L
.81397 .3355 L
.81785 .33323 L
.82178 .33098 L
.82532 .32884 L
.82876 .32677 L
.83242 .3247 L
.83556 .32279 L
.83867 .3209 L
.84188 .31914 L
.84493 .31747 L
.84813 .31588 L
.85115 .31449 L
.85453 .31317 L
.85798 .312 L
.86174 .31095 L
.86528 .31003 L
.86905 .30927 L
.87325 .30866 L
.87664 .30819 L
.88041 .30788 L
.88378 .3077 L
.88711 .30763 L
.88999 .30764 L
.8925 .30771 L
.89441 .3078 L
.89606 .30789 L
.89739 .30797 L
.89833 .30803 L
.8989 .30807 L
.89917 .30807 L
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
Mistroke
.89837 .30859 L
.89833 .30856 L
.89831 .30843 L
.8983 .30815 L
.89829 .30769 L
.89825 .30698 L
.89814 .30596 L
.89793 .30467 L
.89762 .30302 L
.8972 .30105 L
.89664 .29877 L
.89594 .29623 L
.8951 .29331 L
.89418 .29075 L
.89313 .28762 L
.89199 .28506 L
.89079 .28241 L
.88956 .27986 L
.88836 .27774 L
.88713 .27581 L
.88591 .27422 L
.88467 .27288 L
.88354 .27181 L
.88244 .27092 L
.88137 .2702 L
.88033 .26962 L
.87933 .26911 L
.87838 .26864 L
.87759 .26822 L
.8768 .26786 L
.87613 .26752 L
.87554 .26719 L
.87505 .26688 L
.87464 .26661 L
.87435 .26637 L
.87416 .26619 L
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
Mistroke
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
.87346 .26838 L
.87324 .26836 L
.87287 .26841 L
.87232 .26857 L
.87166 .26883 L
.87086 .26921 L
.86995 .26966 L
.86897 .27015 L
.86804 .27061 L
.86714 .271 L
.86633 .27131 L
.86564 .27151 L
.86513 .27158 L
.86477 .27155 L
.86457 .27146 L
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
Mistroke
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
.86948 .27075 L
.86948 .27033 L
.86951 .26963 L
.86952 .26857 L
.86948 .26713 L
.86933 .26525 L
.86905 .26295 L
.86855 .26019 L
.86783 .25705 L
.86689 .25369 L
.86571 .24979 L
.86426 .24612 L
.86265 .24196 L
.86086 .2376 L
.85892 .23332 L
.85684 .22913 L
.85472 .22519 L
.85259 .22146 L
.8505 .21802 L
.84859 .21517 L
.84695 .21261 L
.84538 .21041 L
.84418 .20879 L
.8432 .20748 L
.84247 .2065 L
.84199 .20584 L
.84172 .20548 L
.84159 .20536 L
.84154 .20536 L
.84147 .20531 L
.84131 .2051 L
.84093 .20459 L
.84027 .20369 L
.83927 .20234 L
.83789 .20042 L
.8362 .19813 L
.83411 .19531 L
.83156 .19184 L
.82915 .18835 L
Mistroke
.82613 .18388 L
.82313 .17998 L
.81989 .17543 L
.81643 .17067 L
.81302 .1658 L
.81 .16142 L
.80675 .15681 L
.80338 .15196 L
.8004 .14762 L
.79753 .14376 L
.79452 .1397 L
.79153 .13591 L
.78823 .13209 L
.78516 .12902 L
.78179 .12598 L
.77838 .12286 L
.77537 .12047 L
.77175 .1182 L
.76859 .11606 L
.76532 .11417 L
.76244 .11253 L
.75954 .1112 L
.7571 .11029 L
.75527 .10958 L
.75381 .1091 L
.75279 .10883 L
.75216 .10867 L
.75188 .1086 L
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
Mistroke
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
.75677 .10992 L
.7564 .1099 L
.75594 .10987 L
.75541 .10986 L
.75482 .1099 L
.75421 .11002 L
.75359 .11021 L
.75298 .11047 L
.75238 .11078 L
.75183 .11112 L
.7514 .11144 L
.75113 .11173 L
.75107 .11195 L
.75118 .11209 L
.7514 .11214 L
.75166 .11207 L
.75183 .11183 L
.75179 .11142 L
.75142 .11078 L
.75064 .1099 L
.74937 .10876 L
.74752 .10736 L
.74504 .10576 L
.74237 .10393 L
.73908 .10199 L
.73509 .09995 L
.73108 .09784 L
.72641 .09564 L
.72084 .09335 L
.71607 .09099 L
.71062 .08855 L
.70465 .086 L
.69923 .0836 L
.69285 .0811 L
.6877 .07868 L
.68187 .07632 L
.67547 .07389 L
.67027 .07158 L
.66432 .06922 L
.65827 .0668 L
.65263 .06448 L
.64681 .06207 L
.64059 .05976 L
.63535 .05754 L
.62946 .05527 L
.62443 .05319 L
.61915 .05107 L
Mistroke
.61416 .04912 L
.60928 .04717 L
.60447 .04534 L
.59964 .04361 L
.59514 .04209 L
.5907 .04071 L
.5863 .03951 L
.58241 .03852 L
.57857 .03771 L
.57511 .03705 L
.57164 .03654 L
.56871 .03616 L
.56572 .03588 L
.56251 .0357 L
.55965 .03559 L
.55658 .03553 L
.55326 .03549 L
.54969 .03545 L
.54656 .03541 L
.54272 .03535 L
.5389 .03525 L
.53466 .03511 L
.52981 .03497 L
.52536 .03481 L
.5204 .03465 L
.51522 .03448 L
.51043 .03432 L
.50528 .03417 L
.50113 .03403 L
.49665 .0339 L
.49297 .03378 L
.48934 .03367 L
.48628 .03356 L
.48323 .03346 L
.48095 .03337 L
.479 .0333 L
.47744 .03325 L
.47625 .03324 L
.47544 .03325 L
.4749 .03328 L
.47461 .03332 L
.47448 .03336 L
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
Mistroke
.47595 .03318 L
.47598 .03325 L
.47592 .03343 L
.47577 .03373 L
.47553 .03416 L
.4752 .03472 L
.47478 .03539 L
.47426 .03613 L
.47366 .03695 L
.473 .03781 L
.47231 .03866 L
.47165 .03945 L
.47103 .04016 L
.47048 .04077 L
.47001 .04128 L
.46963 .04165 L
.46935 .0419 L
.46918 .04203 L
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
.46913 .0413 L
.46928 .04167 L
.46952 .04226 L
.46987 .04311 L
.47032 .04426 L
.4709 .04574 L
.47159 .04742 L
.47244 .04961 L
.47344 .05196 L
.47461 .05473 L
.47592 .05773 L
.47733 .06102 L
.4788 .06409 L
.48031 .06749 L
.48176 .07086 L
.48318 .07429 L
Mistroke
.48451 .07753 L
.48577 .08068 L
.48696 .0837 L
.48802 .0864 L
.489 .08886 L
.48986 .09079 L
.49059 .09249 L
.49118 .09376 L
.49161 .09477 L
.49188 .09552 L
.49198 .09613 L
.49193 .09669 L
.49175 .09733 L
.49144 .09816 L
.49101 .09925 L
.49046 .10063 L
.4898 .10233 L
.48907 .10401 L
.48825 .1062 L
.48738 .10843 L
.48649 .11093 L
.48569 .11345 L
.48494 .11558 L
.48429 .11761 L
.48377 .11944 L
.48338 .12087 L
.48313 .12195 L
.483 .12264 L
.483 .12298 L
.48313 .12309 L
.48341 .12312 L
.48386 .12321 L
.48454 .12342 L
.48548 .12382 L
.48672 .12447 L
.48825 .12536 L
.49007 .12651 L
.4922 .12793 L
.4945 .12952 L
.49693 .13133 L
.49943 .13316 L
.50196 .13505 L
.50436 .13685 L
.50667 .13849 L
.50858 .13983 L
.51026 .14088 L
.51161 .14163 L
.51259 .14206 L
.51325 .14227 L
.51362 .1423 L
Mistroke
.51372 .14224 L
.51361 .14221 L
.51337 .14229 L
.51306 .14259 L
.51275 .14318 L
.51249 .14417 L
.51233 .14552 L
.51225 .14752 L
.51223 .14995 L
.51227 .15296 L
.51232 .15642 L
.51236 .16036 L
.51233 .16478 L
.51223 .16897 L
.51203 .17367 L
.51174 .17851 L
.51136 .18368 L
.5109 .18825 L
.51037 .19348 L
.50979 .19761 L
.50918 .20216 L
.50858 .20595 L
.508 .2095 L
.50747 .21312 L
.50701 .21563 L
.50665 .21774 L
.5064 .2194 L
.50627 .22061 L
.50624 .22136 L
.50628 .22169 L
.50632 .2217 L
.5063 .22154 L
.50616 .22134 L
.50582 .22123 L
.50525 .22128 L
.5044 .2216 L
.50326 .22229 L
.50178 .22336 L
.49997 .22468 L
.49802 .22606 L
.49577 .22761 L
.49331 .2292 L
.49087 .23073 L
.48833 .23223 L
.48597 .23364 L
.48386 .2348 L
.48198 .23572 L
.48045 .23636 L
.47934 .23675 L
.4786 .23689 L
Mistroke
.47822 .2368 L
.47822 .23661 L
.47858 .23643 L
.47927 .2364 L
.48031 .23667 L
.48167 .23734 L
.48328 .2384 L
.48511 .23988 L
.48704 .2417 L
.48901 .24381 L
.49097 .24627 L
.49291 .24888 L
.49468 .25108 L
.49642 .25358 L
.49795 .25576 L
.49935 .25821 L
.50052 .26016 L
.50145 .262 L
.50207 .2637 L
.50237 .26529 L
.50232 .26691 L
.50198 .2687 L
.50138 .27075 L
.50057 .27287 L
.49963 .27531 L
.49858 .27817 L
.49749 .28149 L
.49639 .28463 L
.49524 .28819 L
.49411 .29157 L
.49302 .29502 L
.49205 .29818 L
.49127 .30081 L
.49067 .30316 L
.49023 .30507 L
.48993 .30647 L
.48973 .30752 L
.48953 .30833 L
.48922 .30895 L
.4887 .30945 L
.48795 .30989 L
.4869 .31033 L
.48547 .31078 L
.4836 .31126 L
.48159 .31183 L
.47904 .31244 L
.47619 .31314 L
.47275 .31393 L
.46938 .31481 L
.46534 .31574 L
Mistroke
.46185 .31669 L
.45785 .31768 L
.4537 .3187 L
.44902 .3197 L
.44506 .32068 L
.44051 .32164 L
.43609 .32255 L
.43142 .32339 L
.42628 .32412 L
.42186 .3247 L
.41702 .32513 L
.41157 .32538 L
.40725 .32542 L
.40225 .32522 L
.39751 .32477 L
.39297 .32404 L
.38799 .32304 L
.3841 .32178 L
.3799 .32034 L
.37637 .31875 L
.37286 .3171 L
.36999 .3155 L
.36713 .31399 L
.36502 .3126 L
.36318 .31131 L
.36163 .31021 L
.36041 .30926 L
.35957 .30851 L
.3591 .30799 L
.35891 .30775 L
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
Mistroke
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
Mistroke
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
Mistroke
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
.36221 .31241 L
.36216 .31249 L
.36206 .31266 L
.36193 .31291 L
.36175 .31326 L
.36154 .31365 L
.36131 .31405 L
.36107 .31442 L
.36083 .31476 L
.36059 .31504 L
.36035 .31526 L
.36014 .31541 L
.35995 .31546 L
.35981 .31542 L
.35972 .31529 L
.35969 .3151 L
.35972 .31485 L
.3598 .31454 L
.35994 .31413 L
.36008 .31375 L
.36018 .31334 L
Mistroke
.36022 .31297 L
.36015 .31264 L
.35997 .31232 L
.35964 .31198 L
.35914 .31161 L
.35845 .31118 L
.35759 .31063 L
.35653 .30998 L
.35528 .30922 L
.35385 .30837 L
.3523 .30741 L
.35052 .30634 L
.34851 .30519 L
.34623 .30386 L
.3439 .30245 L
.34126 .30085 L
.3386 .29907 L
.33581 .29723 L
.3327 .29515 L
.32989 .29303 L
.32669 .2909 L
.32327 .28854 L
.31991 .28632 L
.31602 .28392 L
.31286 .28141 L
.30942 .27905 L
.30593 .27658 L
.30329 .27451 L
.30057 .27257 L
.29836 .27087 L
.29642 .26955 L
.29479 .26835 L
.29366 .26757 L
.29284 .26695 L
.29231 .2665 L
.29213 .26621 L
.29224 .26615 L
.29257 .26627 L
.29304 .26655 L
.29355 .2669 L
.29403 .26724 L
.29446 .26755 L
.29481 .26779 L
.29508 .26793 L
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
Mistroke
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
Mistroke
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
.29774 .27233 L
.29744 .27233 L
.297 .27233 L
.29642 .27236 L
.29571 .27241 L
.29488 .27249 L
.29391 .27256 L
.29281 .27261 L
.29152 .27264 L
.29002 .27262 L
.2883 .27253 L
.2865 .27233 L
.28445 .27201 L
.28214 .27156 L
.27992 .27098 L
.2774 .27025 L
.27476 .26942 L
.2718 .26847 L
.26916 .26738 L
.26614 .26615 L
.26311 .2648 L
.25988 .26338 L
.25664 .2618 L
.25397 .26017 L
.25135 .25843 L
.24893 .25677 L
.24683 .25512 L
.24501 .25347 L
.24357 .252 L
.24224 .25052 L
.24116 .24916 L
.24013 .24778 L
.2392 .24664 L
.23809 .24555 L
.23678 .24448 L
.2352 .24343 L
.23329 .24238 L
Mistroke
.23113 .24133 L
.22924 .24033 L
.22673 .23919 L
.22389 .2379 L
.22084 .23645 L
.21729 .23475 L
.21384 .23295 L
.20989 .23076 L
.20666 .2287 L
.20311 .2264 L
.1998 .22404 L
.1964 .22147 L
.19357 .21924 L
.19074 .21685 L
.18801 .21432 L
.18566 .21217 L
.18346 .20991 L
.18146 .20772 L
.17973 .20559 L
.1783 .20362 L
.17718 .2017 L
.17639 .20004 L
.17587 .19852 L
.1756 .19716 L
.17552 .19601 L
.1756 .19493 L
.1758 .19403 L
.17608 .19327 L
.17639 .19267 L
.17671 .19223 L
.17699 .19195 L
.17723 .19181 L
.1774 .19178 L
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
.17717 .19235 L
.17739 .19212 L
.17776 .19179 L
.17827 .19136 L
.17894 .19083 L
Mistroke
.17977 .1902 L
.18076 .18947 L
.18198 .1886 L
.18337 .18759 L
.18498 .18644 L
.18666 .1852 L
.18846 .18387 L
.19028 .18254 L
.19201 .18125 L
.19366 .18 L
.19511 .17883 L
.19638 .17783 L
.19745 .17688 L
.19829 .17609 L
.19895 .1754 L
.19945 .17484 L
.1998 .17444 L
.20002 .1742 L
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
.19939 .17468 L
.19942 .17415 L
.19954 .17336 L
.19976 .17229 L
.2001 .17092 L
.20055 .16947 L
.20112 .16764 L
.20176 .16577 L
.20249 .1637 L
.20331 .1614 L
.20422 .15928 L
.20525 .15688 L
.20645 .15459 L
.20775 .15237 L
.20918 .15004 L
.21074 .14787 L
.21237 .14572 L
.2141 .14357 L
.21579 .14178 L
.21747 .13999 L
.21913 .13828 L
.2207 .13678 L
.22229 .13528 L
.2237 .13407 L
.22503 .13301 L
Mistroke
.22624 .13213 L
.2273 .13147 L
.22822 .13099 L
.22904 .13068 L
.22982 .13051 L
.23067 .13041 L
.23167 .13036 L
.23291 .13031 L
.23446 .13025 L
.23629 .13016 L
.23842 .13008 L
.24087 .13 L
.24343 .12996 L
.24598 .12994 L
.24855 .12995 L
.25103 .12997 L
.25345 .12999 L
.25558 .13002 L
.25743 .13005 L
.25912 .1301 L
.26051 .13018 L
.26162 .13029 L
.26245 .13042 L
.26301 .13059 L
.26336 .1308 L
.26357 .13105 L
.26369 .13135 L
.26376 .13166 L
.26382 .132 L
.26394 .13233 L
.2641 .13263 L
.26425 .13288 L
.26438 .13307 L
.26448 .13321 L
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
Mistroke
.26484 .13259 L
.26501 .1324 L
.26517 .13216 L
.26527 .1319 L
.26522 .13168 L
.26496 .13152 L
.26444 .13145 L
.2636 .13151 L
.26239 .13174 L
.26077 .13219 L
.25884 .13286 L
.25642 .1338 L
.25336 .13497 L
.25024 .13631 L
.24633 .13787 L
.24219 .13953 L
.23816 .14135 L
.23315 .1433 L
.22886 .14532 L
.22362 .14752 L
.2191 .14972 L
.21422 .15209 L
.20907 .15463 L
.2047 .1574 L
.20006 .16023 L
.19586 .16327 L
.19157 .16663 L
.18789 .17012 L
.18423 .17388 L
.18076 .17791 L
.17761 .18211 L
.17462 .18644 L
.17166 .19099 L
.16879 .19569 L
.16585 .20069 L
.16301 .20544 L
.15997 .21054 L
.15698 .21606 L
.15412 .22085 L
.15095 .22622 L
.14786 .23151 L
.14451 .23706 L
.14148 .24224 L
.1383 .2475 L
.13529 .25286 L
.13233 .25768 L
.12927 .26285 L
.12656 .26755 L
.12363 .27229 L
.12087 .27693 L
Mistroke
.11802 .28164 L
.11516 .28656 L
.11238 .29107 L
.10949 .29604 L
.10691 .30078 L
.1042 .30575 L
.10184 .31055 L
.09955 .31546 L
.09746 .32029 L
.09552 .32555 L
.09384 .33005 L
.09231 .33494 L
.09097 .33987 L
.08983 .34509 L
.08887 .35024 L
.08804 .35564 L
.08736 .36104 L
.08674 .36695 L
.08619 .37231 L
.08571 .37741 L
.0853 .3828 L
.08495 .38737 L
.08466 .39187 L
.0844 .39632 L
.08416 .39955 L
.08393 .40236 L
.0838 .40412 L
.08372 .4059 L
.08376 .40723 L
.08396 .40815 L
.08429 .40867 L
.08475 .40903 L
.0854 .40935 L
.08637 .40975 L
.08761 .41023 L
.08867 .41089 L
.09005 .4119 L
.09098 .41324 L
.09239 .41486 L
.09365 .41678 L
.09476 .41888 L
.09572 .42141 L
.09661 .42413 L
.09731 .42719 L
.09774 .43094 L
.09792 .43439 L
.09783 .43803 L
.09751 .44165 L
.09696 .44573 L
.09615 .45059 L
Mistroke
.09499 .45443 L
.09351 .45861 L
.09211 .46291 L
.09044 .46722 L
.0882 .47147 L
.08635 .47535 L
.08415 .47927 L
.08236 .48294 L
.07994 .48682 L
.07807 .48999 L
.07647 .49295 L
.0747 .49627 L
.07337 .49885 L
.07225 .50148 L
.0714 .50378 L
.07085 .50581 L
.07052 .50755 L
.07038 .50891 L
.07036 .51002 L
.07043 .51099 L
.07054 .51181 L
.07065 .51253 L
.0707 .51307 L
.07074 .51357 L
.07079 .51399 L
.07079 .51434 L
.07076 .51462 L
.07072 .51484 L
.07067 .51509 L
.07059 .51538 L
.07047 .51569 L
.0703 .51604 L
.07015 .5163 L
.07003 .51652 L
.06998 .51667 L
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
Mistroke
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
.07318 .51663 L
.07301 .51698 L
.07279 .51749 L
.07253 .51815 L
.07224 .51894 L
.07194 .51985 L
.07161 .52087 L
.07134 .52197 L
.07102 .52322 L
.07069 .5246 L
.07037 .52614 L
.07009 .52765 L
.06988 .52927 L
.06976 .53097 L
.06972 .5327 L
.06977 .53424 L
.06989 .5358 L
.07006 .53737 L
.07027 .53888 L
.0705 .5403 L
.07073 .54162 L
.07095 .54278 L
.07118 .54373 L
.07141 .5445 L
.07163 .5451 L
.07182 .54551 L
.07199 .54575 L
Mistroke
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
.07476 .5472 L
Mistroke
.07474 .54703 L
.07467 .54694 L
.07459 .54704 L
.07449 .54742 L
.07441 .5481 L
.07434 .54915 L
.0743 .55066 L
.07429 .55269 L
.07433 .5548 L
.07442 .55739 L
.07458 .56084 L
.07481 .56386 L
.0751 .56809 L
.07544 .57215 L
.07584 .57649 L
.0763 .58022 L
.07682 .58473 L
.07732 .58971 L
.07787 .59382 L
.07846 .59836 L
.07909 .60313 L
.0797 .60776 L
.08035 .61312 L
.08106 .61713 L
.08172 .62207 L
.08244 .62822 L
.08321 .63271 L
.08394 .63873 L
.08485 .64356 L
.08565 .65021 L
.08651 .65577 L
.08748 .66073 L
.08839 .66645 L
.08938 .67323 L
.09047 .67815 L
.09142 .68389 L
.09249 .68981 L
.09355 .69606 L
.09467 .7017 L
.09575 .70612 L
.09692 .7113 L
.09793 .71536 L
.09899 .71999 L
.09986 .72305 L
.10067 .72607 L
.10138 .7287 L
.10193 .73053 L
.10236 .73195 L
.10269 .73301 L
.10291 .73368 L
Mistroke
.10305 .73396 L
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
.10239 .73886 L
.10242 .73908 L
.10253 .73941 L
.10276 .73984 L
.10311 .74035 L
.1036 .74092 L
.10426 .74155 L
.10505 .74228 L
.10579 .74316 L
.10677 .74411 L
.10778 .74518 L
.109 .74655 L
.11037 .74775 L
.11155 .74921 L
.11279 .75072 L
.11422 .75191 L
.1156 .75371 L
.11723 .7553 L
.11864 .75709 L
.1202 .75928 L
.12218 .76139 L
.12406 .76388 L
.12612 .76654 L
.12842 .76929 L
.13081 .77232 L
.13347 .77562 L
.13621 .77848 L
.13908 .78196 L
.14208 .7852 L
.14523 .78894 L
.14846 .79261 L
.15192 .79643 L
.15546 .8002 L
.15923 .80394 L
.16302 .80782 L
.16702 .81167 L
.17142 .81604 L
Mistroke
.17552 .81976 L
.17996 .82404 L
.18445 .8284 L
.18895 .83282 L
.1936 .83737 L
.19852 .84209 L
.20298 .84659 L
.20768 .85112 L
.21233 .8557 L
.21706 .86041 L
.22138 .86481 L
.22582 .86921 L
.2301 .87348 L
.23407 .87765 L
.23812 .88144 L
.24185 .88487 L
.2455 .88822 L
.24916 .89113 L
.25256 .8939 L
.25604 .89646 L
.25938 .89859 L
.26275 .90057 L
.26626 .90235 L
.26967 .90399 L
.27342 .90553 L
.27693 .90689 L
.28066 .90831 L
.28428 .90967 L
.28798 .91107 L
.29177 .91246 L
.29569 .91389 L
.29999 .91529 L
.3039 .91671 L
.30829 .91819 L
.31279 .91964 L
.31784 .92119 L
.3222 .92281 L
.3273 .92458 L
.33262 .92639 L
.33768 .92838 L
.34314 .93036 L
.34871 .93242 L
.35499 .93454 L
.36004 .93664 L
.36584 .93881 L
.37172 .94091 L
.37703 .94296 L
.38257 .94493 L
.38806 .94676 L
.39337 .94849 L
Mistroke
.39865 .95009 L
.40389 .95163 L
.40895 .95315 L
.41427 .9546 L
.41916 .95608 L
.42428 .95755 L
.42935 .95897 L
.4342 .9604 L
.43902 .96172 L
.44374 .96294 L
.44847 .964 L
.45299 .96494 L
.45753 .96568 L
.46207 .96621 L
.46665 .96655 L
.47132 .96669 L
.47589 .96664 L
.48053 .96646 L
.48501 .96612 L
.48939 .96568 L
.49362 .96515 L
.49773 .96461 L
.50145 .96409 L
.50496 .96361 L
.50819 .96319 L
.51081 .96285 L
.51308 .96259 L
.5149 .96238 L
.51625 .96221 L
.51721 .96209 L
.51784 .96199 L
.51824 .96191 L
.51843 .96185 L
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
.5178 .96202 L
.51818 .96205 L
.5189 .96203 L
.52007 .96198 L
.52174 .96188 L
.52385 .96176 L
.52605 .96159 L
.52895 .96135 L
.53246 .961 L
.5365 .96054 L
.54102 .95997 L
Mistroke
.54588 .95926 L
.55101 .95844 L
.55654 .95753 L
.56209 .95658 L
.56794 .95559 L
.57356 .95453 L
.57965 .95342 L
.58535 .95231 L
.59129 .95112 L
.5977 .9499 L
.60335 .94865 L
.60941 .94741 L
.61567 .9462 L
.6215 .945 L
.62739 .94383 L
.63329 .94266 L
.63863 .94158 L
.64378 .94051 L
.64839 .93936 L
.65265 .93846 L
.65616 .93761 L
.65939 .93692 L
.66212 .93635 L
.6645 .93587 L
.66675 .93542 L
.66891 .93491 L
.67107 .93428 L
.67334 .93347 L
.67573 .93245 L
.67841 .93126 L
.68115 .92978 L
.68437 .92803 L
.68769 .92627 L
.69145 .92415 L
.69537 .92184 L
.69935 .91947 L
.70359 .91684 L
.7073 .9144 L
.71111 .91188 L
.71453 .90955 L
.71767 .90737 L
.7204 .90543 L
.72277 .90369 L
.72472 .90222 L
.72637 .90094 L
.72766 .89982 L
.72871 .89884 L
.72952 .898 L
.73011 .89733 L
.73049 .89679 L
Mistroke
.73074 .89635 L
.73089 .89603 L
.73098 .89582 L
.73105 .89565 L
.73112 .89553 L
.7312 .89545 L
.73133 .89537 L
.73148 .8953 L
.73164 .89524 L
.73177 .89518 L
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
.73191 .89524 L
.73219 .89506 L
.73254 .8948 L
.73296 .89447 L
.73345 .89405 L
.734 .89356 L
.73465 .89301 L
.73536 .89241 L
.73611 .89178 L
.73684 .8911 L
.73752 .89041 L
.73809 .88973 L
.73852 .88905 L
.7388 .88848 L
.73894 .888 L
.73894 .88764 L
.73885 .88742 L
.7387 .88729 L
.73852 .88722 L
.73836 .88719 L
.73822 .88713 L
.73811 .88704 L
.73804 .8869 L
.73807 .88669 L
.73824 .88642 L
.73862 .88607 L
.7392 .88565 L
.74002 .88512 L
Mistroke
.74108 .88447 L
.74237 .8837 L
.74394 .88278 L
.74577 .88167 L
.74791 .88042 L
.75042 .87902 L
.75322 .87746 L
.75643 .87575 L
.7599 .87384 L
.76376 .87165 L
.76769 .8693 L
.772 .86662 L
.77635 .86365 L
.78077 .86059 L
.78559 .85725 L
.78988 .85392 L
.79429 .85039 L
.79862 .84699 L
.80302 .84317 L
.80702 .84001 L
.81109 .83664 L
.81493 .83322 L
.8187 .83009 L
.82239 .8268 L
.82602 .8238 L
.82965 .82069 L
.83319 .81784 L
.83678 .81487 L
.84011 .81219 L
.84331 .80961 L
.84633 .80716 L
.84901 .80499 L
.85157 .80313 L
.85356 .80158 L
.8551 .80026 L
.85646 .79915 L
.85748 .7983 L
.85829 .79762 L
.85887 .79718 L
.85924 .79698 L
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
Mistroke
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
.86125 .79251 L
.86134 .79209 L
.86141 .79144 L
.86148 .7905 L
.86158 .78921 L
.8617 .78764 L
.86185 .78567 L
.86201 .78342 L
.86217 .78088 L
.86234 .77835 L
.86249 .77563 L
.86263 .77291 L
.86274 .77034 L
.86283 .76786 L
.86289 .76578 L
.86291 .76395 L
.8629 .76238 L
Mistroke
.86287 .76117 L
.86282 .76019 L
.86278 .75953 L
.86275 .75908 L
.86276 .75883 L
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
.85723 .75963 L
.85739 .75962 L
.85756 .7596 L
.85772 .75959 L
.85788 .75958 L
.85805 .75959 L
.85821 .75964 L
.85838 .75973 L
.85854 .75985 L
.85869 .75998 L
.85884 .76008 L
.85902 .76012 L
.85923 .76006 L
.85952 .75988 L
Mistroke
.85991 .75952 L
.86045 .75894 L
.86118 .7581 L
.86215 .75694 L
.86338 .7554 L
.86487 .75338 L
.86662 .75091 L
.86853 .74803 L
.87066 .74468 L
.87289 .74098 L
.87532 .73689 L
.87768 .7327 L
.88028 .72808 L
.88251 .72346 L
.88506 .71849 L
.88763 .71324 L
.88983 .70793 L
.89222 .70244 L
.89433 .69673 L
.89648 .69089 L
.89858 .68455 L
.90059 .67892 L
.90267 .67266 L
.90456 .66657 L
.90661 .65994 L
.90846 .65324 L
.91031 .64634 L
.91212 .64015 L
.9139 .63344 L
.91562 .62667 L
.9173 .6198 L
.91895 .6123 L
.92057 .60594 L
.92214 .5989 L
.92365 .59182 L
.92507 .58468 L
.92642 .57833 L
.92765 .57204 L
.92883 .56568 L
.92979 .56089 L
.93066 .55642 L
.93136 .5525 L
.93192 .54952 L
.93233 .54718 L
.93261 .5456 L
.93276 .54468 L
.93284 .5443 L
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
Mistroke
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
.93278 .54769 L
.93278 .54709 L
.93273 .54594 L
.93263 .54421 L
.93246 .54186 L
.93221 .53885 L
.93188 .53509 L
.93146 .53052 L
.93095 .5255 L
.93038 .51955 L
.92976 .51342 L
.92908 .50669 L
.92837 .49945 L
.92764 .4923 L
.9269 .48496 L
.92617 .47773 L
.92545 .46983 L
.92479 .46302 L
.92418 .45617 L
.92362 .4495 L
.92312 .44303 L
.92266 .43661 L
.92225 .43089 L
.92185 .42528 L
.92146 .42002 L
.92104 .41493 L
.9206 .40993 L
.92012 .40497 L
.91959 .39988 L
.919 .39503 L
.91836 .38992 L
.91765 .38476 L
.91688 .37915 L
.91606 .37397 L
.91517 .36837 L
.91423 .36248 L
.91329 .35698 L
.91237 .35141 L
.91152 .34622 L
.91074 .3413 L
.91007 .33716 L
.90951 .33349 L
.90906 .33037 L
.90873 .32783 L
.90851 .32593 L
.90841 .3245 L
Mistroke
.90838 .32346 L
.9084 .32265 L
.90843 .32195 L
.90841 .32119 L
.90828 .32017 L
.90796 .3188 L
.90745 .317 L
.90671 .31503 L
.90574 .31255 L
.90453 .30956 L
.90309 .30626 L
.9015 .30252 L
.89973 .29898 L
.8978 .29522 L
.89573 .29134 L
.89351 .28753 L
.89133 .28386 L
.88901 .28008 L
.88665 .27637 L
.88426 .27263 L
.88187 .26884 L
.87941 .26497 L
.87687 .26098 L
.87421 .25665 L
.87151 .25245 L
.86862 .24758 L
.86573 .24314 L
.86274 .23849 L
.85971 .23367 L
.85665 .22893 L
.85355 .22404 L
.85044 .21936 L
.84733 .21466 L
.84417 .20982 L
.8411 .20536 L
.83805 .20076 L
.83502 .19645 L
.83199 .19208 L
.82905 .18794 L
.8261 .18384 L
.82311 .17958 L
.82007 .17567 L
.81705 .17171 L
.81392 .16761 L
.81072 .16348 L
.80733 .15916 L
.80426 .15513 L
.80096 .15098 L
.79766 .14677 L
.79471 .14294 L
Mistroke
.79165 .13905 L
.78875 .1353 L
.78598 .13192 L
.78354 .12881 L
.78131 .12609 L
.77945 .12382 L
.77794 .12205 L
.77672 .12071 L
.77581 .1198 L
.77516 .11925 L
.77471 .11897 L
.77444 .11893 L
.77432 .11905 L
.77431 .11928 L
.77438 .11958 L
.77448 .11991 L
.77462 .12023 L
.77475 .12052 L
.77486 .12075 L
.77494 .12091 L
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
.77555 .12105 L
.77547 .1208 L
.77524 .12046 L
.77481 .12003 L
.77415 .11953 L
.77324 .11897 L
.7721 .11834 L
.77074 .11769 L
.7692 .11701 L
.76759 .11631 L
.76585 .11568 L
.76404 .11517 L
.76208 .1148 L
.76005 .11459 L
Mistroke
.75797 .11455 L
.75599 .11465 L
.75411 .11487 L
.75237 .11516 L
.7509 .11551 L
.74981 .11588 L
.74892 .11623 L
.74812 .11653 L
.74745 .11671 L
.74683 .11676 L
.74621 .11657 L
.74555 .11612 L
.74483 .11536 L
.74399 .11426 L
.74287 .11282 L
.74143 .11103 L
.73955 .10892 L
.73733 .10686 L
.73442 .1045 L
.73113 .10201 L
.72699 .09934 L
.72253 .09649 L
.71733 .09364 L
.71228 .09073 L
.70662 .08779 L
.70054 .08481 L
.69471 .08196 L
.68856 .07914 L
.68237 .07646 L
.67591 .07375 L
.67005 .07122 L
.66402 .06869 L
.65772 .0662 L
.65181 .06366 L
.64647 .0614 L
.64071 .05907 L
.63503 .0568 L
.62904 .0545 L
.62354 .05243 L
.61816 .05031 L
.61272 .04832 L
.60711 .04633 L
.6018 .04446 L
.59618 .04279 L
.59089 .04122 L
.58563 .0398 L
.58052 .03859 L
.57538 .03761 L
.57083 .03684 L
.56609 .03627 L
Mistroke
.56191 .03585 L
.55735 .03555 L
.55338 .03534 L
.54912 .03521 L
.54486 .03512 L
.5404 .03504 L
.53579 .03497 L
.53099 .03489 L
.52596 .03478 L
.52079 .03465 L
.51539 .03448 L
.50971 .0343 L
.50365 .03412 L
.49798 .03392 L
.49191 .03371 L
.48577 .03347 L
.47953 .03321 L
.47344 .03295 L
.46749 .03274 L
.46138 .03258 L
.45595 .0325 L
.45032 .03251 L
.44486 .0326 L
.43937 .03276 L
.43417 .03299 L
.42902 .03326 L
.42387 .03356 L
.4191 .03386 L
.41422 .03415 L
.40985 .0344 L
.40562 .0346 L
.40142 .03477 L
.39816 .03489 L
.39512 .03498 L
.39232 .03503 L
.38998 .03504 L
.38788 .03503 L
.38602 .03505 L
.38432 .03516 L
.38261 .03544 L
.38079 .03592 L
.37882 .03664 L
.37648 .0376 L
.37363 .03884 L
.37062 .04037 L
.36697 .04217 L
.36295 .04425 L
.35866 .04641 L
.354 .04876 L
.34885 .05141 L
Mistroke
.34402 .05401 L
.33882 .05683 L
.33361 .05975 L
.32812 .06285 L
.32319 .06583 L
.31806 .0689 L
.31301 .07192 L
.30784 .07502 L
.30304 .07787 L
.29773 .08089 L
.2927 .08401 L
.28785 .08707 L
.28222 .09036 L
.2773 .09364 L
.27184 .09703 L
.26636 .10045 L
.26086 .10386 L
.25531 .10731 L
.2503 .1107 L
.24503 .11405 L
.23987 .1174 L
.23452 .12084 L
.23 .12407 L
.22538 .12739 L
.22105 .13067 L
.21695 .13394 L
.21315 .13724 L
.20948 .1406 L
.20595 .14413 L
.20269 .14769 L
.19937 .15144 L
.19596 .15553 L
.19272 .15962 L
.18947 .16391 L
.18614 .16843 L
.18289 .17312 L
.17967 .178 L
.17652 .18294 L
.1734 .18786 L
.17015 .1932 L
.16716 .19796 L
.16404 .20304 L
.16085 .20811 L
.15772 .21349 L
.1546 .21822 L
.15134 .22353 L
.14828 .22849 L
.14506 .23382 L
.14201 .23905 L
.13883 .24442 L
Mistroke
.13564 .24972 L
.13256 .25493 L
.12958 .26001 L
.12686 .26509 L
.12423 .27007 L
.12167 .27439 L
.1193 .27878 L
.11685 .28338 L
.11476 .28716 L
.11263 .29096 L
.11047 .29485 L
.1086 .2984 L
.10666 .3021 L
.10487 .30563 L
.10308 .30921 L
.10134 .31307 L
.09977 .31692 L
.09821 .32109 L
.09667 .32547 L
.09526 .33014 L
.09389 .33492 L
.09267 .33998 L
.09153 .34527 L
.09047 .35042 L
.08945 .35618 L
.08849 .36108 L
.08759 .36664 L
.08675 .37131 L
.08603 .37607 L
.08548 .38008 L
.08507 .3839 L
.0848 .38691 L
.08466 .38968 L
.08467 .39188 L
.08484 .39377 L
.0852 .39539 L
.08577 .39683 L
.08653 .39817 L
.08746 .39956 L
.08855 .40106 L
.08968 .40257 L
.09087 .40445 L
.09206 .40667 L
.09314 .40936 L
.09423 .41241 L
.09519 .41582 L
.09606 .41945 L
.09677 .42334 L
.09727 .42743 L
.0975 .43183 L
Mistroke
.0974 .43579 L
.09698 .44008 L
.09625 .44443 L
.09527 .44879 L
.09411 .45309 L
.0928 .45693 L
.09157 .46071 L
.09021 .46398 L
.08873 .46697 L
.08738 .46952 L
.08604 .47171 L
.08474 .47347 L
.08362 .47488 L
.08264 .47606 L
.0818 .47708 L
.08113 .47797 L
.08062 .47878 L
.08022 .47959 L
.0799 .48045 L
.07962 .48137 L
.07938 .48232 L
.07915 .48327 L
.07892 .48419 L
.07868 .48507 L
.07843 .48593 L
.07814 .48679 L
.07778 .48766 L
.07736 .4886 L
.07687 .4897 L
.07626 .49094 L
.07555 .49243 L
.07478 .49404 L
.07394 .49589 L
.07301 .498 L
.07206 .5002 L
.0711 .50286 L
.07018 .50582 L
.06939 .50911 L
.06877 .51263 L
.06835 .51613 L
.06811 .5199 L
.06804 .52358 L
.06812 .52733 L
.06834 .53103 L
.06858 .53455 L
.06897 .53817 L
.06951 .54184 L
.07007 .54538 L
.07069 .5493 L
.07136 .55321 L
Mistroke
.07206 .55698 L
.07276 .56122 L
.07343 .56547 L
.0741 .56966 L
.07476 .57448 L
.07538 .57892 L
.07599 .58367 L
.07662 .58869 L
.07721 .59318 L
.0778 .59823 L
.07836 .60269 L
.07887 .60723 L
.07935 .61156 L
.07981 .61613 L
.08028 .61986 L
.08078 .62374 L
.0813 .62756 L
.08186 .63115 L
.08248 .63474 L
.08316 .63827 L
.08384 .64178 L
.08455 .64533 L
.08527 .64856 L
.08593 .65173 L
.08657 .65457 L
.08715 .65724 L
.08765 .65932 L
.08806 .66104 L
.08838 .66236 L
.08864 .66331 L
.08881 .66388 L
.08891 .66413 L
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
.08862 .66173 L
.08862 .66212 L
.08866 .66289 L
.08875 .66407 L
.08889 .66564 L
.0891 .66767 L
.08939 .6703 L
.08978 .67331 L
.09025 .67692 L
.09082 .68089 L
.09146 .68555 L
Mistroke
.09217 .69009 L
.0929 .69424 L
.09368 .69885 L
.0945 .70309 L
.09525 .70711 L
.09605 .71086 L
.09675 .71379 L
.09742 .71641 L
.09804 .71837 L
.0986 .7199 L
.09909 .721 L
.09949 .72164 L
.09982 .72185 L
.10008 .72181 L
.10028 .7217 L
.10041 .72156 L
.1005 .72145 L
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
.10016 .72074 L
.10033 .72121 L
.10064 .72206 L
.10111 .72334 L
.10176 .72509 L
.10257 .72708 L
.10359 .7294 L
.10484 .73195 L
.1063 .73452 L
.10754 .73712 L
.10914 .73965 L
.11068 .74217 L
.11254 .74457 L
.11404 .74657 L
.1156 .74837 L
.11714 .74989 L
.11854 .75114 L
.11982 .75212 L
Mistroke
.12098 .75293 L
.12206 .75359 L
.12298 .75411 L
.1239 .75456 L
.12466 .75493 L
.12539 .75528 L
.12601 .75554 L
.12658 .75579 L
.12709 .75604 L
.12753 .75619 L
.12788 .75628 L
.12816 .75634 L
.12837 .75636 L
.12851 .75634 L
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
.12667 .75548 L
.12681 .75592 L
.12712 .75652 L
.1277 .75744 L
.12853 .75868 L
.12966 .76026 L
.13117 .76199 L
.13299 .7641 L
.13476 .76643 L
.13667 .76884 L
.13881 .77143 L
.14075 .77391 L
.14305 .77634 L
.14516 .77867 L
.1472 .78073 L
.14892 .78236 L
.15044 .78374 L
.15175 .78485 L
.15277 .78566 L
.15359 .78621 L
.15413 .78652 L
.15445 .78666 L
.15461 .78663 L
.15465 .78649 L
Mistroke
.15461 .78627 L
.15452 .78602 L
.15441 .78582 L
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
.1565 .78514 L
.15678 .78583 L
.1572 .78687 L
.15777 .78824 L
.15849 .78994 L
.15935 .79194 L
.16018 .7939 L
.16117 .79612 L
.16218 .79833 L
.16319 .80064 L
.16417 .80284 L
.16503 .80501 L
.16579 .80668 L
.16641 .80809 L
.16687 .80921 L
.16717 .80995 L
.16731 .81028 L
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
.1663 .80419 L
.16628 .80459 L
.1664 .80523 L
Mistroke
.1667 .80612 L
.16723 .80729 L
.16803 .80867 L
.16917 .81044 L
.17066 .8128 L
.17253 .81518 L
.17484 .81812 L
.17758 .82139 L
.18089 .82528 L
.18424 .82894 L
.18817 .83308 L
.19243 .8376 L
.1968 .84206 L
.20137 .84684 L
.20607 .8514 L
.21118 .85676 L
.21571 .8612 L
.22061 .86634 L
.22594 .87114 L
.23039 .87542 L
.2352 .87974 L
.23998 .88381 L
.24472 .8878 L
.24958 .89114 L
.25399 .89441 L
.2588 .8975 L
.26353 .90024 L
.26811 .90279 L
.27295 .90517 L
.27787 .90737 L
.28311 .9095 L
.28792 .91138 L
.29307 .91329 L
.29856 .91518 L
.30375 .91703 L
.3091 .91896 L
.31517 .92087 L
.32078 .92278 L
.32642 .9248 L
.33243 .92671 L
.33833 .92869 L
.34405 .93058 L
.34972 .93255 L
.35582 .93444 L
.36146 .93633 L
.36723 .93834 L
.37296 .94027 L
.3782 .94215 L
.38373 .94407 L
.38895 .94582 L
Mistroke
.39396 .94756 L
.39868 .9491 L
.40325 .95059 L
.40752 .95199 L
.41161 .95336 L
.41551 .95457 L
.41901 .95575 L
.42231 .9569 L
.42546 .95795 L
.42837 .95899 L
.43119 .96001 L
.43396 .96098 L
.43675 .96196 L
.43963 .96292 L
.44277 .96381 L
.44596 .96467 L
.44942 .96544 L
.45333 .96609 L
.45684 .96658 L
.46064 .96691 L
.46459 .96709 L
.46851 .96715 L
.47214 .96709 L
.47554 .96695 L
.47873 .96676 L
.48123 .9665 L
.48355 .9662 L
.48532 .9659 L
.48675 .96561 L
.48785 .96536 L
.48854 .9652 L
.48892 .96513 L
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
Mistroke
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
.487 .96548 L
.4872 .96548 L
.48751 .96544 L
.48794 .96534 L
.48848 .96519 L
.48911 .96493 L
.48977 .96455 L
.49045 .96404 L
.49113 .9634 L
.49189 .96263 L
.4925 .96182 L
.49321 .9609 L
.49389 .95993 L
.4945 .95896 L
.49504 .95804 L
.4955 .9572 L
.49588 .95647 L
.49622 .95584 L
.49648 .95533 L
.49674 .95493 L
.49701 .95467 L
.4973 .95455 L
.49755 .95454 L
.49782 .95459 L
.49805 .95469 L
Mistroke
.49826 .95477 L
.49847 .95475 L
.49875 .95456 L
.49915 .95419 L
.49969 .95367 L
.50044 .95303 L
.50147 .95231 L
.50276 .95151 L
.50425 .95066 L
.50588 .94975 L
.50743 .9488 L
.5091 .94784 L
.51094 .9468 L
.51257 .94582 L
.51419 .94486 L
.51555 .94401 L
.51696 .9431 L
.51824 .94219 L
.5196 .94117 L
.52066 .94029 L
.52174 .93923 L
.5229 .93789 L
.52392 .93679 L
.52514 .93549 L
.52648 .93421 L
.52808 .93282 L
.52937 .93168 L
.5309 .93058 L
.53223 .92957 L
.53359 .92858 L
.53473 .92777 L
.53574 .92706 L
.53654 .9265 L
.53715 .92603 L
.53762 .92575 L
.53796 .92554 L
.53819 .92539 L
.53835 .92528 L
.53847 .92521 L
.53859 .92513 L
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
Mistroke
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
.53847 .92516 L
.53823 .92528 L
.53797 .9254 L
.53772 .92549 L
.53752 .92559 L
.5374 .92572 L
.5374 .92589 L
.5376 .92609 L
.53805 .92627 L
.53882 .9264 L
.53999 .92643 L
.54164 .92637 L
.54383 .92624 L
.54647 .926 L
.5496 .92563 L
.55305 .92515 L
.55699 .9247 L
.56069 .92431 L
.56454 .92391 L
.56839 .92357 L
.57161 .92332 L
.57469 .92313 L
.57738 .92302 L
.57947 .92306 L
.58118 .92327 L
.58245 .92355 L
.58323 .92352 L
.58372 .92368 L
.58395 .9238 L
.584 .92376 L
.58398 .92349 L
.58394 .92299 L
.58393 .92232 L
.58396 .92156 L
.58407 .9206 L
.58427 .91973 L
.58453 .91893 L
.58484 .91797 L
.58516 .91704 L
.58552 .91629 L
.58593 .91584 L
Mistroke
.58646 .91558 L
.58718 .91544 L
.58815 .91536 L
.58947 .91524 L
.59121 .91502 L
.59344 .91468 L
.59598 .91415 L
.59904 .91343 L
.60245 .91255 L
.6065 .91153 L
.61051 .91041 L
.6149 .90919 L
.61936 .90792 L
.62408 .90663 L
.62859 .90537 L
.63318 .90418 L
.63749 .90312 L
.6414 .9022 L
.64504 .90147 L
.64827 .90091 L
.65081 .90051 L
.65309 .90023 L
.65497 .90007 L
.65642 .90002 L
.65754 .90011 L
.65841 .90028 L
.65915 .90054 L
.6599 .9008 L
.66077 .90102 L
.66185 .90113 L
.66317 .90111 L
.6649 .90093 L
.66693 .90058 L
.66929 .90008 L
.67178 .89946 L
.6747 .89871 L
.67767 .8978 L
.68085 .89672 L
.68395 .89555 L
.68699 .89428 L
.68988 .89297 L
.69247 .89165 L
.69478 .89038 L
.69678 .88923 L
.69847 .88821 L
.69983 .88733 L
.7009 .8866 L
.7017 .88601 L
.70224 .88552 L
.70253 .88513 L
Mistroke
.70261 .88483 L
.70254 .88463 L
.70236 .88455 L
.70216 .88457 L
.70203 .88465 L
.70204 .88478 L
.70225 .88491 L
.7027 .88504 L
.70339 .88516 L
.70433 .88527 L
.70551 .88537 L
.70681 .88546 L
.7082 .88553 L
.70973 .88559 L
.71128 .88564 L
.71296 .88568 L
.71434 .8857 L
.71556 .8857 L
.71656 .88569 L
.71732 .88567 L
.71788 .88566 L
.71827 .88567 L
.71852 .8857 L
.71877 .88575 L
.71922 .8858 L
.72 .8858 L
.7212 .88571 L
.72285 .88546 L
.72515 .88503 L
.72789 .88438 L
.73071 .88351 L
.73454 .8824 L
.73815 .88102 L
.74249 .87945 L
.74733 .87758 L
.7524 .87547 L
.757 .87305 L
.76211 .87035 L
.76729 .86758 L
.77213 .86454 L
.77688 .86144 L
.78166 .85817 L
.78662 .85492 L
.79071 .85161 L
.7951 .84824 L
.79958 .84476 L
.80368 .84119 L
.80751 .83777 L
.81156 .8341 L
.81518 .83067 L
Mistroke
.81881 .82716 L
.82228 .82376 L
.82554 .82044 L
.82875 .81714 L
.8318 .81416 L
.83472 .81116 L
.83757 .80821 L
.84052 .80524 L
.8431 .80252 L
.84586 .79971 L
.84848 .79688 L
.8511 .79403 L
.85379 .79106 L
.8563 .78812 L
.85876 .78511 L
.86116 .78202 L
.86329 .77921 L
.8653 .77645 L
.86717 .7738 L
.86871 .77153 L
.87007 .76941 L
.87121 .76757 L
.87206 .76614 L
.87264 .7651 L
.87294 .76446 L
.873 .76417 L
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
Mistroke
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
.86994 .76937 L
.86981 .7696 L
.86961 .7699 L
.86933 .77028 L
.86897 .77069 L
.86851 .77122 L
.86799 .77185 L
.86746 .77258 L
.86691 .77343 L
.86638 .77444 L
.86587 .77558 L
.86544 .77693 L
.86503 .77811 L
.86467 .77923 L
.86439 .78018 L
.8642 .78096 L
.86407 .78163 L
.86398 .7822 L
.86392 .78268 L
.86388 .78308 L
.86382 .78341 L
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
.86367 .78375 L
.86392 .78345 L
.86431 .78286 L
.86489 .78194 L
.86571 .78052 L
.86661 .77887 L
.86778 .77665 L
.86909 .77393 L
.87053 .77086 L
.87204 .76737 L
.87359 .76357 L
.87521 .75929 L
.87687 .75461 L
.87874 .74952 L
.88044 .74402 L
.88232 .73821 L
.88426 .73212 L
.8862 .72573 L
Mistroke
.88828 .71883 L
.89029 .71227 L
.89249 .70528 L
.89463 .69774 L
.89652 .69121 L
.8985 .68431 L
.90039 .67774 L
.90217 .67153 L
.9037 .66617 L
.90504 .66123 L
.90618 .65653 L
.90715 .65283 L
.90806 .64936 L
.90889 .6461 L
.90972 .64306 L
.91056 .63993 L
.91145 .63674 L
.91232 .63328 L
.91328 .62939 L
.91421 .62533 L
.91522 .62111 L
.91631 .61629 L
.91741 .61085 L
.91858 .60531 L
.91974 .59945 L
.92085 .59371 L
.92194 .58794 L
.92296 .58222 L
.92392 .57663 L
.92484 .57138 L
.92571 .5663 L
.92655 .56133 L
.92732 .55663 L
.92803 .55182 L
.9286 .54723 L
.92906 .54248 L
.92935 .53772 L
.92951 .53303 L
.92953 .52835 L
.92943 .52379 L
.92921 .51944 L
.92893 .51538 L
.9286 .51164 L
.92825 .50825 L
.92791 .50536 L
.92761 .50286 L
.92736 .50083 L
.9272 .49926 L
.92711 .49812 L
.92709 .49743 L
Mistroke
.92713 .49716 L
.92723 .49722 L
.92737 .4975 L
.92753 .49794 L
.92767 .49845 L
.92775 .499 L
.92777 .49958 L
.92769 .50024 L
.92751 .50106 L
.92724 .50213 L
.92688 .50355 L
.92644 .5054 L
.92593 .50772 L
.92535 .51054 L
.92474 .51357 L
.92409 .51721 L
.92344 .52153 L
.92282 .52576 L
.92228 .53081 L
.92181 .53669 L
.92147 .54196 L
.92125 .54815 L
.92112 .55475 L
.92103 .56068 L
.92093 .56752 L
.92074 .5737 L
.92042 .58069 L
.91993 .5868 L
.91925 .59381 L
.91842 .6003 L
.91739 .60699 L
.91617 .61363 L
.91478 .62039 L
.91322 .62734 L
.9115 .63414 L
.90967 .64098 L
.90773 .64778 L
.90572 .65492 L
.90369 .66181 L
.90163 .6689 L
.89954 .67621 L
.89744 .68403 L
.89535 .69105 L
.89329 .69852 L
.89129 .70592 L
.88933 .71315 L
.88738 .72058 L
.88544 .72748 L
.88353 .73458 L
.88162 .74102 L
Mistroke
.87967 .7477 L
.87769 .75405 L
.87561 .76002 L
.87335 .76632 L
.87099 .77148 L
.86837 .77689 L
.86538 .78218 L
.86213 .78698 L
.85846 .79205 L
.85464 .79663 L
.8503 .80135 L
.84629 .80563 L
.84197 .8098 L
.83738 .81382 L
.83322 .81759 L
.82877 .82124 L
.82436 .82483 L
.81949 .82863 L
.81529 .83216 L
.81058 .83593 L
.80585 .83979 L
.80056 .84385 L
.796 .84755 L
.79053 .85162 L
.78565 .8556 L
.77986 .85993 L
.77458 .86411 L
.76888 .86846 L
.76294 .87304 L
.75743 .87725 L
.75158 .88163 L
.7458 .88599 L
.7402 .89032 L
.73441 .89447 L
.72887 .89843 L
.72324 .90253 L
.71762 .90638 L
.71237 .91016 L
.70742 .91367 L
.70258 .91706 L
.69823 .92013 L
.69383 .92307 L
.69034 .92541 L
.68719 .92751 L
.68447 .9293 L
.68235 .93069 L
.68078 .93178 L
.67972 .93261 L
.67907 .93319 L
.67873 .93356 L
Mistroke
.67856 .93374 L
.67844 .93377 L
.67824 .93366 L
.67783 .93344 L
.67716 .93313 L
.67618 .93277 L
.67483 .93239 L
.67301 .93203 L
.67061 .93174 L
.66767 .93154 L
.6643 .93145 L
.66023 .93146 L
.65544 .93157 L
.65079 .93179 L
.64555 .93208 L
.64069 .93252 L
.63501 .93321 L
.62971 .93389 L
.62377 .9348 L
.61839 .93584 L
.61245 .937 L
.60678 .93807 L
.60157 .93923 L
.59596 .94041 L
.59079 .94152 L
.58548 .94271 L
.58033 .94396 L
.57514 .9454 L
.57024 .94663 L
.56497 .94806 L
.56013 .94954 L
.5548 .95106 L
.54958 .95253 L
.54434 .95401 L
.53847 .9555 L
.53314 .95697 L
.52724 .95845 L
.52115 .95991 L
.51497 .9613 L
.50838 .96261 L
.50251 .96377 L
.4958 .96475 L
.48943 .96549 L
.48349 .96599 L
.47709 .96624 L
.47136 .96623 L
.46549 .96597 L
.45966 .96545 L
.45429 .9647 L
.44888 .96374 L
Mistroke
.44377 .96259 L
.43859 .96133 L
.43404 .95994 L
.42948 .95849 L
.42512 .95699 L
.4209 .95555 L
.41689 .9541 L
.41303 .9527 L
.40928 .95133 L
.40562 .95003 L
.40224 .94873 L
.39889 .94746 L
.39574 .94628 L
.39269 .94515 L
.38998 .94411 L
.38747 .94319 L
.38533 .94235 L
.38348 .9416 L
.38193 .94095 L
.38069 .9404 L
.37974 .93997 L
.37907 .93965 L
.37864 .93946 L
.37844 .93936 L
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
Mistroke
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
.38043 .94034 L
.38009 .94021 L
.37946 .93997 L
.37847 .9396 L
.37705 .9391 L
.37517 .93848 L
.37305 .93773 L
.37044 .93689 L
.36738 .93593 L
.36402 .93483 L
.36012 .93364 L
.35611 .93236 L
.35146 .93095 L
.34713 .92946 L
.34199 .9279 L
.33746 .92635 L
.3322 .92474 L
.32772 .92315 L
.32277 .9215 L
.3181 .91982 L
.31345 .91801 L
.3087 .9163 L
.30446 .91446 L
.3002 .91275 L
.29601 .91105 L
.29221 .90942 L
.28852 .90785 L
.28493 .90645 L
.28162 .905 L
.2783 .90376 L
.27543 .90257 L
.2726 .90144 L
.26992 .9004 L
.26773 .89949 L
.26563 .89864 L
.26379 .89789 L
.26222 .89728 L
.26098 .89676 L
.25999 .89632 L
.25927 .89595 L
.25877 .89563 L
.25848 .89537 L
.25836 .8952 L
Mistroke
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
.25955 .89601 L
.25903 .89564 L
.2582 .895 L
.25703 .89403 L
.2555 .8927 L
.25359 .89097 L
.25165 .88918 L
.24917 .88686 L
.24661 .8845 L
.24367 .88163 L
.24054 .87856 L
.23745 .87553 L
.23439 .87243 L
.23123 .86914 L
.22811 .8658 L
.22512 .86268 L
.22223 .85959 L
.21945 .85672 L
.21672 .85388 L
.21397 .85128 L
.21126 .8487 L
.20844 .84618 L
.20573 .84357 L
.20287 .84129 L
.20014 .8389 L
.19735 .83653 L
.19466 .83407 L
.19198 .83189 L
.18934 .82959 L
.1866 .82728 L
.18412 .82488 L
.18156 .82249 L
.17901 .81992 L
.17654 .81758 L
.17406 .815 L
.17184 .81243 L
.1696 .80967 L
.16751 .80725 L
Mistroke
.16541 .80466 L
.16335 .80193 L
.16131 .79914 L
.1593 .79628 L
.15725 .7932 L
.1553 .79058 L
.15343 .78763 L
.15165 .78482 L
.15006 .78197 L
.14861 .77917 L
.14736 .77658 L
.14623 .77405 L
.14535 .7717 L
.14464 .7697 L
.14412 .76794 L
.1438 .76642 L
.14366 .76517 L
.14366 .76405 L
.14371 .76304 L
.14372 .76202 L
.14364 .76094 L
.14337 .75974 L
.14287 .75833 L
.14213 .75677 L
.14114 .75485 L
.13991 .75253 L
.13851 .75009 L
.13683 .7471 L
.13491 .74363 L
.13302 .74023 L
.13086 .73634 L
.12868 .73232 L
.12638 .72804 L
.12395 .72396 L
.12167 .71983 L
.11941 .71567 L
.1174 .7118 L
.11543 .70807 L
.11364 .70438 L
.11215 .70119 L
.11086 .69797 L
.10987 .69501 L
.1092 .69246 L
.10881 .69003 L
.10869 .68784 L
.10877 .68586 L
.10904 .68421 L
.10942 .68277 L
.10986 .68155 L
.11032 .68055 L
Mistroke
.11077 .67975 L
.11119 .67911 L
.11153 .67861 L
.1118 .67825 L
.11198 .67801 L
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
.11229 .6785 L
.11246 .67867 L
.11257 .67887 L
.11257 .67906 L
.11233 .6792 L
.11183 .67922 L
.11106 .67904 L
.10995 .67858 L
.1085 .67779 L
.10671 .67664 L
.10479 .67511 L
.10325 .67328 L
.10111 .67111 L
.09867 .66841 L
.09668 .66535 L
.09415 .66179 L
.09215 .6578 L
.09015 .65347 L
.08823 .64925 L
.08651 .64388 L
.08519 .63921 L
.08397 .63365 L
.08292 .62844 L
.08196 .62253 L
.08107 .61705 L
.08024 .61154 L
.07944 .60597 L
.07871 .60032 L
.07805 .5942 L
.07746 .58907 L
Mistroke
.07693 .58295 L
.07643 .57794 L
.07594 .57268 L
.07542 .56744 L
.07489 .56235 L
.07434 .55761 L
.07378 .5525 L
.07322 .54849 L
.0727 .54427 L
.07219 .54054 L
.0717 .53752 L
.07126 .5347 L
.07088 .53233 L
.07055 .53065 L
.0703 .52948 L
.07012 .52874 L
.07 .52832 L
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
Mistroke
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
Mistroke
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
.07573 .51733 L
.07578 .51685 L
.0758 .51596 L
.07583 .51463 L
.07593 .51277 L
.0761 .51058 L
.07638 .50763 L
.07674 .50461 L
.07719 .50106 L
.07772 .49712 L
.07828 .49331 L
.07888 .48922 L
.0795 .48538 L
.08012 .4821 L
.08072 .47888 L
.08125 .47612 L
.08171 .47373 L
.0821 .47205 L
.0824 .47079 L
.08263 .47006 L
.08277 .46972 L
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
Mistroke
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
.08255 .47159 L
.08273 .47127 L
.08301 .47087 L
.0834 .47043 L
.08389 .46997 L
.08449 .46937 L
.0851 .46869 L
.08581 .46797 L
.08658 .46724 L
.08731 .46656 L
.08804 .46594 L
.08874 .46542 L
.08936 .465 L
Mistroke
.08987 .46467 L
.09029 .46446 L
.0906 .46438 L
.0908 .46439 L
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
.09098 .46469 L
.09121 .46469 L
.09147 .46466 L
.09174 .46459 L
.09206 .46451 L
.09243 .46441 L
.09289 .4643 L
.09343 .46422 L
.09415 .4642 L
.09491 .46425 L
.09585 .4644 L
.09705 .46468 L
.09856 .46514 L
.10029 .46581 L
.10199 .46669 L
.10363 .46777 L
.10574 .46908 L
.10811 .47061 L
.11037 .47231 L
.11279 .47422 L
.11562 .4763 L
.11775 .47872 L
.12072 .48137 L
.123 .48419 L
.12532 .48715 L
.12745 .49055 L
.12945 .49389 L
.13135 .49736 L
.1332 .50118 L
Mistroke
.1349 .50443 L
.13647 .50784 L
.13794 .51105 L
.13929 .51371 L
.14048 .51629 L
.14151 .51841 L
.14232 .52003 L
.14295 .5212 L
.1434 .52189 L
.14371 .52217 L
.14388 .5221 L
.14396 .52182 L
.14396 .52141 L
.1439 .52096 L
.14383 .52053 L
.14375 .52015 L
.14368 .51986 L
.14363 .51964 L
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
.14337 .51863 L
.14322 .51896 L
.1431 .51961 L
.14303 .52066 L
.14304 .5222 L
.14311 .52434 L
.14326 .52669 L
.14345 .52983 L
.14364 .5332 L
.14389 .53697 L
Mistroke
.14418 .54138 L
.14453 .54555 L
.14497 .55009 L
.14544 .55527 L
.14598 .55932 L
.14654 .56385 L
.14714 .56859 L
.14775 .57251 L
.1484 .57687 L
.14904 .58088 L
.14977 .58479 L
.15056 .58882 L
.15143 .59288 L
.15233 .59687 L
.15321 .60091 L
.154 .60502 L
.15465 .60889 L
.1552 .61331 L
.15563 .6168 L
.15599 .6205 L
.1563 .62417 L
.15663 .62758 L
.15701 .63116 L
.15752 .63445 L
.1582 .63795 L
.15908 .64153 L
.16022 .64551 L
.1615 .649 L
.16312 .65282 L
.16497 .65683 L
.16703 .66089 L
.16926 .66484 L
.17156 .66889 L
.17383 .67231 L
.17569 .67548 L
.17734 .67844 L
.17883 .68105 L
.18009 .68304 L
.18123 .68458 L
.18215 .68557 L
.18303 .68608 L
.18397 .68624 L
.18507 .68608 L
.18643 .68565 L
.18808 .68503 L
.19003 .68427 L
.1919 .68342 L
.19427 .68247 L
.19667 .68148 L
.19945 .68043 L
Mistroke
.20251 .67934 L
.20577 .67821 L
.20865 .67707 L
.21184 .67599 L
.21484 .67495 L
.21784 .67398 L
.22083 .6731 L
.22379 .67232 L
.22673 .67167 L
.22991 .67112 L
.23308 .67072 L
.23641 .67049 L
.23987 .6705 L
.24363 .67076 L
.24711 .67128 L
.25088 .67204 L
.25495 .67305 L
.25847 .67434 L
.26223 .67581 L
.2661 .67749 L
.26964 .67941 L
.27329 .68131 L
.27692 .68337 L
.28059 .68558 L
.284 .68763 L
.28767 .68977 L
.29145 .69182 L
.29542 .69378 L
.29954 .69558 L
.30385 .69725 L
.30773 .69868 L
.31172 .69994 L
.31554 .70101 L
.31909 .7019 L
.32216 .70261 L
.32483 .70319 L
.32741 .70363 L
.32939 .70393 L
.33099 .7041 L
.33208 .70419 L
.33264 .7042 L
.33271 .70416 L
.3324 .70408 L
.33187 .70401 L
.33123 .70395 L
.33056 .70391 L
.32997 .70391 L
.32947 .70392 L
.3291 .70394 L
.32878 .70395 L
Mistroke
.32855 .70396 L
.32839 .70397 L
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
.32885 .70422 L
.32919 .7043 L
.3298 .70434 L
.33067 .70432 L
.33181 .70421 L
.33317 .70397 L
.33478 .70355 L
.33664 .70296 L
.33855 .70218 L
.34062 .7012 L
.34287 .70006 L
.34502 .69872 L
.34742 .69711 L
.34966 .69522 L
.35198 .69317 L
.35427 .69085 L
.35655 .68821 L
.35888 .68552 L
.36138 .68243 L
.36389 .67951 L
.36664 .6763 L
.36972 .67277 L
.37276 .66971 L
.37614 .6663 L
.37966 .66274 L
.3834 .65929 L
.38686 .65592 L
.39043 .6525 L
.39422 .64923 L
.39741 .64598 L
.40077 .64285 L
.40396 .63962 L
.40719 .6364 L
.41001 .63302 L
.4128 .62963 L
Mistroke
.41532 .62611 L
.41769 .62249 L
.41979 .61894 L
.42173 .61572 L
.42339 .61261 L
.42487 .60966 L
.42614 .60698 L
.42718 .60455 L
.42801 .60254 L
.42867 .60093 L
.42919 .59968 L
.42958 .59878 L
.42986 .59821 L
.43008 .59792 L
.43027 .59786 L
.43045 .59794 L
.43064 .59809 L
.43083 .59826 L
.431 .59844 L
.43118 .59857 L
.43138 .59864 L
.43158 .59866 L
.43177 .59865 L
.43192 .59865 L
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
.43194 .5986 L
.43179 .59833 L
.4316 .59797 L
.43137 .59756 L
.43112 .5971 L
.43086 .59661 L
.4306 .59612 L
.43033 .59563 L
.43006 .59513 L
.42979 .59463 L
.42953 .59419 L
.42926 .59386 L
Mistroke
.42901 .59369 L
.42878 .5937 L
.42862 .59388 L
.42855 .59422 L
.42858 .59468 L
.42877 .59519 L
.42914 .59567 L
.42976 .59604 L
.43073 .59622 L
.43212 .59611 L
.43398 .59571 L
.43628 .59506 L
.43898 .59414 L
.44218 .59279 L
.44579 .591 L
.44969 .58891 L
.45389 .58642 L
.45851 .58359 L
.463 .58063 L
.46789 .57735 L
.47296 .57392 L
.47752 .57076 L
.48251 .56736 L
.48734 .564 L
.49227 .56064 L
.49721 .55699 L
.50197 .55373 L
.50678 .55026 L
.51157 .54667 L
.51653 .54302 L
.52113 .5392 L
.52571 .53553 L
.5301 .53173 L
.53422 .52795 L
.5381 .52415 L
.54184 .52021 L
.54504 .5165 L
.54815 .51263 L
.55107 .50865 L
.55388 .50443 L
.5565 .5005 L
.5591 .49622 L
.56167 .49195 L
.56434 .48768 L
.56689 .48317 L
.56958 .47894 L
.57254 .47458 L
.57547 .47038 L
.5787 .46607 L
.5823 .46137 L
Mistroke
.58568 .45755 L
.58953 .45334 L
.59344 .44928 L
.59752 .44517 L
.60207 .44102 L
.60634 .43714 L
.61096 .43317 L
.61578 .42922 L
.62103 .42524 L
.62603 .42146 L
.63135 .41765 L
.63734 .41374 L
.64254 .41026 L
.64842 .40666 L
.6542 .40319 L
.66061 .39967 L
.66609 .39644 L
.67204 .39325 L
.67856 .38999 L
.68396 .38686 L
.6898 .38364 L
.69565 .38042 L
.70186 .37716 L
.70704 .37377 L
.71259 .37055 L
.71794 .36715 L
.723 .36376 L
.72794 .36041 L
.73312 .35691 L
.73784 .35341 L
.7424 .35018 L
.74707 .34673 L
.75183 .34338 L
.75634 .33989 L
.76112 .33661 L
.76543 .33326 L
.77008 .32969 L
.7747 .32647 L
.77881 .32278 L
.7833 .31947 L
.78766 .31598 L
.79186 .31299 L
.79605 .30973 L
.8003 .30668 L
.80415 .30406 L
.8081 .30148 L
.81191 .29928 L
.8158 .29741 L
.81956 .2958 L
.82354 .29457 L
Mistroke
.82722 .29365 L
.831 .29302 L
.83473 .29264 L
.83848 .29246 L
.84226 .29242 L
.84602 .2925 L
.84986 .29264 L
.85344 .29281 L
.85705 .29298 L
.8607 .29312 L
.86406 .29322 L
.86746 .29327 L
.87081 .29328 L
.87388 .29326 L
.87682 .29322 L
.8795 .29318 L
.88189 .29317 L
.88398 .29319 L
.8859 .29325 L
.88765 .29337 L
.88919 .29359 L
.89061 .29391 L
.89188 .29432 L
.89302 .29484 L
.89401 .29544 L
.89485 .2961 L
.89553 .29681 L
.8961 .29753 L
.89659 .2982 L
.89704 .2988 L
.89744 .29932 L
.89776 .29974 L
.898 .30007 L
.89815 .30033 L
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
.89803 .30187 L
.89788 .30175 L
.8977 .30152 L
Mistroke
.89752 .30117 L
.89735 .30071 L
.89719 .30011 L
.89703 .29938 L
.89686 .29849 L
.89668 .29742 L
.89647 .29618 L
.89624 .29478 L
.89598 .2934 L
.89567 .29184 L
.8953 .2902 L
.89484 .2886 L
.89424 .28691 L
.89348 .28513 L
.89258 .28331 L
.89149 .28148 L
.89021 .27956 L
.88885 .27769 L
.88738 .2758 L
.8858 .27388 L
.88425 .2721 L
.88273 .27031 L
.88117 .26852 L
.87957 .26689 L
.87818 .26528 L
.87678 .26392 L
.87531 .26271 L
.87382 .26168 L
.87234 .26088 L
.87076 .26028 L
.86902 .25988 L
.86737 .25965 L
.86559 .25956 L
.86375 .25957 L
.86201 .25963 L
.86074 .25971 L
.8593 .25973 L
.85823 .25964 L
.85736 .25948 L
.85672 .2593 L
.85639 .25914 L
.85641 .25906 L
.85674 .25916 L
.85736 .2595 L
.85811 .26012 L
.85903 .26106 L
.86 .26238 L
.86099 .2641 L
.86193 .2662 L
.86277 .26818 L
Mistroke
.86353 .27057 L
.86418 .27335 L
.86473 .2759 L
.86517 .27881 L
.8656 .28125 L
.86601 .28366 L
.86644 .28578 L
.8669 .28767 L
.86742 .28914 L
.86806 .29031 L
.8689 .29116 L
.87 .29174 L
.87127 .29215 L
.87285 .29244 L
.87446 .29264 L
.87637 .29276 L
.87847 .29286 L
.88063 .29294 L
.8827 .29303 L
.88488 .29312 L
.88661 .29325 L
.88836 .29337 L
.88972 .29349 L
.89087 .29358 L
.89177 .29366 L
.89238 .29373 L
.89273 .29378 L
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
Mistroke
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
.89221 .29136 L
.89247 .29158 L
.89282 .29189 L
.89322 .29226 L
.89367 .29269 L
.89415 .29317 L
.89469 .29371 L
.89526 .2943 L
.89588 .29496 L
.89652 .29566 L
.89716 .29646 L
.89781 .29739 L
.89844 .29843 L
.89906 .29957 L
.89965 .30081 L
.90019 .30203 L
.90073 .30335 L
.90126 .30468 L
.90178 .30603 L
.90228 .30729 L
.90275 .30857 L
.90316 .30963 L
.90351 .31056 L
.90378 .31131 L
.90397 .31186 L
.90409 .31221 L
.90415 .31237 L
.90419 .31242 L
.9042 .31249 L
.90422 .31266 L
.90422 .31296 L
.90421 .31343 L
.90419 .31408 L
.90418 .3149 L
.90418 .3158 L
.90419 .31668 L
.90423 .31751 L
.90432 .31816 L
.90444 .31872 L
Mistroke
.90458 .31905 L
.90471 .31913 L
.9048 .31899 L
.90483 .31829 L
.90473 .31702 L
.90443 .31529 L
.90388 .31298 L
.90308 .31014 L
.90199 .30695 L
.90058 .30309 L
.89897 .29935 L
.897 .29502 L
.89473 .29072 L
.89219 .28588 L
.88936 .28075 L
.88614 .27566 L
.88313 .27032 L
.87985 .265 L
.87653 .25953 L
.87313 .25429 L
.87003 .2492 L
.86684 .24395 L
.86388 .23922 L
.86097 .23473 L
.85806 .23015 L
.85522 .22568 L
.85229 .22098 L
.84941 .21692 L
.8464 .21251 L
.84338 .20809 L
.8403 .20364 L
.83712 .19887 L
.834 .19421 L
.83068 .18955 L
.82741 .18519 L
.82395 .18017 L
.8202 .17531 L
.81681 .1701 L
.81348 .16591 L
.81013 .16145 L
.8071 .15738 L
.80423 .15359 L
.80197 .15068 L
.79989 .14786 L
.79809 .1457 L
.79669 .14399 L
.79541 .14245 L
.79423 .14104 L
.79318 .13973 L
.79226 .13849 L
Mistroke
.79144 .13726 L
.79069 .13601 L
.78998 .13481 L
.78932 .13381 L
.78858 .13275 L
.78759 .13136 L
.78653 .13002 L
.78529 .12854 L
.78389 .12702 L
.78232 .12552 L
.78057 .1241 L
.77864 .12276 L
.77677 .12158 L
.77465 .1204 L
.77221 .11918 L
.76973 .11789 L
.76675 .11644 L
.76388 .11487 L
.7605 .11311 L
.75708 .11126 L
.7532 .10935 L
.74962 .10735 L
.74556 .10541 L
.74139 .10341 L
.73715 .10134 L
.73244 .09933 L
.72821 .09726 L
.72378 .09525 L
.71962 .09327 L
.71545 .09137 L
.7113 .08958 L
.70713 .08801 L
.70389 .08663 L
.70077 .08548 L
.69771 .0846 L
.69516 .08395 L
.69278 .08354 L
.69064 .08335 L
.68891 .08339 L
.68734 .0836 L
.68595 .0839 L
.68477 .08425 L
.6838 .08462 L
.68298 .08501 L
.68228 .08543 L
.68168 .08586 L
.68116 .08628 L
.68072 .08667 L
.68034 .08705 L
.68002 .08744 L
Mistroke
.67973 .08782 L
.67948 .08818 L
.67926 .08853 L
.67908 .08887 L
.67888 .08919 L
.67864 .08946 L
.6784 .08964 L
.67817 .08971 L
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
.67785 .08839 L
.67823 .0886 L
.67884 .08908 L
.67972 .08985 L
.68091 .09095 L
.68238 .09245 L
.68418 .09429 L
.68631 .09668 L
.68873 .0991 L
.69143 .10191 L
.69442 .10524 L
.69727 .10847 L
.70035 .112 L
.70349 .11573 L
.70629 .11896 L
.70904 .12217 L
.71157 .12529 L
.71394 .12846 L
.71595 .13086 L
.71792 .13312 L
Mistroke
.71964 .13539 L
.72134 .13736 L
.72306 .1394 L
.72474 .14149 L
.72644 .14346 L
.72825 .1456 L
.72996 .14741 L
.73175 .14937 L
.73351 .15132 L
.73524 .15333 L
.7369 .15531 L
.7384 .15692 L
.73966 .15846 L
.74074 .15974 L
.74158 .16081 L
.74218 .16163 L
.74254 .16214 L
.74269 .16235 L
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
.74189 .15984 L
.74202 .15997 L
.74221 .16016 L
Mistroke
.74246 .1604 L
.74276 .16066 L
.74312 .16092 L
.74353 .16115 L
.74396 .16132 L
.74445 .16143 L
.74494 .16148 L
.74542 .16149 L
.74587 .16145 L
.74627 .16142 L
.74662 .16142 L
.7469 .1615 L
.74714 .16171 L
.74736 .16209 L
.74759 .16269 L
.74786 .16354 L
.74822 .16468 L
.74863 .1662 L
.74911 .16818 L
.74962 .17041 L
.7501 .17301 L
.75057 .17589 L
.75099 .17909 L
.75137 .1822 L
.7517 .18539 L
.75199 .1885 L
.75223 .19138 L
.75243 .1941 L
.75254 .19652 L
.75259 .19835 L
.75259 .19987 L
.75252 .20099 L
.75233 .20164 L
.75199 .20187 L
.75145 .20171 L
.75066 .20128 L
.74952 .20067 L
.74807 .19997 L
.74615 .19924 L
.74402 .19853 L
.74141 .19791 L
.73814 .19743 L
.73517 .19711 L
.7313 .19693 L
.72796 .1969 L
.72395 .19701 L
.71928 .19726 L
.71549 .1976 L
.7108 .19801 L
.70677 .19845 L
Mistroke
.70226 .19891 L
.69767 .19938 L
.69336 .19988 L
.6886 .20039 L
.68389 .20088 L
.67984 .20134 L
.67525 .20172 L
.67098 .20203 L
.66671 .20224 L
.66269 .20236 L
.65902 .20236 L
.65529 .20226 L
.65216 .20207 L
.64896 .20182 L
.64627 .20149 L
.64388 .20112 L
.64187 .20072 L
.64008 .20026 L
.63857 .19974 L
.63733 .19905 L
.63632 .19823 L
.63542 .19717 L
.63459 .19584 L
.63379 .19415 L
.63299 .19204 L
.63219 .18985 L
.63141 .18715 L
.63054 .18383 L
.62969 .18107 L
.62883 .17734 L
.62797 .17324 L
.62712 .16978 L
.6263 .16559 L
.62561 .16134 L
.62516 .15698 L
.62499 .15302 L
.62514 .14899 L
.62562 .14491 L
.62642 .1411 L
.62755 .13727 L
.62889 .13341 L
.63045 .12964 L
.63221 .12607 L
.6341 .12253 L
.63612 .11944 L
.63811 .11668 L
.64006 .11416 L
.64191 .11202 L
.64356 .11014 L
.64495 .10874 L
Mistroke
.64614 .10763 L
.64706 .10682 L
.64773 .10629 L
.64817 .106 L
.64841 .10591 L
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
.64827 .10653 L
.6484 .10647 L
.64856 .10645 L
.64875 .10647 L
.64896 .10655 L
.64919 .1067 L
.64946 .10692 L
.64977 .10722 L
.65016 .10759 L
.65064 .10803 L
.65122 .10853 L
.6519 .10908 L
.65268 .10966 L
.65355 .11026 L
.65446 .11086 L
.65542 .11144 L
.65642 .11196 L
.65739 .11237 L
.65835 .11268 L
.65919 .11288 L
.6599 .11301 L
.66044 .1131 L
.66078 .11319 L
.66091 .11333 L
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
Mistroke
.65642 .11745 L
.65648 .11754 L
.65656 .1177 L
.65662 .11798 L
.65665 .11839 L
.65667 .11896 L
.65668 .11965 L
.6567 .12039 L
.65672 .12121 L
.65676 .12207 L
.65681 .12292 L
.65686 .12372 L
.65688 .12445 L
.65686 .12508 L
.6568 .12557 L
.65672 .12589 L
.65662 .12602 L
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
Mistroke
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
.65675 .12602 L
.65651 .12639 L
.6562 .12687 L
.65584 .12743 L
.65544 .12804 L
.65502 .12868 L
.6546 .12931 L
.65418 .12993 L
.65377 .13055 L
.65339 .13113 L
.65306 .13165 L
.6528 .13206 L
.65261 .13234 L
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
Mistroke
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
.65315 .13854 L
.65299 .13832 L
.65272 .13806 L
.65234 .1378 L
.65189 .1376 L
.65137 .13749 L
.65082 .13749 L
.65026 .13765 L
.6497 .13799 L
.64915 .13855 L
.64864 .1394 L
.64816 .1405 L
.64773 .1419 L
.64733 .14367 L
.64694 .14578 L
.64656 .14823 L
.64614 .15105 L
.64569 .15398 L
.64518 .15716 L
.64461 .16072 L
.64391 .16403 L
.64312 .16765 L
.6422 .1716 L
.64119 .17526 L
.64007 .17916 L
.63888 .18322 L
.63765 .18721 L
.63643 .19105 L
.63522 .19544 L
.63408 .19884 L
.63293 .20301 L
.63183 .20649 L
.63066 .21032 L
Mistroke
.62941 .21424 L
.62813 .21787 L
.62673 .22151 L
.62516 .22523 L
.6235 .22856 L
.62168 .23168 L
.61962 .23491 L
.61739 .23799 L
.615 .24065 L
.61214 .24335 L
.60901 .24593 L
.60523 .24832 L
.60176 .25054 L
.59717 .25259 L
.59314 .25432 L
.58849 .25591 L
.58427 .25727 L
.57942 .25843 L
.57444 .25934 L
.56893 .25996 L
.56415 .26028 L
.55889 .26027 L
.55346 .25994 L
.54873 .25935 L
.54378 .25853 L
.5391 .25752 L
.53415 .25631 L
.5303 .25501 L
.52603 .2536 L
.52219 .25207 L
.51802 .25043 L
.51452 .24877 L
.51069 .24701 L
.50709 .24518 L
.50327 .24328 L
.49974 .2415 L
.49582 .23964 L
.49225 .23762 L
.48847 .23544 L
.48475 .23313 L
.48072 .23058 L
.47688 .22794 L
.47342 .22518 L
.46954 .22208 L
.46598 .21907 L
.46235 .21585 L
.45875 .21266 L
.45538 .20924 L
.45204 .20565 L
.44896 .20235 L
Mistroke
.44597 .19893 L
.44322 .19561 L
.44041 .19224 L
.43808 .18926 L
.43581 .18623 L
.43369 .18322 L
.43173 .1804 L
.42977 .17735 L
.42781 .1742 L
.42604 .17104 L
.42417 .16774 L
.42241 .16417 L
.42061 .16053 L
.41892 .15671 L
.4173 .1526 L
.41581 .14858 L
.41453 .14415 L
.41354 .13987 L
.4129 .1359 L
.41261 .13158 L
.41269 .12723 L
.41314 .12305 L
.41394 .11859 L
.41499 .11442 L
.41627 .11014 L
.41766 .10585 L
.41911 .1016 L
.42053 .09803 L
.42192 .09425 L
.42311 .09091 L
.42414 .08783 L
.42503 .0852 L
.42576 .08317 L
.42634 .08156 L
.42675 .08041 L
.42699 .07972 L
.42708 .07944 L
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
.4263 .08073 L
.42662 .08035 L
.42704 .07984 L
.42757 .07923 L
.42818 .07852 L
.42885 .07777 L
Mistroke
.42956 .07698 L
.4303 .07622 L
.43104 .07551 L
.43176 .07489 L
.43243 .0744 L
.43304 .07403 L
.43359 .07378 L
.43407 .07361 L
.43451 .07351 L
.43491 .07349 L
.4353 .07351 L
.43569 .07356 L
.43608 .07362 L
.43647 .07367 L
.43685 .07371 L
.43725 .07375 L
.43764 .07377 L
.43801 .07379 L
.43831 .0738 L
.4385 .07383 L
.43853 .07392 L
.4384 .07404 L
.43812 .07419 L
.43772 .07432 L
.43723 .07441 L
.43667 .0744 L
.43605 .07426 L
.4354 .07395 L
.4347 .07342 L
.43392 .07265 L
.43306 .0716 L
.43215 .07023 L
.43121 .06861 L
.43028 .06665 L
.42938 .06443 L
.42854 .06198 L
.42778 .05939 L
.42707 .05676 L
.4264 .05422 L
.42578 .05183 L
.4252 .04964 L
.42472 .04774 L
.4244 .04606 L
.4243 .0447 L
.42444 .04359 L
.42479 .04271 L
.42532 .04205 L
.42599 .04159 L
.42672 .0413 L
.42748 .04114 L
Mistroke
.42823 .04106 L
.42894 .04101 L
.4296 .04095 L
.43019 .04087 L
.43068 .04078 L
.43106 .04068 L
.43133 .0406 L
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
.43307 .04064 L
.43335 .04048 L
.43382 .04025 L
.43448 .03998 L
.43534 .0397 L
.43637 .03943 L
.43754 .03921 L
Mistroke
.43885 .03905 L
.44024 .03894 L
.44171 .03892 L
.44321 .03899 L
.44467 .03912 L
.44602 .03931 L
.44724 .03955 L
.44832 .03984 L
.44927 .04015 L
.45016 .04047 L
.45102 .04078 L
.45191 .04105 L
.45286 .04128 L
.45388 .04146 L
.45496 .0416 L
.45608 .04169 L
.45722 .04172 L
.45835 .04171 L
.45947 .04171 L
.46055 .04173 L
.46156 .04175 L
.46246 .04178 L
.46324 .04178 L
.46389 .04175 L
.46439 .04168 L
.46475 .04157 L
.46498 .04146 L
.46509 .04137 L
.46512 .04134 L
.4651 .04143 L
.46505 .04163 L
.46498 .04196 L
.46486 .04242 L
.46469 .04297 L
.46448 .04359 L
.46425 .04426 L
.46407 .04499 L
.46395 .04574 L
.46385 .04646 L
.46374 .0471 L
.46359 .04762 L
.46339 .04798 L
.4631 .04813 L
.46273 .04809 L
.46225 .04786 L
.46166 .04752 L
.46099 .04711 L
.46029 .04665 L
.45951 .04617 L
.45835 .04563 L
Mistroke
.4567 .04502 L
.45449 .04433 L
.45164 .04356 L
.44811 .04269 L
.44385 .04176 L
.43894 .0408 L
.43404 .03986 L
.4288 .03894 L
.42284 .038 L
.41795 .03703 L
.41344 .03615 L
.40839 .03549 L
.40265 .03513 L
.39665 .03518 L
.39067 .03577 L
.38493 .03701 L
.37922 .03878 L
.37305 .04089 L
.36755 .04324 L
.36178 .04578 L
.35587 .04856 L
.34996 .05128 L
.34411 .05408 L
.33826 .05703 L
.33245 .06012 L
.32698 .06319 L
.32216 .06607 L
.31799 .06872 L
.31434 .07102 L
.31078 .07338 L
.30743 .07547 L
.30411 .07756 L
.30036 .0799 L
.29585 .08257 L
.29084 .08546 L
.28594 .08831 L
.28065 .09136 L
.27527 .09448 L
.26979 .09772 L
.26435 .1009 L
.25891 .10423 L
.25335 .10776 L
.2482 .11112 L
.24337 .11445 L
.23907 .11748 L
.23546 .1202 L
.23243 .1226 L
.23001 .12462 L
.22812 .12627 L
.22673 .12756 L
Mistroke
.22583 .1285 L
.22535 .12913 L
.2252 .12952 L
.22526 .12972 L
.22545 .12979 L
.22564 .12981 L
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
Mistroke
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
.22685 .13587 L
.22657 .13606 L
.22601 .1364 L
.22512 .13692 L
.22387 .13764 L
.22223 .13858 L
.22017 .13978 L
.21766 .14134 L
.21476 .1433 L
.21143 .14569 L
.20776 .1485 L
.20384 .15173 L
.19974 .15541 L
.1955 .15952 L
.19137 .16386 L
.18725 .1688 L
.18328 .17352 L
.1794 .17904 L
.17569 .18416 L
.17208 .19002 L
.16862 .19535 L
.16522 .20125 L
.16193 .20671 L
.15865 .2127 L
.15536 .21809 L
.15198 .224 L
.14861 .22949 L
.14512 .23553 L
.14158 .24104 L
.13787 .24721 L
.13409 .25297 L
.13027 .2593 L
.12638 .2652 L
.12267 .27145 L
.11878 .27764 L
.11528 .28391 L
.1118 .29009 L
.10852 .29607 L
.10561 .30191 L
Mistroke
.10274 .30735 L
.10054 .31248 L
.09851 .31725 L
.09674 .32163 L
.09527 .32558 L
.09407 .32947 L
.09309 .33317 L
.09227 .33665 L
.09155 .34037 L
.09091 .34439 L
.09034 .34823 L
.08975 .35266 L
.0891 .35774 L
.08842 .36232 L
.08772 .3678 L
.08706 .37299 L
.08643 .37881 L
.08586 .38386 L
.08536 .38892 L
.08493 .39315 L
.08457 .39715 L
.0843 .4003 L
.08408 .40287 L
.08391 .40475 L
.08379 .40611 L
.08376 .40698 L
.08382 .40749 L
.08397 .40777 L
.08425 .40789 L
.08467 .40798 L
.08523 .40818 L
.08594 .40853 L
.08678 .40902 L
.08777 .40967 L
.08887 .41044 L
.09002 .41129 L
.09118 .41219 L
.09235 .41314 L
.09346 .41411 L
.09447 .41517 L
.09536 .41629 L
.09608 .41751 L
.09665 .41888 L
.09708 .42046 L
.09738 .42222 L
.09757 .42426 L
.09768 .4265 L
.0977 .42895 L
.09762 .43165 L
.09744 .43452 L
Mistroke
.09712 .43771 L
.09662 .44116 L
.09589 .44496 L
.09491 .4488 L
.0937 .45294 L
.09216 .45691 L
.0903 .46114 L
.08845 .46515 L
.0863 .4692 L
.08416 .47324 L
.08196 .47715 L
.07955 .48127 L
.07759 .48487 L
.07569 .48851 L
.07387 .49211 L
.07232 .4957 L
.07098 .49913 L
.0699 .50264 L
.06907 .50611 L
.0685 .50979 L
.06812 .51369 L
.06794 .51766 L
.06794 .52185 L
.06808 .52619 L
.06836 .53076 L
.06877 .53483 L
.06936 .53883 L
.06991 .54256 L
.07058 .54588 L
.07123 .54894 L
.07194 .55177 L
.07255 .55373 L
.07309 .55548 L
.07355 .55681 L
.07393 .5577 L
.0742 .5582 L
.07438 .55838 L
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
Mistroke
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
.07398 .55638 L
.07393 .55686 L
.07392 .55776 L
.07397 .5592 L
.07409 .56129 L
.07427 .56419 L
.07455 .56731 L
.07491 .57126 L
.07537 .57647 L
.07588 .58107 L
.07654 .58759 L
.07727 .59304 L
.07811 .5996 L
.07906 .60644 L
.08005 .6132 L
.08111 .61957 L
.08212 .62642 L
.08317 .63318 L
.08415 .6395 L
.08515 .64597 L
.08608 .65203 L
Mistroke
.08705 .65792 L
.0879 .66382 L
.08874 .6695 L
.08957 .6738 L
.09031 .67799 L
.09101 .68135 L
.09169 .68501 L
.0923 .6876 L
.09288 .68977 L
.09343 .69129 L
.09393 .69214 L
.09439 .69251 L
.09479 .69253 L
.09515 .69232 L
.09544 .69193 L
.09566 .69153 L
.09579 .69121 L
.09585 .69097 L
.09586 .69085 L
.09582 .69091 L
.09576 .69116 L
.09573 .69161 L
.09575 .69225 L
.09586 .69307 L
.09608 .69404 L
.0964 .69514 L
.09685 .69638 L
.09741 .69772 L
.09802 .69923 L
.09876 .70094 L
.09962 .7028 L
.10054 .70481 L
.10165 .70691 L
.10276 .7091 L
.10397 .71139 L
.10525 .71369 L
.10637 .71567 L
.10747 .71777 L
.10846 .71967 L
.10938 .72148 L
.11012 .72308 L
.11079 .72439 L
.11122 .72536 L
.11151 .72606 L
.11166 .72653 L
.11167 .72679 L
.1115 .72686 L
.11119 .72679 L
.11079 .72668 L
.1104 .7266 L
Mistroke
.11009 .72657 L
.10987 .72659 L
.10975 .72668 L
.10975 .72684 L
.10989 .72708 L
.11015 .72731 L
.11051 .72755 L
.11095 .72772 L
.11144 .72781 L
.11194 .72784 L
.11239 .72784 L
.11282 .72784 L
.11319 .72784 L
.11344 .72789 L
.11352 .72801 L
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
Mistroke
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
Mistroke
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
Mistroke
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
Mistroke
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
Mistroke
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
Mistroke
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
Mistroke
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
.10805 .7255 L
.10777 .72574 L
.10738 .72611 L
.10694 .72661 L
.10651 .72724 L
.10617 .72798 L
.10574 .72864 L
.10538 .72942 L
.10505 .73018 L
.10469 .73085 L
.10437 .73147 L
.10408 .73197 L
.10381 .73232 L
.1036 .73252 L
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
Mistroke
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
.10543 .73301 L
.10527 .73344 L
.10506 .73406 L
.10481 .73486 L
.10454 .73582 L
.10425 .73691 L
.10394 .73803 L
.10362 .7392 L
.10329 .74041 L
.10299 .74161 L
.10272 .74272 L
.10252 .74364 L
.1024 .74438 L
.10237 .74494 L
.10244 .74535 L
.1026 .74563 L
.10284 .74579 L
.10316 .74589 L
.10356 .74601 L
.10405 .74623 L
.10465 .74657 L
Mistroke
.10538 .74704 L
.10624 .74764 L
.10719 .7484 L
.10822 .7493 L
.10932 .75031 L
.11038 .75137 L
.11142 .75244 L
.11232 .75338 L
.11315 .75422 L
.11381 .75485 L
.11436 .75534 L
.1148 .7557 L
.11512 .7559 L
.11532 .75601 L
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
Mistroke
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
.11503 .75556 L
.11528 .75611 L
.11577 .75703 L
.11655 .75833 L
.11762 .76011 L
.1191 .76215 L
.12092 .76468 L
.12337 .76775 L
.12595 .77102 L
.12931 .7742 L
.13301 .77804 L
.1369 .78178 L
.14116 .78643 L
.14575 .79057 L
.15027 .7951 L
.15487 .79971 L
.15947 .80419 L
.16398 .8087 L
.16831 .81339 L
.17274 .81765 L
.17675 .82193 L
.1807 .82589 L
.18462 .82986 L
.18827 .83371 L
.19179 .83736 L
.19519 .84085 L
.19824 .84386 L
.20111 .84665 L
.20377 .84906 L
.20595 .85097 L
.20788 .85259 L
.20949 .85388 L
.21076 .85478 L
.21166 .85534 L
.21222 .85558 L
.21248 .85562 L
.21254 .85555 L
.2125 .85544 L
Mistroke
.21241 .85535 L
.21234 .85531 L
.21234 .85536 L
.21246 .85552 L
.2127 .85583 L
.21305 .85626 L
.21353 .85684 L
.21411 .85752 L
.2148 .85826 L
.21557 .85899 L
.21639 .85972 L
.21729 .86045 L
.21831 .86117 L
.21951 .86194 L
.22089 .86288 L
.22255 .86407 L
.22444 .86548 L
.2266 .8671 L
.22903 .86903 L
.23176 .87136 L
.23479 .87377 L
.23816 .87665 L
.24175 .87968 L
.24592 .88304 L
.24975 .8863 L
.25405 .89002 L
.25866 .8932 L
.2634 .89649 L
.26822 .89967 L
.2733 .90284 L
.2787 .906 L
.28419 .90866 L
.28996 .91136 L
.29576 .91399 L
.30197 .91645 L
.30834 .91896 L
.31442 .92127 L
.32071 .92357 L
.32658 .92576 L
.33245 .9279 L
.33814 .92993 L
.34353 .93188 L
.34908 .93381 L
.35384 .93555 L
.35895 .93725 L
.36371 .93887 L
.36876 .94041 L
.3733 .94192 L
.37804 .94338 L
.383 .94485 L
Mistroke
.38783 .94636 L
.39314 .94796 L
.39826 .94958 L
.40365 .9513 L
.40883 .95312 L
.41423 .95491 L
.41999 .95678 L
.42483 .95848 L
.43002 .96017 L
.43503 .96173 L
.44003 .96311 L
.44511 .96428 L
.45001 .96526 L
.45504 .96601 L
.46025 .96649 L
.46542 .96676 L
.4708 .96681 L
.47637 .96666 L
.48219 .96633 L
.48774 .96587 L
.49358 .96535 L
.4992 .96477 L
.5049 .96415 L
.5104 .96349 L
.51587 .96279 L
.52192 .96202 L
.52701 .96121 L
.53274 .96033 L
.53837 .95938 L
.54465 .95837 L
.54992 .95735 L
.55592 .9563 L
.56221 .95521 L
.56793 .95414 L
.57424 .95298 L
.58069 .95175 L
.5874 .95049 L
.5936 .94922 L
.60012 .94799 L
.60672 .94681 L
.61294 .94568 L
.61914 .94463 L
.62533 .94363 L
.63127 .94264 L
.63736 .94167 L
.64301 .94062 L
.64885 .93952 L
.65433 .93837 L
.65973 .93715 L
.66496 .93582 L
Mistroke
.67018 .93434 L
.67553 .93261 L
.68036 .9305 L
.68548 .92816 L
.69071 .92545 L
.69625 .92216 L
.7009 .91934 L
.70593 .91582 L
.71085 .91259 L
.71579 .90881 L
.72025 .90602 L
.72441 .90292 L
.72814 .90006 L
.73129 .89793 L
.73397 .89586 L
.73594 .8943 L
.73735 .89307 L
.7382 .89224 L
.73856 .89181 L
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
Mistroke
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
.73413 .89364 L
.73439 .89364 L
.7348 .89353 L
.73535 .89332 L
.73604 .89302 L
.73684 .89266 L
.7377 .89223 L
.73855 .89175 L
.7394 .8912 L
.74023 .89058 L
.74104 .88988 L
.74179 .8891 L
.74244 .88826 L
.74297 .88738 L
.74336 .88649 L
.74363 .88563 L
.74378 .88482 L
.74385 .88408 L
.74386 .88339 L
.74383 .88274 L
.74377 .88214 L
.74369 .8816 L
.74362 .88112 L
.74358 .88072 L
.74359 .88044 L
.74368 .88029 L
.74382 .88028 L
.74399 .88037 L
.74414 .88055 L
.74424 .88076 L
.74429 .88099 L
.74424 .88119 L
.74409 .88136 L
.74386 .88149 L
.74357 .8816 L
.74327 .88168 L
.74294 .88174 L
.74269 .88182 L
.74249 .88194 L
.74235 .88206 L
.74229 .88216 L
.74232 .88219 L
.74251 .88213 L
.74288 .88196 L
Mistroke
.74349 .88166 L
.74437 .88117 L
.74556 .88044 L
.74708 .87942 L
.74896 .87798 L
.75117 .8761 L
.75394 .87393 L
.75687 .87155 L
.76054 .86871 L
.76423 .86557 L
.76849 .86225 L
.77314 .85865 L
.77813 .85496 L
.78303 .85135 L
.78804 .84783 L
.79315 .84409 L
.79746 .84119 L
.80159 .83827 L
.80533 .8356 L
.80826 .83324 L
.81082 .83145 L
.8127 .82991 L
.81402 .82891 L
.81491 .82821 L
.81538 .82777 L
.81544 .82761 L
.81521 .82769 L
.81481 .82794 L
.81432 .82829 L
.81382 .82872 L
.81336 .82916 L
.81299 .82959 L
.81275 .82998 L
.81264 .83023 L
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
Mistroke
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
Mistroke
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
Mistroke
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
.81302 .83034 L
.81254 .83043 L
.8119 .83049 L
.81114 .83054 L
.81032 .8306 L
.80948 .8307 L
.80866 .83084 L
.80784 .83104 L
.80701 .8313 L
.8062 .83163 L
.80543 .83201 L
.80475 .83243 L
.80418 .83287 L
.80375 .83333 L
.80345 .83377 L
.80327 .83421 L
.80321 .83467 L
.80323 .83512 L
.80328 .83556 L
.80336 .83592 L
.80348 .83614 L
.80365 .83618 L
.80388 .83601 L
.80414 .83566 L
.80447 .83519 L
.80485 .83466 L
.80525 .83414 L
.80564 .83367 L
.80598 .83329 L
.80621 .83303 L
.80626 .83291 L
.80609 .83299 L
.80568 .83331 L
.80496 .83392 L
.80389 .83486 L
.80246 .83615 L
.80064 .83779 L
.79855 .83982 L
.79601 .84219 L
Mistroke
.79301 .84491 L
.78964 .84792 L
.78576 .85125 L
.78159 .85476 L
.77711 .85848 L
.77236 .86238 L
.76741 .86625 L
.76239 .87045 L
.75739 .8745 L
.75225 .87883 L
.74653 .88321 L
.74167 .88729 L
.73622 .89162 L
.7309 .89561 L
.72536 .89973 L
.7195 .90383 L
.71494 .90716 L
.70987 .91072 L
.70471 .91401 L
.69991 .91724 L
.69491 .92046 L
.69068 .92304 L
.68654 .92573 L
.68208 .9282 L
.67801 .93022 L
.674 .93201 L
.67007 .93354 L
.66611 .93481 L
.66221 .93587 L
.65807 .93678 L
.65413 .93756 L
.65 .93821 L
.64589 .93868 L
.64196 .93903 L
.63785 .93925 L
.63419 .93935 L
.6304 .93938 L
.62686 .93934 L
.62324 .93921 L
.62007 .93899 L
.61691 .93867 L
.61376 .93825 L
.6109 .93775 L
.60796 .93715 L
.60483 .93649 L
.60171 .93577 L
.59851 .93501 L
.59524 .93418 L
.59173 .93331 L
.58838 .93242 L
Mistroke
.58493 .93153 L
.58136 .93061 L
.5782 .92967 L
.5751 .92868 L
.57194 .92762 L
.56925 .92653 L
.56669 .92547 L
.56435 .92439 L
.56233 .92334 L
.56073 .9223 L
.55964 .92129 L
.55894 .92035 L
.55855 .91951 L
.55838 .9188 L
.55836 .91826 L
.55839 .91793 L
.55838 .91783 L
.55823 .91796 L
.5578 .91834 L
.55702 .91905 L
.55589 .92013 L
.55433 .92159 L
.55242 .92328 L
.54995 .92529 L
.54693 .92752 L
.54347 .92983 L
.5395 .93213 L
.53523 .93458 L
.53063 .93686 L
.5253 .939 L
.52102 .94121 L
.51576 .94276 L
.51101 .94386 L
.50579 .94497 L
.50071 .94566 L
.49549 .94606 L
.49007 .94637 L
.48447 .94635 L
.47908 .94626 L
.47316 .94618 L
.46739 .94613 L
.46178 .94617 L
.45541 .94632 L
.45006 .94657 L
.44417 .94693 L
.4387 .94733 L
.43314 .94775 L
.42772 .94818 L
.42249 .94864 L
.41785 .94897 L
Mistroke
.41333 .94911 L
.40916 .94896 L
.40512 .94844 L
.40138 .94752 L
.3975 .94628 L
.3938 .94472 L
.38984 .94292 L
.38594 .94101 L
.38197 .93895 L
.37776 .93682 L
.37326 .93473 L
.36884 .9327 L
.36421 .93079 L
.35903 .92906 L
.3545 .92763 L
.34939 .92641 L
.34419 .92533 L
.33925 .92436 L
.33408 .92346 L
.32903 .92253 L
.32424 .92146 L
.31903 .92019 L
.31439 .91869 L
.3096 .91696 L
.3046 .91494 L
.30017 .91263 L
.29553 .91017 L
.29126 .90766 L
.28684 .90497 L
.28294 .90221 L
.27895 .89944 L
.27507 .89671 L
.2714 .89412 L
.26762 .8916 L
.26412 .88927 L
.26067 .88715 L
.25718 .88512 L
.25407 .88319 L
.25098 .88149 L
.24839 .87998 L
.24607 .87866 L
.24404 .87757 L
.24238 .8767 L
.24106 .87602 L
.24007 .87552 L
.23941 .87517 L
.23901 .87493 L
.23882 .87478 L
.23876 .87471 L
.2388 .87473 L
Mistroke
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
.24006 .8739 L
.24006 .87414 L
.24004 .87443 L
.24002 .87474 L
.23992 .87497 L
.23965 .87506 L
.2391 .87493 L
.23823 .87459 L
.23699 .87395 L
.23527 .87298 L
Mistroke
.23323 .87164 L
.23067 .86989 L
.22763 .86774 L
.22465 .86548 L
.22154 .86292 L
.21771 .86007 L
.2145 .85722 L
.21104 .85419 L
.20764 .85125 L
.20442 .84843 L
.20154 .8458 L
.19905 .84334 L
.19708 .84123 L
.19549 .83938 L
.1943 .83789 L
.19345 .83668 L
.19289 .83574 L
.1925 .83502 L
.19225 .83449 L
.19213 .83408 L
.1921 .83373 L
.19211 .83336 L
.19211 .83291 L
.19205 .83228 L
.1919 .83144 L
.19166 .83033 L
.1913 .82898 L
.19075 .82725 L
.18995 .82508 L
.18884 .82262 L
.18743 .81962 L
.18569 .81644 L
.18366 .81288 L
.18136 .80915 L
.17872 .80525 L
.17581 .80121 L
.1732 .79733 L
.17024 .79337 L
.16692 .78932 L
.16391 .78564 L
.16068 .78189 L
.1574 .77826 L
.1543 .77486 L
.15116 .7716 L
.14828 .76862 L
.1455 .76584 L
.14281 .76335 L
.14049 .76111 L
.13816 .75912 L
.13615 .75738 L
Mistroke
.13428 .7558 L
.13259 .75436 L
.13118 .75304 L
.13006 .75169 L
.12926 .75024 L
.12868 .74887 L
.12834 .7475 L
.12818 .74611 L
.12816 .74476 L
.12825 .74364 L
.12838 .74249 L
.12854 .74147 L
.12874 .74047 L
.12896 .73946 L
.12918 .73862 L
.12935 .73787 L
.12944 .73707 L
.12945 .73626 L
.12934 .73541 L
.12905 .73444 L
.12853 .73328 L
.12774 .73164 L
.12665 .72953 L
.12531 .72717 L
.12364 .72438 L
.12165 .72122 L
.11932 .71766 L
.11686 .71401 L
.1142 .71017 L
.11138 .70639 L
.10849 .70267 L
.10599 .69891 L
.10341 .69522 L
.10102 .69194 L
.09882 .68857 L
.09686 .68527 L
.09517 .68195 L
.09375 .67876 L
.09258 .67538 L
.09169 .67192 L
.091 .66808 L
.0905 .66432 L
.09015 .66034 L
.08992 .65602 L
.08977 .65135 L
.08967 .64651 L
.08961 .6421 L
.08961 .63725 L
.08963 .63254 L
.08969 .62794 L
Mistroke
.08981 .62372 L
.09 .61949 L
.09028 .61571 L
.09068 .61225 L
.09123 .60889 L
.09196 .60597 L
.09289 .60309 L
.09398 .60056 L
.09529 .5982 L
.09675 .59601 L
.09833 .59408 L
.09992 .59233 L
.10147 .59077 L
.10297 .58946 L
.10437 .58835 L
.10562 .58739 L
.10678 .58658 L
.10785 .5859 L
.10883 .58533 L
.10979 .58485 L
.11078 .58442 L
.11183 .58403 L
.11295 .58368 L
.11422 .58332 L
.11559 .58293 L
.11712 .58248 L
.1188 .58192 L
.12058 .58124 L
.12244 .58047 L
.12434 .57967 L
.12627 .57887 L
.12816 .57806 L
.13007 .57726 L
.13202 .57646 L
.13403 .5756 L
.13621 .57465 L
.13836 .57357 L
.14067 .57238 L
.14306 .57104 L
.14545 .56959 L
.1478 .56812 L
.15002 .5668 L
.152 .56546 L
.15384 .56419 L
.15542 .56307 L
.1567 .56203 L
.15776 .56113 L
.15861 .56047 L
.15931 .5601 L
.15995 .56006 L
Mistroke
.1606 .56037 L
.16139 .56103 L
.16249 .56204 L
.16398 .56337 L
.16564 .56491 L
.1677 .56669 L
.17022 .56874 L
.17286 .57076 L
.17592 .57317 L
.17886 .57526 L
.18169 .57743 L
.18448 .57964 L
.18709 .58161 L
.18958 .58335 L
.19162 .58493 L
.19347 .58624 L
.19514 .58724 L
.19661 .58801 L
.19795 .58857 L
.19915 .58892 L
.20029 .58911 L
.20138 .58917 L
.2024 .58912 L
.20338 .58899 L
.20433 .58883 L
.20522 .58865 L
.20606 .58846 L
.20677 .58828 L
.20734 .58814 L
.20777 .58804 L
.20808 .588 L
.20833 .58801 L
.20853 .58809 L
.20871 .58823 L
.20896 .58847 L
.20932 .58884 L
.20985 .58937 L
.21059 .59009 L
.21157 .59101 L
.21287 .59209 L
.21449 .59338 L
.21651 .59483 L
.21895 .59641 L
.22188 .59814 L
.22504 .59977 L
.22873 .60162 L
.23262 .60349 L
.23709 .6053 L
.24151 .60721 L
.24629 .60917 L
Mistroke
.25126 .6111 L
.25648 .61314 L
.26153 .61507 L
.26704 .61709 L
.27218 .61918 L
.27757 .62126 L
.28284 .62358 L
.28813 .62577 L
.29367 .62822 L
.2987 .63075 L
.30407 .63327 L
.30926 .63595 L
.31449 .63855 L
.31985 .64126 L
.32461 .64396 L
.32972 .64664 L
.33448 .64925 L
.33921 .65181 L
.34378 .65439 L
.34818 .65676 L
.35241 .65921 L
.35674 .66148 L
.36072 .66385 L
.36472 .66605 L
.36873 .6683 L
.37274 .6706 L
.37691 .67295 L
.38079 .67498 L
.38486 .67714 L
.38913 .67973 L
.39321 .682 L
.39748 .68452 L
.40188 .68722 L
.40658 .69002 L
.41073 .69309 L
.4154 .69607 L
.41997 .69942 L
.42429 .70283 L
.42885 .70648 L
.43326 .71041 L
.43771 .71478 L
.44186 .71899 L
.44599 .72355 L
.45 .72823 L
.45403 .73327 L
.45764 .7383 L
.46131 .74323 L
.4648 .74859 L
.46824 .75347 L
.47141 .75861 L
Mistroke
.4745 .76343 L
.47744 .76861 L
.4803 .77285 L
.48292 .77724 L
.48543 .78128 L
.48775 .7848 L
.48988 .78805 L
.49177 .79069 L
.49336 .79292 L
.49462 .7946 L
.49551 .79576 L
.4961 .7965 L
.49643 .7969 L
.4966 .79705 L
.49667 .79705 L
.49674 .79699 L
.49692 .79695 L
.49726 .79698 L
.49782 .79708 L
.4987 .7973 L
.49994 .79767 L
.50167 .79829 L
.50379 .79916 L
.50644 .8002 L
.50949 .80144 L
.5129 .80285 L
.51666 .80424 L
.52069 .8057 L
.52494 .80723 L
.52909 .80872 L
.53342 .81018 L
.5378 .81177 L
.54158 .81324 L
.54547 .81475 L
.54915 .81625 L
.55279 .81767 L
.55606 .81903 L
.55945 .82016 L
.5626 .82126 L
.56572 .82217 L
.56898 .82297 L
.57233 .82372 L
.57589 .82443 L
.57982 .82512 L
.5833 .82577 L
.5873 .82639 L
.59147 .82698 L
.59565 .82753 L
.59997 .82811 L
.60431 .82873 L
Mistroke
.60854 .8294 L
.61242 .83009 L
.61604 .83076 L
.61946 .83138 L
.62229 .83188 L
.62504 .83223 L
.62745 .83238 L
.62962 .83234 L
.63172 .8321 L
.6337 .83166 L
.63576 .83102 L
.6378 .83015 L
.63965 .82906 L
.64181 .82771 L
.64438 .82615 L
.64699 .8244 L
.65015 .8223 L
.65356 .8202 L
.65751 .81785 L
.66115 .81546 L
.66521 .81283 L
.66944 .81017 L
.6733 .80771 L
.6774 .805 L
.68151 .80228 L
.68573 .79944 L
.68975 .79657 L
.69382 .7936 L
.6979 .79051 L
.70163 .78724 L
.70536 .78412 L
.70885 .78076 L
.71224 .77771 L
.71548 .7743 L
.71856 .77117 L
.72162 .76782 L
.72462 .76442 L
.72745 .76147 L
.7304 .75822 L
.73338 .75526 L
.73642 .75218 L
.73952 .74937 L
.74261 .74688 L
.74581 .74445 L
.7492 .74223 L
.75267 .74015 L
.75632 .73838 L
.76011 .73673 L
.76394 .73532 L
.76801 .73411 L
Mistroke
.77212 .73318 L
.77654 .73252 L
.78047 .73215 L
.78467 .73201 L
.78896 .73209 L
.79316 .73234 L
.79741 .73273 L
.80161 .73324 L
.80584 .73386 L
.8097 .73459 L
.81348 .7354 L
.81694 .73628 L
.82014 .73721 L
.82326 .73808 L
.82617 .7388 L
.82879 .73934 L
.83125 .73964 L
.8337 .7397 L
.83588 .73945 L
.83806 .73888 L
.84025 .738 L
.84246 .73682 L
.84472 .73535 L
.84715 .73366 L
.84944 .73176 L
.85195 .72958 L
.85459 .72723 L
.85747 .72468 L
.86011 .72209 L
.86295 .7194 L
.86589 .71667 L
.86848 .71396 L
.8712 .71121 L
.8739 .7085 L
.87673 .70571 L
.8792 .70281 L
.88182 .69969 L
.88441 .69634 L
.88695 .69285 L
.88948 .68913 L
.89196 .68526 L
.89432 .68119 L
.89666 .67687 L
.89883 .67254 L
.90088 .66813 L
.90271 .66369 L
.90433 .65927 L
.90579 .65455 L
.90705 .65022 L
.90809 .64595 L
Mistroke
.90899 .64177 L
.9098 .63772 L
.91054 .63371 L
.91127 .62967 L
.91205 .62553 L
.91296 .62119 L
.91403 .61638 L
.91532 .6116 L
.91678 .6062 L
.91841 .60069 L
.92023 .59441 L
.92202 .58868 L
.92385 .58225 L
.92557 .57528 L
.92714 .56903 L
.92845 .56214 L
.92953 .55515 L
.93034 .54762 L
.93088 .54105 L
.93116 .53382 L
.93119 .52656 L
.93098 .51961 L
.93056 .51231 L
.92996 .50483 L
.92921 .49747 L
.92839 .48992 L
.92752 .48245 L
.92664 .47559 L
.9258 .46888 L
.92503 .46244 L
.92437 .45669 L
.92377 .45152 L
.92325 .44732 L
.9228 .44344 L
.9224 .44041 L
.92207 .43796 L
.92179 .43597 L
.92159 .43436 L
.92144 .43298 L
.92135 .43158 L
.92128 .42989 L
.92124 .42781 L
.92118 .42534 L
.92108 .42216 L
.9209 .41846 L
.92061 .4142 L
.9202 .40912 L
.91964 .40353 L
.91895 .39708 L
.91812 .39089 L
Mistroke
.91719 .38409 L
.91616 .37651 L
.9151 .37013 L
.91402 .36326 L
.91295 .35631 L
.91195 .35053 L
.91102 .34481 L
.91018 .3394 L
.90947 .33504 L
.90888 .33107 L
.90843 .32783 L
.90811 .32529 L
.90793 .32348 L
.90786 .32231 L
.90787 .32172 L
.90793 .32161 L
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
.90869 .32632 L
.90847 .32593 L
.90807 .32516 L
.90745 .32394 L
.90661 .32223 L
.90554 .32003 L
.9043 .31736 L
.90286 .3143 L
.90117 .31067 L
.89927 .30657 L
.89707 .30232 L
.89469 .2973 L
.89213 .29208 L
.88927 .28621 L
.88626 .28037 L
.88296 .27415 L
.87971 .2678 L
.87636 .26154 L
.87284 .25509 L
.86947 .24927 L
.86608 .24352 L
.86275 .23799 L
.85968 .23335 L
.85704 .22909 L
Mistroke
.85455 .22521 L
.85234 .22178 L
.8505 .21907 L
.84887 .21681 L
.8475 .21493 L
.84618 .21323 L
.84479 .21154 L
.84327 .2098 L
.84158 .20782 L
.83989 .20556 L
.83775 .20281 L
.83544 .19963 L
.83289 .19621 L
.83014 .19232 L
.82732 .18823 L
.82412 .18368 L
.82119 .17933 L
.81826 .17515 L
.81526 .17054 L
.81231 .16603 L
.80939 .16143 L
.8065 .15729 L
.80361 .15291 L
.80105 .14916 L
.79845 .14551 L
.79595 .14208 L
.79356 .13885 L
.79122 .13579 L
.7891 .1332 L
.78707 .13079 L
.7852 .12861 L
.78348 .12676 L
.78186 .12508 L
.78034 .1236 L
.77888 .12234 L
.77731 .1212 L
.77553 .12011 L
.77344 .11902 L
.77106 .1179 L
.76841 .11664 L
.76531 .11519 L
.76186 .11359 L
.75827 .11181 L
.75435 .10993 L
.75038 .1079 L
.74624 .10586 L
.7418 .10373 L
.73769 .10155 L
.73332 .0994 L
.72875 .09721 L
Mistroke
.72448 .09517 L
.72003 .09314 L
.71535 .09114 L
.71092 .08918 L
.70637 .08727 L
.70176 .08537 L
.69704 .08356 L
.69237 .08175 L
.68782 .07998 L
.68336 .07822 L
.67891 .07654 L
.67491 .07487 L
.67095 .07326 L
.66697 .07171 L
.66361 .07028 L
.66022 .06889 L
.65676 .06755 L
.6534 .06627 L
.64992 .06501 L
.64629 .06374 L
.64219 .06242 L
.63808 .06106 L
.63374 .05962 L
.62877 .05803 L
.62419 .05633 L
.61883 .05449 L
.61397 .05258 L
.60883 .05058 L
.60369 .04862 L
.59861 .04666 L
.59387 .04477 L
.58905 .043 L
.58425 .0414 L
.57963 .03997 L
.575 .03872 L
.57041 .03769 L
.56556 .03684 L
.56088 .03617 L
.55559 .03566 L
.55048 .03529 L
.54565 .03504 L
.54007 .03487 L
.53482 .03475 L
.52884 .03463 L
.52369 .03449 L
.51782 .03432 L
.5125 .03413 L
.50653 .03395 L
.50133 .0338 L
.4955 .03373 L
Mistroke
.49023 .03373 L
.48474 .03383 L
.47952 .03399 L
.47417 .03421 L
.46879 .03448 L
.46361 .03477 L
.45845 .03506 L
.45283 .03536 L
.44796 .03563 L
.44241 .03585 L
.43738 .03599 L
.43209 .03604 L
.42656 .03601 L
.42146 .03592 L
.41616 .03579 L
.41074 .03566 L
.40585 .03559 L
.40049 .03561 L
.39595 .03575 L
.39101 .03603 L
.38688 .03642 L
.38271 .03689 L
.37911 .0374 L
.37573 .03794 L
.37294 .0385 L
.37049 .03905 L
.36847 .03957 L
.3669 .04005 L
.3657 .04047 L
.36486 .04081 L
.36437 .04104 L
.36416 .04116 L
.36417 .0412 L
.36436 .04117 L
.36467 .04113 L
.36502 .0411 L
.36538 .04114 L
.36567 .04125 L
.36596 .04144 L
.36622 .04167 L
.36647 .04193 L
.36672 .04221 L
.36697 .04252 L
.36721 .04284 L
.36741 .04317 L
.36761 .04343 L
.36783 .0436 L
.36807 .04367 L
.36832 .04365 L
.36855 .04355 L
Mistroke
.36871 .04337 L
.36873 .04316 L
.3685 .04297 L
.36796 .04286 L
.36708 .04288 L
.3658 .04307 L
.36409 .04351 L
.36195 .04422 L
.35968 .04514 L
.35688 .04645 L
.35352 .04795 L
.35018 .04974 L
.34629 .05185 L
.34206 .0541 L
.33798 .05657 L
.33338 .05915 L
.32895 .06178 L
.32455 .06445 L
.31996 .06708 L
.31561 .06974 L
.31113 .07243 L
.30661 .07521 L
.30204 .07797 L
.2976 .08074 L
.29313 .08347 L
.28891 .08621 L
.28486 .08876 L
.28107 .09125 L
.2776 .09357 L
.27447 .09571 L
.27175 .09759 L
.26938 .0993 L
.26752 .10065 L
.26599 .10178 L
.26484 .10265 L
.26406 .10326 L
.26361 .10363 L
.26343 .10379 L
.26345 .10379 L
.2636 .10369 L
.26382 .10356 L
.26404 .1034 L
.26423 .10327 L
.26435 .10317 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
Mistroke
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.2644 .10313 L
.26446 .10311 L
.26458 .10306 L
.26477 .10296 L
.26499 .10283 L
.26522 .10267 L
.26541 .10251 L
.26549 .10241 L
.26538 .1024 L
.265 .10252 L
.26427 .10283 L
.26307 .10343 L
.26136 .10434 L
.25911 .10557 L
.25656 .10709 L
.25335 .10895 L
.24953 .1112 L
.24543 .11372 L
.24085 .11658 L
.23577 .11961 L
.23105 .12295 L
.22614 .12626 L
.22098 .12991 L
.21674 .13312 L
.21232 .13661 L
.2082 .14015 L
.20431 .14383 L
.20087 .14737 L
.19751 .15107 L
.1943 .15511 L
.19138 .15904 L
.18851 .16293 L
.18561 .16758 L
.1829 .17202 L
.18013 .17672 L
.1773 .18134 L
.17435 .18661 L
.17119 .1921 L
.1683 .19719 L
.16496 .20315 L
.1619 .20816 L
.15861 .21405 L
.15555 .21926 L
Mistroke
.15234 .22515 L
.14911 .23024 L
.14588 .2356 L
.14279 .24104 L
.13961 .2459 L
.13637 .25122 L
.1335 .25558 L
.13043 .26021 L
.1277 .2646 L
.12504 .26858 L
.12234 .27266 L
.12009 .27623 L
.11788 .27967 L
.11582 .28297 L
.11397 .28583 L
.11217 .2887 L
.1105 .29137 L
.1089 .29408 L
.10743 .29672 L
.10605 .2994 L
.10468 .30217 L
.1033 .30508 L
.1019 .3083 L
.10059 .3114 L
.09923 .31485 L
.09782 .31844 L
.09645 .32226 L
.09517 .32588 L
.09399 .32968 L
.09299 .33303 L
.09212 .33645 L
.09141 .33923 L
.09084 .3418 L
.09042 .34409 L
.09014 .34585 L
.08996 .34722 L
.08985 .34825 L
.08982 .34897 L
.08985 .34942 L
.08992 .34962 L
.09 .34966 L
.09008 .34958 L
.09013 .34947 L
.09015 .34936 L
.09016 .34926 L
.09016 .34917 L
.09016 .3491 L
.09016 .34906 L
.09016 .34903 L
.09016 .34903 L
Mistroke
.09016 .34902 L
.09016 .34898 L
.09016 .3489 L
.09018 .34878 L
.09022 .34857 L
.09028 .34823 L
.09035 .34786 L
.09041 .34765 L
.09043 .34768 L
.09039 .34804 L
.09027 .34886 L
.09005 .35028 L
.08973 .35255 L
.08932 .35583 L
.08883 .35931 L
.08829 .364 L
.08773 .36867 L
.08713 .37356 L
.08653 .37866 L
.08596 .38364 L
.08542 .38909 L
.08495 .39451 L
.08456 .39878 L
.08427 .40275 L
.08408 .40595 L
.08399 .40831 L
.08398 .41003 L
.08402 .41113 L
.08408 .41164 L
.08414 .41164 L
.08418 .41136 L
.08421 .41093 L
.08422 .41048 L
.08423 .41004 L
.08423 .40969 L
.08423 .4095 L
.08423 .40944 L
.08423 .40955 L
.08423 .40974 L
.08422 .41001 L
.08422 .4103 L
.08421 .41061 L
.08421 .4109 L
.0842 .41115 L
.0842 .41134 L
.08419 .41149 L
.08419 .41162 L
.08419 .4117 L
.08419 .41171 L
.08419 .41166 L
Mistroke
.08419 .41157 L
.0842 .41145 L
.0842 .41127 L
.0842 .41103 L
.08421 .41074 L
.08421 .4104 L
.08422 .41002 L
.08423 .4096 L
.08424 .40916 L
.08424 .40871 L
.08425 .40831 L
.08426 .40797 L
.08426 .40777 L
.08426 .4077 L
.08426 .40777 L
.08426 .40795 L
.08425 .40824 L
.08425 .40859 L
.08424 .40898 L
.08423 .40936 L
.08423 .40973 L
.08422 .41007 L
.08422 .41039 L
.08421 .4107 L
.08421 .411 L
.0842 .4114 L
.0842 .41159 L
.08419 .41169 L
.08419 .41167 L
.0842 .4115 L
.0842 .41123 L
.08421 .41087 L
.08422 .41042 L
.08423 .40988 L
.08424 .40929 L
.08424 .40874 L
.08422 .40829 L
.08419 .4079 L
.08415 .40757 L
.08413 .4074 L
.08412 .40736 L
.08413 .40746 L
.08416 .4077 L
.08421 .40808 L
.0843 .40856 L
.08443 .40909 L
.08464 .40962 L
.08496 .41011 L
.08545 .41054 L
.08605 .4109 L
Mistroke
.08679 .41119 L
.08768 .41142 L
.08872 .41169 L
.08985 .41207 L
.09081 .41262 L
.09182 .41335 L
.09293 .4143 L
.09384 .41551 L
.09483 .41696 L
.09559 .41868 L
.09628 .42072 L
.09684 .42295 L
.09723 .4255 L
.09742 .42835 L
.09741 .43145 L
.0972 .43474 L
.09681 .43829 L
.09626 .4419 L
.09557 .44587 L
.09479 .44925 L
.09402 .45304 L
.09316 .4561 L
.09226 .45923 L
.09145 .462 L
.09056 .4645 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0029Ool=002:Ool007eoo``0
00eoo``007ioo`00M7oo00<007ooOol01P000Woo00<007ooOol017oo0`0027oo0P003goo1P00N7oo
001]Ool20003OolY0004Ool01000Oomoogoo100000=oo`0000000`00Lgoo001ZOol[00000goo0000
000@0005Ool4001_Ool006Qoob0000Uoo`<00006Ool00000001oo`0027oo2@001Woo1@00JWoo001V
Ool;0002Ool40002Ool600000goo0000000700000goo0000000500000goo00000004Ool5000:Ool7
0008Ool3001WOol006=oo`P00003Ool00000009oo`<00004Ool007oo0002Ool300000goo00000007
000017oo000000003Goo2P002Woo1P0027oo0`00I7oo001QOol<0006Ool8000<Ool00`00Oomoo`0<
Ool20008Ool60008Ool50009Ool2001ROol005ioo`L000Eoo`03001oogoo00eoo`03001oogoo00]o
o`03001oogoo01Moo`80009ooa4000Moo`<005moo`00Fgoo0`0000=oo`00000010005Goo00<007oo
Ool02goo00<007ooOol067oo10000Woo400027oo0`00G7oo001IOol20002Ool4000IOol00`00Oomo
o`0;Ool00`00Oomoo`0WOol;0007Ool2001JOol005Ioo`<0009oo`D001]oo`03001oogoo00]oo`03
001oogoo02Uoo`T000Qoo`<005Moo`00EGoo00<007ooOol00Woo1@0077oo00<007ooOol02goo00<0
07ooOol0:goo2@002Goo00<007ooOol0E7oo001COol20003Ool5000OOol2000<Ool00`00Oomoo`0]
Ool80008Ool2001DOol0055oo`8000Aoo`D001moo`<000aoo`03001oogoo039oo`H000Moo`80059o
o`00Cgoo0P0017oo1`007Woo0P003goo00<007ooOol0<Woo1`001goo0P00D7oo001>Ool00`00Oomo
o`02Ool7000POol00`00Oomoo`0>Ool00`00Oomoo`0dOol200000goo000000030006Ool00`00Oomo
o`1=Ool004aoo`8000=oo`L0025oo`03001oogoo00moo`8003Eoo`<0009oo`D000Eoo`8004eoo`00
BWoo0P0017oo1`008Woo00<007ooOol047oo00<007ooOol0<goo0P001Woo1@0017oo0P00Bgoo0018
Ool20005Ool500000goo0000000ROol00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`06Ool4
0005Ool20019Ool004Ioo`8000Eoo`H00003Ool0000002=oo`03001oogoo015oo`03001oogoo03Ao
o`03001oogoo00Moo`D000Aoo`8004Moo`00AGoo00<007ooOol00goo1`0000=oo`0000008goo00<0
07ooOol04Goo0P00=goo00<007ooOol01goo1P0017oo00<007ooOol0A7oo0013Ool20004Ool;000T
Ool00`00Oomoo`0AOol00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomoo`08Ool70002Ool20014
Ool0049oo`03001oogoo00=oo`H00003Ool0000002Ioo`03001oogoo019oo`03001oogoo02Yoo`80
00aoo`03001oogoo00Uoo`L0009oo`03001oogoo045oo`00@7oo0P0017oo1`0000=oo`0000009goo
00<007ooOol04Goo00<007ooOol0:Woo1@002goo00<007ooOol02Goo1`000Woo0P00@Goo000oOol0
0`00Oomoo`03Ool:000XOol00`00Oomoo`0AOol00`00Oomoo`0YOol20003Ool2000;Ool00`00Oomo
o`09Ool00`00Ool000050002Ool00`00Oomoo`0nOol003ioo`03001oogoo009oo`D002moo`03001o
ogoo011oo`8002]oo`03001oogoo009oo`8000]oo`03001oogoo00Uoo`X00003Ool0000003ioo`00
?Goo00<007ooOol00Woo1@00;goo00<007ooOol04Goo00<007ooOol0:Goo00<007ooOol00Woo0P00
3Goo00<007ooOol037oo200000=oo`00Ool0?7oo000kOol20004Ool5000`Ool00`00Oomoo`0AOol3
000XOol00`00Oomoo`03Ool2000>Ool2000<Ool300000goo0000000300000goo001oo`0kOol003Yo
o`03001oogoo009oo`L0031oo`03001oogoo01=oo`8002Moo`03001oogoo00=oo`8000moo`03001o
ogoo00Moo`<0009oo`03001oo`0000@0009oo`03001oogoo03Uoo`00>7oo0P0017oo3`00:Goo00<0
07ooOol057oo0P009Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol017oo0P001Woo1`00
0Woo0P00>Goo000gOol00`00Oomoo`02Ool80004Ool5000YOol00`00Oomoo`0FOol2000SOol00`00
Oomoo`03Ool2000BOol00`00Oomoo`02Ool20008Ool00`00Ool000040003Ool00`00Oomoo`0fOol0
03Ioo`04001oogooOol90003Ool2000^Ool00`00Oomoo`0GOol2000ROol00`00Oomoo`03Ool2000C
Ool00`00Oomoo`02000:Ool70003Ool00`00Oomoo`0eOol003Ioo`03001oogoo00T00004Ool00000
000`Ool00`00Oomoo`0HOol3000OOol00`00Oomoo`03Ool2000DOol3000<Ool01@00Ool00000Ool0
0P000goo00<007ooOol0=Goo000eOol00`00Oomoo`060003Ool2000cOol00`00Oomoo`0JOol00`00
Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`0DOol2000=Ool70003Ool00`00Oomoo`0dOol003=o
o`80009oo`H00004Ool00000000fOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`03Ool0
0`00Oomoo`0EOol2000<Ool80003Ool2000dOol0039oo`03001oogoo009oo`L003Uoo`03001oogoo
01Uoo`03001oogoo01eoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo00]oo`80009oo`@0
00Aoo`03001oogoo035oo`00<Goo00<007ooOol00goo0`0000=oo`000000>goo00<007ooOol067oo
00<007ooOol07Goo00<007ooOol00goo00<007ooOol05goo00<007ooOol02Woo00<007ooOol00goo
0P001Goo00<007ooOol0<7oo000`Ool00`00Oomoo`03Ool6000lOol00`00Oomoo`0HOol00`00Oomo
o`0MOol00`00Oomoo`03Ool00`00Oomoo`0GOol3000:Ool00`00Oomoo`03Ool30005Ool00`00Oomo
o`0_Ool002moo`03001oogoo00=oo`@00003Ool0000003aoo`03001oogoo01Qoo`03001oogoo01eo
o`03001oogoo00=oo`03001oogoo01Qoo`<000Uoo`03001oogoo00Eoo`8000Eoo`03001oogoo02io
o`00;Woo00<007ooOol017oo0`0000=oo`000000?Woo00<007ooOol05goo00<007ooOol07Goo00<0
07ooOol00Woo00<007ooOol06Woo0P002Goo00<007ooOol01Goo0P001Woo00<007ooOol0;Goo000]
Ool00`00Oomoo`04Ool400000goo0000000nOol00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomo
o`02Ool00`00Oomoo`0JOol30009Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0/Ool002aoo`03
001oogoo00Eoo`<00003Ool00000041oo`03001oogoo01Eoo`03001oogoo01moo`05001oogooOol0
000MOol20009Ool00`00Oomoo`03Ool00`00Oomoo`020006Ool00`00Oomoo`0[Ool002]oo`03001o
ogoo00Eoo`L0045oo`03001oogoo01Aoo`03001oogoo01moo`05001oogooOol0000MOol20009Ool0
0`00Oomoo`03Ool00`00Oomoo`030006Ool00`00Oomoo`0ZOol002Yoo`03001oogoo00Eoo`<0009o
o`80049oo`03001oogoo01Aoo`03001oogoo01moo`04001oogoo000OOol20009Ool00`00Oomoo`02
Ool20002Ool20007Ool00`00Oomoo`0YOol002Yoo`03001oogoo00Eoo`800004Ool000000014Ool0
0`00Oomoo`0COol00`00Oomoo`0OOol01000Oomoo`007goo0P002Goo00<007ooOol00goo00<007oo
Ool00`001Woo00<007ooOol0:Goo000YOol00`00Oomoo`05Ool60016Ool00`00Oomoo`0BOol00`00
Oomoo`0POol00`00Ool0000OOol00`00Ool00009Ool<0006Ool00`00Oomoo`0XOol002Moo`8000Mo
o`D004Qoo`03001oogoo019oo`03001oogoo021oo`80021oo`03001oo`0000Yoo`8000=oo`03001o
ogoo00@000Ioo`8002Qoo`009Woo00<007ooOol01goo1000BWoo00<007ooOol04Goo00<007ooOol0
87oo0P0087oo00@007ooOol000Qoo`800003Ool007oo009oo`03001oogoo00<000Qoo`03001oogoo
02Eoo`009Goo00<007ooOol01goo0P0000=oo`00Ool0Bgoo00<007ooOol047oo00<007ooOol08Goo
00<007ooOol04Goo300000Aoo`00Oomoo`8000Moo`04001oogooOol20002Ool00`00Oomoo`030008
Ool00`00Oomoo`0TOol002Eoo`03001oogoo00Moo`800003Ool007oo04]oo`03001oogoo011oo`03
001oogoo021oo`L000Aoo`X000aoo`8000=oo`03001oogoo00Aoo`8000Eoo`800003Ool007oo00@0
00Moo`03001oogoo02Aoo`0097oo00<007ooOol01goo0P000goo00<007ooOol0BWoo00<007ooOol0
3goo00<007ooOol087oo00<007ooOol017oo100077oo00<007ooOol00goo00<007ooOol01Woo2000
1goo00<007ooOol08goo000SOol00`00Oomoo`08Ool20003Ool2001<Ool00`00Oomoo`0=Ool00`00
Oomoo`0QOol00`00Oomoo`0TOol00`00Oomoo`02Ool2000;Ool200000goo00000008Ool00`00Oomo
o`0ROol0029oo`03001oogoo00Qoo`8000Eoo`8004aoo`03001oogoo00aoo`03001oogoo025oo`03
001oogoo02Eoo`05001oogooOol0000=Ool50007Ool00`00Oomoo`0ROol0025oo`03001oogoo00Qo
o`<000Ioo`03001oogoo04]oo`8000aoo`03001oogoo021oo`03001oogoo02Ioo`800003Ool007oo
00ioo`04001oo`000008Ool00`00Oomoo`0QOol0025oo`03001oogoo00Moo`H000Eoo`8004eoo`03
001oogoo00Uoo`03001oogoo021oo`03001oogoo02Moo`<000moo`800003Ool0000000Qoo`03001o
ogoo021oo`0087oo00<007ooOol027oo1@0027oo00<007ooOol0Bgoo00<007ooOol01goo0P008Goo
00<007ooOol0:7oo0P0047oo0P0000Aoo`00000000Qoo`03001oogoo01moo`007goo00<007ooOol0
2Goo0`002goo0P00C7oo00<007ooOol017oo0`008Woo00<007ooOol09Woo0P0000=oo`00000047oo
00<007oo00000`0027oo00<007ooOol07Woo000OOol00`00Oomoo`08Ool4000=Ool00`00Oomoo`1:
Ool00`00Oomoo`02Ool2000SOol00`00Oomoo`0VOol00`00Oomoo`02Ool2000?Ool00`00Oomoo`03
0008Ool00`00Oomoo`0NOol001ioo`03001oogoo00Qoo`@000moo`8004]oo`@002Eoo`03001oogoo
02Aoo`8000Ioo`<000eoo`03001oogoo00@000Qoo`03001oogoo01eoo`007Goo00<007ooOol027oo
10004Woo0P00BGoo100097oo00<007ooOol08goo0P002Woo0P0047oo100027oo00<007ooOol077oo
000MOol00`00Oomoo`08Ool4000DOol20018Ool200000goo0000000ROol00`00Oomoo`0ROol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool20008Ool00`00Oomoo`0LOol001aoo`03001oogoo00Qoo`@001Mo
o`8004Moo`80009oo`8001ioo`8002Aoo`03001oogoo00ioo`8000moo`<000Qoo`03001oogoo01]o
o`006goo00<007ooOol02Goo0`006Goo0P00Agoo00<007ooOol00Woo0P006goo00<007ooOol08Woo
0P004Woo0P003goo0P002Goo00<007ooOol06Woo000KOol00`00Oomoo`08Ool3000KOol20017Ool0
0`00Oomoo`03Ool2000GOol2000SOol2000FOol00`00Oomoo`0<Ool30008Ool00`00Oomoo`0JOol0
01Yoo`03001oogoo00Qoo`<001eoo`8004Ioo`8000Ioo`<0015oo`<002Aoo`03001oogoo01Moo`80
00aoo`03001oo`0000Uoo`03001oogoo01Uoo`006Woo00<007ooOol027oo0`007Woo0P00AWoo00<0
07ooOol01goo10002goo0P0057oo0P003goo0P0077oo00<007ooOol01Woo00@007ooOomoo`<000Qo
o`03001oogoo01Uoo`006Goo00<007ooOol027oo100087oo00<007ooOol0A7oo00<007ooOol02Woo
2`004Goo1@0000=oo`0000001@0027oo0P007Woo0P001Woo200027oo00<007ooOol067oo000IOol0
0`00Oomoo`08Ool4000QOol30013Ool2000QOol6000=Ool40002Ool2000ROol20005Ool200000goo
000000020008Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Qoo`<00003Ool007oo02=oo`8000Eo
o`<003Yoo`03001oogoo01]oo`@001Moo`<002Eoo`<000=oo`03001oo`0000@000Qoo`03001oogoo
01Moo`0067oo00<007ooOol027oo1@009Woo0`000goo0P00>Goo0P0067oo1@00AWoo2`001goo00<0
07ooOol05goo000GOol00`00Oomoo`08Ool200000goo0000000ZOol7000gOol00`00Oomoo`0DOol3
001?Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Qoo`800003Ool0
0000035oo`03001oogoo03Eoo`03001oogoo011oo`@0059oo`03001oogoo00=oo`8000Qoo`03001o
ogoo01Eoo`005Woo00<007ooOol027oo0P0000=oo`000000<Woo0P00=7oo00<007ooOol03Goo1000
EWoo00<007ooOol00goo0P0027oo00<007ooOol05Goo000EOol00`00Oomoo`08Ool200000goo0000
000eOol00`00Oomoo`0aOol00`00Oomoo`0:Ool3001JOol00`00Oomoo`03Ool30008Ool00`00Oomo
o`0DOol001Eoo`03001oogoo00Qoo`@003Moo`80035oo`03001oogoo00Aoo`H005eoo`03001oogoo
00Aoo`<000Moo`03001oogoo01Aoo`0057oo00<007ooOol027oo1000>Woo00<007ooOol0;Goo00@0
07ooOomoo`@005Yoo`D000Eoo`8000Aoo`<000Qoo`03001oogoo01=oo`0057oo00<007ooOol01goo
1000?7oo0P00;Goo1000FWoo10001Goo3`001goo00<007ooOol04goo000COol00`00Oomoo`08Ool3
000oOol2000VOol6001JOol3000EOol30008Ool00`00Oomoo`0BOol001=oo`03001oogoo00Moo`@0
041oo`80021oo`D000Aoo`03001oogoo05Qoo`03001oogoo01Moo`<000Qoo`03001oogoo015oo`00
4Woo00<007ooOol027oo1000@Woo0P0000=oo`0000006goo0P001goo00<007ooOol0Egoo00<007oo
Ool05Woo1@0027oo00<007ooOol04Goo000BOol00`00Oomoo`07Ool40015Ool3000JOol00`00Oomo
o`07Ool00`00Oomoo`1EOol2000BOol=0007Ool00`00Oomoo`0AOol0019oo`03001oogoo00Ioo`<0
0003Ool007oo04Eoo`<001Qoo`03001oogoo00Aoo`@005Moo`03001oogoo00moo`<000Uoo`@000Qo
o`03001oogoo011oo`004Goo00<007ooOol01goo0P0000=oo`00Ool0BGoo0P005Goo00@007ooOomo
o`@005Uoo`80011oo`8000eoo`<000Qoo`03001oogoo011oo`0047oo00<007ooOol027oo1000C7oo
0`004Goo1@00G7oo00<007ooOol03Woo0P003goo0`002Goo00<007ooOol03goo000@Ool00`00Oomo
o`07Ool4001@Ool40009Ool5001OOol00`00Oomoo`0=Ool2000BOol30008Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Moo`<005Eoo`T000=oo`03001oogoo05eoo`03001oogoo00aoo`8001Aoo`<0
00Qoo`03001oogoo00moo`0047oo00<007ooOol01goo0`00H7oo00<007ooOol0G7oo0P003Goo0P00
5Woo0`002Goo00<007ooOol03Woo000?Ool00`00Oomoo`08Ool3001POol00`00Oomoo`1KOol00`00
Oomoo`0<Ool00`00Oomoo`0GOol20009Ool00`00Oomoo`0>Ool000moo`03001oogoo00Qoo`<005mo
o`03001oogoo05]oo`03001oogoo00]oo`8001Yoo`8000Uoo`03001oogoo00ioo`003goo00<007oo
Ool01goo0`00Ggoo00<007ooOol0FWoo0P003Goo00<007ooOol06Woo0P002Woo00<007ooOol03Goo
000>Ool00`00Oomoo`08Ool3001NOol00`00Oomoo`1JOol00`00Oomoo`0<Ool00`00Oomoo`0KOol2
000:Ool00`00Oomoo`0=Ool000eoo`03001oogoo00Uoo`<005eoo`03001oogoo05Yoo`03001oogoo
00]oo`8001ioo`8000]oo`03001oogoo00aoo`003Goo00<007ooOol02Goo0P00GGoo0P00FWoo0P00
3Goo00<007ooOol07Woo0P002goo00<007ooOol037oo000=Ool00`00Oomoo`09Ool2001MOol00`00
Oomoo`1HOol00`00Oomoo`0;Ool2000POol200000goo001oo`09Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Uoo`8005aoo`8005Qoo`8000eoo`03001oogoo02=oo`03001oogoo00Uoo`03001oogoo
00]oo`0037oo00<007ooOol02Goo0P00G7oo0P00F7oo00<007ooOol037oo00<007ooOol097oo00<0
07ooOol02Goo00<007ooOol02goo000<Ool00`00Oomoo`09Ool2001KOol2001HOol00`00Oomoo`0=
Ool00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`80059o
o`8000Ioo`8005Moo`80011oo`03001oogoo02Aoo`8000]oo`03001oogoo00Yoo`002goo00<007oo
Ool02Woo0P00Cgoo1P0017oo00<007ooOol0EGoo0P004Goo00<007ooOol09Goo0P002goo00<007oo
Ool02Woo000;Ool00`00Oomoo`0:Ool2001=Ool20005Ool20002Ool00`00Oomoo`1EOol00`00Oomo
o`0@Ool00`00Oomoo`0VOol2000;Ool00`00Oomoo`0:Ool000]oo`03001oogoo00Yoo`8004Yoo`<0
00Qoo`<005Ioo`80019oo`03001oogoo02Moo`8000]oo`03001oogoo00Yoo`002goo00<007ooOol0
2Woo0P00Agoo0`00HWoo0P004goo00<007ooOol0:Goo00<007ooOol02Goo00<007ooOol02Woo000;
Ool00`00Oomoo`0:Ool2000oOol8001TOol00`00Oomoo`0COol00`00Oomoo`0YOol00`00Oomoo`0:
Ool00`00Oomoo`09Ool000Yoo`03001oogoo00]oo`8003ioo`80009oo`8006=oo`@001Ioo`03001o
ogoo02Uoo`03001oogoo00Yoo`03001oogoo00Uoo`002Woo00<007ooOol02goo0P00?Goo0P00Igoo
00<007ooOol05goo00<007ooOol0:Woo00<007ooOol02Woo00<007ooOol02Goo000:Ool00`00Oomo
o`0;Ool2000mOol00`00Oomoo`1TOol2000IOol00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool000Uoo`03001oogoo00]oo`@003]oo`03001oogoo06=oo`8001]oo`03001oogoo02]oo`80
00aoo`03001oogoo00Qoo`002Goo00<007ooOol02goo1@00>Woo00<007ooOol0HWoo00<007ooOol0
6goo00<007ooOol0:goo0P0037oo00<007ooOol027oo0009Ool00`00Oomoo`0;Ool5000iOol00`00
Oomoo`1QOol2000MOol00`00Oomoo`0]Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool000Uoo`03001o
ogoo00]oo`D003Uoo`03001oogoo05moo`8001moo`03001oogoo02eoo`03001oogoo00Yoo`03001o
ogoo00Qoo`002Goo00<007ooOol02goo1@00>7oo0P00H7oo00<007ooOol07Woo00<007ooOol0;Woo
00<007ooOol02Woo00<007ooOol027oo0008Ool00`00Oomoo`0?Ool3000gOol00`00Oomoo`1MOol2
000POol00`00Oomoo`0_Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03001oogoo00moo`@0
03Eoo`03001oogoo05eoo`03001oogoo021oo`03001oogoo02moo`03001oogoo00]oo`03001oogoo
00Moo`0027oo00<007ooOol047oo1`00<Goo00<007ooOol0GGoo00<007ooOol087oo00<007ooOol0
;goo00<007ooOol02goo00<007ooOol01goo0008Ool00`00Oomoo`0@Ool400000goo0000000`Ool0
0`00Oomoo`1LOol2000ROol00`00Oomoo`0`Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03
001oogoo011oo`80009oo`D002ioo`03001oogoo05]oo`03001oogoo029oo`03001oogoo031oo`03
001oogoo00]oo`03001oogoo00Moo`0027oo00<007ooOol047oo0P000Woo1P00;Goo00<007ooOol0
FWoo00<007ooOol08goo00<007ooOol0<7oo00<007ooOol02goo00<007ooOol01goo0008Ool00`00
Oomoo`0@Ool;000[Ool00`00Oomoo`1IOol2000UOol00`00Oomoo`0aOol2000=Ool00`00Oomoo`06
Ool000Moo`03001oogoo015oo`L0009oo`8002]oo`03001oogoo05Qoo`03001oogoo02Eoo`03001o
ogoo035oo`8000eoo`03001oogoo00Ioo`001goo00<007ooOol047oo1P0017oo00<007oo0000:Goo
00<007ooOol0F7oo00<007ooOol09Woo00<007ooOol0<Goo0P003Goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0@Ool60003Ool20002Ool00`00Oomoo`0VOol00`00Oomoo`1GOol00`00Oomoo`0VOol0
0`00Oomoo`0bOol2000=Ool00`00Oomoo`06Ool000Moo`03001oogoo011oo`@0009oo`T002Ioo`03
001oogoo05Qoo`03001oogoo02Ioo`03001oogoo039oo`8000eoo`03001oogoo00Ioo`001goo00<0
07ooOol03goo0`0000Aoo`00Oomoo`@0009oo`03001oogoo00<000Aoo`03001oogoo01aoo`03001o
ogoo05Moo`03001oogoo02Moo`03001oogoo035oo`<000eoo`03001oogoo00Ioo`001goo00<007oo
Ool02goo2`001Woo00@007ooOomoo`P001aoo`8005Qoo`03001oogoo02Qoo`03001oogoo035oo`03
001oo`0000eoo`03001oogoo00Ioo`001goo00<007ooOol02Woo4@0000=oo`0000002Goo00<007oo
Ool06Woo00<007ooOol0EWoo00<007ooOol0:Goo00<007ooOol0<Goo0`003Goo00<007ooOol01Woo
0007Ool00`00Oomoo`0:Ool=0004Ool40008Ool00`00Oomoo`0IOol00`00Oomoo`1FOol00`00Oomo
o`0ZOol00`00Oomoo`0aOol3000=Ool00`00Oomoo`06Ool000Moo`03001oogoo00Yoo`P00004Ool0
0000Ool20005Ool50005Ool00`00Oomoo`0IOol00`00Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomo
o`0bOol4000<Ool00`00Oomoo`06Ool000Moo`03001oogoo00Yoo`H000Eoo`03001oo`0000<000=o
o`800008Ool00000001oo`00Ool001Yoo`03001oogoo05Ioo`03001oogoo02Yoo`03001oogoo035o
o`800003Ool0000000aoo`03001oogoo00Ioo`001goo00<007ooOol02Woo1@001goo100000=oo`00
00000Woo00<007ooOol00Woo0P0000=oo`00Ool067oo00<007ooOol0EWoo00<007ooOol0:goo00<0
07ooOol0<Goo0P0000=oo`00000037oo00<007ooOol01Woo0007Ool00`00Oomoo`0:Ool50008Ool0
0`00Ool00003Ool900000goo001oo`0GOol2001GOol00`00Oomoo`0[Ool00`00Oomoo`0aOol01000
Ool007oo0P003Goo00<007ooOol01Goo0006Ool00`00Oomoo`0;Ool60008Ool20005Ool30006Ool0
0`00Oomoo`0DOol00`00Oomoo`1FOol00`00Oomoo`0/Ool00`00Oomoo`0`Ool200001Goo001oogoo
00003Goo00<007ooOol01Goo0006Ool00`00Oomoo`0;Ool30002Ool60004Ool30006Ool20004Ool0
0`00Oomoo`0@Ool01@00Oomoogoo0000Egoo00<007ooOol0;7oo00<007ooOol0<7oo0P000Woo00@0
07ooOol000eoo`03001oogoo00Eoo`001Woo00<007ooOol02Woo100027oo20001Woo0`000Woo00<0
07ooOol03goo0`0000=oo`00Ool0Egoo00<007ooOol0:goo00<007ooOol0<Goo00D007ooOomoo`00
009oo`03001oogoo00]oo`03001oogoo00Eoo`001Woo00<007ooOol02goo0`0037oo10002Goo1000
3Goo100000Aoo`00000005Qoo`03001oogoo02]oo`03001oogoo031oo`03001oogoo00=oo`03001o
o`0000eoo`03001oogoo00Eoo`001Woo00<007ooOol02Woo10003Goo0`0037oo3`000goo0P0000=o
o`000000EWoo00<007ooOol0:goo00<007ooOol0<7oo0P001Goo00<007oo00003Goo00<007ooOol0
1Goo0006Ool00`00Oomoo`0:Ool4000>Ool2000=Ool00`00Oomoo`0=Ool30002Ool00`00Oomoo`1C
Ool00`00Oomoo`0/Ool00`00Oomoo`0`Ool00`00Oomoo`04Ool00`00Ool0000=Ool00`00Oomoo`05
Ool000Ioo`03001oogoo00Yoo`@000ioo`8000ioo`03001oogoo00]oo`8000Aoo`03001oogoo059o
o`03001oogoo02aoo`03001oogoo035oo`03001oogoo00Aoo`03001oo`0000eoo`03001oogoo00Eo
o`001Woo00<007ooOol02Woo0`003goo0`003Woo0P002Goo0P001Woo00<007ooOol0DWoo00<007oo
Ool0:goo00<007ooOol0<Woo00<007ooOol017oo100037oo00<007ooOol01Goo0006Ool00`00Oomo
o`0:Ool3000?Ool00`00Ool0000@Ool30004Ool30007Ool00`00Oomoo`1BOol00`00Oomoo`0[Ool0
0`00Oomoo`0aOol00`00Oomoo`06Ool3000<Ool00`00Oomoo`05Ool000Ioo`03001oogoo00Yoo`<0
00moo`03001oo`0001=oo`D000Yoo`03001oogoo051oo`03001oogoo02aoo`03001oogoo035oo`03
001oogoo00Ioo`<000aoo`03001oogoo00Eoo`001Woo00<007ooOol02Woo0`003goo1@0087oo00<0
07ooOol0Cgoo00<007ooOol0;Goo00<007ooOol0<Goo00<007ooOol01Woo0`0037oo00<007ooOol0
1Goo0007Ool00`00Oomoo`09Ool3000AOol4000OOol00`00Oomoo`1>Ool00`00Oomoo`0^Ool00`00
Oomoo`0aOol00`00Oomoo`06Ool3000<Ool00`00Oomoo`05Ool000Moo`03001oogoo00Uoo`8001Ao
o`<001ioo`03001oogoo04eoo`03001oogoo02moo`03001oogoo035oo`03001oogoo00Eoo`04001o
o`00000;Ool00`00Oomoo`06Ool000Moo`03001oogoo00Uoo`8001Aoo`03001oo`0001ioo`03001o
ogoo04aoo`03001oogoo031oo`03001oogoo035oo`03001oogoo00Eoo`04001oo`00000;Ool00`00
Oomoo`06Ool000Moo`03001oogoo00Uoo`8001Aoo`04001oogoo000MOol00`00Oomoo`1:Ool2000c
Ool00`00Oomoo`0aOol00`00Oomoo`05Ool01000Ool000002goo00<007ooOol01Woo0007Ool00`00
Oomoo`09Ool2000DOol01000Oomoo`007Goo00<007ooOol0BGoo00<007ooOol0<goo00<007ooOol0
<Goo00<007ooOol01Goo00@007oo000000]oo`03001oogoo00Ioo`001goo00<007ooOol02Goo0P00
57oo00<007ooOol00P0077oo00<007ooOol0B7oo00<007ooOol0=7oo00<007ooOol0<7oo00<007oo
Ool01Woo00@007oo000000]oo`03001oogoo00Ioo`001goo00<007ooOol02Goo0P0057oo00D007oo
Oomoo`0001aoo`03001oogoo04Ioo`8003Moo`03001oogoo031oo`03001oogoo00Ioo`04001oo`00
000;Ool00`00Oomoo`06Ool000Moo`03001oogoo00Uoo`<001=oo`80009oo`03001oogoo01]oo`03
001oogoo04Aoo`03001oogoo03Moo`03001oogoo031oo`03001oogoo00Ioo`04001oo`00000;Ool0
0`00Oomoo`06Ool000Moo`03001oogoo00Uoo`<001=oo`80009oo`8001aoo`03001oogoo04=oo`03
001oogoo03Qoo`03001oogoo031oo`03001oogoo00Ioo`04001oo`00000;Ool00`00Oomoo`06Ool0
00Moo`03001oogoo00Uoo`<001=oo`<0009oo`03001oogoo01Yoo`03001oogoo045oo`8003]oo`03
001oogoo031oo`03001oogoo00Ioo`04001oo`00000;Ool00`00Oomoo`06Ool000Moo`03001oogoo
00Yoo`8001=oo`06001oo`00001oo`0077oo00<007ooOol0@7oo00<007ooOol0>goo00<007ooOol0
<7oo00<007ooOol01Woo00@007oo000000]oo`03001oogoo00Ioo`001goo00<007ooOol02Woo0P00
4goo00<007ooOol00`000Woo00<007ooOol05goo00<007ooOol0?Woo0P00?Woo00<007ooOol0<7oo
00<007ooOol01Woo00@007oo000000]oo`03001oogoo00Ioo`0027oo00<007ooOol02Goo0P0057oo
00<007oo00001@006Goo00<007ooOol0?Goo00<007ooOol0?Woo00<007ooOol0<7oo00<007ooOol0
1Woo10002goo00<007ooOol01Woo0008Ool00`00Oomoo`09Ool2000DOol200000goo001oo`02000J
Ool00`00Oomoo`0lOol00`00Oomoo`0oOol00`00Oomoo`0`Ool00`00Oomoo`06Ool3000;Ool00`00
Oomoo`07Ool000Qoo`03001oogoo00Yoo`03001oogoo015oo`8000Eoo`8001Uoo`03001oogoo03Yo
o`80049oo`03001oogoo031oo`03001oogoo00Ioo`<000]oo`03001oogoo00Moo`0027oo00<007oo
Ool02Woo00<007ooOol03goo0P0000=oo`00Ool01Woo00<007ooOol05Woo00<007ooOol0>Goo00<0
07ooOol0@Woo00<007ooOol0<7oo0P001goo0`002goo00<007ooOol01goo0008Ool00`00Oomoo`0:
Ool2000=Ool30003Ool00`00Oomoo`06Ool2000FOol00`00Oomoo`0gOol20015Ool00`00Oomoo`0a
Ool00`00Oomoo`05Ool2000<Ool00`00Oomoo`07Ool000Qoo`03001oogoo00Yoo`8000]oo`<000Eo
o`03001oogoo00Moo`8001Eoo`03001oogoo03Ioo`03001oogoo04Eoo`03001oogoo035oo`03001o
ogoo00Eoo`8000aoo`03001oogoo00Moo`0027oo00<007ooOol02Woo0`001goo10001goo00<007oo
Ool02Goo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0AWoo00<007ooOol0<7oo0P001goo
0P0037oo00<007ooOol01goo0009Ool00`00Oomoo`09Ool30005Ool2000<Ool00`00Oomoo`09Ool2
000017oo000000003Woo00<007ooOol0=7oo00<007ooOol0Agoo00<007ooOol0<7oo00<007ooOol0
1Woo0P002goo00<007ooOol027oo0009Ool00`00Oomoo`09Ool30004Ool2000=Ool00`00Oomoo`0;
Ool200000goo0000000=Ool00`00Oomoo`0aOol3001:Ool00`00Oomoo`0_Ool00`00Oomoo`07Ool2
000;Ool00`00Oomoo`08Ool000Uoo`03001oogoo00Yoo`8000Aoo`03001oogoo00aoo`03001oogoo
00moo`8000aoo`03001oogoo02aoo`D004eoo`03001oogoo02ioo`03001oogoo00Moo`<000]oo`03
001oogoo00Qoo`002Goo00<007ooOol02Woo0P000goo00<007ooOol03Goo00<007ooOol047oo0P00
37oo00<007ooOol0;7oo0P00Cgoo00<007ooOol0;Woo00<007ooOol01goo0P0037oo00<007ooOol0
27oo0009Ool00`00Oomoo`0:Ool20002Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol2000:Ool00`00
Oomoo`0[Ool2001@Ool2000^Ool20009Ool2000<Ool00`00Oomoo`08Ool000Yoo`03001oogoo00Uo
o`80009oo`03001oogoo00moo`03001oogoo01=oo`<000Moo`03001oogoo02]oo`03001oogoo051o
o`8002eoo`03001oogoo00Qoo`8000]oo`03001oogoo00Uoo`002Woo00<007ooOol02Goo0P000Woo
00<007ooOol03goo00<007ooOol05Woo0`0017oo00<007ooOol0:Woo0P00E7oo0`00:Goo00<007oo
Ool02Goo0P002goo00<007ooOol02Goo000:Ool00`00Oomoo`09Ool20002Ool00`00Oomoo`0?Ool0
0`00Oomoo`0IOol3000017oo00000000:Woo00<007ooOol0E7oo0`00:7oo00<007ooOol027oo0P00
37oo00<007ooOol02Goo000;Ool00`00Oomoo`08Ool200000goo001oo`0AOol00`00Oomoo`0LOol4
000ZOol00`00Oomoo`1FOol2000ROol300000goo0000000:Ool2000<Ool00`00Oomoo`09Ool000]o
o`03001oogoo00Qoo`800003Ool007oo015oo`03001oogoo01eoo`<002Uoo`03001oogoo05Qoo`<0
01ioo`<00003Ool00000008000Yoo`8000]oo`03001oogoo00Yoo`002goo00<007ooOol027oo1000
4Woo00<007ooOol077oo00@007ooOomoo`<002Eoo`03001oogoo05]oo`8001aoo`80015oo`8000]o
o`03001oogoo00Yoo`002goo00<007ooOol02Goo0`004Woo00<007ooOol077oo00<007ooOol017oo
0P008goo00<007ooOol0G7oo00<007ooOol067oo0P004Woo0P0037oo00<007ooOol02Woo000;Ool0
0`00Oomoo`09Ool3000BOol00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomo
o`1MOol00`00Oomoo`0HOol00`00Oomoo`0AOol2000<Ool00`00Oomoo`0:Ool000aoo`03001oogoo
00Qoo`<001=oo`03001oogoo01]oo`03001oogoo00Moo`<001eoo`03001oogoo05ioo`03001oogoo
01Moo`03001oogoo015oo`<000aoo`03001oogoo00Yoo`0037oo00<007ooOol027oo0`004goo00<0
07ooOol06goo00<007ooOol02Woo0P006Woo00<007ooOol0Ggoo00<007ooOol05Goo0P004goo1000
2goo00<007ooOol02goo000<Ool00`00Oomoo`08Ool3000COol00`00Oomoo`0KOol00`00Oomoo`0<
Ool00`00Oomoo`0FOol00`00Oomoo`1POol2000EOol00`00Oomoo`0BOol4000<Ool00`00Oomoo`0;
Ool000eoo`03001oogoo00Qoo`8001=oo`03001oogoo01]oo`03001oogoo00eoo`<001Eoo`03001o
ogoo061oo`8001=oo`8001Eoo`04001oo`00000<Ool00`00Oomoo`0;Ool000eoo`03001oogoo00Qo
o`8001=oo`03001oogoo01]oo`03001oogoo011oo`03001oogoo015oo`03001oogoo069oo`80011o
o`8001Moo`@000]oo`03001oogoo00aoo`003Goo00<007ooOol027oo0P0057oo00<007ooOol06Woo
00<007ooOol04Goo0P0047oo00<007ooOol0I7oo0P003Goo0P006Goo10002goo00<007ooOol037oo
000=Ool00`00Oomoo`08Ool2000DOol00`00Oomoo`0JOol00`00Oomoo`0COol2000=Ool00`00Oomo
o`1VOol2000:Ool3000JOol3000<Ool00`00Oomoo`0<Ool000ioo`03001oogoo00Moo`<001Aoo`03
001oogoo01Uoo`03001oogoo01Eoo`8000Yoo`03001oogoo06Uoo`@0009oo`@001eoo`<000]oo`03
001oogoo00eoo`003goo00<007ooOol01Woo0P0000=oo`00Ool04Woo00<007ooOol06Goo00<007oo
Ool05goo0P001Woo0P00KGoo00<007oo00000P008Goo0`002goo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool4000DOol00`00Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`2B
Ool4000:Ool00`00Oomoo`0>Ool000moo`03001oogoo00Moo`800003Ool007oo01=oo`03001oogoo
01Moo`03001oogoo01Yoo`800003Ool007oo09Aoo`<000]oo`03001oogoo00ioo`0047oo00<007oo
Ool01Woo0P000Woo00<007ooOol04Goo00<007ooOol037oo2@000Woo00<007ooOol077oo0P00UGoo
0`002goo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool20002Ool3000BOol00`00Oomoo`08Ool3
0009Ool3000NOol01000Ool00000SWoo20002Woo00<007ooOol03goo000@Ool00`00Oomoo`06Ool2
0003Ool3000AOol00`00Oomoo`05Ool3000?Ool2000KOol00`00Oomoo`02Ool00`00Oomoo`2;Ool0
1000Oomoogoo0`002goo00<007ooOol03goo000AOol00`00Oomoo`05Ool30003Ool00`00Oomoo`0A
Ool01000Oomoogoo0`004Woo00<007oo000067oo0P001Woo0`00RWoo00@007ooOomoo`<000]oo`03
001oogoo00moo`004Goo00<007ooOol01Goo0`000goo00<007ooOol04Goo1@0057oo00<007ooOol0
0P005Woo00<007ooOol027oo00<007ooOol0Qgoo00<007ooOol010002Woo00<007ooOol047oo000B
Ool00`00Oomoo`04Ool40002Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool2000COol00`00Oomoo`0:
Ool00`00Oomoo`26Ool00`00Oomoo`03000;Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Aoo`@0
009oo`03001oogoo02]oo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00aoo`<008Eoo`03
001oo`0000<000Yoo`03001oogoo015oo`004Woo00<007ooOol01Goo0P0000Aoo`00Ool002eoo`03
001oogoo00Aoo`<000eoo`03001oogoo011oo`03001oogoo089oo`H000Yoo`03001oogoo015oo`00
4goo00<007ooOol017oo0`0000=oo`000000;Goo0P0027oo0`0027oo0P0057oo00<007ooOol0PGoo
1@002goo00<007ooOol04Goo000COol00`00Oomoo`04Ool30002Ool2000]Ool00`00Oomoo`09Ool8
000GOol20020Ool6000:Ool00`00Oomoo`0BOol001Aoo`03001oogoo00=oo`@00003Ool0000002eo
o`03001oogoo00eoo`8001]oo`03001oogoo07]oo`P000Uoo`03001oogoo01=oo`005Goo00<007oo
Ool00goo100000=oo`000000;Goo00<007ooOol0:Woo00<007ooOol0NGoo0`0000Aoo`00001oo`80
00Uoo`03001oogoo01=oo`005Goo00<007ooOol00goo10000Woo00<007ooOol0:goo00<007ooOol0
:goo00<007ooOol0Mgoo100000=oo`00Ool00P002Goo00<007ooOol057oo000EOol00`00Oomoo`03
Ool50002Ool00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`1bOol00`00Ool000040003Ool0
1000Ool000002Goo00<007ooOol057oo000FOol00`00Oomoo`02Ool300001Goo000007oo0000;Goo
00<007ooOol0:goo0P00LWoo0`000Woo00<007ooOol00Woo00@007oo000000Qoo`03001oogoo01Eo
o`005Woo00<007ooOol00goo1@000Woo00<007ooOol0:goo00<007ooOol0;7oo00<007ooOol0L7oo
00@007ooOol000Eoo`<000Uoo`03001oogoo01Eoo`005goo00<007ooOol00Woo1P0000=oo`000000
;7oo00<007ooOol0;Goo00<007ooOol0KWoo00@007ooOol000Ioo`03001oo`0000Qoo`03001oogoo
01Ioo`0067oo00@007ooOomoo`L00004Ool007oo000[Ool00`00Oomoo`0]Ool00`00Oomoo`1]Ool0
0`00Ool00007Ool30007Ool00`00Oomoo`0GOol001Qoo`04001oogooOol30002Ool7000[Ool00`00
Oomoo`0/Ool00`00Oomoo`1GOol=0009Ool20007Ool30008Ool00`00Oomoo`0GOol001Uoo`03001o
ogoo00<000=oo`D002aoo`03001oogoo02eoo`03001oogoo05=oo`<000eoo`@000Aoo`8000Qoo`<0
00Moo`03001oogoo01Qoo`006Goo00@007ooOomoo`X002eoo`03001oogoo02eoo`03001oogoo055o
o`03001oogoo019oo`D000Qoo`04001oo`000007Ool00`00Oomoo`0HOol001Yoo`03001oogoo00@0
009oo`800003Ool0000002aoo`03001oogoo02eoo`03001oogoo04moo`8001Uoo`8000Ioo`D000Io
o`03001oogoo01Uoo`006Woo00<007ooOol01@000Woo00<007ooOol00P00;7oo00<007ooOol0;Goo
00<007ooOol0CGoo00<007ooOol06Goo0P001Woo1@001Woo00<007ooOol06Goo000KOol00`00Oomo
o`05000017oo000007oo0P00;Goo00<007ooOol0;Goo00<007ooOol0BWoo0P0077oo00<007ooOol0
17oo00<007oo00000P001Woo00<007ooOol06Woo000KOol01000Oomoogoo200000=oo`000000;7oo
00<007ooOol0;Goo00<007ooOol0BGoo00<007ooOol06goo00<007ooOol017oo0P0000Aoo`000000
00Ioo`03001oogoo01Yoo`0077oo00@007ooOomoo`<00003Ool0000000@002eoo`03001oogoo02eo
o`03001oogoo04Moo`03001oogoo01aoo`03001oogoo009oo`<0009oo`8000Ioo`03001oogoo01]o
o`007Goo00@007ooOomoo`<00003Ool007oo00<002ioo`03001oogoo02eoo`03001oogoo04Eoo`03
001oogoo01eoo`03001oogoo009oo`<0009oo`8000Eoo`03001oogoo01aoo`007Goo00@007ooOomo
o`@00003Ool0000000<002eoo`03001oogoo02eoo`03001oogoo04Aoo`03001oogoo01eoo`03001o
ogoo00Eoo`03001oo`00008000Eoo`03001oogoo01aoo`007Woo00<007ooOol00Woo0P0000Aoo`00
001oo`8002ioo`03001oogoo02eoo`03001oogoo04=oo`03001oogoo01eoo`03001oogoo00Eoo`@0
00Eoo`03001oogoo01eoo`007goo00<007ooOol00Woo2000;Woo00<007ooOol0;7oo00<007ooOol0
@Woo00<007ooOol07Goo00<007ooOol01Woo100017oo00<007ooOol07Woo000OOol00`00Oomoo`02
Ool700000goo001oo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`10Ool00`00Oomoo`0NOol00`00Oomo
o`06Ool30005Ool00`00Oomoo`0NOol0021oo`03001oogoo00=oo`H00003Ool007oo02]oo`8002io
o`03001oogoo03moo`03001oogoo01ioo`8000Qoo`<000Aoo`03001oogoo01moo`008Goo00<007oo
Ool00Woo1`0000=oo`00Ool0:goo00<007ooOol0;Goo00<007ooOol0?Goo00<007ooOol07goo00<0
07ooOol01goo0P0017oo00<007ooOol087oo000QOol00`00Oomoo`04Ool600000goo001oo`0ZOol0
0`00Oomoo`0]Ool00`00Oomoo`0kOol2000QOol00`00Oomoo`07Ool30004Ool00`00Oomoo`0POol0
029oo`03001oogoo00Aoo`D00003Ool007oo02Uoo`80031oo`8003Yoo`03001oogoo025oo`03001o
ogoo00Eoo`D000=oo`03001oogoo025oo`008goo00<007ooOol00goo1P0000=oo`00Ool0:7oo00<0
07ooOol0<7oo0P0077oo00<007ooOol067oo0P0097oo00<007ooOol01Goo10000goo00<007ooOol0
8Woo000TOol00`00Oomoo`03Ool50002Ool00`00Oomoo`0VOol00`00Oomoo`0`Ool3000IOol5000G
Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Ool000040002Ool00`00Oomoo`0SOol002Eoo`03
001oogoo00Aoo`@0009oo`03001oogoo02Eoo`03001oogoo039oo`<000ioo`8000Aoo`<000Aoo`<0
01Aoo`03001oogoo02Aoo`03001oogoo00=oo`H0009oo`03001oogoo02Aoo`009Goo00<007ooOol0
17oo10000goo00<007ooOol097oo00<007ooOol0=Goo0`002goo1P002Goo0P004Woo00<007ooOol0
9Goo00<007ooOol00goo00@007oo000000Aoo`03001oogoo02Aoo`009Woo00<007ooOol017oo1000
0Woo00<007ooOol08goo0P00>Woo0P0027oo0P003goo0`003Woo0P009goo00<007ooOol00goo1000
17oo00<007ooOol09Goo000WOol20005Ool40002Ool00`00Oomoo`0ROol00`00Oomoo`0kOol40003
Ool2000BOol3000:Ool2000XOol20004Ool40003Ool2000XOol002Uoo`03001oogoo00=oo`@00003
Ool007oo02=oo`03001oogoo03moo`<001Ioo`8000Qoo`03001oogoo02Qoo`8000=oo`@000=oo`03
001oogoo02Qoo`00:Woo00<007ooOol00Woo10000Woo00<007ooOol08Goo00<007ooOol0@7oo0`00
5goo0`000goo0P00:goo00@007ooOomoo`@000=oo`03001oogoo02Uoo`00:Woo00<007ooOol017oo
0`0000=oo`00Ool08Woo00<007ooOol0?goo00@007ooOomoo`@001Ioo`<002eoo`03001oogoo00<0
00Eoo`03001oogoo02Uoo`00:goo00<007ooOol01Goo10008Woo00<007ooOol0?Woo00<007ooOol0
1Woo1@004Goo0`00;Goo1@001Goo00<007ooOol0:Woo000/Ool00`00Oomoo`04Ool4000ROol00`00
Oomoo`0nOol00`00Oomoo`0;Ool60009Ool20002Ool2000[Ool50005Ool00`00Oomoo`0[Ool002eo
o`03001oogoo00Aoo`D0021oo`03001oogoo03aoo`8001Aoo`X000Aoo`<002Moo`H000Eoo`03001o
ogoo02aoo`00;Woo00<007ooOol017oo0`0000=oo`0000007Woo00<007ooOol0>goo00<007ooOol0
97oo2@007goo10001Woo00<007ooOol0;Goo000_Ool00`00Oomoo`04Ool400000goo0000000MOol0
0`00Oomoo`0iOol00`00Oomoo`0]Ool3000LOol40006Ool00`00Oomoo`0^Ool0031oo`03001oogoo
00Eoo`<0009oo`8001]oo`03001oogoo03Qoo`03001oogoo035oo`8000moo`03001oogoo00Ioo`D0
00Ioo`03001oogoo02moo`00<Goo00<007ooOol017oo10000Woo00<007ooOol06Woo00<007ooOol0
=Woo00<007ooOol07Goo00D007ooOomoo`00015oo`8000]oo`H000=oo`03001oo`0000@000Ioo`03
001oogoo031oo`00<Woo00<007ooOol017oo100000=oo`00Ool06goo00<007ooOol0=7oo0P0087oo
1@004goo0`001goo0P0017oo0P000Woo1P001Woo00<007ooOol0<Goo000cOol20005Ool400000goo
001oo`0JOol2000eOol00`00Oomoo`0OOol01@00Oomoogoo00005Goo0`000goo0P001goo00<007oo
000010001Woo0P00=7oo000eOol00`00Oomoo`04Ool4000LOol00`00Oomoo`0bOol00`00Oomoo`0O
Ool00`00Oomoo`02Ool2000FOol40009Ool60006Ool00`00Oomoo`0dOol003Ioo`03001oogoo00Ao
o`@001aoo`03001oogoo031oo`03001oogoo01moo`8000Eoo`03001oogoo01Ioo`03001oogoo00Qo
o`D000Ioo`03001oogoo03Eoo`00=Woo00<007ooOol017oo1@006goo00<007ooOol0;goo00<007oo
Ool087oo00<007ooOol017oo00<007ooOol087oo1@001goo00<007ooOol0=Goo000gOol00`00Oomo
o`04Ool4000KOol2000_Ool2000QOol00`00Oomoo`05Ool00`00Oomoo`0OOol50007Ool00`00Oomo
o`0fOol003Qoo`8000Eoo`@00003Ool007oo01Qoo`03001oogoo02aoo`03001oogoo01moo`<000Mo
o`8001moo`@000Moo`8003Uoo`00>Woo00<007ooOol00goo1@006Woo00<007ooOol0:goo00<007oo
Ool07goo0P002Goo00<007ooOol06goo1@001goo00<007ooOol0>Goo000kOol00`00Oomoo`03Ool6
000HOol00`00Oomoo`0ZOol00`00Oomoo`0POol00`00Oomoo`08Ool2000IOol70007Ool00`00Oomo
o`0jOol003aoo`03001oogoo00=oo`L001Ioo`03001oogoo02Uoo`80029oo`03001oogoo00Uoo`03
001oogoo01Eoo`L000Qoo`03001oogoo03]oo`00?Goo0P001Goo1@005goo00<007ooOol0:7oo00<0
07ooOol08Goo00<007ooOol02Woo0`002Woo00<007ooOol017oo2@001goo0P00?Woo000oOol00`00
Oomoo`03Ool6000FOol00`00Oomoo`0UOol2000TOol00`00Oomoo`0;Ool20009Ool90002Ool40008
Ool00`00Oomoo`0nOol0041oo`8000Aoo`L001Aoo`03001oogoo02Eoo`03001oogoo02=oo`03001o
ogoo00]oo`03001oogoo00Ioo`8000Ioo`80009oo`@000Moo`80045oo`00@Woo00<007ooOol00Woo
1@0000=oo`00Ool04goo00<007ooOol077oo00<007ooOol00goo0P009Woo00<007ooOol02goo00<0
07ooOol01Goo00<007ooOol01Woo0P0000=oo`0000000P001goo00<007ooOol0@Goo0013Ool20004
Ool400000goo0000000COol00`00Oomoo`0KOol30002Ool2000WOol00`00Oomoo`0;Ool20002Ool4
0008Ool60007Ool20014Ool004Eoo`03001oogoo009oo`P0019oo`03001oogoo01Uoo`800003Ool0
0000008002Qoo`03001oogoo00Eoo`X000]oo`H000Moo`03001oogoo04Aoo`00AWoo0P0017oo1@00
00=oo`00Ool047oo00<007ooOol067oo0P00;Woo00<007ooOol00Woo0`0027oo0P001goo20001goo
0P00Agoo0018Ool20004Ool9000>Ool00`00Oomoo`0GOol00`00Oomoo`0]Ool5000=Ool00`00Oomo
o`02Ool20002Ool50006Ool20019Ool004Yoo`8000Eoo`L000eoo`8001Moo`03001oogoo02]oo`@0
015oo`80009oo`800004Ool00000Ool30005Ool2001;Ool004aoo`8000Eoo`L000aoo`03001oogoo
01Aoo`8002Uoo`@000=oo`80015oo`<0009oo`D000Eoo`8004eoo`00CWoo00<007ooOol01Goo2000
2Goo0P004goo00<007ooOol087oo0P001Woo00<007ooOol01Goo00<007oo00000P003Goo100000=o
o`00Ool00P001Woo00<007ooOol0CGoo001?Ool20008Ool60009Ool00`00Oomoo`0AOol00`00Oomo
o`0KOol01000Oomoogoo10000Woo10001goo00D007ooOol007oo00<000Uoo`80009oo`D000Eoo`80
051oo`00DGoo0`0027oo2@0017oo00<007ooOol03goo00<007ooOol06goo2`000goo00<007ooOol0
1Woo00@007ooOol0009oo`@000Aoo`X000=oo`<0059oo`00E7oo00<007ooOol01goo2P000Woo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol06Woo0P0000=oo`0000001goo0P002Woo00D007oo
Oomoo`0000Eoo``000Aoo`03001oogoo05=oo`00EGoo0P002goo2P0017oo0P0027oo00<007ooOol0
6Woo0P0000=oo`00Ool02Woo10001Woo0P000Woo4@000goo0P00EWoo001GOol3000:Ool:000017oo
0000000027oo00<007ooOol06Goo100047oo60000goo0`00F7oo001JOol00`00Oomoo`0:Ool80002
Ool20006Ool00`00Oomoo`0IOol2000COolD0006Ool00`00Oomoo`1IOol005]oo`@000]oo`T000Eo
o`03001oogoo01Moo`@0011oo`@000Aoo`/00003Ool0000000Aoo`@005aoo`00Ggoo0`002goo2000
0goo0`000Woo5`003goo0`001Woo2P001goo0`00H7oo001ROol00`00Oomoo`0;Ool=000COol3000;
OolF0008Ool00`00Oomoo`1QOol006=oo`@000aoo`P0019oo`@000Yooa@000Uoo`@006Aoo`00Igoo
0`0037oo7@0017oo3P0047oo0`00J7oo001ZOol5000:Ool@0003OolC000AOol5001[Ool006moo`<0
00Yooah001=oo`<0071oo`00LWoo1@0027oo3`006Woo1@00Lgoo001gOol7000SOol7001hOol007io
o``000]oo``007moo`00RWoo2`00Rgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-178.502, -178.502, 1.24392, \
1.24392}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\nThis graph provides some qualitative information on the way the mouse \
moves during the session, for instance it highlights the fact that the mouse \
mostly moved on  the periphery of the arena, progressing along relatively \
smooth paths. Each of these features suggests a corresponding quantitative \
measure  which might turn out to be useful by revealing a  regularity or even \
an invariance. Indeed the measures currently used to phenotype rodent open \
field behavior are: the overall amount of activity and  the ratio spent at \
the periphery versus the center of the arena, activity  level per fixed time \
interval across the session, and the path's degree of meandering (",
  StyleBox["Paulus and Geyer, ",
    FontColor->RGBColor[1, 0, 0]],
  " ). To perform the same computations on several files we use the function \
Script. This function loads a file, performs one or several computations on \
it, then unloads that file, loads the next one, etc.,. If  you loaded a file \
before using Script, make sure to first UnLoad it: "
}], "Text",
  PageWidth->WindowWidth,
  TextJustification->0,
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(UnLoad[balbfiles[\([1]\)]]\)\(\n\)\)\)], "Input"],

Cell["\<\
Because Script works on a list of files, it is useful to define such lists \
using the FileNames function . To compare the behavior of a particular c57 \
mouse to that of a particular Balb mouse, for example, we defined the list \
\"twofiles\" including the two data files (see at the top of this notebook).  \
 \
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Show", "[", 
      RowBox[{"GraphicsArray", "[", 
        RowBox[{"Partition", "[", 
          RowBox[{
            RowBox[{"Flatten", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["Script",
                    FontColor->RGBColor[1, 0, 1]], "[", 
                  
                  RowBox[{\({"\<See[PathPlot[{1,Length[data]}],PlotLabel->\
sessionname2,TextStyle->{FontSize->14},DisplayFunction->Identity]\>"}\), ",", 
                    
                    StyleBox["twofiles",
                      FontColor->RGBColor[1, 0, 1]]}], "]"}], ",", "1"}], 
              "]"}], ",", "2"}], "]"}], "]"}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.09259 .43598 m
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09257 .43598 L
.09254 .43598 L
.09249 .43598 L
.09245 .43598 L
.09241 .43594 L
.09239 .43588 L
.0924 .43577 L
.09244 .43564 L
.09254 .43551 L
.09271 .43543 L
.09296 .43543 L
.0933 .43559 L
.09376 .43595 L
.09432 .43654 L
.09498 .43735 L
.09573 .4384 L
.09654 .43965 L
.09737 .44085 L
.09822 .44231 L
.09907 .44396 L
.0999 .44549 L
.10069 .44709 L
.10143 .44886 L
.10207 .45038 L
.10264 .45188 L
.10312 .45334 L
.10352 .45475 L
.10386 .4561 L
.10417 .45736 L
.10449 .45866 L
.10487 .46006 L
.10531 .46159 L
.10582 .46326 L
.10642 .46489 L
.10708 .46656 L
.10777 .46829 L
.10855 .46996 L
.10937 .47148 L
.11022 .47288 L
.11112 .47414 L
.112 .47522 L
.1129 .47619 L
.11377 .47703 L
Mistroke
.11459 .47774 L
.11538 .47834 L
.11615 .4789 L
.11695 .47946 L
.11779 .48005 L
.11873 .48067 L
.11976 .48136 L
.12081 .48206 L
.12194 .48281 L
.12309 .48359 L
.1243 .48439 L
.12554 .48519 L
.12687 .48595 L
.12818 .48664 L
.12958 .48725 L
.13093 .48777 L
.13232 .48822 L
.13371 .48861 L
.13501 .48897 L
.13634 .48931 L
.13775 .48966 L
.13918 .49007 L
.14074 .49054 L
.14235 .4911 L
.14411 .49177 L
.14586 .49255 L
.14764 .49339 L
.14943 .49426 L
.15117 .49514 L
.15278 .49597 L
.15431 .4967 L
.15573 .49731 L
.15695 .49785 L
.15807 .49835 L
.15902 .49879 L
.15977 .49917 L
.16034 .49951 L
.16076 .49988 L
.16108 .50034 L
.16136 .50094 L
.16162 .50169 L
.16191 .50262 L
.16224 .50374 L
.16266 .50502 L
.16317 .5066 L
.16374 .50852 L
.16438 .51076 L
.16505 .51288 L
.16577 .51547 L
.16651 .5178 L
Mistroke
.16721 .52037 L
.1679 .52309 L
.16856 .52535 L
.1692 .52791 L
.16983 .53017 L
.17046 .53263 L
.17108 .53479 L
.17166 .53702 L
.17222 .53923 L
.17277 .54142 L
.17331 .54361 L
.17384 .54596 L
.17436 .54811 L
.17487 .55047 L
.17535 .55272 L
.17578 .555 L
.17614 .55747 L
.17642 .55979 L
.17658 .56226 L
.17665 .56452 L
.17664 .56683 L
.17655 .569 L
.17638 .57095 L
.17614 .57293 L
.17583 .57494 L
.17545 .57685 L
.17499 .57874 L
.17444 .58076 L
.1738 .58279 L
.17309 .58476 L
.17235 .58677 L
.17162 .5887 L
.17097 .59025 L
.17034 .59177 L
.16975 .5932 L
.16924 .59438 L
.16877 .59537 L
.16836 .59616 L
.16803 .59675 L
.16778 .59714 L
.16763 .59735 L
.16759 .59743 L
.16764 .59741 L
.16774 .59735 L
.16785 .59727 L
.16794 .5972 L
.16797 .5971 L
.16795 .59696 L
.16787 .59676 L
.16776 .59648 L
Mistroke
.16766 .59612 L
.16756 .5957 L
.16744 .59525 L
.16724 .59479 L
.16697 .59433 L
.16662 .59385 L
.16617 .59336 L
.16563 .59287 L
.16498 .59239 L
.16418 .59196 L
.16321 .59158 L
.16209 .59127 L
.16086 .59106 L
.1596 .59093 L
.1582 .59088 L
.15657 .59082 L
.15474 .5907 L
.1531 .59049 L
.15128 .59018 L
.14924 .58983 L
.14755 .58947 L
.14589 .58913 L
.14416 .58884 L
.14233 .58861 L
.14046 .58848 L
.13881 .58842 L
.13715 .58843 L
.13542 .58848 L
.13359 .58861 L
.13167 .58883 L
.12995 .5892 L
.1281 .58972 L
.12604 .59038 L
.12385 .59116 L
.12196 .59202 L
.12002 .59293 L
.11794 .59386 L
.11595 .59475 L
.11402 .59561 L
.11193 .59646 L
.11019 .59737 L
.1084 .59837 L
.10657 .59946 L
.1048 .60059 L
.10331 .60171 L
.10195 .60281 L
.10064 .60398 L
.0994 .60524 L
.09824 .6066 L
.09721 .60804 L
Mistroke
.09631 .60947 L
.09549 .61095 L
.09477 .61248 L
.09415 .61407 L
.0936 .61572 L
.09309 .61725 L
.09261 .6191 L
.09211 .62081 L
.09163 .62259 L
.09118 .62443 L
.09078 .62634 L
.09043 .62832 L
.09015 .63032 L
.08998 .63215 L
.08992 .63389 L
.08998 .63559 L
.09015 .63729 L
.0904 .639 L
.09072 .64066 L
.09108 .64229 L
.09146 .64386 L
.09185 .64539 L
.09223 .64688 L
.09259 .64842 L
.0929 .65007 L
.09315 .6519 L
.09334 .65385 L
.09348 .65558 L
.09361 .65762 L
.09376 .65954 L
.09393 .66158 L
.09415 .66375 L
.09441 .66602 L
.09476 .66806 L
.09519 .67023 L
.09572 .67254 L
.09633 .67493 L
.09701 .67718 L
.09773 .67941 L
.09849 .68156 L
.09928 .68382 L
.10007 .68608 L
.10088 .68837 L
.10172 .69068 L
.10258 .69272 L
.10347 .69478 L
.10436 .69686 L
.10522 .69885 L
.10603 .70083 L
.10678 .70282 L
Mistroke
.10746 .70473 L
.10809 .70671 L
.10866 .70883 L
.1092 .71105 L
.10971 .71342 L
.1102 .71586 L
.11065 .71857 L
.11107 .72117 L
.11143 .72393 L
.11174 .72641 L
.11199 .72896 L
.1122 .73115 L
.11236 .73327 L
.11249 .73524 L
.11259 .73691 L
.11265 .73825 L
.11268 .73928 L
.11271 .73998 L
.11271 .74039 L
.11271 .74058 L
.11274 .74062 L
.11281 .74062 L
.11296 .74065 L
.1132 .74079 L
.11351 .74109 L
.1139 .74156 L
.11432 .74223 L
.11477 .74312 L
.11522 .74419 L
.11566 .7453 L
.11609 .74646 L
.1165 .74765 L
.11689 .74883 L
.11725 .74995 L
.11757 .75091 L
.11787 .7517 L
.11814 .75227 L
.11841 .75264 L
.11867 .75282 L
.11892 .75287 L
.11918 .75286 L
.11947 .75286 L
.11981 .75292 L
.12025 .75306 L
.12082 .7533 L
.12154 .75365 L
.12239 .75412 L
.12336 .75473 L
.12445 .75545 L
.12566 .75629 L
Mistroke
.12686 .75723 L
.12814 .75824 L
.12948 .7593 L
.13079 .76044 L
.13222 .76167 L
.1337 .76295 L
.13508 .76433 L
.13649 .76585 L
.13791 .76749 L
.13925 .76919 L
.14066 .77114 L
.14199 .77316 L
.14346 .77546 L
.14507 .77772 L
.14654 .77983 L
.1481 .7821 L
.1498 .78443 L
.15161 .7866 L
.15325 .78871 L
.15482 .79072 L
.15627 .7924 L
.15754 .79388 L
.15867 .79521 L
.15966 .79625 L
.16059 .79715 L
.16138 .79796 L
.16209 .7987 L
.16276 .79941 L
.16342 .80015 L
.16408 .8009 L
.16479 .80175 L
.16554 .8027 L
.16641 .80375 L
.16736 .80482 L
.16842 .80606 L
.16959 .80754 L
.17087 .80897 L
.17229 .8105 L
.17383 .81206 L
.17536 .81356 L
.17698 .81503 L
.17857 .81635 L
.18019 .81765 L
.18185 .81895 L
.1833 .82029 L
.18494 .82159 L
.18664 .82304 L
.18825 .82449 L
.19001 .82606 L
.19169 .82777 L
Mistroke
.19344 .82955 L
.19518 .83108 L
.19669 .83283 L
.19815 .83459 L
.19956 .83627 L
.201 .83803 L
.20246 .83973 L
.20382 .8413 L
.20518 .84276 L
.20647 .84401 L
.20756 .84502 L
.20856 .84588 L
.20944 .8466 L
.21025 .84721 L
.21102 .84775 L
.21175 .84824 L
.21247 .84871 L
.21319 .84918 L
.2139 .84966 L
.21463 .85021 L
.21536 .85083 L
.21607 .8515 L
.21681 .85225 L
.21758 .85305 L
.21837 .85387 L
.21917 .85467 L
.21997 .85544 L
.22069 .85613 L
.22139 .85673 L
.22201 .85723 L
.22256 .8576 L
.22306 .85785 L
.22351 .85798 L
.22394 .85803 L
.22434 .85803 L
.22471 .85804 L
.22504 .85807 L
.22537 .85815 L
.2257 .85835 L
.22609 .8587 L
.22655 .85922 L
.22709 .85992 L
.22768 .8607 L
.2283 .86162 L
.22895 .86265 L
.22964 .86367 L
.23038 .86473 L
.23118 .86581 L
.23205 .86685 L
.23297 .8678 L
Mistroke
.23395 .86863 L
.23504 .86935 L
.23618 .86992 L
.23744 .87034 L
.23887 .87064 L
.24037 .87086 L
.24199 .87102 L
.24378 .87115 L
.24569 .87126 L
.24781 .87141 L
.2497 .87162 L
.25181 .87192 L
.25415 .87235 L
.25616 .87289 L
.25828 .87353 L
.26035 .87423 L
.26249 .87502 L
.26435 .87596 L
.26629 .87704 L
.26818 .87827 L
.2701 .87952 L
.27189 .8809 L
.27366 .88236 L
.27547 .88389 L
.27734 .88549 L
.27917 .8869 L
.28103 .8884 L
.28305 .88988 L
.28484 .89124 L
.28675 .89261 L
.28871 .89399 L
.29075 .89515 L
.29272 .89625 L
.29471 .89729 L
.29683 .89824 L
.29876 .89912 L
.30083 .89996 L
.30289 .90077 L
.30512 .90154 L
.30723 .90229 L
.30949 .90303 L
.31177 .90378 L
.31404 .90453 L
.31641 .90527 L
.31843 .90596 L
.32072 .90665 L
.3228 .90735 L
.325 .90806 L
.3272 .90879 L
.32941 .90957 L
Mistroke
.33157 .91041 L
.33376 .91132 L
.33593 .91221 L
.33814 .91312 L
.34025 .91408 L
.34238 .91514 L
.34457 .91621 L
.34673 .91725 L
.34899 .91826 L
.35127 .9192 L
.35353 .92006 L
.35576 .92089 L
.35788 .92168 L
.36002 .92242 L
.362 .92313 L
.36403 .92382 L
.36606 .9245 L
.36809 .92512 L
.37008 .92568 L
.37218 .92617 L
.37417 .92659 L
.37616 .92694 L
.37815 .92723 L
.38017 .92745 L
.38236 .92761 L
.38436 .92774 L
.38654 .92786 L
.38871 .92802 L
.39095 .92824 L
.39307 .92855 L
.39524 .929 L
.39742 .92963 L
.3995 .93048 L
.40158 .93155 L
.40369 .93282 L
.40564 .93396 L
.40761 .93546 L
.40955 .93668 L
.41139 .93792 L
.41327 .93922 L
.41494 .94043 L
.41664 .94158 L
.41832 .94262 L
.42003 .94348 L
.42177 .94429 L
.42363 .94502 L
.42545 .9457 L
.42743 .94634 L
.42947 .94695 L
.43163 .94748 L
Mistroke
.43393 .94798 L
.43649 .94843 L
.43895 .94882 L
.44174 .94916 L
.44449 .94942 L
.44724 .94962 L
.45012 .94973 L
.45304 .94975 L
.45606 .94969 L
.45876 .94956 L
.4616 .94938 L
.46445 .94918 L
.46705 .94897 L
.46965 .94876 L
.47216 .94853 L
.47467 .94831 L
.47696 .9481 L
.47923 .94792 L
.48141 .94777 L
.48355 .94764 L
.48568 .9475 L
.48779 .94733 L
.48995 .94712 L
.49197 .94689 L
.49408 .94663 L
.49604 .94637 L
.49807 .94611 L
.50007 .94586 L
.50209 .94563 L
.50415 .94542 L
.50635 .94522 L
.50834 .94504 L
.51048 .94487 L
.51262 .94471 L
.5149 .94457 L
.51693 .94446 L
.51908 .94438 L
.52136 .94431 L
.52341 .94424 L
.5256 .94417 L
.52779 .94408 L
.52997 .94396 L
.53209 .9438 L
.53429 .9436 L
.53652 .94339 L
.53881 .94318 L
.54121 .94298 L
.54327 .94279 L
.54551 .9426 L
.54769 .94241 L
Mistroke
.54977 .94223 L
.55172 .94206 L
.55358 .94192 L
.55509 .94181 L
.55646 .94173 L
.55754 .94167 L
.5584 .94161 L
.55899 .94155 L
.55929 .94148 L
.55932 .94139 L
.55914 .94126 L
.55882 .94111 L
.55842 .94094 L
.55802 .94074 L
.55765 .94052 L
.55739 .9403 L
.55724 .94006 L
.55725 .93983 L
.55744 .93959 L
.55783 .93936 L
.55844 .93916 L
.5593 .93897 L
.5604 .93882 L
.56173 .93869 L
.56328 .93857 L
.56505 .93846 L
.56696 .93833 L
.5691 .93818 L
.57134 .938 L
.57361 .93779 L
.57605 .93758 L
.57855 .93735 L
.58124 .93713 L
.58359 .93691 L
.58604 .93669 L
.58859 .93649 L
.5906 .93629 L
.59256 .93612 L
.59439 .93596 L
.59602 .93582 L
.59734 .9357 L
.59836 .93562 L
.59907 .93556 L
.59953 .93554 L
.59979 .93558 L
.59992 .93564 L
.6 .9357 L
.60012 .93573 L
.60034 .93569 L
.6007 .93556 L
Mistroke
.60125 .93534 L
.60199 .935 L
.603 .93455 L
.60416 .93403 L
.60564 .93342 L
.60736 .93278 L
.60934 .93212 L
.61168 .93145 L
.61392 .93078 L
.61653 .93015 L
.6191 .92957 L
.62195 .92907 L
.62473 .92864 L
.62772 .92824 L
.63087 .92786 L
.6338 .92746 L
.63696 .92701 L
.64011 .92649 L
.64312 .92591 L
.64585 .92524 L
.64846 .92455 L
.65082 .92385 L
.6531 .9232 L
.65488 .92256 L
.65669 .92186 L
.65823 .92113 L
.65966 .9204 L
.66097 .91969 L
.66219 .91899 L
.66329 .91835 L
.66448 .91767 L
.66565 .91696 L
.66702 .91619 L
.66854 .91529 L
.67013 .91439 L
.67202 .91342 L
.67412 .91241 L
.67648 .91137 L
.67871 .91034 L
.68114 .90934 L
.68369 .90844 L
.68621 .90761 L
.68886 .90682 L
.69155 .90605 L
.69443 .9053 L
.69706 .90457 L
.69979 .90387 L
.70246 .90317 L
.70493 .90246 L
.7073 .90171 L
Mistroke
.70953 .9009 L
.7117 .90002 L
.71374 .89901 L
.71583 .89798 L
.71777 .89688 L
.71976 .89569 L
.72175 .8944 L
.72368 .89309 L
.72555 .89181 L
.7274 .89047 L
.729 .88915 L
.73055 .88795 L
.73198 .88685 L
.73318 .88588 L
.73425 .88506 L
.73508 .88437 L
.73573 .8838 L
.73617 .88336 L
.73642 .88307 L
.73649 .88291 L
.73646 .88285 L
.73639 .88285 L
.73636 .88287 L
.73643 .88287 L
.73664 .8828 L
.73702 .88263 L
.73759 .8823 L
.73836 .8818 L
.73934 .88115 L
.74054 .88035 L
.74187 .87945 L
.74344 .87841 L
.7451 .87724 L
.74698 .87595 L
.74902 .87458 L
.7512 .87311 L
.75343 .87161 L
.75574 .87015 L
.75809 .86864 L
.76049 .86708 L
.76279 .86558 L
.76513 .86406 L
.76759 .86244 L
.76985 .86081 L
.77224 .85909 L
.77472 .85739 L
.77708 .8557 L
.77952 .85393 L
.78198 .85221 L
.78445 .8505 L
Mistroke
.78698 .84875 L
.78942 .84707 L
.79189 .84548 L
.79444 .84385 L
.7968 .84231 L
.79926 .84074 L
.80188 .83919 L
.80408 .83771 L
.80644 .83617 L
.8087 .83459 L
.81096 .83303 L
.8133 .83142 L
.8156 .82969 L
.81787 .82799 L
.8206 .82614 L
.82285 .82439 L
.82532 .82252 L
.82797 .82063 L
.83092 .81881 L
.83335 .81696 L
.83615 .81519 L
.83912 .81337 L
.84167 .81176 L
.8444 .81012 L
.84709 .80847 L
.84985 .80681 L
.85219 .80516 L
.85457 .80338 L
.85679 .80155 L
.8589 .79958 L
.86074 .79773 L
.86251 .79569 L
.86415 .79361 L
.86566 .79144 L
.86711 .78919 L
.86848 .78684 L
.86977 .78431 L
.87102 .78213 L
.87219 .7798 L
.87331 .77751 L
.87434 .77519 L
.87529 .77322 L
.87617 .77112 L
.87703 .76908 L
.87782 .7672 L
.87866 .76525 L
.87946 .76323 L
.8803 .76117 L
.88119 .75886 L
.88213 .75655 L
Mistroke
.883 .75407 L
.88399 .75136 L
.88488 .74876 L
.88579 .74596 L
.88672 .74315 L
.88752 .74036 L
.88834 .73795 L
.88901 .73573 L
.88958 .73379 L
.89002 .73243 L
.89033 .73142 L
.8905 .73079 L
.89054 .73049 L
.8905 .73051 L
.89042 .73078 L
.89031 .73121 L
.8902 .73169 L
.89011 .73214 L
.89004 .7325 L
.89 .73266 L
.89 .73254 L
.89007 .73205 L
.89022 .7312 L
.89047 .73006 L
.89083 .72865 L
.89131 .72699 L
.89188 .72514 L
.89257 .72308 L
.89337 .72111 L
.89418 .71892 L
.8951 .71666 L
.89601 .71435 L
.89699 .7119 L
.89794 .70928 L
.89894 .70686 L
.89989 .70422 L
.90087 .70154 L
.90183 .6989 L
.90278 .6961 L
.90374 .69348 L
.90459 .69063 L
.90541 .68805 L
.90618 .68529 L
.90692 .68268 L
.90757 .67986 L
.90823 .67747 L
.9088 .67501 L
.90934 .6726 L
.90987 .67025 L
.91041 .66795 L
Mistroke
.91096 .66556 L
.91155 .66334 L
.91214 .66098 L
.91283 .65859 L
.91356 .65613 L
.9144 .65363 L
.91524 .65095 L
.91617 .64838 L
.91711 .64563 L
.91809 .64279 L
.91899 .63995 L
.91991 .63709 L
.9208 .63418 L
.92166 .63116 L
.92255 .62805 L
.92342 .62488 L
.92434 .62156 L
.92526 .61822 L
.92623 .61461 L
.92715 .61137 L
.92807 .60812 L
.92889 .60494 L
.92973 .60215 L
.93041 .59957 L
.93109 .5971 L
.9316 .59527 L
.93202 .59372 L
.93236 .59245 L
.93261 .59151 L
.93277 .59087 L
.93286 .59052 L
.93288 .59041 L
.93286 .59046 L
.93282 .5906 L
.93276 .5908 L
.93271 .59101 L
.93267 .59116 L
.93265 .59123 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
Mistroke
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59125 L
.93265 .59127 L
.93267 .59133 L
.93269 .59142 L
.93271 .59154 L
.93271 .59166 L
.93268 .59177 L
.93265 .59184 L
.9326 .59181 L
.93253 .59164 L
.93246 .59128 L
.93239 .5907 L
.93233 .58988 L
.93228 .58881 L
.93221 .58753 L
.93215 .58593 L
.93207 .58405 L
.93198 .58185 L
.93189 .57941 L
.93182 .57664 L
.93178 .57387 L
.93176 .57082 L
.93178 .56767 L
.93185 .56449 L
.93197 .56116 L
.93213 .55763 L
.93234 .5544 L
Mistroke
.9326 .55068 L
.9329 .54726 L
.93328 .54338 L
.93374 .53986 L
.93425 .53614 L
.93476 .53224 L
.9353 .52861 L
.93583 .52486 L
.93629 .52109 L
.93672 .51712 L
.93709 .51348 L
.93739 .50964 L
.93762 .50579 L
.93779 .50185 L
.93788 .49828 L
.9379 .4946 L
.93783 .49078 L
.93767 .4873 L
.93745 .4837 L
.93717 .48012 L
.93684 .47636 L
.93649 .47309 L
.93612 .46962 L
.93577 .46617 L
.93544 .46262 L
.93512 .45939 L
.93481 .45602 L
.93453 .45262 L
.93428 .44931 L
.93407 .4459 L
.9339 .4425 L
.93378 .43925 L
.93367 .43595 L
.93358 .43238 L
.9335 .42916 L
.9334 .42554 L
.93329 .42198 L
.93317 .41882 L
.93306 .41547 L
.93295 .41236 L
.93285 .40946 L
.93276 .40698 L
.93268 .40467 L
.93261 .40295 L
.93255 .40138 L
.93252 .40028 L
.93249 .39948 L
.93248 .399 L
.9325 .39887 L
.93254 .39902 L
Mistroke
.93258 .39934 L
.93261 .39972 L
.93262 .40008 L
.93259 .40035 L
.93251 .40045 L
.93239 .40036 L
.93223 .40008 L
.93204 .39966 L
.93181 .39917 L
.93158 .39867 L
.93136 .3982 L
.93115 .39777 L
.93093 .39739 L
.93073 .39706 L
.93056 .39678 L
.93041 .39654 L
.93031 .39632 L
.93025 .39612 L
.93023 .39591 L
.93023 .39565 L
.93025 .39533 L
.93027 .39494 L
.93028 .3945 L
.93028 .39404 L
.93026 .39362 L
.93026 .39323 L
.93027 .39291 L
.9303 .39269 L
.93033 .39261 L
.93034 .39269 L
.93034 .39294 L
.93031 .39339 L
.93024 .39399 L
.93015 .39472 L
.93001 .39554 L
.92983 .3964 L
.92962 .39724 L
.9294 .398 L
.9292 .39866 L
.92902 .39922 L
.92887 .3997 L
.92877 .40008 L
.92873 .40036 L
.92876 .40057 L
.92886 .4007 L
.92901 .40078 L
.92921 .4008 L
.92946 .40077 L
.9297 .4007 L
.92993 .40062 L
Mistroke
.93015 .40056 L
.93033 .40053 L
.93046 .40053 L
.93055 .40052 L
.93059 .40047 L
.93058 .40036 L
.93053 .4002 L
.93046 .40004 L
.93041 .39991 L
.93039 .39986 L
.93042 .39992 L
.93051 .40014 L
.93064 .40058 L
.93082 .40126 L
.93103 .40222 L
.93128 .40346 L
.93154 .405 L
.93181 .40662 L
.93209 .40859 L
.93237 .41062 L
.93263 .41285 L
.93287 .41516 L
.93308 .41741 L
.93326 .41975 L
.93339 .42198 L
.93348 .4242 L
.93354 .42626 L
.93359 .42825 L
.93362 .43014 L
.93365 .43175 L
.9337 .43328 L
.93374 .43464 L
.93378 .4358 L
.93382 .43685 L
.93385 .43759 L
.93387 .43826 L
.9339 .43877 L
.93393 .43914 L
.93397 .43941 L
.93399 .43963 L
.93399 .43995 L
.93397 .44049 L
.93393 .44137 L
.93389 .44259 L
.93387 .44417 L
.93388 .44623 L
.9339 .44878 L
.93394 .4513 L
.93397 .45421 L
.934 .45746 L
Mistroke
.93401 .46059 L
.93401 .46402 L
.93401 .46767 L
.93402 .47099 L
.93404 .47451 L
.93406 .47803 L
.9341 .48155 L
.93413 .48519 L
.93415 .48881 L
.93413 .49259 L
.93408 .49658 L
.93398 .50073 L
.93384 .50493 L
.93364 .50929 L
.93341 .51394 L
.93314 .51815 L
.93281 .52249 L
.93243 .52689 L
.93198 .53068 L
.9315 .53455 L
.93096 .53829 L
.93039 .54188 L
.92979 .54495 L
.92917 .54806 L
.92852 .55109 L
.92783 .55405 L
.92709 .55713 L
.92631 .56043 L
.92552 .56386 L
.92469 .56765 L
.9239 .57154 L
.92311 .57561 L
.92236 .57991 L
.92162 .58465 L
.92092 .58927 L
.92025 .59437 L
.9197 .59906 L
.91923 .60419 L
.91884 .6089 L
.91853 .61362 L
.91827 .61839 L
.91804 .62245 L
.91781 .62654 L
.91752 .63062 L
.91716 .63398 L
.9167 .63758 L
.91608 .6409 L
.91527 .64438 L
.91438 .64755 L
.91327 .65092 L
Mistroke
.91202 .65422 L
.91063 .65748 L
.90907 .66103 L
.90768 .6644 L
.90601 .6682 L
.90454 .67198 L
.90294 .67603 L
.90136 .68029 L
.89987 .68452 L
.89847 .68891 L
.89716 .69317 L
.89599 .69749 L
.89495 .70183 L
.89406 .70583 L
.89329 .70979 L
.89259 .71371 L
.89194 .7172 L
.89126 .72068 L
.89054 .7241 L
.88979 .727 L
.88902 .72983 L
.8882 .73243 L
.88727 .73489 L
.88617 .73733 L
.88491 .73962 L
.88339 .7419 L
.8816 .74436 L
.87959 .74694 L
.87735 .74961 L
.87498 .75241 L
.87242 .75539 L
.86996 .7581 L
.86737 .7611 L
.86449 .7644 L
.8619 .76731 L
.85917 .77039 L
.85634 .77354 L
.85354 .77664 L
.85068 .77971 L
.84821 .7823 L
.84569 .78474 L
.84331 .78686 L
.84097 .78876 L
.83883 .79025 L
.83658 .79146 L
.83446 .79234 L
.83231 .7928 L
.83019 .79288 L
.82829 .79265 L
.82645 .79222 L
Mistroke
.82466 .79167 L
.82295 .79115 L
.82127 .79076 L
.81953 .79061 L
.81771 .79075 L
.81595 .79123 L
.81408 .79208 L
.8121 .79331 L
.81011 .79484 L
.80798 .79673 L
.80567 .79902 L
.80342 .80156 L
.80088 .80445 L
.79832 .80735 L
.79554 .81049 L
.79291 .81348 L
.79 .81663 L
.78741 .81959 L
.78479 .82273 L
.78229 .82577 L
.77991 .82897 L
.77782 .83197 L
.77585 .83514 L
.77407 .83817 L
.77244 .84124 L
.77085 .84447 L
.76929 .84733 L
.76768 .85064 L
.76601 .85344 L
.76417 .85631 L
.76214 .85921 L
.76011 .86182 L
.75786 .86427 L
.75529 .86659 L
.75272 .86864 L
.74964 .87066 L
.7467 .87245 L
.74341 .8742 L
.73994 .87596 L
.7363 .87778 L
.73274 .87961 L
.72899 .88157 L
.72534 .88351 L
.72171 .88562 L
.71791 .88783 L
.71384 .89019 L
.71022 .89261 L
.70611 .89524 L
.70216 .89783 L
.69807 .9005 L
Mistroke
.69382 .90302 L
.69001 .90547 L
.6861 .90779 L
.68192 .90995 L
.67845 .91188 L
.6747 .91362 L
.67107 .91507 L
.66725 .91623 L
.66399 .91708 L
.6606 .91764 L
.65749 .91795 L
.65423 .91803 L
.65137 .91795 L
.64839 .91774 L
.6454 .91744 L
.64273 .91709 L
.63991 .91671 L
.637 .91637 L
.63428 .9161 L
.63139 .91597 L
.62865 .91598 L
.62595 .91615 L
.62321 .91645 L
.6208 .91687 L
.6184 .91739 L
.61598 .91801 L
.61381 .91875 L
.61156 .91962 L
.60921 .92065 L
.60711 .9218 L
.60498 .92313 L
.6028 .92462 L
.60072 .92616 L
.59849 .92779 L
.59612 .92943 L
.59396 .93084 L
.59123 .93241 L
.58879 .93372 L
.58608 .93496 L
.58297 .9361 L
.57996 .9371 L
.57669 .93791 L
.57346 .93848 L
.56993 .93881 L
.56664 .9389 L
.56291 .93878 L
.5594 .93847 L
.5554 .93802 L
.55175 .93748 L
.54782 .93691 L
Mistroke
.54381 .93628 L
.54013 .93562 L
.53628 .93488 L
.53284 .93407 L
.52914 .93322 L
.52592 .93229 L
.52295 .93137 L
.51995 .93043 L
.51725 .92944 L
.51479 .9284 L
.51246 .9273 L
.51044 .92623 L
.50857 .92491 L
.50689 .92359 L
.50533 .92216 L
.50387 .9206 L
.50248 .91894 L
.50108 .91713 L
.49972 .9154 L
.49838 .91344 L
.49707 .91158 L
.49575 .90958 L
.4944 .9075 L
.49298 .90532 L
.49147 .90311 L
.48982 .90073 L
.48812 .89854 L
.48631 .89609 L
.48447 .89396 L
.48257 .89175 L
.48077 .88956 L
.47901 .88755 L
.47744 .88566 L
.47605 .88391 L
.47478 .88238 L
.47373 .88097 L
.47287 .87955 L
.4722 .87826 L
.47174 .87693 L
.47148 .87551 L
.47137 .87396 L
.47138 .8723 L
.47145 .87058 L
.47152 .86916 L
.47155 .86753 L
.47152 .86587 L
.47147 .86427 L
.47146 .86246 L
.47152 .86082 L
.47171 .85908 L
Mistroke
.47207 .85745 L
.47261 .85582 L
.47333 .85425 L
.47426 .85281 L
.47535 .85162 L
.47665 .85037 L
.47817 .84913 L
.47986 .84796 L
.4817 .84677 L
.48366 .84555 L
.48569 .84439 L
.48771 .84329 L
.48967 .84228 L
.49155 .84139 L
.49331 .84064 L
.4949 .84003 L
.49633 .83949 L
.4977 .83901 L
.4989 .83858 L
.49999 .8382 L
.50095 .83789 L
.50177 .83765 L
.50247 .83747 L
.50308 .83733 L
.5036 .83726 L
.50409 .83726 L
.50459 .83732 L
.50514 .83742 L
.50578 .83756 L
.50651 .83775 L
.50734 .83798 L
.5083 .83823 L
.50935 .83852 L
.51056 .83885 L
.51188 .83922 L
.51339 .83964 L
.51504 .84016 L
.51686 .84076 L
.51884 .84148 L
.52097 .84229 L
.5232 .84321 L
.52546 .84419 L
.52774 .84529 L
.53002 .84645 L
.53212 .8477 L
.53414 .8491 L
.53596 .85062 L
.53755 .8523 L
.53883 .854 L
.53986 .85584 L
Mistroke
.54055 .85768 L
.54098 .85947 L
.54116 .86129 L
.5411 .86311 L
.54079 .86468 L
.54029 .86619 L
.53962 .86759 L
.53879 .86883 L
.53792 .8698 L
.53696 .87057 L
.5359 .87109 L
.53473 .87136 L
.53343 .87144 L
.53211 .87137 L
.53072 .87115 L
.52903 .87075 L
.52732 .87024 L
.52529 .86961 L
.52293 .86884 L
.52081 .8679 L
.51834 .86678 L
.51547 .86551 L
.51302 .86398 L
.51013 .86219 L
.50722 .86045 L
.50434 .85841 L
.50142 .85622 L
.4985 .85388 L
.49566 .85139 L
.49285 .84871 L
.49031 .84615 L
.48808 .84367 L
.48582 .84103 L
.48375 .83852 L
.48183 .83583 L
.48031 .83339 L
.47893 .83082 L
.47779 .8282 L
.47687 .82547 L
.47617 .82281 L
.47572 .82008 L
.47551 .81728 L
.47553 .81459 L
.47579 .81186 L
.47632 .80925 L
.4771 .80674 L
.47812 .80437 L
.47934 .80213 L
.48077 .79997 L
.48233 .79802 L
Mistroke
.48406 .79611 L
.48596 .79438 L
.48804 .79269 L
.49024 .79119 L
.49261 .78974 L
.49517 .78838 L
.49776 .78714 L
.50053 .7861 L
.50337 .7852 L
.50627 .7845 L
.5094 .784 L
.51245 .78374 L
.51558 .78373 L
.51893 .78399 L
.52198 .78451 L
.52519 .78531 L
.52831 .78632 L
.53151 .78754 L
.53448 .78898 L
.53738 .79054 L
.54043 .79224 L
.54304 .79399 L
.54577 .79592 L
.54844 .79775 L
.55104 .79977 L
.55366 .80157 L
.55601 .80344 L
.55847 .80534 L
.56066 .80732 L
.56296 .80917 L
.56515 .81125 L
.56738 .81314 L
.56961 .8152 L
.57186 .81727 L
.5741 .81947 L
.57642 .82154 L
.57871 .8234 L
.58108 .82529 L
.58353 .8272 L
.58611 .82894 L
.5887 .83052 L
.59146 .83209 L
.59452 .83363 L
.59738 .83503 L
.60058 .8364 L
.60393 .83773 L
.60735 .83909 L
.61121 .84049 L
.61462 .84182 L
.61831 .84332 L
Mistroke
.62167 .84475 L
.62507 .84631 L
.62864 .84798 L
.63217 .8498 L
.63511 .85161 L
.63832 .8536 L
.64117 .85572 L
.64395 .85783 L
.64667 .86027 L
.64931 .86272 L
.65199 .86557 L
.65477 .86843 L
.65742 .87124 L
.66032 .87431 L
.66331 .87739 L
.66662 .88062 L
.66941 .88355 L
.67257 .88659 L
.67584 .88953 L
.67883 .89201 L
.682 .89442 L
.68506 .89662 L
.68816 .89838 L
.69103 .89986 L
.69392 .90095 L
.69672 .90166 L
.69955 .90204 L
.70223 .9021 L
.70472 .90195 L
.7072 .90158 L
.70956 .90107 L
.71177 .90046 L
.71375 .89975 L
.71551 .89901 L
.71694 .89823 L
.71813 .89743 L
.71904 .89666 L
.7197 .89594 L
.72014 .89529 L
.72038 .89469 L
.72047 .89414 L
.72046 .89366 L
.72038 .89325 L
.72026 .89287 L
.72012 .89249 L
.72002 .89211 L
.71998 .89176 L
.71998 .89149 L
.72 .89132 L
.72 .89125 L
Mistroke
.71998 .89126 L
.71996 .89131 L
.71997 .89137 L
.72005 .89139 L
.72023 .89133 L
.72051 .89119 L
.72092 .89098 L
.72143 .89072 L
.72201 .89043 L
.72261 .89013 L
.72318 .88983 L
.72374 .88953 L
.72427 .88925 L
.72473 .88899 L
.72512 .88876 L
.72543 .88858 L
.72564 .88846 L
.72573 .8884 L
.72569 .88838 L
.72555 .88841 L
.72535 .88847 L
.72513 .88853 L
.72494 .88858 L
.7248 .88861 L
.72473 .88862 L
.72473 .88862 L
.72476 .88862 L
.7248 .88861 L
.72483 .88861 L
.72484 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72486 .88861 L
.72487 .8886 L
.72488 .8886 L
.72488 .8886 L
.72486 .88861 L
.72484 .88861 L
.7248 .88861 L
.72477 .88862 L
.72473 .88862 L
.7247 .88862 L
.72467 .88863 L
.72465 .88863 L
Mistroke
.72464 .88863 L
.72464 .88863 L
.72464 .88863 L
.72465 .88863 L
.72466 .88863 L
.72469 .88862 L
.72472 .88862 L
.72477 .88859 L
.72484 .88851 L
.72491 .8884 L
.72498 .8883 L
.72501 .88825 L
.725 .88829 L
.72494 .88843 L
.72484 .8887 L
.72469 .88912 L
.72452 .88968 L
.72432 .89033 L
.72409 .89104 L
.72385 .89178 L
.72361 .8925 L
.72336 .89322 L
.7231 .89396 L
.72284 .89469 L
.7226 .89535 L
.7224 .89587 L
.72227 .89618 L
.72225 .89626 L
.72234 .89613 L
.72254 .89581 L
.72284 .89536 L
.72321 .89481 L
.72364 .89423 L
.72409 .89366 L
.72455 .89312 L
.72503 .8926 L
.7255 .8921 L
.72595 .89165 L
.72636 .89127 L
.72671 .89096 L
.72699 .89075 L
.72717 .89061 L
.72726 .89051 L
.72728 .89045 L
.72729 .89038 L
.72731 .89028 L
.72736 .89012 L
.72744 .88991 L
.72755 .88965 L
.72764 .8894 L
Mistroke
.72768 .88915 L
.72764 .88892 L
.72754 .88871 L
.72737 .88854 L
.72715 .88841 L
.72689 .88833 L
.72664 .88829 L
.72639 .88824 L
.72614 .88818 L
.72588 .88814 L
.72559 .88816 L
.72527 .88826 L
.72493 .88844 L
.72458 .88873 L
.72423 .88916 L
.72389 .88973 L
.72356 .89039 L
.72324 .89111 L
.72294 .89184 L
.72265 .89255 L
.72231 .89323 L
.72191 .89392 L
.72148 .89458 L
.72101 .89516 L
.72049 .89561 L
.71991 .89594 L
.71925 .89617 L
.71854 .89635 L
.71779 .89652 L
.71698 .89671 L
.71615 .89699 L
.71521 .89736 L
.71418 .89784 L
.71308 .89839 L
.71193 .899 L
.7108 .89963 L
.70967 .90032 L
.7085 .90109 L
.70723 .90195 L
.70582 .90289 L
.70424 .90393 L
.70243 .90509 L
.7003 .90642 L
.69782 .90791 L
.69522 .90939 L
.69237 .91103 L
.68919 .91286 L
.68604 .91462 L
.68245 .91651 L
.67927 .91819 L
Mistroke
.67596 .91983 L
.67259 .92135 L
.66937 .92262 L
.66606 .92376 L
.66289 .92473 L
.65974 .92551 L
.65643 .92609 L
.65322 .92651 L
.64974 .92677 L
.64625 .92691 L
.6424 .92694 L
.63848 .9269 L
.63432 .92678 L
.62992 .92663 L
.62548 .92649 L
.62071 .92636 L
.61601 .9262 L
.61112 .92601 L
.60595 .9258 L
.60114 .92558 L
.59569 .92538 L
.59118 .92521 L
.58632 .92505 L
.58164 .92487 L
.57689 .92466 L
.57232 .92437 L
.56784 .92396 L
.56328 .92341 L
.55862 .92269 L
.55461 .92179 L
.55039 .92074 L
.54627 .91965 L
.54203 .9184 L
.53835 .91703 L
.53459 .91546 L
.53066 .91394 L
.52723 .91219 L
.52361 .91029 L
.51968 .9083 L
.5161 .90617 L
.51217 .90378 L
.50807 .90152 L
.50401 .89901 L
.4995 .89638 L
.49564 .89358 L
.49148 .89074 L
.48665 .88768 L
.48267 .88475 L
.47836 .88172 L
.47399 .87859 L
Mistroke
.46979 .87545 L
.46607 .87271 L
.46224 .8698 L
.45863 .86683 L
.45492 .86405 L
.4515 .86118 L
.44794 .85837 L
.44424 .85552 L
.44027 .85266 L
.43675 .85047 L
.43294 .8482 L
.42864 .84598 L
.42496 .84424 L
.42099 .84263 L
.41692 .84122 L
.41276 .84021 L
.40892 .83946 L
.4051 .839 L
.40127 .83879 L
.39756 .83881 L
.39373 .83902 L
.38996 .83936 L
.38589 .83974 L
.38184 .84011 L
.37764 .84042 L
.37316 .84063 L
.36902 .8407 L
.36461 .84058 L
.36031 .84023 L
.35576 .83965 L
.35143 .83882 L
.34699 .83772 L
.34245 .83639 L
.33849 .8348 L
.33435 .83287 L
.33052 .83083 L
.32668 .82845 L
.32289 .82579 L
.31918 .82305 L
.31555 .82011 L
.31199 .8171 L
.30841 .81395 L
.30489 .81103 L
.30161 .80808 L
.29801 .80495 L
.29497 .80234 L
.29181 .79963 L
.2885 .79686 L
.28541 .7944 L
.28202 .79185 L
Mistroke
.27868 .7894 L
.27523 .78699 L
.27148 .78458 L
.26815 .78248 L
.26446 .78034 L
.2607 .77827 L
.25682 .7763 L
.25272 .77436 L
.24907 .7726 L
.245 .77087 L
.24145 .76934 L
.23765 .76785 L
.23416 .76636 L
.23066 .76489 L
.22728 .76335 L
.22406 .76181 L
.22091 .76008 L
.21769 .75815 L
.21486 .7562 L
.21198 .75401 L
.2093 .75155 L
.20681 .74902 L
.20441 .74619 L
.20217 .74327 L
.20007 .74017 L
.1981 .73706 L
.19626 .73378 L
.19446 .73047 L
.19273 .7269 L
.19102 .72343 L
.18933 .7197 L
.18755 .71583 L
.18567 .71217 L
.18366 .70827 L
.18158 .70434 L
.17946 .70013 L
.17735 .69675 L
.17525 .69314 L
.17315 .6893 L
.17117 .68638 L
.16925 .68356 L
.16742 .68096 L
.16564 .67869 L
.16394 .67682 L
.16218 .67525 L
.16038 .67398 L
.15853 .67294 L
.15658 .67203 L
.15465 .67119 L
.15263 .67035 L
Mistroke
.15046 .66948 L
.14815 .66854 L
.14596 .66756 L
.14343 .66645 L
.14102 .66523 L
.13842 .6638 L
.13572 .66215 L
.13303 .66041 L
.13018 .65847 L
.12749 .65647 L
.12469 .65447 L
.12176 .65246 L
.11913 .65062 L
.11636 .64892 L
.1138 .64721 L
.11145 .64578 L
.10918 .64445 L
.10712 .64329 L
.10545 .64233 L
.10409 .6416 L
.10303 .6411 L
.10227 .6408 L
.10177 .64069 L
.1015 .64073 L
.10141 .64087 L
.10142 .64104 L
.10148 .64116 L
.10159 .64119 L
.10173 .64113 L
.10184 .64097 L
.10188 .64071 L
.10178 .64035 L
.10156 .63992 L
.10124 .63945 L
.10086 .63895 L
.1004 .63845 L
.09984 .63796 L
.09916 .63749 L
.09836 .63706 L
.09743 .63668 L
.0964 .6364 L
.09528 .63621 L
.09408 .63613 L
.09282 .63613 L
.09152 .6362 L
.09024 .63632 L
.08903 .63645 L
.08789 .63655 L
.08681 .63662 L
.08583 .63666 L
Mistroke
.08497 .63669 L
.08426 .63671 L
.08369 .63673 L
.08325 .63675 L
.08295 .63676 L
.08279 .63676 L
.08273 .63676 L
.08274 .63676 L
.08278 .63676 L
.08281 .63676 L
.08284 .63676 L
.08288 .63676 L
.08292 .63676 L
.08296 .63676 L
.08298 .63676 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08299 .63675 L
.083 .63671 L
.08304 .63662 L
.08309 .6365 L
.08313 .63639 L
.08315 .63631 L
.08314 .63629 L
.08308 .63638 L
.08296 .63661 L
.08279 .637 L
.08256 .63755 L
.0823 .63825 L
.082 .63909 L
.08168 .64008 L
.08133 .64117 L
.08096 .64238 L
.0806 .64371 L
.08028 .64515 L
.08004 .64663 L
.07988 .64805 L
.07982 .64945 L
.07987 .65077 L
.08002 .65199 L
.08025 .65314 L
.08052 .65423 L
Mistroke
.08081 .65535 L
.08109 .65655 L
.08135 .65786 L
.08159 .65929 L
.0818 .66066 L
.08197 .66211 L
.0821 .6636 L
.08219 .66511 L
.08222 .66656 L
.0822 .66786 L
.08214 .66918 L
.08206 .67058 L
.08197 .67199 L
.0819 .67331 L
.08183 .67456 L
.08177 .67576 L
.0817 .67692 L
.08163 .67795 L
.08158 .67893 L
.08156 .67985 L
.0816 .68077 L
.08168 .68164 L
.08181 .68241 L
.08199 .68306 L
.0822 .68358 L
.08242 .68395 L
.08265 .68418 L
.08289 .68429 L
.08316 .68431 L
.08345 .68429 L
.08376 .68427 L
.08409 .68426 L
.08443 .68429 L
.08476 .68437 L
.08508 .68447 L
.08537 .68456 L
.08564 .68467 L
.08587 .68486 L
.0861 .68515 L
.08632 .68555 L
.08654 .68606 L
.08673 .6867 L
.08688 .68746 L
.08698 .68836 L
.08702 .6894 L
.08701 .69057 L
.08696 .69181 L
.08688 .69305 L
.0868 .69435 L
.08672 .69577 L
Mistroke
.08667 .6973 L
.08662 .69882 L
.08659 .70022 L
.08656 .70134 L
.08654 .70228 L
.08652 .70301 L
.08651 .70353 L
.0865 .70383 L
.0865 .7039 L
.0865 .70374 L
.08651 .7034 L
.08652 .70296 L
.08653 .70241 L
.08655 .70179 L
.08657 .70113 L
.08658 .70048 L
.0866 .69988 L
.08661 .69931 L
.08663 .69879 L
.08666 .69835 L
.0867 .69801 L
.08675 .69778 L
.08679 .69761 L
.08682 .69746 L
.08681 .69729 L
.08676 .69708 L
.08666 .6968 L
.08653 .69646 L
.08637 .69605 L
.08619 .6956 L
.08598 .69509 L
.08573 .69449 L
.08545 .69379 L
.08512 .69299 L
.08476 .69207 L
.08438 .69103 L
.08398 .68988 L
.08359 .68867 L
.08323 .68742 L
.08291 .68607 L
.08265 .68463 L
.08244 .68309 L
.08228 .68143 L
.08217 .67977 L
.08208 .67795 L
.082 .67597 L
.08193 .67415 L
.08187 .67217 L
.08181 .67 L
.08173 .66799 L
Mistroke
.08165 .66581 L
.08156 .66355 L
.08144 .66135 L
.08128 .65907 L
.08108 .65703 L
.08084 .65498 L
.08056 .65302 L
.08025 .6512 L
.07992 .64951 L
.07958 .64779 L
.07925 .64629 L
.07894 .64485 L
.07864 .64349 L
.07837 .64225 L
.07812 .64104 L
.07791 .63985 L
.07776 .63869 L
.07769 .6375 L
.07771 .63625 L
.07784 .63492 L
.07806 .63361 L
.07835 .63225 L
.07868 .63083 L
.079 .62945 L
.07927 .62794 L
.07944 .62655 L
.0795 .62509 L
.07942 .62353 L
.07921 .6219 L
.07889 .62035 L
.07844 .61871 L
.07786 .61711 L
.07718 .61548 L
.07644 .6139 L
.07566 .61235 L
.07485 .61068 L
.07411 .60914 L
.07343 .60751 L
.07283 .60582 L
.07231 .60411 L
.07188 .60231 L
.07154 .60058 L
.07129 .59871 L
.07113 .59675 L
.07105 .59499 L
.07101 .59312 L
.07099 .59112 L
.07096 .58934 L
.07092 .58748 L
.07088 .58559 L
Mistroke
.07083 .58392 L
.07076 .58225 L
.07066 .58066 L
.07052 .57909 L
.07034 .57748 L
.0701 .57597 L
.06982 .57432 L
.0695 .57252 L
.06917 .57075 L
.06883 .56882 L
.06848 .56681 L
.06813 .56462 L
.06778 .56265 L
.06745 .56041 L
.06711 .55823 L
.06677 .55617 L
.06642 .55397 L
.06605 .55189 L
.06572 .54983 L
.06539 .54778 L
.06512 .54609 L
.0649 .54435 L
.06472 .54298 L
.0646 .54175 L
.0645 .54068 L
.06444 .5398 L
.06439 .53911 L
.06437 .53862 L
.06437 .53832 L
.06439 .53817 L
.06442 .53813 L
.06445 .53816 L
.06448 .53824 L
.06449 .53831 L
.06449 .53837 L
.06449 .53842 L
.06449 .53849 L
.06449 .53858 L
.06448 .53867 L
.06448 .53874 L
.06448 .53878 L
.06448 .53875 L
.06448 .53865 L
.06449 .53846 L
.0645 .53817 L
.06451 .5378 L
.06453 .53736 L
.06455 .53688 L
.06456 .53637 L
.06458 .53587 L
Mistroke
.0646 .53538 L
.06462 .53489 L
.06463 .53443 L
.06465 .53406 L
.06466 .53379 L
.06466 .53365 L
.06466 .5336 L
.06466 .5336 L
.06467 .53362 L
.06469 .53362 L
.06471 .53354 L
.06472 .53335 L
.06472 .53302 L
.0647 .53257 L
.06467 .53203 L
.06464 .53141 L
.06461 .53077 L
.06458 .53009 L
.06456 .5294 L
.06456 .52871 L
.06456 .52806 L
.06458 .52749 L
.06459 .52702 L
.06461 .52665 L
.06463 .52638 L
.06466 .52621 L
.06471 .52612 L
.06476 .52609 L
.06482 .52608 L
.06488 .52609 L
.06492 .52612 L
.06496 .52615 L
.06498 .52619 L
.06497 .52623 L
.06495 .52624 L
.06493 .52624 L
.06494 .52623 L
.06497 .5262 L
.06504 .52616 L
.06512 .52614 L
.06516 .52615 L
.06513 .5262 L
.06502 .52629 L
.06481 .52641 L
.0645 .52656 L
.06411 .52673 L
.06367 .52693 L
.06324 .52715 L
.06285 .52735 L
.06252 .52751 L
Mistroke
.06226 .52759 L
.06202 .52755 L
.0618 .52735 L
.06159 .52697 L
.06141 .52636 L
.06136 .52553 L
.0614 .52446 L
.0615 .52317 L
.06165 .52186 L
.06182 .52035 L
.062 .51877 L
.06212 .51732 L
.06218 .51586 L
.06219 .51454 L
.0622 .51325 L
.0622 .51203 L
.06225 .51099 L
.06233 .51005 L
.06244 .50924 L
.06257 .50853 L
.0627 .5079 L
.06281 .50731 L
.0629 .50674 L
.06297 .50622 L
.063 .5057 L
.063 .50521 L
.06298 .50475 L
.06297 .50429 L
.06298 .50382 L
.063 .50335 L
.06301 .50289 L
.06303 .50243 L
.06305 .50197 L
.06306 .50151 L
.06308 .50104 L
.0631 .50054 L
.06312 .49998 L
.06314 .49937 L
.06316 .49874 L
.06318 .49809 L
.06321 .49742 L
.06323 .49674 L
.06325 .49606 L
.06327 .49538 L
.06327 .49473 L
.06328 .49415 L
.06329 .49363 L
.06332 .49315 L
.06337 .49267 L
.06342 .49217 L
Mistroke
.06349 .49165 L
.06356 .49114 L
.06361 .49065 L
.06363 .49015 L
.06363 .4896 L
.06362 .48902 L
.06363 .48836 L
.06367 .4876 L
.06375 .4868 L
.06388 .48598 L
.06403 .48513 L
.06421 .48427 L
.0644 .48339 L
.06461 .48249 L
.06483 .48159 L
.06509 .48064 L
.06539 .47964 L
.06575 .4786 L
.06615 .47759 L
.06659 .4765 L
.06703 .47534 L
.06744 .47415 L
.06782 .4729 L
.06815 .47157 L
.06842 .47018 L
.06867 .46885 L
.06893 .46749 L
.06921 .46614 L
.06951 .46497 L
.06982 .46388 L
.07014 .46295 L
.07044 .46218 L
.07073 .46153 L
.071 .461 L
.07126 .46059 L
.0715 .46029 L
.07175 .4601 L
.07201 .46002 L
.07226 .46002 L
.07248 .46008 L
.07265 .46017 L
.07276 .46027 L
.07283 .46034 L
.07285 .46037 L
.07283 .46038 L
.07279 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07267 .46038 L
.07264 .46038 L
.0726 .46038 L
.07256 .46038 L
Mistroke
.07254 .46038 L
.07255 .46038 L
.07261 .46038 L
.07272 .46038 L
.07288 .46038 L
.07309 .46037 L
.07333 .46037 L
.0736 .46036 L
.07388 .46036 L
.07416 .46036 L
.07444 .46035 L
.07471 .46035 L
.07497 .46034 L
.07519 .46034 L
.07537 .46034 L
.07549 .46033 L
.07556 .46033 L
.07558 .46033 L
.07556 .46033 L
.07552 .46033 L
.07548 .46033 L
.07544 .46034 L
.07543 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07543 .46033 L
.07544 .4603 L
.07549 .46022 L
.07558 .46011 L
.07566 .46001 L
.07569 .45997 L
.07567 .46001 L
.07556 .46017 L
.07535 .46046 L
.07502 .46091 L
.07458 .46151 L
.07405 .46222 L
.07349 .46301 L
.07291 .46381 L
.07235 .46458 L
.07182 .46533 L
.07128 .46604 L
.07075 .46669 L
.07026 .46719 L
.06987 .46748 L
.0696 .4675 L
.06944 .46725 L
.06937 .46677 L
.06941 .46614 L
.06954 .46542 L
.06973 .46465 L
.06993 .4639 L
.07014 .46315 L
.07034 .46243 L
.07053 .46169 L
.07069 .46095 L
.0708 .46026 L
.07087 .45969 L
.07089 .45927 L
.07089 .45902 L
Mistroke
.07086 .4589 L
.0708 .45881 L
.07071 .45874 L
.07061 .45864 L
.07053 .45853 L
.07048 .45839 L
.07048 .45825 L
.07052 .45813 L
.07061 .45803 L
.07075 .45795 L
.07087 .45789 L
.07101 .45775 L
.07112 .45754 L
.07117 .45728 L
.0712 .45695 L
.07122 .45665 L
.07124 .45643 L
.07125 .45631 L
.07127 .45633 L
.07127 .45647 L
.0713 .45668 L
.07133 .45695 L
.07139 .45724 L
.0715 .45755 L
.07168 .45788 L
.07192 .45829 L
.07219 .45876 L
.07244 .4592 L
.07267 .45966 L
.07291 .46002 L
.07319 .46028 L
.07355 .46042 L
.07406 .46041 L
.07469 .46025 L
.0755 .45994 L
.07651 .45951 L
.07775 .459 L
.07912 .45841 L
.08033 .45777 L
.08179 .4571 L
.08309 .45642 L
.08467 .45573 L
.08603 .45503 L
.08755 .45433 L
.08882 .45363 L
.09005 .45292 L
.09109 .45221 L
.09202 .45148 L
.09284 .45069 L
.09353 .44984 L
Mistroke
.09413 .44886 L
.09469 .4477 L
.09523 .44636 L
.09573 .44492 L
.09619 .44341 L
.0966 .44179 L
.09694 .44019 L
.09725 .43858 L
.09753 .43716 L
.0978 .43583 L
.09804 .43456 L
.09826 .43357 L
.09842 .43272 L
.09852 .43201 L
.09852 .43147 L
.09842 .43108 L
.09821 .43081 L
.09791 .43057 L
.09754 .43032 L
.09711 .43 L
.09663 .42961 L
.09615 .42911 L
.09564 .42856 L
.09512 .42791 L
.09459 .42727 L
.09413 .42658 L
.09372 .42591 L
.09336 .42531 L
.09309 .42479 L
.0929 .42436 L
.09279 .42405 L
.09276 .42384 L
.09278 .42375 L
.09282 .42378 L
.09287 .42391 L
.09291 .4241 L
.09294 .42429 L
.09296 .42443 L
.09294 .42448 L
.09291 .4244 L
.09288 .42417 L
.09285 .42375 L
.09285 .4231 L
.09289 .4222 L
.09299 .42104 L
.09314 .41974 L
.09335 .41815 L
.09361 .41631 L
.09391 .41435 L
.09425 .41213 L
Mistroke
.0946 .40988 L
.09494 .40772 L
.09529 .40535 L
.09563 .4032 L
.09595 .40098 L
.09623 .39878 L
.09646 .39666 L
.09661 .39458 L
.0967 .39245 L
.09674 .3904 L
.09677 .38824 L
.09679 .38614 L
.09683 .38406 L
.09694 .38173 L
.09713 .37959 L
.09741 .37728 L
.09777 .37489 L
.09819 .37249 L
.09865 .37001 L
.09909 .36751 L
.09954 .36487 L
.09997 .36205 L
.10039 .35931 L
.10078 .35644 L
.10111 .3537 L
.10133 .35071 L
.10148 .34832 L
.10157 .34577 L
.10161 .34366 L
.10162 .34164 L
.10162 .33994 L
.10164 .33842 L
.10171 .33731 L
.10187 .33626 L
.10199 .33562 L
.10215 .33523 L
.10234 .33507 L
.10255 .33507 L
.10279 .33518 L
.10301 .33531 L
.1032 .33545 L
.10336 .3356 L
.10352 .33575 L
.10368 .33587 L
.10384 .33596 L
.10395 .33606 L
.104 .33613 L
.10397 .33614 L
.10389 .33607 L
.10373 .33589 L
Mistroke
.10349 .33557 L
.10315 .33509 L
.10269 .33446 L
.10214 .33367 L
.10149 .33274 L
.10084 .33177 L
.10009 .33067 L
.09935 .32958 L
.09861 .32852 L
.0979 .32751 L
.09724 .32659 L
.0967 .32579 L
.09625 .32506 L
.09593 .32443 L
.09571 .32388 L
.0956 .3234 L
.09557 .32297 L
.09558 .32255 L
.0956 .32212 L
.09562 .3217 L
.09563 .32131 L
.09564 .32093 L
.09565 .32053 L
.09565 .32006 L
.09567 .31954 L
.09572 .31895 L
.09581 .31832 L
.09598 .3176 L
.09623 .31677 L
.09659 .31581 L
.09706 .3147 L
.09764 .3134 L
.09833 .31201 L
.09914 .31029 L
.10007 .30852 L
.10104 .30658 L
.1021 .30455 L
.10321 .30252 L
.10433 .30041 L
.10553 .29835 L
.10669 .29638 L
.10793 .29436 L
.10919 .29239 L
.1105 .29042 L
.11183 .28849 L
.11315 .2865 L
.11452 .28459 L
.11577 .28267 L
.11708 .28077 L
.11836 .27888 L
Mistroke
.11973 .27694 L
.1212 .27488 L
.12254 .27286 L
.12396 .2707 L
.12546 .26855 L
.12684 .26635 L
.12837 .26408 L
.12975 .26203 L
.13123 .25991 L
.13302 .25762 L
.13453 .25551 L
.13609 .25327 L
.1378 .25093 L
.13962 .24867 L
.1412 .24637 L
.14272 .2443 L
.14422 .24223 L
.14562 .24018 L
.14704 .23826 L
.14852 .23624 L
.14987 .23429 L
.15129 .23242 L
.15279 .23047 L
.15417 .22842 L
.15561 .22635 L
.15691 .22452 L
.15827 .22263 L
.15972 .22077 L
.16107 .21896 L
.16255 .21709 L
.16393 .21527 L
.16535 .21329 L
.1668 .21144 L
.16812 .20948 L
.16942 .20753 L
.17079 .20547 L
.17215 .20331 L
.17363 .20132 L
.1751 .19916 L
.17668 .19695 L
.17816 .19482 L
.17971 .19276 L
.1811 .19072 L
.18236 .18897 L
.18365 .1874 L
.18474 .18577 L
.18575 .18443 L
.18667 .18318 L
.18747 .18205 L
.18821 .18103 L
Mistroke
.18891 .18006 L
.18959 .17916 L
.19028 .17821 L
.19106 .17726 L
.19198 .17624 L
.19302 .17508 L
.19422 .17372 L
.19561 .17236 L
.1971 .17085 L
.1987 .16918 L
.20048 .16737 L
.20235 .16536 L
.20426 .16345 L
.20621 .16127 L
.20818 .15904 L
.21012 .15657 L
.21197 .15436 L
.21373 .1521 L
.21539 .1498 L
.21684 .14795 L
.21817 .14619 L
.21928 .14462 L
.22024 .14341 L
.22101 .14246 L
.22162 .14179 L
.2221 .14136 L
.22244 .14113 L
.22263 .14106 L
.22267 .1411 L
.22256 .14121 L
.22234 .14132 L
.22199 .14143 L
.22155 .1415 L
.22104 .14155 L
.22049 .14157 L
.21993 .14155 L
.21938 .14154 L
.21885 .14152 L
.21831 .1415 L
.2178 .14148 L
.21733 .14147 L
.21696 .14145 L
.2167 .14145 L
.21658 .14145 L
.21657 .14147 L
.21665 .14153 L
.21681 .14162 L
.21705 .14171 L
.21736 .14178 L
.21776 .14183 L
Mistroke
.21828 .14184 L
.21894 .14177 L
.21975 .1416 L
.22073 .14133 L
.22182 .14092 L
.22307 .14036 L
.22451 .13961 L
.22599 .13872 L
.22771 .13765 L
.22945 .13641 L
.23139 .13505 L
.23338 .13358 L
.23539 .13214 L
.23748 .13078 L
.23931 .12949 L
.24115 .12832 L
.24283 .12731 L
.24458 .12638 L
.24604 .1256 L
.2476 .12489 L
.24902 .12424 L
.2505 .12359 L
.25203 .12291 L
.25353 .12217 L
.25521 .12134 L
.25686 .12047 L
.25874 .11944 L
.2609 .11826 L
.26287 .11698 L
.26508 .11564 L
.26754 .11423 L
.26972 .11282 L
.2721 .1114 L
.27447 .1101 L
.27681 .10881 L
.27909 .10752 L
.28136 .10626 L
.28351 .10501 L
.28582 .10369 L
.28798 .10229 L
.29008 .10091 L
.29251 .09949 L
.29461 .09807 L
.29693 .09663 L
.29924 .09527 L
.30146 .094 L
.30371 .09283 L
.30552 .09185 L
.30734 .09105 L
.30874 .09039 L
Mistroke
.30995 .08988 L
.31096 .08954 L
.31173 .08936 L
.31235 .0893 L
.31282 .08931 L
.31317 .08933 L
.31345 .08935 L
.31371 .08932 L
.31403 .0892 L
.31448 .08897 L
.31513 .0886 L
.31594 .08809 L
.31701 .08746 L
.31834 .08669 L
.31981 .08579 L
.32155 .0848 L
.32344 .08378 L
.32548 .08266 L
.32771 .08144 L
.32982 .08024 L
.33219 .07903 L
.3343 .07777 L
.33657 .07658 L
.33878 .07534 L
.34102 .07414 L
.34318 .07303 L
.34534 .0719 L
.3473 .07077 L
.34928 .06969 L
.35124 .06864 L
.35315 .06757 L
.35516 .06649 L
.35713 .0654 L
.3593 .06429 L
.36145 .06323 L
.36373 .06221 L
.36612 .06117 L
.36854 .06009 L
.37111 .05905 L
.37343 .05805 L
.37595 .05705 L
.37834 .05608 L
.38076 .05518 L
.38328 .05435 L
.38551 .05362 L
.38785 .05301 L
.39009 .05251 L
.39231 .05209 L
.39447 .05178 L
.39663 .05159 L
Mistroke
.39868 .05151 L
.40081 .05152 L
.40276 .05156 L
.40474 .05162 L
.40666 .05164 L
.40849 .0516 L
.41025 .05147 L
.4119 .05124 L
.41341 .05091 L
.4148 .05051 L
.41612 .05008 L
.41734 .04967 L
.41854 .04927 L
.41973 .04887 L
.421 .04849 L
.42234 .04816 L
.42387 .04791 L
.42553 .04777 L
.42737 .04772 L
.42943 .04775 L
.43157 .04785 L
.43392 .04799 L
.43617 .04814 L
.43873 .04828 L
.44119 .04839 L
.44383 .04848 L
.44632 .04856 L
.44865 .04864 L
.45088 .04872 L
.4529 .04878 L
.4547 .04884 L
.45621 .04889 L
.45754 .04893 L
.45855 .04896 L
.45936 .04899 L
.45996 .04901 L
.46035 .04902 L
.46055 .04902 L
.46059 .04902 L
.4605 .04902 L
.46035 .04901 L
.46021 .04901 L
.46016 .04901 L
.46029 .04901 L
.46068 .04902 L
.46135 .04904 L
.4623 .04907 L
.46356 .04911 L
.46496 .04916 L
.46675 .04921 L
Mistroke
.46874 .04928 L
.47098 .04935 L
.47343 .04943 L
.476 .04951 L
.47883 .04959 L
.48156 .04968 L
.48428 .04976 L
.48711 .04985 L
.48992 .04993 L
.49289 .05002 L
.49564 .0501 L
.4986 .05019 L
.50164 .05028 L
.50477 .05036 L
.50776 .05045 L
.51098 .05054 L
.51426 .05063 L
.51749 .05073 L
.52078 .05082 L
.52415 .05091 L
.52757 .051 L
.53068 .05109 L
.53396 .05118 L
.53709 .05127 L
.54029 .05135 L
.54338 .05143 L
.54649 .05151 L
.54942 .05159 L
.55231 .05167 L
.55518 .05174 L
.55789 .05181 L
.56067 .05188 L
.56327 .05195 L
.56591 .05202 L
.56846 .05208 L
.57095 .05215 L
.57342 .05221 L
.57574 .05227 L
.57787 .05233 L
.57989 .05238 L
.58165 .05242 L
.58324 .05246 L
.58461 .05247 L
.58572 .05245 L
.58663 .0524 L
.58733 .05235 L
.5878 .05233 L
.58803 .05232 L
.58804 .05237 L
.5879 .05247 L
Mistroke
.58768 .05264 L
.5875 .05291 L
.58742 .05329 L
.58751 .0538 L
.58781 .05443 L
.58838 .05515 L
.58913 .05592 L
.59014 .05677 L
.59143 .05771 L
.59293 .05871 L
.59475 .05973 L
.59667 .06072 L
.59888 .06173 L
.60137 .06274 L
.60383 .06367 L
.6067 .06456 L
.60936 .0654 L
.61237 .06617 L
.61511 .06684 L
.6182 .0674 L
.62089 .06786 L
.6237 .06827 L
.62617 .06861 L
.62853 .06888 L
.63066 .06908 L
.63247 .06921 L
.63394 .06932 L
.63518 .06941 L
.63614 .0695 L
.6369 .06965 L
.6375 .06985 L
.63799 .07015 L
.63845 .07061 L
.63897 .07119 L
.63962 .07183 L
.6404 .07264 L
.64141 .07361 L
.64265 .07475 L
.64413 .07598 L
.64584 .07739 L
.64772 .07888 L
.64975 .08044 L
.6519 .0822 L
.65416 .08383 L
.6565 .0856 L
.65891 .08739 L
.66138 .08929 L
.6639 .09108 L
.66654 .093 L
.66905 .09481 L
Mistroke
.67168 .09668 L
.67426 .09852 L
.67688 .10052 L
.6796 .10238 L
.68223 .10451 L
.68481 .10643 L
.68762 .1085 L
.69008 .11048 L
.69263 .11244 L
.69518 .11446 L
.69745 .11621 L
.69968 .11791 L
.70202 .11969 L
.70395 .12117 L
.70589 .12259 L
.70785 .1239 L
.70979 .12506 L
.71171 .12608 L
.71363 .12693 L
.7156 .12759 L
.71773 .12813 L
.71986 .12857 L
.722 .12891 L
.72439 .12919 L
.72679 .12941 L
.72945 .12956 L
.7322 .12964 L
.73517 .12968 L
.73806 .12967 L
.74109 .12964 L
.74413 .12959 L
.74735 .12953 L
.75022 .12947 L
.75313 .12942 L
.75615 .1294 L
.75887 .12942 L
.76175 .1295 L
.7645 .12966 L
.76735 .12991 L
.76986 .13028 L
.77246 .13078 L
.77499 .13142 L
.77763 .13219 L
.77985 .13306 L
.78221 .13405 L
.78457 .13519 L
.787 .1364 L
.78925 .13772 L
.79161 .13909 L
.79379 .14049 L
Mistroke
.79581 .14197 L
.79777 .14351 L
.79958 .14505 L
.80127 .14667 L
.80281 .1483 L
.80421 .15005 L
.80557 .15183 L
.80686 .15376 L
.80815 .15567 L
.80945 .15769 L
.8108 .15986 L
.81225 .16194 L
.81375 .1642 L
.81531 .16645 L
.81698 .16884 L
.81866 .1712 L
.82044 .17354 L
.82234 .17602 L
.82421 .17849 L
.82616 .18105 L
.82822 .18361 L
.83013 .18629 L
.83215 .18888 L
.83409 .19152 L
.83598 .19407 L
.83781 .19657 L
.83954 .19887 L
.84117 .20104 L
.84267 .20308 L
.84399 .20478 L
.84515 .20629 L
.84616 .20757 L
.84695 .20856 L
.84756 .20934 L
.848 .2099 L
.84829 .21026 L
.84847 .21047 L
.84858 .21058 L
.84862 .21061 L
.84858 .21055 L
.84848 .21043 L
.8483 .21025 L
.84807 .21001 L
.84779 .20971 L
.84747 .20938 L
.84711 .20904 L
.84673 .20868 L
.84632 .20827 L
.84588 .2078 L
.84543 .20727 L
Mistroke
.84495 .2067 L
.84445 .20611 L
.84395 .20555 L
.84347 .20505 L
.84303 .20464 L
.84263 .20431 L
.84229 .20406 L
.84203 .20387 L
.84182 .20378 L
.84168 .20377 L
.84164 .20386 L
.84171 .20408 L
.84193 .20445 L
.84232 .20502 L
.84289 .20583 L
.8436 .20688 L
.84449 .20817 L
.8455 .20955 L
.84666 .21118 L
.84801 .21307 L
.84938 .21497 L
.85092 .21716 L
.8525 .21956 L
.8542 .22219 L
.85581 .22481 L
.85738 .22773 L
.85889 .23033 L
.86034 .23324 L
.86164 .23604 L
.86285 .23912 L
.86386 .24231 L
.86475 .24521 L
.86548 .24855 L
.86602 .25181 L
.86633 .25515 L
.86643 .25837 L
.86636 .26168 L
.86615 .26508 L
.86584 .26842 L
.86547 .27193 L
.86503 .27547 L
.86454 .27887 L
.86402 .28262 L
.86347 .28609 L
.86285 .28947 L
.86218 .29314 L
.86146 .29652 L
.86069 .29981 L
.85986 .30332 L
.85898 .30664 L
Mistroke
.85801 .31 L
.85697 .31341 L
.85581 .31672 L
.85452 .31968 L
.85307 .32275 L
.85148 .3257 L
.84984 .32853 L
.84797 .3313 L
.84589 .33402 L
.84398 .3366 L
.84187 .33908 L
.83981 .34152 L
.83777 .34391 L
.83578 .34634 L
.83414 .34862 L
.8326 .35103 L
.83121 .35344 L
.83014 .35598 L
.82929 .35857 L
.8287 .36129 L
.82839 .36423 L
.82833 .36742 L
.82848 .3707 L
.82881 .37422 L
.82932 .37779 L
.82998 .38171 L
.83079 .38506 L
.83173 .38869 L
.83284 .39207 L
.83407 .3954 L
.83548 .39858 L
.83702 .40146 L
.83876 .40412 L
.84049 .40666 L
.84235 .40901 L
.84428 .41132 L
.84625 .41364 L
.84831 .41602 L
.85038 .41851 L
.85244 .42118 L
.85458 .42418 L
.8568 .42694 L
.85894 .43003 L
.86126 .43336 L
.86335 .43644 L
.86559 .43956 L
.86811 .44302 L
.87024 .44585 L
.87256 .44872 L
.87495 .45158 L
Mistroke
.87755 .45431 L
.87982 .4569 L
.88232 .45935 L
.88494 .46176 L
.8878 .46423 L
.89025 .46653 L
.89298 .46903 L
.8958 .47156 L
.89889 .47422 L
.90177 .477 L
.90484 .47995 L
.90813 .48275 L
.91102 .48553 L
.91408 .48808 L
.917 .49044 L
.91995 .49247 L
.92255 .49419 L
.92485 .49563 L
.92702 .49666 L
.92898 .49737 L
.9307 .49772 L
.93203 .49772 L
.93317 .49734 L
.93409 .49664 L
.93478 .49567 L
.93525 .49446 L
.93556 .49311 L
.93573 .49171 L
.9358 .49026 L
.93581 .48879 L
.93577 .48728 L
.93569 .48568 L
.93559 .484 L
.9355 .48214 L
.9354 .4801 L
.93529 .47784 L
.93517 .47539 L
.93506 .47268 L
.93495 .46997 L
.93485 .46705 L
.93474 .46388 L
.93462 .46067 L
.93451 .45722 L
.93439 .45364 L
.93426 .45013 L
.93414 .44647 L
.93401 .44267 L
.93388 .43902 L
.93378 .43527 L
.93369 .43162 L
Mistroke
.93363 .42803 L
.93357 .42458 L
.93348 .42115 L
.93336 .41848 L
.93317 .41582 L
.93292 .41338 L
.93259 .41163 L
.9322 .41017 L
.93177 .40903 L
.93134 .40827 L
.93095 .40785 L
.93061 .40764 L
.9303 .40748 L
.93004 .40718 L
.92981 .4066 L
.92961 .40554 L
.92942 .40393 L
.92925 .40165 L
.92908 .39908 L
.92891 .39573 L
.92872 .3917 L
.92848 .38771 L
.92817 .3833 L
.92775 .37853 L
.92724 .37405 L
.92665 .36941 L
.92604 .3646 L
.92543 .36045 L
.92483 .35634 L
.92424 .35233 L
.92366 .34867 L
.92311 .34504 L
.92257 .34155 L
.92201 .33807 L
.92142 .3347 L
.92078 .33118 L
.92012 .32816 L
.91939 .32499 L
.91859 .32168 L
.91775 .31881 L
.91683 .31588 L
.91586 .313 L
.9148 .3103 L
.91361 .30756 L
.91232 .30493 L
.91093 .30234 L
.90935 .29959 L
.90768 .2969 L
.90588 .29409 L
.90395 .29122 L
Mistroke
.90183 .28814 L
.8998 .28519 L
.8977 .28209 L
.89528 .27865 L
.89317 .27568 L
.89084 .27231 L
.88847 .26898 L
.88605 .26541 L
.88342 .26195 L
.88108 .25842 L
.87855 .25478 L
.87613 .25101 L
.87346 .24728 L
.87083 .24305 L
.86823 .2393 L
.86565 .23545 L
.8629 .23136 L
.86018 .22724 L
.85754 .22326 L
.85513 .21954 L
.85284 .21601 L
.85072 .21265 L
.84871 .20967 L
.84679 .2068 L
.84499 .20404 L
.84335 .20152 L
.8417 .19915 L
.84004 .19676 L
.83835 .19442 L
.83661 .19195 L
.83491 .18959 L
.83316 .18703 L
.83122 .18435 L
.82909 .18132 L
.82685 .17833 L
.82444 .17502 L
.8218 .17157 L
.81923 .16818 L
.81649 .16466 L
.81414 .16134 L
.81181 .15837 L
.80974 .15555 L
.80787 .15307 L
.80616 .15086 L
.80486 .14913 L
.80376 .14765 L
.80289 .14651 L
.80226 .14567 L
.80186 .1451 L
.80167 .1448 L
Mistroke
.80167 .14472 L
.80181 .14482 L
.80201 .14501 L
.80222 .14523 L
.80238 .14542 L
.80245 .14552 L
.80241 .14547 L
.80226 .1453 L
.80202 .14504 L
.80172 .14476 L
.80136 .14448 L
.80103 .14425 L
.80077 .14407 L
.80053 .14392 L
.80025 .14378 L
.79989 .14361 L
.79945 .1434 L
.79891 .14313 L
.79822 .14275 L
.79734 .14226 L
.79625 .14164 L
.79488 .14095 L
.79321 .14003 L
.79129 .13888 L
.78954 .13757 L
.78728 .13598 L
.78465 .13425 L
.78203 .13239 L
.77926 .13066 L
.77653 .12897 L
.77424 .12758 L
.77209 .12639 L
.77034 .12543 L
.76888 .12472 L
.76783 .12424 L
.76716 .12399 L
.76686 .12396 L
.76686 .12415 L
.76711 .12451 L
.76757 .12499 L
.76817 .12554 L
.76882 .1261 L
.76949 .12665 L
.77013 .12722 L
.77071 .1278 L
.77118 .1284 L
.77153 .12901 L
.77183 .12964 L
.7721 .13028 L
.77238 .13092 L
Mistroke
.77267 .13153 L
.773 .1321 L
.77341 .13259 L
.7739 .13301 L
.7745 .13337 L
.77521 .13368 L
.77603 .13395 L
.77697 .13417 L
.77801 .13435 L
.77914 .13448 L
.78033 .13457 L
.78151 .13465 L
.78269 .13473 L
.78386 .13484 L
.78496 .13499 L
.78598 .1352 L
.78687 .13543 L
.78765 .13566 L
.78827 .1359 L
.78876 .13612 L
.78913 .13633 L
.78939 .1365 L
.78954 .13664 L
.78961 .13674 L
.78962 .13679 L
.78959 .13681 L
.78953 .13679 L
.78946 .13676 L
.78939 .13672 L
.78935 .13669 L
.78933 .13667 L
.78931 .13664 L
.78925 .13657 L
.78915 .13645 L
.78903 .13632 L
.78891 .13621 L
.78882 .13615 L
.78882 .13618 L
.78892 .13634 L
.78918 .13666 L
.7896 .13715 L
.79023 .13782 L
.79106 .13866 L
.79209 .13967 L
.79321 .14079 L
.79452 .1422 L
.79605 .14372 L
.79766 .14546 L
.79947 .14736 L
.80138 .14942 L
Mistroke
.80336 .1515 L
.80538 .15375 L
.80746 .15603 L
.80951 .15845 L
.81168 .16104 L
.81363 .16368 L
.81575 .16637 L
.81783 .1691 L
.81987 .17203 L
.82204 .17481 L
.82411 .17768 L
.82621 .18065 L
.82824 .18345 L
.83037 .18645 L
.83251 .18943 L
.83469 .19251 L
.83679 .19581 L
.83881 .19873 L
.84087 .20191 L
.84295 .20523 L
.84495 .20827 L
.84696 .21142 L
.84905 .21443 L
.85083 .21737 L
.85257 .2201 L
.85419 .22254 L
.85563 .22456 L
.85675 .22627 L
.85778 .22764 L
.85867 .22868 L
.8594 .22952 L
.86006 .23026 L
.86068 .23097 L
.86129 .23173 L
.86193 .23264 L
.8626 .23375 L
.86335 .2352 L
.86422 .23692 L
.8653 .23914 L
.86664 .24182 L
.8682 .24502 L
.87006 .24878 L
.87197 .25283 L
.87408 .25737 L
.8762 .26212 L
.87832 .26737 L
.88022 .27227 L
.88203 .27743 L
.8838 .28322 L
.88519 .28787 L
Mistroke
.88644 .29312 L
.88751 .2982 L
.88836 .30351 L
.88896 .3083 L
.88934 .31341 L
.88953 .31835 L
.88955 .32339 L
.88942 .32848 L
.88915 .33382 L
.88879 .33932 L
.88836 .34484 L
.88786 .35047 L
.88728 .35636 L
.88657 .36217 L
.88573 .3682 L
.88476 .37419 L
.88369 .37993 L
.88256 .38516 L
.88138 .39057 L
.88018 .39576 L
.87898 .40084 L
.87774 .40603 L
.87648 .41082 L
.87515 .41583 L
.87378 .42076 L
.87231 .42577 L
.87074 .43073 L
.86908 .43581 L
.86727 .44083 L
.86543 .44586 L
.86346 .45061 L
.86132 .45553 L
.85904 .45992 L
.85646 .46444 L
.85381 .46865 L
.85069 .47287 L
.84755 .47654 L
.84422 .48004 L
.84078 .48321 L
.83718 .4861 L
.83368 .48858 L
.83021 .4908 L
.82648 .49262 L
.82323 .49417 L
.8196 .49549 L
.81583 .49659 L
.81269 .49752 L
.80932 .49835 L
.80555 .49918 L
.80228 .50014 L
Mistroke
.79841 .50132 L
.79513 .50269 L
.79131 .50439 L
.78775 .50641 L
.78416 .50876 L
.78045 .51142 L
.77688 .51423 L
.77378 .51731 L
.77059 .52045 L
.76771 .52376 L
.76489 .52716 L
.76236 .53045 L
.75978 .53388 L
.75731 .53722 L
.75472 .54069 L
.75195 .54426 L
.74941 .54789 L
.74665 .55163 L
.74371 .55539 L
.74111 .55925 L
.73829 .56327 L
.73602 .56729 L
.73384 .5717 L
.73184 .57586 L
.73035 .58027 L
.72916 .58487 L
.7283 .58921 L
.72778 .59392 L
.72755 .59832 L
.72754 .60301 L
.72768 .60745 L
.72793 .61215 L
.72821 .61731 L
.72849 .62185 L
.72878 .62683 L
.72905 .63168 L
.7293 .63668 L
.7295 .64203 L
.72965 .64673 L
.72973 .65206 L
.72971 .65744 L
.72959 .66233 L
.72934 .66783 L
.72896 .67323 L
.72848 .6791 L
.72789 .68402 L
.72725 .68911 L
.72656 .69434 L
.72583 .69903 L
.72512 .70406 L
Mistroke
.72449 .70908 L
.72398 .71431 L
.72365 .71936 L
.72355 .72457 L
.72367 .72972 L
.72402 .73521 L
.72459 .74008 L
.72533 .74522 L
.72619 .75063 L
.72714 .75558 L
.7281 .761 L
.72904 .76569 L
.72987 .77066 L
.73055 .77546 L
.73102 .78016 L
.73122 .78505 L
.73112 .78949 L
.73068 .79433 L
.7299 .79887 L
.72883 .80353 L
.72746 .80842 L
.72587 .81297 L
.72405 .81786 L
.72202 .82287 L
.71985 .82743 L
.71756 .83227 L
.7152 .83718 L
.71287 .84184 L
.71057 .84652 L
.70835 .85142 L
.7062 .85579 L
.70409 .86048 L
.7021 .86513 L
.70018 .86999 L
.69838 .87442 L
.69668 .87918 L
.6951 .88345 L
.69366 .88771 L
.69227 .89153 L
.69083 .89526 L
.68935 .89855 L
.68769 .90179 L
.68584 .90462 L
.68371 .90736 L
.6812 .90998 L
.67853 .9123 L
.67533 .91454 L
.67195 .91651 L
.66801 .91838 L
.66423 .92011 L
Mistroke
.65991 .92175 L
.65546 .92327 L
.65083 .92462 L
.64611 .9258 L
.64139 .92678 L
.63663 .92758 L
.63159 .9282 L
.62729 .92867 L
.62268 .92905 L
.61814 .9294 L
.6134 .92976 L
.60901 .93018 L
.6045 .93067 L
.59968 .93124 L
.59548 .9319 L
.59096 .93264 L
.58655 .93343 L
.58211 .93426 L
.5776 .93516 L
.5734 .93606 L
.56917 .937 L
.56518 .93793 L
.5613 .93882 L
.55728 .93963 L
.55376 .94035 L
.55015 .94097 L
.54666 .94147 L
.54336 .9419 L
.54007 .94225 L
.5369 .94252 L
.53355 .9427 L
.53018 .9428 L
.5265 .94282 L
.5226 .94276 L
.51838 .94258 L
.51385 .94236 L
.50874 .94211 L
.5045 .94185 L
.49973 .94158 L
.49418 .94136 L
.48972 .94119 L
.4851 .94112 L
.4802 .94118 L
.47545 .94135 L
.4709 .94165 L
.46612 .9421 L
.462 .94269 L
.45776 .94333 L
.45362 .94393 L
.44952 .94448 L
Mistroke
.44551 .94493 L
.44143 .94525 L
.43747 .94543 L
.43373 .94544 L
.4298 .94529 L
.42642 .9449 L
.42291 .94424 L
.41942 .94328 L
.4161 .94219 L
.41264 .94095 L
.40937 .93961 L
.40596 .93831 L
.40238 .937 L
.39897 .93584 L
.39529 .93472 L
.39142 .93354 L
.38788 .93243 L
.38407 .93127 L
.38024 .93005 L
.37653 .92882 L
.37294 .92766 L
.36963 .92648 L
.36659 .92546 L
.36388 .92447 L
.36144 .92355 L
.35937 .92268 L
.35771 .92191 L
.35633 .92123 L
.35527 .92067 L
.35455 .92028 L
.35415 .92003 L
.35403 .9199 L
.35411 .91987 L
.35429 .91989 L
.35448 .91994 L
.3546 .91998 L
.35457 .92 L
.35428 .91996 L
.35365 .91983 L
.35266 .91957 L
.35133 .91918 L
.34963 .91869 L
.34763 .91809 L
.34529 .91741 L
.34263 .91665 L
.33972 .91582 L
.33666 .915 L
.33356 .91411 L
.33037 .91305 L
.32743 .91201 L
Mistroke
.32445 .91086 L
.32155 .90961 L
.31887 .90828 L
.31625 .90698 L
.31372 .9056 L
.31123 .90432 L
.30874 .90302 L
.30616 .90171 L
.30368 .90044 L
.30108 .89918 L
.29839 .89802 L
.29565 .89689 L
.29291 .8958 L
.29021 .8948 L
.28766 .89391 L
.28525 .8931 L
.28303 .89233 L
.28119 .8916 L
.27966 .89093 L
.2785 .89034 L
.27769 .88983 L
.27714 .88936 L
.27678 .88891 L
.27653 .88849 L
.27626 .88809 L
.27589 .8877 L
.27534 .88733 L
.27458 .88696 L
.27355 .88662 L
.27226 .88632 L
.27071 .88604 L
.2691 .88575 L
.26732 .8854 L
.26532 .88497 L
.26303 .88445 L
.26083 .88386 L
.25853 .88323 L
.25614 .88253 L
.25379 .88177 L
.2514 .88089 L
.24895 .87986 L
.24658 .87869 L
.24413 .87737 L
.24153 .8758 L
.23895 .87404 L
.23635 .87215 L
.23373 .87012 L
.23122 .86796 L
.22877 .86591 L
.22639 .86363 L
Mistroke
.22417 .86154 L
.22199 .8593 L
.2199 .85702 L
.2179 .85478 L
.21595 .85257 L
.2141 .85038 L
.21223 .84835 L
.21038 .84639 L
.20851 .84445 L
.20674 .84263 L
.20501 .84071 L
.20343 .83898 L
.2019 .83725 L
.20047 .83553 L
.19916 .83387 L
.19791 .8322 L
.19662 .83063 L
.19535 .82903 L
.19399 .82739 L
.1925 .82584 L
.19086 .82423 L
.18927 .82259 L
.18742 .82089 L
.1855 .81918 L
.18342 .81742 L
.18098 .81555 L
.17877 .81367 L
.17632 .81162 L
.17368 .80944 L
.17093 .80703 L
.16796 .8044 L
.16505 .80157 L
.16208 .79853 L
.15874 .79517 L
.15568 .79178 L
.15223 .78841 L
.14902 .78489 L
.14544 .78099 L
.14242 .77794 L
.13915 .77449 L
.13592 .77087 L
.13322 .76802 L
.13047 .76511 L
.12784 .76221 L
.12544 .75954 L
.12318 .75697 L
.12107 .75447 L
.11906 .75203 L
.11708 .74947 L
.11525 .74705 L
Mistroke
.11345 .74445 L
.11154 .74172 L
.10962 .73886 L
.10761 .73601 L
.10576 .73316 L
.10395 .73033 L
.10225 .7277 L
.10065 .72543 L
.0992 .7232 L
.09794 .72123 L
.09678 .71944 L
.0958 .71802 L
.09492 .71683 L
.09412 .7158 L
.09341 .7149 L
.09278 .71402 L
.0922 .71309 L
.09162 .71204 L
.09103 .71081 L
.09046 .70932 L
.08989 .70763 L
.08935 .70596 L
.08881 .70429 L
.08832 .70236 L
.08785 .70057 L
.08741 .69867 L
.08698 .69682 L
.08655 .69485 L
.08613 .69304 L
.0857 .69117 L
.08527 .68922 L
.08485 .68725 L
.08445 .68551 L
.08401 .68363 L
.08355 .68163 L
.08307 .67967 L
.08262 .67759 L
.08225 .67555 L
.08199 .6735 L
.08185 .67154 L
.08184 .66958 L
.08192 .66784 L
.08208 .66617 L
.08229 .6646 L
.08251 .66316 L
.08271 .66175 L
.08287 .66027 L
.08297 .65872 L
.08301 .65712 L
.08302 .65538 L
Mistroke
.08297 .65351 L
.08287 .65144 L
.08272 .64939 L
.08253 .64713 L
.08225 .64488 L
.082 .64247 L
.08168 .6398 L
.08129 .63727 L
.08084 .63435 L
.08033 .63157 L
.07974 .62859 L
.07906 .62532 L
.07837 .62236 L
.0776 .61948 L
.07679 .61622 L
.07604 .61334 L
.07522 .61013 L
.07454 .60714 L
.07387 .60421 L
.07322 .60126 L
.07262 .59839 L
.07207 .59551 L
.07158 .59287 L
.07113 .58999 L
.07068 .58727 L
.07023 .5842 L
.06979 .58141 L
.06937 .57831 L
.06899 .57523 L
.06857 .57177 L
.06811 .5687 L
.06769 .56529 L
.06727 .56179 L
.06684 .55876 L
.06643 .55552 L
.06607 .55237 L
.06579 .54946 L
.06557 .54656 L
.06542 .54418 L
.06528 .54189 L
.06512 .53988 L
.06494 .53787 L
.06472 .53588 L
.06448 .53404 L
.06423 .53215 L
.06398 .53024 L
.06375 .52857 L
.06355 .52682 L
.06337 .52523 L
.06319 .52366 L
Mistroke
.06301 .52221 L
.06282 .5208 L
.06265 .5195 L
.06252 .51846 L
.06243 .51759 L
.06239 .51692 L
.06238 .51647 L
.06241 .51624 L
.06245 .5162 L
.06249 .51628 L
.06252 .51642 L
.06253 .51658 L
.06252 .5167 L
.06252 .51675 L
.06252 .51668 L
.06253 .51643 L
.06255 .51596 L
.06257 .51528 L
.0626 .51439 L
.06263 .51325 L
.06266 .51185 L
.06268 .51031 L
.0627 .50856 L
.06275 .50662 L
.06284 .50476 L
.06297 .50282 L
.06314 .50084 L
.06333 .49923 L
.06352 .49773 L
.06372 .49634 L
.06392 .49508 L
.06413 .494 L
.06437 .49301 L
.0646 .49207 L
.06484 .49112 L
.06509 .49008 L
.06535 .48895 L
.0656 .48762 L
.06581 .48607 L
.06598 .48454 L
.06613 .48265 L
.06627 .48084 L
.06639 .47888 L
.06652 .47693 L
.06665 .47502 L
.06677 .47338 L
.06689 .4719 L
.06696 .47063 L
.067 .46963 L
.06701 .4688 L
Mistroke
.06699 .46815 L
.06699 .46765 L
.06699 .46728 L
.067 .46703 L
.067 .46688 L
.06701 .46677 L
.06701 .46665 L
.06702 .46647 L
.06703 .46619 L
.06704 .46581 L
.06705 .46533 L
.06706 .46474 L
.06705 .46409 L
.06703 .46341 L
.06701 .46276 L
.06701 .46221 L
.06703 .46177 L
.06708 .46147 L
.06716 .46132 L
.06728 .46129 L
.06744 .46139 L
.06766 .46158 L
.06793 .46185 L
.06827 .46215 L
.06866 .46244 L
.06909 .46265 L
.06955 .46279 L
.07004 .46278 L
.07054 .46258 L
.07102 .46225 L
.07144 .46175 L
.07182 .46114 L
.07214 .46047 L
.07239 .45982 L
.07257 .45927 L
.07267 .45884 L
.07273 .45859 L
.07275 .45848 L
.07275 .45856 L
.07273 .45875 L
.07272 .459 L
.07275 .45932 L
.07286 .45964 L
.07307 .45991 L
.07338 .46009 L
.07379 .46016 L
.07428 .46008 L
.07486 .45984 L
.07553 .45945 L
.07627 .45895 L
Mistroke
.07707 .4584 L
.07781 .45786 L
.07869 .45735 L
.07947 .45689 L
.08026 .4565 L
.08109 .45616 L
.08195 .45589 L
.08279 .45566 L
.08365 .45542 L
.08453 .45511 L
.08544 .45469 L
.08626 .45414 L
.08713 .45343 L
.08802 .45257 L
.08888 .45152 L
.08975 .45033 L
.09059 .44921 L
.09131 .44806 L
.09198 .44685 L
.0926 .44584 L
.09319 .44493 L
.09377 .44416 L
.09433 .44356 L
.09492 .44316 L
.09557 .44293 L
.09631 .44282 L
.09712 .44279 L
.09789 .44278 L
.0988 .44275 L
.09972 .44269 L
.10067 .4426 L
.10166 .44247 L
.1025 .44229 L
.1033 .4421 L
.10404 .44191 L
.10466 .44169 L
.10515 .44143 L
.10552 .44111 L
.10577 .44072 L
.10593 .44024 L
.10603 .43961 L
.10611 .43878 L
.10615 .43771 L
.10618 .43643 L
.10621 .43483 L
.10626 .43283 L
.10634 .43077 L
.10644 .42824 L
.10659 .42558 L
.10676 .42265 L
Mistroke
.10689 .41964 L
.10696 .4161 L
.10696 .41313 L
.10689 .40966 L
.10672 .40636 L
.10644 .40299 L
.10603 .39937 L
.10552 .39624 L
.10491 .39285 L
.10419 .38972 L
.10339 .3866 L
.10257 .38346 L
.1017 .38101 L
.10084 .37848 L
.10012 .37606 L
.09937 .37375 L
.09882 .37136 L
.09836 .36936 L
.09799 .36728 L
.09774 .36497 L
.09758 .36242 L
.0975 .35995 L
.09744 .3576 L
.09737 .35499 L
.09731 .35196 L
.09723 .34906 L
.09712 .34584 L
.09696 .34285 L
.09675 .33985 L
.09655 .3368 L
.09634 .3338 L
.09614 .33123 L
.09594 .32878 L
.09579 .32655 L
.09567 .32471 L
.09559 .32302 L
.09556 .32153 L
.09559 .3203 L
.09567 .31924 L
.09576 .31835 L
.09584 .31768 L
.09591 .31717 L
.09594 .31681 L
.09596 .31658 L
.09596 .31646 L
.09595 .31643 L
.09594 .31646 L
.09594 .31651 L
.09594 .31656 L
.09593 .31661 L
Mistroke
.09593 .31665 L
.09593 .31669 L
.09593 .31672 L
.09593 .31674 L
.09593 .31674 L
.09593 .31675 L
.09591 .31678 L
.09588 .31683 L
.09583 .31691 L
.09579 .31698 L
.09576 .31704 L
.09575 .31706 L
.09579 .31702 L
.0959 .31689 L
.09608 .31664 L
.09631 .31626 L
.09658 .31575 L
.09687 .3151 L
.09719 .31435 L
.09753 .31356 L
.0979 .31274 L
.09827 .31192 L
.09865 .31107 L
.09905 .31021 L
.0994 .3094 L
.09975 .30861 L
.10012 .30786 L
.10047 .30715 L
.10079 .30649 L
.10113 .3059 L
.1015 .30537 L
.1019 .30488 L
.10233 .30444 L
.10274 .30403 L
.10312 .30365 L
.10347 .30329 L
.10378 .30295 L
.10403 .30267 L
.10422 .30248 L
.10435 .30237 L
.10444 .30234 L
.1045 .30238 L
.10451 .30245 L
.1045 .30252 L
.10445 .30258 L
.10441 .30261 L
.10437 .30261 L
.10436 .30261 L
.10435 .30261 L
.10435 .30261 L
Mistroke
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30258 L
.10435 .30253 L
.10436 .30246 L
.10436 .30239 L
.10436 .30235 L
.10436 .30237 L
.10436 .30245 L
.10435 .30264 L
.10434 .30292 L
.10434 .30328 L
.10433 .30369 L
.10432 .30414 L
.10431 .30462 L
.1043 .3051 L
.10429 .30556 L
.10428 .30601 L
.10428 .30643 L
.10427 .3068 L
.10426 .30711 L
.10426 .30735 L
.10426 .30748 L
.10425 .30753 L
.10424 .30751 L
.10421 .30745 L
.10416 .30738 L
.10412 .30733 L
.1041 .30732 L
.10411 .3073 L
.10416 .30726 L
.10425 .30719 L
.10438 .30713 L
.10454 .3071 L
.10474 .30712 L
.10498 .30721 L
.10529 .30743 L
.10567 .30777 L
.10609 .30822 L
.10654 .30873 L
.107 .30924 L
.10742 .30971 L
.10778 .3101 L
.10806 .3104 L
.10823 .3106 L
.1083 .31069 L
.10828 .31065 L
Mistroke
.10818 .31049 L
.10804 .31022 L
.10788 .30987 L
.10769 .30948 L
.10749 .30905 L
.10731 .30859 L
.10717 .30813 L
.10712 .30773 L
.10721 .3074 L
.10748 .30709 L
.10795 .30678 L
.10859 .30645 L
.10935 .3061 L
.11024 .30573 L
.11122 .30531 L
.11216 .30488 L
.11314 .30444 L
.11407 .30402 L
.11493 .30362 L
.11576 .30326 L
.11642 .30295 L
.11699 .3027 L
.11745 .30248 L
.11779 .30231 L
.11801 .30216 L
.11813 .30202 L
.11815 .30187 L
.11811 .30168 L
.11805 .30147 L
.11798 .30122 L
.11792 .30098 L
.11788 .30076 L
.11787 .30057 L
.11787 .30042 L
.11787 .30032 L
.11787 .30026 L
.11787 .30024 L
.11787 .30026 L
.11787 .3003 L
.11785 .30036 L
.11781 .30045 L
.11774 .30054 L
.11766 .30065 L
.11761 .30075 L
.11759 .30083 L
.11764 .30086 L
.11776 .30082 L
.11797 .30066 L
.11825 .30037 L
.1186 .29991 L
Mistroke
.11903 .29925 L
.11953 .29834 L
.12008 .2972 L
.12082 .2958 L
.12156 .29404 L
.12237 .29205 L
.12327 .28978 L
.12424 .28729 L
.12527 .28438 L
.12618 .28173 L
.1272 .27899 L
.12833 .27569 L
.12933 .27294 L
.13039 .26974 L
.13157 .26672 L
.13294 .26365 L
.13446 .26028 L
.13585 .25759 L
.13734 .25462 L
.13901 .25152 L
.14064 .2483 L
.14241 .24563 L
.1443 .24269 L
.14617 .23962 L
.14812 .23695 L
.15009 .23428 L
.15195 .23172 L
.15363 .22922 L
.15525 .22711 L
.15681 .22485 L
.15811 .22297 L
.15949 .22107 L
.16068 .21924 L
.1619 .21743 L
.16316 .21561 L
.16433 .214 L
.16559 .21217 L
.16694 .2104 L
.16819 .20845 L
.16954 .20643 L
.17102 .20429 L
.17248 .20211 L
.17408 .19988 L
.17577 .1977 L
.17731 .19549 L
.17897 .19335 L
.1805 .19121 L
.18203 .18905 L
.18344 .18706 L
.18483 .18506 L
Mistroke
.18599 .18331 L
.1871 .18168 L
.18807 .18019 L
.18897 .17891 L
.18969 .17786 L
.19027 .17698 L
.1907 .17627 L
.19097 .17577 L
.19108 .17548 L
.19108 .17535 L
.19103 .17533 L
.19096 .17535 L
.19092 .17535 L
.19095 .17529 L
.19107 .17513 L
.1913 .17484 L
.19162 .17441 L
.19205 .17386 L
.19259 .17322 L
.19318 .17253 L
.19395 .17169 L
.19474 .17081 L
.19561 .16982 L
.19657 .16871 L
.19758 .16751 L
.19855 .16624 L
.19955 .16501 L
.20053 .16369 L
.2015 .16228 L
.20247 .16087 L
.20339 .15943 L
.20431 .15795 L
.20521 .15648 L
.20603 .15503 L
.20676 .15377 L
.2074 .15264 L
.20793 .15165 L
.20835 .15079 L
.20871 .15011 L
.20899 .14955 L
.20921 .14908 L
.20935 .14875 L
.20944 .14854 L
.20946 .14838 L
.20944 .14829 L
.20939 .14822 L
.20934 .14818 L
.20929 .14815 L
.20926 .14812 L
.20924 .1481 L
Mistroke
.20924 .14808 L
.20924 .14807 L
.20924 .14808 L
.20923 .14812 L
.20922 .14815 L
.20918 .14816 L
.20912 .14818 L
.20905 .1482 L
.20898 .14826 L
.20893 .14834 L
.20891 .14842 L
.20896 .14848 L
.20908 .14848 L
.20931 .1484 L
.20963 .14823 L
.21008 .14798 L
.21066 .14764 L
.21135 .14722 L
.2122 .14669 L
.21321 .14609 L
.21434 .14536 L
.21568 .14449 L
.21712 .14357 L
.21877 .14256 L
.22059 .14144 L
.22251 .14021 L
.22476 .13889 L
.227 .13761 L
.22903 .13621 L
.23144 .13481 L
.23377 .13335 L
.23608 .13193 L
.23838 .13057 L
.2405 .12927 L
.24263 .12811 L
.24432 .1271 L
.246 .12619 L
.24742 .12545 L
.24873 .12483 L
.2498 .1243 L
.25073 .12383 L
.25155 .12339 L
.25229 .12295 L
.25304 .1225 L
.25384 .122 L
.25471 .12144 L
.25574 .12077 L
.25699 .11997 L
.25841 .11902 L
.26009 .11794 L
Mistroke
.26174 .1168 L
.26345 .11562 L
.26537 .11445 L
.26719 .11338 L
.26869 .11243 L
.27017 .11164 L
.27155 .11104 L
.27279 .11063 L
.27374 .1104 L
.27453 .11033 L
.27514 .11042 L
.2756 .11066 L
.27596 .11101 L
.27631 .11147 L
.27669 .112 L
.27715 .11257 L
.27772 .11312 L
.27838 .11359 L
.27902 .11392 L
.27972 .11406 L
.28054 .114 L
.28145 .11377 L
.28231 .11336 L
.28316 .11281 L
.28397 .11211 L
.28468 .1113 L
.28532 .11046 L
.28588 .1096 L
.28636 .10876 L
.28677 .10795 L
.28712 .10721 L
.28744 .10661 L
.2877 .10616 L
.28792 .10585 L
.28809 .1057 L
.2882 .10571 L
.28827 .10588 L
.2883 .10614 L
.2883 .10647 L
.28828 .10685 L
.28824 .10725 L
.2882 .10762 L
.28816 .10795 L
.28815 .10824 L
.28815 .10843 L
.28815 .10861 L
.28815 .10875 L
.28815 .10887 L
.28815 .10893 L
.28815 .10899 L
Mistroke
.28815 .10902 L
.28815 .10901 L
.28815 .10897 L
.28815 .10892 L
.28815 .10885 L
.28815 .10877 L
.28815 .10866 L
.28815 .10855 L
.28815 .10846 L
.28815 .10839 L
.28815 .10835 L
.28815 .10837 L
.28815 .10843 L
.28815 .10853 L
.28815 .10862 L
.28815 .10869 L
.28815 .10877 L
.28815 .10885 L
.28815 .10892 L
.28815 .109 L
.28815 .10906 L
.28815 .1091 L
.28815 .10911 L
.28815 .10909 L
.28815 .10904 L
.28815 .10896 L
.28815 .10887 L
.28815 .10878 L
.28815 .1087 L
.28815 .10862 L
.28815 .10854 L
.28815 .10846 L
.28815 .1084 L
.28816 .10836 L
.28818 .10834 L
.2882 .10835 L
.2882 .10838 L
.28819 .10845 L
.28815 .10852 L
.2881 .10859 L
.28804 .10866 L
.28797 .10872 L
.28791 .10877 L
.28786 .10881 L
.28782 .10887 L
.2878 .10897 L
.28779 .10905 L
.28779 .10913 L
.28779 .10918 L
.28781 .10919 L
Mistroke
.28784 .10919 L
.28789 .10919 L
.28795 .10924 L
.28802 .10932 L
.28809 .10942 L
.28814 .10951 L
.28819 .10955 L
.28821 .10952 L
.2882 .10941 L
.28818 .10918 L
.28816 .10885 L
.28815 .10844 L
.28815 .10801 L
.28815 .10764 L
.28815 .10732 L
.28815 .10705 L
.28815 .10682 L
.28815 .10663 L
.28815 .10648 L
.28815 .10635 L
.28815 .10626 L
.28815 .1062 L
.28815 .10618 L
.28815 .10619 L
.28815 .10621 L
.28815 .10622 L
.28815 .10616 L
.28815 .10603 L
.28815 .10579 L
.28815 .10557 L
.28815 .10532 L
.28815 .10511 L
.28815 .10498 L
.28815 .10492 L
.28815 .10494 L
.28815 .10498 L
.28815 .10503 L
.28815 .10506 L
.28815 .10508 L
.28815 .10511 L
.28815 .10512 L
.28815 .1051 L
.28815 .10501 L
.28815 .10488 L
.28815 .10473 L
.28815 .10461 L
.28815 .10455 L
.28815 .1046 L
.28815 .10474 L
.28815 .105 L
Mistroke
.28815 .10535 L
.28815 .10578 L
.28815 .10624 L
.28815 .1067 L
.28815 .10716 L
.28815 .10761 L
.28815 .10806 L
.28815 .10849 L
.28815 .10888 L
.28815 .10918 L
.28815 .10938 L
.28815 .10949 L
.28815 .10953 L
.28815 .1095 L
.28815 .10943 L
.28815 .10936 L
.28815 .1093 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
Mistroke
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10928 L
.28815 .10929 L
.28815 .1093 L
.28815 .1093 L
.28815 .10929 L
.28815 .10929 L
.28815 .10931 L
.28815 .10934 L
.28815 .10937 L
.28815 .10936 L
.28815 .1093 L
.28815 .10916 L
.28815 .10894 L
.28816 .10862 L
.28818 .10826 L
.28822 .10782 L
.28824 .10737 L
.28823 .10695 L
.28818 .10657 L
.28811 .10619 L
.28801 .10584 L
.2879 .10553 L
.28779 .10528 L
.28769 .10508 L
.28761 .10493 L
.28756 .10483 L
.28753 .1048 L
.28752 .10482 L
.28753 .1049 L
.28754 .10497 L
.28759 .10499 L
.28766 .10496 L
.28776 .10489 L
.28787 .10481 L
.28799 .10473 L
.28809 .10466 L
.28818 .10461 L
.28823 .10458 L
.28825 .10459 L
.28823 .10462 L
Mistroke
.28819 .10464 L
.28818 .10463 L
.2882 .10458 L
.28824 .1045 L
.28827 .10444 L
.28829 .10441 L
.28828 .10443 L
.28822 .10453 L
.28812 .10472 L
.28797 .10499 L
.28776 .10535 L
.28751 .10581 L
.28722 .10633 L
.28692 .10687 L
.28664 .10736 L
.28639 .10778 L
.28618 .10812 L
.28605 .10837 L
.28598 .1085 L
.28601 .10852 L
.2861 .10845 L
.28625 .10833 L
.28645 .10816 L
.28665 .10792 L
.28684 .10766 L
.28702 .10737 L
.2872 .1071 L
.28737 .10685 L
.28757 .10666 L
.28783 .10654 L
.28821 .10635 L
.28878 .10624 L
.28958 .10614 L
.2906 .10596 L
.29192 .10568 L
.29361 .10527 L
.2954 .10472 L
.29765 .10405 L
.30039 .1033 L
.30305 .10245 L
.30628 .10146 L
.30955 .10034 L
.3132 .09909 L
.31706 .09762 L
.32067 .09599 L
.32434 .09424 L
.32849 .09226 L
.33246 .09036 L
.33621 .08831 L
.34031 .08609 L
Mistroke
.34413 .08401 L
.34812 .08166 L
.35185 .07943 L
.35589 .07689 L
.35956 .07448 L
.36298 .07197 L
.36639 .06946 L
.37009 .06693 L
.37287 .06446 L
.37578 .06223 L
.37864 .05997 L
.3809 .05804 L
.38303 .05622 L
.38484 .05455 L
.38626 .0533 L
.38738 .05227 L
.38816 .05149 L
.38866 .05097 L
.38893 .05069 L
.38903 .05061 L
.38906 .05067 L
.38912 .05081 L
.38929 .05095 L
.38959 .05105 L
.39006 .05108 L
.39068 .051 L
.39146 .05078 L
.39228 .05043 L
.3932 .04998 L
.39414 .04951 L
.39506 .04906 L
.3958 .04864 L
.39646 .04833 L
.39705 .04809 L
.39755 .04795 L
.39797 .04791 L
.39832 .04796 L
.39866 .04809 L
.39912 .04826 L
.39981 .04844 L
.40078 .0486 L
.402 .04875 L
.40336 .0489 L
.40496 .04896 L
.40691 .04895 L
.40903 .04888 L
.41122 .0487 L
.41337 .04847 L
.41547 .04821 L
.41747 .04796 L
Mistroke
.41923 .04776 L
.42067 .04763 L
.42192 .04758 L
.42293 .0476 L
.42368 .04764 L
.42425 .0477 L
.42471 .04777 L
.42511 .04782 L
.42548 .04786 L
.42586 .04787 L
.42631 .04789 L
.42687 .04791 L
.42764 .04793 L
.42863 .04796 L
.42982 .048 L
.43124 .04805 L
.43287 .04811 L
.43478 .04817 L
.4367 .04824 L
.43885 .04831 L
.44116 .04839 L
.44343 .04847 L
.44593 .04856 L
.44822 .04866 L
.45061 .04878 L
.45293 .04889 L
.4551 .04897 L
.45707 .04903 L
.45877 .04903 L
.46018 .04899 L
.46133 .04889 L
.46222 .04875 L
.46289 .04857 L
.46336 .04836 L
.46363 .04814 L
.46376 .04791 L
.46376 .04768 L
.46365 .04745 L
.46349 .04723 L
.46329 .04705 L
.4631 .04689 L
.46295 .04679 L
.46285 .04673 L
.46278 .04671 L
.46275 .04672 L
.46272 .04674 L
.46267 .04675 L
.46258 .04674 L
.46247 .04672 L
.46236 .0467 L
Mistroke
.46228 .04671 L
.46227 .04676 L
.46237 .04685 L
.46263 .04699 L
.46309 .04718 L
.46378 .0474 L
.46471 .04765 L
.46591 .04792 L
.46725 .0482 L
.46892 .04848 L
.47082 .04876 L
.47292 .04899 L
.47526 .04918 L
.47771 .04933 L
.48025 .04947 L
.48282 .04961 L
.48534 .04978 L
.48778 .04998 L
.49002 .05025 L
.49217 .05059 L
.49397 .05098 L
.49567 .0514 L
.49721 .05182 L
.49855 .05226 L
.49964 .05271 L
.50049 .05322 L
.50107 .05377 L
.5014 .05434 L
.50149 .05493 L
.50139 .0555 L
.50116 .05604 L
.50083 .05655 L
.50045 .057 L
.50007 .05738 L
.49967 .05773 L
.49926 .05809 L
.49888 .05847 L
.49852 .0588 L
.49821 .05907 L
.49796 .05924 L
.49781 .05933 L
.49774 .05936 L
.49776 .05933 L
.49783 .05927 L
.49792 .05922 L
.498 .05922 L
.49807 .05927 L
.49811 .05933 L
.49812 .05936 L
.49811 .05934 L
Mistroke
.49806 .05925 L
.49797 .05907 L
.49783 .05881 L
.49765 .05846 L
.49745 .05805 L
.49722 .05761 L
.49698 .05714 L
.49673 .05669 L
.49649 .05624 L
.49625 .0558 L
.49604 .05538 L
.49585 .055 L
.4957 .0547 L
.4956 .05449 L
.49554 .05437 L
.49552 .05434 L
.49553 .05436 L
.49557 .05442 L
.49561 .0545 L
.49564 .05455 L
.49565 .05457 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49569 .05458 L
.49574 .05458 L
.49582 .05458 L
.49589 .05459 L
.49597 .05459 L
.49604 .05459 L
.49607 .05461 L
.49603 .05466 L
.49591 .05473 L
.49568 .05478 L
.49532 .0548 L
.49479 .05476 L
.49406 .05465 L
.4931 .05445 L
.4919 .05415 L
.4904 .05377 L
.48853 .05331 L
.48644 .0528 L
.48416 .05227 L
.48152 .05173 L
.47842 .05121 L
.47542 .05067 L
.47193 .05013 L
.4683 .04963 L
.46422 .04921 L
Mistroke
.46053 .04889 L
.45612 .04864 L
.45188 .04847 L
.44747 .04837 L
.443 .04831 L
.43848 .04824 L
.43373 .04813 L
.42915 .04844 L
.42515 .04838 L
.42091 .04834 L
.41726 .04833 L
.41341 .04837 L
.41011 .04844 L
.40712 .04854 L
.40425 .04865 L
.40164 .04881 L
.39923 .04899 L
.39701 .04922 L
.39511 .0495 L
.39328 .04989 L
.39151 .05037 L
.38978 .05096 L
.38811 .05164 L
.38638 .05239 L
.38461 .05315 L
.38293 .05385 L
.38135 .05453 L
.37991 .05516 L
.37863 .05575 L
.37755 .05628 L
.37662 .05675 L
.37583 .05714 L
.37515 .05742 L
.37463 .05756 L
.37424 .05757 L
.37401 .05746 L
.37391 .05727 L
.37392 .05703 L
.37399 .05676 L
.37411 .05649 L
.37423 .05622 L
.37433 .05595 L
.37439 .05571 L
.37445 .0555 L
.37452 .05532 L
.37458 .05516 L
.37459 .05503 L
.37454 .05493 L
.37442 .05487 L
.37424 .05483 L
Mistroke
.37402 .05482 L
.37376 .05482 L
.3735 .05486 L
.37325 .05496 L
.37302 .05511 L
.37279 .05534 L
.37257 .05565 L
.37232 .05605 L
.37205 .05652 L
.37174 .05707 L
.37137 .0577 L
.37092 .05839 L
.37034 .05917 L
.36953 .06001 L
.36842 .06096 L
.36696 .06204 L
.3651 .06327 L
.36291 .06462 L
.36018 .06614 L
.35686 .06787 L
.35362 .06977 L
.34981 .07181 L
.34582 .07401 L
.34163 .07623 L
.33704 .07853 L
.33275 .08091 L
.32831 .08316 L
.32403 .08543 L
.3196 .08754 L
.31563 .08952 L
.31153 .09146 L
.30782 .09321 L
.304 .09492 L
.30043 .09663 L
.29667 .09828 L
.29283 .10013 L
.28899 .10202 L
.28474 .1041 L
.28103 .10628 L
.2771 .1085 L
.27316 .11084 L
.26957 .11305 L
.26599 .11518 L
.26306 .11713 L
.26052 .1187 L
.25807 .12013 L
.25616 .12127 L
.25454 .12226 L
.25324 .12311 L
.25221 .12385 L
Mistroke
.25134 .12454 L
.25047 .12526 L
.2495 .12613 L
.24836 .12723 L
.2471 .12849 L
.24546 .13007 L
.24341 .13184 L
.241 .13382 L
.23822 .1362 L
.23533 .13886 L
.23206 .14184 L
.22871 .14452 L
.22499 .14746 L
.22166 .15048 L
.21792 .15359 L
.2144 .15644 L
.21052 .15958 L
.20696 .16268 L
.20295 .16602 L
.19965 .16929 L
.1962 .17304 L
.19272 .17657 L
.18932 .18001 L
.18588 .18403 L
.18289 .18789 L
.17984 .19161 L
.17678 .19577 L
.17381 .19986 L
.17093 .20401 L
.16814 .2082 L
.16549 .21235 L
.16299 .21646 L
.16073 .22043 L
.15868 .22436 L
.15691 .22815 L
.15533 .2316 L
.15404 .23485 L
.15298 .23761 L
.15216 .24006 L
.15159 .24195 L
.15122 .24338 L
.15105 .24446 L
.15104 .24513 L
.15113 .24549 L
.15126 .24558 L
.15136 .24548 L
.15137 .24531 L
.15122 .24516 L
.15085 .24515 L
.15021 .24542 L
Mistroke
.14926 .24606 L
.14792 .24714 L
.14632 .24858 L
.14422 .25053 L
.14207 .25289 L
.13955 .25579 L
.13643 .25927 L
.13372 .26243 L
.13061 .26601 L
.12735 .2699 L
.12437 .27383 L
.12114 .27814 L
.11816 .28172 L
.11526 .28563 L
.11257 .28928 L
.1099 .29305 L
.10734 .29673 L
.10488 .30003 L
.10254 .30348 L
.10066 .30652 L
.09886 .30951 L
.09739 .3122 L
.0961 .31484 L
.09503 .31722 L
.0942 .31971 L
.09356 .32198 L
.09309 .32434 L
.09272 .32682 L
.09241 .32938 L
.0921 .33224 L
.09176 .33505 L
.0913 .33817 L
.09071 .34167 L
.09003 .34485 L
.08927 .34825 L
.08845 .35196 L
.08763 .35558 L
.08681 .35932 L
.08601 .36316 L
.08527 .36688 L
.0846 .37023 L
.08401 .37377 L
.08353 .37703 L
.08315 .38025 L
.08287 .38323 L
.08266 .38616 L
.08252 .38874 L
.08244 .39114 L
.08239 .39329 L
.08238 .39515 L
Mistroke
.08238 .39681 L
.08241 .39814 L
.08244 .39918 L
.08249 .39994 L
.08256 .40043 L
.08265 .40069 L
.08273 .40077 L
.08281 .40072 L
.08287 .4006 L
.0829 .40046 L
.0829 .40032 L
.08288 .4002 L
.08285 .40013 L
.08283 .40009 L
.08281 .40008 L
.08275 .40007 L
.08267 .40004 L
.08256 .4 L
.08246 .39993 L
.08242 .39985 L
.08247 .39976 L
.08262 .39969 L
.0829 .39968 L
.08332 .39976 L
.08386 .39997 L
.08454 .40036 L
.08534 .40094 L
.0862 .40171 L
.08719 .40265 L
.08831 .40374 L
.08943 .40494 L
.09059 .40615 L
.09173 .40742 L
.09275 .40873 L
.09364 .4099 L
.09436 .41101 L
.09488 .41204 L
.09521 .41297 L
.09535 .4139 L
.09533 .41488 L
.09516 .41597 L
.09486 .41722 L
.09445 .41862 L
.09393 .42026 L
.09333 .42213 L
.09269 .42414 L
.09207 .42592 L
.09149 .42785 L
.09098 .42985 L
.09056 .43151 L
Mistroke
.09024 .43305 L
.08999 .43435 L
.08983 .4353 L
.08974 .43587 L
.0897 .43611 L
.08971 .43612 L
.08978 .43603 L
.08988 .43593 L
.09 .43599 L
.09009 .43634 L
.09013 .43704 L
.09009 .43814 L
.08999 .4396 L
.08983 .44136 L
.0896 .44304 L
.08928 .44508 L
.08883 .44709 L
.0882 .44929 L
.08739 .45162 L
.08638 .45376 L
.08494 .45601 L
.08361 .45798 L
.08199 .46001 L
.0801 .46207 L
.07831 .46409 L
.07678 .46578 L
.0752 .46766 L
.0733 .46943 L
.07188 .47105 L
.07059 .47267 L
.06935 .4743 L
.06831 .47591 L
.06753 .47732 L
.06693 .47865 L
.06652 .47985 L
.06627 .4809 L
.06615 .48179 L
.06612 .48251 L
.06614 .48308 L
.06619 .48357 L
.06625 .48399 L
.0663 .48432 L
.06633 .48458 L
.06636 .48478 L
.06637 .48492 L
.06637 .485 L
.06637 .48502 L
.06637 .48498 L
.06638 .48491 L
.06638 .48486 L
Mistroke
.06638 .48485 L
.06638 .48491 L
.06637 .48497 L
.06637 .48501 L
.06637 .48499 L
.06638 .48489 L
.06639 .48469 L
.0664 .48441 L
.06641 .48405 L
.06642 .48362 L
.06644 .48316 L
.06646 .48269 L
.06647 .48223 L
.06649 .48177 L
.06651 .4813 L
.06652 .48084 L
.06653 .4804 L
.06654 .48002 L
.06652 .47973 L
.0665 .47952 L
.06649 .47939 L
.06649 .47928 L
.06651 .47913 L
.06654 .4789 L
.06659 .47851 L
.06668 .47795 L
.06681 .47721 L
.06698 .47634 L
.0672 .47534 L
.06745 .47424 L
.06773 .47315 L
.06802 .47192 L
.06832 .47058 L
.06863 .4693 L
.0689 .46796 L
.06917 .46662 L
.06941 .46535 L
.06961 .4642 L
.06977 .46318 L
.06988 .46233 L
.06996 .46161 L
.07002 .46099 L
.07005 .46046 L
.07007 .46002 L
.07007 .45966 L
.07005 .4594 L
.07003 .45925 L
.07002 .4592 L
.07001 .45925 L
.06999 .45936 L
Mistroke
.06995 .4595 L
.06991 .45961 L
.06986 .45975 L
.06983 .45991 L
.06984 .46009 L
.06989 .46026 L
.07 .46039 L
.07016 .46044 L
.07037 .46038 L
.07062 .4602 L
.07089 .4599 L
.07119 .45955 L
.07149 .45908 L
.07178 .45857 L
.07207 .45806 L
.07234 .4576 L
.07257 .45713 L
.07276 .45669 L
.0729 .45628 L
.07298 .45593 L
.07301 .45564 L
.073 .45543 L
.07296 .4553 L
.07292 .45526 L
.07288 .4553 L
.07286 .45537 L
.07286 .45545 L
.07288 .45552 L
.07293 .45558 L
.07301 .45562 L
.07308 .45566 L
.07312 .45567 L
.07309 .45566 L
.07299 .45561 L
.07279 .45552 L
.07248 .45538 L
.07206 .4552 L
.07157 .45499 L
.07104 .45476 L
.0705 .45452 L
.06997 .45428 L
.06946 .45403 L
.06895 .4538 L
.06845 .45358 L
.06799 .45339 L
.06763 .45324 L
.06738 .45314 L
.06725 .45308 L
.0672 .45306 L
.06722 .45308 L
Mistroke
.06729 .45311 L
.06738 .45315 L
.06744 .45318 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06745 .45318 L
.06742 .45316 L
.06737 .45312 L
.06733 .45308 L
.0673 .45306 L
.06728 .45308 L
.0673 .45313 L
.06738 .45323 L
.06752 .45337 L
.06773 .45355 L
.06803 .45376 L
.0684 .45399 L
.06883 .45423 L
.0693 .45448 L
.06981 .45472 L
.07033 .45496 L
.07086 .45517 L
.07136 .45536 L
.0718 .45551 L
.07219 .45561 L
.07251 .45567 L
.07276 .45568 L
.07292 .45567 L
.07301 .45563 L
.07304 .45559 L
.07304 .45555 L
.07301 .45554 L
.07296 .45554 L
.07292 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45553 L
.07286 .45551 L
.07286 .45545 L
.07286 .45538 L
.07286 .4553 L
Mistroke
.07287 .45527 L
.07286 .45529 L
.07286 .4554 L
.07285 .45559 L
.07284 .45588 L
.07283 .45624 L
.07282 .45667 L
.0728 .45715 L
.07278 .45765 L
.07277 .45814 L
.07275 .45864 L
.07273 .45912 L
.07272 .45958 L
.07273 .46 L
.07277 .46036 L
.07285 .46065 L
.07292 .46084 L
.07294 .46092 L
.07291 .46086 L
.0728 .46069 L
.0726 .46043 L
.07228 .46009 L
.07186 .4597 L
.07135 .45927 L
.07078 .4588 L
.07018 .45831 L
.06962 .45782 L
.06911 .45734 L
.06861 .45686 L
.06817 .45642 L
.06782 .45603 L
.06763 .45572 L
.06761 .4555 L
.06774 .45538 L
.06797 .45533 L
.06829 .45536 L
.06865 .45542 L
.06902 .4555 L
.06937 .45556 L
.06965 .45558 L
.06988 .45558 L
.07006 .45558 L
.07018 .45558 L
.07026 .45558 L
.07028 .45558 L
.07027 .45558 L
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45555 L
.07013 .45549 L
.07013 .45542 L
.07013 .45535 L
.07013 .45531 L
.07011 .45534 L
.07008 .45544 L
.07003 .45563 L
.06998 .45592 L
.06995 .45629 L
.06995 .45672 L
.06999 .45719 L
.07008 .45769 L
.07023 .45818 L
.07042 .45867 L
.07064 .45915 L
.0709 .4596 L
.07116 .45998 L
.07143 .46029 L
.07171 .46051 L
.07197 .46063 L
.07223 .46066 L
.07245 .46063 L
.07263 .46056 L
.07275 .46047 L
.07283 .46041 L
.07285 .46038 L
.07283 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46037 L
.07267 .46035 L
.07264 .46029 L
.0726 .46022 L
.07257 .46015 L
.07255 .46011 L
.07256 .46014 L
.07262 .46024 L
Mistroke
.07272 .46043 L
.07287 .46071 L
.07306 .46108 L
.07329 .4615 L
.07354 .46197 L
.07381 .46247 L
.07407 .46296 L
.07434 .46345 L
.07459 .46393 L
.07483 .46437 L
.07504 .46476 L
.0752 .46507 L
.07532 .46529 L
.07539 .46541 L
.07541 .46545 L
.07539 .46542 L
.07535 .46535 L
.07531 .46527 L
.07528 .46521 L
.07526 .46518 L
.07526 .46517 L
.07527 .46511 L
.07528 .46499 L
.07529 .46482 L
.0753 .46465 L
.07532 .46451 L
.07535 .46445 L
.07539 .46451 L
.07543 .46474 L
.07546 .46519 L
.07546 .46588 L
.07543 .46686 L
.0753 .4682 L
.07503 .46997 L
.07457 .47183 L
.07404 .47436 L
.07332 .47688 L
.07244 .48 L
.07158 .4831 L
.07051 .48648 L
.06947 .48973 L
.06835 .49292 L
.06723 .49593 L
.06604 .49919 L
.06507 .50172 L
.06417 .50455 L
.06336 .50683 L
.06271 .50908 L
.06225 .51127 L
.06197 .51324 L
Mistroke
.06184 .51493 L
.06184 .51616 L
.06192 .51739 L
.06205 .51849 L
.06219 .51937 L
.0623 .52015 L
.06234 .52082 L
.06231 .52134 L
.06217 .52168 L
.06187 .52187 L
.06143 .52195 L
.06091 .52195 L
.06038 .52192 L
.05985 .5219 L
.05936 .52187 L
.05892 .52179 L
.05854 .52166 L
.05822 .52147 L
.05801 .52118 L
.05792 .52081 L
.05797 .52038 L
.05814 .51989 L
.0584 .51938 L
.05873 .51887 L
.05909 .51836 L
.05944 .51788 L
.05971 .51744 L
.05986 .51708 L
.05993 .5168 L
.05995 .5166 L
.05994 .51646 L
.0599 .51637 L
.05986 .51629 L
.05983 .51619 L
.05981 .51605 L
.05982 .51586 L
.05983 .51562 L
.05983 .51538 L
.05984 .51518 L
.05985 .51502 L
.05985 .51492 L
.05985 .51487 L
.05985 .51489 L
.05985 .51494 L
.05984 .51503 L
.05983 .51514 L
.05979 .5153 L
.05974 .51549 L
.05969 .5157 L
.05966 .51593 L
Mistroke
.05967 .51617 L
.05971 .51645 L
.05979 .51678 L
.05991 .51719 L
.06006 .51773 L
.06022 .51842 L
.0604 .5193 L
.06059 .52038 L
.06081 .52175 L
.06106 .52346 L
.06134 .52547 L
.06166 .52766 L
.06201 .53029 L
.06239 .53314 L
.06279 .53636 L
.06322 .53961 L
.06365 .54321 L
.06413 .54712 L
.06465 .55082 L
.06521 .55518 L
.06581 .55964 L
.06646 .56398 L
.06714 .56933 L
.06779 .57423 L
.06841 .57854 L
.069 .58394 L
.06957 .58873 L
.0701 .59378 L
.07062 .59952 L
.07117 .60414 L
.07173 .60941 L
.07234 .61462 L
.073 .6199 L
.07372 .62453 L
.07445 .62955 L
.07524 .6344 L
.07606 .63915 L
.07686 .64385 L
.07769 .64846 L
.07852 .65316 L
.07932 .65813 L
.08014 .66283 L
.08087 .66719 L
.0816 .67186 L
.08234 .6764 L
.0831 .68098 L
.0838 .6852 L
.08455 .68956 L
.08533 .69362 L
.0861 .69729 L
Mistroke
.08689 .7008 L
.0877 .70422 L
.08846 .70682 L
.08919 .70926 L
.08986 .71149 L
.0904 .71307 L
.09083 .71433 L
.09118 .71529 L
.09143 .71598 L
.0916 .71647 L
.09172 .71681 L
.0918 .71709 L
.09188 .71737 L
.09198 .7177 L
.09212 .7181 L
.09233 .71864 L
.09263 .71931 L
.09302 .72012 L
.09349 .72106 L
.09403 .72208 L
.09462 .72313 L
.09526 .72416 L
.09587 .72511 L
.09644 .72591 L
.09696 .72652 L
.09742 .72703 L
.09784 .72744 L
.0982 .72781 L
.09854 .72816 L
.09888 .72854 L
.09927 .72893 L
.09972 .72933 L
.10026 .72971 L
.1009 .73007 L
.10163 .73047 L
.10239 .73094 L
.10329 .73153 L
.10419 .73224 L
.10515 .73304 L
.10614 .73388 L
.10705 .73472 L
.10795 .73554 L
.10866 .73636 L
.10927 .73719 L
.10975 .73803 L
.11008 .73887 L
.11026 .73974 L
.11032 .74063 L
.11028 .74152 L
.11018 .74236 L
Mistroke
.11004 .74309 L
.10988 .74368 L
.10973 .74417 L
.10963 .74457 L
.1096 .74488 L
.10966 .74513 L
.10983 .74536 L
.11011 .74558 L
.11053 .74583 L
.11108 .74612 L
.11177 .74646 L
.11252 .74688 L
.11339 .74738 L
.1143 .74797 L
.11524 .74865 L
.11623 .74937 L
.11718 .75009 L
.11811 .75075 L
.11899 .75137 L
.11978 .75193 L
.12047 .75238 L
.12107 .75272 L
.12157 .75293 L
.12197 .75302 L
.1223 .75301 L
.1226 .75297 L
.12289 .75293 L
.12316 .75291 L
.12339 .7529 L
.12355 .7529 L
.12362 .75288 L
.12358 .75281 L
.12341 .75266 L
.12313 .75246 L
.12277 .75219 L
.12236 .75187 L
.12189 .75146 L
.12136 .75094 L
.12075 .75031 L
.12009 .74959 L
.11937 .74878 L
.11861 .74791 L
.11782 .747 L
.11704 .74607 L
.11627 .74518 L
.11556 .74425 L
.11492 .74331 L
.11437 .74244 L
.11388 .74158 L
.11339 .74072 L
Mistroke
.11286 .73985 L
.11228 .73899 L
.11165 .73818 L
.11098 .73746 L
.11023 .73681 L
.1094 .73622 L
.10851 .73568 L
.10758 .73517 L
.10668 .73473 L
.10585 .7344 L
.10512 .73415 L
.1044 .73398 L
.10369 .73389 L
.10301 .73382 L
.10241 .73371 L
.10189 .7335 L
.10141 .73315 L
.10096 .73266 L
.10056 .73203 L
.1002 .73128 L
.09983 .73041 L
.09938 .72955 L
.09881 .72863 L
.09818 .72776 L
.09754 .72697 L
.0969 .7264 L
.09632 .72595 L
.0958 .72565 L
.09537 .72552 L
.09504 .72557 L
.09477 .72578 L
.09456 .72614 L
.09438 .7266 L
.09422 .72709 L
.09407 .72758 L
.09396 .72806 L
.09389 .7284 L
.09387 .72866 L
.09389 .72879 L
.09393 .72884 L
.09396 .72883 L
.09396 .72876 L
.09393 .72866 L
.09389 .72856 L
.09387 .72851 L
.09389 .72854 L
.09394 .72864 L
.09404 .72882 L
.0942 .7291 L
.09439 .72947 L
Mistroke
.09462 .72991 L
.09486 .73039 L
.09509 .7309 L
.09532 .7314 L
.09555 .7319 L
.09579 .73239 L
.09605 .73284 L
.09632 .73324 L
.0966 .73355 L
.09688 .73377 L
.09715 .73389 L
.09741 .73392 L
.09767 .73388 L
.09791 .7338 L
.09814 .7337 L
.09839 .73363 L
.09865 .73359 L
.09889 .73357 L
.09911 .73356 L
.09927 .73356 L
.09935 .73355 L
.09938 .73355 L
.09935 .73355 L
.0993 .73353 L
.09924 .73346 L
.0992 .73334 L
.0992 .73323 L
.09929 .73317 L
.09946 .73319 L
.09974 .7333 L
.1001 .73352 L
.10057 .73385 L
.1011 .7343 L
.10173 .73487 L
.10243 .73554 L
.1032 .73633 L
.10399 .73721 L
.10482 .73812 L
.10565 .7391 L
.10642 .74013 L
.10714 .74117 L
.10779 .74216 L
.10836 .74303 L
.10883 .74371 L
.10921 .74426 L
.10949 .74469 L
.10968 .74504 L
.10977 .7453 L
.10977 .74552 L
.10972 .74569 L
Mistroke
.10967 .74583 L
.10964 .74593 L
.10967 .74606 L
.10981 .74624 L
.11006 .74651 L
.11047 .74692 L
.11103 .74748 L
.11176 .7482 L
.11259 .74909 L
.11365 .75019 L
.11495 .75144 L
.1163 .75285 L
.11784 .75446 L
.11954 .75616 L
.12129 .7579 L
.12312 .75972 L
.12475 .76141 L
.12635 .76304 L
.12779 .76451 L
.12915 .76593 L
.1303 .76702 L
.13137 .76793 L
.13225 .76867 L
.133 .76924 L
.13364 .76968 L
.13423 .77003 L
.13485 .77037 L
.13554 .77084 L
.13637 .77156 L
.13743 .77257 L
.13874 .7739 L
.14033 .77559 L
.14183 .77738 L
.14372 .77966 L
.14564 .78188 L
.14771 .78437 L
.14982 .7868 L
.15179 .7892 L
.15384 .79168 L
.15587 .7942 L
.15776 .79624 L
.15951 .79823 L
.16113 .80008 L
.16265 .80176 L
.16416 .80335 L
.16569 .80481 L
.16733 .80635 L
.16914 .80807 L
.1711 .80982 L
.17328 .81185 L
Mistroke
.17566 .81408 L
.1783 .8167 L
.18111 .81919 L
.18404 .82197 L
.18736 .82526 L
.19047 .82804 L
.19386 .83125 L
.19717 .8344 L
.20068 .83791 L
.20389 .84097 L
.20722 .84434 L
.21051 .84756 L
.21365 .85087 L
.21675 .85396 L
.21977 .85712 L
.22277 .86022 L
.22586 .86346 L
.22893 .8663 L
.23214 .86914 L
.23559 .87216 L
.23887 .87451 L
.24248 .87689 L
.24613 .87925 L
.25016 .88132 L
.25362 .88325 L
.25748 .88505 L
.26196 .88669 L
.26574 .88829 L
.27012 .88995 L
.27443 .89158 L
.27904 .8933 L
.28425 .89524 L
.28883 .89723 L
.29397 .89931 L
.29962 .9016 L
.30447 .90374 L
.30991 .90599 L
.31586 .90816 L
.3206 .91026 L
.32586 .91235 L
.33101 .91428 L
.33621 .9162 L
.34064 .91793 L
.34514 .91962 L
.3495 .92123 L
.35375 .92281 L
.35792 .92426 L
.3622 .92578 L
.36642 .92731 L
.37096 .92885 L
Mistroke
.37526 .93046 L
.37989 .93212 L
.3846 .93382 L
.38921 .93554 L
.39402 .93736 L
.39908 .93911 L
.40368 .9408 L
.40838 .94248 L
.41277 .94405 L
.4169 .94548 L
.42065 .94677 L
.4239 .94785 L
.42673 .94871 L
.42913 .94937 L
.43092 .94982 L
.43229 .95007 L
.43324 .95016 L
.43382 .95013 L
.43409 .94999 L
.43413 .94981 L
.43411 .9496 L
.43423 .94941 L
.43462 .94927 L
.43536 .94919 L
.43647 .94919 L
.438 .94926 L
.43987 .94937 L
.44204 .94949 L
.44435 .94961 L
.44674 .9497 L
.44915 .94976 L
.4516 .94978 L
.45368 .94977 L
.45561 .94974 L
.45721 .94969 L
.45849 .94961 L
.4594 .94954 L
.45993 .94947 L
.46015 .94941 L
.46015 .94938 L
.46003 .94937 L
.45986 .94938 L
.45971 .94937 L
.45963 .94932 L
.45964 .94924 L
.45972 .94916 L
.45976 .94912 L
.45974 .94915 L
.45961 .94926 L
.45937 .94948 L
Mistroke
.45901 .94979 L
.45851 .95019 L
.45788 .95067 L
.4571 .9512 L
.45619 .95178 L
.45519 .95238 L
.45412 .95301 L
.45299 .95364 L
.45185 .95424 L
.45074 .95475 L
.44971 .95512 L
.44884 .9553 L
.4481 .95529 L
.44754 .95508 L
.44717 .95472 L
.447 .95424 L
.44697 .9537 L
.44703 .95317 L
.44709 .95267 L
.44707 .9522 L
.44692 .95175 L
.44658 .95131 L
.44601 .95091 L
.44521 .95058 L
.44418 .95036 L
.44296 .95022 L
.4416 .95014 L
.44023 .9501 L
.43874 .95007 L
.43703 .95001 L
.4354 .94985 L
.43369 .94958 L
.43192 .9492 L
.43008 .94871 L
.42818 .94813 L
.42626 .94743 L
.42415 .94667 L
.42174 .94581 L
.41906 .94484 L
.41588 .94372 L
.41241 .94247 L
.40845 .9411 L
.40434 .93959 L
.39974 .93794 L
.3952 .9362 L
.39022 .93436 L
.38528 .93234 L
.37953 .93035 L
.37466 .92823 L
.36923 .92599 L
Mistroke
.36356 .92375 L
.3583 .92147 L
.35257 .91924 L
.34738 .91703 L
.34184 .9149 L
.33623 .91278 L
.33124 .91093 L
.32606 .90908 L
.32102 .90729 L
.31598 .90548 L
.3112 .9037 L
.30643 .90175 L
.30167 .8997 L
.29695 .89752 L
.29216 .89516 L
.28758 .89268 L
.28276 .88992 L
.27763 .88684 L
.27358 .88432 L
.26881 .88147 L
.26389 .87819 L
.25964 .87558 L
.25501 .87282 L
.25027 .87023 L
.24574 .86758 L
.24113 .86525 L
.23688 .86291 L
.23259 .86073 L
.22829 .85841 L
.22421 .85606 L
.22025 .85367 L
.21619 .85099 L
.21252 .84822 L
.2088 .84513 L
.20527 .84189 L
.20175 .83834 L
.1986 .83509 L
.19544 .8316 L
.19219 .8278 L
.18913 .82458 L
.18578 .82111 L
.18261 .81777 L
.17909 .81429 L
.17579 .81122 L
.17225 .80798 L
.16873 .80488 L
.16491 .80156 L
.16166 .7986 L
.15798 .79535 L
.15449 .79191 L
Mistroke
.15101 .78853 L
.14758 .78483 L
.14426 .78112 L
.14102 .77687 L
.13796 .77306 L
.13499 .76866 L
.13204 .7638 L
.12937 .75932 L
.12664 .75421 L
.12393 .74932 L
.12124 .74426 L
.11852 .73854 L
.11591 .73404 L
.11327 .7291 L
.11061 .72409 L
.10788 .71979 L
.1053 .71523 L
.10262 .71151 L
.10014 .70814 L
.0977 .70514 L
.09539 .70263 L
.09338 .70062 L
.09158 .69903 L
.08999 .69781 L
.08873 .69692 L
.08771 .69632 L
.08695 .69594 L
.08644 .69578 L
.08618 .69578 L
.08613 .69593 L
.08626 .69616 L
.08653 .69647 L
.0869 .69681 L
.08731 .69715 L
.08771 .69747 L
.08806 .69776 L
.08838 .69802 L
.08866 .69827 L
.08891 .69849 L
.08912 .69868 L
.08929 .69884 L
.08941 .69895 L
.08948 .69901 L
.0895 .69903 L
.08948 .69901 L
.08944 .69897 L
.0894 .69893 L
.08936 .6989 L
.08934 .69889 L
.08934 .69888 L
Mistroke
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .69901 L
.08934 .69903 L
.08934 .69902 L
.08934 .69896 L
.08934 .69887 L
.08934 .69875 L
.08935 .69862 L
.08935 .69848 L
.08935 .69831 L
.08936 .6981 L
.08937 .69784 L
.08938 .69754 L
.0894 .69718 L
.08945 .69677 L
.0895 .6963 L
.08955 .69577 L
.08957 .69518 L
.08954 .69451 L
.08946 .69373 L
.08932 .69284 L
.08913 .69178 L
.08893 .69055 L
.08873 .68914 L
.08855 .68765 L
.08841 .68603 L
.08836 .68433 L
.08839 .68254 L
.08854 .68072 L
.08882 .67885 L
.08924 .67681 L
.08983 .67479 L
.09061 .6726 L
.09157 .67032 L
.0927 .66789 L
.094 .66559 L
.09539 .66314 L
.09687 .66071 L
.09835 .65814 L
.09985 .65572 L
.10135 .65332 L
.10292 .65087 L
.10455 .64857 L
.10629 .64622 L
.10814 .64409 L
.11002 .64203 L
Mistroke
.112 .6402 L
.11393 .63855 L
.11585 .63717 L
.11779 .63599 L
.1196 .63501 L
.12132 .63419 L
.12314 .63359 L
.12471 .63321 L
.1263 .63306 L
.1279 .63313 L
.1294 .63347 L
.1309 .63402 L
.13233 .63475 L
.13354 .63559 L
.13477 .6365 L
.13598 .63746 L
.13705 .63841 L
.1381 .6394 L
.13897 .64036 L
.13967 .6413 L
.14017 .64221 L
.14048 .64309 L
.14068 .64394 L
.14077 .6447 L
.14079 .64534 L
.14075 .64592 L
.14071 .64642 L
.14068 .64686 L
.14066 .64723 L
.14066 .64752 L
.14069 .64768 L
.14071 .64767 L
.14073 .64747 L
.14073 .6471 L
.14071 .64654 L
.14066 .64584 L
.14055 .645 L
.14041 .64404 L
.14029 .6429 L
.14025 .64153 L
.14033 .63995 L
.14056 .63811 L
.14099 .63608 L
.14165 .63386 L
.14247 .63143 L
.14352 .62908 L
.14469 .62669 L
.14592 .62422 L
.14716 .62178 L
.14842 .61956 L
Mistroke
.14953 .61722 L
.15062 .61497 L
.15169 .61269 L
.15269 .61058 L
.1536 .60845 L
.15446 .6063 L
.15527 .60428 L
.15605 .60216 L
.15679 .59993 L
.15743 .59775 L
.1581 .59537 L
.1587 .59307 L
.15928 .59061 L
.1598 .588 L
.1602 .58548 L
.16047 .58269 L
.1606 .57999 L
.16056 .5771 L
.16039 .57394 L
.16008 .57052 L
.15969 .5677 L
.15926 .56433 L
.15883 .56038 L
.15841 .5571 L
.15801 .55359 L
.15765 .54978 L
.15737 .54588 L
.15718 .54198 L
.15708 .53814 L
.15708 .53418 L
.15717 .53031 L
.15733 .52637 L
.15749 .52226 L
.15758 .51794 L
.15756 .51385 L
.15738 .50937 L
.157 .50497 L
.1564 .50071 L
.15554 .4962 L
.15454 .49209 L
.1533 .48767 L
.1518 .48384 L
.15013 .47988 L
.14832 .47607 L
.14661 .47248 L
.14475 .46904 L
.14283 .46591 L
.14124 .46293 L
.13968 .46003 L
.13839 .45758 L
Mistroke
.13732 .45519 L
.13654 .45288 L
.13603 .45065 L
.13578 .44857 L
.13582 .44657 L
.13614 .44464 L
.13677 .44278 L
.13767 .4409 L
.13882 .43898 L
.1402 .43696 L
.14175 .4348 L
.1435 .43246 L
.14544 .43004 L
.14747 .42747 L
.14964 .42502 L
.15191 .4225 L
.15428 .41997 L
.15675 .41744 L
.1593 .41489 L
.16189 .41248 L
.16463 .40996 L
.16737 .40753 L
.17021 .40497 L
.17308 .40244 L
.17599 .39986 L
.17885 .39733 L
.18159 .39486 L
.18464 .39231 L
.18719 .38979 L
.18998 .38723 L
.19276 .38465 L
.19553 .38202 L
.19837 .37958 L
.2011 .37716 L
.2039 .37485 L
.2068 .37263 L
.20991 .37066 L
.21259 .36872 L
.21542 .36685 L
.21812 .36504 L
.22112 .36319 L
.22418 .36137 L
.22712 .3596 L
.2301 .35787 L
.23289 .3563 L
.23546 .35485 L
.23792 .35359 L
.23984 .35252 L
.24173 .35156 L
.24321 .3507 L
Mistroke
.24437 .34985 L
.24516 .34894 L
.24563 .34806 L
.24584 .34698 L
.24585 .34569 L
.24575 .34422 L
.24557 .34236 L
.24541 .34013 L
.24534 .33739 L
.24543 .33445 L
.2457 .33105 L
.2461 .32715 L
.2466 .32308 L
.24725 .31882 L
.24806 .31408 L
.24894 .3098 L
.2499 .3052 L
.25093 .30054 L
.25194 .29569 L
.25296 .29135 L
.25398 .28671 L
.25497 .28201 L
.25597 .27739 L
.25697 .27285 L
.25798 .26845 L
.25901 .26368 L
.26001 .25959 L
.26099 .25518 L
.26191 .25064 L
.26275 .24636 L
.2635 .24178 L
.26415 .23715 L
.2647 .23289 L
.26517 .2281 L
.26557 .2238 L
.26591 .21977 L
.26623 .21562 L
.26657 .21176 L
.26694 .20781 L
.26742 .20404 L
.26804 .20041 L
.26884 .19715 L
.26985 .19384 L
.27108 .19059 L
.27257 .18731 L
.27421 .18406 L
.27606 .18058 L
.27817 .17686 L
.28039 .17303 L
.28281 .16877 L
Mistroke
.28537 .16446 L
.28811 .15988 L
.29083 .15552 L
.29369 .15085 L
.29662 .14573 L
.29957 .14151 L
.30255 .13694 L
.30553 .13233 L
.30843 .12813 L
.31129 .12388 L
.31428 .1199 L
.31693 .11608 L
.31969 .11232 L
.3221 .10871 L
.32443 .1052 L
.32656 .10175 L
.32849 .09854 L
.33025 .09525 L
.33189 .09236 L
.3335 .08956 L
.33508 .08694 L
.33673 .0845 L
.33851 .08216 L
.34059 .08004 L
.34309 .0779 L
.34581 .0758 L
.34867 .07374 L
.35184 .07173 L
.35523 .06971 L
.35855 .06787 L
.36205 .06607 L
.36531 .06435 L
.36832 .06281 L
.37136 .06135 L
.37408 .06017 L
.37634 .05916 L
.37845 .05838 L
.38044 .05782 L
.38233 .0575 L
.38417 .05737 L
.38595 .0574 L
.38782 .05753 L
.3899 .05761 L
.39201 .05764 L
.39421 .05759 L
.3966 .0574 L
.39915 .05705 L
.40186 .05661 L
.40453 .05612 L
.40721 .05562 L
Mistroke
.40963 .0551 L
.41205 .05455 L
.41441 .05399 L
.41677 .0534 L
.41919 .0528 L
.42173 .05222 L
.42448 .05167 L
.42755 .05117 L
.43043 .05073 L
.43355 .05033 L
.43649 .05001 L
.43968 .04972 L
.44272 .04946 L
.4456 .0492 L
.44831 .04897 L
.45111 .04879 L
.45345 .04868 L
.45577 .04865 L
.45794 .04869 L
.46005 .04878 L
.46204 .04891 L
.46408 .04905 L
.46631 .04917 L
.46852 .04926 L
.47094 .04934 L
.47352 .04942 L
.47625 .04951 L
.47898 .04959 L
.48175 .04968 L
.48427 .04976 L
.48656 .04983 L
.48859 .04989 L
.49033 .04994 L
.49178 .04998 L
.49304 .05002 L
.49409 .05005 L
.49504 .05008 L
.49594 .0501 L
.49688 .05013 L
.49793 .05016 L
.49919 .05019 L
.50061 .05024 L
.50224 .05028 L
.50417 .05034 L
.5064 .0504 L
.50888 .05048 L
.51166 .05055 L
.51448 .05064 L
.51749 .05072 L
.52053 .05081 L
Mistroke
.52369 .05089 L
.5268 .05098 L
.52997 .05105 L
.53306 .05109 L
.53616 .05113 L
.53918 .05117 L
.54206 .05122 L
.54479 .0513 L
.54741 .05143 L
.54995 .05161 L
.55247 .05184 L
.55486 .05213 L
.5572 .05247 L
.55966 .05286 L
.56212 .05329 L
.56459 .05376 L
.56722 .05422 L
.56962 .0547 L
.57203 .05516 L
.57438 .0556 L
.57666 .05604 L
.57891 .05635 L
.58082 .05662 L
.58238 .05681 L
.58367 .05693 L
.58464 .05698 L
.5853 .057 L
.58564 .057 L
.58571 .057 L
.58567 .05699 L
.5857 .05698 L
.5859 .05696 L
.5863 .05696 L
.58693 .05697 L
.58787 .05696 L
.58907 .05694 L
.59048 .05691 L
.59203 .05688 L
.59372 .05689 L
.59545 .05694 L
.59737 .05706 L
.59924 .05725 L
.60101 .05752 L
.6028 .05788 L
.60461 .05833 L
.6064 .05885 L
.60801 .05944 L
.60969 .06006 L
.61135 .06067 L
.61302 .06128 L
Mistroke
.61466 .06186 L
.61627 .06241 L
.61784 .06291 L
.61937 .06335 L
.62088 .06374 L
.62241 .06413 L
.62379 .06451 L
.62517 .06493 L
.62657 .06539 L
.62803 .06594 L
.62956 .06662 L
.6311 .06738 L
.63274 .06826 L
.63466 .06924 L
.63662 .07034 L
.63883 .07151 L
.64122 .07268 L
.64379 .07389 L
.6464 .07509 L
.64901 .07618 L
.65163 .07732 L
.65427 .0783 L
.65704 .07928 L
.65977 .08031 L
.66262 .08139 L
.66562 .08254 L
.66877 .08367 L
.67187 .08486 L
.6751 .08613 L
.67837 .08745 L
.68154 .08868 L
.68472 .08999 L
.68802 .09129 L
.6915 .09283 L
.69469 .09418 L
.69789 .09557 L
.70112 .097 L
.70435 .0984 L
.7075 .09982 L
.7109 .10128 L
.71391 .10259 L
.71715 .10402 L
.72052 .10553 L
.72399 .10699 L
.72745 .10857 L
.73105 .11024 L
.73475 .11185 L
.73838 .11355 L
.74209 .11522 L
.7458 .11686 L
Mistroke
.74937 .11843 L
.75287 .12001 L
.7563 .12154 L
.75968 .12303 L
.76298 .12454 L
.76621 .12602 L
.7695 .12752 L
.77262 .12893 L
.77578 .13037 L
.77892 .13183 L
.78177 .13324 L
.78456 .13465 L
.78711 .13605 L
.78936 .13733 L
.79151 .13856 L
.79323 .13964 L
.79489 .14065 L
.79631 .14163 L
.79755 .14261 L
.79861 .14356 L
.79947 .14456 L
.80019 .14564 L
.8009 .14686 L
.80168 .14827 L
.80259 .14982 L
.80371 .15154 L
.80509 .15358 L
.80671 .15574 L
.80854 .15808 L
.81052 .16059 L
.81267 .16306 L
.81464 .16563 L
.81677 .16817 L
.81899 .17076 L
.82103 .17312 L
.82311 .17553 L
.8251 .17775 L
.82697 .17999 L
.8287 .1821 L
.83029 .18409 L
.83178 .18619 L
.83316 .18822 L
.83448 .19036 L
.83581 .19263 L
.83716 .19482 L
.83858 .19716 L
.84001 .19934 L
.84147 .20153 L
.84293 .20372 L
.84435 .20565 L
Mistroke
.84573 .20761 L
.84701 .20955 L
.84814 .21115 L
.84911 .21269 L
.84994 .21414 L
.85063 .21547 L
.85122 .21668 L
.85174 .21776 L
.85224 .21881 L
.85277 .21993 L
.8534 .2212 L
.85416 .22271 L
.8551 .22441 L
.85628 .22646 L
.85757 .22879 L
.85924 .23135 L
.86116 .23422 L
.86327 .23733 L
.86565 .24059 L
.86822 .24412 L
.87083 .24767 L
.87353 .25144 L
.87595 .25512 L
.87868 .25878 L
.88118 .26198 L
.88394 .26547 L
.88616 .26879 L
.88857 .27207 L
.89103 .27523 L
.89339 .27846 L
.89565 .2816 L
.8978 .28503 L
.90015 .28801 L
.90225 .29118 L
.90444 .29443 L
.90675 .29779 L
.90881 .30098 L
.91061 .30416 L
.91253 .30729 L
.91405 .31008 L
.91569 .31301 L
.91691 .31547 L
.918 .31792 L
.91893 .32013 L
.91969 .32219 L
.92029 .32407 L
.92077 .32586 L
.92116 .32761 L
.9215 .32941 L
.9218 .3312 L
Mistroke
.92214 .33315 L
.92253 .33529 L
.92298 .33733 L
.92347 .33957 L
.92399 .34185 L
.9245 .34424 L
.92497 .34664 L
.9254 .34898 L
.92577 .35141 L
.92606 .35374 L
.92631 .35615 L
.92652 .35826 L
.92674 .36043 L
.92697 .3626 L
.92721 .36474 L
.92747 .36693 L
.92772 .36892 L
.92794 .3709 L
.92812 .37287 L
.92826 .37458 L
.92837 .37625 L
.92845 .37772 L
.92851 .37894 L
.92856 .38009 L
.92859 .38092 L
.92859 .38154 L
.92854 .38194 L
.92842 .38207 L
.92827 .38195 L
.92808 .38161 L
.9279 .38113 L
.92772 .38055 L
.92756 .3799 L
.92743 .37923 L
.92732 .37853 L
.9272 .37779 L
.92707 .37697 L
.9269 .37604 L
.9267 .37495 L
.92648 .37372 L
.92626 .37237 L
.92605 .371 L
.92585 .36955 L
.92566 .36809 L
.92549 .36664 L
.92535 .36533 L
.92522 .36417 L
.92512 .3631 L
.92504 .36224 L
.92498 .36145 L
Mistroke
.92496 .36076 L
.92496 .36018 L
.92497 .35968 L
.92498 .35918 L
.92498 .35857 L
.92496 .35783 L
.92494 .35695 L
.92493 .35587 L
.92491 .35468 L
.92489 .35321 L
.92485 .35144 L
.92478 .3496 L
.9247 .34757 L
.92459 .34559 L
.92446 .34346 L
.92431 .34164 L
.92412 .3398 L
.92389 .33791 L
.92358 .336 L
.92321 .33401 L
.92274 .332 L
.92217 .32977 L
.92148 .32752 L
.92067 .32503 L
.91979 .32253 L
.91881 .32012 L
.91778 .3175 L
.91669 .31503 L
.91561 .31246 L
.9145 .30992 L
.91344 .30774 L
.91238 .30561 L
.9113 .30364 L
.91032 .3018 L
.90938 .30019 L
.90845 .29868 L
.90753 .2972 L
.90665 .29577 L
.90573 .29422 L
.90477 .29258 L
.90373 .2908 L
.90262 .28889 L
.90141 .28683 L
.90014 .28476 L
.8988 .28262 L
.89746 .28057 L
.89607 .27854 L
.89483 .2767 L
.89368 .27507 L
.89262 .27362 L
Mistroke
.89166 .27238 L
.89088 .27137 L
.89023 .27059 L
.88971 .27002 L
.88933 .26966 L
.88908 .26946 L
.88894 .26939 L
.8889 .26941 L
.88893 .26948 L
.889 .26959 L
.88908 .2697 L
.88916 .26978 L
.88922 .26984 L
.88925 .26988 L
.88926 .26991 L
.88926 .26995 L
.88926 .26998 L
.88928 .27002 L
.8893 .27006 L
.88934 .27008 L
.88937 .27005 L
.88939 .26994 L
.88938 .26972 L
.88933 .26939 L
.88923 .26897 L
.88908 .2685 L
.88889 .26805 L
.88867 .26763 L
.88842 .26723 L
.88817 .26687 L
.88792 .26653 L
.88768 .2662 L
.88745 .26587 L
.88725 .26556 L
.88707 .26526 L
.88693 .26501 L
.88684 .26479 L
.88679 .26462 L
.88679 .26449 L
.88683 .26436 L
.88689 .26426 L
.88695 .26421 L
.887 .26422 L
.88704 .26431 L
.88706 .26452 L
.88707 .26488 L
.88706 .26536 L
.88703 .26592 L
.88698 .26649 L
.88693 .26707 L
Mistroke
.88688 .26758 L
.88686 .26801 L
.88686 .2684 L
.88692 .26879 L
.88705 .26923 L
.88726 .26979 L
.88758 .27057 L
.88805 .27161 L
.88866 .27297 L
.88938 .27454 L
.8903 .27652 L
.89136 .27871 L
.89262 .28131 L
.894 .28395 L
.89551 .28685 L
.89712 .2897 L
.89872 .29258 L
.90039 .29533 L
.90186 .29768 L
.90329 .29985 L
.90455 .30169 L
.90569 .3032 L
.90669 .30435 L
.90748 .30519 L
.90811 .30579 L
.9086 .30617 L
.90897 .30641 L
.90927 .30654 L
.90955 .30658 L
.90984 .30657 L
.91014 .30653 L
.91043 .30645 L
.91068 .30636 L
.91091 .30627 L
.91114 .30623 L
.91135 .30625 L
.91149 .30632 L
.91156 .3064 L
.91154 .30646 L
.91141 .3065 L
.91116 .30649 L
.9108 .30645 L
.91033 .3064 L
.90974 .30631 L
.90903 .30614 L
.90822 .30584 L
.90729 .30536 L
.90627 .30463 L
.90514 .30363 L
.9038 .30224 L
Mistroke
.90222 .30037 L
.90052 .298 L
.89837 .29495 L
.89604 .29164 L
.89358 .28799 L
.89088 .28362 L
.88789 .27894 L
.88499 .27399 L
.88185 .26869 L
.87824 .26229 L
.87511 .25714 L
.87168 .25156 L
.86817 .24567 L
.86474 .23983 L
.86097 .23394 L
.85763 .22854 L
.85399 .22315 L
.85031 .21752 L
.84668 .21225 L
.84303 .20645 L
.83937 .20159 L
.83578 .19621 L
.83222 .19097 L
.82869 .18574 L
.82538 .18034 L
.82217 .17552 L
.81926 .1708 L
.81659 .16641 L
.81423 .16208 L
.81219 .1588 L
.81044 .15552 L
.80892 .15273 L
.80764 .15054 L
.80652 .14857 L
.80554 .14694 L
.80464 .14557 L
.80378 .14441 L
.80292 .14344 L
.80198 .14258 L
.8009 .14178 L
.79973 .14105 L
.79832 .14021 L
.79663 .13921 L
.79467 .13807 L
.79237 .13675 L
.78996 .13534 L
.78746 .13391 L
.78473 .1325 L
.78212 .13118 L
.77944 .12993 L
Mistroke
.77704 .12877 L
.7747 .12772 L
.77253 .12677 L
.7706 .1259 L
.76899 .12514 L
.7676 .1245 L
.76653 .124 L
.76574 .12363 L
.76522 .12338 L
.76494 .12322 L
.76486 .12313 L
.76493 .12309 L
.76512 .1231 L
.76541 .12316 L
.76576 .12325 L
.76615 .12339 L
.76656 .12356 L
.76701 .12375 L
.7675 .12397 L
.76806 .12419 L
.76867 .12442 L
.76932 .12464 L
.76998 .12484 L
.77066 .12503 L
.77132 .12523 L
.77195 .12544 L
.77252 .12565 L
.773 .12585 L
.77338 .12603 L
.77368 .12619 L
.77388 .12631 L
.774 .12642 L
.77404 .12649 L
.77401 .12652 L
.77393 .12651 L
.7738 .12646 L
.77363 .12636 L
.77344 .1262 L
.77325 .12598 L
.77311 .12569 L
.77306 .12537 L
.77308 .12504 L
.77314 .12475 L
.77316 .12449 L
.77312 .12426 L
.77298 .12408 L
.77267 .12394 L
.77217 .12382 L
.77139 .12367 L
.77029 .12347 L
Mistroke
.7688 .12317 L
.76689 .12275 L
.76488 .12219 L
.76242 .12146 L
.7595 .12057 L
.75651 .1195 L
.75303 .1183 L
.74987 .117 L
.74627 .11572 L
.74327 .11444 L
.73992 .11319 L
.73713 .11202 L
.73422 .11088 L
.73166 .10984 L
.72912 .10883 L
.72662 .10785 L
.72413 .10692 L
.72138 .10602 L
.71856 .10512 L
.71536 .10424 L
.71156 .10328 L
.70767 .10224 L
.70306 .10108 L
.69787 .09983 L
.69221 .09843 L
.68647 .09688 L
.67983 .09522 L
.67387 .09344 L
.66697 .09165 L
.6607 .08965 L
.65367 .08761 L
.64757 .08531 L
.64127 .08291 L
.63551 .08044 L
.62985 .07771 L
.62463 .07507 L
.61963 .07229 L
.61467 .06959 L
.61027 .06686 L
.60591 .06445 L
.60166 .06184 L
.59764 .05988 L
.5934 .05803 L
.58965 .05634 L
.58576 .05493 L
.58169 .05381 L
.57807 .05292 L
.57426 .05225 L
.57057 .05179 L
.56708 .0515 L
Mistroke
.5635 .05132 L
.56027 .05121 L
.557 .05111 L
.55401 .05098 L
.55107 .05082 L
.5483 .05064 L
.54559 .05044 L
.54297 .05021 L
.5404 .04995 L
.53803 .04972 L
.53572 .04952 L
.53336 .04935 L
.53109 .04924 L
.52879 .04918 L
.52646 .04917 L
.52432 .04921 L
.5222 .04929 L
.5202 .04941 L
.51833 .04957 L
.51662 .04975 L
.51513 .04995 L
.51377 .05014 L
.51256 .05031 L
.51153 .05046 L
.51073 .05059 L
.51016 .05067 L
.50981 .0507 L
.50959 .05067 L
.50948 .05058 L
.50942 .05042 L
.50939 .05022 L
.50936 .04999 L
.5093 .04975 L
.50924 .04951 L
.50924 .04928 L
.50932 .04905 L
.50948 .04883 L
.5097 .04863 L
.50999 .04846 L
.5103 .04831 L
.51064 .04821 L
.51101 .04816 L
.51141 .04816 L
.51186 .0482 L
.51237 .04827 L
.51293 .04835 L
.51355 .04843 L
.51419 .04849 L
.51483 .04854 L
.51546 .04858 L
Mistroke
.51608 .04861 L
.5167 .04864 L
.51727 .04865 L
.5178 .04867 L
.51827 .04867 L
.51864 .04866 L
.5189 .04863 L
.51902 .04858 L
.51897 .04854 L
.5187 .04852 L
.5182 .04851 L
.51747 .04851 L
.51651 .04851 L
.51536 .04851 L
.51406 .04851 L
.51264 .04852 L
.51113 .04855 L
.50956 .04859 L
.50801 .04865 L
.50639 .04875 L
.5047 .04887 L
.50305 .04899 L
.50132 .04912 L
.49948 .04925 L
.49752 .04935 L
.49542 .04945 L
.4931 .04954 L
.49054 .0496 L
.48806 .04966 L
.48518 .04969 L
.48231 .0497 L
.47913 .04968 L
.47584 .04961 L
.4726 .04951 L
.46914 .04937 L
.46582 .04923 L
.46242 .04909 L
.45926 .04898 L
.45598 .04887 L
.45269 .04877 L
.44961 .04867 L
.44637 .04856 L
.44302 .04846 L
.44 .04836 L
.4367 .04825 L
.43339 .04813 L
.42992 .04799 L
.42649 .04782 L
.42298 .04762 L
.41946 .04743 L
Mistroke
.41622 .04726 L
.41326 .04713 L
.41042 .04704 L
.40794 .04701 L
.40542 .04706 L
.40335 .0472 L
.40135 .04744 L
.39936 .04779 L
.39734 .04831 L
.39536 .04902 L
.39311 .04987 L
.39049 .05092 L
.38788 .05219 L
.38481 .05371 L
.38127 .05523 L
.37783 .05696 L
.3743 .05876 L
.37026 .06063 L
.36663 .06235 L
.36336 .06389 L
.35988 .06552 L
.35704 .067 L
.35401 .06845 L
.35167 .06979 L
.34946 .07095 L
.34727 .07203 L
.34497 .07308 L
.34254 .07422 L
.33994 .07552 L
.33757 .0768 L
.33474 .07831 L
.33174 .08 L
.32833 .08182 L
.32526 .08339 L
.32185 .08506 L
.31888 .08644 L
.31588 .0877 L
.31354 .08872 L
.31141 .08959 L
.30971 .09015 L
.30846 .09051 L
.30766 .09068 L
.30721 .09068 L
.30703 .09055 L
.30707 .0903 L
.30729 .09002 L
.30759 .08977 L
.30791 .08956 L
.30821 .08937 L
.30849 .08919 L
Mistroke
.30876 .08903 L
.30905 .0889 L
.30937 .08875 L
.30973 .08857 L
.31013 .08836 L
.31054 .08814 L
.31096 .08792 L
.31137 .0877 L
.31174 .0875 L
.31206 .08733 L
.31235 .08719 L
.31261 .0871 L
.31285 .08705 L
.31309 .08704 L
.31329 .08706 L
.31342 .0871 L
.31346 .08714 L
.31337 .08717 L
.31316 .08717 L
.31284 .08714 L
.31243 .08705 L
.31197 .08692 L
.31152 .08679 L
.31112 .0867 L
.31077 .08666 L
.31043 .08668 L
.31008 .08681 L
.30969 .08706 L
.30926 .08748 L
.30876 .08807 L
.30817 .08882 L
.30745 .08976 L
.30659 .09084 L
.30553 .09201 L
.3042 .09336 L
.3026 .09495 L
.30048 .09664 L
.29796 .09844 L
.2949 .10042 L
.29144 .10236 L
.2876 .10444 L
.28343 .10669 L
.2788 .10889 L
.27437 .11137 L
.26933 .11384 L
.26434 .11654 L
.25926 .11924 L
.25413 .12209 L
.24914 .12484 L
.24414 .12766 L
Mistroke
.23943 .13031 L
.23505 .13297 L
.23116 .13535 L
.22756 .13775 L
.2248 .1396 L
.22236 .14131 L
.22028 .14283 L
.21867 .14402 L
.21746 .14494 L
.21666 .14563 L
.21622 .1461 L
.21606 .14637 L
.21609 .14649 L
.21623 .14653 L
.21643 .1465 L
.21662 .14643 L
.21677 .14635 L
.21687 .14626 L
.21694 .14619 L
.21697 .14613 L
.21698 .1461 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21699 .14609 L
.21702 .1461 L
.21711 .1461 L
.21723 .1461 L
.21735 .14611 L
.2174 .14611 L
.21736 .14611 L
.21719 .1461 L
.21688 .14609 L
.21643 .14608 L
.21584 .14606 L
.21514 .14603 L
.21437 .14599 L
.21353 .14594 L
.21271 .14587 L
.21191 .14578 L
.21116 .14569 L
.2105 .1456 L
.20997 .14554 L
Mistroke
.20961 .14553 L
.20944 .14561 L
.20942 .14579 L
.20953 .14609 L
.20969 .14652 L
.20987 .14709 L
.21001 .14779 L
.21006 .14865 L
.21001 .14966 L
.20985 .15081 L
.20958 .15204 L
.20915 .15344 L
.20852 .15504 L
.20768 .15664 L
.20659 .15845 L
.20526 .16046 L
.20376 .16236 L
.2021 .16433 L
.20033 .16647 L
.19867 .16841 L
.19692 .17045 L
.19517 .17238 L
.19359 .17402 L
.19208 .17558 L
.1907 .17702 L
.18956 .17814 L
.1887 .17906 L
.18814 .17976 L
.18788 .18022 L
.18789 .18047 L
.18812 .18057 L
.18853 .18054 L
.18902 .18042 L
.1895 .18029 L
.1899 .18017 L
.1902 .1801 L
.19038 .18008 L
.19041 .18014 L
.19029 .18027 L
.19002 .18044 L
.18965 .18063 L
.18921 .18085 L
.18873 .18108 L
.18817 .1813 L
.18759 .18153 L
.18697 .18174 L
.18634 .18194 L
.18576 .18212 L
.18526 .18228 L
.18486 .18241 L
Mistroke
.18457 .1825 L
.1844 .18253 L
.18436 .18251 L
.18446 .18244 L
.18475 .18234 L
.18497 .18225 L
.18521 .18215 L
.18555 .18204 L
.18598 .18192 L
.1865 .18175 L
.1871 .18151 L
.1878 .18115 L
.18857 .18064 L
.1894 .17997 L
.19025 .17915 L
.19108 .17819 L
.19187 .17711 L
.19259 .17603 L
.19322 .17486 L
.19382 .17369 L
.19437 .17261 L
.19488 .17156 L
.19536 .17066 L
.19582 .16987 L
.19626 .16925 L
.19666 .16884 L
.19701 .16868 L
.19732 .16876 L
.19757 .16908 L
.19778 .16958 L
.19797 .17019 L
.19817 .17085 L
.19837 .17152 L
.19855 .17219 L
.19871 .17287 L
.19882 .17354 L
.19887 .17422 L
.19889 .17487 L
.1989 .17545 L
.19892 .17592 L
.19896 .17626 L
.19901 .1765 L
.19905 .17667 L
.19907 .17681 L
.19903 .17694 L
.19888 .17709 L
.19859 .17726 L
.19817 .17747 L
.19759 .17772 L
.19687 .178 L
Mistroke
.19602 .17827 L
.19513 .17851 L
.19417 .17878 L
.19316 .17906 L
.19215 .17935 L
.19117 .17966 L
.19032 .17996 L
.18958 .18018 L
.189 .1803 L
.18863 .18033 L
.1884 .18029 L
.18827 .18021 L
.1882 .18013 L
.18814 .18008 L
.18801 .18005 L
.18778 .18003 L
.18746 .18002 L
.18705 .18001 L
.18656 .17999 L
.18603 .17998 L
.18547 .17996 L
.18494 .17994 L
.18445 .17993 L
.18391 .17991 L
.18341 .17989 L
.183 .17985 L
.18273 .17981 L
.1826 .17977 L
.18262 .17976 L
.18278 .17977 L
.18307 .17982 L
.18349 .17989 L
.184 .17998 L
.18461 .18007 L
.18532 .18017 L
.18615 .18031 L
.18701 .1805 L
.1878 .18075 L
.18851 .18109 L
.18905 .18155 L
.18936 .18214 L
.18938 .18288 L
.18907 .1838 L
.18844 .18491 L
.18759 .18612 L
.18635 .18758 L
.18476 .18932 L
.18313 .19119 L
.18122 .19345 L
.17901 .19594 L
Mistroke
.17661 .19857 L
.17415 .20154 L
.17164 .20472 L
.16905 .20802 L
.16652 .21152 L
.16394 .21507 L
.16132 .21894 L
.15859 .22294 L
.15592 .22681 L
.15305 .23103 L
.15017 .23538 L
.14723 .23991 L
.14417 .24424 L
.14086 .24952 L
.13794 .25366 L
.13455 .2592 L
.1313 .26352 L
.12831 .26844 L
.12519 .2731 L
.12203 .27731 L
.11877 .28195 L
.11576 .28637 L
.11299 .29051 L
.11019 .29419 L
.10758 .29767 L
.10515 .30057 L
.10294 .30341 L
.10135 .30563 L
.09978 .30781 L
.09869 .30941 L
.09786 .31078 L
.09727 .31194 L
.09693 .31289 L
.09682 .31364 L
.09688 .31424 L
.09701 .31474 L
.09715 .31525 L
.09726 .31581 L
.09731 .31648 L
.09723 .31734 L
.09699 .31848 L
.09659 .31997 L
.09605 .32165 L
.09542 .32356 L
.09472 .32585 L
.09393 .32858 L
.09308 .33138 L
.09221 .33408 L
.09135 .33741 L
.09053 .34095 L
Mistroke
.08973 .34476 L
.08895 .34834 L
.08819 .35263 L
.08744 .35629 L
.08665 .35991 L
.08582 .36399 L
.08502 .36775 L
.08424 .37154 L
.08353 .3755 L
.08288 .37902 L
.0823 .38251 L
.0818 .38589 L
.08139 .38876 L
.08104 .39142 L
.08076 .39373 L
.08052 .39582 L
.08032 .39735 L
.08015 .39861 L
.08003 .39958 L
.07995 .40026 L
.07992 .40067 L
.07994 .40085 L
.07998 .40086 L
.08003 .40076 L
.08007 .4006 L
.08009 .40042 L
.0801 .40027 L
.0801 .40016 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
Mistroke
.0802 .40006 L
.08028 .40002 L
.08036 .39998 L
.08039 .39996 L
.08036 .39998 L
.08024 .40003 L
.08002 .40013 L
.07967 .40029 L
.0792 .40051 L
.07864 .40076 L
.07804 .40104 L
.07745 .40131 L
.07692 .40155 L
.07644 .40176 L
.07601 .40191 L
.07565 .40199 L
.0754 .402 L
.07529 .40194 L
.07533 .40181 L
.07549 .40163 L
.07575 .40139 L
.07608 .40112 L
.07644 .40084 L
.0768 .40057 L
.07707 .40035 L
.07724 .40017 L
.07732 .40006 L
.07737 .4 L
.0774 .39998 L
.07742 .39998 L
.07745 .39999 L
.07752 .39999 L
.07764 .39998 L
.07783 .39998 L
.07808 .39999 L
.07838 .40004 L
.07874 .40014 L
.07916 .40028 L
.07964 .40045 L
.08018 .40066 L
.08077 .40089 L
.08136 .40114 L
.08192 .40138 L
.08245 .40161 L
.08294 .40179 L
.08339 .40193 L
.08384 .40205 L
.08429 .40215 L
.08477 .40225 L
.08528 .40234 L
Mistroke
.08581 .40246 L
.08632 .40263 L
.08683 .40285 L
.08734 .40315 L
.08784 .40357 L
.08838 .40412 L
.08897 .40481 L
.08955 .4056 L
.09017 .40651 L
.09079 .40752 L
.0914 .40865 L
.09193 .40991 L
.09236 .41131 L
.09266 .41294 L
.09287 .4148 L
.09297 .41699 L
.093 .41924 L
.09296 .42193 L
.09285 .42466 L
.09263 .42787 L
.09229 .43127 L
.09176 .43401 L
.09107 .4373 L
.09021 .44006 L
.08917 .44335 L
.08794 .44583 L
.08651 .44825 L
.08501 .45045 L
.08387 .45215 L
.08245 .45345 L
.08099 .45445 L
.07985 .45519 L
.07879 .45569 L
.07777 .45601 L
.07684 .45617 L
.07611 .45619 L
.07557 .45609 L
.07518 .45588 L
.07492 .45562 L
.07474 .45531 L
.0746 .45501 L
.07447 .45473 L
.07435 .45447 L
.07416 .45422 L
.07389 .45397 L
.07361 .45373 L
.07337 .45351 L
.07316 .45332 L
.07299 .45316 L
.07287 .45306 L
Mistroke
.0728 .453 L
.07278 .45298 L
.0728 .45299 L
.07284 .45303 L
.07288 .45307 L
.07292 .4531 L
.07293 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07295 .45312 L
.07299 .45312 L
.07308 .45315 L
.07321 .4532 L
.07334 .45328 L
.07338 .45335 L
.0733 .45339 L
.07309 .4534 L
.07271 .45336 L
.0721 .45326 L
.07127 .45307 L
.07027 .45279 L
.06918 .4524 L
.06813 .4519 L
.06726 .45129 L
.06618 .45057 L
.06525 .44976 L
.06429 .44884 L
.06337 .44783 L
.06265 .44673 L
.06219 .4456 L
.06196 .44447 L
.0619 .44329 L
.06197 .4421 L
.06213 .44088 L
.06231 .43961 L
.06244 .4383 L
.06253 .43698 L
.06258 .43559 L
.06262 .4342 L
.06262 .4329 L
Mistroke
.06262 .43164 L
.0626 .4304 L
.06259 .42919 L
.06261 .42804 L
.06267 .4269 L
.0628 .42573 L
.06301 .42459 L
.06332 .42344 L
.0637 .42229 L
.06416 .42116 L
.06468 .42016 L
.06522 .41918 L
.06578 .41824 L
.06633 .41735 L
.06685 .41658 L
.06733 .41587 L
.06777 .41527 L
.06818 .41479 L
.06854 .41446 L
.06886 .41427 L
.06913 .4142 L
.06937 .41423 L
.06959 .4143 L
.0698 .41437 L
.07 .41444 L
.07018 .41448 L
.07039 .41449 L
.07063 .41448 L
.07089 .41451 L
.07118 .41456 L
.0715 .41466 L
.07183 .41481 L
.07215 .41498 L
.07244 .41517 L
.0727 .41533 L
.07292 .41548 L
.07308 .41559 L
.07317 .41575 L
.07319 .4158 L
.07314 .41599 L
.07297 .41617 L
.0727 .41631 L
.07234 .41639 L
.0719 .41642 L
.0714 .41637 L
.07085 .41627 L
.0703 .41611 L
.06981 .41595 L
.06939 .41581 L
.06906 .4157 L
Mistroke
.06882 .41557 L
.06865 .41543 L
.06856 .41525 L
.06854 .41502 L
.06855 .41476 L
.06859 .41447 L
.06864 .41418 L
.0687 .4139 L
.06875 .41365 L
.06877 .41344 L
.06878 .41324 L
.06879 .41303 L
.06879 .4128 L
.0688 .41258 L
.06881 .41239 L
.06881 .41224 L
.06882 .41213 L
.06882 .41207 L
.06882 .41205 L
.06882 .41207 L
.06882 .4121 L
.06882 .41215 L
.06881 .41218 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06882 .41216 L
.06882 .41209 L
.06882 .41199 L
.06883 .41188 L
.06883 .41184 L
.06883 .41187 L
.06882 .41201 L
.06881 .41228 L
.0688 .41269 L
.06878 .41323 L
.06876 .41388 L
.06874 .41459 L
Mistroke
.06872 .41533 L
.06871 .41602 L
.06872 .41665 L
.06874 .41726 L
.06876 .41788 L
.06876 .41846 L
.06873 .41896 L
.06866 .41939 L
.06854 .41976 L
.06837 .42011 L
.06815 .42045 L
.0679 .42079 L
.06762 .42114 L
.06732 .42155 L
.06703 .42202 L
.06674 .42252 L
.06645 .42301 L
.06618 .42347 L
.06596 .42384 L
.06581 .42407 L
.06572 .42417 L
.06569 .42418 L
.06569 .42417 L
.0657 .42416 L
.06567 .42423 L
.0656 .42442 L
.06546 .42479 L
.06525 .42532 L
.06496 .42597 L
.06463 .42669 L
.06427 .42744 L
.06393 .42815 L
.06361 .42885 L
.06332 .42954 L
.0631 .43022 L
.06297 .43083 L
.06294 .43132 L
.06304 .43162 L
.06325 .43175 L
.06355 .43173 L
.0639 .43162 L
.06425 .43148 L
.06457 .43137 L
.06484 .43135 L
.06501 .43144 L
.06508 .43164 L
.06504 .43194 L
.0649 .43233 L
.06469 .43284 L
.0644 .43346 L
Mistroke
.06408 .43418 L
.06374 .43495 L
.06338 .43578 L
.06306 .43666 L
.06278 .43753 L
.06257 .43836 L
.06242 .43911 L
.06232 .43979 L
.06227 .44039 L
.06227 .44088 L
.0623 .44124 L
.06234 .44146 L
.06237 .44155 L
.06237 .4415 L
.06235 .44131 L
.06232 .44099 L
.06229 .44053 L
.06229 .43996 L
.06233 .43929 L
.06241 .43856 L
.06255 .43779 L
.06276 .43698 L
.06303 .43618 L
.06335 .4354 L
.06369 .43465 L
.06402 .43395 L
.06431 .43331 L
.06455 .4327 L
.06474 .43214 L
.06485 .43162 L
.06489 .43111 L
.06484 .43057 L
.06471 .42998 L
.06451 .42933 L
.06427 .42866 L
.064 .42794 L
.0637 .42716 L
.06342 .42628 L
.06319 .42529 L
.06301 .42429 L
.06289 .42324 L
.06281 .42216 L
.06278 .42115 L
.0628 .42014 L
.06289 .41912 L
.06302 .4181 L
.06319 .41711 L
.0634 .41623 L
.06363 .41539 L
.0639 .41466 L
Mistroke
.06419 .41402 L
.06449 .41349 L
.06478 .41303 L
.06507 .41265 L
.06536 .41235 L
.06562 .41214 L
.06585 .41202 L
.06603 .41198 L
.06615 .412 L
.0662 .41203 L
.06619 .41206 L
.06613 .4121 L
.06605 .41214 L
.06596 .41219 L
.06591 .41223 L
.06591 .41226 L
.06597 .41229 L
.06609 .41232 L
.06628 .41235 L
.06654 .41237 L
.06687 .41239 L
.06728 .41239 L
.06775 .41239 L
.06828 .41239 L
.06889 .41237 L
.06958 .41235 L
.07031 .41233 L
.07106 .41229 L
.07184 .41225 L
.07262 .41221 L
.07336 .41217 L
.07405 .41213 L
.07471 .4121 L
.07534 .41206 L
.07594 .41202 L
.07646 .41197 L
.07686 .41191 L
.07712 .41185 L
.0772 .41183 L
.07706 .41189 L
.07667 .41205 L
.07606 .4123 L
.07527 .41266 L
.07441 .4131 L
.07353 .41362 L
.0727 .41421 L
.07191 .41488 L
.07112 .41561 L
.07031 .41641 L
.06955 .41716 L
Mistroke
.06893 .41798 L
.06853 .41883 L
.06833 .41972 L
.06828 .42064 L
.06831 .42161 L
.0684 .4226 L
.06849 .42366 L
.06849 .42482 L
.06839 .42606 L
.06822 .42733 L
.06802 .42854 L
.06777 .42974 L
.06748 .43099 L
.06713 .43227 L
.06674 .43357 L
.06631 .43475 L
.06583 .43591 L
.06534 .43706 L
.06484 .43816 L
.06436 .43918 L
.06391 .44008 L
.06353 .44081 L
.0632 .44149 L
.06292 .44213 L
.06268 .44272 L
.06249 .44323 L
.06234 .44364 L
.06223 .44393 L
.06216 .44408 L
.06214 .44411 L
.06217 .44401 L
.06221 .44381 L
.06227 .44356 L
.06231 .4433 L
.06234 .44306 L
.06235 .44281 L
.06236 .44255 L
.06236 .4423 L
.06237 .44205 L
.06238 .4418 L
.06239 .44158 L
.0624 .44138 L
.0624 .44123 L
.0624 .44112 L
.06241 .44106 L
.06241 .44104 L
.06241 .44106 L
.0624 .44109 L
.0624 .44113 L
.0624 .44117 L
Mistroke
.0624 .44118 L
.0624 .44118 L
.0624 .44116 L
.06241 .4411 L
.06241 .441 L
.06241 .44089 L
.06242 .44083 L
.06241 .44085 L
.06241 .44098 L
.0624 .44123 L
.06238 .44159 L
.06237 .44207 L
.06235 .44266 L
.06233 .44331 L
.06231 .444 L
.06228 .44471 L
.06226 .44536 L
.06222 .44603 L
.06216 .44669 L
.06209 .44737 L
.06202 .44784 L
.06195 .44821 L
.06189 .44839 L
.06188 .44844 L
.06194 .44842 L
.06209 .44837 L
.06236 .44835 L
.06274 .4484 L
.06322 .44855 L
.06381 .44878 L
.06446 .44907 L
.0652 .44944 L
.06603 .4499 L
.06687 .45048 L
.06782 .45116 L
.06868 .45197 L
.06953 .45294 L
.07033 .45409 L
.07101 .45543 L
.07154 .45694 L
.07189 .45842 L
.07209 .45999 L
.07213 .46166 L
.07205 .46341 L
.07188 .46501 L
.07164 .4665 L
.07138 .46798 L
.07109 .46939 L
.07079 .47051 L
.07048 .47147 L
Mistroke
.07017 .47225 L
.0699 .47285 L
.0697 .47325 L
.06958 .47348 L
.06955 .47354 L
.06959 .47345 L
.06965 .47322 L
.06971 .47295 L
.06972 .47255 L
.06968 .47203 L
.06957 .47138 L
.06941 .4706 L
.06924 .4697 L
.06907 .46873 L
.06895 .46767 L
.06887 .46655 L
.06885 .46544 L
.06887 .4643 L
.06889 .4632 L
.06892 .46226 L
.06897 .46141 L
.06904 .46065 L
.06914 .45997 L
.06928 .45939 L
.06945 .45892 L
.06962 .45853 L
.06975 .45824 L
.06985 .45803 L
.06987 .45788 L
.06982 .45774 L
.06973 .45761 L
.06965 .45748 L
.0696 .45733 L
.06959 .45718 L
.06961 .45702 L
.06965 .45688 L
.0697 .45675 L
.06974 .45659 L
.06978 .45656 L
.0698 .45638 L
.06982 .4562 L
.06986 .45604 L
.06992 .45589 L
.06999 .45575 L
.07006 .45562 L
.07012 .45552 L
.07017 .45547 L
.07019 .45547 L
.07018 .4555 L
.07016 .45552 L
Mistroke
.07014 .45554 L
.07014 .45558 L
.07017 .45562 L
.07021 .45566 L
.07025 .4557 L
.07027 .45572 L
.07026 .45571 L
.0702 .45565 L
.07009 .45556 L
.06993 .45542 L
.06973 .45524 L
.06949 .45502 L
.06921 .45477 L
.0689 .4545 L
.06858 .45421 L
.06826 .45392 L
.06793 .45367 L
.06763 .45346 L
.06738 .45332 L
.06721 .45328 L
.06715 .45335 L
.06723 .45351 L
.06748 .45374 L
.06794 .45401 L
.06859 .45427 L
.0694 .4545 L
.07039 .45468 L
.07158 .45477 L
.07299 .4548 L
.07429 .45476 L
.07573 .45465 L
.07732 .45449 L
.07885 .45428 L
.08045 .45402 L
.0818 .45374 L
.08313 .45345 L
.0844 .4532 L
.0855 .453 L
.08644 .45286 L
.08723 .45278 L
.08785 .45275 L
.08831 .45276 L
.08868 .4528 L
.08896 .45283 L
.08917 .45286 L
.08933 .45288 L
.08944 .45288 L
.08949 .45288 L
.08951 .45288 L
.08949 .45287 L
Mistroke
.08945 .45286 L
.08941 .45283 L
.08936 .45279 L
.08933 .45276 L
.08932 .45274 L
.08931 .45274 L
.08931 .45277 L
.08931 .45281 L
.08931 .45287 L
.08931 .45299 L
.0893 .45316 L
.08929 .45343 L
.08928 .45378 L
.08926 .45423 L
.08924 .45476 L
.08922 .45536 L
.0892 .45601 L
.08918 .45668 L
.08918 .45729 L
.0892 .45781 L
.08922 .45824 L
.08925 .45864 L
.08927 .45901 L
.08927 .45937 L
.08921 .45974 L
.08908 .46019 L
.08887 .46073 L
.0886 .46136 L
.08828 .46207 L
.08793 .46286 L
.08756 .46375 L
.0872 .46469 L
.08685 .46573 L
.08652 .46682 L
.08622 .46793 L
.08595 .469 L
.08576 .46991 L
.08561 .47074 L
.08555 .47134 L
.08558 .47179 L
.08573 .47205 L
.08595 .47216 L
.08616 .47216 L
.08634 .47209 L
.08642 .47198 L
.08639 .47187 L
.0862 .47181 L
.0858 .47186 L
.08512 .47208 L
.08415 .47252 L
Mistroke
.08289 .47322 L
.08135 .47425 L
.07978 .47561 L
.07817 .47729 L
.07618 .47938 L
.07385 .48197 L
.07212 .48451 L
.06973 .48788 L
.068 .49106 L
.06613 .4948 L
.06469 .49863 L
.06339 .50265 L
.06233 .50687 L
.06164 .51117 L
.06132 .51536 L
.06125 .5198 L
.06143 .52454 L
.06179 .52926 L
.06231 .53348 L
.06293 .53864 L
.06357 .54278 L
.06426 .54773 L
.06498 .55158 L
.06568 .55554 L
.06639 .55966 L
.06709 .56341 L
.06774 .56716 L
.06833 .5705 L
.06887 .57371 L
.06935 .5767 L
.06973 .5796 L
.07001 .58201 L
.07022 .58457 L
.07038 .5869 L
.07052 .58936 L
.07063 .59187 L
.07073 .5942 L
.07083 .59659 L
.07095 .59897 L
.07109 .60098 L
.07125 .60295 L
.07142 .60471 L
.07158 .60636 L
.07174 .60803 L
.07192 .60951 L
.07209 .61098 L
.07228 .6124 L
.07246 .61377 L
.07265 .61508 L
.07283 .61634 L
Mistroke
.073 .61741 L
.07316 .61859 L
.0733 .6199 L
.07344 .62115 L
.07361 .62249 L
.07383 .62391 L
.07411 .62536 L
.07443 .62676 L
.07477 .62809 L
.07511 .62932 L
.07545 .63055 L
.07579 .63183 L
.07612 .63319 L
.07644 .63467 L
.07675 .6362 L
.07706 .63785 L
.07737 .6396 L
.0777 .64141 L
.07806 .643 L
.07842 .64487 L
.07878 .64656 L
.07914 .6484 L
.07949 .65043 L
.07984 .6526 L
.08019 .65465 L
.08053 .65676 L
.08085 .65893 L
.08113 .66092 L
.08138 .66285 L
.08158 .66468 L
.08175 .66638 L
.08187 .66781 L
.08197 .66911 L
.08204 .67022 L
.08208 .6711 L
.08209 .67172 L
.08206 .6721 L
.08202 .67227 L
.08197 .6723 L
.08194 .67222 L
.08193 .67207 L
.08193 .67189 L
.08193 .67174 L
.08194 .67168 L
.08194 .67167 L
.08194 .67166 L
.08194 .67161 L
.08194 .67151 L
.08194 .67138 L
.08195 .67126 L
Mistroke
.08195 .67116 L
.08194 .67113 L
.0819 .67122 L
.08185 .67149 L
.0818 .67196 L
.08176 .67266 L
.08175 .67358 L
.08178 .67469 L
.08186 .67598 L
.08198 .67725 L
.08215 .67864 L
.08235 .68008 L
.08257 .68152 L
.08281 .68284 L
.08306 .68406 L
.08331 .68507 L
.08356 .68588 L
.08379 .68647 L
.08399 .68682 L
.08413 .68694 L
.08421 .6869 L
.08424 .68677 L
.08424 .68663 L
.08421 .68651 L
.0842 .68645 L
.08421 .6865 L
.08426 .68666 L
.08437 .68695 L
.08453 .68738 L
.08474 .68794 L
.08502 .68864 L
.08539 .68946 L
.08584 .69038 L
.08641 .6914 L
.08709 .69244 L
.08789 .69346 L
.08876 .6944 L
.08972 .69528 L
.09079 .6961 L
.0919 .69687 L
.0932 .69757 L
.09455 .69823 L
.09609 .69887 L
.0977 .69952 L
.09947 .70016 L
.10135 .70074 L
.10325 .70122 L
.10524 .70157 L
.10742 .70186 L
.10953 .70208 L
Mistroke
.11183 .70221 L
.11424 .70222 L
.1166 .70206 L
.11923 .7017 L
.12194 .7011 L
.12469 .70028 L
.12769 .69929 L
.13039 .69814 L
.13289 .6969 L
.13513 .69565 L
.1374 .69444 L
.13951 .69337 L
.14161 .69236 L
.1431 .6915 L
.14432 .69074 L
.14529 .69011 L
.14603 .6896 L
.14654 .6892 L
.14681 .68894 L
.14689 .6888 L
.14685 .68878 L
.14676 .68885 L
.14663 .68896 L
.14648 .68908 L
.14635 .68917 L
.14629 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14626 .68922 L
.14623 .68925 L
.14618 .68931 L
.14614 .6894 L
.1461 .68949 L
.14608 .6896 L
.14609 .68972 L
.14616 .68981 L
.14627 .68984 L
Mistroke
.14645 .68976 L
.1467 .68949 L
.14703 .68897 L
.14741 .68814 L
.14785 .68696 L
.14836 .68543 L
.14894 .68353 L
.14962 .68117 L
.15043 .67852 L
.15132 .67564 L
.15233 .67228 L
.15346 .66894 L
.15461 .66531 L
.15583 .66158 L
.15714 .65801 L
.15835 .65455 L
.15967 .65133 L
.16109 .64843 L
.16241 .64599 L
.16391 .64391 L
.16529 .6423 L
.16678 .64104 L
.16839 .64011 L
.16992 .63945 L
.17155 .63902 L
.1733 .63877 L
.17502 .63865 L
.17683 .63862 L
.1787 .63863 L
.18053 .63861 L
.18231 .63855 L
.184 .6384 L
.18559 .63821 L
.18692 .63801 L
.18824 .63787 L
.18934 .63787 L
.19034 .63803 L
.19124 .63839 L
.19204 .63898 L
.19273 .63982 L
.19341 .64092 L
.19412 .64228 L
.19487 .64386 L
.19579 .64583 L
.19676 .64787 L
.1979 .65025 L
.19929 .65305 L
.2008 .65593 L
.20263 .65921 L
.2045 .66264 L
Mistroke
.20658 .66646 L
.20885 .67029 L
.21148 .67437 L
.21404 .67863 L
.21678 .68321 L
.2192 .68765 L
.22167 .69232 L
.22399 .69708 L
.22609 .70212 L
.22792 .70674 L
.22955 .71161 L
.23091 .71648 L
.23203 .72157 L
.23297 .72626 L
.23371 .73098 L
.23426 .73556 L
.23464 .73957 L
.23485 .74418 L
.23495 .74819 L
.23492 .75242 L
.23479 .75618 L
.23459 .75988 L
.23431 .76357 L
.23393 .76725 L
.2335 .77013 L
.23304 .77313 L
.23259 .77661 L
.23222 .77932 L
.23202 .78214 L
.23205 .78513 L
.23237 .78799 L
.23295 .79089 L
.23376 .79392 L
.23478 .79709 L
.23596 .80055 L
.23713 .80407 L
.23845 .80789 L
.23983 .81201 L
.24114 .81668 L
.24248 .82054 L
.24368 .82501 L
.24477 .82981 L
.24569 .83381 L
.24638 .83825 L
.24682 .8426 L
.24706 .8468 L
.24713 .85062 L
.24707 .8543 L
.24694 .85752 L
.24676 .86048 L
Mistroke
.24653 .8631 L
.24626 .86542 L
.24599 .8675 L
.24576 .86906 L
.24557 .8703 L
.24539 .87121 L
.24519 .87185 L
.24496 .87225 L
.24468 .87247 L
.2443 .87262 L
.24381 .87278 L
.24322 .87302 L
.24254 .87336 L
.2418 .87376 L
.24102 .87421 L
.24024 .87468 L
.23947 .87513 L
.23869 .8755 L
.23795 .87575 L
.23729 .87587 L
.23675 .87586 L
.23637 .87572 L
.23615 .87546 L
.23608 .87511 L
.23614 .87467 L
.23631 .87417 L
.23653 .87365 L
.23677 .87318 L
.23698 .8728 L
.23716 .87251 L
.23729 .87227 L
.23736 .87205 L
.23735 .87181 L
.23724 .87153 L
.23701 .87114 L
.23665 .87063 L
.23614 .86996 L
.23548 .86915 L
.23466 .86824 L
.23372 .86727 L
.23275 .86628 L
.23177 .86528 L
.23083 .86431 L
.22992 .86341 L
.22901 .8626 L
.22816 .86188 L
.22732 .86125 L
.22646 .86076 L
.22556 .86041 L
.22461 .86023 L
Mistroke
.22366 .86024 L
.22275 .86042 L
.2219 .86075 L
.22118 .8612 L
.22054 .86175 L
.21995 .86235 L
.21943 .86296 L
.21901 .86353 L
.21877 .86407 L
.21876 .86457 L
.21898 .86502 L
.21943 .86541 L
.22005 .8657 L
.2208 .86589 L
.2216 .86598 L
.22238 .86598 L
.22306 .86591 L
.22366 .86581 L
.22419 .8657 L
.22465 .86561 L
.22505 .86556 L
.22541 .86553 L
.22571 .86548 L
.22597 .8654 L
.22618 .86528 L
.22633 .86516 L
.22648 .86507 L
.22665 .86504 L
.22692 .86509 L
.2273 .86521 L
.22784 .86544 L
.22852 .86579 L
.22936 .86629 L
.23034 .86695 L
.23146 .86776 L
.23281 .86869 L
.2344 .86981 L
.23623 .87104 L
.23839 .87239 L
.24089 .87402 L
.24383 .87568 L
.24728 .87748 L
.25107 .87952 L
.25533 .8815 L
.26002 .88369 L
.2654 .88612 L
.27061 .88834 L
.27624 .89084 L
.28224 .8933 L
.28794 .89581 L
Mistroke
.29402 .89825 L
.30075 .90081 L
.30611 .90305 L
.31187 .90557 L
.31777 .90791 L
.32352 .91019 L
.32945 .91272 L
.33519 .91483 L
.34075 .91711 L
.34644 .91938 L
.35207 .92166 L
.35806 .92386 L
.36382 .92627 L
.36967 .92833 L
.37557 .93056 L
.38175 .9329 L
.38769 .93497 L
.39373 .93719 L
.39971 .93909 L
.40537 .94097 L
.41149 .94276 L
.41694 .94429 L
.42264 .94567 L
.42841 .94688 L
.43399 .94784 L
.43946 .94864 L
.44487 .94921 L
.45036 .94958 L
.45551 .94973 L
.46076 .94967 L
.46594 .94944 L
.47158 .94907 L
.47659 .94861 L
.48222 .94808 L
.4879 .94751 L
.49442 .94693 L
.50008 .94636 L
.50651 .9458 L
.51319 .94524 L
.52054 .94467 L
.52694 .94412 L
.53398 .94357 L
.54157 .94302 L
.54767 .94245 L
.55444 .94186 L
.56146 .94126 L
.56711 .94064 L
.57293 .94001 L
.57836 .93937 L
.58337 .93874 L
Mistroke
.58809 .9381 L
.59237 .93749 L
.59644 .9369 L
.60012 .93633 L
.60361 .93578 L
.60695 .93526 L
.6102 .9348 L
.61329 .93442 L
.61637 .93411 L
.61949 .93384 L
.62268 .93359 L
.62606 .93333 L
.6296 .93301 L
.63335 .93257 L
.63733 .93198 L
.64171 .93124 L
.64579 .93037 L
.65003 .92938 L
.65442 .92829 L
.65843 .92717 L
.66259 .92597 L
.66646 .92472 L
.66989 .92341 L
.67327 .92204 L
.67631 .92074 L
.67919 .9194 L
.68189 .91805 L
.68448 .91667 L
.68701 .91532 L
.68961 .91388 L
.69226 .91242 L
.69494 .91088 L
.69774 .90923 L
.70071 .90745 L
.7036 .90573 L
.70652 .90391 L
.70951 .90212 L
.71235 .90027 L
.71525 .89842 L
.71815 .89662 L
.72099 .89474 L
.72381 .89284 L
.72664 .89091 L
.72956 .88885 L
.73261 .88671 L
.73589 .88439 L
.73936 .8822 L
.74311 .87973 L
.74705 .87734 L
.75111 .87479 L
Mistroke
.75523 .87224 L
.7594 .86985 L
.76336 .86737 L
.76713 .86503 L
.77076 .86278 L
.77367 .86077 L
.77634 .85888 L
.77867 .85722 L
.78061 .85575 L
.78219 .8544 L
.78353 .8531 L
.78471 .85194 L
.78593 .85075 L
.78734 .84946 L
.78903 .848 L
.79101 .84645 L
.79348 .84468 L
.79606 .84262 L
.79919 .8404 L
.80291 .83798 L
.80663 .83526 L
.8109 .83246 L
.81544 .82944 L
.82035 .82585 L
.82495 .8229 L
.82982 .81985 L
.83442 .81658 L
.83908 .81315 L
.84335 .81007 L
.84761 .80669 L
.85164 .80361 L
.85494 .80041 L
.85863 .79724 L
.86206 .79392 L
.86502 .79055 L
.86774 .78694 L
.87025 .78328 L
.87248 .77955 L
.87453 .7756 L
.87642 .77163 L
.8782 .76751 L
.8799 .76323 L
.88159 .75878 L
.8832 .75444 L
.88476 .74996 L
.88629 .74539 L
.88767 .74108 L
.88901 .73689 L
.89019 .73275 L
.89123 .72926 L
Mistroke
.89209 .72594 L
.89278 .72306 L
.89331 .72055 L
.89371 .71859 L
.89401 .71699 L
.89422 .71582 L
.8944 .71501 L
.89456 .7145 L
.89472 .71425 L
.89488 .71417 L
.89506 .71419 L
.89524 .71421 L
.89543 .71425 L
.89562 .71435 L
.89581 .71448 L
.89596 .71465 L
.89605 .71488 L
.89607 .71521 L
.89603 .71563 L
.89596 .71609 L
.89584 .71657 L
.89569 .71708 L
.89548 .71769 L
.89523 .71838 L
.89495 .71915 L
.89466 .72 L
.89438 .7209 L
.89406 .7219 L
.8937 .72303 L
.89326 .72429 L
.89272 .72573 L
.89207 .72728 L
.89131 .72911 L
.89041 .73128 L
.88938 .73361 L
.88825 .73633 L
.88706 .7393 L
.886 .74173 L
.88484 .74459 L
.88384 .74679 L
.8829 .74891 L
.88205 .75098 L
.88133 .75289 L
.88074 .75448 L
.88029 .7559 L
.87999 .75715 L
.87983 .75821 L
.87979 .75907 L
.87982 .75974 L
.87989 .76027 L
Mistroke
.87996 .7607 L
.88001 .76106 L
.88005 .76136 L
.88009 .76161 L
.88012 .76181 L
.88014 .76194 L
.88014 .76198 L
.88014 .76193 L
.88014 .76181 L
.88013 .76164 L
.88013 .76146 L
.88013 .76131 L
.88013 .76124 L
.88013 .76126 L
.88013 .76131 L
.88013 .76135 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88016 .76134 L
.88021 .76128 L
.88028 .76119 L
.88035 .76107 L
.88042 .76094 L
.88047 .7608 L
.88049 .76071 L
.88046 .76071 L
.88034 .76082 L
.88012 .76112 L
.87974 .76166 L
.87914 .76259 L
.87829 .76395 L
Mistroke
.87723 .76567 L
.87595 .76779 L
.87442 .7704 L
.87277 .77303 L
.87091 .77617 L
.86918 .77919 L
.86742 .78234 L
.86567 .78546 L
.86414 .78807 L
.86265 .79084 L
.86149 .79292 L
.86052 .79473 L
.85976 .79621 L
.85923 .79728 L
.85891 .79794 L
.85878 .79823 L
.85879 .79827 L
.85887 .79817 L
.85898 .79798 L
.8591 .79776 L
.8592 .79756 L
.85927 .79744 L
.8593 .79738 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79736 L
.85932 .79733 L
.85935 .79725 L
.85938 .79714 L
.85941 .79704 L
.85944 .79701 L
.85945 .79708 L
.85943 .79727 L
.85934 .7976 L
.8592 .7981 L
.85901 .7987 L
.85877 .79939 L
.8585 .80008 L
.85821 .80071 L
.85793 .80119 L
.85766 .80154 L
.85741 .80172 L
.85719 .80172 L
.857 .80151 L
.85686 .80103 L
.85676 .80031 L
.85672 .79941 L
.85673 .79837 L
Mistroke
.85679 .79726 L
.85687 .79612 L
.85697 .7951 L
.85706 .79423 L
.85713 .79356 L
.85717 .7931 L
.85719 .79281 L
.85718 .79267 L
.85716 .79269 L
.85714 .79282 L
.85713 .79301 L
.85713 .79321 L
.85713 .79337 L
.85713 .79344 L
.85713 .79337 L
.85713 .79315 L
.85713 .79281 L
.85712 .79231 L
.85711 .79159 L
.85711 .79062 L
.85709 .78947 L
.85708 .78811 L
.85706 .78662 L
.85704 .78497 L
.85703 .78328 L
.85701 .78161 L
.85699 .77996 L
.85697 .7785 L
.85696 .77721 L
.85694 .7761 L
.85694 .77533 L
.85693 .77481 L
.85693 .77453 L
.85693 .77451 L
.85693 .77471 L
.85694 .77513 L
.85695 .77573 L
.85695 .77634 L
.85696 .77697 L
.85697 .77758 L
.85698 .77816 L
.85698 .77864 L
.85698 .77901 L
.85699 .77927 L
.85699 .77945 L
.85699 .77957 L
.85699 .77961 L
.85699 .77958 L
.85699 .77952 L
.85699 .77944 L
Mistroke
.85699 .77938 L
.85699 .77935 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77935 L
.85699 .77937 L
.85699 .77943 L
.85699 .7795 L
.85699 .77957 L
.85701 .77964 L
.85705 .77969 L
.85711 .77971 L
.85717 .77967 L
.85723 .77954 L
.85728 .77928 L
.8573 .77886 L
Mistroke
.85726 .77827 L
.85714 .77747 L
.85693 .77651 L
.8566 .77536 L
.85615 .77399 L
.85551 .77238 L
.85468 .77065 L
.85359 .76869 L
.85238 .7665 L
.85097 .76434 L
.84939 .76202 L
.84793 .75978 L
.84649 .75757 L
.84502 .75544 L
.84371 .75354 L
.84244 .75174 L
.84149 .75031 L
.84064 .74914 L
.84003 .74828 L
.83956 .74765 L
.83921 .74724 L
.83901 .74702 L
.83894 .7469 L
.83892 .74677 L
.83888 .74648 L
.83879 .74592 L
.83865 .74498 L
.83846 .74359 L
.83818 .74171 L
.83786 .7397 L
.83752 .73722 L
.83723 .73402 L
.83704 .73051 L
.83698 .7272 L
.8371 .72314 L
.83744 .71891 L
.83805 .7139 L
.8389 .7097 L
.84005 .70502 L
.84148 .70025 L
.84315 .69568 L
.84505 .69094 L
.84714 .68684 L
.84957 .68261 L
.85178 .67836 L
.85421 .67464 L
.85716 .6709 L
.85956 .66767 L
.86225 .66441 L
.86499 .66152 L
Mistroke
.86803 .65874 L
.87102 .65631 L
.87359 .65391 L
.87666 .65165 L
.87968 .64944 L
.88266 .64733 L
.88608 .64532 L
.88908 .64348 L
.89235 .64175 L
.89542 .64018 L
.89864 .6388 L
.90147 .63759 L
.90422 .63653 L
.90693 .6356 L
.90926 .63473 L
.9113 .6339 L
.91316 .63309 L
.91476 .63227 L
.9161 .63148 L
.91715 .63066 L
.91796 .62984 L
.91855 .62903 L
.91895 .62825 L
.9192 .62752 L
.91934 .62689 L
.91939 .62636 L
.9194 .62597 L
.91938 .62572 L
.91935 .62556 L
.91932 .62548 L
.91933 .62543 L
.91939 .62536 L
.91951 .62524 L
.91972 .62502 L
.92007 .62467 L
.92053 .62416 L
.92103 .62352 L
.92153 .62281 L
.92199 .62214 L
.92237 .62153 L
.92261 .62103 L
.92269 .62069 L
.92263 .62054 L
.92245 .62057 L
.9222 .62078 L
.9219 .62114 L
.92158 .62162 L
.92122 .62223 L
.92079 .6229 L
.92032 .62359 L
Mistroke
.91985 .62426 L
.91945 .62483 L
.91918 .62528 L
.91902 .6256 L
.91896 .62578 L
.91896 .62584 L
.91901 .62584 L
.91904 .62582 L
.91902 .62583 L
.91896 .62591 L
.91889 .62605 L
.91886 .6262 L
.91889 .62626 L
.91902 .62618 L
.91925 .62591 L
.91961 .62537 L
.9201 .62452 L
.92076 .6233 L
.92155 .62171 L
.92253 .61963 L
.92369 .61695 L
.92502 .614 L
.92652 .61039 L
.92813 .60609 L
.92983 .60166 L
.93151 .59662 L
.93317 .59092 L
.93479 .58523 L
.93621 .57984 L
.93754 .57387 L
.93869 .56775 L
.93964 .56267 L
.94041 .55752 L
.94095 .55294 L
.94129 .54869 L
.94144 .54571 L
.94142 .54315 L
.94126 .54115 L
.94102 .53985 L
.94073 .53908 L
.94043 .5388 L
.94015 .53893 L
.93989 .53937 L
.93967 .54 L
.93949 .5407 L
.93937 .54139 L
.93929 .54196 L
.93925 .54231 L
.93923 .54247 L
.93925 .5425 L
Mistroke
.93928 .54244 L
.93931 .54234 L
.93933 .54226 L
.93934 .54223 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93934 .54224 L
.93933 .5423 L
.93931 .54241 L
.93929 .54256 L
.93926 .54272 L
.93925 .54282 L
.93926 .54281 L
.9393 .54263 L
.93937 .54226 L
.93947 .54169 L
.9396 .54092 L
.93975 .53994 L
.93991 .53876 L
.94008 .53748 L
.94025 .53608 L
.94041 .53451 L
.94056 .53296 L
.9407 .53137 L
.94081 .52987 L
.9409 .52848 L
.94095 .52727 L
.94098 .5263 L
.94098 .52559 L
.94098 .52514 L
.94097 .52494 L
.94097 .5249 L
.94096 .52496 L
.94094 .52506 L
.9409 .52515 L
.94083 .52518 L
.94071 .52507 L
.94056 .52477 L
.94039 .52419 L
.94019 .52316 L
.93996 .52158 L
.9397 .51955 L
.93939 .51692 L
Mistroke
.93903 .51374 L
.93864 .50982 L
.93821 .50572 L
.93777 .50089 L
.93732 .49554 L
.93688 .49007 L
.93648 .48428 L
.9361 .47766 L
.93574 .4713 L
.93536 .46534 L
.93497 .45875 L
.93456 .4519 L
.93415 .44515 L
.93375 .43869 L
.93335 .43194 L
.93294 .42535 L
.93252 .41872 L
.93209 .4125 L
.93163 .40571 L
.93115 .39978 L
.93061 .39381 L
.93004 .38805 L
.92944 .3824 L
.92884 .37715 L
.92827 .37203 L
.92773 .36724 L
.92722 .36281 L
.92673 .35882 L
.92628 .35507 L
.92583 .35177 L
.92539 .34877 L
.92494 .34599 L
.92448 .34329 L
.92403 .341 L
.92357 .33877 L
.9231 .33656 L
.92264 .33442 L
.92213 .33224 L
.92159 .32999 L
.921 .32797 L
.9204 .32573 L
.91977 .32343 L
.91911 .32123 L
.91845 .31906 L
.91786 .3171 L
.91732 .31544 L
.91683 .31411 L
.9164 .31313 L
.91605 .31252 L
.91575 .3122 L
Mistroke
.91551 .31214 L
.91533 .31229 L
.91522 .31261 L
.91518 .31302 L
.91521 .31353 L
.91529 .31409 L
.9154 .31466 L
.91551 .31515 L
.9156 .3155 L
.91564 .31565 L
.9156 .31556 L
.91546 .31517 L
.91517 .31445 L
.91472 .3134 L
.91407 .31204 L
.9133 .31045 L
.91232 .30853 L
.91109 .30631 L
.90992 .30408 L
.90864 .30166 L
.90705 .29911 L
.90579 .29671 L
.90441 .29429 L
.90292 .29209 L
.90179 .29017 L
.90073 .28852 L
.89979 .28719 L
.89905 .2862 L
.89848 .28546 L
.89806 .28494 L
.89779 .28461 L
.89764 .28442 L
.89757 .28435 L
.89758 .28439 L
.89767 .28455 L
.89783 .28483 L
.89806 .2852 L
.89834 .28565 L
.89866 .28614 L
.89903 .28662 L
.8994 .28707 L
.89978 .28748 L
.90016 .28785 L
.90056 .28819 L
.90096 .28848 L
.90136 .28874 L
.90174 .28898 L
.90209 .28921 L
.90242 .28947 L
.90273 .2898 L
Mistroke
.90303 .29021 L
.90331 .29071 L
.90359 .29128 L
.90387 .29194 L
.90413 .29264 L
.90437 .29334 L
.90458 .29399 L
.90475 .29457 L
.90488 .29506 L
.90494 .29542 L
.90494 .29564 L
.90488 .29575 L
.90477 .29574 L
.90465 .29565 L
.90454 .29554 L
.90447 .29547 L
.90445 .29549 L
.90449 .29563 L
.9046 .29593 L
.9048 .29644 L
.9051 .2972 L
.90552 .29823 L
.90607 .29954 L
.90675 .30115 L
.90756 .303 L
.90846 .30503 L
.90947 .30717 L
.91058 .30942 L
.91169 .31146 L
.91283 .31353 L
.91395 .31531 L
.91501 .31705 L
.91602 .31845 L
.91691 .31962 L
.9177 .32051 L
.91839 .3211 L
.91894 .32143 L
.91938 .32158 L
.91969 .32165 L
.91989 .32169 L
.91998 .32174 L
.91999 .32186 L
.91993 .32207 L
.91982 .32234 L
.91969 .3226 L
.91954 .3228 L
.91941 .32289 L
.91929 .32287 L
.9192 .32273 L
.91914 .32248 L
Mistroke
.9191 .32213 L
.91907 .32162 L
.91905 .32098 L
.91904 .32023 L
.91906 .31939 L
.9191 .31854 L
.91916 .31771 L
.91924 .31695 L
.91933 .3163 L
.91941 .3158 L
.91947 .31544 L
.91952 .31517 L
.91955 .315 L
.91958 .31494 L
.91966 .31497 L
.91978 .31507 L
.9199 .3152 L
.91995 .31529 L
.91991 .31528 L
.91974 .31514 L
.9194 .31484 L
.91887 .31433 L
.91813 .31358 L
.91715 .31255 L
.91596 .31119 L
.91482 .30968 L
.91318 .30781 L
.91165 .30554 L
.90992 .30318 L
.90788 .3004 L
.90567 .29725 L
.9033 .29387 L
.90086 .29023 L
.89826 .28627 L
.89549 .28206 L
.89237 .27748 L
.88946 .27241 L
.88635 .26808 L
.88291 .26268 L
.87955 .25771 L
.87595 .25211 L
.87228 .24657 L
.86884 .24162 L
.86533 .23627 L
.86166 .2307 L
.85838 .22574 L
.85503 .22025 L
.852 .21583 L
.84905 .21111 L
.84628 .20672 L
Mistroke
.84395 .20323 L
.84176 .19979 L
.83987 .1967 L
.83822 .19406 L
.83702 .19206 L
.8361 .19049 L
.83542 .18936 L
.83497 .1886 L
.83471 .18817 L
.83458 .18796 L
.83452 .18785 L
.83444 .18775 L
.83431 .18756 L
.8341 .18728 L
.83381 .18691 L
.8334 .18645 L
.83282 .18588 L
.83208 .18519 L
.83118 .18437 L
.83004 .18335 L
.82874 .18225 L
.82712 .18088 L
.82515 .1792 L
.82293 .17721 L
.82094 .17503 L
.81864 .17269 L
.81594 .16986 L
.81371 .16709 L
.81105 .1642 L
.80854 .1611 L
.80616 .15829 L
.8038 .1551 L
.80203 .15257 L
.80049 .15041 L
.79921 .14848 L
.79827 .14683 L
.79768 .14561 L
.79737 .14487 L
.79727 .14451 L
.79731 .14443 L
.79744 .14451 L
.79761 .1447 L
.7978 .14495 L
.79794 .1452 L
.79801 .14534 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
Mistroke
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14539 L
.79802 .14544 L
.79803 .14552 L
.79807 .1456 L
.79815 .14568 L
.79826 .14573 L
.79837 .14571 L
.79846 .14559 L
.79851 .14535 L
.79846 .14496 L
.79829 .14444 L
.79795 .14378 L
.79743 .143 L
.79671 .14218 L
.7958 .14125 L
.7947 .14025 L
.7935 .13921 L
.79213 .13818 L
.79059 .13713 L
.78892 .13606 L
.78722 .13502 L
.78539 .13402 L
.78365 .13308 L
.78187 .13221 L
.78012 .13142 L
.77845 .13064 L
.77679 .12985 L
.77523 .12903 L
.77364 .12817 L
.77206 .12728 L
.77039 .12636 L
.76864 .12542 L
.76691 .12446 L
.76498 .12348 L
Mistroke
.76288 .12249 L
.76054 .12138 L
.75804 .12021 L
.75508 .11889 L
.75221 .11744 L
.74887 .11592 L
.74534 .11429 L
.74161 .11256 L
.7379 .11084 L
.734 .10914 L
.73053 .1075 L
.72698 .10591 L
.72393 .10449 L
.72097 .10315 L
.71862 .10194 L
.71652 .10093 L
.71501 .10015 L
.71388 .09956 L
.71307 .09913 L
.71256 .09883 L
.71229 .09862 L
.71219 .09848 L
.71217 .09837 L
.7122 .09829 L
.71226 .09821 L
.7123 .09813 L
.71231 .09805 L
.71228 .09799 L
.71223 .09795 L
.71218 .09795 L
.71216 .09804 L
.7122 .09822 L
.71232 .09851 L
.71252 .09888 L
.7128 .0993 L
.71311 .09976 L
.71343 .10024 L
.71375 .10075 L
.7141 .10125 L
.7145 .10178 L
.71501 .10234 L
.7157 .10294 L
.71658 .10361 L
.71772 .10436 L
.71913 .10519 L
.72082 .10611 L
.72259 .10699 L
.72465 .10795 L
.72646 .10894 L
.72866 .10995 L
Mistroke
.73106 .11094 L
.7332 .11189 L
.7355 .11274 L
.73773 .11344 L
.73978 .114 L
.74162 .11441 L
.74324 .11466 L
.74457 .11478 L
.74571 .1148 L
.74672 .11473 L
.74763 .11462 L
.74845 .11449 L
.74917 .11439 L
.74975 .11432 L
.75019 .11432 L
.75049 .1144 L
.75065 .11456 L
.75073 .11482 L
.7508 .11517 L
.75093 .11563 L
.7512 .11624 L
.75165 .11701 L
.75228 .11793 L
.75314 .11905 L
.75415 .12033 L
.75537 .12173 L
.75684 .12322 L
.7584 .12487 L
.76006 .12656 L
.76193 .12834 L
.76366 .13013 L
.76547 .13201 L
.76714 .13378 L
.76866 .13556 L
.76992 .13723 L
.77092 .13878 L
.77164 .14005 L
.77217 .14129 L
.77258 .1423 L
.77294 .14324 L
.77333 .14413 L
.7738 .145 L
.77441 .1459 L
.77518 .14687 L
.77613 .14795 L
.7773 .1492 L
.77861 .15063 L
.78013 .15208 L
.78193 .1539 L
.78394 .15589 L
Mistroke
.78619 .15818 L
.78862 .16069 L
.79122 .16326 L
.79383 .16588 L
.79656 .16852 L
.79925 .17124 L
.80201 .17387 L
.80479 .17656 L
.80769 .17926 L
.8106 .18206 L
.81364 .18475 L
.81656 .18764 L
.81945 .1901 L
.82231 .19268 L
.82495 .19489 L
.8274 .19718 L
.82963 .19906 L
.83152 .20074 L
.83318 .20223 L
.83449 .2034 L
.83543 .20438 L
.83596 .20521 L
.83607 .2059 L
.83578 .20652 L
.83514 .20714 L
.83422 .20788 L
.83304 .20878 L
.83164 .20995 L
.83004 .2114 L
.82823 .21312 L
.82622 .21493 L
.82399 .21712 L
.82159 .21936 L
.81882 .22187 L
.81586 .22452 L
.8126 .22723 L
.8092 .23008 L
.80549 .23309 L
.80194 .23612 L
.79797 .23954 L
.7944 .24273 L
.79037 .24628 L
.78677 .24994 L
.78318 .25352 L
.77941 .25751 L
.77578 .26099 L
.77239 .2645 L
.76889 .26794 L
.76539 .27135 L
.7618 .27454 L
Mistroke
.75795 .27727 L
.75424 .27988 L
.75015 .28225 L
.74595 .28431 L
.74138 .28614 L
.73685 .28767 L
.73173 .28883 L
.72745 .2897 L
.72258 .29027 L
.71801 .29052 L
.71389 .29046 L
.70982 .29008 L
.70591 .28939 L
.7022 .28835 L
.69887 .287 L
.69581 .28531 L
.69307 .28329 L
.6907 .28097 L
.68863 .27836 L
.68691 .27519 L
.68549 .27216 L
.68436 .26858 L
.68355 .2644 L
.68298 .26021 L
.68268 .25587 L
.68264 .25118 L
.68284 .24612 L
.68327 .24108 L
.68395 .2354 L
.68484 .23009 L
.68593 .22449 L
.68722 .21855 L
.68873 .21307 L
.69045 .20747 L
.6924 .20202 L
.69461 .19638 L
.6971 .19102 L
.69989 .18597 L
.70288 .18106 L
.70614 .17639 L
.70961 .17212 L
.71323 .16834 L
.71692 .16451 L
.7207 .16099 L
.72449 .15796 L
.72814 .15499 L
.73164 .1524 L
.73496 .14999 L
.73791 .14772 L
.74058 .1458 L
Mistroke
.74288 .14399 L
.74483 .14227 L
.74628 .14077 L
.74733 .1393 L
.74798 .13807 L
.74824 .13691 L
.74816 .13581 L
.74778 .13476 L
.74719 .13368 L
.74647 .13255 L
.74566 .13131 L
.7447 .13001 L
.74361 .12845 L
.74233 .12662 L
.74079 .12472 L
.73888 .12233 L
.73657 .12006 L
.73376 .11748 L
.73068 .11479 L
.72713 .11225 L
.72312 .10953 L
.71958 .10709 L
.71539 .10462 L
.71125 .10217 L
.70727 .10005 L
.70286 .09796 L
.69881 .09606 L
.69519 .09426 L
.69167 .09271 L
.68835 .09125 L
.68534 .08989 L
.68233 .08865 L
.67937 .08742 L
.67621 .08617 L
.67292 .08489 L
.66919 .0835 L
.66547 .082 L
.66143 .08054 L
.65696 .07893 L
.65281 .07729 L
.6482 .07554 L
.64351 .07375 L
.63932 .07184 L
.63489 .06998 L
.63057 .06814 L
.62648 .0664 L
.62252 .06483 L
.61908 .06334 L
.61582 .06198 L
.61293 .06071 L
Mistroke
.6102 .05953 L
.60766 .05845 L
.60519 .05744 L
.60282 .05653 L
.60052 .05573 L
.59842 .05504 L
.59639 .05445 L
.59444 .05392 L
.59246 .05347 L
.5905 .05307 L
.58845 .05275 L
.58624 .0525 L
.58413 .05232 L
.58185 .05219 L
.57939 .05212 L
.57673 .05211 L
.57409 .05214 L
.57125 .05217 L
.56823 .05217 L
.5651 .0521 L
.562 .05198 L
.55888 .05179 L
.55615 .05156 L
.55328 .05128 L
.55097 .05099 L
.54886 .05069 L
.54699 .05043 L
.5454 .05021 L
.54409 .05003 L
.5429 .04991 L
.54172 .04984 L
.54038 .04983 L
.5388 .04986 L
.53687 .04994 L
.53474 .05005 L
.53208 .05019 L
.52876 .05034 L
.52522 .05048 L
.52118 .05059 L
.5166 .05064 L
.51217 .05062 L
.50733 .05054 L
.50221 .05041 L
.49721 .05025 L
.49226 .05007 L
.4872 .04988 L
.48216 .04969 L
.47693 .04953 L
.47232 .04937 L
.46714 .04923 L
Mistroke
.46278 .04908 L
.45803 .04893 L
.45344 .04878 L
.44874 .04863 L
.44398 .04848 L
.43965 .04833 L
.43509 .04818 L
.43106 .04804 L
.42697 .04791 L
.4236 .04779 L
.42027 .04768 L
.41757 .04758 L
.41511 .04749 L
.41294 .04742 L
.41121 .04735 L
.40975 .04728 L
.40852 .04718 L
.40753 .04707 L
.40674 .04697 L
.40607 .04689 L
.40544 .04683 L
.40475 .04683 L
.40393 .04689 L
.4029 .04702 L
.40163 .04722 L
.40008 .04752 L
.39823 .04794 L
.39611 .04851 L
.39375 .04924 L
.39117 .05012 L
.38839 .05117 L
.38577 .05241 L
.38264 .05376 L
.37971 .05521 L
.37649 .05681 L
.37305 .05841 L
.36942 .06011 L
.36564 .06206 L
.36187 .06383 L
.35766 .06577 L
.3536 .06789 L
.34912 .07022 L
.34471 .07246 L
.33983 .0749 L
.33522 .07734 L
.32999 .08009 L
.32526 .08249 L
.3203 .08527 L
.31512 .08798 L
.31028 .09087 L
Mistroke
.30478 .09401 L
.30016 .09664 L
.29512 .09955 L
.29006 .1023 L
.28566 .10505 L
.2811 .1077 L
.27657 .11022 L
.27273 .11247 L
.26875 .11454 L
.26509 .11658 L
.26194 .1183 L
.25882 .11999 L
.25576 .12163 L
.25295 .12307 L
.25018 .12451 L
.24739 .126 L
.24482 .12747 L
.24192 .12908 L
.23887 .13074 L
.2361 .13228 L
.23324 .13383 L
.23015 .13552 L
.22705 .13726 L
.2242 .13909 L
.22161 .14074 L
.21916 .14239 L
.21697 .14398 L
.21509 .14541 L
.21347 .14676 L
.21209 .14795 L
.21093 .14895 L
.21 .14974 L
.20917 .15034 L
.20847 .15077 L
.20787 .151 L
.20735 .15107 L
.20691 .15098 L
.20658 .15072 L
.20635 .15033 L
.2062 .14981 L
.20611 .1492 L
.2061 .14853 L
.20615 .14785 L
.20624 .14724 L
.20639 .14677 L
.20658 .14641 L
.20684 .14616 L
.20716 .14601 L
.20754 .14593 L
.20798 .14589 L
Mistroke
.20847 .14582 L
.20898 .14572 L
.20954 .14559 L
.21012 .14543 L
.21072 .14527 L
.21133 .14506 L
.21195 .14479 L
.21254 .14445 L
.21314 .14415 L
.21371 .14382 L
.21428 .1435 L
.21488 .14319 L
.21552 .14292 L
.21619 .14272 L
.21693 .14257 L
.21771 .14242 L
.21847 .14224 L
.21919 .14203 L
.21985 .14175 L
.22043 .14142 L
.22093 .14103 L
.22135 .1406 L
.2217 .14011 L
.22196 .1396 L
.22215 .13908 L
.22226 .13855 L
.22232 .138 L
.22234 .13742 L
.22233 .13684 L
.22232 .1363 L
.22233 .13582 L
.22236 .13543 L
.22241 .13511 L
.22242 .13489 L
.22237 .13476 L
.22224 .13469 L
.22204 .13469 L
.22175 .13474 L
.22141 .13485 L
.22104 .13502 L
.22067 .13523 L
.22034 .13545 L
.22007 .13565 L
.21991 .13584 L
.21972 .13605 L
.21946 .13628 L
.21918 .13655 L
.21889 .13686 L
.21862 .13719 L
.21836 .13752 L
Mistroke
.21812 .13786 L
.2179 .1382 L
.21768 .13855 L
.21742 .1389 L
.21712 .13928 L
.21671 .13971 L
.21624 .14021 L
.21567 .14083 L
.21504 .14159 L
.21445 .14252 L
.21383 .14362 L
.21321 .14489 L
.21245 .14637 L
.21157 .14806 L
.21053 .15 L
.20931 .15196 L
.20781 .15433 L
.20612 .15679 L
.2042 .15967 L
.2023 .16238 L
.20021 .16534 L
.19806 .16834 L
.19569 .17148 L
.19344 .17444 L
.19119 .17753 L
.18879 .18046 L
.18645 .18351 L
.18415 .1866 L
.182 .18946 L
.1797 .19253 L
.17735 .19568 L
.17507 .19878 L
.17272 .20194 L
.17025 .20524 L
.16786 .20856 L
.16521 .21217 L
.16246 .2159 L
.15963 .21986 L
.15649 .22406 L
.15345 .22851 L
.1502 .23283 L
.14677 .23756 L
.1439 .2416 L
.14081 .2461 L
.13805 .25008 L
.1352 .25434 L
.13274 .25777 L
.13018 .26145 L
.12807 .26469 L
.12599 .26803 L
Mistroke
.12392 .27136 L
.12205 .27417 L
.12014 .2771 L
.11817 .28024 L
.11624 .28342 L
.1144 .28626 L
.11244 .28934 L
.11036 .29269 L
.1084 .29563 L
.10646 .29875 L
.10432 .30214 L
.1026 .30507 L
.10094 .30841 L
.09933 .31154 L
.09778 .31504 L
.09633 .31887 L
.09509 .32214 L
.09392 .32592 L
.09281 .33029 L
.09179 .33397 L
.09085 .3385 L
.08994 .34296 L
.08902 .34716 L
.08808 .35234 L
.08717 .35696 L
.08628 .36192 L
.08543 .36662 L
.08463 .37162 L
.08386 .37586 L
.08312 .38042 L
.08244 .38416 L
.08185 .38783 L
.08135 .39112 L
.08092 .39372 L
.08056 .39609 L
.08027 .39778 L
.08007 .39911 L
.07994 .40006 L
.0799 .40068 L
.07995 .40105 L
.08009 .40124 L
.08032 .4013 L
.0806 .40131 L
.08091 .40132 L
.08123 .40138 L
.08152 .4015 L
.08181 .40168 L
.08207 .40189 L
.08232 .4021 L
.08253 .40229 L
Mistroke
.08271 .40244 L
.08283 .40255 L
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08287 .40258 L
.08283 .40256 L
.08281 .40253 L
.08279 .40252 L
.08277 .4025 L
.08275 .40247 L
.08272 .40244 L
.08269 .4024 L
.08266 .40236 L
.08263 .40233 L
.08261 .40231 L
.0826 .40229 L
.08259 .40228 L
.08259 .40228 L
.08259 .40227 L
.08259 .40228 L
.08261 .4023 L
.08263 .40232 L
.08265 .40236 L
.08268 .40239 L
.08272 .40243 L
.08275 .40247 L
.08277 .4025 L
.08278 .40251 L
.08279 .40252 L
.08278 .40251 L
.08277 .4025 L
.08276 .40249 L
.08276 .40248 L
.08274 .40248 L
.08271 .40248 L
.08266 .40248 L
.08262 .40248 L
.0826 .40248 L
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08316 .40248 L
.0834 .40248 L
.0837 .40248 L
.08405 .40247 L
.08445 .40247 L
.08485 .40247 L
.08518 .40247 L
Mistroke
.08541 .40246 L
.08548 .40246 L
.08535 .40247 L
.08498 .40247 L
.08441 .40247 L
.08372 .40248 L
.08297 .40248 L
.08222 .40249 L
.08152 .40249 L
.08088 .4025 L
.08028 .4025 L
.07973 .40251 L
.07927 .40251 L
.07895 .40248 L
.07892 .40242 L
.07915 .40233 L
.07961 .40224 L
.08026 .40215 L
.08109 .4021 L
.08201 .40214 L
.08299 .4023 L
.08401 .40258 L
.08502 .403 L
.08608 .40355 L
.08716 .40423 L
.08824 .40503 L
.08935 .40585 L
.0904 .40672 L
.0914 .40763 L
.09231 .40859 L
.09309 .4095 L
.09375 .41044 L
.09425 .41139 L
.09458 .41236 L
.09472 .41347 L
.09471 .41472 L
.09455 .41616 L
.09427 .41784 L
.09389 .4196 L
.09342 .42177 L
.09289 .42391 L
.09231 .42634 L
.09173 .42861 L
.09118 .43091 L
.09068 .43344 L
.09024 .4354 L
.0899 .4372 L
.08967 .43886 L
.08954 .44028 L
.08949 .44139 L
Mistroke
.08951 .44216 L
.08959 .44267 L
.0897 .443 L
.08982 .4432 L
.08989 .44329 L
.08989 .44331 L
.08978 .44329 L
.08957 .44325 L
.08925 .44318 L
.08884 .44304 L
.08836 .44284 L
.08783 .44259 L
.08728 .44231 L
.08674 .44203 L
.0862 .44175 L
.0857 .44148 L
.08525 .44124 L
.08489 .44101 L
.08462 .44084 L
.08442 .44074 L
.08427 .44073 L
.08413 .4408 L
.08395 .44093 L
.08371 .44109 L
.08338 .44126 L
.08295 .4414 L
.08244 .44151 L
.08187 .44158 L
.08132 .44162 L
.08078 .44165 L
.08025 .44165 L
.07974 .44163 L
.07929 .44158 L
.07895 .4415 L
.07877 .4414 L
.07873 .44128 L
.07877 .44115 L
.07887 .44103 L
.07897 .44092 L
.07902 .44083 L
.07896 .44078 L
.07876 .44077 L
.07839 .44079 L
.07787 .44084 L
.07719 .44091 L
.0763 .44103 L
.07529 .44118 L
.07418 .44138 L
.07297 .44161 L
.07169 .44187 L
Mistroke
.0704 .44213 L
.06921 .4424 L
.06818 .44267 L
.06723 .44292 L
.06638 .44316 L
.06568 .44336 L
.06516 .44352 L
.06484 .44363 L
.06468 .4437 L
.06463 .44372 L
.06466 .4437 L
.06476 .44366 L
.06491 .44363 L
.06501 .44363 L
.06505 .44365 L
.06505 .44369 L
.06505 .4437 L
.06505 .44369 L
.06506 .44364 L
.06506 .44354 L
.06506 .4434 L
.06507 .44322 L
.06508 .443 L
.06509 .44276 L
.06509 .44251 L
.0651 .44226 L
.06511 .44201 L
.06512 .44177 L
.06513 .44154 L
.06513 .44135 L
.06514 .44119 L
.06514 .44108 L
.06514 .44102 L
.06514 .441 L
.06514 .44102 L
.06514 .44106 L
.06514 .4411 L
.06514 .44113 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06515 .44115 L
.06518 .44115 L
.06522 .44115 L
.06527 .44115 L
Mistroke
.06529 .44115 L
.06528 .44115 L
.06523 .44115 L
.06513 .44115 L
.06497 .44115 L
.06476 .44116 L
.06451 .44116 L
.06425 .44116 L
.06397 .44117 L
.06366 .44117 L
.06341 .44118 L
.06314 .44118 L
.06288 .44118 L
.06264 .44118 L
.06246 .44117 L
.06234 .44114 L
.06227 .4411 L
.06225 .44107 L
.06226 .44105 L
.0623 .44106 L
.06235 .44111 L
.06239 .44121 L
.0624 .44135 L
.06239 .44153 L
.06238 .44175 L
.06237 .44199 L
.06235 .44226 L
.06231 .44254 L
.06225 .44283 L
.0622 .44311 L
.06217 .44335 L
.06218 .44353 L
.06224 .44364 L
.06235 .44365 L
.06251 .44356 L
.06273 .44339 L
.06298 .44316 L
.06325 .44288 L
.06355 .44259 L
.06384 .4423 L
.06415 .44205 L
.06446 .44185 L
.06477 .4417 L
.06503 .44158 L
.06523 .44146 L
.06534 .44134 L
.06536 .44119 L
.06528 .44103 L
.06511 .44083 L
.06487 .4406 L
Mistroke
.06459 .44032 L
.0643 .43998 L
.06401 .43956 L
.06374 .43904 L
.06347 .43842 L
.06322 .43769 L
.063 .43685 L
.06281 .43589 L
.06267 .43483 L
.06258 .43368 L
.06255 .43253 L
.06257 .4313 L
.06263 .42998 L
.06271 .42861 L
.06281 .4272 L
.06289 .42568 L
.06296 .42415 L
.06301 .42261 L
.06306 .42118 L
.0631 .41986 L
.06314 .41863 L
.06318 .41753 L
.06321 .4166 L
.06323 .41585 L
.06325 .41529 L
.06326 .41492 L
.06326 .41478 L
.06326 .41485 L
.06325 .41511 L
.06324 .4155 L
.06321 .41596 L
.06316 .41641 L
.0631 .41683 L
.06305 .41718 L
.06302 .41742 L
.06303 .41754 L
.06309 .41753 L
.06321 .41737 L
.06338 .41708 L
.0636 .41667 L
.06386 .41613 L
.06415 .41551 L
.06445 .41485 L
.06475 .41422 L
.06505 .41367 L
.06534 .41323 L
.0656 .41288 L
.06583 .41261 L
.06602 .41241 L
.06615 .41226 L
Mistroke
.06622 .41216 L
.06624 .41211 L
.06623 .41208 L
.06619 .41207 L
.06614 .41209 L
.0661 .41213 L
.06608 .41217 L
.06608 .4122 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.0661 .4122 L
.06613 .41217 L
.06618 .41212 L
.06622 .41208 L
.06624 .41204 L
.0662 .41201 L
.06611 .41202 L
.06595 .41208 L
.06574 .41224 L
.06549 .41252 L
.06523 .41292 L
.06497 .41341 L
.06476 .41395 L
.06462 .41453 L
.06456 .415 L
.06457 .41547 L
.06466 .41587 L
.06486 .41617 L
.06512 .41638 L
.06546 .41648 L
.06587 .4165 L
.06634 .41638 L
Mistroke
.06685 .41621 L
.06733 .41594 L
.0678 .41562 L
.06824 .41529 L
.06865 .415 L
.06902 .41478 L
.06939 .4146 L
.06977 .41448 L
.07019 .41445 L
.07063 .41445 L
.07113 .41446 L
.07167 .41443 L
.07228 .41436 L
.07293 .41425 L
.07358 .41409 L
.07422 .41391 L
.07482 .4137 L
.07535 .41348 L
.0758 .41324 L
.07617 .41302 L
.07648 .41282 L
.07673 .41263 L
.07692 .41246 L
.07706 .41233 L
.07713 .41223 L
.07717 .41215 L
.07718 .41207 L
.0772 .41196 L
.07725 .41183 L
.07729 .41172 L
.0773 .41167 L
.07727 .41173 L
.07717 .41189 L
.07699 .41216 L
.0767 .41253 L
.07632 .41301 L
.07588 .41356 L
.07537 .41419 L
.07482 .41489 L
.07421 .41568 L
.0736 .4165 L
.07297 .41734 L
.07233 .41819 L
.07172 .41903 L
.07114 .41983 L
.0706 .42055 L
.0701 .42121 L
.0696 .42187 L
.06908 .42259 L
.06852 .42345 L
Mistroke
.0679 .42446 L
.06721 .42569 L
.06644 .42717 L
.06566 .42883 L
.06496 .43034 L
.06431 .43197 L
.06372 .43361 L
.06319 .4351 L
.06275 .43665 L
.06244 .43791 L
.06227 .43904 L
.06225 .43999 L
.06237 .44073 L
.0626 .44125 L
.06294 .44155 L
.06336 .44168 L
.0638 .44173 L
.06424 .44177 L
.06468 .4418 L
.06513 .44186 L
.0656 .44198 L
.06606 .44218 L
.0665 .44243 L
.06691 .44268 L
.06733 .44292 L
.06775 .44314 L
.06818 .44332 L
.06864 .44347 L
.06912 .44358 L
.06961 .44363 L
.07012 .44364 L
.07062 .44362 L
.07109 .44358 L
.07155 .44353 L
.07197 .44349 L
.07236 .44347 L
.07269 .44346 L
.07297 .44346 L
.07317 .44346 L
.07331 .44345 L
.07338 .44345 L
.07341 .44345 L
.0734 .44345 L
.07341 .44345 L
.07349 .44345 L
.07358 .44345 L
.0736 .44345 L
.07356 .44345 L
.07343 .44345 L
.07316 .44346 L
Mistroke
.0727 .44346 L
.07204 .44347 L
.07125 .44348 L
.07042 .44349 L
.06962 .4435 L
.06888 .44351 L
.06817 .44353 L
.06744 .44354 L
.06667 .44355 L
.06592 .44355 L
.06534 .44353 L
.06501 .44348 L
.06487 .44341 L
.06486 .44334 L
.06491 .4433 L
.06501 .44332 L
.06509 .44341 L
.06503 .44356 L
.06482 .44379 L
.06453 .44408 L
.06418 .44444 L
.06382 .44488 L
.06349 .44541 L
.06324 .44602 L
.06305 .44671 L
.06295 .44744 L
.06295 .44818 L
.06307 .44892 L
.06331 .44958 L
.06371 .45016 L
.06421 .45065 L
.06485 .4511 L
.06559 .45155 L
.06633 .45206 L
.06706 .45268 L
.06771 .45346 L
.06823 .45444 L
.06858 .45564 L
.06876 .457 L
.06877 .45865 L
.06863 .46059 L
.06832 .46295 L
.06788 .46565 L
.06731 .46889 L
.06663 .47223 L
.06586 .47629 L
.06504 .48061 L
.06425 .48486 L
.06349 .49008 L
.06283 .49483 L
Mistroke
.06232 .50016 L
.06196 .50545 L
.06175 .51073 L
.06168 .51612 L
.06174 .52191 L
.06196 .52714 L
.06233 .533 L
.06286 .53799 L
.0635 .54323 L
.06424 .54849 L
.06503 .55361 L
.06578 .55879 L
.06653 .56349 L
.06724 .56893 L
.06789 .5735 L
.06853 .57868 L
.06913 .58337 L
.0698 .58832 L
.07057 .59326 L
.07143 .59806 L
.07238 .60276 L
.07346 .60706 L
.07446 .61123 L
.07553 .6151 L
.07668 .61856 L
.07773 .62172 L
.07895 .62466 L
.07993 .62711 L
.08087 .62941 L
.08172 .63157 L
.08242 .63362 L
.08295 .63554 L
.08326 .63752 L
.08337 .63958 L
.08332 .64175 L
.08319 .64402 L
.08302 .6461 L
.0828 .64835 L
.08259 .65085 L
.08241 .65355 L
.08228 .65613 L
.08217 .65886 L
.0821 .66138 L
.08208 .66389 L
.08212 .66628 L
.08222 .66833 L
.08237 .67026 L
.08256 .6721 L
.08278 .67381 L
.08302 .67541 L
Mistroke
.08326 .67689 L
.0835 .67826 L
.08372 .6796 L
.0839 .68092 L
.08404 .68226 L
.08414 .68361 L
.0842 .68499 L
.08424 .68649 L
.08428 .68809 L
.08433 .68974 L
.0844 .69134 L
.08452 .69278 L
.08469 .69412 L
.08491 .69536 L
.08516 .69648 L
.08541 .69742 L
.08567 .69817 L
.08593 .69873 L
.08617 .69912 L
.08638 .69935 L
.08655 .69943 L
.08668 .69939 L
.08675 .69928 L
.08677 .69918 L
.08676 .69907 L
.08672 .69892 L
.08666 .69873 L
.0866 .69856 L
.08655 .69848 L
.0865 .69853 L
.08648 .69873 L
.08648 .69911 L
.08653 .69969 L
.08662 .70045 L
.08676 .70134 L
.08694 .70231 L
.08715 .70333 L
.08739 .70432 L
.08765 .70528 L
.0879 .70625 L
.08816 .70718 L
.08841 .70797 L
.08865 .70856 L
.08885 .70889 L
.08901 .70902 L
.0891 .70903 L
.08912 .70901 L
.0891 .70901 L
.08906 .70912 L
.08902 .70942 L
Mistroke
.08902 .70992 L
.08907 .71058 L
.08918 .71128 L
.08933 .71197 L
.08951 .71261 L
.08972 .71325 L
.08997 .71393 L
.09025 .71467 L
.09057 .71543 L
.09093 .71619 L
.09131 .71694 L
.0917 .71766 L
.09206 .71831 L
.09237 .71888 L
.09264 .7194 L
.09285 .71991 L
.09304 .72051 L
.09321 .72125 L
.0934 .72211 L
.09365 .72304 L
.09403 .72401 L
.09456 .72501 L
.09524 .72607 L
.09609 .72724 L
.09704 .72847 L
.09822 .72988 L
.09946 .73142 L
.10091 .73307 L
.10233 .73481 L
.10401 .73651 L
.10542 .73809 L
.10698 .73942 L
.10841 .74057 L
.10961 .74146 L
.11061 .74207 L
.11136 .74244 L
.11185 .74262 L
.11214 .74256 L
.1123 .74228 L
.11238 .74173 L
.11242 .74093 L
.11246 .73989 L
.11252 .73865 L
.11257 .73726 L
.11259 .73572 L
.11256 .73402 L
.11247 .73224 L
.11233 .73026 L
.11212 .72813 L
.11184 .72603 L
Mistroke
.11146 .72376 L
.11094 .72137 L
.11023 .71893 L
.10934 .71653 L
.10838 .71401 L
.10738 .71159 L
.1064 .70904 L
.10557 .70647 L
.1049 .70384 L
.10452 .70096 L
.10441 .69796 L
.10456 .6945 L
.10498 .69102 L
.10568 .68699 L
.10659 .68293 L
.10789 .67839 L
.1093 .67358 L
.11095 .66833 L
.11286 .66292 L
.1148 .65829 L
.1168 .653 L
.11876 .64848 L
.12036 .64354 L
.122 .63899 L
.12343 .63498 L
.12477 .63111 L
.12591 .62754 L
.1269 .6244 L
.12761 .62118 L
.12807 .61809 L
.12823 .61482 L
.12811 .6116 L
.12773 .60794 L
.12711 .60417 L
.12628 .60001 L
.1253 .59556 L
.1241 .59129 L
.12274 .58652 L
.12118 .58147 L
.11947 .57637 L
.11763 .57131 L
.11568 .5663 L
.11365 .56113 L
.11161 .55656 L
.10961 .55184 L
.10755 .54742 L
.10555 .54308 L
.10373 .53897 L
.10183 .53484 L
.10001 .53076 L
Mistroke
.09815 .52689 L
.09645 .523 L
.09479 .51933 L
.09319 .51581 L
.09166 .51236 L
.09019 .50937 L
.08892 .50651 L
.08763 .50401 L
.08631 .50183 L
.085 .49991 L
.08381 .49842 L
.08266 .49726 L
.08153 .49646 L
.08043 .49601 L
.07943 .49579 L
.0786 .49571 L
.0779 .4957 L
.07724 .49573 L
.07652 .49579 L
.07576 .49592 L
.07495 .49613 L
.07408 .49646 L
.07312 .49692 L
.07206 .49752 L
.07094 .49829 L
.06985 .49925 L
.06886 .50043 L
.06803 .50184 L
.06708 .50343 L
.06587 .50544 L
.06485 .50743 L
.06393 .50966 L
.06317 .51209 L
.06262 .51461 L
.06226 .5167 L
.06207 .51893 L
.06199 .52089 L
.06202 .52273 L
.06207 .52442 L
.06209 .52578 L
.06209 .52696 L
.06209 .52792 L
.06209 .52858 L
.06207 .52896 L
.06205 .52907 L
.06203 .52898 L
.062 .52877 L
.06198 .52854 L
.06196 .52835 L
.06195 .52827 L
Mistroke
.06197 .52837 L
.06201 .52872 L
.06207 .5294 L
.06217 .53055 L
.06233 .53224 L
.06257 .53438 L
.06291 .53716 L
.06336 .54024 L
.0639 .54404 L
.06453 .5487 L
.06526 .55253 L
.06601 .55706 L
.06679 .5624 L
.06757 .56663 L
.06825 .57218 L
.06889 .57664 L
.06941 .5807 L
.06985 .58495 L
.07023 .58889 L
.07053 .5923 L
.07075 .59532 L
.07091 .59805 L
.07102 .60019 L
.0711 .60216 L
.07118 .6038 L
.07129 .60535 L
.07146 .60673 L
.07169 .60803 L
.072 .60928 L
.07236 .61048 L
.07273 .61167 L
.07311 .61291 L
.07348 .61425 L
.07382 .61577 L
.07414 .61741 L
.07446 .61927 L
.07479 .62156 L
.07514 .62391 L
.07553 .62665 L
.07593 .62976 L
.07635 .63259 L
.07676 .63582 L
.07716 .63919 L
.07755 .64248 L
.07796 .64578 L
.07838 .64921 L
.07881 .65205 L
.07926 .65494 L
.07971 .65769 L
.08012 .65994 L
Mistroke
.08049 .66192 L
.08081 .66354 L
.08109 .66473 L
.08133 .66563 L
.08156 .66629 L
.08175 .66672 L
.08191 .66698 L
.08205 .6671 L
.08215 .66713 L
.08221 .6671 L
.08223 .66703 L
.08221 .66694 L
.08218 .66686 L
.08213 .66677 L
.0821 .66671 L
.08208 .66668 L
.08208 .66667 L
.08209 .66667 L
.08213 .66667 L
.08221 .66666 L
.0823 .66666 L
.08234 .66666 L
.08232 .66666 L
.08221 .66667 L
.08198 .66668 L
.08162 .66666 L
.08116 .66662 L
.08064 .66655 L
.08015 .66648 L
.07971 .66641 L
.07931 .66636 L
.07905 .66636 L
.07878 .66645 L
.07858 .66665 L
.07847 .66699 L
.07851 .6675 L
.07876 .66821 L
.07918 .6691 L
.07981 .67015 L
.08055 .67139 L
.08144 .67282 L
.08245 .67438 L
.08354 .67616 L
.0846 .67797 L
.08576 .67998 L
.08693 .68215 L
.08818 .68443 L
.08943 .68679 L
.09074 .68938 L
.09201 .69192 L
Mistroke
.0933 .69473 L
.09451 .6977 L
.0957 .70082 L
.09675 .70414 L
.09772 .70714 L
.09859 .7104 L
.09933 .71352 L
.09999 .7164 L
.10056 .7192 L
.10103 .72148 L
.10141 .72363 L
.10172 .72525 L
.10197 .7266 L
.10216 .72767 L
.10229 .72845 L
.10237 .72893 L
.10238 .72916 L
.10236 .72921 L
.10231 .72912 L
.10226 .72895 L
.10224 .72873 L
.10227 .7285 L
.10234 .72831 L
.10242 .72819 L
.10246 .72814 L
.10243 .72817 L
.10231 .72828 L
.1021 .72849 L
.10177 .72879 L
.10135 .72919 L
.10086 .72965 L
.10031 .73017 L
.09974 .73071 L
.09919 .73125 L
.09864 .73178 L
.0981 .73231 L
.09758 .73279 L
.09712 .73322 L
.09676 .73355 L
.09651 .73379 L
.09636 .73393 L
.09632 .73397 L
.09635 .73393 L
.09643 .73386 L
.09652 .73377 L
.09658 .7337 L
.09662 .73367 L
.09662 .73366 L
.09662 .73366 L
.0966 .73365 L
Mistroke
.09657 .73362 L
.09652 .73358 L
.09647 .73354 L
.09642 .73353 L
.09639 .73354 L
.09641 .7336 L
.09649 .73369 L
.09665 .73383 L
.09687 .73401 L
.09717 .73422 L
.09753 .73445 L
.09796 .73467 L
.09844 .73485 L
.099 .73501 L
.09962 .73516 L
.10031 .73533 L
.10101 .73553 L
.10176 .73577 L
.10253 .73606 L
.10332 .73639 L
.10408 .73676 L
.10484 .73716 L
.10558 .73758 L
.10628 .73803 L
.10695 .73848 L
.10759 .73895 L
.10819 .73942 L
.10871 .73986 L
.10916 .74025 L
.10953 .74056 L
.1098 .74077 L
.11 .74089 L
.11015 .74092 L
.11032 .74088 L
.11046 .7408 L
.11051 .74072 L
.11045 .74066 L
.11028 .74064 L
.10998 .74065 L
.10953 .74067 L
.1089 .74069 L
.10814 .74073 L
.10734 .74079 L
.10659 .74088 L
.10589 .74099 L
.1052 .7411 L
.10447 .74116 L
.10368 .74117 L
.1029 .74109 L
.10221 .74092 L
Mistroke
.10165 .74064 L
.1012 .74028 L
.10081 .73985 L
.10051 .73937 L
.10032 .73886 L
.10021 .73835 L
.10003 .73784 L
.09986 .73735 L
.09976 .73688 L
.09974 .73648 L
.09979 .73615 L
.09992 .73592 L
.10012 .73578 L
.10041 .73573 L
.10078 .73575 L
.1012 .7358 L
.10166 .73587 L
.10212 .73591 L
.10256 .73593 L
.10296 .73592 L
.10332 .7359 L
.10363 .73589 L
.1039 .73588 L
.10413 .73587 L
.10434 .73586 L
.10453 .73587 L
.10472 .7359 L
.10489 .73596 L
.10501 .73604 L
.10508 .73613 L
.10508 .73619 L
.105 .73617 L
.10483 .73606 L
.10459 .73582 L
.10427 .73546 L
.10388 .73497 L
.10343 .73437 L
.10292 .73369 L
.10242 .733 L
.10188 .73225 L
.10134 .73149 L
.10088 .73077 L
.1005 .73009 L
.10019 .72947 L
.09991 .72897 L
.09967 .72864 L
.09946 .72846 L
.09926 .72841 L
.09904 .72843 L
.09878 .72848 L
Mistroke
.09845 .72849 L
.09804 .72844 L
.09754 .72829 L
.09692 .72801 L
.09626 .72764 L
.09551 .7272 L
.09467 .72671 L
.09376 .72622 L
.0928 .72576 L
.09183 .72536 L
.09098 .72502 L
.09009 .72484 L
.08928 .72479 L
.08852 .72491 L
.08784 .7252 L
.08725 .72567 L
.08679 .72622 L
.08646 .72684 L
.08627 .72739 L
.08618 .72789 L
.08619 .72826 L
.08628 .72847 L
.08643 .72851 L
.08663 .72836 L
.08684 .72805 L
.08709 .72762 L
.08735 .72711 L
.08761 .72656 L
.08782 .72597 L
.08799 .72539 L
.08808 .72486 L
.08812 .72442 L
.08812 .72406 L
.08812 .72377 L
.08816 .72356 L
.08828 .72344 L
.08851 .72343 L
.08885 .72352 L
.08929 .7237 L
.08984 .72395 L
.09048 .72426 L
.0912 .72465 L
.09197 .72515 L
.09267 .72571 L
.09342 .72628 L
.09425 .72681 L
.09497 .7273 L
.09563 .7277 L
.0962 .72798 L
.09662 .72808 L
Mistroke
.09691 .72799 L
.09706 .72769 L
.09711 .7272 L
.09707 .72656 L
.09701 .72583 L
.09694 .72502 L
.09689 .72418 L
.09684 .72336 L
.0968 .72262 L
.09677 .722 L
.09676 .7215 L
.09678 .72115 L
.09684 .72096 L
.09695 .72093 L
.09711 .72103 L
.09731 .72123 L
.09754 .72148 L
.0978 .72177 L
.09808 .72206 L
.09835 .72236 L
.09862 .72264 L
.09888 .7229 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72358 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
Mistroke
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09959 .72354 L
.09962 .72357 L
.09966 .72361 L
.0997 .72364 L
.09972 .72366 L
.09971 .72365 L
.09965 .7236 L
.09954 .7235 L
.09939 .72336 L
.09919 .72318 L
.09895 .72296 L
.09869 .72273 L
.09841 .72248 L
.09814 .72223 L
.09787 .72198 L
.0976 .72174 L
.09736 .72151 L
Mistroke
.09714 .72132 L
.09697 .72117 L
.09685 .72106 L
.09678 .72099 L
.09675 .72096 L
.09673 .72095 L
.09673 .72095 L
.09674 .72095 L
.09675 .72096 L
.09678 .72099 L
.09684 .72105 L
.09694 .72114 L
.0971 .72129 L
.0973 .72147 L
.09754 .72168 L
.0978 .72192 L
.09807 .72217 L
.09835 .72242 L
.09862 .72267 L
.09888 .72291 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72359 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
Mistroke
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72354 L
.09957 .72357 L
.09957 .72361 L
.09957 .72365 L
.09957 .72367 L
.09957 .72366 L
.09956 .72361 L
.09955 .72352 L
.09951 .72341 L
.09945 .72329 L
.09935 .72316 L
.09924 .72302 L
.09916 .72287 L
.09913 .72268 L
.09921 .72242 L
.09942 .72206 L
.09978 .7216 L
.10033 .72102 L
.10109 .72031 L
.10208 .71944 L
.10315 .71843 L
.1045 .7173 L
.10595 .71598 L
.10744 .71444 L
.10917 .71268 L
.11089 .71069 L
.11268 .70857 L
.11445 .70606 L
.11608 .70341 L
.11763 .70034 L
.11892 .69722 L
.12003 .69369 L
.12085 .69 L
.12133 .686 L
.12151 .68135 L
.12136 .67725 L
.12082 .67256 L
.11996 .66711 L
.11862 .66279 L
.11706 .65778 L
.1152 .65274 L
.11312 .64716 L
.11076 .64228 L
Mistroke
.10841 .63704 L
.10615 .63173 L
.10416 .62568 L
.10193 .62077 L
.09975 .61534 L
.0979 .60939 L
.09609 .60368 L
.09446 .59759 L
.0932 .59137 L
.0921 .58515 L
.09113 .5788 L
.09031 .57245 L
.08959 .56602 L
.08894 .55962 L
.08836 .55329 L
.08789 .54684 L
.08755 .54074 L
.08734 .53448 L
.08726 .52835 L
.08725 .52225 L
.0873 .5162 L
.08737 .51024 L
.08743 .5045 L
.08748 .49893 L
.08749 .49346 L
.08749 .4882 L
.08752 .48305 L
.08763 .47795 L
.08785 .47317 L
.0882 .46841 L
.08866 .46378 L
.08929 .45924 L
.09008 .45485 L
.09107 .45048 L
.09222 .44624 L
.09362 .44212 L
.09519 .4381 L
.09698 .43428 L
.09895 .43057 L
.10096 .42707 L
.10312 .4237 L
.10521 .42061 L
.10724 .41778 L
.10923 .4153 L
.11098 .41313 L
.11262 .41133 L
.11399 .4099 L
.11518 .40886 L
.11616 .40813 L
.11691 .40767 L
Mistroke
.11746 .40739 L
.1178 .40721 L
.11796 .40706 L
.11801 .40689 L
.11801 .40663 L
.11803 .40623 L
.11813 .40566 L
.11839 .40492 L
.11882 .40399 L
.11945 .4029 L
.12026 .4016 L
.12128 .40018 L
.12248 .39868 L
.12379 .39719 L
.12523 .39573 L
.12674 .39434 L
.12832 .39303 L
.12997 .39181 L
.13157 .39066 L
.1332 .38956 L
.13479 .38851 L
.13638 .38747 L
.13795 .38643 L
.13959 .3854 L
.14121 .38437 L
.14288 .3833 L
.14468 .38219 L
.1465 .38105 L
.14831 .38003 L
.15018 .37925 L
.15197 .37851 L
.1538 .37758 L
.15549 .37642 L
.15718 .37496 L
.15884 .37298 L
.16029 .37038 L
.16167 .36711 L
.16294 .36334 L
.16408 .35943 L
.16505 .35594 L
.16583 .3523 L
.16648 .34908 L
.16701 .34591 L
.16745 .3427 L
.1678 .33971 L
.16807 .33735 L
.16825 .33581 L
.16836 .335 L
.16841 .33472 L
.16842 .33487 L
Mistroke
.16839 .33539 L
.16834 .33603 L
.1683 .33647 L
.16823 .33663 L
.16811 .33653 L
.16791 .33623 L
.16763 .33577 L
.16728 .33512 L
.16688 .33428 L
.16643 .3332 L
.16594 .33192 L
.16541 .33041 L
.16482 .32867 L
.16423 .32672 L
.16364 .32453 L
.16306 .32212 L
.16254 .3196 L
.16212 .31703 L
.16183 .31453 L
.16166 .31218 L
.16155 .30993 L
.16143 .30758 L
.16125 .30509 L
.16098 .30238 L
.16059 .29963 L
.16007 .29671 L
.15945 .29366 L
.15876 .2906 L
.15806 .28768 L
.15737 .285 L
.15671 .28268 L
.15604 .28055 L
.15533 .27847 L
.1546 .27646 L
.15391 .27461 L
.1533 .27301 L
.1528 .27169 L
.15241 .27065 L
.15209 .26991 L
.1518 .26945 L
.15151 .2692 L
.15126 .269 L
.15101 .26858 L
.15079 .2679 L
.15067 .26704 L
.15073 .26606 L
.15101 .26499 L
.15147 .26392 L
.15206 .2629 L
.15273 .26196 L
Mistroke
.15346 .26105 L
.15425 .26013 L
.15505 .25912 L
.15593 .25793 L
.15683 .25652 L
.15774 .25492 L
.15862 .25319 L
.1594 .25137 L
.16009 .24943 L
.16078 .24733 L
.16149 .24492 L
.16233 .24207 L
.16331 .23884 L
.16458 .23487 L
.16621 .23017 L
.16807 .22521 L
.17017 .21969 L
.17227 .2141 L
.17399 .20954 L
.1757 .20494 L
.17719 .20107 L
.17856 .19753 L
.17996 .19405 L
.1813 .19081 L
.18239 .18821 L
.18312 .18646 L
.18357 .18537 L
.18384 .18471 L
.184 .18437 L
.18405 .18438 L
.18411 .18452 L
.18435 .18438 L
.1848 .18396 L
.18537 .18347 L
.18601 .18303 L
.18666 .18264 L
.1873 .18224 L
.18787 .1818 L
.1884 .18132 L
.18887 .18076 L
.18929 .18012 L
.18968 .17937 L
.19007 .17849 L
.19049 .17745 L
.19098 .17623 L
.19158 .17488 L
.1923 .17338 L
.19315 .17176 L
.19409 .17003 L
.1952 .16823 L
Mistroke
.19641 .16637 L
.19775 .16453 L
.19917 .16272 L
.20064 .16099 L
.20211 .15931 L
.20355 .15768 L
.20488 .15606 L
.20618 .15446 L
.20742 .15287 L
.20859 .15132 L
.20966 .14987 L
.21074 .1485 L
.21181 .1472 L
.21292 .14598 L
.21403 .14479 L
.2152 .14365 L
.21639 .14257 L
.21765 .14156 L
.21889 .14064 L
.22015 .13979 L
.22141 .13899 L
.22263 .13821 L
.22385 .13743 L
.22511 .13666 L
.22642 .13589 L
.22769 .13515 L
.22898 .13443 L
.23025 .13373 L
.2315 .13307 L
.23271 .13248 L
.23389 .13195 L
.23495 .1315 L
.23591 .13111 L
.23667 .13077 L
.23725 .1305 L
.2376 .13031 L
.23768 .13021 L
.23749 .1302 L
.23706 .13024 L
.23641 .13029 L
.23558 .13036 L
.23461 .13043 L
.23362 .13049 L
.23253 .13054 L
.23151 .13063 L
.23052 .13077 L
.22961 .13096 L
.22881 .13121 L
.22815 .13151 L
.22765 .13186 L
Mistroke
.22732 .13224 L
.22712 .13256 L
.22708 .13296 L
.22715 .13338 L
.22729 .13371 L
.22744 .13404 L
.22752 .13432 L
.2275 .13457 L
.22734 .13479 L
.22704 .13497 L
.22661 .13513 L
.22608 .13528 L
.22552 .13544 L
.225 .13561 L
.22454 .1358 L
.22414 .13601 L
.22382 .13622 L
.22354 .13644 L
.22331 .13664 L
.22315 .13682 L
.22311 .13697 L
.22322 .13708 L
.22349 .13712 L
.22387 .1371 L
.2243 .13703 L
.22472 .13694 L
.22505 .13688 L
.2252 .13688 L
.22514 .13696 L
.22489 .13714 L
.22451 .1374 L
.22405 .13773 L
.22355 .13813 L
.22302 .13857 L
.22249 .13903 L
.22196 .13949 L
.22144 .13997 L
.22095 .14046 L
.22051 .14093 L
.22012 .14133 L
.21977 .14165 L
.21949 .14184 L
.21927 .1419 L
.21911 .14181 L
.21901 .14159 L
.21895 .14127 L
.21891 .14088 L
.21885 .14046 L
.21877 .14004 L
.21869 .1396 L
Mistroke
.21864 .13915 L
.21863 .13864 L
.21867 .13815 L
.21878 .13763 L
.21893 .13715 L
.21914 .13677 L
.2194 .13652 L
.21971 .13639 L
.2201 .13636 L
.22057 .13638 L
.22117 .13639 L
.22191 .13635 L
.22283 .13622 L
.22396 .13598 L
.22535 .13561 L
.22707 .13508 L
.229 .13437 L
.23122 .13354 L
.23377 .13247 L
.23664 .13125 L
.23988 .12975 L
.24326 .12802 L
.24694 .12618 L
.25073 .12416 L
.25488 .122 L
.25882 .11993 L
.26351 .11767 L
.26754 .11538 L
.27185 .1131 L
.27722 .11055 L
.2814 .10795 L
.28616 .10518 L
.2912 .10223 L
.29644 .09911 L
.30036 .09679 L
.30443 .09434 L
.30855 .09177 L
.31161 .08999 L
.31467 .0884 L
.31729 .08696 L
.31913 .08604 L
.32059 .08541 L
.32158 .08507 L
.32213 .085 L
.32229 .08518 L
.32215 .08557 L
.32183 .08606 L
.32146 .08657 L
.32109 .08702 L
.32077 .08736 L
Mistroke
.32053 .08756 L
.3204 .08765 L
.32037 .08767 L
.32041 .08761 L
.32045 .08754 L
.32048 .08748 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.32048 .08747 L
.32045 .08753 L
.32041 .0876 L
.32035 .08766 L
.32029 .0877 L
.32024 .08768 L
.32021 .08762 L
.32024 .08749 L
.32035 .0873 L
.32056 .08704 L
.32086 .08668 L
.32126 .08623 L
.32177 .0857 L
.32237 .0851 L
.32309 .08443 L
.32391 .08372 L
.3248 .08298 L
.32582 .08223 L
.3269 .08148 L
.32811 .08077 L
.32942 .08009 L
.33083 .07941 L
.33236 .07871 L
.33394 .07797 L
.33567 .07717 L
.33756 .07628 L
.33962 .0753 L
.34178 .07426 L
.3441 .07328 L
.34629 .07232 L
.34846 .0714 L
.3506 .07045 L
.35266 .06961 L
.35454 .06876 L
.35634 .06789 L
.35814 .0671 L
.35967 .06631 L
Mistroke
.36116 .0655 L
.36266 .06465 L
.3642 .06375 L
.36581 .06279 L
.3674 .06189 L
.36905 .06083 L
.37085 .05964 L
.37271 .0585 L
.37463 .05727 L
.37656 .05605 L
.37844 .05492 L
.38023 .05389 L
.38188 .05303 L
.38335 .05234 L
.38458 .05178 L
.38563 .05137 L
.38649 .05109 L
.38718 .05091 L
.38771 .05083 L
.3881 .05084 L
.38836 .05092 L
.38853 .05103 L
.38864 .05113 L
.38873 .05118 L
.38881 .05115 L
.3889 .051 L
.38897 .05074 L
.38902 .0504 L
.38904 .05 L
.38902 .04955 L
.38898 .04907 L
.38893 .04857 L
.38885 .04813 L
.38872 .04771 L
.38856 .04731 L
.38842 .04696 L
.38831 .04668 L
.38829 .04652 L
.38837 .04645 L
.38862 .04645 L
.38905 .0465 L
.38972 .04659 L
.39067 .04669 L
.39193 .04679 L
.3935 .04687 L
.3951 .04695 L
.39706 .04701 L
.39916 .04708 L
.40141 .04714 L
.40371 .04719 L
Mistroke
.40599 .04724 L
.40801 .04729 L
.40987 .04733 L
.41158 .04736 L
.41289 .0474 L
.41399 .04744 L
.41482 .04748 L
.41539 .04751 L
.41574 .04752 L
.41591 .04753 L
.41593 .04753 L
.41585 .04753 L
.41571 .04752 L
.41554 .04751 L
.41538 .04751 L
.41524 .0475 L
.41514 .0475 L
.41506 .0475 L
.415 .04749 L
.41498 .04749 L
.41503 .0475 L
.41515 .0475 L
.41538 .04751 L
.41574 .04753 L
.41625 .04756 L
.41695 .04759 L
.41789 .04762 L
.41911 .04765 L
.42057 .0477 L
.42229 .04776 L
.42427 .04783 L
.42647 .04791 L
.42878 .04798 L
.43114 .04802 L
.43355 .04803 L
.43582 .04801 L
.43799 .04794 L
.44009 .04783 L
.44177 .0477 L
.44327 .04754 L
.44453 .04737 L
.44551 .0472 L
.44626 .04702 L
.44678 .04684 L
.4471 .04668 L
.44721 .04652 L
.44713 .04639 L
.4469 .04629 L
.44653 .04621 L
.44607 .04617 L
Mistroke
.44552 .04616 L
.44493 .04617 L
.44431 .04618 L
.44369 .04618 L
.44306 .04614 L
.44243 .04609 L
.44175 .04603 L
.44098 .04599 L
.44016 .04597 L
.43929 .04598 L
.4384 .04603 L
.43746 .0461 L
.43641 .04618 L
.43525 .04627 L
.43384 .04639 L
.43218 .04655 L
.43025 .04677 L
.4282 .04705 L
.4258 .0474 L
.42338 .04781 L
.42096 .04828 L
.41861 .04882 L
.41683 .0494 L
.41484 .04995 L
.4131 .0504 L
.41158 .05077 L
.41016 .05106 L
.40886 .05124 L
.40773 .05128 L
.40676 .05116 L
.40592 .0509 L
.40515 .05051 L
.40444 .05005 L
.40377 .04952 L
.40307 .04897 L
.40226 .04841 L
.40134 .04788 L
.40036 .04744 L
.39944 .04709 L
.39863 .04684 L
.39799 .04671 L
.39746 .04667 L
.39705 .04671 L
.39674 .04679 L
.39648 .04687 L
.39625 .04691 L
.39604 .04688 L
.39583 .04677 L
.39562 .0466 L
.39542 .04638 L
Mistroke
.39522 .04613 L
.39501 .04588 L
.39479 .04565 L
.3946 .04546 L
.39446 .04531 L
.39441 .04522 L
.39446 .04518 L
.3946 .0452 L
.39483 .04529 L
.39513 .04543 L
.39548 .04562 L
.39588 .04586 L
.39632 .04611 L
.39676 .04638 L
.39719 .04662 L
.39761 .04681 L
.398 .04695 L
.39842 .04702 L
.39893 .04706 L
.39959 .04707 L
.40045 .04706 L
.40162 .04707 L
.40313 .04709 L
.40504 .04715 L
.40732 .04722 L
.40994 .04732 L
.41304 .04743 L
.41624 .04754 L
.41985 .04767 L
.42367 .0478 L
.42728 .04794 L
.43123 .04809 L
.43529 .04823 L
.43901 .04837 L
.44279 .04851 L
.44652 .04863 L
.45004 .04874 L
.45354 .0488 L
.45665 .04882 L
.45961 .0488 L
.46237 .04876 L
.46498 .04871 L
.46737 .04866 L
.46959 .04864 L
.47172 .04863 L
.47374 .04865 L
.4758 .04871 L
.47787 .04878 L
.48005 .04889 L
.4822 .049 L
Mistroke
.4844 .04916 L
.48693 .04934 L
.48964 .04955 L
.49275 .04976 L
.49587 .04998 L
.49969 .05018 L
.50337 .05036 L
.50746 .05052 L
.51184 .05065 L
.51678 .05075 L
.52065 .05085 L
.52544 .05095 L
.53047 .05107 L
.53474 .0512 L
.53956 .05133 L
.54435 .05147 L
.54937 .05159 L
.55367 .05172 L
.55829 .05183 L
.56268 .05194 L
.56643 .05204 L
.5703 .05212 L
.57393 .0522 L
.57722 .05225 L
.5803 .05228 L
.58298 .0523 L
.58546 .05234 L
.58766 .05242 L
.58963 .05255 L
.59146 .05275 L
.59315 .05306 L
.59469 .05341 L
.59604 .05381 L
.59731 .05427 L
.59846 .05471 L
.59949 .05518 L
.60041 .05561 L
.60122 .05605 L
.60195 .05646 L
.60259 .05681 L
.60312 .05706 L
.60355 .05721 L
.60389 .05728 L
.60416 .05732 L
.60439 .05736 L
.60461 .05743 L
.60485 .05755 L
.60511 .05776 L
.60542 .05806 L
.60578 .05845 L
Mistroke
.60619 .05889 L
.60664 .05935 L
.60712 .05982 L
.60762 .06028 L
.60814 .06075 L
.60868 .06122 L
.60917 .06165 L
.60957 .06201 L
.60985 .06225 L
.61001 .06235 L
.61001 .06231 L
.60986 .06214 L
.60957 .06187 L
.60916 .06154 L
.60864 .06115 L
.60802 .06071 L
.6073 .0602 L
.60652 .05958 L
.60569 .05889 L
.60481 .05811 L
.60394 .05728 L
.6031 .05648 L
.60232 .05576 L
.6016 .05519 L
.60096 .05477 L
.60033 .05448 L
.59968 .0543 L
.59897 .05422 L
.59817 .05427 L
.59727 .05444 L
.59633 .05472 L
.59536 .05505 L
.59434 .05539 L
.59329 .05573 L
.59223 .05603 L
.59112 .05621 L
.58998 .05624 L
.58888 .05608 L
.58782 .05577 L
.58683 .05536 L
.58595 .05491 L
.5852 .05449 L
.58455 .05406 L
.584 .05367 L
.58354 .05328 L
.58316 .0529 L
.58287 .05253 L
.58267 .05221 L
.58257 .05196 L
.58258 .05176 L
Mistroke
.58271 .05162 L
.58297 .05154 L
.58333 .05153 L
.5838 .05158 L
.58438 .05169 L
.5851 .05189 L
.58595 .05217 L
.58699 .05258 L
.5882 .05307 L
.58952 .05363 L
.59097 .05424 L
.59244 .05486 L
.59393 .05545 L
.59532 .05601 L
.59665 .05651 L
.5978 .05693 L
.59881 .05723 L
.59968 .05742 L
.60039 .05752 L
.60095 .05756 L
.60137 .05754 L
.60164 .05748 L
.60177 .05741 L
.60179 .05735 L
.60176 .05731 L
.60171 .0573 L
.60165 .0573 L
.6016 .05731 L
.60154 .05732 L
.60147 .05734 L
.60136 .05735 L
.60121 .05737 L
.60101 .05738 L
.60077 .05739 L
.60051 .05739 L
.60025 .05739 L
.60003 .05739 L
.59986 .05741 L
.59975 .05746 L
.59971 .05752 L
.59973 .05756 L
.59981 .05757 L
.59991 .05753 L
.60004 .05742 L
.60016 .05722 L
.60028 .05691 L
.60035 .0565 L
.60037 .05602 L
.60031 .05552 L
.60018 .055 L
Mistroke
.59999 .05451 L
.59978 .05408 L
.59958 .05376 L
.59939 .05359 L
.59924 .05358 L
.59916 .05378 L
.59921 .05417 L
.59939 .05476 L
.59974 .05547 L
.60028 .05626 L
.60101 .05711 L
.60195 .058 L
.60306 .05887 L
.60441 .05964 L
.60602 .06039 L
.60781 .06116 L
.60984 .06196 L
.61227 .06279 L
.61476 .06366 L
.61774 .06457 L
.62085 .0656 L
.62398 .06675 L
.62746 .06787 L
.63093 .06908 L
.63458 .07046 L
.63794 .07175 L
.64133 .0731 L
.64489 .07447 L
.64807 .07581 L
.65123 .0772 L
.65471 .07867 L
.65797 .08019 L
.66132 .0819 L
.66486 .08384 L
.66855 .08565 L
.67189 .08774 L
.6756 .08997 L
.67942 .09201 L
.68281 .09425 L
.68664 .0961 L
.68973 .09786 L
.69297 .09953 L
.69578 .10085 L
.69823 .10193 L
.70026 .10269 L
.70184 .10314 L
.70295 .10333 L
.7037 .10333 L
.70415 .10324 L
.70441 .10312 L
Mistroke
.70458 .10303 L
.70476 .10306 L
.70508 .10324 L
.70563 .10358 L
.70648 .10411 L
.70768 .10486 L
.70927 .1058 L
.71112 .10691 L
.71355 .10823 L
.71618 .10974 L
.71939 .11133 L
.72299 .11307 L
.72658 .11487 L
.73087 .11672 L
.73517 .11851 L
.74025 .12034 L
.74452 .12212 L
.7493 .12373 L
.75397 .12532 L
.75891 .12686 L
.76317 .12827 L
.76745 .12956 L
.77178 .13076 L
.77525 .13187 L
.77879 .13284 L
.78187 .13371 L
.78461 .13447 L
.78682 .13512 L
.78865 .13566 L
.79012 .1361 L
.79128 .13645 L
.79219 .13669 L
.79285 .13685 L
.79334 .13694 L
.79368 .13697 L
.79389 .13695 L
.79398 .13692 L
.79399 .13688 L
.79395 .13684 L
.79388 .1368 L
.7938 .13677 L
.79374 .13675 L
.79369 .13675 L
.79365 .13675 L
.79362 .13672 L
.7936 .13667 L
.79359 .1366 L
.79356 .13654 L
.79351 .1365 L
.79345 .1365 L
Mistroke
.7934 .13654 L
.79337 .13664 L
.79337 .13682 L
.79343 .13711 L
.79355 .13748 L
.79373 .13795 L
.794 .13847 L
.79433 .13904 L
.79476 .13966 L
.79528 .14036 L
.79592 .14113 L
.7967 .14199 L
.79759 .14297 L
.7986 .144 L
.79969 .14514 L
.80083 .14641 L
.80201 .14781 L
.80324 .14935 L
.8045 .15084 L
.80583 .15256 L
.80722 .15442 L
.80864 .15629 L
.81012 .15825 L
.81163 .1603 L
.81318 .16226 L
.81467 .1643 L
.81609 .1662 L
.81746 .16799 L
.81869 .16961 L
.81982 .17107 L
.82082 .17228 L
.82165 .17329 L
.82231 .17405 L
.82274 .17456 L
.82297 .1748 L
.82299 .17481 L
.82283 .17463 L
.82251 .17422 L
.8221 .17364 L
.82166 .17291 L
.82123 .17211 L
.82084 .17132 L
.82051 .1706 L
.82027 .17 L
.82013 .16955 L
.8201 .16927 L
.82017 .16919 L
.8203 .16925 L
.82046 .16945 L
.82063 .16968 L
Mistroke
.82079 .16998 L
.82096 .17038 L
.82113 .17088 L
.82128 .17151 L
.82143 .17228 L
.8216 .17326 L
.82183 .17452 L
.82216 .1761 L
.82262 .1779 L
.82326 .18021 L
.8241 .18283 L
.82522 .18591 L
.82657 .18935 L
.82824 .19328 L
.83018 .19755 L
.83245 .20226 L
.83484 .20694 L
.83766 .21169 L
.84038 .2166 L
.84345 .22121 L
.84667 .22621 L
.8501 .23069 L
.853 .23476 L
.8569 .23906 L
.85997 .24327 L
.86355 .24674 L
.86687 .25034 L
.87045 .25356 L
.87365 .25661 L
.87644 .25935 L
.87937 .26195 L
.88227 .26421 L
.88437 .26613 L
.88632 .2678 L
.8882 .26915 L
.88958 .27023 L
.89073 .27115 L
.89161 .2719 L
.89226 .27262 L
.89276 .27348 L
.89322 .27459 L
.89372 .27604 L
.89434 .27791 L
.8951 .28007 L
.89611 .28299 L
.89728 .28639 L
.89874 .28972 L
.90035 .2938 L
.90234 .2984 L
.90431 .30313 L
Mistroke
.90667 .30863 L
.9088 .31329 L
.91127 .31828 L
.91349 .32326 L
.91586 .32834 L
.91794 .33305 L
.91996 .33769 L
.92192 .34231 L
.92349 .34624 L
.92496 .35042 L
.92621 .35383 L
.92725 .3572 L
.92808 .36037 L
.92871 .36312 L
.92916 .36592 L
.92948 .36826 L
.92969 .37057 L
.92982 .37285 L
.9299 .37493 L
.92993 .37701 L
.92994 .37906 L
.92995 .38103 L
.92995 .38262 L
.92996 .38415 L
.92998 .3856 L
.93002 .38693 L
.93005 .38795 L
.93009 .38865 L
.93013 .38896 L
.93017 .38893 L
.93019 .38869 L
.93018 .38831 L
.93015 .38786 L
.93008 .38736 L
.92997 .38691 L
.92983 .38656 L
.92966 .38632 L
.92948 .38622 L
.92932 .38628 L
.92918 .3865 L
.92909 .38681 L
.92901 .38717 L
.92894 .38757 L
.92888 .38799 L
.92883 .38836 L
.92881 .38863 L
.92882 .38882 L
.92886 .38891 L
.92893 .38893 L
.92902 .3889 L
Mistroke
.92911 .38889 L
.92922 .38891 L
.92933 .38903 L
.92944 .38927 L
.92956 .38961 L
.92973 .39007 L
.92993 .39064 L
.93017 .39135 L
.93045 .39225 L
.93074 .39338 L
.93106 .39473 L
.93137 .39632 L
.93167 .3982 L
.93194 .40029 L
.93217 .40268 L
.93238 .40532 L
.93258 .40789 L
.93275 .41062 L
.93291 .41338 L
.93303 .41604 L
.93313 .41863 L
.93322 .42095 L
.93329 .42308 L
.93336 .42492 L
.93343 .42636 L
.93349 .42743 L
.93353 .42812 L
.93354 .42846 L
.93354 .42853 L
.93352 .42844 L
.93351 .42825 L
.93349 .42798 L
.93348 .42765 L
.93347 .4273 L
.93346 .42691 L
.93344 .42652 L
.93343 .42615 L
.93342 .42581 L
.93341 .42548 L
.93339 .42513 L
.93338 .42475 L
.93338 .42433 L
.93339 .42386 L
.9334 .42332 L
.93341 .4227 L
.9334 .42201 L
.93337 .42125 L
.9333 .42047 L
.93319 .41971 L
.93304 .41901 L
Mistroke
.93286 .41837 L
.93265 .4178 L
.93241 .41729 L
.93214 .41684 L
.93189 .41647 L
.93165 .4162 L
.93145 .41607 L
.93131 .41611 L
.93124 .41632 L
.93124 .41671 L
.93132 .41721 L
.93148 .41774 L
.93172 .41822 L
.932 .41863 L
.93231 .419 L
.93263 .41936 L
.93291 .41973 L
.93315 .42013 L
.9333 .42065 L
.93336 .42137 L
.93331 .42236 L
.93312 .42372 L
.93279 .4255 L
.93231 .42775 L
.93171 .43026 L
.93101 .43336 L
.93026 .43711 L
.92947 .4414 L
.92869 .44632 L
.92796 .4522 L
.92729 .45747 L
.9267 .46403 L
.92622 .4706 L
.92587 .47698 L
.92566 .48386 L
.9256 .4909 L
.92569 .49808 L
.92588 .50524 L
.92615 .51241 L
.92645 .52002 L
.92672 .52735 L
.92693 .53472 L
.92702 .54223 L
.927 .55007 L
.92688 .55747 L
.92665 .56587 L
.92633 .57269 L
.92595 .57991 L
.9255 .5867 L
.92503 .59307 L
Mistroke
.92452 .59988 L
.924 .60585 L
.92346 .6108 L
.92291 .61603 L
.92232 .62065 L
.92166 .62522 L
.92088 .62991 L
.91995 .63419 L
.91879 .63879 L
.91739 .64364 L
.91565 .64902 L
.91364 .65475 L
.91135 .66109 L
.90883 .66807 L
.90591 .67549 L
.90306 .683 L
.90016 .69136 L
.89724 .69845 L
.8944 .70638 L
.89169 .71412 L
.88926 .72195 L
.88708 .72921 L
.88512 .7364 L
.88335 .74296 L
.88187 .74861 L
.88054 .75441 L
.87936 .75988 L
.87834 .76459 L
.87749 .76906 L
.87678 .77278 L
.87611 .77618 L
.87539 .77901 L
.87448 .78163 L
.87328 .78412 L
.87182 .78626 L
.87002 .78828 L
.86786 .79019 L
.8653 .79198 L
.86254 .79367 L
.85923 .79531 L
.85605 .79682 L
.85213 .79848 L
.84774 .80028 L
.84341 .80214 L
.83837 .80417 L
.83309 .8063 L
.82762 .8086 L
.82195 .81104 L
.81623 .81342 L
.81027 .81592 L
Mistroke
.80413 .81841 L
.79793 .82102 L
.79149 .82364 L
.78492 .82631 L
.77824 .82895 L
.77154 .83144 L
.76479 .83367 L
.75769 .83555 L
.75183 .83696 L
.74544 .83786 L
.73894 .83819 L
.73304 .83794 L
.72703 .83709 L
.72123 .83566 L
.7154 .83371 L
.70989 .8312 L
.70422 .82838 L
.69846 .82516 L
.69268 .82166 L
.68645 .81804 L
.68067 .81428 L
.67461 .81051 L
.66812 .80682 L
.66212 .80337 L
.65582 .80017 L
.64971 .79737 L
.64326 .79502 L
.63704 .79325 L
.63069 .79202 L
.62459 .79139 L
.6183 .79129 L
.6122 .79169 L
.60579 .79249 L
.59946 .79362 L
.593 .79485 L
.58698 .79618 L
.58015 .79745 L
.57433 .79844 L
.56799 .79913 L
.5617 .79935 L
.55522 .799 L
.54893 .79793 L
.54228 .79612 L
.53625 .79358 L
.52963 .79034 L
.52332 .78655 L
.517 .7823 L
.51064 .77763 L
.50378 .77245 L
.49773 .76741 L
Mistroke
.49131 .76201 L
.48447 .75584 L
.47881 .75062 L
.47282 .7447 L
.46702 .7389 L
.46153 .7328 L
.45651 .72713 L
.452 .72217 L
.44795 .71731 L
.4443 .71296 L
.44127 .70905 L
.43872 .70529 L
.43682 .70256 L
.43542 .70016 L
.43459 .69811 L
.43434 .6965 L
.43457 .69522 L
.43523 .69424 L
.43624 .69358 L
.43756 .69311 L
.43908 .69266 L
.44084 .69221 L
.4429 .69175 L
.44508 .69119 L
.44749 .69042 L
.45012 .68952 L
.45298 .68864 L
.45616 .68787 L
.45937 .68727 L
.46299 .68685 L
.46698 .68663 L
.47126 .68654 L
.47603 .68655 L
.48107 .68665 L
.48631 .68687 L
.49225 .68722 L
.49802 .68773 L
.50404 .68847 L
.51025 .68943 L
.51704 .69068 L
.52358 .69221 L
.53026 .69398 L
.53644 .69602 L
.54304 .69818 L
.54953 .70066 L
.5559 .70346 L
.56182 .70665 L
.56788 .71006 L
.57382 .71373 L
.5799 .71812 L
Mistroke
.58597 .72216 L
.59213 .72675 L
.59795 .73165 L
.60438 .73715 L
.60969 .74203 L
.61519 .74762 L
.62101 .75369 L
.62569 .75967 L
.63073 .76596 L
.63522 .77254 L
.63959 .77951 L
.64362 .78589 L
.64747 .79273 L
.65121 .79958 L
.65505 .80624 L
.65882 .81256 L
.66274 .819 L
.66702 .82453 L
.67156 .82954 L
.67634 .83461 L
.68141 .8391 L
.68637 .84318 L
.69163 .84669 L
.69666 .84986 L
.70188 .8525 L
.7064 .85507 L
.71127 .85724 L
.7158 .85923 L
.72014 .86092 L
.72447 .86253 L
.72802 .86394 L
.73139 .86519 L
.7344 .86629 L
.73693 .86735 L
.73904 .86836 L
.74067 .86929 L
.74175 .8702 L
.74235 .87109 L
.7425 .87196 L
.74228 .87281 L
.74176 .87363 L
.74101 .87442 L
.74013 .87512 L
.73926 .87581 L
.7384 .87647 L
.7376 .8771 L
.73692 .87764 L
.73641 .87809 L
.7361 .87841 L
.73599 .8786 L
Mistroke
.73608 .87867 L
.73637 .87864 L
.73686 .87853 L
.73751 .87839 L
.73829 .87827 L
.73918 .87816 L
.74017 .87802 L
.74128 .8778 L
.74257 .87748 L
.74399 .87703 L
.74562 .87643 L
.74743 .87569 L
.74934 .8748 L
.75152 .87373 L
.75382 .87246 L
.75634 .87101 L
.75911 .86935 L
.76188 .86747 L
.76493 .86542 L
.76792 .86326 L
.77116 .86097 L
.77444 .85857 L
.77779 .85622 L
.78114 .85379 L
.78425 .85147 L
.78729 .84909 L
.79002 .84704 L
.79249 .84507 L
.79474 .84327 L
.79672 .84168 L
.79836 .84033 L
.79974 .83926 L
.80082 .83842 L
.80166 .83779 L
.8023 .83731 L
.80279 .83693 L
.80316 .83662 L
.80343 .83641 L
.80359 .8363 L
.80364 .83635 L
.80356 .83656 L
.80338 .83694 L
.80311 .83744 L
.80276 .83805 L
.80234 .83874 L
.80188 .83947 L
.80139 .84023 L
.80091 .84097 L
.80044 .8417 L
.8 .84242 L
Mistroke
.7996 .8431 L
.79924 .84371 L
.79896 .84419 L
.79878 .84454 L
.79869 .84475 L
.79868 .84484 L
.79871 .84484 L
.79876 .84475 L
.79879 .84462 L
.79878 .84449 L
.79874 .84438 L
.79865 .84427 L
.79855 .84416 L
.79845 .84404 L
.79837 .84389 L
.79832 .84369 L
.79832 .84342 L
.79837 .84307 L
.79846 .84264 L
.79861 .84213 L
.79882 .84158 L
.79907 .841 L
.79936 .84041 L
.79967 .83983 L
.80001 .83928 L
.80038 .83872 L
.80075 .83819 L
.80107 .83772 L
.80128 .83732 L
.80136 .83706 L
.8013 .83696 L
.80107 .83705 L
.80068 .83733 L
.80013 .83776 L
.79947 .83829 L
.79875 .83889 L
.79802 .8395 L
.79735 .84007 L
.79673 .84061 L
.79617 .84112 L
.79568 .8416 L
.79531 .84201 L
.79508 .84233 L
.795 .84255 L
.79507 .84266 L
.79525 .84268 L
.79553 .84262 L
.79585 .84252 L
.79617 .84242 L
.79643 .84233 L
Mistroke
.79661 .84229 L
.79671 .84227 L
.79677 .84227 L
.79679 .84226 L
.79677 .84226 L
.79674 .84227 L
.7967 .84227 L
.79667 .84227 L
.79666 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84232 L
.79665 .84241 L
.79665 .84256 L
.79665 .84273 L
.79664 .84293 L
.7966 .84309 L
.79653 .84318 L
.79643 .84314 L
.7963 .84292 L
.79614 .84244 L
Mistroke
.796 .84162 L
.79592 .84036 L
.79595 .8386 L
.79614 .83652 L
.79654 .83384 L
.79722 .83067 L
.79821 .82679 L
.79954 .82286 L
.80128 .81852 L
.80346 .81343 L
.80592 .80898 L
.80883 .80414 L
.81216 .79908 L
.81579 .79486 L
.81961 .79049 L
.82365 .78642 L
.82776 .78283 L
.83201 .77959 L
.83597 .77698 L
.84012 .77475 L
.8434 .77313 L
.84718 .77192 L
.85089 .77115 L
.85381 .77079 L
.85638 .77074 L
.859 .77094 L
.86082 .77132 L
.86276 .77177 L
.86414 .77224 L
.86531 .77267 L
.86631 .77299 L
.86717 .77312 L
.86798 .77303 L
.86882 .77267 L
.86975 .77201 L
.87083 .77109 L
.87195 .76985 L
.87318 .76825 L
.87454 .7663 L
.87606 .76396 L
.87782 .76137 L
.8798 .75833 L
.8816 .75499 L
.88346 .75121 L
.88527 .74728 L
.88702 .74321 L
.88864 .73858 L
.89016 .73441 L
.89158 .72976 L
.89294 .72541 L
Mistroke
.8943 .72138 L
.89555 .71719 L
.89687 .71317 L
.89814 .70951 L
.89944 .70585 L
.90072 .70253 L
.90196 .69928 L
.90318 .696 L
.90433 .69294 L
.90546 .68977 L
.90659 .68641 L
.90769 .68335 L
.90882 .67999 L
.90994 .67649 L
.91112 .67273 L
.91231 .66904 L
.91359 .66499 L
.91486 .66049 L
.91619 .65614 L
.91759 .65136 L
.91906 .64631 L
.92061 .64069 L
.92222 .63562 L
.92389 .62943 L
.92561 .62392 L
.9274 .61781 L
.9291 .61218 L
.93084 .60592 L
.93257 .59971 L
.9343 .59394 L
.93592 .58776 L
.93744 .58219 L
.93884 .57639 L
.94005 .57094 L
.94108 .56573 L
.9419 .56054 L
.94251 .55534 L
.9429 .55109 L
.94312 .54665 L
.94314 .54274 L
.94303 .53933 L
.94281 .53628 L
.94251 .53384 L
.94218 .53186 L
.94183 .53038 L
.94149 .52938 L
.94118 .52886 L
.94093 .52876 L
.94075 .52901 L
.94065 .52954 L
Mistroke
.94061 .53026 L
.94063 .5311 L
.94067 .53199 L
.94073 .53287 L
.94079 .53369 L
.94084 .53439 L
.9409 .53495 L
.94095 .53539 L
.94102 .53569 L
.94108 .53587 L
.94114 .53591 L
.94119 .53586 L
.94125 .53573 L
.9413 .5356 L
.94134 .53551 L
.94134 .53547 L
.94129 .53546 L
.9412 .53545 L
.94106 .53547 L
.94086 .53552 L
.9406 .53562 L
.94034 .53579 L
.94012 .53602 L
.93996 .53632 L
.93985 .53667 L
.93979 .53707 L
.93976 .53752 L
.93975 .53799 L
.93975 .53847 L
.93984 .53892 L
.94001 .53932 L
.94023 .53962 L
.94049 .53979 L
.94076 .53982 L
.94102 .53971 L
.94125 .53947 L
.9414 .53912 L
.94144 .53868 L
.94142 .53817 L
.94137 .5376 L
.94133 .537 L
.94131 .53643 L
.94129 .53592 L
.94128 .53552 L
.94126 .53527 L
.94122 .53521 L
.94114 .53536 L
.94103 .5357 L
.94089 .5362 L
.94073 .5368 L
Mistroke
.94055 .53745 L
.94036 .53813 L
.94017 .53878 L
.93998 .5394 L
.9398 .54002 L
.93963 .54066 L
.93949 .54136 L
.93938 .54213 L
.93932 .543 L
.9393 .54397 L
.93932 .54505 L
.93939 .5462 L
.9395 .54747 L
.93964 .54883 L
.93976 .55026 L
.93984 .55166 L
.93986 .55312 L
.93982 .55442 L
.93969 .55559 L
.93947 .55658 L
.93916 .55736 L
.93877 .55791 L
.93833 .55823 L
.93788 .55836 L
.93745 .55835 L
.93704 .55825 L
.93665 .5581 L
.93629 .55795 L
.93603 .55787 L
.9359 .55783 L
.93594 .55783 L
.93614 .55782 L
.9365 .5578 L
.93697 .55778 L
.93752 .55775 L
.93813 .55773 L
.93878 .55769 L
.93939 .55764 L
.93999 .55757 L
.94057 .55751 L
.94106 .55747 L
.94147 .55749 L
.94176 .55755 L
.94192 .55766 L
.94192 .55779 L
.94178 .55794 L
.9415 .55809 L
.94113 .55822 L
.9407 .55832 L
.94023 .5584 L
Mistroke
.93977 .55844 L
.93935 .55849 L
.93893 .55855 L
.93855 .55858 L
.93821 .55856 L
.93793 .55845 L
.93773 .55824 L
.93762 .55795 L
.93757 .55761 L
.93758 .55727 L
.93762 .55697 L
.93768 .55676 L
.93773 .55667 L
.93775 .55667 L
.93775 .55673 L
.93775 .55678 L
.93775 .55678 L
.93775 .55673 L
.93775 .55664 L
.93775 .55653 L
.93774 .55637 L
.93774 .55617 L
.93773 .55591 L
.93772 .5556 L
.93771 .55525 L
.9377 .55482 L
.93769 .55438 L
.93768 .55407 L
.93767 .55396 L
.93768 .554 L
.93768 .55416 L
.93769 .55437 L
.9377 .55455 L
.93771 .55451 L
.9377 .55406 L
.93766 .553 L
.9376 .55114 L
.93751 .54831 L
.93739 .54446 L
.93724 .53968 L
.93706 .5345 L
.93684 .52793 L
.9366 .52046 L
.93633 .51204 L
.93604 .50285 L
.93576 .49468 L
.93547 .48446 L
.93519 .47542 L
.93491 .46566 L
.93462 .45666 L
Mistroke
.93431 .44723 L
.93396 .43886 L
.93357 .43062 L
.93314 .42164 L
.93265 .41419 L
.9321 .40623 L
.93149 .39751 L
.93083 .39047 L
.9301 .38281 L
.92929 .3751 L
.92842 .36831 L
.92751 .3615 L
.92656 .35484 L
.92559 .34923 L
.92467 .34386 L
.92378 .3392 L
.92297 .33524 L
.92224 .3321 L
.9216 .32965 L
.92104 .32789 L
.92058 .32674 L
.92021 .32605 L
.91993 .32575 L
.91974 .32575 L
.91964 .32593 L
.9196 .32624 L
.91962 .3266 L
.91966 .32697 L
.91971 .3273 L
.91977 .32757 L
.91981 .32778 L
.91984 .32793 L
.91986 .32804 L
.91987 .32809 L
.9199 .32808 L
.91996 .32799 L
.92004 .32776 L
.92011 .32735 L
.92015 .32672 L
.92013 .32583 L
.92001 .3247 L
.91977 .32328 L
.91939 .32163 L
.91886 .31973 L
.91822 .31768 L
.91747 .31551 L
.91663 .3133 L
.91583 .31117 L
.91494 .30913 L
.9141 .30732 L
Mistroke
.91327 .30572 L
.91249 .30439 L
.91184 .30333 L
.91132 .30254 L
.91096 .302 L
.91074 .30169 L
.91065 .30154 L
.91064 .30151 L
.91069 .30158 L
.91075 .30168 L
.91077 .30181 L
.91076 .30191 L
.91073 .30198 L
.91068 .30197 L
.91056 .30183 L
.91034 .30152 L
.91001 .30103 L
.90956 .30033 L
.90897 .29944 L
.90825 .29837 L
.9074 .29714 L
.90647 .2958 L
.90543 .29434 L
.9043 .29278 L
.90308 .29106 L
.90171 .28913 L
.90033 .28706 L
.89874 .28469 L
.89692 .28201 L
.89491 .27904 L
.89275 .27576 L
.89038 .27217 L
.88778 .26834 L
.88495 .26367 L
.88194 .25929 L
.87858 .25362 L
.87505 .24876 L
.87113 .24264 L
.8672 .23666 L
.86309 .23101 L
.85893 .22484 L
.85487 .21889 L
.85053 .21235 L
.84659 .20676 L
.8426 .20156 L
.83859 .19587 L
.83462 .19022 L
.83077 .18475 L
.82688 .1789 L
.82343 .1742 L
Mistroke
.82009 .16933 L
.81694 .16451 L
.8142 .16068 L
.81168 .15713 L
.80952 .15362 L
.80773 .15114 L
.80627 .14896 L
.80518 .14726 L
.8044 .14594 L
.80391 .14504 L
.80367 .14455 L
.80364 .14439 L
.80372 .14444 L
.80388 .14462 L
.80406 .14487 L
.80421 .14511 L
.80431 .14531 L
.80438 .14544 L
.80444 .14553 L
.80449 .1456 L
.80452 .14567 L
.80454 .14571 L
.80453 .14568 L
.80448 .14559 L
.80439 .14542 L
.80426 .14517 L
.8041 .14485 L
.80392 .14448 L
.80373 .14408 L
.80353 .14365 L
.80334 .14321 L
.80312 .14276 L
.80289 .14231 L
.80263 .14185 L
.80237 .14143 L
.8021 .14105 L
.80183 .14076 L
.80159 .14055 L
.80136 .14046 L
.80115 .14047 L
.80096 .14056 L
.80078 .14066 L
.80059 .14071 L
.80041 .14069 L
.80024 .14058 L
.8001 .14042 L
.8 .14024 L
.79994 .14005 L
.79993 .13989 L
.79994 .13977 L
Mistroke
.79997 .13968 L
.80001 .13964 L
.80003 .13961 L
.80005 .1396 L
.80005 .1396 L
.80005 .13963 L
.80007 .13973 L
.8001 .13993 L
.80014 .14021 L
.80018 .14057 L
.80023 .14096 L
.80028 .14136 L
.80032 .14171 L
.80034 .14197 L
.80034 .14211 L
.80028 .14214 L
.80014 .14207 L
.79988 .14192 L
.7995 .14172 L
.79897 .14146 L
.79826 .14109 L
.79737 .1406 L
.79626 .14 L
.79497 .13928 L
.79345 .13846 L
.79166 .13751 L
.78965 .13644 L
.78737 .13524 L
.78483 .13393 L
.78185 .1325 L
.77876 .13101 L
.77533 .12939 L
.77168 .12763 L
.76804 .1259 L
.76414 .1241 L
.76038 .12227 L
.75681 .12056 L
.75322 .11886 L
.74967 .11723 L
.74639 .11577 L
.74358 .11439 L
.74094 .11314 L
.73861 .11201 L
.7365 .11098 L
.7347 .11003 L
.73298 .10916 L
.73137 .10829 L
.72971 .10742 L
.72793 .10653 L
.72606 .10564 L
Mistroke
.724 .10474 L
.72162 .10379 L
.71903 .1028 L
.71604 .10175 L
.71244 .10063 L
.70879 .09941 L
.70454 .09804 L
.69987 .09651 L
.69442 .0948 L
.68892 .09288 L
.68389 .09086 L
.67765 .08875 L
.67192 .08637 L
.66534 .08382 L
.65857 .08115 L
.6519 .07826 L
.64545 .0754 L
.63852 .07242 L
.63146 .06952 L
.62425 .06662 L
.61722 .06408 L
.61034 .06147 L
.60335 .05936 L
.5964 .05737 L
.58949 .05558 L
.58251 .05414 L
.57591 .05296 L
.56994 .05205 L
.56331 .05141 L
.558 .05101 L
.55228 .0508 L
.54709 .05072 L
.54198 .05072 L
.53676 .05073 L
.53176 .05072 L
.52623 .05069 L
.52132 .05063 L
.51572 .05054 L
.51017 .05042 L
.50418 .05029 L
.49799 .05014 L
.49199 .04999 L
.48567 .04981 L
.47903 .04962 L
.47246 .04941 L
.46609 .04919 L
.45952 .04897 L
.45299 .04876 L
.44633 .04854 L
.44017 .04833 L
Mistroke
.43396 .04813 L
.4282 .04793 L
.42278 .04773 L
.41788 .04754 L
.41307 .04738 L
.40938 .04725 L
.40602 .04714 L
.40317 .04707 L
.40104 .04703 L
.39942 .04701 L
.3983 .047 L
.39764 .04701 L
.39736 .04703 L
.39735 .04704 L
.39751 .04706 L
.39776 .04707 L
.39803 .04708 L
.39824 .04708 L
.39838 .04707 L
.39847 .04705 L
.39852 .04702 L
.39853 .04697 L
.39853 .0469 L
.39853 .04682 L
.39853 .04675 L
.39853 .04673 L
.39853 .04676 L
.39853 .04685 L
.39853 .04696 L
.39853 .04709 L
.39853 .04724 L
.39853 .04742 L
.39853 .04763 L
.39853 .0479 L
.39853 .04822 L
.39853 .04857 L
.39853 .04894 L
.39853 .04931 L
.39853 .04971 L
.39853 .05007 L
.39853 .05036 L
.39854 .05064 L
.39859 .05088 L
.39868 .05107 L
.39883 .05124 L
.39899 .05137 L
.39912 .05147 L
.39918 .05151 L
.39909 .05148 L
.39885 .05141 L
Mistroke
.39841 .05132 L
.39776 .05126 L
.39689 .05126 L
.3958 .05135 L
.39451 .0515 L
.39312 .05169 L
.39153 .05191 L
.38974 .05219 L
.38788 .05252 L
.38587 .05295 L
.38379 .05349 L
.38166 .05417 L
.37957 .05498 L
.37755 .05592 L
.37555 .05697 L
.37357 .05808 L
.3717 .05915 L
.36978 .06022 L
.36793 .06125 L
.36616 .06223 L
.36457 .06316 L
.3632 .06394 L
.36202 .06458 L
.36102 .06507 L
.36012 .06541 L
.35933 .0656 L
.35853 .0657 L
.35772 .06574 L
.35681 .06586 L
.3557 .06616 L
.35431 .06672 L
.35259 .0676 L
.35064 .06878 L
.34834 .07036 L
.34562 .0722 L
.34236 .0745 L
.33915 .07703 L
.33508 .07998 L
.33094 .08288 L
.32627 .08607 L
.32063 .08954 L
.31593 .09267 L
.30952 .09605 L
.30402 .0994 L
.29782 .10254 L
.29148 .10578 L
.28447 .10916 L
.27746 .11218 L
.27065 .11542 L
.26375 .11863 L
Mistroke
.25632 .12165 L
.2501 .12467 L
.24393 .12771 L
.23817 .13063 L
.2319 .13366 L
.22751 .13643 L
.22283 .1394 L
.21822 .14248 L
.21476 .14542 L
.21126 .14871 L
.20781 .15234 L
.20502 .15556 L
.2021 .15921 L
.19908 .16347 L
.19645 .16724 L
.19345 .17174 L
.19055 .17595 L
.18743 .18059 L
.18418 .18532 L
.18088 .19012 L
.17788 .19445 L
.17494 .19857 L
.1722 .20243 L
.16944 .20656 L
.16714 .20978 L
.16489 .21298 L
.16261 .21646 L
.16055 .21946 L
.15842 .22268 L
.15624 .22593 L
.15387 .22955 L
.15118 .23361 L
.14859 .23729 L
.1457 .24123 L
.14247 .24583 L
.13916 .25038 L
.13551 .25538 L
.13146 .26135 L
.12791 .26613 L
.12401 .27157 L
.1201 .2771 L
.11622 .28305 L
.11278 .28799 L
.10927 .29394 L
.10635 .2988 L
.10353 .30431 L
.10099 .30968 L
.0986 .31515 L
.09643 .32054 L
.09457 .3262 L
Mistroke
.09284 .33117 L
.09126 .33665 L
.08989 .34251 L
.08864 .34742 L
.08753 .35333 L
.08658 .35807 L
.08568 .36339 L
.08484 .36834 L
.08403 .37315 L
.08325 .378 L
.08252 .38185 L
.08188 .38581 L
.08136 .38916 L
.08094 .3922 L
.08062 .39467 L
.08039 .39677 L
.08021 .39834 L
.08009 .3995 L
.08 .4003 L
.07994 .40078 L
.07992 .401 L
.07993 .401 L
.07998 .40088 L
.08003 .40071 L
.08007 .40052 L
.0801 .40034 L
.0801 .40022 L
.0801 .40014 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08005 .40006 L
.08001 .40002 L
.07997 .39999 L
.07993 .39997 L
.07991 .39998 L
.07992 .40002 L
.07996 .40009 L
.08003 .40017 L
Mistroke
.08016 .40027 L
.08038 .40039 L
.08072 .40056 L
.08118 .40079 L
.08177 .4011 L
.08249 .4015 L
.08332 .402 L
.08424 .4026 L
.08518 .4033 L
.08613 .40408 L
.08703 .40492 L
.08773 .40573 L
.08844 .40656 L
.08911 .40735 L
.08973 .40815 L
.09029 .40886 L
.09075 .40961 L
.0911 .41039 L
.09132 .41122 L
.09143 .4121 L
.09145 .41304 L
.09139 .41408 L
.09129 .41518 L
.09118 .41641 L
.09109 .41769 L
.09103 .41886 L
.09094 .42014 L
.09082 .42131 L
.09068 .42249 L
.09053 .42365 L
.09038 .42472 L
.09025 .42567 L
.09014 .4265 L
.09007 .42724 L
.09003 .42789 L
.09004 .42846 L
.09006 .42896 L
.09007 .42942 L
.09006 .4299 L
.09005 .43036 L
.09003 .43079 L
.09002 .43114 L
.09001 .43142 L
.09 .43161 L
.09 .43172 L
.09002 .43175 L
.09011 .43169 L
.09025 .43158 L
.09038 .43145 L
.09046 .43134 L
Mistroke
.09047 .43127 L
.0904 .43122 L
.09022 .43118 L
.08989 .43114 L
.08931 .43108 L
.08848 .43103 L
.08743 .43098 L
.08619 .43096 L
.08487 .43098 L
.08356 .43104 L
.08205 .43118 L
.08018 .43142 L
.07839 .43177 L
.07658 .43223 L
.07454 .43281 L
.07259 .43351 L
.07097 .43431 L
.06951 .4352 L
.06805 .43617 L
.06664 .43717 L
.06543 .43816 L
.06453 .43907 L
.06378 .43987 L
.06317 .44056 L
.06271 .4411 L
.06238 .44149 L
.06217 .44173 L
.06207 .44185 L
.06205 .44186 L
.06207 .4418 L
.06213 .44169 L
.06222 .44157 L
.06232 .44145 L
.06237 .4414 L
.06239 .44142 L
.06239 .44153 L
.06238 .4417 L
.06238 .44191 L
.06237 .44216 L
.06236 .44244 L
.06235 .4427 L
.06234 .4429 L
.06234 .44305 L
.06234 .44317 L
.06233 .44329 L
.06233 .44341 L
.06232 .44356 L
.06229 .44374 L
.06223 .44394 L
.06214 .44419 L
Mistroke
.06204 .4445 L
.06196 .4449 L
.06192 .44538 L
.06196 .44592 L
.06211 .4465 L
.06239 .44715 L
.0628 .44788 L
.06334 .44868 L
.06407 .44953 L
.06481 .45036 L
.06545 .45119 L
.06625 .45205 L
.067 .45296 L
.06786 .45398 L
.06854 .45517 L
.06915 .45661 L
.06966 .45817 L
.06999 .45997 L
.07012 .46204 L
.07006 .46442 L
.06981 .46709 L
.06939 .46965 L
.06884 .47248 L
.0682 .47564 L
.06757 .47869 L
.06691 .48182 L
.06625 .48469 L
.0656 .48748 L
.065 .48988 L
.06448 .49204 L
.06403 .49363 L
.06368 .49482 L
.06344 .49563 L
.06328 .49607 L
.06317 .49622 L
.0631 .49619 L
.06305 .49617 L
.063 .49636 L
.06293 .49684 L
.06281 .49768 L
.06266 .49875 L
.06249 .5004 L
.06234 .50266 L
.06223 .505 L
.06217 .50781 L
.06217 .51081 L
.06222 .51369 L
.06237 .51694 L
.06258 .51945 L
.06284 .52175 L
Mistroke
.06312 .52387 L
.0634 .5257 L
.06365 .52708 L
.06386 .52799 L
.06402 .52858 L
.06412 .52905 L
.06414 .52959 L
.06409 .53035 L
.06405 .53141 L
.06407 .53285 L
.06416 .53492 L
.06428 .53774 L
.06449 .54084 L
.06484 .54461 L
.06536 .54892 L
.06595 .55356 L
.0666 .5589 L
.06728 .56407 L
.06792 .56982 L
.06864 .57589 L
.06924 .58138 L
.06978 .58766 L
.07025 .59209 L
.07068 .59754 L
.07104 .60171 L
.07136 .60545 L
.07164 .60915 L
.07189 .61239 L
.07216 .6149 L
.07245 .61702 L
.07276 .61874 L
.07311 .62009 L
.07349 .62112 L
.07386 .62189 L
.07418 .62241 L
.07446 .62287 L
.07469 .6232 L
.07486 .62345 L
.07498 .62362 L
.07507 .62377 L
.07512 .62393 L
.07514 .62418 L
.07517 .62462 L
.07522 .62532 L
.07531 .62629 L
.07545 .6276 L
.07568 .62933 L
.07599 .6315 L
.0764 .63377 L
.07683 .63643 L
Mistroke
.07732 .63981 L
.07788 .64303 L
.07847 .6468 L
.07903 .65065 L
.07958 .65488 L
.0801 .65852 L
.08056 .66223 L
.08093 .66604 L
.08122 .66915 L
.08141 .67225 L
.08153 .67521 L
.08159 .67772 L
.08162 .67997 L
.08165 .68181 L
.08169 .6832 L
.08177 .68421 L
.08189 .68485 L
.08205 .68519 L
.08224 .68531 L
.08247 .68531 L
.08274 .68522 L
.08302 .68507 L
.0833 .68486 L
.08357 .68465 L
.08383 .68446 L
.08406 .68429 L
.08424 .68416 L
.08437 .68407 L
.08444 .68401 L
.08446 .68398 L
.08445 .68399 L
.08441 .68402 L
.08436 .68405 L
.08432 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.0843 .68406 L
.08429 .68402 L
.08426 .68394 L
Mistroke
.08422 .68382 L
.08419 .68372 L
.08417 .68366 L
.08418 .6837 L
.08423 .68386 L
.08433 .68415 L
.08448 .68459 L
.08467 .68515 L
.0849 .68581 L
.08514 .68653 L
.0854 .6873 L
.08566 .68805 L
.08592 .68879 L
.08617 .68951 L
.08639 .69018 L
.08656 .69073 L
.08669 .69114 L
.08676 .69141 L
.0868 .69155 L
.08683 .69163 L
.08687 .69169 L
.08694 .69177 L
.08705 .69193 L
.08721 .69221 L
.08743 .69261 L
.08768 .69309 L
.08795 .69361 L
.08821 .69411 L
.08848 .69462 L
.08874 .69511 L
.08897 .69556 L
.08918 .69596 L
.08935 .69628 L
.08947 .6965 L
.08953 .69662 L
.08956 .69666 L
.08954 .69663 L
.0895 .69656 L
.08946 .69648 L
.08942 .69641 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69637 L
.08941 .69634 L
.08941 .69625 L
.08941 .69613 L
.0894 .69602 L
Mistroke
.08937 .69595 L
.08933 .69594 L
.08929 .696 L
.08926 .69618 L
.08927 .69648 L
.08931 .69693 L
.0894 .69756 L
.08954 .69841 L
.08971 .69948 L
.08992 .70073 L
.09015 .7021 L
.09037 .70361 L
.09057 .70521 L
.09075 .70685 L
.09093 .70839 L
.0911 .70987 L
.09126 .71132 L
.09143 .7128 L
.09159 .71412 L
.09177 .71542 L
.09199 .71672 L
.09226 .71805 L
.0926 .71942 L
.09302 .72081 L
.09352 .72208 L
.09414 .72345 L
.09485 .72491 L
.0956 .72643 L
.09633 .72789 L
.09702 .72927 L
.09763 .73049 L
.09813 .73143 L
.09848 .73209 L
.0987 .73249 L
.09879 .73262 L
.09875 .73252 L
.09861 .73223 L
.09841 .73182 L
.09816 .73134 L
.09788 .73081 L
.09759 .73025 L
.0973 .7297 L
.09703 .7292 L
.09682 .72881 L
.09668 .72857 L
.09661 .72845 L
.09659 .72842 L
.0966 .72845 L
.09664 .72854 L
.09668 .72865 L
Mistroke
.09672 .72871 L
.09674 .7287 L
.09674 .72861 L
.09675 .72846 L
.09675 .72825 L
.09676 .72797 L
.09677 .72761 L
.09677 .72726 L
.09678 .72688 L
.09679 .72648 L
.0968 .72609 L
.09681 .72569 L
.09681 .72532 L
.09682 .72494 L
.09682 .72465 L
.09683 .72437 L
.09684 .72413 L
.09684 .72393 L
.09684 .72382 L
.09685 .72375 L
.09685 .72373 L
.09685 .72374 L
.09685 .72375 L
.09685 .72374 L
.09685 .72374 L
.09685 .72374 L
.09685 .72376 L
.09685 .72378 L
.09685 .72379 L
.09685 .7238 L
.09684 .72382 L
.09685 .72382 L
.09685 .72378 L
.09685 .72371 L
.09685 .7236 L
.09686 .72349 L
.09686 .72341 L
.09687 .72342 L
.09689 .72355 L
.0969 .7238 L
.0969 .72415 L
.09687 .72455 L
.09683 .72497 L
.09677 .72535 L
.09671 .72564 L
.09664 .72585 L
.09658 .72597 L
.09654 .72602 L
.09651 .726 L
.09649 .72591 L
Mistroke
.09649 .72575 L
.09649 .72548 L
.0965 .72513 L
.09653 .72473 L
.09657 .7243 L
.09662 .72391 L
.09668 .7236 L
.09675 .72341 L
.09681 .72335 L
.09686 .72338 L
.0969 .72345 L
.09691 .72353 L
.09691 .72359 L
.09689 .72362 L
.09687 .72363 L
.09686 .72363 L
.09686 .72363 L
.09686 .72365 L
.09686 .72368 L
.09685 .72372 L
.09685 .72375 L
.09685 .72377 L
.09683 .72376 L
.09679 .72371 L
.09673 .72361 L
.09667 .72347 L
.09661 .72328 L
.09657 .72307 L
.09658 .72285 L
.09669 .72264 L
.09691 .72245 L
.09725 .72225 L
.09772 .72203 L
.0983 .72178 L
.09902 .72151 L
.09974 .72121 L
.10056 .72088 L
.10133 .72051 L
.10206 .7201 L
.10279 .71964 L
.10336 .71909 L
.10382 .71842 L
.10414 .71758 L
.10437 .71654 L
.10455 .71529 L
.10467 .71383 L
.10479 .71225 L
.10496 .71053 L
.10522 .70865 L
.10556 .70675 L
Mistroke
.10606 .70479 L
.10677 .70278 L
.10765 .70068 L
.10888 .69858 L
.11008 .69656 L
.11146 .69447 L
.11295 .6924 L
.11447 .69037 L
.11619 .6883 L
.1178 .68631 L
.1194 .68429 L
.12117 .68234 L
.12294 .68041 L
.1247 .67865 L
.12654 .67695 L
.12815 .6753 L
.12986 .67386 L
.13128 .67251 L
.13268 .67136 L
.13377 .67034 L
.13473 .66947 L
.13555 .66873 L
.13615 .6681 L
.1365 .66753 L
.1366 .66696 L
.13647 .6663 L
.13614 .66545 L
.13564 .66434 L
.13502 .66292 L
.13436 .66122 L
.13366 .65922 L
.13295 .65686 L
.13224 .65446 L
.13157 .65179 L
.13093 .6488 L
.13034 .6459 L
.12985 .64287 L
.12946 .63945 L
.12919 .6363 L
.12904 .6327 L
.12901 .62916 L
.12905 .62542 L
.12906 .62169 L
.12912 .61786 L
.12916 .61391 L
.12919 .60962 L
.12921 .60582 L
.12923 .60141 L
.12931 .59695 L
.12953 .59259 L
Mistroke
.12993 .5879 L
.1305 .58328 L
.13124 .57878 L
.13212 .57435 L
.13303 .57052 L
.13408 .5669 L
.13525 .56354 L
.13642 .56053 L
.13766 .55782 L
.1389 .55508 L
.13997 .55271 L
.141 .55032 L
.14194 .5478 L
.14277 .54512 L
.14341 .54227 L
.14389 .53961 L
.14429 .53676 L
.14465 .53343 L
.14498 .53033 L
.14527 .52708 L
.14555 .52347 L
.14586 .51998 L
.14616 .51632 L
.14641 .51256 L
.14661 .50927 L
.14674 .50583 L
.14683 .50252 L
.14691 .4992 L
.14702 .49568 L
.14722 .49232 L
.14751 .48888 L
.14797 .48523 L
.14858 .48159 L
.14935 .47796 L
.15024 .47436 L
.15127 .47102 L
.15242 .46775 L
.15363 .46471 L
.15493 .46185 L
.1562 .45931 L
.15752 .45695 L
.15876 .45486 L
.15999 .45287 L
.16121 .45093 L
.16237 .44899 L
.16356 .44707 L
.16469 .44505 L
.16582 .44299 L
.16693 .44084 L
.16794 .43864 L
Mistroke
.16892 .43635 L
.16983 .4342 L
.17068 .432 L
.17151 .42973 L
.17227 .42761 L
.17303 .42543 L
.1738 .42324 L
.17462 .42103 L
.17549 .41888 L
.17641 .41667 L
.17732 .4145 L
.17833 .41225 L
.17934 .40996 L
.18043 .40754 L
.18149 .40484 L
.18262 .402 L
.1838 .39883 L
.18497 .3954 L
.18625 .39171 L
.18753 .38782 L
.18889 .38368 L
.1903 .37978 L
.19177 .37563 L
.19315 .37177 L
.1946 .36777 L
.19622 .36399 L
.19779 .36062 L
.19953 .3571 L
.20124 .35412 L
.20309 .35115 L
.20495 .34849 L
.20692 .34589 L
.20885 .34356 L
.21087 .34121 L
.21271 .33895 L
.2147 .33671 L
.21675 .33431 L
.21882 .3319 L
.22095 .32934 L
.22311 .32664 L
.22534 .32376 L
.22731 .32093 L
.22927 .31783 L
.23116 .31454 L
.23299 .31097 L
.23473 .30731 L
.23648 .3034 L
.23826 .29924 L
.24002 .29483 L
.24177 .29041 L
Mistroke
.24351 .28582 L
.24521 .28164 L
.24697 .27736 L
.24867 .27328 L
.25043 .26923 L
.25215 .26599 L
.25398 .26279 L
.25592 .25978 L
.25797 .25716 L
.26031 .25462 L
.26279 .25229 L
.26539 .24993 L
.26836 .24761 L
.27143 .24514 L
.27481 .24257 L
.27835 .23981 L
.28202 .23708 L
.28577 .23396 L
.28984 .2308 L
.29384 .22742 L
.29732 .22405 L
.30134 .22052 L
.30498 .21695 L
.3085 .21347 L
.31205 .20989 L
.3156 .2063 L
.31908 .20238 L
.3221 .19879 L
.32538 .19488 L
.32832 .19092 L
.33146 .18686 L
.33411 .18282 L
.33686 .17879 L
.3394 .17471 L
.34202 .17053 L
.34437 .1662 L
.34681 .16172 L
.34921 .15727 L
.35174 .15338 L
.35431 .14872 L
.35706 .14426 L
.36002 .14003 L
.36286 .1352 L
.36646 .13147 L
.36958 .12714 L
.37281 .1232 L
.37633 .11991 L
.37964 .11642 L
.38331 .11295 L
.38625 .1104 L
Mistroke
.38947 .10797 L
.39272 .10572 L
.39559 .10362 L
.39824 .10167 L
.4012 .0997 L
.40365 .09786 L
.40614 .09598 L
.40866 .09406 L
.41069 .09236 L
.41271 .09056 L
.4147 .08866 L
.4163 .08685 L
.41787 .08484 L
.41919 .08302 L
.42034 .08113 L
.42123 .07917 L
.42185 .07735 L
.42228 .07564 L
.42254 .07393 L
.42268 .0723 L
.42273 .07079 L
.42274 .06934 L
.42272 .06801 L
.42269 .0668 L
.42267 .06576 L
.42263 .06493 L
.42259 .06429 L
.42255 .06383 L
.42252 .06354 L
.42251 .06337 L
.4225 .06329 L
.42251 .06327 L
.42252 .06333 L
.42255 .06344 L
.42259 .06359 L
.42262 .06373 L
.42264 .06382 L
.42263 .06381 L
.42258 .06371 L
.42248 .06351 L
.42234 .06321 L
.42216 .06284 L
.42194 .06243 L
.42171 .06203 L
.42146 .06166 L
.42122 .06137 L
.42097 .06115 L
.42073 .06102 L
.42051 .06096 L
.42031 .06099 L
Mistroke
.42016 .06113 L
.42005 .06134 L
.41999 .06163 L
.41997 .062 L
.41999 .06242 L
.42002 .06284 L
.42007 .0632 L
.4201 .06348 L
.42011 .06364 L
.42011 .06372 L
.42011 .06374 L
.42011 .06371 L
.42011 .06367 L
.42011 .06362 L
.42011 .06357 L
.42011 .06355 L
.42011 .06356 L
.42011 .06358 L
.42011 .06359 L
.42011 .06359 L
.42011 .06357 L
.42011 .06353 L
.42011 .06348 L
.42011 .06341 L
.42011 .06334 L
.42011 .06327 L
.42011 .0632 L
.42011 .06314 L
.42011 .06307 L
.42011 .06302 L
.42011 .06298 L
.42011 .06296 L
.42011 .06295 L
.42012 .06298 L
.42013 .06304 L
.42016 .06311 L
.4202 .0632 L
.42023 .06327 L
.42025 .06335 L
.42024 .06343 L
.42019 .06351 L
.42009 .06357 L
.41993 .06358 L
.41972 .06354 L
.41946 .06339 L
.41919 .06312 L
.41892 .06273 L
.41869 .06233 L
.41849 .06189 L
.41835 .06148 L
Mistroke
.41826 .06113 L
.41825 .06089 L
.41831 .06074 L
.41844 .06068 L
.41863 .06073 L
.41886 .06086 L
.41912 .06107 L
.4194 .06133 L
.41967 .06168 L
.41989 .0621 L
.42006 .06256 L
.42017 .063 L
.42024 .06338 L
.42026 .06363 L
.42024 .06377 L
.42021 .0638 L
.42016 .06377 L
.42013 .0637 L
.42012 .06363 L
.42011 .06357 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
Mistroke
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42012 .06353 L
.42014 .06351 L
.42019 .06347 L
.42027 .0634 L
.42034 .06333 L
.42037 .0633 L
.42035 .06334 L
.42025 .06348 L
.42006 .06372 L
.41978 .06403 L
.41942 .06438 L
.41899 .06473 L
.41852 .06503 L
.41803 .06527 L
.41755 .06543 L
.41707 .06552 L
.4166 .06555 L
.41615 .06552 L
.41576 .06542 L
.41545 .06527 L
.41523 .06503 L
.41512 .06473 L
.41511 .06442 L
.41518 .06411 L
.41528 .06384 L
.41539 .06361 L
.41547 .06345 L
.41548 .06334 L
.41542 .06322 L
.4153 .06303 L
.4151 .06273 L
.41484 .06232 L
.41451 .06178 L
.41412 .06116 L
.41369 .06051 L
.41323 .05984 L
.41276 .05915 L
.41229 .05849 L
.41185 .05787 L
.41145 .05733 L
.4111 .05689 L
Mistroke
.41082 .05656 L
.41061 .05634 L
.41047 .05622 L
.41039 .05617 L
.41037 .05616 L
.41038 .05616 L
.41041 .05617 L
.41045 .05619 L
.41049 .05624 L
.41052 .05633 L
.41054 .05645 L
.41054 .05662 L
.41052 .05683 L
.41048 .05707 L
.41042 .05733 L
.41035 .05761 L
.4103 .05786 L
.4103 .05807 L
.41036 .0582 L
.4105 .05822 L
.41074 .05812 L
.41106 .05788 L
.41145 .0575 L
.4119 .057 L
.41238 .05641 L
.41287 .05574 L
.41337 .05505 L
.41385 .05437 L
.41431 .05375 L
.41473 .05319 L
.41507 .05272 L
.41534 .05233 L
.41551 .05205 L
.41559 .05187 L
.41559 .05178 L
.41554 .05177 L
.41547 .0518 L
.4154 .05187 L
.41535 .05194 L
.41533 .05201 L
.41533 .05203 L
.41533 .05204 L
.41534 .05201 L
.41535 .05196 L
.41536 .05189 L
.41536 .05182 L
.41535 .05179 L
.41532 .05181 L
.41529 .05191 L
.41525 .05209 L
Mistroke
.41521 .05236 L
.41518 .0527 L
.41515 .0531 L
.41513 .05355 L
.41512 .05401 L
.41512 .05447 L
.41512 .05493 L
.41513 .05538 L
.41515 .0558 L
.41517 .05617 L
.4152 .05647 L
.41524 .05668 L
.41528 .05679 L
.41532 .05683 L
.41534 .05683 L
.41536 .05681 L
.41537 .05681 L
.41536 .05682 L
.41534 .05682 L
.41533 .0568 L
.41533 .0567 L
.41533 .05652 L
.41533 .05625 L
.41533 .0559 L
.41533 .0555 L
.41533 .05504 L
.41531 .05456 L
.41528 .0541 L
.41524 .05365 L
.41518 .05321 L
.41511 .05279 L
.41504 .05243 L
.41501 .05215 L
.41506 .05197 L
.41522 .05189 L
.41551 .05188 L
.41592 .05192 L
.41646 .052 L
.4171 .05209 L
.41778 .05217 L
.41853 .05221 L
.41929 .05222 L
.42002 .05223 L
.42071 .05226 L
.42133 .05232 L
.42187 .0524 L
.42227 .05247 L
.42257 .05249 L
.42275 .05247 L
.42284 .05238 L
Mistroke
.42286 .05222 L
.42286 .05198 L
.42288 .05164 L
.42295 .05124 L
.42307 .0508 L
.42326 .05035 L
.4235 .04989 L
.42376 .04944 L
.42402 .04897 L
.42427 .0485 L
.4245 .04808 L
.42469 .04773 L
.42484 .04749 L
.42493 .0474 L
.42496 .04746 L
.42492 .04766 L
.42483 .04798 L
.42469 .04838 L
.42457 .04883 L
.4245 .0493 L
.42453 .04977 L
.42469 .05024 L
.42499 .05071 L
.42546 .05118 L
.4261 .05163 L
.4269 .05205 L
.4278 .0524 L
.42885 .05265 L
.42995 .05281 L
.43112 .05286 L
.43231 .05286 L
.43341 .05284 L
.43443 .05283 L
.4353 .05284 L
.43597 .05288 L
.43644 .05295 L
.43669 .05303 L
.43676 .0531 L
.43672 .05319 L
.43661 .05326 L
.43644 .0533 L
.43622 .0533 L
.43593 .05327 L
.43554 .05323 L
.43502 .05313 L
.43435 .05297 L
.43355 .05271 L
.43263 .05237 L
.43159 .05194 L
.4305 .05146 L
Mistroke
.42953 .05093 L
.4285 .05043 L
.42746 .04994 L
.42642 .04946 L
.42531 .04908 L
.42429 .0487 L
.42333 .04835 L
.42246 .04806 L
.42172 .04784 L
.42105 .04769 L
.4204 .04759 L
.41969 .04753 L
.41887 .04749 L
.41791 .04746 L
.41673 .04742 L
.41534 .04736 L
.41374 .04727 L
.41196 .04715 L
.41029 .04703 L
.40838 .04693 L
.40631 .04689 L
.40447 .04693 L
.40254 .04706 L
.40044 .04731 L
.39825 .0477 L
.39605 .04821 L
.39377 .04883 L
.39165 .04954 L
.38952 .05034 L
.38752 .05126 L
.38544 .05228 L
.38336 .05333 L
.38132 .05435 L
.37922 .05536 L
.37725 .05635 L
.37546 .05728 L
.37371 .05819 L
.37202 .05907 L
.37049 .05991 L
.36914 .06071 L
.36792 .06149 L
.36688 .06224 L
.36602 .06292 L
.36531 .06352 L
.36472 .06402 L
.36419 .06443 L
.36366 .06479 L
.36306 .06513 L
.36233 .06549 L
.36144 .06587 L
Mistroke
.36033 .06632 L
.35892 .06689 L
.35716 .06762 L
.3553 .0685 L
.35319 .06957 L
.35063 .07085 L
.34785 .07215 L
.34451 .07382 L
.34161 .0754 L
.33791 .07713 L
.33458 .07892 L
.33054 .08081 L
.32739 .08254 L
.32316 .08444 L
.31997 .0861 L
.31602 .08783 L
.31246 .08959 L
.30855 .09147 L
.30493 .09326 L
.30099 .09529 L
.29735 .0973 L
.29283 .09962 L
.28948 .10173 L
.2848 .1042 L
.28071 .10669 L
.27598 .10935 L
.2725 .11162 L
.26762 .11416 L
.26316 .11675 L
.25975 .11901 L
.25521 .12149 L
.25157 .12373 L
.24708 .12601 L
.24349 .12829 L
.24018 .13028 L
.23631 .13228 L
.23352 .134 L
.23042 .1356 L
.22745 .13708 L
.22507 .13834 L
.22312 .13933 L
.22142 .14016 L
.21989 .14082 L
.2186 .14132 L
.21764 .14165 L
.21698 .14185 L
.21661 .14192 L
.21643 .14191 L
.2164 .14186 L
.21649 .1418 L
Mistroke
.21666 .14175 L
.21679 .14168 L
.21686 .14159 L
.2169 .14145 L
.21695 .14126 L
.21698 .14103 L
.217 .14079 L
.217 .14056 L
.217 .14038 L
.21701 .14026 L
.21701 .14018 L
.21701 .14015 L
.21701 .14015 L
.21701 .14017 L
.21702 .14018 L
.21705 .14024 L
.21709 .14034 L
.21713 .1405 L
.21716 .14071 L
.21716 .14095 L
.21714 .14117 L
.21712 .14137 L
.21708 .14156 L
.21698 .14176 L
.2168 .14206 L
.2165 .14252 L
.21608 .14317 L
.2155 .14406 L
.21478 .14509 L
.21393 .1463 L
.213 .14768 L
.21203 .14916 L
.21106 .15061 L
.21016 .1517 L
.20934 .15312 L
.20856 .1542 L
.20784 .1552 L
.20723 .1561 L
.20676 .15683 L
.20644 .15735 L
.20627 .15766 L
.20621 .1578 L
.20624 .15782 L
.20635 .15773 L
.20647 .1576 L
.20657 .15748 L
.2066 .15741 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15737 L
.20661 .15738 L
.20661 .15738 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .15729 L
.20661 .15726 L
.20661 .15723 L
.20661 .15721 L
.20661 .15719 L
.20661 .15719 L
.20661 .15718 L
.20661 .15718 L
.20661 .15719 L
.20661 .1572 L
.20661 .15722 L
.20661 .15725 L
.20661 .15728 L
.20661 .15731 L
Mistroke
.20661 .15734 L
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
.20661 .15739 L
.2066 .1574 L
.2066 .15741 L
.2066 .15741 L
.20661 .15739 L
.20661 .15737 L
.20661 .15733 L
.20661 .15729 L
.20661 .15725 L
.20661 .15721 L
.20661 .15718 L
.20661 .15716 L
.20661 .15715 L
.20661 .15715 L
.20661 .15717 L
.20661 .15719 L
.20661 .15724 L
.20661 .15727 L
.20661 .15729 L
.20661 .15728 L
.20661 .15724 L
.20661 .15717 L
.20661 .15708 L
.20661 .15698 L
.20661 .15688 L
.20661 .15678 L
.20661 .15668 L
.20661 .15661 L
.20661 .15657 L
.20661 .15655 L
.20661 .15655 L
.20661 .15658 L
.20661 .15664 L
.20661 .15675 L
.20661 .1569 L
.20661 .15702 L
.20661 .15716 L
.20661 .15728 L
.20661 .15735 L
.20661 .15742 L
.20661 .15745 L
.20661 .15743 L
.20661 .15738 L
.20661 .15733 L
.20661 .15727 L
.20661 .1572 L
Mistroke
.20661 .15712 L
.20661 .15705 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .15731 L
.20661 .15738 L
.20661 .15743 L
.20661 .15745 L
.20661 .15744 L
.20661 .1574 L
.20661 .15735 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15726 L
.20661 .15727 L
.20661 .15729 L
.20661 .1573 L
.20661 .15731 L
.20661 .15732 L
.20661 .15735 L
.20661 .15736 L
.20661 .15735 L
.20661 .1573 L
.20661 .15722 L
.20661 .15712 L
.20661 .15701 L
.20661 .1569 L
.20661 .15682 L
.20661 .15676 L
.20661 .15673 L
.20661 .15672 L
.20661 .15674 L
.20661 .15678 L
.20661 .15681 L
.20661 .15688 L
.20661 .15696 L
.20661 .15704 L
Mistroke
.20661 .15714 L
.20661 .15723 L
.20661 .1573 L
.20661 .15737 L
.20661 .15742 L
.20661 .15746 L
.20661 .15747 L
.20661 .15747 L
.20661 .15745 L
.20661 .15741 L
.20661 .15737 L
.20661 .15731 L
.20661 .15724 L
.20661 .15716 L
.20661 .15709 L
.20661 .15704 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .1573 L
.20661 .15736 L
.20661 .15741 L
.20661 .15743 L
.20661 .15743 L
.20661 .1574 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
Mistroke
.20661 .15738 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15727 L
.20661 .15732 L
.20661 .15737 L
.20661 .1574 L
.20661 .15741 L
.20661 .15738 L
.20661 .15734 L
.20661 .15731 L
.20661 .15727 L
.20661 .15723 L
.20661 .15715 L
.20661 .157 L
.20661 .15678 L
.20661 .15649 L
.20661 .15622 L
.20661 .15602 L
.20661 .15585 L
.20661 .15572 L
.20661 .15561 L
.20662 .15552 L
.20662 .15537 L
.20662 .15527 L
.20662 .15512 L
.20662 .15493 L
.20662 .15471 L
.20662 .15449 L
.20662 .15425 L
.20662 .15407 L
.20662 .15388 L
.20662 .15367 L
.20663 .15341 L
.20663 .1531 L
.20663 .1528 L
.20663 .15258 L
.20663 .15249 L
.20663 .15255 L
Mistroke
.20663 .15273 L
.20663 .15298 L
.20663 .15323 L
.20663 .15344 L
.20663 .15358 L
.20662 .15367 L
.20662 .15371 L
.20662 .15371 L
.20662 .15365 L
.20663 .15357 L
.20663 .15346 L
.20663 .15336 L
.20663 .15326 L
.20663 .15317 L
.20663 .15312 L
.20663 .15313 L
.20663 .1532 L
.20663 .1533 L
.20663 .15343 L
.20663 .15358 L
.20662 .15376 L
.20662 .1539 L
.20662 .15399 L
.20662 .15407 L
.20662 .15413 L
.20662 .15418 L
.20662 .15423 L
.20662 .15431 L
.20662 .15443 L
.20662 .15461 L
.20662 .15483 L
.20662 .15509 L
.20662 .15538 L
.20661 .15567 L
.20661 .15588 L
.20661 .15599 L
.20661 .15596 L
.20661 .15583 L
.20661 .15561 L
.20662 .1553 L
.20662 .15493 L
.20662 .15455 L
.20662 .15414 L
.20662 .15374 L
.20663 .15336 L
.20663 .15303 L
.20663 .15277 L
.20663 .15261 L
.20663 .15254 L
.20663 .15252 L
Mistroke
.20663 .15254 L
.20663 .15258 L
.20663 .15264 L
.20663 .15269 L
.20663 .15272 L
.20663 .15272 L
.20663 .1527 L
.20663 .15267 L
.20663 .15263 L
.20663 .15262 L
.20663 .15265 L
.20663 .1527 L
.20663 .15277 L
.20663 .15285 L
.20663 .15295 L
.20663 .15303 L
.20663 .1531 L
.20663 .15316 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .15361 L
.20662 .15372 L
.20662 .15381 L
.20662 .15388 L
.20662 .15393 L
.20662 .15403 L
.20662 .15417 L
.20662 .15437 L
.20662 .1546 L
.20662 .15484 L
.20662 .15507 L
.20662 .15526 L
.20662 .15534 L
.20662 .15532 L
.20662 .15522 L
.20662 .15501 L
.20662 .15476 L
.20662 .15449 L
.20662 .15425 L
.20662 .15401 L
.20662 .1538 L
.20663 .1536 L
.20663 .15343 L
.20663 .15333 L
.20663 .15329 L
.20663 .15331 L
.20663 .15337 L
.20663 .15344 L
.20663 .15352 L
Mistroke
.20663 .1536 L
.20663 .15362 L
.20663 .15361 L
.20663 .15352 L
.20663 .15338 L
.20663 .1532 L
.20663 .15301 L
.20663 .15284 L
.20663 .1527 L
.20663 .15262 L
.20663 .1526 L
.20663 .15264 L
.20663 .15271 L
.20663 .15277 L
.20663 .15278 L
.20663 .15275 L
.20663 .15273 L
.20663 .15277 L
.20663 .15286 L
.20663 .15298 L
.20663 .15314 L
.20663 .1533 L
.20663 .15346 L
.20663 .15359 L
.20662 .15367 L
.20662 .15372 L
.20662 .15372 L
.20662 .15368 L
.20663 .15361 L
.20663 .15359 L
.20663 .15355 L
.20663 .15349 L
.20663 .1534 L
.20663 .1533 L
.20663 .1532 L
.20663 .15311 L
.20663 .15305 L
.20663 .15301 L
.20663 .15302 L
.20663 .15309 L
.20663 .15318 L
.20663 .15326 L
.20663 .15328 L
.20663 .15327 L
.20663 .15323 L
.20663 .15317 L
.20663 .15308 L
.20663 .15298 L
.20663 .15288 L
.20663 .15282 L
Mistroke
.20663 .15279 L
.20663 .15279 L
.20663 .15281 L
.20663 .15282 L
.20663 .15283 L
.20663 .15287 L
.20663 .15294 L
.20663 .15303 L
.20663 .15313 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .1536 L
.20662 .15367 L
.20662 .1537 L
.20662 .1537 L
.20662 .15368 L
.20662 .15363 L
.20663 .15355 L
.20663 .15343 L
.20663 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .1529 L
.20663 .15277 L
.20663 .15267 L
.20663 .15264 L
.20663 .15267 L
.20663 .15275 L
.20663 .15289 L
.20663 .1531 L
.20663 .15341 L
.20662 .15381 L
.20662 .15422 L
.20662 .15464 L
.20662 .155 L
.20662 .15527 L
.20662 .15545 L
.20662 .15555 L
.20662 .15555 L
.20662 .15544 L
.20662 .15523 L
.20662 .15495 L
.20662 .15465 L
.20662 .15428 L
.20662 .15389 L
.20663 .1535 L
.20663 .15316 L
.20663 .1529 L
.20663 .15273 L
Mistroke
.20663 .15263 L
.20663 .15257 L
.20663 .15259 L
.20663 .15268 L
.20663 .15282 L
.20663 .15295 L
.20663 .15306 L
.20663 .15315 L
.20663 .15324 L
.20663 .15332 L
.20663 .15339 L
.20663 .15344 L
.20663 .15348 L
.20663 .1535 L
.20663 .15352 L
.20663 .15352 L
.20663 .15348 L
.20663 .15341 L
.20663 .15329 L
.20663 .15319 L
.20663 .15306 L
.20663 .15294 L
.20663 .15286 L
.20663 .15283 L
.20663 .15285 L
.20663 .1529 L
.20663 .15297 L
.20663 .15303 L
.20663 .15307 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15302 L
.20663 .15305 L
.20663 .15306 L
.20663 .15308 L
.20663 .1531 L
.20663 .15312 L
.20663 .15312 L
.20663 .15311 L
.20663 .1531 L
.20663 .15309 L
.20663 .15308 L
.20663 .15307 L
.20663 .15306 L
.20663 .15307 L
.20663 .15308 L
.20663 .15311 L
.20663 .15314 L
Mistroke
.20663 .15319 L
.20662 .15326 L
.20662 .15334 L
.20662 .15341 L
.20662 .15351 L
.20662 .15361 L
.20662 .15367 L
.20662 .1537 L
.20662 .15369 L
.20662 .15363 L
.20662 .15354 L
.20662 .15343 L
.20662 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .15291 L
.20663 .15282 L
.20663 .15275 L
.20663 .15271 L
.20663 .15271 L
.20663 .15271 L
.20663 .1527 L
.20663 .15269 L
.20663 .15268 L
.20663 .15269 L
.20663 .15271 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
Mistroke
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15269 L
.20663 .15265 L
.20663 .1526 L
.20663 .15255 L
.20663 .15252 L
.20663 .15254 L
.20663 .15261 L
.20663 .15274 L
.20663 .15295 L
.20663 .15321 L
.20663 .15355 L
.20662 .15395 L
.20662 .1544 L
.20662 .15485 L
.20662 .15526 L
.20661 .15562 L
.20661 .15587 L
.20661 .15606 L
.20661 .15617 L
.20661 .15621 L
.20661 .15617 L
.20661 .15604 L
.20661 .15582 L
.20662 .15556 L
.20662 .15527 L
.20662 .15497 L
.20662 .15467 L
.20662 .15442 L
.20662 .15416 L
.20662 .15396 L
.20662 .15384 L
.20662 .15375 L
.20662 .15367 L
.20663 .15362 L
.20663 .15356 L
.20663 .15351 L
.20663 .15343 L
.20663 .15337 L
.20663 .15337 L
.20663 .15345 L
.20663 .15356 L
.20662 .15368 L
.20662 .1538 L
.20662 .15386 L
Mistroke
.20662 .15385 L
.20662 .15378 L
.20662 .15367 L
.20663 .15354 L
.20663 .15341 L
.20663 .15334 L
.20663 .15337 L
.20663 .15348 L
.20662 .1537 L
.20662 .15398 L
.20662 .1543 L
.20662 .15462 L
.20662 .15488 L
.20662 .15509 L
.20662 .15526 L
.20662 .15537 L
.20662 .15541 L
.20662 .15538 L
.20662 .15522 L
.20662 .15496 L
.20662 .15461 L
.20662 .15418 L
.20662 .15369 L
.20663 .1532 L
.20663 .15276 L
.20663 .15243 L
.20663 .15228 L
.20663 .15231 L
.20663 .15249 L
.20663 .15278 L
.20663 .15311 L
.20663 .15345 L
.20662 .15375 L
.20662 .15397 L
.20662 .15412 L
.20662 .15422 L
.20662 .15428 L
.20662 .15432 L
.20662 .15432 L
.20662 .15427 L
.20662 .15414 L
.20662 .15395 L
.20662 .15372 L
.20663 .15347 L
.20663 .1532 L
.20663 .15295 L
.20663 .15279 L
.20663 .15272 L
.20663 .15277 L
.20663 .1529 L
Mistroke
.20663 .15305 L
.20663 .15317 L
.20663 .15327 L
.20663 .15334 L
.20663 .15341 L
.20663 .15345 L
.20663 .15346 L
.20663 .15344 L
.20663 .15341 L
.20663 .1534 L
.20663 .1534 L
.20663 .15345 L
.20663 .15356 L
.20662 .15374 L
.20662 .15396 L
.20662 .15421 L
.20662 .15443 L
.20662 .1546 L
.20662 .15471 L
.20662 .15479 L
.20662 .15487 L
.20662 .15492 L
.20662 .15489 L
.20662 .15481 L
.20662 .15466 L
.20662 .15442 L
.20662 .15411 L
.20662 .15379 L
.20663 .15351 L
.20663 .15329 L
.20663 .15321 L
.20663 .15326 L
.20663 .15341 L
.20663 .15359 L
.20662 .15378 L
.20662 .15394 L
.20662 .15408 L
.20662 .15416 L
.20662 .15419 L
.20662 .15418 L
.20662 .15418 L
.20662 .15416 L
.20662 .15411 L
.20662 .15407 L
.20662 .15399 L
.20662 .1539 L
.20662 .15381 L
.20662 .15376 L
.20662 .15373 L
.20662 .15373 L
Mistroke
.20662 .15372 L
.20662 .15373 L
.20662 .15369 L
.20662 .15361 L
.20662 .15346 L
.20662 .15334 L
.20663 .15321 L
.20663 .15309 L
.20663 .153 L
.20663 .15301 L
.20663 .15313 L
.20663 .15337 L
.20662 .15368 L
.20662 .15406 L
.20662 .15445 L
.20662 .15482 L
.2066 .15509 L
.20657 .15526 L
.20653 .15534 L
.20649 .15531 L
.20648 .15519 L
.20649 .15499 L
.20655 .15472 L
.20665 .15436 L
.2068 .15395 L
.207 .15354 L
.20723 .15316 L
.20749 .15287 L
.20776 .15268 L
.20802 .15258 L
.20828 .15255 L
.20853 .15258 L
.20875 .15266 L
.20893 .15278 L
.20905 .1529 L
.20914 .15299 L
.20921 .15303 L
.20927 .15299 L
.20935 .15287 L
.20947 .15269 L
.20961 .15247 L
.20976 .15224 L
.20994 .15201 L
.21013 .15176 L
.21033 .15149 L
.21052 .15119 L
.21071 .15088 L
.2109 .15054 L
.21109 .1502 L
.21127 .14984 L
Mistroke
.21142 .14952 L
.21152 .14925 L
.21157 .14907 L
.21159 .14891 L
.21161 .14878 L
.21162 .14867 L
.21167 .14856 L
.21173 .14842 L
.2118 .14828 L
.21185 .14816 L
.21188 .14809 L
.21189 .14808 L
.21187 .14812 L
.21184 .14818 L
.21182 .14823 L
.21182 .14824 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
Mistroke
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14824 L
.21182 .14823 L
.21183 .1482 L
.21184 .14818 L
.21184 .14817 L
.21183 .14819 L
.21182 .14824 L
.21179 .14831 L
.21176 .14839 L
.21173 .14847 L
.21171 .14855 L
.21168 .14861 L
.21167 .14866 L
.21166 .14869 L
.21167 .14869 L
.2117 .14868 L
.21174 .14868 L
.21178 .14866 L
.21181 .14863 L
.21182 .14858 L
.21178 .14852 L
.21168 .14845 L
.21154 .14839 L
.21136 .14833 L
.21118 .14829 L
.21102 .14827 L
.21088 .14828 L
.21077 .1483 L
.2107 .14833 L
.21068 .14834 L
.21069 .14833 L
.21073 .14832 L
.21079 .1483 L
.21091 .14828 L
.21108 .14826 L
.21128 .14824 L
.21149 .14822 L
.2117 .14821 L
.21187 .1482 L
.212 .14821 L
.21207 .14822 L
.21207 .14824 L
.21202 .14826 L
.21193 .14828 L
.2118 .14831 L
Mistroke
.21164 .14833 L
.21144 .14835 L
.2112 .14836 L
.21095 .14836 L
.21067 .14836 L
.21039 .14835 L
.21011 .14833 L
.20985 .14828 L
.20963 .14823 L
.20944 .14819 L
.20929 .14817 L
.2092 .14818 L
.20916 .14822 L
.20917 .1483 L
.20921 .14841 L
.20925 .14854 L
.20929 .14867 L
.20932 .14878 L
.20933 .14886 L
.20934 .1489 L
.20933 .14889 L
.20933 .14887 L
.20932 .14888 L
.2093 .1489 L
.20927 .14893 L
.20925 .14893 L
.20923 .14892 L
.20922 .1489 L
.20921 .14889 L
.20921 .14891 L
.20922 .14899 L
.20922 .1491 L
.20923 .1493 L
.20923 .14954 L
.20923 .1498 L
.20923 .15007 L
.20922 .15033 L
.20922 .15056 L
.20922 .1508 L
.20922 .15101 L
.20922 .15123 L
.20922 .15151 L
.20922 .15176 L
.20922 .15205 L
.20922 .1523 L
.20922 .1525 L
.20922 .15259 L
.20922 .15262 L
.20922 .15259 L
.20922 .15254 L
Mistroke
.20922 .15241 L
.20922 .15237 L
.20922 .15234 L
.20922 .15233 L
.20922 .15232 L
.20922 .15232 L
.20922 .15232 L
.20922 .15233 L
.20922 .15236 L
.20922 .15243 L
.20922 .15252 L
.20921 .15262 L
.20921 .15272 L
.20921 .1528 L
.20921 .15286 L
.20921 .15289 L
.20921 .15289 L
.20921 .15286 L
.20921 .15282 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.2092 .1528 L
.20917 .1528 L
.20913 .1528 L
.20909 .1528 L
.20907 .1528 L
.20908 .1528 L
Mistroke
.20915 .1528 L
.20928 .15281 L
.20946 .15281 L
.20969 .15283 L
.20993 .15286 L
.21016 .15287 L
.21038 .15288 L
.21056 .15288 L
.21071 .15288 L
.21081 .15285 L
.21086 .15281 L
.21087 .15276 L
.21081 .15269 L
.21071 .15262 L
.21056 .15253 L
.21037 .15244 L
.21015 .15235 L
.20994 .15227 L
.20976 .15219 L
.20963 .15211 L
.20954 .15205 L
.2095 .152 L
.2095 .15199 L
.20954 .15202 L
.20961 .15207 L
.2097 .15212 L
.20979 .15218 L
.20988 .15223 L
.20996 .15229 L
.21002 .15232 L
.21006 .15237 L
.21007 .15243 L
.21004 .15248 L
.21001 .15252 L
.20996 .15257 L
.2099 .15262 L
.20981 .15265 L
.20971 .15267 L
.20959 .15269 L
.20947 .15271 L
.20935 .15272 L
.20925 .15274 L
.20917 .15276 L
.20912 .15279 L
.20911 .15281 L
.20913 .15283 L
.20917 .15284 L
.2092 .15283 L
.20921 .15282 L
.20921 .15281 L
Mistroke
.20921 .1528 L
.20921 .15281 L
.20921 .15281 L
.20921 .15283 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
.20921 .15279 L
.20921 .15276 L
.20921 .15274 L
.20921 .15272 L
.20921 .1527 L
.20921 .15267 L
.20921 .15265 L
.20921 .15262 L
.20922 .15258 L
.20922 .15253 L
.20922 .15248 L
.20922 .15242 L
.20922 .15237 L
.20922 .15233 L
.20922 .15231 L
.20922 .15231 L
.20922 .15231 L
.20922 .15233 L
.20922 .15236 L
.20922 .1524 L
.20922 .15241 L
.20922 .15246 L
.20922 .15252 L
.20921 .1526 L
.20921 .15267 L
.20921 .15274 L
.20921 .15279 L
.20921 .15282 L
.20921 .15284 L
.20921 .15284 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
.20921 .15281 L
.20921 .15281 L
.2092 .15282 L
.20919 .15284 L
.20918 .15286 L
.20916 .15289 L
.20914 .15292 L
.20913 .15295 L
.20913 .15296 L
.20915 .15292 L
Mistroke
.2092 .15283 L
.2093 .15266 L
.20944 .15241 L
.20962 .15209 L
.20984 .15171 L
.21008 .15128 L
.21033 .15085 L
.21059 .15039 L
.21084 .14996 L
.21108 .14953 L
.21131 .14913 L
.21153 .14876 L
.21171 .14844 L
.21185 .14819 L
.21193 .14805 L
.21196 .148 L
.21194 .14803 L
.21187 .14813 L
.21179 .14827 L
.21169 .14843 L
.21161 .14857 L
.21154 .14866 L
.2115 .14871 L
.21148 .14873 L
.21147 .14875 L
.21147 .14876 L
.21147 .14878 L
.21149 .14879 L
.21152 .14877 L
.21157 .14873 L
.21163 .14866 L
.21169 .14859 L
.21176 .14851 L
.21183 .14843 L
.2119 .14837 L
.21196 .14834 L
.21199 .14834 L
.21199 .14836 L
.21196 .14837 L
.21189 .14836 L
.21179 .14832 L
.21163 .14828 L
.21142 .14824 L
.21117 .14821 L
.21091 .14817 L
.21066 .14814 L
.21042 .14813 L
.21019 .14814 L
.20998 .14814 L
.20979 .14813 L
Mistroke
.20963 .14813 L
.20951 .14817 L
.20941 .14826 L
.20933 .14837 L
.20929 .1485 L
.20928 .14863 L
.2093 .14877 L
.20934 .1489 L
.20939 .14901 L
.20943 .14911 L
.20949 .14917 L
.20959 .14919 L
.20976 .14914 L
.20998 .14906 L
.21023 .14894 L
.21048 .14882 L
.21071 .14875 L
.21092 .14874 L
.21104 .14883 L
.2111 .14898 L
.21109 .1492 L
.21103 .14946 L
.21094 .14973 L
.21083 .15001 L
.21071 .15027 L
.21059 .15048 L
.21051 .1506 L
.21046 .15065 L
.21046 .15064 L
.21051 .15053 L
.21062 .15036 L
.21079 .15008 L
.21101 .14971 L
.21122 .14935 L
.21144 .14897 L
.21163 .14865 L
.21176 .1484 L
.21184 .14826 L
.21188 .14817 L
.21191 .14809 L
.21194 .14802 L
.21198 .14796 L
.212 .14795 L
.21198 .14799 L
.21192 .1481 L
.2118 .14827 L
.21164 .1485 L
.21144 .14878 L
.21121 .14912 L
.21095 .1495 L
Mistroke
.21068 .14992 L
.21042 .15036 L
.21015 .1508 L
.20989 .15123 L
.20965 .15168 L
.20943 .15199 L
.20927 .15231 L
.20915 .15256 L
.20908 .15273 L
.20906 .15283 L
.20908 .15288 L
.20912 .15288 L
.20916 .15288 L
.20919 .15287 L
.20921 .15287 L
.20921 .15287 L
.20921 .15285 L
.20921 .15283 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20922 .1528 L
.20924 .15276 L
.20931 .15266 L
.20943 .1525 L
.20959 .15229 L
.20976 .15206 L
.20992 .15185 L
.21002 .15173 L
.21 .15176 L
.20981 .15201 L
.20938 .15256 L
.20864 .15351 L
.20756 .1549 L
.20605 .15679 L
.20427 .15908 L
.20215 .16199 L
.19947 .16541 L
.19663 .16937 L
.19315 .1739 L
.18919 .17905 L
.18555 .18453 L
.18134 .19029 L
.1764 .19694 L
.17219 .2029 L
.16753 .20955 L
.16222 .21655 L
.15685 .22399 L
.15265 .2305 L
.14734 .23765 L
.14164 .24496 L
.13711 .25201 L
.1316 .25897 L
.12676 .26561 L
.12232 .27264 L
.1176 .27931 L
.11307 .28561 L
Mistroke
.10937 .29218 L
.1054 .29847 L
.10246 .30458 L
.09955 .31089 L
.09698 .3167 L
.09469 .32311 L
.09276 .32863 L
.09107 .33454 L
.08958 .34106 L
.08823 .34645 L
.087 .35286 L
.08597 .35839 L
.08498 .36423 L
.08409 .36991 L
.08326 .37516 L
.0825 .37981 L
.08183 .38449 L
.08126 .38811 L
.08078 .39161 L
.0804 .39465 L
.08013 .39699 L
.07996 .39885 L
.07988 .40015 L
.07986 .40095 L
.07988 .40133 L
.07992 .4014 L
.07997 .40124 L
.08002 .40095 L
.08007 .40065 L
.08009 .4004 L
.0801 .40024 L
.0801 .40015 L
.08009 .4001 L
.08006 .40006 L
.08001 .40002 L
.07997 .39999 L
.07995 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08072 .40066 L
.08098 .40089 L
.08126 .40114 L
.08151 .40139 L
.08175 .40164 L
.08198 .40188 L
.08218 .4021 L
.08236 .40229 L
Mistroke
.08252 .40244 L
.08265 .40255 L
.08279 .40261 L
.08296 .40263 L
.08316 .40261 L
.08342 .40257 L
.08376 .40251 L
.08418 .40245 L
.08468 .40242 L
.08524 .40242 L
.0858 .40244 L
.08631 .40247 L
.08676 .40252 L
.08712 .40257 L
.08741 .40259 L
.08759 .40257 L
.08768 .40253 L
.08768 .40248 L
.08764 .40243 L
.08759 .4024 L
.08755 .40244 L
.08754 .40254 L
.08757 .40273 L
.08764 .40304 L
.0878 .40348 L
.08806 .40406 L
.08843 .40477 L
.08888 .40555 L
.08939 .40641 L
.08994 .40733 L
.0905 .40827 L
.09107 .40921 L
.09159 .41011 L
.09207 .41102 L
.09247 .41195 L
.09284 .41296 L
.09314 .41412 L
.09334 .41551 L
.09343 .41723 L
.09338 .41926 L
.09316 .42179 L
.0927 .42463 L
.09194 .42808 L
.09088 .4318 L
.08951 .43566 L
.08777 .44023 L
.0859 .44459 L
.0838 .44949 L
.08139 .45394 L
.0791 .45884 L
Mistroke
.07656 .46389 L
.07447 .46857 L
.07216 .47334 L
.07007 .47801 L
.06833 .48294 L
.06657 .48814 L
.06499 .49395 L
.06393 .49916 L
.06314 .50458 L
.06265 .50957 L
.06243 .51553 L
.06245 .52162 L
.0627 .52878 L
.06317 .53423 L
.06375 .54112 L
.06449 .5471 L
.06535 .55307 L
.06619 .55885 L
.06711 .56474 L
.06789 .57046 L
.06863 .57518 L
.06932 .58008 L
.06986 .58459 L
.07029 .5886 L
.07059 .59251 L
.07075 .59552 L
.0708 .59838 L
.07076 .60081 L
.07066 .60287 L
.07055 .60454 L
.07046 .60583 L
.07042 .60688 L
.07044 .60767 L
.07052 .60823 L
.07066 .60854 L
.07086 .60865 L
.0711 .60856 L
.07133 .60836 L
.07157 .60808 L
.07178 .60776 L
.07197 .60749 L
.07213 .60733 L
.07225 .60733 L
.07235 .60751 L
.07239 .60793 L
.07242 .60863 L
.07248 .60971 L
.0726 .61118 L
.07276 .61322 L
.07302 .61591 L
Mistroke
.07342 .61895 L
.07394 .62277 L
.07454 .62717 L
.07526 .63181 L
.0761 .6381 L
.07697 .64326 L
.07802 .6495 L
.07902 .65708 L
.08023 .66349 L
.08135 .67051 L
.0826 .67721 L
.08396 .68377 L
.08513 .69112 L
.08632 .6966 L
.08754 .70276 L
.08867 .70748 L
.08981 .71239 L
.09075 .71582 L
.09165 .71874 L
.09249 .72127 L
.09314 .72308 L
.09366 .72419 L
.09405 .72479 L
.09429 .72501 L
.0944 .72499 L
.09444 .7248 L
.09442 .72451 L
.09437 .72419 L
.09431 .72395 L
.09425 .72383 L
.0942 .72378 L
.09416 .72375 L
.09415 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09416 .72375 L
.09419 .72378 L
.09423 .72382 L
.09427 .72386 L
.09429 .72388 L
.09427 .72386 L
.09422 .72381 L
.09411 .72371 L
.09396 .72357 L
.09375 .72339 L
.09352 .72318 L
.09326 .72294 L
.09298 .72269 L
Mistroke
.09271 .72244 L
.09244 .72219 L
.09218 .72195 L
.09193 .72173 L
.09172 .72153 L
.09154 .72138 L
.09142 .72127 L
.09136 .72121 L
.09133 .72119 L
.09134 .72119 L
.09135 .7212 L
.09135 .7212 L
.09134 .7212 L
.09134 .72119 L
.09135 .72121 L
.09141 .72126 L
.09152 .72136 L
.09167 .7215 L
.09187 .72168 L
.09211 .72189 L
.09237 .72213 L
.09264 .72238 L
.09291 .72263 L
.09318 .72288 L
.09345 .72312 L
.09369 .72335 L
.09391 .72354 L
.09408 .72369 L
.0942 .7238 L
.09427 .72386 L
.09429 .72388 L
.09428 .72386 L
.09424 .72383 L
.09419 .72379 L
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .72291 L
.09417 .72264 L
.09417 .72238 L
.09418 .72212 L
.09419 .72187 L
.09419 .72164 L
.0942 .72143 L
.0942 .72127 L
.09421 .72117 L
.09422 .72113 L
.09425 .72117 L
.09429 .72126 L
.09433 .72137 L
.09435 .72145 L
.09433 .72146 L
.09428 .72137 L
.09417 .72118 L
.09402 .72089 L
.09382 .72052 L
.09359 .72008 L
.09334 .7196 L
.09307 .71909 L
.09281 .71858 L
.09254 .71808 L
.09229 .71759 L
.09205 .71713 L
.09183 .71674 L
.09167 .71642 L
.09155 .7162 L
Mistroke
.09149 .71607 L
.09148 .71605 L
.09153 .7161 L
.0916 .71618 L
.09168 .71626 L
.09174 .71631 L
.09174 .71633 L
.09169 .71634 L
.09159 .71635 L
.09143 .71635 L
.09122 .71634 L
.09098 .71629 L
.09072 .71619 L
.09045 .71604 L
.09018 .71581 L
.08991 .71553 L
.08966 .71518 L
.08943 .71479 L
.08923 .71437 L
.08906 .71395 L
.08894 .71351 L
.08882 .71305 L
.08876 .71266 L
.08875 .71226 L
.08878 .71192 L
.08884 .71163 L
.08893 .71141 L
.08905 .71128 L
.0892 .71123 L
.08941 .71123 L
.08965 .71125 L
.08991 .71128 L
.09018 .7113 L
.09046 .71131 L
.09074 .71132 L
.09101 .71133 L
.09126 .71132 L
.09149 .71131 L
.09167 .71131 L
.09179 .7113 L
.09186 .7113 L
.09189 .7113 L
.09187 .7113 L
.09183 .7113 L
.09179 .7113 L
.09175 .71128 L
.09174 .71122 L
.09174 .71115 L
.09174 .71109 L
.09174 .71106 L
Mistroke
.09174 .71109 L
.09174 .71119 L
.09173 .71135 L
.09173 .71158 L
.09172 .71189 L
.09171 .71227 L
.0917 .71269 L
.09169 .71316 L
.09168 .71364 L
.09167 .71412 L
.09165 .7146 L
.09164 .71509 L
.09163 .71548 L
.09162 .71584 L
.09162 .71612 L
.09161 .71631 L
.09161 .71641 L
.09161 .71645 L
.09161 .71644 L
.09161 .71641 L
.09161 .71639 L
.09161 .71638 L
.09161 .71637 L
.09161 .71636 L
.09161 .71634 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09159 .71632 L
.09156 .71632 L
.09152 .71632 L
.09148 .71632 L
.09146 .71633 L
.09148 .71632 L
.09153 .71632 L
.09164 .71632 L
.0918 .71631 L
.09201 .7163 L
.09225 .71629 L
.09251 .71628 L
.09279 .71627 L
.09307 .71626 L
.09334 .71625 L
.09361 .71624 L
.09386 .71623 L
.09408 .71622 L
.09426 .71622 L
.09439 .71621 L
.09445 .71621 L
Mistroke
.09448 .71621 L
.09446 .71621 L
.09442 .71621 L
.09438 .71621 L
.09434 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71622 L
.09433 .71624 L
.09433 .7163 L
.09433 .71638 L
.09433 .71645 L
.09432 .71649 L
.09432 .71647 L
.09431 .71636 L
.09431 .71616 L
.09431 .71587 L
.09431 .71549 L
.09432 .71504 L
.09432 .71455 L
.09433 .71404 L
.09435 .71352 L
.09436 .71301 L
.09437 .71251 L
.09439 .71205 L
.0944 .71164 L
.09442 .71131 L
.09443 .71108 L
.09445 .71095 L
.09445 .71091 L
.09446 .71094 L
.09446 .71101 L
Mistroke
.09446 .7111 L
.09446 .71116 L
.09445 .71119 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .71122 L
.09445 .71125 L
.09445 .71129 L
.09445 .71139 L
.09444 .71155 L
.09444 .71174 L
.09444 .71189 L
.09445 .71196 L
.09449 .71189 L
.09454 .71161 L
.09461 .71107 L
.09471 .71023 L
.09481 .70907 L
.09487 .70765 L
.09488 .70583 L
.09481 .70363 L
.09461 .7014 L
.09428 .69879 L
.0938 .69605 L
.09313 .6929 L
.0924 .6895 L
.09143 .68631 L
.09027 .68267 L
.08915 .6794 L
.08808 .6759 L
Mistroke
.08678 .67248 L
.08533 .66906 L
.08415 .66578 L
.08302 .66249 L
.08188 .65914 L
.0809 .65608 L
.08007 .65299 L
.07935 .6504 L
.07878 .64789 L
.07837 .64574 L
.07806 .64383 L
.07784 .64222 L
.07768 .64081 L
.07755 .6396 L
.07746 .63859 L
.07737 .6377 L
.07726 .63687 L
.07714 .63604 L
.07698 .63514 L
.07679 .63411 L
.07656 .63296 L
.07629 .63153 L
.07596 .62992 L
.07558 .62798 L
.07516 .62579 L
.07473 .62329 L
.0743 .6203 L
.07391 .61752 L
.07354 .61426 L
.07317 .61075 L
.0728 .60742 L
.0724 .60366 L
.07196 .59946 L
.07148 .59576 L
.07094 .59148 L
.07034 .58685 L
.06969 .5826 L
.06899 .57774 L
.06837 .57286 L
.06761 .56804 L
.0669 .5623 L
.06615 .55718 L
.06542 .55156 L
.06478 .54522 L
.06418 .53976 L
.06365 .53381 L
.06325 .52769 L
.06297 .52169 L
.06283 .515 L
.06282 .51005 L
Mistroke
.06293 .50465 L
.06315 .49897 L
.06346 .49488 L
.06383 .49085 L
.06424 .48718 L
.06467 .48415 L
.06509 .48161 L
.06548 .47983 L
.06583 .47845 L
.06614 .47746 L
.06639 .47686 L
.06658 .47658 L
.06672 .47653 L
.06679 .47664 L
.06681 .47682 L
.06679 .47705 L
.06675 .47734 L
.06669 .47763 L
.06664 .47788 L
.06661 .47805 L
.06659 .47808 L
.06657 .47794 L
.06654 .4776 L
.06652 .477 L
.06653 .4761 L
.06659 .47488 L
.0667 .47334 L
.06686 .47179 L
.06709 .46985 L
.06737 .46793 L
.06768 .46574 L
.06802 .46386 L
.06837 .46198 L
.0687 .46019 L
.06904 .45862 L
.06935 .45739 L
.06963 .45644 L
.06987 .45579 L
.07006 .45542 L
.07019 .45525 L
.07026 .45523 L
.07028 .45529 L
.07026 .45538 L
.07022 .45547 L
.07017 .45554 L
.07014 .45559 L
.07012 .45563 L
.07012 .45562 L
.07012 .45559 L
.07012 .45557 L
Mistroke
.07012 .45555 L
.07013 .45554 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .4556 L
.07015 .45562 L
.07019 .45566 L
.07024 .4557 L
.07026 .45572 L
.07026 .45571 L
.07022 .45565 L
.07013 .45556 L
.06998 .45542 L
.06979 .45524 L
.06955 .45503 L
.06927 .4548 L
.06896 .45455 L
.06862 .4543 L
.06835 .45405 L
.06806 .45381 L
.06782 .45359 L
.06764 .4534 L
.06756 .45325 L
.06759 .45314 L
.06773 .45307 L
Mistroke
.06795 .45305 L
.06822 .45306 L
.06854 .45309 L
.06887 .45313 L
.06919 .45316 L
.06949 .45317 L
.06975 .45317 L
.06997 .45316 L
.07015 .45316 L
.07027 .45316 L
.07034 .45316 L
.07036 .45316 L
.07035 .45316 L
.07031 .45316 L
.07026 .45316 L
.07022 .45316 L
.0702 .45316 L
.07019 .45314 L
.07016 .45312 L
.07011 .45308 L
.07008 .45304 L
.07005 .45302 L
.07007 .45303 L
.07012 .45309 L
.07023 .45318 L
.07039 .45332 L
.07059 .4535 L
.07082 .45371 L
.07108 .45395 L
.07136 .4542 L
.07161 .45445 L
.07182 .45471 L
.07199 .45498 L
.07214 .45524 L
.07227 .45547 L
.07238 .45564 L
.07248 .45575 L
.07264 .45579 L
.07289 .45577 L
.07329 .45571 L
.07387 .45561 L
.07465 .45547 L
.07566 .45526 L
.07673 .45495 L
.07802 .45453 L
.07947 .45398 L
.08094 .45332 L
.08248 .45253 L
.08401 .45162 L
.08525 .45056 L
Mistroke
.08643 .44939 L
.0875 .44803 L
.08837 .44641 L
.08909 .44468 L
.08966 .44266 L
.09011 .44044 L
.09049 .43786 L
.09082 .43519 L
.09112 .43212 L
.09138 .42863 L
.09158 .42492 L
.09173 .42065 L
.09186 .4159 L
.09196 .41074 L
.09205 .40427 L
.09211 .39871 L
.09214 .39212 L
.09214 .38592 L
.09211 .37943 L
.09207 .37271 L
.09203 .36532 L
.09201 .35947 L
.09201 .35327 L
.09208 .34684 L
.09222 .34156 L
.0924 .33704 L
.09261 .33254 L
.0928 .32899 L
.09294 .32592 L
.09303 .32365 L
.09306 .32181 L
.09307 .3205 L
.09306 .31957 L
.09306 .319 L
.09309 .3187 L
.09317 .31859 L
.09328 .31862 L
.09343 .31874 L
.0936 .3189 L
.09379 .31905 L
.09402 .31911 L
.09429 .319 L
.09463 .31865 L
.09504 .31801 L
.09556 .31711 L
.09618 .31597 L
.09691 .3146 L
.09776 .31302 L
.09861 .31146 L
.09957 .30972 L
Mistroke
.10059 .30807 L
.10154 .30646 L
.10257 .30496 L
.10352 .30364 L
.10445 .30253 L
.10531 .30153 L
.10604 .30068 L
.10665 .29998 L
.10711 .29944 L
.1074 .29907 L
.10754 .29881 L
.10753 .29865 L
.10741 .29857 L
.10721 .29857 L
.10694 .29862 L
.10664 .29867 L
.10633 .29868 L
.10605 .29877 L
.10583 .29884 L
.10563 .29899 L
.1054 .29918 L
.10512 .2994 L
.1048 .29965 L
.10442 .29993 L
.10399 .30024 L
.10349 .30058 L
.10296 .30095 L
.10242 .3014 L
.1019 .30193 L
.10138 .30253 L
.10091 .30318 L
.10047 .30383 L
.09996 .30446 L
.09951 .30506 L
.09913 .30565 L
.09884 .30623 L
.09861 .30679 L
.09841 .30733 L
.09826 .30783 L
.09816 .3083 L
.09808 .30875 L
.09798 .30917 L
.09783 .30959 L
.09769 .30998 L
.09759 .3104 L
.09755 .31086 L
.09758 .31134 L
.09768 .3118 L
.09786 .31219 L
.09812 .31248 L
Mistroke
.09845 .31265 L
.09882 .31267 L
.09921 .31254 L
.09962 .31227 L
.10001 .31187 L
.1004 .31135 L
.10081 .3107 L
.10124 .30989 L
.10173 .30895 L
.10228 .30785 L
.10289 .30657 L
.10354 .30511 L
.10425 .3036 L
.10505 .3019 L
.10596 .30006 L
.10698 .29798 L
.1082 .29589 L
.10954 .29349 L
.11109 .29097 L
.11277 .2884 L
.11464 .28535 L
.11655 .28247 L
.11857 .27936 L
.12082 .27579 L
.12289 .2727 L
.12516 .26921 L
.12742 .26581 L
.12974 .26228 L
.13199 .25877 L
.13442 .25534 L
.13662 .25179 L
.139 .24852 L
.14137 .24507 L
.14386 .24159 L
.14638 .23803 L
.14922 .23419 L
.15175 .23068 L
.1546 .22686 L
.15743 .22294 L
.16031 .21895 L
.16324 .21509 L
.16618 .21102 L
.16929 .2066 L
.17202 .20282 L
.17486 .19872 L
.17765 .19465 L
.1805 .1904 L
.18301 .18681 L
.18557 .18306 L
.1882 .17913 L
Mistroke
.19056 .17588 L
.193 .17244 L
.1954 .16922 L
.19773 .16604 L
.19997 .16311 L
.20209 .16031 L
.20421 .15763 L
.20615 .15494 L
.20819 .15248 L
.21027 .14995 L
.2125 .14752 L
.21476 .14517 L
.2171 .14274 L
.21968 .14076 L
.22224 .13879 L
.22495 .13706 L
.22719 .13547 L
.22965 .13395 L
.23179 .13274 L
.23386 .13164 L
.23581 .13065 L
.23733 .12978 L
.23861 .12903 L
.2396 .12841 L
.24028 .12792 L
.24068 .12755 L
.24088 .1272 L
.24093 .12688 L
.2409 .12658 L
.24081 .1263 L
.24064 .12606 L
.24041 .12589 L
.24013 .12579 L
.23981 .12576 L
.23944 .12576 L
.23903 .12576 L
.23856 .12574 L
.23805 .12571 L
.23748 .12567 L
.23692 .12568 L
.23627 .12575 L
.2356 .12592 L
.23495 .12617 L
.23437 .1265 L
.23389 .1269 L
.23354 .12735 L
.23333 .12782 L
.23324 .1283 L
.23325 .12879 L
.23332 .12929 L
Mistroke
.23343 .12976 L
.23355 .13015 L
.23366 .13046 L
.2338 .13067 L
.23396 .13078 L
.23412 .13079 L
.23426 .13071 L
.23438 .13056 L
.23449 .13036 L
.23457 .13015 L
.23471 .12992 L
.235 .12964 L
.23551 .12931 L
.23629 .12889 L
.23738 .12833 L
.23888 .12768 L
.24082 .12686 L
.24334 .12586 L
.24603 .12466 L
.24923 .12321 L
.25309 .12148 L
.25738 .11963 L
.26188 .11735 L
.26599 .11494 L
.27098 .11216 L
.27629 .1092 L
.28207 .10599 L
.28771 .10266 L
.29413 .09921 L
.29937 .09607 L
.30541 .09274 L
.31122 .08987 L
.31649 .08691 L
.32228 .08389 L
.32653 .08165 L
.33108 .07956 L
.33472 .07769 L
.33806 .07612 L
.34063 .07484 L
.34275 .0739 L
.34426 .07318 L
.34523 .07267 L
.34578 .07231 L
.34603 .07209 L
.34603 .07198 L
.34589 .07195 L
.34571 .07197 L
.34554 .072 L
.34539 .07207 L
.34528 .07215 L
Mistroke
.34521 .07223 L
.34517 .07228 L
.34514 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
Mistroke
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34515 .07229 L
.3452 .07225 L
.34528 .07219 L
.34534 .07215 L
.34536 .07214 L
.34533 .07219 L
.34523 .07229 L
.34506 .07245 L
.34479 .07264 L
.34444 .07287 L
.34402 .07312 L
.34356 .07333 L
.34311 .07348 L
.34268 .07358 L
.34229 .07365 L
.34192 .07372 L
.34159 .07382 L
.34131 .07392 L
.34109 .07406 L
.34093 .07419 L
.34083 .07432 L
.34078 .07449 L
.34078 .07465 L
.34079 .07484 L
.34081 .07503 L
.34079 .07532 L
.34071 .07567 L
.3406 .07603 L
.34049 .07635 L
.34037 .0766 L
.34027 .07677 L
.34018 .07688 L
.34012 .07691 L
.3401 .0769 L
.34013 .07685 L
.34016 .07678 L
.34019 .07674 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
Mistroke
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.3402 .07673 L
.34017 .07678 L
.34013 .07685 L
.34009 .07692 L
.34007 .07695 L
.34008 .07694 L
.34011 .07685 L
.34018 .07669 L
.34028 .07645 L
.3404 .07615 L
.34053 .07582 L
.34064 .07548 L
.34076 .07512 L
.34089 .07473 L
.34105 .07432 L
.34128 .07386 L
.34168 .07335 L
.34231 .07278 L
.3433 .07213 L
.34476 .07137 L
.3467 .07051 L
.34921 .06953 L
.35209 .06852 L
.35513 .06736 L
.35847 .06608 L
.3625 .06466 L
.36589 .06313 L
.36968 .06155 L
.37326 .05993 L
.37618 .05855 L
.3797 .05719 L
.38225 .05603 L
.38459 .05493 L
.38657 .05396 L
.38807 .05313 L
.38918 .05242 L
.39021 .05175 L
.39116 .05112 L
.39212 .05053 L
.39312 .04996 L
.39415 .04943 L
.39511 .04892 L
.39614 .0485 L
.39711 .04812 L
.39804 .04778 L
.39895 .04748 L
.39981 .04722 L
Mistroke
.40063 .04702 L
.40144 .04688 L
.40229 .04682 L
.40321 .04683 L
.40429 .0469 L
.40559 .04702 L
.4072 .04715 L
.40917 .04727 L
.41148 .04737 L
.41412 .04746 L
.417 .04757 L
.42017 .04767 L
.42342 .04779 L
.42641 .0479 L
.4298 .048 L
.43255 .04811 L
.43538 .04821 L
.43812 .04829 L
.44034 .04837 L
.44227 .04843 L
.44376 .04848 L
.44489 .04852 L
.4457 .04854 L
.44627 .04856 L
.4467 .04857 L
.44718 .04858 L
.4478 .0486 L
.44867 .04863 L
.44991 .04868 L
.45167 .04875 L
.45388 .04883 L
.4567 .04893 L
.45967 .04904 L
.46352 .04917 L
.46735 .0493 L
.47187 .04941 L
.47664 .04951 L
.48071 .04958 L
.4854 .04964 L
.49028 .04969 L
.49498 .04974 L
.49948 .0498 L
.50369 .04986 L
.50798 .04994 L
.51165 .05003 L
.51555 .05014 L
.51943 .05026 L
.52319 .05039 L
.5273 .05055 L
.53113 .05073 L
Mistroke
.53502 .05093 L
.53911 .05113 L
.54306 .05132 L
.54722 .05151 L
.55176 .05167 L
.55575 .05181 L
.56022 .05192 L
.56448 .05197 L
.56869 .05199 L
.57252 .05201 L
.5762 .05206 L
.57977 .05217 L
.58278 .05233 L
.58546 .05257 L
.58791 .05289 L
.58996 .05328 L
.59161 .05371 L
.59297 .05418 L
.59403 .05466 L
.59489 .05512 L
.5956 .05558 L
.59622 .05602 L
.59676 .05644 L
.59729 .05682 L
.59785 .05712 L
.59843 .05733 L
.59903 .05746 L
.59965 .05751 L
.60028 .0575 L
.60088 .05746 L
.60144 .0574 L
.60194 .05735 L
.60238 .05734 L
.60274 .05734 L
.60304 .05735 L
.60327 .05736 L
.60346 .05736 L
.6036 .05736 L
.60369 .05737 L
.60375 .05737 L
.60378 .05737 L
.60378 .05737 L
.60376 .05737 L
.60373 .05737 L
.60369 .05737 L
.60366 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
Mistroke
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05736 L
.60364 .05735 L
.60364 .05731 L
.60362 .05726 L
.60358 .05721 L
.60352 .05717 L
.60345 .05717 L
.6034 .05722 L
.6034 .05734 L
.60346 .05752 L
.6036 .05778 L
.60382 .05812 L
.6041 .05851 L
.60445 .05894 L
.60483 .05939 L
.60525 .05982 L
.60569 .06028 L
.60619 .06067 L
.6067 .06108 L
.60723 .06143 L
.60775 .06172 L
.60825 .06191 L
.6087 .06202 L
.60909 .06206 L
.60941 .06206 L
.60965 .06202 L
.60984 .06198 L
.61 .06195 L
.61014 .06194 L
.61028 .06193 L
.6104 .06192 L
.6105 .06192 L
.61055 .06193 L
.61057 .06193 L
.61055 .06193 L
.61052 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
Mistroke
.61045 .06193 L
.6105 .06195 L
.61057 .062 L
.61064 .06207 L
.61068 .06213 L
.61066 .06216 L
.61057 .06214 L
.6104 .06204 L
.61014 .06186 L
.60979 .0616 L
.60939 .06126 L
.60895 .06086 L
.60851 .06041 L
.60808 .05996 L
.60773 .0595 L
.60733 .05906 L
.60693 .05862 L
.60653 .0582 L
.60613 .05783 L
.60575 .05753 L
.60536 .05732 L
.60498 .0572 L
.6046 .05715 L
.60423 .05716 L
.60385 .05721 L
.60345 .05728 L
.603 .05732 L
.60255 .05733 L
.60213 .05733 L
.60176 .05732 L
.60147 .05731 L
.60127 .05731 L
.60115 .05731 L
.60112 .05731 L
.60115 .05731 L
.60121 .05733 L
.60129 .05736 L
.60136 .05739 L
.60141 .05739 L
.60146 .05736 L
.60149 .05731 L
.60152 .05724 L
.60156 .05718 L
.60159 .05715 L
.60162 .05716 L
.6016 .05716 L
.60154 .05712 L
.60138 .057 L
.60108 .05682 L
.60062 .05656 L
Mistroke
.59997 .05626 L
.59915 .05591 L
.59816 .05554 L
.597 .05515 L
.59567 .05476 L
.59435 .0544 L
.59289 .05401 L
.59129 .05362 L
.58953 .05324 L
.58798 .05287 L
.58644 .05256 L
.58494 .05238 L
.58353 .05231 L
.58229 .05231 L
.5813 .05234 L
.58047 .05238 L
.5798 .05238 L
.57927 .05232 L
.57886 .0522 L
.57856 .05203 L
.57837 .05182 L
.57828 .0516 L
.57827 .05137 L
.57833 .05114 L
.57843 .05091 L
.57854 .0507 L
.57862 .05049 L
.57865 .05032 L
.57866 .05017 L
.57866 .05006 L
.57866 .04997 L
.57866 .04991 L
.57866 .04985 L
.57866 .04981 L
.57866 .0498 L
.5787 .04984 L
.57877 .04996 L
.57889 .05017 L
.57899 .0505 L
.57907 .05094 L
.57909 .05148 L
.57904 .0521 L
.57889 .05271 L
.57862 .05341 L
.57821 .05415 L
.57762 .05482 L
.5768 .05546 L
.57575 .05602 L
.57452 .05646 L
.57314 .05671 L
Mistroke
.57154 .05676 L
.56973 .05659 L
.56796 .05624 L
.56612 .05578 L
.56431 .05526 L
.56275 .05473 L
.56134 .05419 L
.56024 .0537 L
.55938 .05321 L
.5588 .05273 L
.55853 .05226 L
.55859 .05182 L
.55893 .05144 L
.55947 .05113 L
.56018 .05087 L
.56097 .05066 L
.56179 .05049 L
.56262 .05032 L
.56332 .05015 L
.56392 .04997 L
.56445 .04982 L
.56491 .04974 L
.56531 .04974 L
.56568 .04983 L
.56608 .04999 L
.56659 .05021 L
.56731 .05047 L
.5683 .05076 L
.56954 .05105 L
.57109 .05131 L
.57298 .05154 L
.57488 .05175 L
.57702 .05196 L
.57935 .05216 L
.58149 .05239 L
.58369 .05264 L
.58596 .05295 L
.58783 .0533 L
.58965 .05372 L
.59117 .0541 L
.59244 .05455 L
.59339 .05505 L
.59405 .05552 L
.5944 .05601 L
.59457 .05645 L
.59464 .05682 L
.59466 .05706 L
.5947 .05713 L
.5948 .05704 L
.59496 .05681 L
Mistroke
.59519 .05646 L
.59548 .05602 L
.59581 .05554 L
.59617 .05505 L
.59658 .0546 L
.59702 .05417 L
.59746 .05375 L
.59788 .05334 L
.59826 .05296 L
.5986 .05262 L
.5989 .05233 L
.59916 .05209 L
.59939 .05189 L
.59954 .05171 L
.5996 .05155 L
.59956 .05139 L
.59942 .0512 L
.59915 .051 L
.59876 .05084 L
.59827 .05072 L
.5977 .05063 L
.59707 .05059 L
.5964 .05057 L
.59571 .05058 L
.59504 .0506 L
.59437 .05062 L
.59373 .05064 L
.59316 .05063 L
.59269 .05061 L
.59235 .05059 L
.59213 .05056 L
.59202 .05051 L
.59201 .05046 L
.59207 .0504 L
.5922 .05035 L
.59238 .05032 L
.59258 .05031 L
.59279 .05032 L
.59299 .0504 L
.59312 .05057 L
.59312 .0508 L
.59294 .05106 L
.59255 .05135 L
.59189 .05166 L
.59089 .05195 L
.58951 .05223 L
.5877 .05245 L
.58573 .05263 L
.58326 .0528 L
.58039 .0529 L
Mistroke
.57723 .05295 L
.57359 .05295 L
.57016 .05285 L
.56615 .05264 L
.56236 .05235 L
.55815 .05198 L
.5545 .05157 L
.55052 .05116 L
.54691 .05076 L
.54341 .05038 L
.53995 .05004 L
.53668 .04973 L
.53344 .04944 L
.53008 .04917 L
.52713 .0489 L
.52408 .04866 L
.5212 .04848 L
.51837 .04836 L
.5157 .04831 L
.51368 .04831 L
.51172 .04834 L
.50996 .04839 L
.50863 .04843 L
.50752 .04846 L
.50666 .04847 L
.50608 .04847 L
.50577 .04847 L
.50572 .04847 L
.50585 .04847 L
.50611 .04846 L
.50642 .04844 L
.50671 .04841 L
.50695 .04836 L
.50713 .0483 L
.50725 .04825 L
.50737 .0482 L
.50754 .04815 L
.50778 .04812 L
.50814 .04809 L
.50866 .0481 L
.5094 .04812 L
.51037 .04817 L
.51157 .04825 L
.51303 .04838 L
.51472 .04857 L
.5167 .04879 L
.51877 .04905 L
.5211 .04933 L
.5235 .04963 L
.52608 .04993 L
Mistroke
.52862 .05023 L
.53111 .05053 L
.53375 .0508 L
.53634 .05106 L
.53886 .05127 L
.54129 .05143 L
.5435 .05155 L
.54556 .05162 L
.54743 .05165 L
.54913 .05168 L
.5507 .0517 L
.55213 .05174 L
.5534 .05178 L
.55451 .0518 L
.55542 .05178 L
.55612 .05172 L
.5566 .05164 L
.55689 .05154 L
.55706 .05143 L
.55718 .05131 L
.5573 .05119 L
.55753 .05107 L
.55804 .05099 L
.55893 .05097 L
.56016 .05102 L
.56165 .05116 L
.56352 .0514 L
.5658 .05177 L
.56796 .05225 L
.57024 .0528 L
.57282 .05339 L
.57527 .05397 L
.57816 .05449 L
.58076 .05497 L
.58305 .05546 L
.58536 .05594 L
.58772 .0564 L
.59009 .05686 L
.59246 .05732 L
.59473 .05778 L
.59697 .05824 L
.59938 .05871 L
.60188 .05921 L
.60447 .05974 L
.60732 .06034 L
.6099 .06104 L
.61261 .06183 L
.61526 .06268 L
.61786 .06354 L
.6204 .06441 L
Mistroke
.62291 .06531 L
.62521 .06621 L
.62756 .06709 L
.62997 .06792 L
.63239 .06877 L
.63483 .06963 L
.63722 .07053 L
.63966 .07141 L
.64208 .07224 L
.64438 .07307 L
.64655 .07391 L
.64862 .07475 L
.65057 .07555 L
.65241 .07634 L
.65418 .07711 L
.65586 .07785 L
.65746 .0785 L
.65898 .07908 L
.66039 .07959 L
.6617 .08005 L
.66288 .08044 L
.66392 .08073 L
.66482 .08092 L
.66555 .08102 L
.66614 .08107 L
.6666 .08111 L
.66693 .08111 L
.66713 .08107 L
.66719 .081 L
.66712 .08093 L
.66694 .08082 L
.66666 .08063 L
.66632 .08034 L
.66593 .07998 L
.6655 .07956 L
.66505 .07912 L
.66462 .07865 L
.66422 .07821 L
.66386 .07777 L
.66351 .07733 L
.66315 .07692 L
.66276 .07656 L
.66234 .07627 L
.66189 .07607 L
.66142 .07596 L
.66091 .07591 L
.66041 .07593 L
.65994 .076 L
.65951 .07608 L
.65909 .07616 L
Mistroke
.65864 .07623 L
.6581 .07629 L
.65746 .07634 L
.65669 .07636 L
.65575 .07634 L
.65465 .07625 L
.65333 .07606 L
.65175 .07574 L
.64984 .07528 L
.64791 .07465 L
.64552 .07389 L
.6426 .07295 L
.63968 .07184 L
.63626 .07062 L
.63239 .06933 L
.62861 .06785 L
.62447 .06626 L
.62023 .06473 L
.61567 .06309 L
.61115 .06151 L
.60591 .05989 L
.60129 .05853 L
.59599 .05725 L
.59046 .05606 L
.58517 .05499 L
.57966 .05414 L
.57452 .05339 L
.56959 .05273 L
.56492 .05218 L
.56054 .05172 L
.55694 .05134 L
.55352 .05102 L
.55086 .05076 L
.54865 .05054 L
.54692 .05034 L
.54566 .05016 L
.54478 .04998 L
.54421 .04978 L
.54388 .04957 L
.54372 .04939 L
.54366 .04924 L
.54366 .04914 L
.54369 .04908 L
.54375 .04907 L
.54387 .04909 L
.54407 .04915 L
.54435 .04922 L
.54472 .04928 L
.54516 .04932 L
.54567 .04938 L
Mistroke
.54625 .04941 L
.54689 .04944 L
.54756 .04947 L
.54824 .04949 L
.5489 .04951 L
.54952 .04952 L
.55007 .04952 L
.55055 .04952 L
.55092 .0495 L
.5512 .04948 L
.55137 .04946 L
.55146 .04943 L
.55147 .04941 L
.55144 .0494 L
.55138 .04939 L
.55132 .0494 L
.55127 .0494 L
.55126 .0494 L
.55131 .04938 L
.55142 .04934 L
.55152 .04931 L
.55159 .0493 L
.55159 .04931 L
.55151 .04935 L
.55137 .04944 L
.55115 .04956 L
.55085 .04972 L
.55045 .04991 L
.54994 .05012 L
.54931 .05033 L
.54849 .05054 L
.54752 .05075 L
.54632 .05094 L
.54485 .05111 L
.54306 .05124 L
.54089 .05132 L
.53856 .05136 L
.53573 .05134 L
.53245 .05127 L
.52881 .05115 L
.52432 .051 L
.51981 .05084 L
.51555 .05067 L
.51007 .05051 L
.50511 .05035 L
.49911 .05019 L
.49432 .05003 L
.48859 .04987 L
.48397 .04972 L
.47877 .04958 L
Mistroke
.47483 .04944 L
.47085 .04933 L
.46728 .04923 L
.46452 .04914 L
.46224 .04907 L
.46048 .04901 L
.45918 .04897 L
.45828 .04895 L
.45771 .04893 L
.45742 .04892 L
.45733 .04892 L
.45736 .04892 L
.45747 .04892 L
.45762 .04893 L
.45778 .04893 L
.45792 .04894 L
.45801 .04894 L
.45807 .04894 L
.4581 .04894 L
.45811 .04894 L
.45811 .04894 L
.45811 .04894 L
.45814 .04896 L
.45819 .04899 L
.45827 .04903 L
.45834 .04906 L
.45837 .04908 L
.45835 .04907 L
.45825 .04901 L
.45806 .04892 L
.45778 .04878 L
.45742 .04859 L
.457 .04838 L
.45654 .04814 L
.45605 .04789 L
.45556 .04764 L
.45506 .04739 L
.45458 .04714 L
.45411 .04689 L
.45369 .04666 L
.45336 .04647 L
.45313 .04634 L
.45302 .04629 L
.45304 .04632 L
.45323 .04642 L
.4536 .04657 L
.4541 .04673 L
.45463 .04691 L
.45512 .0471 L
.45552 .04732 L
Mistroke
.45569 .0476 L
.45556 .04793 L
.45508 .04831 L
.45422 .04872 L
.45288 .04915 L
.45104 .0496 L
.44872 .05008 L
.44649 .05058 L
.44334 .05106 L
.4402 .05149 L
.43615 .05187 L
.43164 .05221 L
.4277 .0525 L
.42311 .05274 L
.41854 .05293 L
.41411 .05314 L
.40946 .05335 L
.40604 .05354 L
.40226 .05372 L
.39852 .05389 L
.39559 .05406 L
.39274 .05427 L
.38995 .05445 L
.38765 .05466 L
.38569 .05486 L
.38408 .05504 L
.38279 .0552 L
.38178 .05537 L
.38106 .05554 L
.38047 .05567 L
.38001 .05574 L
.37968 .05572 L
.37949 .05563 L
.37951 .05549 L
.37976 .05529 L
.38022 .05502 L
.38084 .05469 L
.38162 .05431 L
.38253 .0539 L
.38349 .05346 L
.38448 .05304 L
.38543 .05262 L
.38636 .05222 L
.38726 .05187 L
.3881 .05159 L
.38884 .05138 L
.38945 .05122 L
.38991 .0511 L
.39025 .051 L
.39048 .05086 L
Mistroke
.39063 .05068 L
.39072 .05042 L
.39077 .05008 L
.3908 .04966 L
.3908 .0492 L
.39079 .04874 L
.39076 .04832 L
.39074 .04791 L
.39072 .04752 L
.39073 .04718 L
.39078 .04691 L
.39086 .04669 L
.39095 .0465 L
.39104 .04633 L
.39111 .04618 L
.39115 .04605 L
.39119 .04593 L
.39122 .0458 L
.39128 .04569 L
.39139 .04561 L
.3916 .04556 L
.3919 .04554 L
.39227 .04557 L
.39271 .04564 L
.39317 .04574 L
.39365 .04588 L
.39413 .04607 L
.39458 .04627 L
.39499 .04648 L
.39536 .04665 L
.3957 .04675 L
.39599 .04677 L
.39622 .04675 L
.39639 .04671 L
.3965 .0467 L
.39659 .04675 L
.39668 .04691 L
.39677 .04716 L
.3969 .04751 L
.39705 .04792 L
.39724 .04838 L
.39744 .04885 L
.39765 .04932 L
.39784 .04978 L
.398 .05023 L
.39815 .05066 L
.39826 .05103 L
.39835 .05133 L
.39841 .05154 L
.39846 .05166 L
Mistroke
.39851 .0517 L
.39857 .05168 L
.39864 .05161 L
.39869 .05154 L
.39873 .05149 L
.39873 .05146 L
.39872 .05147 L
.39869 .05148 L
.39863 .05148 L
.39851 .05147 L
.39831 .05144 L
.39804 .05141 L
.39771 .05138 L
.39732 .05134 L
.39689 .0513 L
.39642 .05126 L
.39594 .05123 L
.39547 .05121 L
.39503 .05119 L
.39462 .05117 L
.39427 .05116 L
.39398 .05115 L
.39377 .05116 L
.39363 .05117 L
.39356 .05119 L
.39354 .05122 L
.39355 .05125 L
.39358 .05127 L
.39362 .05129 L
.39367 .0513 L
.3937 .0513 L
.39373 .0513 L
.39376 .05131 L
.3938 .05133 L
.39384 .05133 L
.39386 .05132 L
.39384 .05129 L
.39379 .05124 L
.3937 .05119 L
.39357 .05112 L
.39342 .05103 L
.39328 .0509 L
.39318 .05075 L
.39312 .05061 L
.39307 .05049 L
.393 .05041 L
.39283 .05026 L
.39256 .05035 L
.39212 .05059 L
.39147 .05099 L
Mistroke
.39053 .05159 L
.38918 .05241 L
.38742 .05347 L
.38552 .05463 L
.38291 .056 L
.37999 .05752 L
.37688 .05924 L
.37307 .06099 L
.36871 .06304 L
.36484 .06489 L
.35997 .06684 L
.35616 .06871 L
.35131 .07051 L
.34774 .07213 L
.34392 .0737 L
.34041 .0751 L
.33711 .07643 L
.33451 .07759 L
.33209 .07869 L
.32997 .07971 L
.32832 .08061 L
.32697 .08135 L
.32588 .08186 L
.32503 .08221 L
.32436 .0824 L
.32383 .08242 L
.32341 .08231 L
.32307 .08206 L
.32282 .08172 L
.32266 .08131 L
.32261 .08086 L
.32267 .0804 L
.32285 .0799 L
.32314 .0794 L
.32354 .07896 L
.32408 .07861 L
.32474 .07832 L
.32548 .07809 L
.32632 .0779 L
.32719 .07775 L
.32809 .07762 L
.32902 .0775 L
.32996 .07737 L
.33089 .07724 L
.3318 .07712 L
.33267 .07701 L
.33349 .0769 L
.33424 .0768 L
.33495 .07669 L
.33565 .07656 L
Mistroke
.33637 .07639 L
.33711 .07617 L
.33795 .07588 L
.33886 .07551 L
.33991 .07504 L
.34118 .07447 L
.34264 .07381 L
.34436 .07301 L
.34629 .07208 L
.34851 .071 L
.35102 .06977 L
.35377 .06843 L
.35677 .06692 L
.35996 .06534 L
.36323 .0636 L
.3667 .06181 L
.37003 .06022 L
.37322 .0587 L
.37631 .05713 L
.37898 .05563 L
.38162 .05421 L
.3836 .05317 L
.38533 .05231 L
.38677 .05163 L
.38785 .05112 L
.38862 .05077 L
.38912 .05059 L
.3894 .05052 L
.38953 .05051 L
.38958 .05054 L
.38959 .0506 L
.38959 .05068 L
.38964 .05077 L
.38978 .05082 L
.38999 .05084 L
.39021 .05086 L
.39045 .0509 L
.39069 .05095 L
.39091 .05101 L
.39111 .05108 L
.39126 .05114 L
.39137 .05119 L
.39143 .05123 L
.39145 .05125 L
.39143 .05125 L
.3914 .05122 L
.39136 .0512 L
.39133 .0512 L
.39134 .05122 L
.39139 .05127 L
Mistroke
.39147 .05134 L
.39154 .05141 L
.39158 .05145 L
.39155 .05142 L
.39145 .05131 L
.39125 .05108 L
.39097 .05072 L
.3906 .05029 L
.39017 .04983 L
.3897 .0494 L
.3892 .04903 L
.3887 .04874 L
.3882 .04853 L
.38774 .04841 L
.38736 .04837 L
.38708 .04842 L
.38688 .04856 L
.38673 .04875 L
.38659 .04901 L
.38642 .04934 L
.38618 .04974 L
.38582 .0502 L
.38533 .05065 L
.38471 .05105 L
.38407 .05139 L
.38348 .05171 L
.38294 .05202 L
.38244 .05232 L
.38192 .05261 L
.38144 .05292 L
.38099 .05327 L
.38057 .0537 L
.38012 .05421 L
.37965 .05482 L
.37894 .05553 L
.37803 .05635 L
.37686 .05729 L
.37557 .05827 L
.37385 .05931 L
.37169 .06038 L
.36937 .06141 L
.36661 .0626 L
.36407 .06377 L
.36143 .06496 L
.35886 .0661 L
.3567 .06713 L
.35468 .06806 L
.35285 .06888 L
.35129 .06962 L
.35 .07028 L
Mistroke
.34884 .07089 L
.34777 .07151 L
.34676 .07215 L
.34579 .07283 L
.34482 .0735 L
.34385 .07415 L
.34292 .0747 L
.34196 .07517 L
.34094 .07556 L
.33985 .07589 L
.33871 .0762 L
.33756 .07649 L
.33645 .0768 L
.33542 .07714 L
.33449 .07751 L
.33363 .07793 L
.33275 .0784 L
.3319 .07895 L
.33089 .07961 L
.32968 .08041 L
.32825 .08132 L
.32655 .08235 L
.32452 .0835 L
.32235 .08478 L
.31976 .08616 L
.31671 .0877 L
.31367 .08939 L
.31013 .09126 L
.30624 .09323 L
.30226 .09539 L
.29798 .09762 L
.2932 .10001 L
.28911 .10238 L
.28435 .10489 L
.28016 .10728 L
.27547 .10976 L
.27155 .11202 L
.26725 .11427 L
.26357 .11638 L
.25976 .11829 L
.25667 .12 L
.25373 .12152 L
.25128 .12279 L
.24915 .12388 L
.24758 .12474 L
.24642 .12537 L
.24563 .12581 L
.2452 .12606 L
.24504 .12617 L
.24505 .12618 L
Mistroke
.24512 .12617 L
.24512 .12623 L
.24495 .12639 L
.24454 .12673 L
.24384 .12729 L
.24278 .12811 L
.24133 .1292 L
.2397 .13045 L
.2377 .13195 L
.23561 .13358 L
.23326 .13533 L
.23104 .13708 L
.22877 .13885 L
.22664 .14048 L
.22474 .14196 L
.22303 .14327 L
.2217 .14432 L
.22064 .14516 L
.21988 .14578 L
.21939 .14621 L
.21911 .14648 L
.21899 .14662 L
.21898 .14666 L
.21905 .14661 L
.21916 .14651 L
.21931 .14639 L
.21943 .14628 L
.21951 .14622 L
.21954 .14618 L
.21956 .14618 L
.21959 .14616 L
.21968 .14614 L
.2198 .14611 L
.21991 .14607 L
.21997 .14606 L
.21993 .14607 L
.21976 .14611 L
.21946 .1462 L
.21901 .14632 L
.21842 .14648 L
.21773 .14666 L
.21697 .14686 L
.21618 .14708 L
.21539 .14729 L
.21462 .14748 L
.21386 .14763 L
.21314 .14775 L
.21251 .14784 L
.21203 .14789 L
.21174 .14792 L
Mistroke
.21166 .14792 L
.21172 .14795 L
.21186 .14807 L
.21201 .14831 L
.21212 .1487 L
.21211 .1493 L
.21197 .15011 L
.2117 .15108 L
.21128 .15223 L
.21067 .1536 L
.20982 .15524 L
.20866 .15713 L
.20709 .15946 L
.20528 .16179 L
.20307 .16448 L
.20047 .16763 L
.19734 .17119 L
.1937 .1755 L
.19058 .17945 L
.18644 .18399 L
.18248 .18887 L
.17816 .19409 L
.17349 .19975 L
.16875 .20581 L
.1643 .21178 L
.15929 .21807 L
.15437 .22538 L
.14938 .23225 L
.14455 .23907 L
.13959 .24641 L
.13436 .2535 L
.12941 .26183 L
.12444 .26912 L
.11964 .2767 L
.1147 .28536 L
.11043 .29366 L
.10633 .30046 L
.1025 .30864 L
.099 .31634 L
.09589 .3248 L
.09309 .33198 L
.0907 .33932 L
.08862 .34696 L
.08684 .35337 L
.08527 .36012 L
.08394 .36655 L
.08277 .37272 L
.08174 .37832 L
.0809 .38311 L
.0802 .38789 L
Mistroke
.07965 .39127 L
.07925 .39454 L
.07899 .39697 L
.07884 .39887 L
.07879 .40022 L
.07882 .40103 L
.07894 .40139 L
.07914 .40146 L
.07939 .40132 L
.07964 .40105 L
.07987 .40072 L
.08006 .4004 L
.08018 .40021 L
.08024 .40014 L
.08024 .40011 L
.08021 .40011 L
.08016 .40011 L
.08013 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08012 .40009 L
.08016 .40006 L
.08021 .40002 L
.08025 .39998 L
.08027 .39997 L
.08025 .39998 L
.08018 .40003 L
.08006 .40013 L
.07988 .40027 L
.07965 .40046 L
.07939 .40067 L
.07911 .40091 L
.07882 .40115 L
.07854 .40138 L
.0783 .40159 L
.07807 .40178 L
.07785 .40195 L
.07765 .40211 L
Mistroke
.07747 .40228 L
.07733 .40242 L
.07723 .40256 L
.07714 .40271 L
.07704 .4029 L
.07688 .40317 L
.07663 .40356 L
.07627 .40406 L
.0758 .40466 L
.07524 .4053 L
.07463 .40601 L
.07395 .40668 L
.07321 .40745 L
.0724 .40826 L
.07153 .40914 L
.07065 .41007 L
.06972 .4111 L
.06878 .41226 L
.06785 .41357 L
.06694 .41507 L
.06609 .41676 L
.06534 .41844 L
.06467 .42035 L
.06409 .42237 L
.06359 .42439 L
.06318 .42647 L
.06285 .42847 L
.06259 .43029 L
.06242 .43197 L
.06235 .43342 L
.06235 .43455 L
.0624 .43539 L
.06247 .43596 L
.06253 .4363 L
.06255 .43649 L
.06255 .43659 L
.06253 .43664 L
.0625 .43672 L
.06245 .43687 L
.0624 .43714 L
.06237 .43753 L
.06236 .43804 L
.06238 .43866 L
.06244 .43933 L
.06253 .44004 L
.06267 .44076 L
.06287 .44145 L
.06313 .44209 L
.06345 .44264 L
.06382 .44309 L
Mistroke
.06422 .44343 L
.06465 .44365 L
.0651 .44377 L
.06556 .4438 L
.06604 .44378 L
.06651 .44373 L
.06696 .44368 L
.06739 .44363 L
.06778 .44358 L
.06817 .44354 L
.06855 .44352 L
.06894 .44351 L
.06934 .44351 L
.06975 .4435 L
.07019 .4435 L
.07066 .44349 L
.07117 .44348 L
.07167 .44348 L
.07212 .44347 L
.07248 .44348 L
.07273 .44351 L
.07284 .44355 L
.07279 .44359 L
.07257 .44361 L
.07221 .4436 L
.0717 .44355 L
.07109 .44346 L
.07033 .44333 L
.06965 .44315 L
.06884 .44291 L
.06804 .4426 L
.0673 .44225 L
.06667 .44189 L
.06615 .44159 L
.06571 .44137 L
.06533 .44125 L
.06498 .44127 L
.06463 .44144 L
.06428 .44178 L
.06392 .44228 L
.06354 .44296 L
.06321 .4438 L
.06299 .44476 L
.06292 .44579 L
.06302 .4469 L
.06332 .44806 L
.06383 .44925 L
.06456 .45046 L
.06544 .45161 L
.06653 .45275 L
Mistroke
.06771 .45393 L
.06892 .45514 L
.0702 .45643 L
.07147 .45783 L
.07268 .4593 L
.07372 .46088 L
.07463 .46253 L
.0754 .46408 L
.07602 .46553 L
.07653 .46682 L
.07697 .46798 L
.07732 .46896 L
.07762 .4699 L
.07782 .47078 L
.07791 .47158 L
.07785 .47236 L
.07762 .47318 L
.07721 .4741 L
.07658 .47514 L
.07576 .47637 L
.07474 .47782 L
.07369 .47946 L
.07239 .4813 L
.07128 .48303 L
.07015 .48502 L
.06898 .48707 L
.0679 .48882 L
.06704 .49016 L
.06636 .49124 L
.06587 .49208 L
.06557 .4927 L
.06543 .49305 L
.06542 .49323 L
.06552 .49332 L
.06566 .49337 L
.06579 .49348 L
.06586 .49368 L
.06587 .49403 L
.06579 .49463 L
.06562 .4955 L
.06538 .49665 L
.06509 .49803 L
.06475 .49965 L
.06438 .50139 L
.06401 .50317 L
.06365 .505 L
.06333 .50675 L
.06305 .50828 L
.06282 .5097 L
.06265 .51095 L
Mistroke
.06254 .512 L
.06249 .5128 L
.06248 .51342 L
.06251 .51391 L
.06254 .51423 L
.06258 .5144 L
.06259 .51447 L
.0626 .51448 L
.0626 .51442 L
.06261 .51434 L
.06263 .51422 L
.06269 .5141 L
.06277 .51399 L
.06285 .51395 L
.06288 .51397 L
.06286 .51402 L
.06275 .51411 L
.06255 .51422 L
.06223 .51435 L
.06181 .51448 L
.06131 .5146 L
.06076 .5147 L
.06021 .51477 L
.05967 .51482 L
.05916 .51484 L
.05864 .51485 L
.05813 .51484 L
.05766 .5148 L
.05729 .51472 L
.05704 .51462 L
.05691 .5145 L
.05686 .51438 L
.05689 .51429 L
.05696 .51425 L
.05705 .51426 L
.05711 .51432 L
.05713 .51438 L
.05713 .51439 L
.05713 .51433 L
.05712 .51416 L
.0571 .51388 L
.05707 .51353 L
.05705 .51312 L
.05704 .5127 L
.05707 .51228 L
.05714 .51185 L
.05726 .51139 L
.05743 .51088 L
.05765 .51033 L
.05789 .50977 L
Mistroke
.05813 .50924 L
.05838 .50876 L
.05862 .50834 L
.05887 .50795 L
.05915 .50751 L
.05948 .50696 L
.05986 .50629 L
.06029 .50543 L
.06077 .50437 L
.06129 .50312 L
.06185 .50174 L
.06241 .50033 L
.06291 .4991 L
.06345 .49795 L
.06403 .49667 L
.06455 .49562 L
.06506 .4946 L
.06552 .49361 L
.06589 .4927 L
.06616 .49195 L
.06633 .49138 L
.06641 .49096 L
.06641 .49069 L
.06637 .49052 L
.06631 .49041 L
.06626 .49029 L
.06622 .49015 L
.0662 .48997 L
.06621 .48979 L
.06621 .48964 L
.06622 .48954 L
.06622 .48948 L
.06622 .48947 L
.06622 .48948 L
.06622 .48952 L
.06622 .48956 L
.06621 .48959 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
Mistroke
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48962 L
.06622 .48964 L
.06624 .4897 L
.06626 .48978 L
.06626 .48986 L
.06624 .48992 L
.06621 .48994 L
.06616 .48991 L
.0661 .48978 L
.06605 .48954 L
.06601 .48919 L
.06598 .4887 L
.06597 .48808 L
.06598 .48732 L
.066 .48649 L
.06603 .4856 L
.06606 .48467 L
.06611 .4837 L
.06618 .48268 L
.06626 .48166 L
.06635 .48058 L
.06645 .47947 L
.06654 .47833 L
Mistroke
.06661 .47719 L
.06664 .47604 L
.06666 .47489 L
.06669 .47376 L
.06674 .47282 L
.06683 .47174 L
.06698 .4708 L
.06716 .46985 L
.06733 .46889 L
.06748 .46796 L
.06761 .4671 L
.06774 .46631 L
.06788 .46556 L
.06803 .46481 L
.0682 .46405 L
.0684 .46325 L
.0686 .46239 L
.0688 .46147 L
.06899 .46049 L
.06915 .45951 L
.06927 .4586 L
.0694 .4578 L
.06952 .4571 L
.06967 .45652 L
.06982 .45606 L
.06999 .45572 L
.07013 .45549 L
.07022 .45536 L
.07026 .45532 L
.07025 .45534 L
.07021 .45541 L
.07016 .4555 L
.07013 .45558 L
.07011 .45563 L
.07011 .45562 L
.07011 .45558 L
.07011 .45556 L
.07011 .45559 L
.07011 .45566 L
.0701 .45575 L
.0701 .45588 L
.07009 .45603 L
.07009 .4562 L
.07008 .45636 L
.07008 .45651 L
.07007 .45664 L
.07007 .45673 L
.07006 .4568 L
.07006 .45683 L
.07006 .45684 L
Mistroke
.07006 .45678 L
.07007 .45668 L
.07008 .45649 L
.07009 .45633 L
.0701 .45612 L
.0701 .45592 L
.07011 .45575 L
.07012 .45562 L
.07012 .45555 L
.07012 .45553 L
.07012 .45552 L
.07012 .45553 L
.07013 .45553 L
.07013 .45553 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07014 .4556 L
.07019 .45562 L
.07027 .45566 L
.07035 .4557 L
.07038 .45571 L
.07036 .4557 L
.07026 .45565 L
.07006 .45556 L
.06976 .45542 L
.06936 .45525 L
.06887 .45504 L
.06834 .45481 L
.06781 .4546 L
.06732 .45441 L
.06686 .45424 L
.06638 .45409 L
.06588 .45393 L
.06541 .45377 L
.06498 .4536 L
.06463 .4534 L
.06433 .45316 L
.06407 .45286 L
.06386 .45247 L
.06368 .45196 L
Mistroke
.06351 .45132 L
.06332 .45054 L
.06309 .4496 L
.06285 .44846 L
.06264 .44711 L
.06248 .44558 L
.06236 .44393 L
.0623 .44205 L
.0623 .44009 L
.06235 .43801 L
.06244 .43593 L
.06255 .43373 L
.06266 .43172 L
.06277 .42955 L
.06285 .42768 L
.06292 .42568 L
.06298 .42384 L
.06303 .42203 L
.06308 .4206 L
.06312 .41927 L
.06316 .41809 L
.06319 .41711 L
.0632 .41637 L
.06318 .41576 L
.06315 .41529 L
.06312 .41493 L
.0631 .41468 L
.06309 .41451 L
.06312 .41443 L
.0632 .41441 L
.06334 .41444 L
.06354 .4145 L
.06381 .41455 L
.06415 .41458 L
.06455 .41453 L
.06498 .41442 L
.06546 .41425 L
.06599 .41405 L
.06655 .41382 L
.06718 .41358 L
.06776 .41333 L
.06837 .4131 L
.06899 .41287 L
.06962 .41265 L
.07024 .41246 L
.07076 .41231 L
.07126 .41219 L
.07176 .41211 L
.07226 .41207 L
.07276 .41205 L
Mistroke
.07322 .41206 L
.07368 .41208 L
.07414 .4121 L
.07459 .41213 L
.07501 .41214 L
.07538 .41214 L
.07571 .41213 L
.07599 .41213 L
.07624 .41213 L
.07647 .41213 L
.07667 .41213 L
.07685 .41212 L
.07699 .41212 L
.07709 .41212 L
.07714 .41212 L
.07715 .41212 L
.07714 .41212 L
.07709 .41212 L
.07705 .41212 L
.07702 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
Mistroke
.07701 .41213 L
.07701 .41215 L
.07701 .4122 L
.07702 .41227 L
.07702 .41234 L
.07701 .41237 L
.077 .41235 L
.07699 .41225 L
.07698 .41206 L
.07697 .41178 L
.07696 .41142 L
.07696 .41099 L
.07697 .41052 L
.07698 .41003 L
.077 .40955 L
.07701 .40908 L
.07702 .40861 L
.07704 .40816 L
.07706 .40776 L
.07708 .40745 L
.07711 .40725 L
.07713 .40719 L
.07715 .40722 L
.07716 .40732 L
.07716 .40743 L
.07717 .40751 L
.07716 .40752 L
.07715 .40742 L
.07712 .40722 L
.07709 .40692 L
.07706 .40649 L
.07706 .40594 L
.07709 .40526 L
.07717 .40449 L
.0773 .40364 L
.07749 .40269 L
.07773 .40165 L
.07801 .40063 L
.0783 .39961 L
.07861 .39865 L
.07891 .39779 L
.0792 .39708 L
.07948 .39647 L
.07975 .39596 L
.07999 .39556 L
.08018 .39527 L
.08031 .39509 L
.08038 .39501 L
.08041 .395 L
.08039 .39505 L
Mistroke
.08035 .39512 L
.0803 .39521 L
.08027 .39528 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08027 .39529 L
.0803 .39524 L
.08034 .39517 L
.08038 .3951 L
.0804 .39507 L
.08039 .39509 L
.08033 .39519 L
.08022 .39537 L
.08005 .39565 L
.07983 .39602 L
.07957 .39645 L
.07929 .39692 L
.079 .39742 L
.07871 .3979 L
.07843 .39836 L
.07815 .39883 L
.07788 .39928 L
.07764 .39968 L
.07745 .4 L
.07732 .40022 L
.07725 .40034 L
.07722 .40038 L
.07724 .40035 L
.07728 .40027 L
.07733 .40017 L
.07736 .40008 L
.07738 .40002 L
.07738 .39999 L
Mistroke
.07738 .4 L
.07738 .40005 L
.07738 .40015 L
.07737 .40029 L
.07737 .40047 L
.07736 .40068 L
.07735 .40092 L
.07735 .40117 L
.07734 .40142 L
.07733 .40166 L
.07732 .4019 L
.07732 .40213 L
.07731 .40232 L
.07731 .40247 L
.0773 .40258 L
.0773 .40264 L
.0773 .40266 L
.0773 .40265 L
.0773 .40261 L
.0773 .40257 L
.0773 .40254 L
.07731 .40253 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
Mistroke
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07726 .40252 L
.07721 .40252 L
.07717 .40252 L
.07716 .40252 L
.07717 .40252 L
.07723 .40252 L
.07734 .40252 L
.0775 .40252 L
.0777 .40252 L
.07795 .40252 L
.07821 .40252 L
.07849 .40251 L
.07877 .40251 L
.07905 .40251 L
.07932 .40251 L
.07957 .40251 L
.0798 .4025 L
.07997 .4025 L
.08009 .4025 L
.08015 .4025 L
.08014 .4025 L
.08008 .4025 L
.08 .4025 L
.07994 .4025 L
.07991 .40251 L
.07995 .40252 L
.08005 .40255 L
.08021 .40258 L
.08041 .40262 L
Mistroke
.08065 .40263 L
.08091 .40262 L
.08119 .40257 L
.08147 .40247 L
.08174 .40233 L
.082 .40215 L
.08225 .40194 L
.08248 .4017 L
.08268 .40147 L
.08285 .40126 L
.08297 .40109 L
.08304 .40092 L
.08306 .40074 L
.08302 .40053 L
.08293 .40029 L
.08281 .40004 L
.08266 .39976 L
.08246 .39945 L
.08224 .39912 L
.08199 .39875 L
.08172 .39832 L
.08146 .3978 L
.08119 .39722 L
.08093 .39655 L
.0807 .39582 L
.0805 .39506 L
.08034 .3943 L
.08024 .39357 L
.08019 .39292 L
.08018 .39238 L
.08021 .39191 L
.08026 .3915 L
.08032 .39114 L
.08036 .39082 L
.08039 .39056 L
.0804 .39038 L
.0804 .39029 L
.0804 .39027 L
.0804 .3903 L
.0804 .39037 L
.0804 .39045 L
.0804 .3905 L
.08039 .39052 L
.08039 .39053 L
.08039 .39053 L
.08039 .39054 L
.08039 .39057 L
.08039 .3906 L
.08039 .39064 L
.08037 .39065 L
Mistroke
.08034 .39062 L
.0803 .39054 L
.08027 .39044 L
.08025 .39031 L
.08027 .39019 L
.08033 .39007 L
.08044 .38994 L
.08061 .38981 L
.08082 .38967 L
.08106 .38951 L
.08134 .38935 L
.08162 .38917 L
.08191 .389 L
.08219 .38884 L
.08246 .38871 L
.08272 .38862 L
.08294 .38854 L
.08312 .38847 L
.08324 .3884 L
.08332 .38833 L
.08334 .38824 L
.08333 .38815 L
.08329 .38808 L
.08325 .38803 L
.08321 .38802 L
.0832 .38804 L
.08319 .38808 L
.08319 .38811 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
Mistroke
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08317 .38812 L
.08314 .38812 L
.08309 .38812 L
.08305 .38812 L
.08303 .38814 L
.08303 .38819 L
.08305 .38827 L
.08312 .38834 L
.08324 .38837 L
.08343 .38834 L
.08369 .38824 L
.08403 .38806 L
.08443 .38778 L
.08488 .38741 L
.08536 .38698 L
.08588 .38651 L
.0864 .38602 L
.08692 .38554 L
.08739 .38507 L
.0878 .3846 L
.08816 .38416 L
.08845 .38376 L
.08866 .38344 L
.08881 .38322 L
.0889 .3831 L
.08894 .38306 L
.08894 .38308 L
.08892 .38315 L
.08888 .38323 L
.08883 .38329 L
.08879 .38331 L
.08878 .38332 L
Mistroke
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08879 .38334 L
.08883 .3834 L
.08891 .38347 L
.08899 .38354 L
.08902 .38357 L
.08899 .38354 L
.0889 .38343 L
.0887 .38324 L
.08839 .38295 L
.08798 .38258 L
.08749 .38215 L
.08696 .38164 L
.08642 .38109 L
.08589 .38053 L
.08537 .38 L
.08484 .37951 L
.08432 .37908 L
.08385 .37877 L
.08349 .37864 L
.08329 .37871 L
.08326 .37896 L
.08336 .37935 L
.08357 .37984 L
.08385 .38039 L
.08418 .38096 L
.08451 .3815 L
.08481 .382 L
Mistroke
.08509 .38246 L
.08536 .38286 L
.08561 .38319 L
.08583 .3834 L
.08602 .38345 L
.08619 .38338 L
.0863 .38327 L
.08636 .38315 L
.08635 .38307 L
.0863 .38308 L
.08621 .38324 L
.08606 .38357 L
.08586 .38406 L
.08557 .3847 L
.08521 .38549 L
.08478 .38639 L
.08427 .38734 L
.08383 .38831 L
.0833 .38938 L
.08274 .3906 L
.08218 .39192 L
.08167 .39319 L
.08122 .39435 L
.08083 .39545 L
.08051 .39646 L
.08026 .39735 L
.0801 .39808 L
.07999 .3987 L
.07995 .39923 L
.07995 .39966 L
.07997 .39998 L
.08001 .4002 L
.08005 .40033 L
.0801 .40037 L
.08015 .40034 L
.08024 .40026 L
.08032 .40016 L
.08035 .40006 L
.08033 .40001 L
.08023 .40004 L
.08004 .40013 L
.07972 .40027 L
.07929 .40046 L
.07878 .40068 L
.07823 .40091 L
.07768 .40117 L
.07715 .40142 L
.07665 .40167 L
.07614 .40192 L
.07562 .40215 L
Mistroke
.07514 .40234 L
.07475 .40246 L
.0745 .4025 L
.07438 .40248 L
.07435 .40243 L
.07441 .40235 L
.07453 .40229 L
.07468 .40232 L
.07478 .40247 L
.07481 .40274 L
.07477 .40315 L
.07465 .40369 L
.07443 .40435 L
.07411 .4051 L
.07369 .40579 L
.07318 .40658 L
.07257 .40746 L
.07187 .40854 L
.07115 .40949 L
.07038 .41045 L
.06953 .41141 L
.06861 .41243 L
.06765 .4135 L
.06674 .41464 L
.06592 .41587 L
.06527 .41685 L
.06468 .41819 L
.06416 .41972 L
.06369 .42145 L
.06327 .42325 L
.06293 .42515 L
.0627 .42711 L
.06255 .42889 L
.06248 .43051 L
.06247 .43199 L
.06251 .43331 L
.06256 .43439 L
.06257 .43528 L
.06257 .43597 L
.06256 .43646 L
.06255 .43675 L
.06254 .43686 L
.06254 .43685 L
.06255 .43677 L
.06255 .43662 L
.06256 .43645 L
.06257 .43627 L
.06257 .43611 L
.06257 .43601 L
.06258 .436 L
Mistroke
.06257 .43609 L
.06257 .43631 L
.06255 .43666 L
.06254 .43713 L
.06252 .43771 L
.0625 .43837 L
.06247 .4391 L
.06245 .43983 L
.06242 .44058 L
.0624 .44131 L
.06237 .44198 L
.06233 .44258 L
.06227 .44308 L
.06218 .44344 L
.0621 .44368 L
.06205 .44379 L
.06207 .44379 L
.06217 .44372 L
.06236 .44361 L
.06267 .44351 L
.06307 .44343 L
.06354 .44337 L
.06403 .44332 L
.06453 .44326 L
.06504 .44322 L
.06554 .44324 L
.06608 .44335 L
.06665 .44354 L
.06722 .4438 L
.06775 .4441 L
.06822 .4444 L
.06862 .44467 L
.06896 .44489 L
.06923 .44506 L
.06943 .44516 L
.06962 .44521 L
.06983 .44522 L
.07006 .44518 L
.07028 .4451 L
.07045 .44494 L
.07057 .44471 L
.07065 .44439 L
.07072 .44404 L
.0708 .44369 L
.07084 .44343 L
.07084 .44327 L
.07079 .44324 L
.07068 .44334 L
.07047 .44352 L
.07015 .44371 L
Mistroke
.06973 .44388 L
.06923 .44399 L
.06869 .44407 L
.06813 .44412 L
.0676 .44414 L
.06709 .44415 L
.06657 .44415 L
.06606 .44413 L
.06559 .44408 L
.06522 .444 L
.06497 .4439 L
.06483 .44378 L
.06479 .44367 L
.06481 .44357 L
.06488 .4435 L
.06498 .44346 L
.06505 .44344 L
.06511 .44342 L
.06516 .44338 L
.0652 .44333 L
.06522 .44329 L
.06521 .44331 L
.06514 .44341 L
.065 .44357 L
.06478 .44379 L
.0645 .44408 L
.06416 .44443 L
.06381 .44487 L
.06349 .44538 L
.06325 .44594 L
.06308 .44652 L
.063 .44712 L
.06304 .44774 L
.0632 .44837 L
.06348 .44902 L
.06386 .44972 L
.06429 .45054 L
.0648 .45146 L
.06538 .45256 L
.06592 .4539 L
.06644 .45554 L
.06689 .45756 L
.06722 .45963 L
.0674 .46225 L
.0674 .46521 L
.06722 .46831 L
.06688 .47219 L
.06641 .47558 L
.06585 .4797 L
.06526 .48367 L
Mistroke
.06463 .4883 L
.06406 .4924 L
.06349 .49625 L
.06298 .50087 L
.06252 .50516 L
.06218 .5092 L
.06194 .5128 L
.06181 .51712 L
.06185 .52118 L
.06205 .52593 L
.06241 .52992 L
.0629 .53437 L
.06349 .53905 L
.06412 .5441 L
.06487 .54914 L
.06549 .55431 L
.06614 .5595 L
.06679 .56502 L
.06742 .57047 L
.06798 .5767 L
.06853 .58214 L
.06907 .58705 L
.06957 .59235 L
.07005 .59749 L
.07055 .60249 L
.07105 .607 L
.07156 .6111 L
.07205 .61497 L
.07254 .61833 L
.07301 .62138 L
.07345 .62381 L
.07384 .62598 L
.07419 .62758 L
.0745 .6288 L
.07475 .62965 L
.07495 .63018 L
.0751 .63043 L
.07518 .63046 L
.07521 .63036 L
.07521 .63019 L
.07518 .63 L
.07514 .62982 L
.0751 .62968 L
.07506 .62961 L
.07505 .62957 L
.07504 .62953 L
.07503 .62945 L
.075 .62934 L
.07496 .62923 L
.07493 .62916 L
Mistroke
.0749 .62917 L
.07491 .62926 L
.07496 .62944 L
.07505 .62973 L
.07518 .63014 L
.07533 .63068 L
.07551 .63138 L
.07571 .63227 L
.07594 .63335 L
.07621 .63454 L
.07651 .63588 L
.07685 .63732 L
.07722 .63883 L
.07759 .64037 L
.07797 .64182 L
.0783 .64324 L
.07858 .64464 L
.0788 .64604 L
.07898 .64733 L
.07916 .64859 L
.07934 .64981 L
.07955 .65105 L
.07977 .65232 L
.08001 .65365 L
.08024 .65508 L
.08046 .65671 L
.08065 .65861 L
.08083 .66074 L
.08097 .66307 L
.08111 .66566 L
.08123 .6684 L
.08134 .67069 L
.08143 .67352 L
.0815 .67591 L
.08159 .67836 L
.08171 .68087 L
.08186 .68314 L
.08207 .68532 L
.08233 .6873 L
.08266 .68922 L
.08308 .69108 L
.08356 .69303 L
.08413 .69508 L
.08475 .69715 L
.08537 .69938 L
.08596 .70171 L
.08652 .70408 L
.08705 .70619 L
.08751 .70828 L
.08791 .71034 L
Mistroke
.08826 .71233 L
.08856 .71402 L
.08884 .7155 L
.08912 .71671 L
.08941 .7176 L
.0897 .71816 L
.08999 .71846 L
.09026 .71852 L
.09051 .71842 L
.09073 .71822 L
.09095 .718 L
.09113 .71773 L
.09131 .71743 L
.09146 .71708 L
.09156 .7167 L
.09162 .71633 L
.09164 .71604 L
.09163 .71591 L
.09162 .71598 L
.09161 .71625 L
.09159 .7167 L
.09157 .71726 L
.09155 .71787 L
.09154 .7185 L
.09156 .71913 L
.09164 .71977 L
.09176 .72041 L
.09192 .72106 L
.09212 .72169 L
.09234 .72227 L
.09257 .72276 L
.09279 .72313 L
.09299 .72337 L
.0932 .72351 L
.09341 .72357 L
.09363 .72358 L
.09387 .72359 L
.09411 .72362 L
.09437 .72369 L
.09464 .72377 L
.09491 .72381 L
.09517 .72381 L
.09543 .72378 L
.09566 .72373 L
.09591 .72368 L
.09617 .72362 L
.09642 .72355 L
.09664 .72346 L
.09679 .72337 L
.09686 .7233 L
Mistroke
.09685 .72327 L
.09679 .7233 L
.09669 .72341 L
.09659 .72361 L
.09652 .72392 L
.09654 .72436 L
.0967 .72497 L
.09703 .72576 L
.09752 .72672 L
.09818 .72785 L
.09904 .72915 L
.1 .73057 L
.10112 .73202 L
.10232 .73349 L
.10359 .73492 L
.10478 .73622 L
.10606 .73742 L
.1071 .73842 L
.10805 .73927 L
.10888 .73995 L
.10955 .74045 L
.11002 .74076 L
.11031 .74089 L
.11043 .74088 L
.11044 .74081 L
.11037 .74073 L
.11022 .74071 L
.11002 .74076 L
.10983 .74092 L
.10969 .74119 L
.10962 .74155 L
.10962 .74197 L
.10971 .74243 L
.10991 .74296 L
.11023 .74356 L
.11069 .74424 L
.11128 .74501 L
.112 .74585 L
.11279 .74676 L
.11375 .74771 L
.11478 .74872 L
.11597 .74978 L
.11719 .75088 L
.11853 .75207 L
.11991 .75343 L
.12138 .75501 L
.12288 .75677 L
.12453 .75879 L
.12624 .76101 L
.12813 .76343 L
Mistroke
.13024 .76602 L
.13259 .76889 L
.13509 .77167 L
.1377 .77464 L
.14047 .77759 L
.1432 .78061 L
.14602 .78364 L
.14862 .78651 L
.15094 .7892 L
.15337 .79174 L
.15567 .79403 L
.15794 .79616 L
.15987 .79807 L
.16172 .79991 L
.16352 .80164 L
.16531 .80344 L
.16722 .80526 L
.16927 .80732 L
.17155 .80957 L
.17412 .81218 L
.17705 .81511 L
.18036 .81861 L
.18411 .82195 L
.1881 .82616 L
.19251 .83069 L
.19691 .83464 L
.20157 .83936 L
.20643 .84405 L
.21076 .84842 L
.21512 .85315 L
.21906 .85666 L
.22296 .86047 L
.2262 .86342 L
.22915 .86649 L
.23171 .86872 L
.23405 .87064 L
.23611 .87225 L
.23807 .87357 L
.24006 .87475 L
.24208 .87591 L
.24426 .87698 L
.24674 .87822 L
.24957 .87962 L
.25233 .88113 L
.25564 .88283 L
.2592 .88468 L
.26292 .88658 L
.26672 .88841 L
.27032 .89019 L
.27387 .89179 L
Mistroke
.27741 .89335 L
.28086 .89484 L
.28407 .8962 L
.28723 .89751 L
.29027 .89874 L
.29321 .89992 L
.29613 .90105 L
.29903 .90216 L
.30198 .90316 L
.30495 .90428 L
.30798 .90534 L
.3112 .90648 L
.3145 .90771 L
.31803 .90903 L
.32171 .91035 L
.32531 .91175 L
.32916 .91311 L
.33307 .91451 L
.33693 .91594 L
.34091 .91734 L
.34487 .91884 L
.34856 .92039 L
.35247 .92208 L
.35637 .92369 L
.3601 .92532 L
.36387 .92694 L
.36769 .92844 L
.37162 .93 L
.37593 .9316 L
.38022 .93331 L
.38505 .93499 L
.39053 .93682 L
.39557 .9386 L
.40137 .94044 L
.4074 .9422 L
.41419 .94388 L
.41935 .94531 L
.42507 .94664 L
.43115 .94775 L
.43555 .94866 L
.44008 .94941 L
.44395 .94998 L
.44739 .95035 L
.45003 .95054 L
.45212 .95056 L
.45367 .95042 L
.45483 .95017 L
.45562 .94987 L
.4561 .94963 L
.45635 .94951 L
Mistroke
.45642 .94953 L
.45639 .9497 L
.45628 .94999 L
.45606 .95037 L
.45576 .95082 L
.45537 .95132 L
.45495 .95185 L
.45455 .95237 L
.45413 .9529 L
.45369 .95341 L
.45322 .95389 L
.45274 .95432 L
.45232 .95467 L
.45198 .95491 L
.45171 .95506 L
.45145 .95511 L
.45111 .95511 L
.45067 .95507 L
.45008 .95504 L
.44928 .95504 L
.44831 .95508 L
.44721 .95516 L
.44609 .95525 L
.44503 .95533 L
.44407 .9554 L
.44327 .95546 L
.44265 .95551 L
.44219 .95555 L
.44192 .95556 L
.44184 .95557 L
.44201 .95555 L
.44236 .95552 L
.4428 .95549 L
.44324 .95545 L
.44361 .95542 L
.44386 .95541 L
.44393 .9554 L
.44376 .95542 L
.44335 .95545 L
.44275 .9555 L
.44206 .95555 L
.44137 .9556 L
.44074 .95565 L
.44019 .95569 L
.43972 .95573 L
.43936 .95575 L
.43913 .95577 L
.43905 .95577 L
.43912 .95576 L
.43933 .95575 L
Mistroke
.43962 .95572 L
.43998 .95572 L
.44035 .95573 L
.44073 .95578 L
.44107 .95582 L
.44136 .95581 L
.44164 .95572 L
.44194 .95554 L
.44227 .95528 L
.44264 .95499 L
.44303 .95467 L
.44345 .95437 L
.44394 .95411 L
.4445 .95393 L
.44515 .95385 L
.44584 .95384 L
.44655 .95386 L
.44724 .95388 L
.4479 .95386 L
.44851 .95386 L
.4491 .95385 L
.44968 .95381 L
.45028 .95369 L
.4509 .9535 L
.45156 .95322 L
.45223 .95285 L
.45291 .95239 L
.45356 .95184 L
.45416 .95123 L
.45472 .95065 L
.45523 .95018 L
.45569 .94984 L
.4561 .94963 L
.45645 .94951 L
.45671 .94948 L
.45689 .94948 L
.45698 .9495 L
.45699 .94948 L
.45693 .94941 L
.45683 .94926 L
.45673 .94906 L
.45665 .94883 L
.4566 .94858 L
.45658 .94833 L
.45658 .94808 L
.45662 .94786 L
.4567 .94769 L
.45681 .94756 L
.45692 .94747 L
.45701 .9474 L
Mistroke
.45706 .94731 L
.45706 .9472 L
.45698 .94707 L
.45681 .9469 L
.45651 .94667 L
.45607 .94638 L
.45548 .946 L
.45476 .94552 L
.45396 .94496 L
.45306 .94432 L
.45206 .94363 L
.45094 .9429 L
.44969 .94217 L
.44836 .94147 L
.44697 .94085 L
.44553 .94034 L
.44414 .93993 L
.44282 .93961 L
.44165 .93939 L
.44067 .93926 L
.43994 .93919 L
.43944 .93917 L
.43916 .93916 L
.43912 .93914 L
.43928 .93907 L
.43967 .93889 L
.44024 .93852 L
.441 .93785 L
.44198 .9368 L
.44314 .93533 L
.44449 .93342 L
.44592 .93114 L
.44741 .92828 L
.44894 .92513 L
.45048 .92145 L
.45209 .91751 L
.45379 .9127 L
.45549 .90855 L
.45724 .9038 L
.45902 .8986 L
.46074 .89424 L
.46247 .88942 L
.46419 .88464 L
.46595 .88004 L
.46767 .87599 L
.46952 .87202 L
.47157 .86813 L
.47393 .86497 L
.47662 .8618 L
.47961 .85914 L
Mistroke
.48308 .85677 L
.48702 .85478 L
.49131 .85321 L
.4962 .85213 L
.50144 .8515 L
.50708 .85134 L
.51333 .85167 L
.51966 .85252 L
.52668 .85392 L
.53358 .85596 L
.54058 .85844 L
.54784 .86158 L
.55527 .86522 L
.56238 .86959 L
.57016 .87413 L
.57733 .87872 L
.58387 .88412 L
.59051 .889 L
.5967 .89467 L
.60211 .89923 L
.60672 .9041 L
.61097 .90842 L
.61427 .9123 L
.61704 .91551 L
.6196 .91861 L
.62169 .92093 L
.62363 .92282 L
.62557 .92429 L
.6277 .92539 L
.63016 .92615 L
.63297 .92661 L
.63559 .92683 L
.63907 .92682 L
.64326 .9266 L
.6476 .92615 L
.65284 .92547 L
.6585 .92447 L
.66495 .92307 L
.67054 .92121 L
.67702 .91903 L
.68356 .91636 L
.68939 .91327 L
.69572 .90996 L
.7021 .90631 L
.709 .90213 L
.71483 .89849 L
.72144 .8944 L
.72769 .89028 L
.73419 .88601 L
.74094 .88189 L
Mistroke
.74729 .87774 L
.75383 .87362 L
.76015 .86956 L
.76689 .86542 L
.77275 .86166 L
.77884 .85772 L
.78484 .85386 L
.79054 .84978 L
.79612 .84608 L
.80132 .84253 L
.80628 .83875 L
.81128 .83521 L
.81606 .8317 L
.82074 .82826 L
.82548 .82479 L
.82966 .82163 L
.83384 .81858 L
.83779 .81572 L
.84156 .81289 L
.84496 .81029 L
.84805 .80787 L
.85059 .80574 L
.85277 .80385 L
.85451 .80222 L
.85584 .80082 L
.85685 .79966 L
.85756 .79881 L
.85797 .79822 L
.85814 .79789 L
.85813 .79782 L
.85798 .79798 L
.85778 .7983 L
.85759 .79871 L
.85743 .79918 L
.85727 .79969 L
.85708 .80025 L
.85682 .80085 L
.85647 .80146 L
.85599 .80207 L
.85539 .80261 L
.8547 .80308 L
.85393 .80347 L
.85313 .80378 L
.85233 .80402 L
.85158 .80419 L
.85087 .80435 L
.85021 .80451 L
.84963 .8047 L
.84914 .80491 L
.84875 .80512 L
Mistroke
.84846 .80528 L
.84828 .80537 L
.8482 .80539 L
.84822 .80537 L
.84832 .80533 L
.84848 .80527 L
.84864 .80523 L
.84881 .8052 L
.84898 .80518 L
.84917 .80516 L
.84938 .80514 L
.84962 .80514 L
.84987 .80514 L
.85013 .80515 L
.85038 .80516 L
.85059 .80516 L
.85075 .80513 L
.85084 .80508 L
.85085 .80498 L
.85078 .80485 L
.85063 .8047 L
.85043 .80451 L
.85018 .8043 L
.84994 .80405 L
.84971 .80375 L
.8495 .80342 L
.84931 .80311 L
.84912 .80286 L
.84893 .80273 L
.84873 .80278 L
.84849 .80303 L
.84824 .80348 L
.848 .80407 L
.84779 .80475 L
.84761 .80545 L
.8475 .8061 L
.84745 .80666 L
.84749 .80711 L
.84763 .80746 L
.84789 .8077 L
.84827 .8078 L
.84872 .80776 L
.84921 .80758 L
.84974 .80721 L
.85028 .80671 L
.85081 .8061 L
.8513 .80545 L
.85172 .80482 L
.85205 .80429 L
.85229 .80388 L
Mistroke
.85243 .80359 L
.85251 .80338 L
.85253 .8032 L
.85252 .80305 L
.8525 .80291 L
.85251 .80278 L
.85255 .80269 L
.8526 .80266 L
.85267 .8027 L
.85272 .80282 L
.85272 .80302 L
.85266 .80323 L
.85255 .80342 L
.85238 .80353 L
.85222 .80349 L
.85213 .80318 L
.85221 .80251 L
.85254 .80136 L
.85319 .79966 L
.85418 .79731 L
.85556 .7942 L
.85729 .79048 L
.85937 .78607 L
.86191 .78084 L
.86495 .77471 L
.86798 .76819 L
.87142 .76048 L
.87503 .75221 L
.87859 .7442 L
.88251 .73439 L
.88611 .72508 L
.88983 .71345 L
.89355 .7041 L
.89722 .69315 L
.90074 .68201 L
.90463 .66944 L
.90793 .65961 L
.91164 .64856 L
.91538 .63604 L
.91876 .62661 L
.92233 .61608 L
.92576 .60546 L
.92883 .59656 L
.93171 .58726 L
.93421 .57821 L
.93631 .56942 L
.93796 .56071 L
.93918 .55191 L
.93998 .54355 L
.94041 .53455 L
Mistroke
.94055 .52575 L
.94042 .51653 L
.94005 .50665 L
.9395 .49796 L
.93884 .48853 L
.9381 .47827 L
.93732 .46937 L
.93656 .45947 L
.93584 .45035 L
.93516 .44083 L
.93452 .43126 L
.93389 .42141 L
.93322 .41263 L
.93248 .40332 L
.93165 .39397 L
.93075 .38527 L
.92976 .37683 L
.92874 .36834 L
.92772 .36054 L
.92675 .35343 L
.9258 .3468 L
.92487 .34035 L
.92393 .33538 L
.92297 .33061 L
.92198 .32634 L
.921 .32278 L
.91998 .31956 L
.91889 .31681 L
.9177 .31436 L
.91638 .31207 L
.91504 .3099 L
.91337 .30757 L
.91144 .30489 L
.90932 .30187 L
.90674 .29828 L
.90391 .29408 L
.90054 .28929 L
.89704 .28364 L
.89301 .27788 L
.88898 .27142 L
.8844 .26455 L
.87997 .25749 L
.87504 .24962 L
.86986 .24224 L
.86523 .23502 L
.86015 .22753 L
.8548 .21989 L
.84961 .21253 L
.84534 .20588 L
.84049 .19901 L
Mistroke
.83574 .19237 L
.83074 .18577 L
.82631 .1797 L
.82243 .17413 L
.81841 .16875 L
.81458 .16374 L
.81133 .15938 L
.80832 .1553 L
.80588 .15206 L
.80391 .14936 L
.80232 .14718 L
.8012 .14559 L
.80046 .14455 L
.80011 .14403 L
.80013 .14393 L
.80041 .14411 L
.80081 .14445 L
.80127 .14486 L
.80172 .14526 L
.80208 .14553 L
.80228 .14562 L
.80234 .14556 L
.80227 .14539 L
.80211 .14513 L
.80187 .14481 L
.8016 .14442 L
.80132 .144 L
.80104 .14355 L
.80078 .1431 L
.80055 .14265 L
.80034 .14221 L
.80015 .14179 L
.8 .14139 L
.79989 .14105 L
.79983 .14079 L
.79981 .14065 L
.79982 .14064 L
.79985 .14076 L
.79991 .141 L
.79998 .14133 L
.80006 .14171 L
.80014 .14211 L
.80026 .14254 L
.80042 .14299 L
.80061 .14343 L
.80083 .14388 L
.80106 .14432 L
.80129 .14472 L
.80152 .14506 L
.80174 .14534 L
Mistroke
.80194 .14554 L
.80211 .14565 L
.80225 .14568 L
.80238 .14565 L
.80249 .1456 L
.80259 .14556 L
.80269 .14558 L
.80278 .14567 L
.80285 .1458 L
.80286 .14591 L
.80278 .14595 L
.80256 .14588 L
.80217 .14569 L
.80155 .14534 L
.80068 .14479 L
.79954 .14405 L
.79823 .14312 L
.79658 .142 L
.79473 .14077 L
.79258 .13939 L
.79046 .13797 L
.78815 .13651 L
.78588 .1351 L
.78364 .13379 L
.78155 .13262 L
.77978 .13165 L
.77818 .13088 L
.77683 .13032 L
.77579 .12995 L
.77497 .12974 L
.77436 .12965 L
.77396 .12963 L
.77375 .12966 L
.77367 .12973 L
.77371 .12982 L
.77381 .12991 L
.77392 .12997 L
.77403 .13 L
.77411 .13001 L
.77417 .13001 L
.7742 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
Mistroke
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77422 .13001 L
.77429 .13002 L
.77445 .13004 L
.77471 .1301 L
.77501 .13017 L
.7753 .13026 L
.77552 .13036 L
.77559 .13048 L
.77542 .13057 L
.77492 .13058 L
.77397 .13049 L
.77248 .13024 L
.77038 .12978 L
.76759 .12907 L
Mistroke
.76449 .12803 L
.76041 .12664 L
.75581 .12491 L
.75047 .12267 L
.74446 .12018 L
.73737 .11738 L
.73072 .1146 L
.72306 .11118 L
.71443 .10723 L
.70685 .1039 L
.69831 .09998 L
.68984 .09598 L
.6808 .0916 L
.67286 .08809 L
.66456 .08408 L
.6564 .0803 L
.64749 .0764 L
.64064 .07299 L
.6327 .06963 L
.6257 .0664 L
.61854 .06357 L
.61174 .061 L
.60529 .05879 L
.5986 .0567 L
.59212 .05518 L
.58546 .0539 L
.57819 .05288 L
.57136 .05208 L
.5638 .05151 L
.55617 .05112 L
.54803 .05086 L
.53969 .05071 L
.53203 .05061 L
.52379 .05055 L
.51485 .05048 L
.50786 .05036 L
.49983 .05018 L
.49181 .04996 L
.48451 .04974 L
.477 .04952 L
.47011 .04928 L
.46366 .04903 L
.45727 .04875 L
.45125 .04846 L
.44539 .04817 L
.43946 .04791 L
.4341 .04767 L
.42867 .04748 L
.4234 .04738 L
.41819 .04743 L
Mistroke
.41316 .04765 L
.40818 .0481 L
.40298 .04881 L
.39806 .04981 L
.39287 .05115 L
.38722 .05284 L
.38244 .05484 L
.37721 .05718 L
.37182 .05981 L
.3661 .06273 L
.36034 .06585 L
.35509 .06918 L
.34925 .07265 L
.3432 .07622 L
.33715 .07992 L
.33068 .08345 L
.32449 .08713 L
.3181 .09059 L
.31187 .09391 L
.30544 .09719 L
.29902 .10036 L
.29225 .10337 L
.2863 .10629 L
.28017 .10904 L
.27435 .11169 L
.26857 .11426 L
.26347 .11682 L
.25842 .11935 L
.25354 .1219 L
.24896 .12443 L
.24451 .12701 L
.24003 .12968 L
.23603 .13224 L
.23217 .13477 L
.22831 .13734 L
.22462 .13995 L
.22143 .14235 L
.21823 .14484 L
.215 .14746 L
.21184 .15015 L
.20887 .15297 L
.20584 .15601 L
.2027 .15938 L
.19965 .16307 L
.19632 .16734 L
.19289 .17189 L
.18915 .17707 L
.18506 .18281 L
.18086 .18882 L
.17624 .19529 L
Mistroke
.17134 .20263 L
.16648 .20905 L
.16138 .21634 L
.1562 .22369 L
.15094 .23155 L
.14568 .23864 L
.14048 .24609 L
.13513 .25399 L
.12988 .26114 L
.12473 .2689 L
.11956 .27631 L
.11468 .28475 L
.1102 .29237 L
.10586 .30065 L
.10258 .30912 L
.09849 .31847 L
.09556 .3272 L
.09265 .33667 L
.09001 .34555 L
.08786 .35357 L
.08593 .36135 L
.08439 .36907 L
.08317 .37626 L
.08223 .38251 L
.08152 .38716 L
.081 .392 L
.08061 .39523 L
.08033 .39793 L
.08009 .39991 L
.0799 .4011 L
.07977 .40165 L
.07971 .40178 L
.07971 .40164 L
.0798 .40131 L
.07996 .40088 L
.08018 .40053 L
.08044 .40032 L
.08072 .40018 L
.081 .40011 L
.08129 .4001 L
.08157 .4001 L
.08186 .40009 L
.08213 .40009 L
.08239 .40009 L
.0826 .40009 L
.08276 .40007 L
.08285 .40004 L
.08288 .4 L
.08286 .39997 L
.08282 .39995 L
Mistroke
.08279 .39996 L
.0828 .40001 L
.08287 .40011 L
.08301 .40025 L
.0832 .40043 L
.08343 .40063 L
.08366 .40083 L
.08386 .40099 L
.08405 .40111 L
.08425 .40121 L
.08447 .40132 L
.08474 .40144 L
.08509 .40156 L
.08552 .40175 L
.08603 .40204 L
.08659 .40249 L
.08718 .40315 L
.08779 .40411 L
.08841 .40544 L
.089 .40714 L
.08959 .40939 L
.09018 .41195 L
.09071 .41509 L
.09105 .41887 L
.09117 .4226 L
.09103 .42662 L
.09061 .43112 L
.08988 .43581 L
.08881 .44065 L
.0874 .4454 L
.08586 .44996 L
.08418 .4545 L
.08239 .45821 L
.08058 .46191 L
.0789 .46529 L
.07745 .4678 L
.07611 .46986 L
.07483 .47141 L
.07367 .47244 L
.07278 .47297 L
.07222 .47307 L
.07193 .47281 L
.0718 .47226 L
.07175 .47148 L
.07175 .47055 L
.07179 .46955 L
.07177 .4685 L
.07158 .46749 L
.07131 .46654 L
.07105 .46562 L
Mistroke
.07079 .4647 L
.07055 .46379 L
.07032 .46289 L
.07013 .46197 L
.06999 .46105 L
.0699 .46017 L
.06985 .45937 L
.06986 .45868 L
.06989 .45812 L
.06995 .45769 L
.07 .45735 L
.07005 .45708 L
.07007 .45688 L
.07008 .45672 L
.07008 .45662 L
.07008 .45661 L
.07008 .4567 L
.07007 .45689 L
.07006 .45719 L
.07005 .45755 L
.07004 .45792 L
.07003 .45824 L
.07002 .45845 L
.07002 .45859 L
.07002 .45868 L
.07002 .45867 L
.07002 .45863 L
.07001 .45855 L
.06998 .45843 L
.06994 .4582 L
.06991 .45789 L
.0699 .45751 L
.06993 .45706 L
.07 .45662 L
.07013 .45623 L
.0703 .45591 L
.07051 .45566 L
.07076 .45549 L
.07104 .45538 L
.07132 .45535 L
.0716 .45537 L
.07189 .45541 L
.07216 .45546 L
.07241 .45551 L
.07263 .45554 L
.0728 .45554 L
.07293 .45554 L
.073 .45554 L
.07302 .45554 L
.073 .45554 L
Mistroke
.07296 .45554 L
.07291 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07295 .45554 L
.07305 .45556 L
.07315 .45561 L
.07321 .45571 L
.0732 .45582 L
.07311 .45594 L
.07291 .45603 L
.07257 .45603 L
.07208 .45593 L
.07144 .45567 L
.07068 .45527 L
.06981 .4547 L
.06887 .45399 L
.06794 .45314 L
.06697 .45217 L
.06597 .45101 L
.06503 .4497 L
.06422 .4482 L
.06362 .4465 L
.06323 .44471 L
.06303 .44277 L
.06296 .44076 L
.06297 .43864 L
.06304 .43656 L
.06315 .43438 L
.06327 .43221 L
.06342 .42994 L
.06361 .42776 L
.06384 .42555 L
.06407 .42346 L
.06429 .42153 L
Mistroke
.06448 .41983 L
.06464 .41835 L
.06478 .41713 L
.06491 .41617 L
.06505 .41543 L
.06519 .41488 L
.06536 .4145 L
.06554 .41426 L
.06573 .41415 L
.0659 .41415 L
.06603 .41423 L
.06613 .41437 L
.06621 .41451 L
.06629 .41464 L
.06643 .41472 L
.06664 .41474 L
.06695 .41469 L
.06736 .41459 L
.06785 .41444 L
.06841 .41426 L
.06903 .41404 L
.06969 .41379 L
.07039 .41354 L
.07107 .41328 L
.07178 .41302 L
.0725 .41278 L
.07318 .41255 L
.07383 .41235 L
.07446 .41219 L
.07504 .41208 L
.07556 .41201 L
.07598 .41199 L
.07632 .412 L
.07659 .41203 L
.07678 .41207 L
.07692 .4121 L
.07703 .41212 L
.07711 .41212 L
.07716 .41212 L
.07717 .41212 L
.07715 .41212 L
.07711 .41212 L
.07706 .41212 L
.07703 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41213 L
.07702 .41215 L
Mistroke
.07705 .41221 L
.0771 .41228 L
.07713 .41235 L
.07715 .41239 L
.07714 .41237 L
.07707 .41227 L
.07693 .41208 L
.07673 .41181 L
.07649 .41146 L
.07624 .41107 L
.076 .41067 L
.07578 .41026 L
.07561 .40985 L
.07546 .40941 L
.07537 .40893 L
.07533 .4084 L
.07538 .40784 L
.07552 .40725 L
.07576 .40661 L
.0761 .40593 L
.07653 .40524 L
.07703 .40453 L
.07756 .40386 L
.07807 .40317 L
.07855 .40247 L
.07894 .40181 L
.07927 .40124 L
.07953 .40077 L
.07973 .40036 L
.07987 .39999 L
.07998 .39969 L
.08007 .39943 L
.08014 .39922 L
.08022 .39904 L
.08031 .39885 L
.08044 .39862 L
.0806 .39835 L
.08081 .39803 L
.08107 .39767 L
.08137 .39726 L
.08166 .39681 L
.08196 .39633 L
.08224 .39591 L
.0825 .39563 L
.08273 .39546 L
.08291 .39543 L
.08303 .39554 L
.08309 .39576 L
.08311 .39607 L
.08308 .39644 L
Mistroke
.08303 .39684 L
.08297 .39727 L
.0829 .39774 L
.08283 .39825 L
.08275 .39877 L
.08266 .39927 L
.08258 .39967 L
.08253 .39997 L
.08253 .40016 L
.08263 .40025 L
.08284 .40025 L
.08318 .4002 L
.08364 .40014 L
.08422 .4001 L
.08491 .40013 L
.0856 .40024 L
.08638 .40041 L
.08718 .40062 L
.08795 .40085 L
.08874 .40109 L
.08941 .40133 L
.09 .40158 L
.09049 .40182 L
.09086 .40204 L
.0911 .40223 L
.09122 .40238 L
.09124 .40249 L
.0912 .40255 L
.09113 .40257 L
.09106 .40255 L
.09099 .40252 L
.09095 .40248 L
.09093 .40244 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09098 .40243 L
.09106 .40242 L
.09114 .40242 L
.09119 .40242 L
.09117 .40242 L
.09108 .40243 L
.09089 .40243 L
.09058 .40243 L
.09016 .40243 L
Mistroke
.08966 .40244 L
.08912 .40244 L
.08857 .40244 L
.08801 .40245 L
.08755 .40245 L
.08702 .40246 L
.0865 .40246 L
.08602 .40246 L
.08565 .40246 L
.0854 .40247 L
.08526 .40247 L
.08521 .40247 L
.08522 .40247 L
.0853 .40247 L
.08539 .40246 L
.08546 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08549 .40246 L
.0855 .40244 L
.08554 .40239 L
.08558 .40231 L
.08562 .40225 L
.08564 .40223 L
.08562 .40231 L
.08556 .40248 L
.08542 .40272 L
.08521 .40301 L
.08494 .40332 L
.08464 .40361 L
.08432 .40385 L
.08401 .40402 L
.08374 .40414 L
.08351 .40419 L
.08335 .4042 L
.08327 .40416 L
.08332 .40404 L
.0835 .4038 L
.08382 .40344 L
.08428 .403 L
.08486 .40254 L
.08557 .40214 L
.08638 .4019 L
.08723 .40188 L
.08809 .40214 L
.08895 .40269 L
.08978 .40353 L
.09054 .40465 L
.09124 .40604 L
Mistroke
.09184 .40754 L
.0923 .40936 L
.09265 .41129 L
.09287 .41345 L
.09295 .41575 L
.09291 .41793 L
.0928 .42018 L
.09267 .42234 L
.09247 .42441 L
.09217 .42656 L
.09182 .42847 L
.0914 .43048 L
.09089 .43266 L
.09023 .43493 L
.08943 .43741 L
.08844 .44019 L
.08722 .44278 L
.08573 .44583 L
.08431 .44877 L
.0827 .45207 L
.08104 .45561 L
.07897 .45893 L
.07673 .46311 L
.07483 .4667 L
.0726 .47099 L
.07072 .47537 L
.06874 .48062 L
.06737 .48396 L
.06576 .49041 L
.0645 .4956 L
.06383 .50078 L
.06307 .50586 L
.06264 .50994 L
.06234 .51454 L
.06213 .52102 L
.06218 .52561 L
.06239 .52938 L
.06266 .53295 L
.06287 .53651 L
.0631 .53904 L
.06338 .54159 L
.06369 .5436 L
.064 .54469 L
.06427 .54545 L
.06453 .54596 L
.06477 .54624 L
.06504 .54636 L
.06529 .54637 L
.06553 .54634 L
.06573 .54628 L
Mistroke
.06596 .54618 L
.06624 .54607 L
.0665 .54597 L
.06672 .54588 L
.0669 .54583 L
.06702 .54581 L
.06708 .54581 L
.06711 .54581 L
.06709 .54581 L
.06705 .54581 L
.06701 .54581 L
.06698 .54581 L
.06697 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54579 L
.06697 .54574 L
.06697 .54566 L
.06698 .54559 L
.06698 .54556 L
.06698 .54558 L
.06697 .54568 L
.06695 .54587 L
.06693 .54616 L
.06691 .54654 L
.06688 .54698 L
.06686 .54747 L
.06684 .54797 L
.06682 .54846 L
.0668 .54894 L
.06679 .54941 L
.06677 .54987 L
.06676 .55028 L
.06675 .55061 L
.06675 .55083 L
.06675 .55095 L
.06676 .55099 L
.06678 .55097 L
.06679 .5509 L
.0668 .55081 L
.06681 .55075 L
.0668 .55073 L
.0668 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
Mistroke
.06679 .55073 L
.06679 .55072 L
.06678 .55069 L
.06675 .55063 L
.0667 .55055 L
.06664 .55041 L
.06657 .55025 L
.06651 .55008 L
.06647 .54997 L
.06645 .54996 L
.06647 .55009 L
.06656 .55041 L
.06679 .55102 L
.06715 .55196 L
.06769 .55334 L
.06846 .55496 L
.06941 .55748 L
.07098 .56085 L
.0726 .56355 L
.07454 .5676 L
.07722 .57134 L
.07961 .57551 L
.08211 .58064 L
.08391 .5839 L
.08706 .58924 L
.08872 .59244 L
.09155 .59752 L
.09357 .60143 L
.09518 .6052 L
.09687 .60816 L
.09799 .61182 L
.09891 .61569 L
.09969 .61823 L
.10016 .62203 L
.1003 .62475 L
.1003 .62859 L
.10018 .63112 L
.09994 .63475 L
.09962 .63867 L
.09925 .64173 L
.09891 .64565 L
.09848 .64862 L
.09795 .65293 L
.09733 .65569 L
.09668 .65935 L
.09596 .66281 L
.09509 .66664 L
.09406 .66944 L
.09314 .67305 L
.0921 .67601 L
Mistroke
.09096 .67848 L
.09001 .68199 L
.08919 .68438 L
.0885 .68698 L
.08791 .68982 L
.08742 .69212 L
.08711 .69403 L
.08698 .69596 L
.08701 .69812 L
.08719 .70027 L
.08749 .70192 L
.08783 .7036 L
.08822 .7054 L
.08867 .7072 L
.0891 .7088 L
.08951 .71009 L
.08998 .7115 L
.0904 .71314 L
.09086 .71439 L
.09123 .71559 L
.09164 .71676 L
.09205 .71782 L
.09247 .71874 L
.09288 .71944 L
.09324 .72004 L
.09356 .72053 L
.09383 .7209 L
.09405 .72117 L
.09423 .72136 L
.09432 .72148 L
.09436 .72152 L
.09436 .72151 L
.09434 .72146 L
.0943 .72138 L
.09426 .7213 L
.09422 .72125 L
.09421 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72122 L
.0942 .7212 L
.0942 .72116 L
.0942 .72112 L
.09421 .7211 L
.09421 .7211 L
.0942 .72113 L
.0942 .72122 L
.0942 .72135 L
.0942 .72154 L
.09419 .72176 L
.09418 .722 L
.09418 .72225 L
Mistroke
.09417 .72253 L
.09417 .72275 L
.09416 .723 L
.09416 .72325 L
.09415 .72347 L
.09415 .72365 L
.09414 .72377 L
.09414 .72385 L
.09414 .72388 L
.09414 .72387 L
.09414 .72384 L
.09414 .72379 L
.09414 .72376 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09416 .72378 L
.09422 .72382 L
.0943 .72385 L
.09433 .72387 L
.09431 .72385 L
.09424 .7238 L
.09407 .72371 L
.09378 .72358 L
.09334 .7234 L
.0928 .7232 L
.09224 .72297 L
.09174 .72274 L
.09128 .7225 L
.09081 .72226 L
.09034 .72203 L
.08984 .72182 L
.08935 .72163 L
.08896 .72149 L
Mistroke
.08872 .72138 L
.08861 .72132 L
.08857 .72131 L
.08859 .72132 L
.08866 .72136 L
.08874 .72139 L
.08877 .72142 L
.08877 .72144 L
.08876 .72144 L
.08873 .72144 L
.08869 .72145 L
.08865 .72145 L
.08863 .72145 L
.08864 .72145 L
.0887 .72144 L
.0888 .72144 L
.08896 .72143 L
.08917 .72143 L
.08941 .72142 L
.08968 .72141 L
.08996 .72139 L
.09023 .72138 L
.09049 .72137 L
.09075 .72136 L
.091 .72135 L
.09123 .72134 L
.09141 .72134 L
.09154 .72133 L
.09161 .72133 L
.09163 .72133 L
.09162 .72133 L
.09158 .72133 L
.09153 .72133 L
.0915 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
Mistroke
.09149 .72133 L
.09149 .72133 L
.09148 .72133 L
.09147 .72132 L
.09145 .72129 L
.09141 .72125 L
.09137 .72122 L
.09135 .7212 L
.09136 .72121 L
.09142 .72126 L
.09152 .72136 L
.09167 .7215 L
.09188 .72168 L
.09211 .7219 L
.09238 .72213 L
.09265 .72238 L
.09291 .72263 L
.09317 .72288 L
.09343 .72312 L
.09367 .72334 L
.09389 .72353 L
.09407 .72369 L
.09419 .7238 L
.09426 .72386 L
.09428 .72388 L
.09427 .72386 L
.09423 .72383 L
.09419 .72379 L
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .7229 L
.09417 .72264 L
.09417 .72238 L
Mistroke
.09418 .72212 L
.0942 .72188 L
.09423 .7217 L
.09428 .72158 L
.09432 .72149 L
.09434 .72141 L
.09433 .72133 L
.09427 .72122 L
.09417 .72105 L
.09402 .7208 L
.09382 .72046 L
.09359 .72005 L
.09333 .71959 L
.09307 .71909 L
.09281 .71859 L
.09256 .71812 L
.09231 .71764 L
.09207 .71718 L
.09185 .71677 L
.09168 .71645 L
.09156 .71622 L
.09149 .7161 L
.09147 .71606 L
.09148 .71608 L
.09152 .71615 L
.09156 .71623 L
.09159 .71629 L
.09161 .71631 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09162 .71634 L
.09163 .71636 L
.09166 .71641 L
.09169 .71647 L
.09172 .71652 L
.09172 .71654 L
.09167 .71648 L
.09157 .7163 L
.09136 .71611 L
.0911 .71584 L
.09087 .71552 L
.09044 .71522 L
.09025 .71484 L
.0901 .7144 L
.09003 .71397 L
.08997 .71358 L
.08996 .71317 L
.09002 .71265 L
.09013 .71217 L
.09026 .71179 L
.09043 .71147 L
.09064 .71131 L
.09096 .71122 L
.09128 .71119 L
.09155 .71121 L
.09171 .71124 L
.09182 .71128 L
.0919 .71129 L
.09193 .71124 L
.09192 .71117 L
.09186 .71114 L
.09175 .71115 L
.09156 .71122 L
.0913 .71139 L
.09102 .71168 L
.09077 .7121 L
.09057 .71259 L
.09044 .71314 L
.09039 .71359 L
.09037 .71403 L
.09035 .71447 L
.09034 .71488 L
.09036 .71537 L
.09043 .71583 L
.09058 .71619 L
Mistroke
.09079 .71639 L
.09104 .71648 L
.09132 .71651 L
.09155 .71649 L
.09168 .71641 L
.09172 .71633 L
.09173 .71632 L
.09171 .71632 L
.09168 .71632 L
.09164 .71632 L
.09162 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09161 .71637 L
.0916 .71644 L
.0916 .71651 L
.0916 .71654 L
.0916 .71652 L
.09161 .71643 L
.09161 .71626 L
.09162 .71597 L
.09163 .71558 L
.09164 .71512 L
.09165 .71462 L
.09166 .71411 L
.09168 .71364 L
Mistroke
.09169 .71319 L
.0917 .71273 L
.09171 .71226 L
.09172 .71182 L
.09173 .71147 L
.09174 .71124 L
.09174 .71112 L
.09174 .71108 L
.09174 .71109 L
.09174 .71116 L
.09174 .71124 L
.09174 .71129 L
.09173 .7113 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09174 .71131 L
.09174 .71132 L
.09177 .71134 L
.09181 .71138 L
.09184 .71142 L
.09186 .71143 L
.09185 .71143 L
.0918 .71138 L
.0917 .71129 L
.09155 .71116 L
.09134 .71099 L
.0911 .71079 L
.09083 .71056 L
.09056 .71034 L
.09031 .71016 L
.09006 .70999 L
.08981 .70978 L
.08956 .70952 L
.08934 .70921 L
.08916 .70888 L
.08905 .70849 L
.08899 .70804 L
.08898 .70754 L
.08901 .70704 L
.08905 .70654 L
.08911 .7061 L
.08915 .70573 L
.08917 .70538 L
.08918 .70499 L
.08919 .70458 L
.0892 .70423 L
.08921 .70393 L
Mistroke
.08922 .70365 L
.08923 .70332 L
.08923 .70293 L
.08924 .70254 L
.08925 .70215 L
.08927 .7017 L
.08928 .70121 L
.08929 .70074 L
.08931 .70026 L
.08932 .69979 L
.08933 .69936 L
.08934 .69903 L
.08934 .69881 L
.08935 .6987 L
.08935 .69866 L
.08935 .69868 L
.08934 .69875 L
.08934 .69882 L
.08934 .69887 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .699 L
.08934 .69902 L
.08934 .69901 L
.08934 .69895 L
.08934 .69885 L
.08934 .69871 L
.08935 .69852 L
.08935 .69829 L
.08936 .69805 L
.08937 .69779 L
.08938 .69754 L
.08938 .69728 L
.08939 .69704 L
.08939 .6968 L
.0894 .6966 L
.0894 .69644 L
Mistroke
.08941 .69632 L
.08941 .69626 L
.08941 .69624 L
.08941 .69625 L
.08941 .69629 L
.08941 .69634 L
.08941 .69638 L
.08944 .69643 L
.08948 .6965 L
.08951 .69657 L
.08953 .6966 L
.08952 .69658 L
.08947 .69649 L
.08937 .69632 L
.08922 .69604 L
.08902 .69566 L
.08879 .6952 L
.08853 .69472 L
.08827 .69422 L
.08802 .69375 L
.08777 .6933 L
.08753 .69283 L
.08729 .69237 L
.08709 .69197 L
.08695 .69171 L
.08687 .69156 L
.08683 .69149 L
.08681 .69146 L
.08678 .69141 L
.08673 .69131 L
.08662 .69112 L
.08645 .69079 L
.08622 .69034 L
.08596 .68984 L
.08569 .68933 L
.08544 .68886 L
.0852 .68841 L
.08496 .68796 L
.08471 .6875 L
.08449 .68707 L
.08432 .68673 L
.0842 .68651 L
.08413 .68639 L
.08411 .68635 L
.08412 .68636 L
.08416 .68643 L
.0842 .68651 L
.08423 .68655 L
.08424 .68657 L
.08424 .68657 L
Mistroke
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08427 .68656 L
.08431 .68648 L
.08435 .68633 L
.08437 .68628 L
.08436 .68633 L
.0843 .68646 L
.0842 .68676 L
.08403 .68732 L
.08379 .68819 L
.08351 .68933 L
.08321 .69045 L
.08291 .69151 L
.08262 .69244 L
.08235 .69332 L
.08207 .69419 L
.08179 .69507 L
.08152 .69599 L
.08131 .69661 L
.08116 .69672 L
.08106 .6965 L
.08103 .69612 L
.08107 .69559 L
.08117 .69486 L
.08133 .69414 L
.08152 .69341 L
.08176 .69262 L
.08204 .69179 L
.08234 .69095 L
.08264 .69013 L
.08291 .68935 L
.08318 .68865 L
.08345 .68801 L
.08372 .68742 L
.08397 .68686 L
.08416 .68631 L
.0843 .68579 L
.08438 .68533 L
.08441 .68497 L
.0844 .68467 L
.08437 .68447 L
.08433 .68435 L
.08431 .68429 L
.0843 .68425 L
.0843 .68423 L
Mistroke
.0843 .6842 L
.0843 .68415 L
.0843 .684 L
.08431 .68374 L
.08432 .68338 L
.08433 .6829 L
.08435 .68227 L
.08437 .68151 L
.0844 .68079 L
.08443 .68004 L
.08449 .67924 L
.08455 .67836 L
.08461 .6774 L
.08465 .67658 L
.08467 .67581 L
.08464 .67504 L
.08458 .67425 L
.08446 .67344 L
.08428 .6726 L
.08404 .67184 L
.08378 .67091 L
.08353 .66984 L
.08331 .66874 L
.08312 .66774 L
.08291 .66659 L
.08268 .66515 L
.08244 .6637 L
.08222 .6624 L
.08201 .66085 L
.08177 .65914 L
.08158 .65777 L
.08138 .65618 L
.08122 .65435 L
.0811 .65291 L
.08099 .65132 L
.08083 .65 L
.08064 .64848 L
.08043 .64693 L
.08024 .64573 L
.08004 .64454 L
.07984 .64335 L
.07962 .64241 L
.07939 .64148 L
.07917 .6406 L
.07898 .6398 L
.07881 .63909 L
.07862 .63845 L
.07838 .6378 L
.07812 .63712 L
.07786 .63636 L
Mistroke
.07761 .63547 L
.07735 .63445 L
.07709 .63346 L
.07683 .63244 L
.07661 .63125 L
.07641 .62992 L
.07625 .62883 L
.07607 .62736 L
.07586 .6262 L
.07565 .62497 L
.07547 .62365 L
.07534 .62241 L
.07527 .62143 L
.07524 .62052 L
.07525 .61968 L
.07529 .61899 L
.07537 .61848 L
.07545 .6181 L
.07553 .61791 L
.07557 .61778 L
.07558 .61768 L
.07556 .61756 L
.0755 .61738 L
.07539 .61709 L
.07521 .61668 L
.07497 .61614 L
.07467 .61549 L
.0743 .61471 L
.07389 .61382 L
.07345 .61274 L
.07301 .61144 L
.07258 .60989 L
.07218 .60825 L
.07183 .60637 L
.07151 .60438 L
.07121 .60217 L
.07095 .60003 L
.0707 .59769 L
.07048 .59541 L
.07026 .59302 L
.07006 .59048 L
.06986 .58811 L
.06967 .58559 L
.06952 .58317 L
.06937 .58098 L
.06921 .57885 L
.06904 .57697 L
.06888 .57536 L
.06876 .57396 L
.06868 .57282 L
Mistroke
.06865 .57191 L
.06866 .57118 L
.06869 .57062 L
.06875 .57024 L
.0688 .57001 L
.06884 .56992 L
.06885 .56991 L
.06885 .56997 L
.06885 .57006 L
.06884 .57017 L
.06884 .57027 L
.06884 .57037 L
.06883 .57044 L
.06883 .57049 L
.06883 .57054 L
.06883 .57059 L
.06884 .57064 L
.06887 .57066 L
.06892 .57063 L
.06896 .57049 L
.06899 .57023 L
.069 .56984 L
.06896 .56931 L
.0689 .56865 L
.0688 .56786 L
.06867 .56693 L
.06851 .56583 L
.0683 .56458 L
.06806 .56317 L
.06777 .56149 L
.06745 .55983 L
.06712 .558 L
.06677 .55602 L
.06642 .55406 L
.06606 .55203 L
.06571 .54987 L
.06537 .54756 L
.06505 .54495 L
.06472 .54249 L
.06441 .53963 L
.06411 .53659 L
.06381 .5336 L
.06353 .53017 L
.06327 .52723 L
.06305 .52383 L
.06285 .52108 L
.06271 .51837 L
.06261 .51546 L
.06258 .51252 L
.06262 .50992 L
Mistroke
.06274 .50739 L
.06295 .5052 L
.06324 .50311 L
.06358 .5011 L
.06395 .49906 L
.0643 .49715 L
.06463 .49497 L
.06495 .49284 L
.06529 .49046 L
.06564 .48803 L
.06601 .48555 L
.06638 .48293 L
.06674 .48035 L
.06707 .47772 L
.06738 .47506 L
.06769 .47265 L
.068 .47025 L
.06833 .46811 L
.06868 .46629 L
.06908 .46466 L
.06953 .46326 L
.07001 .46219 L
.07048 .46135 L
.07092 .46069 L
.07132 .46021 L
.07168 .45984 L
.07202 .45955 L
.07235 .45929 L
.07269 .45903 L
.07305 .45875 L
.07344 .45843 L
.07378 .45807 L
.07411 .45767 L
.0744 .45724 L
.07464 .45683 L
.07482 .45643 L
.075 .4561 L
.07517 .45583 L
.07532 .45565 L
.07544 .45554 L
.0755 .45549 L
.0755 .45547 L
.07548 .45548 L
.07545 .45551 L
.07543 .45555 L
.07544 .45562 L
.07553 .4557 L
.07573 .45576 L
.07605 .45579 L
.07649 .45579 L
Mistroke
.07703 .45574 L
.07766 .45566 L
.07827 .45552 L
.07905 .45533 L
.07976 .4551 L
.08049 .45485 L
.08123 .45458 L
.08193 .45432 L
.08252 .45407 L
.083 .45382 L
.08338 .45358 L
.08367 .45335 L
.08385 .45316 L
.08396 .453 L
.08402 .45289 L
.08404 .45283 L
.08403 .45281 L
.08401 .45283 L
.08396 .45287 L
.08392 .45291 L
.0839 .45292 L
.08392 .45287 L
.08396 .4528 L
.08401 .45272 L
.08403 .45267 L
.08401 .45267 L
.08394 .45275 L
.08382 .45293 L
.08365 .45324 L
.08342 .45369 L
.08314 .45423 L
.08283 .4548 L
.08251 .45536 L
.0822 .45594 L
.08189 .45647 L
.08159 .457 L
.08128 .45754 L
.08087 .45804 L
.08067 .45848 L
.08054 .45887 L
.08048 .45913 L
.08047 .45935 L
.08052 .45947 L
.0806 .45951 L
.0807 .45956 L
.08078 .45964 L
.08084 .45977 L
.08088 .45993 L
.0809 .46008 L
.08091 .46022 L
Mistroke
.08091 .46032 L
.08091 .46039 L
.0809 .46039 L
.08089 .46036 L
.08088 .46031 L
.08088 .46027 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08089 .46025 L
.0809 .46027 L
.08093 .46032 L
.08097 .46039 L
.08101 .46046 L
.08103 .46048 L
.08102 .46042 L
.08096 .46028 L
.08086 .46007 L
.0807 .45985 L
.08047 .45962 L
.08019 .45939 L
.07987 .45917 L
.07953 .45895 L
.07918 .45872 L
.0789 .45848 L
.07864 .45824 L
.07843 .45803 L
.07832 .45784 L
.07834 .45764 L
.07853 .45742 L
.07891 .45717 L
.07948 .45679 L
.0802 .4562 L
.08107 .45532 L
.08207 .45414 L
.08311 .45267 L
Mistroke
.08418 .45088 L
.08526 .44879 L
.08624 .4468 L
.0872 .44452 L
.08798 .44247 L
.08866 .44033 L
.08923 .43816 L
.0897 .4359 L
.09007 .43398 L
.09034 .43211 L
.09051 .43029 L
.09062 .42853 L
.09068 .42679 L
.09072 .42489 L
.09075 .42281 L
.09079 .42033 L
.09086 .41779 L
.09095 .41494 L
.09104 .4119 L
.09112 .40855 L
.09118 .4054 L
.09122 .40222 L
.09125 .39912 L
.09127 .39658 L
.0913 .39412 L
.09134 .39209 L
.0914 .39051 L
.09146 .3893 L
.09151 .38848 L
.09153 .38795 L
.09148 .38762 L
.09133 .38741 L
.09108 .3872 L
.09075 .38687 L
.09034 .38632 L
.08987 .38545 L
.08937 .38437 L
.08884 .38303 L
.08832 .38141 L
.08782 .37969 L
.08737 .37784 L
.08697 .37603 L
.08664 .37426 L
.0864 .37263 L
.08626 .37104 L
.0862 .36986 L
.08618 .36885 L
.08622 .3679 L
.08627 .36727 L
.08635 .36672 L
Mistroke
.08644 .36634 L
.0865 .36616 L
.08654 .36613 L
.08654 .36618 L
.08654 .3663 L
.08653 .36644 L
.08653 .36655 L
.08653 .36661 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08652 .36664 L
.08651 .36667 L
.08647 .3667 L
.08643 .36674 L
.08639 .36676 L
.08637 .36675 L
.08638 .36669 L
.08644 .3666 L
.08656 .36646 L
.08672 .36628 L
.08693 .36606 L
.08718 .36583 L
.08745 .36558 L
.08774 .36533 L
.08803 .36509 L
.08832 .36488 L
.08858 .36472 L
.0888 .36463 L
.08898 .3646 L
.08911 .3646 L
.08922 .36463 L
.0893 .36463 L
.08938 .36456 L
.08947 .36436 L
.0896 .36402 L
.08977 .36349 L
.08999 .36274 L
Mistroke
.09025 .36177 L
.09053 .36062 L
.0908 .35918 L
.09109 .35737 L
.09138 .35537 L
.09168 .35296 L
.09198 .35023 L
.09229 .34736 L
.0926 .34402 L
.09293 .34079 L
.0933 .33742 L
.09371 .33395 L
.09418 .33059 L
.09471 .3271 L
.09532 .3237 L
.09602 .32074 L
.0968 .31775 L
.09763 .31487 L
.09849 .31238 L
.09939 .31006 L
.1003 .30813 L
.1012 .30644 L
.10208 .305 L
.10293 .30383 L
.1037 .30282 L
.10442 .30198 L
.10508 .30129 L
.10565 .30072 L
.10613 .30031 L
.10653 .30004 L
.10684 .29988 L
.10708 .29984 L
.10724 .29987 L
.10732 .29996 L
.10734 .30006 L
.10732 .30015 L
.10727 .30022 L
.10721 .30025 L
.10716 .30027 L
.10712 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
Mistroke
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.10708 .30027 L
.10705 .30027 L
.10701 .30027 L
.10697 .30027 L
.10694 .30027 L
.10696 .30027 L
.10702 .30027 L
.10713 .30027 L
.10729 .30027 L
.10749 .30028 L
.10773 .30028 L
.10799 .30028 L
Mistroke
.10827 .30028 L
.10855 .30029 L
.10883 .30029 L
.1091 .30029 L
.10935 .30029 L
.10957 .3003 L
.10974 .3003 L
.10986 .3003 L
.10993 .3003 L
.10995 .3003 L
.10994 .3003 L
.1099 .3003 L
.10985 .3003 L
.10981 .3003 L
.1098 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
Mistroke
.10979 .30033 L
.10979 .30039 L
.10979 .30046 L
.10979 .30054 L
.10976 .3006 L
.10971 .30063 L
.10964 .30059 L
.10956 .30047 L
.10949 .30023 L
.10945 .29986 L
.10945 .29939 L
.10954 .29881 L
.10973 .29815 L
.11006 .29745 L
.11053 .29669 L
.11116 .29586 L
.11193 .29497 L
.11277 .29404 L
.11375 .29311 L
.11476 .29212 L
.11585 .29108 L
.11699 .28995 L
.11825 .28869 L
.11955 .28721 L
.12111 .28547 L
.12275 .28342 L
.12469 .28088 L
.12704 .27799 L
.12951 .27426 L
.13208 .27057 L
.13546 .2664 L
.13861 .26126 L
.14241 .25636 L
.14653 .25012 L
.15015 .24498 L
.15445 .23871 L
.15871 .23196 L
.16333 .22448 L
.16726 .21816 L
.17143 .21047 L
.17565 .20346 L
.17961 .19648 L
.1839 .19002 L
.18761 .18368 L
.19152 .17658 L
.19579 .1714 L
.1991 .16549 L
.20302 .16086 L
.20631 .15589 L
.20933 .1523 L
Mistroke
.21238 .14891 L
.21506 .14595 L
.21742 .14337 L
.21943 .14149 L
.22112 .13993 L
.2224 .13881 L
.22337 .138 L
.2241 .13743 L
.22461 .13705 L
.22494 .13682 L
.22514 .13667 L
.22522 .13659 L
.22522 .13659 L
.22515 .13665 L
.22505 .13676 L
.22494 .13689 L
.22487 .13699 L
.22487 .13705 L
.22493 .13705 L
.22502 .137 L
.22509 .13693 L
.22508 .13687 L
.22497 .13683 L
.22473 .13685 L
.22436 .13694 L
.22385 .13711 L
.22323 .13736 L
.22252 .13769 L
.22176 .13808 L
.22102 .1385 L
.22025 .13896 L
.21946 .13941 L
.21875 .13986 L
.21809 .1403 L
.21753 .14071 L
.2171 .14107 L
.21682 .14136 L
.21667 .14156 L
.21663 .14168 L
.21668 .14172 L
.21678 .14169 L
.21687 .14162 L
.21693 .14155 L
.21696 .14149 L
.21695 .14146 L
.21691 .14145 L
.21687 .14145 L
.21685 .14145 L
.21686 .14145 L
.21692 .14145 L
Mistroke
.21702 .14146 L
.21718 .14146 L
.21737 .14147 L
.2176 .14148 L
.21785 .14149 L
.21812 .14149 L
.21838 .14151 L
.21863 .14154 L
.21884 .14161 L
.219 .14169 L
.21911 .14176 L
.21917 .14182 L
.21919 .14185 L
.2192 .14184 L
.21927 .14176 L
.21941 .14158 L
.21967 .1413 L
.22011 .14088 L
.2208 .14033 L
.22176 .13961 L
.22294 .13876 L
.22439 .13776 L
.22608 .13662 L
.22793 .13534 L
.23 .13402 L
.23199 .13266 L
.23405 .13141 L
.23591 .13023 L
.23763 .12917 L
.23913 .1283 L
.24025 .12764 L
.2411 .12718 L
.24166 .1269 L
.24193 .12678 L
.24196 .1268 L
.24178 .12693 L
.24149 .12674 L
.24117 .12688 L
.2409 .12702 L
.24073 .12716 L
.24074 .12726 L
.24099 .1273 L
.24151 .12725 L
.24226 .12702 L
.24321 .12668 L
.24433 .12622 L
.24561 .12565 L
.24713 .125 L
.24863 .12427 L
.2503 .12345 L
Mistroke
.25212 .12251 L
.25409 .12148 L
.2562 .12035 L
.25852 .11902 L
.26114 .11746 L
.26397 .11584 L
.26713 .11394 L
.27049 .1119 L
.27458 .10976 L
.27827 .10738 L
.28277 .105 L
.28723 .10242 L
.29205 .09969 L
.29758 .09688 L
.30239 .09378 L
.30736 .09138 L
.31205 .08861 L
.31672 .08593 L
.32146 .08324 L
.3258 .08116 L
.32932 .07904 L
.33345 .077 L
.3368 .07501 L
.34004 .07333 L
.34318 .07162 L
.34642 .06986 L
.34992 .06829 L
.35277 .06662 L
.35628 .06493 L
.35938 .06309 L
.36271 .06143 L
.36604 .05948 L
.36943 .05769 L
.37282 .05587 L
.37611 .054 L
.37883 .05249 L
.38147 .05105 L
.38369 .04973 L
.38548 .04865 L
.38693 .0478 L
.38797 .04712 L
.38869 .04666 L
.38913 .04638 L
.38935 .04624 L
.38943 .04619 L
.3894 .0462 L
.38932 .04625 L
.38922 .04632 L
.38913 .04639 L
.38904 .04647 L
Mistroke
.38899 .04653 L
.38894 .04655 L
.38889 .04656 L
.38884 .04655 L
.38879 .04655 L
.38872 .04655 L
.38867 .04655 L
.38863 .04655 L
.38864 .04655 L
.38871 .04655 L
.38885 .04655 L
.38909 .04656 L
.38942 .04657 L
.38986 .04659 L
.39041 .04661 L
.39104 .04663 L
.39178 .04666 L
.39258 .04669 L
.39343 .04672 L
.39429 .04675 L
.39513 .04678 L
.39592 .04681 L
.39663 .04684 L
.39723 .04686 L
.39772 .04688 L
.3981 .04689 L
.39838 .0469 L
.39857 .04691 L
.39868 .04691 L
.39874 .04692 L
.39875 .04692 L
.39873 .04691 L
.39868 .04691 L
.39863 .04691 L
.39858 .04691 L
.39855 .04691 L
.39854 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
Mistroke
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39851 .0469 L
.39846 .04688 L
.39839 .04682 L
.3983 .04674 L
.39821 .04667 L
.39813 .04663 L
.3981 .04663 L
.39817 .04668 L
.3984 .04681 L
.39886 .04702 L
.39938 .04736 L
.40006 .04782 L
.40092 .0484 L
.4018 .04909 L
.40278 .04986 L
.40385 .05069 L
.40489 .05156 L
.40608 .05245 L
.40698 .05332 L
.40783 .05411 L
.40867 .05477 L
.40947 .05533 L
.41022 .05577 L
.41089 .0561 L
.41156 .05631 L
.41234 .05644 L
.41335 .05654 L
.41469 .05663 L
.41623 .05678 L
.41827 .05704 L
.42031 .05743 L
.42298 .05798 L
.42593 .05868 L
.42914 .05954 L
Mistroke
.43211 .06051 L
.43532 .06158 L
.43892 .06266 L
.44172 .06375 L
.44473 .06487 L
.44795 .06601 L
.45056 .06695 L
.4532 .06783 L
.45563 .06846 L
.45785 .06896 L
.46 .06926 L
.46178 .06937 L
.46344 .0693 L
.46504 .06905 L
.46642 .06867 L
.46791 .06816 L
.46925 .06753 L
.47066 .06681 L
.47206 .06598 L
.47361 .06502 L
.47515 .06397 L
.47688 .06287 L
.47852 .06181 L
.48021 .06071 L
.48207 .0596 L
.4838 .05854 L
.48561 .05751 L
.48732 .05656 L
.4888 .05574 L
.49019 .05502 L
.4912 .05445 L
.49205 .05404 L
.49273 .05378 L
.49322 .05365 L
.49354 .05363 L
.49376 .05364 L
.49392 .05368 L
.49407 .05376 L
.49421 .05387 L
.49434 .05399 L
.49447 .05414 L
.49463 .05434 L
.49482 .05459 L
.49503 .05491 L
.4952 .05527 L
.49535 .05565 L
.49548 .05606 L
.4956 .05647 L
.49571 .05682 L
.49582 .05715 L
Mistroke
.49594 .05747 L
.49608 .05781 L
.49625 .05816 L
.49645 .05854 L
.49668 .05894 L
.49691 .0594 L
.49716 .05999 L
.49739 .06072 L
.49762 .06165 L
.49781 .06282 L
.49797 .06407 L
.49807 .06559 L
.49812 .06756 L
.49812 .06946 L
.49808 .07166 L
.49802 .07416 L
.49796 .07633 L
.49786 .0788 L
.49782 .08097 L
.4978 .08316 L
.49779 .08525 L
.49779 .08689 L
.49778 .08861 L
.49779 .08992 L
.49781 .09107 L
.49783 .092 L
.49786 .09268 L
.4979 .0931 L
.49794 .09333 L
.49797 .0934 L
.498 .09337 L
.49802 .09326 L
.49802 .0931 L
.49801 .09295 L
.498 .09286 L
.49799 .09282 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
Mistroke
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49798 .09281 L
.49797 .09277 L
.49794 .09269 L
.4979 .09257 L
.49785 .09243 L
.49779 .0923 L
.49773 .09221 L
.4977 .09217 L
.49769 .09224 L
.49775 .09243 L
.49788 .09283 L
.49813 .0935 L
.4985 .09449 L
.49901 .09585 L
.49966 .09755 L
.50048 .09964 L
.50149 .10233 L
.50265 .10516 L
.50401 .10838 L
.50553 .11208 L
.50718 .11538 L
.50894 .11891 L
.51077 .12261 L
.51262 .12552 L
.51449 .1286 L
.51634 .13127 L
.51827 .13379 L
.52009 .13572 L
.52206 .13747 L
.52412 .13902 L
.52629 .14037 L
.52863 .14159 L
.53118 .14264 L
.53395 .14372 L
.53707 .14475 L
.54032 .1457 L
.54399 .14663 L
.54861 .14741 L
Mistroke
.5526 .14803 L
.55748 .14846 L
.56286 .14863 L
.56901 .14855 L
.57443 .14819 L
.58115 .14756 L
.58794 .14669 L
.59459 .14559 L
.60107 .1443 L
.60908 .14286 L
.61609 .14131 L
.6217 .1398 L
.6289 .13821 L
.6347 .13659 L
.64076 .13493 L
.64627 .1331 L
.65133 .13113 L
.65578 .12915 L
.65949 .12693 L
.66312 .12462 L
.66633 .1222 L
.6692 .11962 L
.67186 .11685 L
.67403 .11448 L
.67606 .11189 L
.67794 .10927 L
.67961 .10695 L
.68122 .10466 L
.68275 .1027 L
.6842 .10094 L
.68565 .09955 L
.68703 .09845 L
.68843 .09765 L
.68985 .09711 L
.69128 .09681 L
.69278 .09668 L
.69438 .09668 L
.69605 .0968 L
.69786 .09702 L
.69968 .09733 L
.70153 .09771 L
.70351 .09812 L
.70555 .09858 L
.70767 .09903 L
.70987 .0995 L
.71212 .10001 L
.7144 .1006 L
.71675 .10127 L
.71917 .10204 L
.72154 .10291 L
Mistroke
.72405 .10388 L
.72643 .10492 L
.72894 .106 L
.73141 .10714 L
.73388 .10833 L
.73638 .10954 L
.73883 .11073 L
.74134 .11192 L
.74401 .11316 L
.74669 .11446 L
.74964 .11587 L
.75276 .11736 L
.75634 .11894 L
.75964 .12063 L
.76334 .12237 L
.76717 .12417 L
.77136 .12603 L
.7749 .12778 L
.77866 .12945 L
.78251 .1311 L
.78545 .13253 L
.78854 .13382 L
.79115 .13493 L
.79335 .13583 L
.79515 .13651 L
.79648 .13698 L
.79739 .13724 L
.798 .13734 L
.79834 .13732 L
.79848 .13721 L
.79847 .13709 L
.79839 .13698 L
.79829 .13692 L
.79819 .13687 L
.79809 .13684 L
.798 .13683 L
.79794 .13682 L
.79789 .13682 L
.79788 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
Mistroke
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79788 .1368 L
.79789 .13678 L
.79791 .13677 L
.79794 .13677 L
.79796 .13677 L
.79795 .13676 L
.79791 .13674 L
.79783 .13674 L
.79774 .13676 L
.79763 .13684 L
.79753 .13697 L
.79744 .13715 L
.79737 .13737 L
.79732 .13764 L
.79729 .13794 L
.79729 .1383 L
.7973 .13871 L
.79732 .13914 L
.79736 .13962 L
.79741 .14013 L
.79746 .14068 L
.79751 .14129 L
.79758 .14196 L
.79768 .14272 L
.7978 .14354 L
.79794 .14442 L
.7981 .14539 L
.7983 .14644 L
.79856 .14758 L
.7989 .14886 L
.79934 .15025 L
.79984 .15176 L
.80047 .15344 L
.80118 .15514 L
.80201 .15697 L
.80299 .15896 L
Mistroke
.8041 .161 L
.80538 .16321 L
.80683 .16559 L
.8085 .16809 L
.8104 .17076 L
.81246 .17351 L
.81472 .17642 L
.81729 .1794 L
.81982 .18248 L
.82278 .18539 L
.8255 .18828 L
.82846 .1911 L
.83121 .19361 L
.83417 .19605 L
.83683 .19831 L
.83899 .20027 L
.84105 .2021 L
.8429 .20373 L
.84445 .20519 L
.84567 .20651 L
.8466 .20769 L
.84725 .20869 L
.84767 .20961 L
.84786 .21049 L
.84781 .21138 L
.84751 .21231 L
.84702 .21328 L
.84638 .21438 L
.84549 .21571 L
.84437 .21732 L
.84303 .21929 L
.84163 .22147 L
.83999 .22419 L
.83827 .22736 L
.83653 .23097 L
.83472 .23521 L
.83298 .23974 L
.83133 .24484 L
.82983 .25024 L
.82862 .25598 L
.82771 .26221 L
.82716 .26827 L
.82697 .27465 L
.82717 .28154 L
.82773 .28781 L
.82863 .29457 L
.82988 .30121 L
.83144 .30814 L
.83337 .31538 L
.83564 .32231 L
Mistroke
.83813 .32983 L
.84083 .33789 L
.84352 .34594 L
.84634 .35452 L
.84921 .36291 L
.85164 .37212 L
.85391 .38034 L
.85576 .3893 L
.85713 .39812 L
.8579 .40674 L
.85804 .41507 L
.85763 .42349 L
.85655 .4315 L
.85475 .43868 L
.85243 .44588 L
.8495 .45269 L
.84598 .4593 L
.84243 .46555 L
.83859 .47168 L
.83469 .47778 L
.83098 .48385 L
.82762 .49003 L
.82468 .49601 L
.82209 .50244 L
.82015 .50839 L
.81859 .51481 L
.81745 .52179 L
.81684 .52849 L
.81657 .53562 L
.81666 .5433 L
.81699 .55118 L
.8175 .55967 L
.81805 .56895 L
.81858 .5779 L
.819 .58809 L
.81924 .59707 L
.81921 .60717 L
.81885 .61829 L
.81818 .6285 L
.81718 .63865 L
.81588 .64891 L
.81429 .65941 L
.81252 .66983 L
.81049 .6797 L
.80828 .68976 L
.80591 .70079 L
.80333 .71006 L
.8006 .72056 L
.79778 .73074 L
.79511 .74172 L
Mistroke
.79251 .7514 L
.79011 .76204 L
.78792 .77205 L
.7862 .782 L
.785 .79119 L
.78439 .79977 L
.78445 .8079 L
.78514 .8143 L
.7864 .82015 L
.78816 .82503 L
.79036 .82871 L
.79291 .83143 L
.79559 .83325 L
.79831 .83423 L
.80094 .8345 L
.80327 .8342 L
.80532 .83352 L
.80696 .8326 L
.80812 .83165 L
.80881 .83085 L
.80902 .83034 L
.80876 .83016 L
.80806 .83039 L
.80691 .83108 L
.80523 .83222 L
.80311 .83381 L
.80043 .83583 L
.79716 .83816 L
.79328 .84086 L
.78867 .84382 L
.78346 .84698 L
.7778 .85022 L
.77115 .85348 L
.76435 .85656 L
.75677 .85948 L
.74857 .86215 L
.73981 .86456 L
.73174 .86673 L
.72288 .8687 L
.71405 .87055 L
.7055 .8724 L
.69717 .87446 L
.68882 .87683 L
.6807 .87963 L
.67336 .88296 L
.66562 .88658 L
.65879 .8909 L
.65202 .89534 L
.64596 .9001 L
.64 .90524 L
Mistroke
.63519 .91002 L
.63026 .91478 L
.6259 .91913 L
.62128 .92344 L
.61715 .92706 L
.6128 .9302 L
.60836 .93268 L
.60371 .93451 L
.59865 .93579 L
.59278 .93663 L
.58728 .93713 L
.58053 .93743 L
.57287 .93763 L
.56463 .93781 L
.5554 .938 L
.54568 .93816 L
.53603 .93829 L
.52567 .9384 L
.51518 .9385 L
.50449 .93863 L
.49468 .93882 L
.4842 .93905 L
.47468 .9393 L
.46513 .93955 L
.45615 .93974 L
.44756 .93982 L
.43923 .93972 L
.43163 .93938 L
.42425 .93878 L
.41699 .9379 L
.40979 .93675 L
.40229 .93536 L
.39543 .93377 L
.38823 .9319 L
.38054 .92975 L
.37328 .92731 L
.36563 .92462 L
.35756 .92164 L
.34997 .91861 L
.34207 .91539 L
.33402 .91204 L
.32566 .90863 L
.31766 .90509 L
.30947 .90151 L
.30132 .89784 L
.29295 .89409 L
.28534 .89031 L
.27738 .88658 L
.27009 .88296 L
.26319 .87959 L
Mistroke
.25689 .87653 L
.25073 .8738 L
.24607 .87156 L
.2418 .86973 L
.23812 .86833 L
.23545 .86735 L
.23345 .86673 L
.23209 .86641 L
.23134 .8663 L
.23103 .86629 L
.23091 .8663 L
.23082 .86624 L
.23056 .86597 L
.23003 .86542 L
.2291 .8645 L
.22766 .86315 L
.2257 .86132 L
.22312 .85892 L
.21986 .85591 L
.21591 .85232 L
.21135 .84826 L
.20637 .8436 L
.20067 .83846 L
.19482 .83289 L
.18839 .82667 L
.18191 .82021 L
.17516 .81344 L
.16796 .80609 L
.16078 .79879 L
.1539 .79142 L
.14668 .78387 L
.13947 .77618 L
.13243 .76925 L
.12595 .76211 L
.11976 .75518 L
.1142 .74927 L
.10929 .74351 L
.10489 .73835 L
.10111 .73375 L
.09785 .72961 L
.09541 .7263 L
.09351 .7235 L
.09211 .7212 L
.09112 .71927 L
.09045 .7176 L
.08999 .71602 L
.08965 .7144 L
.08932 .71264 L
.08898 .71069 L
.08861 .70829 L
Mistroke
.08815 .70537 L
.08753 .70183 L
.08672 .69761 L
.08577 .69266 L
.08473 .68698 L
.08359 .68072 L
.08239 .67392 L
.08115 .66704 L
.0799 .66011 L
.07874 .65284 L
.07759 .64487 L
.07646 .63743 L
.07535 .63062 L
.07423 .62282 L
.07309 .61506 L
.072 .60843 L
.07091 .60063 L
.06986 .59389 L
.06883 .58673 L
.06785 .57889 L
.06695 .57226 L
.06608 .56497 L
.0652 .55765 L
.06435 .54987 L
.06355 .54291 L
.06287 .53562 L
.06237 .52747 L
.06209 .52111 L
.06207 .51428 L
.06233 .50747 L
.06281 .50076 L
.06346 .49464 L
.06428 .48877 L
.06515 .48351 L
.06603 .47872 L
.06688 .47442 L
.06769 .47048 L
.06841 .46707 L
.06904 .46428 L
.06956 .46189 L
.06995 .45998 L
.07021 .4585 L
.07032 .45746 L
.07034 .4568 L
.07032 .45643 L
.07027 .45618 L
.07022 .456 L
.07017 .45586 L
.07014 .45572 L
.07012 .45556 L
Mistroke
.07013 .45541 L
.07013 .45531 L
.07013 .45529 L
.07013 .45533 L
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .45557 L
.07014 .45555 L
.07018 .45549 L
.07022 .45541 L
.07027 .45533 L
.07029 .4553 L
.07027 .45532 L
.07021 .45543 L
.07009 .45563 L
.06992 .45593 L
.0697 .45633 L
.06944 .45682 L
.06915 .45738 L
.06885 .45797 L
.06855 .45851 L
.06824 .459 L
Mistroke
.06794 .45938 L
.06764 .45965 L
.06738 .45975 L
.06716 .4597 L
.06703 .45949 L
.06698 .45914 L
.06704 .45867 L
.06719 .45813 L
.06741 .45755 L
.06768 .45697 L
.06797 .45645 L
.06827 .45602 L
.06857 .4557 L
.06887 .45547 L
.06916 .45534 L
.06943 .4553 L
.06968 .45533 L
.0699 .4554 L
.07007 .45548 L
.0702 .45554 L
.07026 .45557 L
.07029 .45558 L
.07027 .45558 L
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.0701 .45558 L
.07007 .45558 L
.07003 .45558 L
.06999 .45558 L
.06996 .45558 L
.06998 .45558 L
.07004 .45558 L
.07015 .45558 L
.07031 .45558 L
.07052 .45557 L
.07076 .45557 L
.07103 .45557 L
.07131 .45556 L
.0716 .45556 L
.07188 .45555 L
.07214 .45555 L
.07236 .45555 L
.07253 .45554 L
.07267 .45554 L
.07276 .45554 L
.07282 .45554 L
.07284 .45556 L
.07283 .45558 L
.07283 .45562 L
.0729 .45566 L
.07307 .45568 L
.07338 .45566 L
.07384 .4556 L
.07444 .4555 L
.07518 .45538 L
.07604 .45524 L
.07701 .4551 L
.07807 .45495 L
.07915 .45479 L
.08036 .4546 L
.08151 .45435 L
.08267 .45403 L
.08382 .45364 L
.08492 .45316 L
.0859 .45256 L
Mistroke
.08678 .45181 L
.0875 .45088 L
.08808 .44976 L
.08856 .44842 L
.08896 .44682 L
.08933 .44494 L
.08971 .44272 L
.0901 .44017 L
.0905 .4372 L
.09085 .4339 L
.09111 .43003 L
.09126 .42579 L
.09128 .42085 L
.09119 .41553 L
.091 .40961 L
.09076 .40307 L
.09048 .39732 L
.09017 .39109 L
.08984 .38457 L
.0895 .37907 L
.08919 .37334 L
.08889 .36833 L
.08864 .36447 L
.08845 .36094 L
.08864 .3589 L
.08858 .35672 L
.08865 .3552 L
.08881 .35444 L
.08899 .35407 L
.08918 .35366 L
.0894 .35312 L
.08961 .35241 L
.08977 .35143 L
.08991 .34997 L
.09008 .34806 L
.0903 .34579 L
.09058 .34329 L
.09091 .34045 L
.0913 .33743 L
.09172 .33433 L
.09216 .33153 L
.09263 .32878 L
.0931 .32613 L
.09359 .32365 L
.09411 .32151 L
.09469 .31942 L
.09531 .31752 L
.096 .31565 L
.09677 .31378 L
.09762 .31209 L
Mistroke
.09846 .31039 L
.09938 .30876 L
.1003 .30733 L
.10111 .3059 L
.10194 .30467 L
.10261 .3035 L
.10322 .30244 L
.10375 .30153 L
.10418 .30083 L
.10448 .30034 L
.10466 .30004 L
.10472 .2999 L
.10471 .29987 L
.10465 .29991 L
.10457 .29999 L
.10449 .30006 L
.10443 .30011 L
.10441 .30016 L
.1044 .3002 L
.1044 .30023 L
.1044 .30024 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30024 L
.10439 .30023 L
.10435 .3002 L
.10431 .30016 L
.10427 .30013 L
.10425 .30011 L
.10427 .30012 L
.10433 .30017 L
.10443 .30027 L
.10459 .30041 L
.10479 .30059 L
.10502 .3008 L
.10528 .30104 L
.10556 .30129 L
.10583 .30153 L
.1061 .30178 L
Mistroke
.10636 .30202 L
.10661 .30225 L
.10682 .30244 L
.10699 .30259 L
.10711 .3027 L
.10718 .30276 L
.1072 .30278 L
.10719 .30276 L
.10715 .30273 L
.1071 .30268 L
.10707 .30265 L
.10705 .30264 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30264 L
.10706 .30265 L
.10707 .30266 L
.10707 .30269 L
.10707 .30272 L
.10706 .30274 L
.10702 .30278 L
.10696 .30282 L
.10687 .30287 L
.10676 .30291 L
.10665 .30291 L
.10657 .30282 L
.10655 .3026 L
.10663 .30223 L
.10686 .30167 L
.10719 .3009 L
.1077 .29995 L
.10837 .2988 L
.1092 .29747 L
.11007 .29606 L
.11111 .29447 L
.11215 .29278 L
.11331 .29102 L
.11432 .2893 L
.11532 .28757 L
.11628 .28593 L
.11704 .28446 L
.11766 .28312 L
.11814 .28195 L
.11851 .281 L
.11874 .28022 L
Mistroke
.11883 .27964 L
.11879 .27924 L
.11864 .27902 L
.11837 .27898 L
.11801 .27911 L
.11756 .27936 L
.11703 .27972 L
.11648 .28017 L
.11591 .28069 L
.11537 .28129 L
.11485 .28195 L
.11432 .28264 L
.11381 .28336 L
.11333 .28409 L
.11296 .28482 L
.1127 .28551 L
.11255 .28613 L
.11249 .28666 L
.11251 .28712 L
.11259 .2875 L
.11269 .2878 L
.11279 .28801 L
.11285 .28816 L
.11289 .28826 L
.11291 .28833 L
.1129 .2884 L
.11284 .28853 L
.11273 .28874 L
.11255 .28907 L
.11232 .28955 L
.11203 .29012 L
.11168 .29078 L
.11128 .29157 L
.11081 .2925 L
.11025 .29366 L
.10956 .29511 L
.10869 .29703 L
.10774 .2991 L
.10663 .30164 L
.10529 .30495 L
.10393 .3083 L
.10224 .31317 L
.10061 .3184 L
.0988 .32331 L
.09649 .33056 L
.09457 .33652 L
.09243 .34444 L
.09024 .35237 L
.08801 .35862 L
.08611 .36586 L
Mistroke
.08436 .37259 L
.08278 .37957 L
.08163 .38423 L
.08068 .38928 L
.07991 .39332 L
.07941 .39619 L
.07907 .39853 L
.07892 .40027 L
.07895 .40124 L
.07909 .40163 L
.07931 .40165 L
.07957 .40147 L
.0798 .40115 L
.07999 .40077 L
.08011 .40045 L
.08018 .40026 L
.0802 .40014 L
.08019 .40009 L
.08017 .40006 L
.08019 .40002 L
.08023 .39998 L
.08026 .39997 L
.08024 .39998 L
.08019 .40003 L
.08008 .40013 L
.07991 .40027 L
.07967 .40046 L
.0794 .40067 L
.0791 .40091 L
.07882 .40116 L
.07852 .40141 L
.07826 .40167 L
.078 .40191 L
.07775 .40213 L
.07749 .40233 L
.07729 .40248 L
.07716 .40259 L
.07711 .40265 L
.07711 .40267 L
.07715 .40265 L
.07722 .40261 L
.07729 .40257 L
.07734 .40254 L
.07734 .40252 L
.07733 .40252 L
.07731 .40252 L
.0773 .40252 L
.07728 .40252 L
.07725 .40252 L
.0772 .40252 L
Mistroke
.07715 .40252 L
.0771 .40252 L
.07708 .40252 L
.07711 .40252 L
.07721 .40252 L
.07739 .40252 L
.07765 .40252 L
.078 .40252 L
.07843 .40251 L
.07892 .40251 L
.07941 .40251 L
.07995 .4025 L
.08049 .4025 L
.08104 .4025 L
.08152 .40249 L
.08196 .40249 L
.08234 .40249 L
.08263 .40248 L
.08283 .40248 L
.08295 .40248 L
.08299 .40248 L
.08297 .40248 L
.08292 .40248 L
.08287 .40248 L
.08282 .40248 L
.08278 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40249 L
.08278 .4025 L
.08281 .40253 L
.08285 .40257 L
Mistroke
.08289 .4026 L
.08291 .40262 L
.08289 .40261 L
.08284 .40256 L
.08273 .40246 L
.08257 .40232 L
.08237 .40214 L
.08214 .40193 L
.08188 .4017 L
.0816 .40145 L
.08133 .4012 L
.08106 .40095 L
.08079 .40071 L
.08055 .40049 L
.08033 .4003 L
.08016 .40015 L
.08004 .40004 L
.07997 .39998 L
.07995 .39996 L
.07997 .39998 L
.08001 .40002 L
.08005 .40006 L
.08009 .40009 L
.0801 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
Mistroke
.08011 .40009 L
.08012 .40006 L
.08016 .40002 L
.08021 .39998 L
.08024 .39997 L
.08024 .39998 L
.08021 .40003 L
.08012 .40013 L
.07998 .40027 L
.07977 .40046 L
.07952 .40067 L
.07925 .40091 L
.07897 .40116 L
.07867 .40141 L
.0784 .40167 L
.07816 .40191 L
.07788 .40213 L
.07762 .40233 L
.07741 .40248 L
.07727 .40259 L
.07718 .40265 L
.07714 .40267 L
.07712 .40265 L
.07711 .40261 L
.07713 .40257 L
.07716 .40254 L
.07718 .40253 L
.07723 .40252 L
.07733 .40252 L
.07749 .40252 L
.0777 .40252 L
.07794 .40252 L
.07821 .40252 L
.07849 .40253 L
.07877 .40256 L
.07905 .40259 L
.07932 .40263 L
.07957 .40264 L
.07979 .40263 L
.07997 .40258 L
.0801 .40248 L
.08017 .40234 L
.0802 .40216 L
.08019 .40194 L
.08016 .40171 L
.08012 .40146 L
.08009 .40121 L
.08008 .40096 L
.08009 .40072 L
.08009 .4005 L
Mistroke
.0801 .4003 L
.0801 .40015 L
.08011 .40004 L
.08011 .39998 L
.08011 .39996 L
.08011 .39998 L
.08011 .40001 L
.08011 .40006 L
.08011 .40009 L
.08011 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08006 .40006 L
.08002 .40002 L
.07998 .39999 L
.07996 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08073 .40066 L
.08099 .40089 L
.08126 .40114 L
.08153 .40139 L
.08181 .40164 L
.08207 .40188 L
Mistroke
.08232 .4021 L
.08253 .40229 L
.0827 .40244 L
.08282 .40255 L
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08286 .40257 L
.08281 .40253 L
.08276 .4025 L
.08271 .40249 L
.08267 .40248 L
.08263 .40248 L
.08261 .40248 L
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08315 .40248 L
.0834 .40248 L
.08366 .40248 L
.08395 .40247 L
.08422 .40247 L
.0845 .40247 L
.08478 .40247 L
.08503 .40247 L
.08525 .40247 L
.08543 .40246 L
.08555 .40246 L
.08562 .40246 L
.08564 .40246 L
.08562 .40246 L
.08558 .40246 L
.08554 .40246 L
.0855 .40246 L
.08549 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
Mistroke
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40247 L
.08548 .40248 L
.08548 .40251 L
.08548 .40255 L
.08548 .40258 L
.08548 .4026 L
.08548 .40259 L
.08548 .40254 L
.08548 .40244 L
.08549 .4023 L
.08549 .40212 L
.0855 .40191 L
.08551 .40167 L
.08551 .40142 L
Mistroke
.08552 .40117 L
.08553 .40092 L
.08554 .40068 L
.08554 .40046 L
.08555 .40027 L
.08555 .40011 L
.08556 .40001 L
.08556 .39994 L
.08556 .39993 L
.08556 .39994 L
.08556 .39998 L
.08556 .40002 L
.08556 .40005 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08555 .40007 L
.08554 .40007 L
.08551 .4001 L
.08547 .40016 L
.08542 .40023 L
.0854 .4003 L
.08542 .40034 L
.08548 .40031 L
.08559 .40021 L
.08573 .40002 L
.08592 .39973 L
.08613 .39937 L
.08636 .39894 L
Mistroke
.08658 .39847 L
.0868 .39798 L
.08703 .39748 L
.08728 .39699 L
.08756 .39651 L
.08787 .39606 L
.08816 .39567 L
.08847 .39536 L
.08878 .39514 L
.08908 .39502 L
.08937 .39495 L
.08966 .39493 L
.08994 .39492 L
.09021 .39493 L
.09048 .39495 L
.09073 .395 L
.09094 .39511 L
.09109 .3953 L
.09117 .39558 L
.09119 .39594 L
.09118 .39637 L
.09115 .39684 L
.09109 .39733 L
.09102 .39783 L
.09097 .39832 L
.09094 .3988 L
.09093 .39924 L
.09093 .39963 L
.09094 .39993 L
.09095 .40014 L
.09097 .40023 L
.09099 .40023 L
.091 .40016 L
.09101 .40007 L
.09102 .4 L
.09101 .39998 L
.09099 .40002 L
.09095 .40009 L
.0909 .40019 L
.09085 .40031 L
.09083 .40046 L
.09082 .40067 L
.09083 .40096 L
.09089 .40138 L
.091 .40193 L
.09116 .40261 L
.0914 .40341 L
.0917 .40431 L
.09207 .40527 L
.09249 .40621 L
Mistroke
.09297 .40711 L
.09349 .40789 L
.09405 .40859 L
.09461 .4092 L
.0951 .40977 L
.09552 .4103 L
.09583 .4108 L
.09602 .41134 L
.09606 .41196 L
.09596 .41275 L
.09573 .41388 L
.09538 .41551 L
.09487 .41762 L
.09424 .41977 L
.09332 .4226 L
.09235 .42586 L
.09119 .42985 L
.0898 .43395 L
.08815 .43882 L
.08616 .44319 L
.08438 .44803 L
.08216 .4534 L
.08027 .45821 L
.07848 .46222 L
.07624 .46665 L
.07429 .47079 L
.07202 .47506 L
.07019 .47851 L
.06863 .482 L
.06718 .48497 L
.0659 .48769 L
.06487 .49005 L
.06419 .49183 L
.06369 .49343 L
.06337 .49463 L
.06316 .49555 L
.06305 .4962 L
.06302 .49663 L
.06302 .49689 L
.06302 .49703 L
.06304 .49711 L
.06307 .49716 L
.06311 .49725 L
.06315 .49746 L
.06317 .49789 L
.06314 .49863 L
.06307 .49974 L
.06298 .5012 L
.06287 .503 L
.06275 .50518 L
Mistroke
.06264 .50768 L
.06256 .51045 L
.0625 .51357 L
.06249 .51656 L
.06252 .51988 L
.06262 .5236 L
.06282 .52705 L
.06313 .53102 L
.06353 .53525 L
.06405 .53957 L
.06466 .54467 L
.06534 .54936 L
.06604 .55429 L
.06675 .55978 L
.06746 .56491 L
.06812 .57054 L
.06879 .57622 L
.0694 .5812 L
.07 .58664 L
.07058 .592 L
.07114 .59702 L
.07166 .60173 L
.07213 .60609 L
.07251 .61016 L
.07288 .61386 L
.07324 .6174 L
.07363 .6204 L
.07404 .62311 L
.0745 .62574 L
.07499 .62825 L
.0755 .63049 L
.076 .63291 L
.07647 .63522 L
.0769 .63774 L
.07733 .64061 L
.07777 .64391 L
.07825 .64706 L
.07875 .65074 L
.0793 .6549 L
.07992 .65957 L
.0806 .6645 L
.08131 .66977 L
.08205 .675 L
.08283 .68011 L
.08365 .68519 L
.08442 .69023 L
.08524 .69433 L
.08601 .69797 L
.08675 .70123 L
.08745 .70387 L
Mistroke
.08803 .7059 L
.08851 .70749 L
.08888 .70862 L
.08914 .70934 L
.08929 .70973 L
.08935 .70987 L
.08935 .70982 L
.0893 .70966 L
.08924 .70947 L
.08918 .70929 L
.08913 .70912 L
.0891 .70898 L
.08908 .70892 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08906 .7089 L
.08903 .70891 L
.08898 .70891 L
.08894 .70891 L
.0889 .70891 L
.08887 .70891 L
.08886 .70891 L
.08889 .70891 L
.089 .70891 L
.0892 .7089 L
.08952 .70889 L
.08995 .70887 L
.09049 .70885 L
.09112 .70883 L
.09183 .7088 L
.0926 .70877 L
.09339 .70874 L
.09413 .70871 L
.0949 .70868 L
.09555 .70865 L
.09614 .70863 L
.09662 .70861 L
.09698 .7086 L
.09721 .70859 L
.09733 .70858 L
.09737 .70858 L
.09736 .70858 L
.09733 .70859 L
Mistroke
.09732 .70859 L
.09736 .70858 L
.09749 .70858 L
.09772 .70857 L
.09805 .70856 L
.09844 .70854 L
.09888 .70853 L
.09936 .70851 L
.09987 .70848 L
.10037 .70845 L
.10083 .7084 L
.10125 .70834 L
.10161 .70829 L
.10193 .70826 L
.10222 .70826 L
.10248 .70831 L
.10271 .70842 L
.10293 .70859 L
.10313 .70881 L
.10333 .70906 L
.10353 .70932 L
.10374 .70956 L
.10399 .70976 L
.10429 .70991 L
.10465 .71 L
.10506 .71002 L
.10549 .70999 L
.1059 .70988 L
.1063 .70972 L
.10666 .70951 L
.10697 .70926 L
.10724 .70898 L
.10748 .7087 L
.10769 .70844 L
.10788 .70824 L
.10803 .70811 L
.10815 .70803 L
.10821 .70801 L
.10823 .70803 L
.10821 .70807 L
.10817 .70811 L
.10813 .70815 L
.10809 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
Mistroke
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10805 .7082 L
.10802 .70827 L
.10797 .70836 L
.10792 .70846 L
.10786 .70858 L
.1078 .70866 L
.10777 .70868 L
.10779 .70859 L
.10787 .70839 L
.10802 .70806 L
.1083 .70757 L
.10873 .70691 L
.10934 .70606 L
.1101 .705 L
.11102 .70367 L
.11214 .70205 L
.11344 .70012 L
.11472 .69787 L
.11605 .69539 L
.11749 .69252 L
.11885 .68945 L
.12045 .68586 L
.12175 .68213 L
.12303 .67772 L
.12433 .67331 L
.12563 .66839 L
.12695 .66321 L
.12816 .65756 L
.12944 .65168 L
.13074 .6459 L
.13197 .63981 L
.13327 .63271 L
Mistroke
.13451 .62663 L
.13577 .61996 L
.13698 .61372 L
.13813 .60762 L
.13916 .60051 L
.14001 .59536 L
.14073 .58968 L
.1413 .58417 L
.14174 .57947 L
.14206 .57492 L
.14227 .57067 L
.1424 .56696 L
.14249 .56351 L
.14253 .56035 L
.14255 .55803 L
.14256 .55587 L
.14259 .55409 L
.14262 .55254 L
.14267 .55124 L
.14273 .5502 L
.1428 .5493 L
.14287 .5485 L
.14295 .54771 L
.14302 .54689 L
.14308 .546 L
.14313 .54506 L
.14315 .54387 L
.14312 .54242 L
.14301 .54071 L
.14282 .53878 L
.1425 .53654 L
.14204 .53393 L
.14148 .53126 L
.14081 .52812 L
.14006 .52521 L
.13925 .52186 L
.13846 .51863 L
.13766 .51517 L
.13694 .51189 L
.13629 .50855 L
.1357 .50522 L
.13521 .50213 L
.1348 .49914 L
.13446 .49632 L
.13422 .49355 L
.13402 .4911 L
.13384 .48866 L
.13367 .48628 L
.13348 .48406 L
.13327 .48183 L
Mistroke
.13302 .47971 L
.13274 .47762 L
.13241 .47562 L
.13201 .47359 L
.13153 .47174 L
.13096 .46979 L
.13033 .46803 L
.1296 .46625 L
.12871 .46459 L
.12767 .46296 L
.12648 .46138 L
.12531 .45998 L
.1239 .45857 L
.12216 .45718 L
.12057 .45586 L
.1188 .45453 L
.11694 .4532 L
.11492 .45185 L
.11275 .4505 L
.1107 .44925 L
.10888 .4481 L
.10711 .44705 L
.10523 .44613 L
.10348 .44533 L
.10178 .44465 L
.10029 .44405 L
.09909 .44357 L
.09811 .44323 L
.09723 .44302 L
.09641 .44293 L
.09566 .44294 L
.09502 .44299 L
.09439 .44304 L
.09372 .44307 L
.09302 .44307 L
.09234 .443 L
.09171 .44286 L
.09117 .44265 L
.09051 .44243 L
.08973 .44219 L
.08895 .44195 L
.08828 .4417 L
.08772 .44147 L
.08727 .44125 L
.08696 .44106 L
.08676 .44091 L
.08668 .4408 L
.08668 .44073 L
.08671 .44068 L
.08674 .44066 L
Mistroke
.08675 .44066 L
.08678 .44068 L
.08683 .44072 L
.0869 .44079 L
.08701 .4409 L
.08716 .44107 L
.08735 .44129 L
.08757 .44154 L
.0878 .4418 L
.08803 .44205 L
.08826 .44227 L
.08851 .44249 L
.08877 .4427 L
.08904 .44286 L
.08931 .44295 L
.08956 .44293 L
.08978 .44279 L
.08998 .44248 L
.09021 .44199 L
.09048 .44132 L
.09083 .44049 L
.0913 .43947 L
.09194 .43827 L
.09277 .43698 L
.09386 .43547 L
.09517 .43365 L
.09676 .4318 L
.09866 .42965 L
.10056 .42734 L
.1028 .42485 L
.1052 .4222 L
.10773 .41923 L
.11044 .41658 L
.11318 .41377 L
.11583 .41092 L
.11844 .40795 L
.12089 .40481 L
.12312 .40191 L
.12533 .39891 L
.12743 .396 L
.12949 .393 L
.13134 .39023 L
.13332 .38731 L
.13525 .38437 L
.13735 .38123 L
.13963 .37829 L
.14178 .3751 L
.14392 .37189 L
.14611 .3684 L
.14847 .36518 L
Mistroke
.15082 .36172 L
.15309 .35807 L
.15519 .35471 L
.15705 .35083 L
.15865 .34726 L
.15997 .34336 L
.16093 .3396 L
.16161 .33578 L
.16198 .33169 L
.16211 .32777 L
.16213 .32372 L
.16208 .3194 L
.162 .31499 L
.16191 .31056 L
.16184 .30602 L
.1618 .3016 L
.16181 .29707 L
.16191 .29214 L
.16208 .2879 L
.16231 .28362 L
.16254 .27997 L
.16275 .27593 L
.16289 .27255 L
.16293 .2691 L
.1628 .26634 L
.1625 .26365 L
.16203 .26146 L
.16139 .25933 L
.16059 .25753 L
.15967 .25579 L
.1587 .25419 L
.15767 .25266 L
.15661 .25121 L
.1556 .24999 L
.15463 .24885 L
.15369 .24782 L
.1528 .24692 L
.15206 .24616 L
.15147 .24551 L
.15104 .24495 L
.1508 .24449 L
.15072 .24414 L
.15075 .24392 L
.15081 .24385 L
.15086 .2439 L
.15083 .24408 L
.15069 .24435 L
.15042 .2447 L
.15005 .24511 L
.14959 .24555 L
Mistroke
.14906 .24601 L
.14851 .24648 L
.14796 .24695 L
.14743 .24742 L
.1469 .24787 L
.1464 .2483 L
.14596 .24867 L
.1456 .24897 L
.14536 .24918 L
.14522 .24929 L
.14518 .24933 L
.14521 .24933 L
.14527 .24931 L
.14533 .24931 L
.14535 .24932 L
.14534 .24935 L
.14532 .24935 L
.14533 .24928 L
.14539 .24913 L
.1455 .24888 L
.14566 .24853 L
.14586 .24809 L
.14609 .2476 L
.14632 .24706 L
.14656 .24647 L
.14681 .24584 L
.14707 .24516 L
.14737 .24445 L
.14768 .24369 L
.14802 .24291 L
.14836 .2421 L
.14869 .24125 L
.14901 .24039 L
.14931 .23952 L
.14958 .2387 L
.14982 .23788 L
.15004 .23705 L
.15023 .23624 L
.15039 .23552 L
.15051 .23496 L
.15058 .23445 L
.15062 .23395 L
.15067 .23349 L
.15076 .233 L
.15094 .23247 L
.15126 .23183 L
.15174 .23098 L
.15241 .22996 L
.15332 .22866 L
.15434 .22707 L
Mistroke
.15562 .22528 L
.15705 .22345 L
.15865 .22123 L
.16043 .2187 L
.16234 .21598 L
.16414 .21314 L
.16617 .21035 L
.16805 .20748 L
.16991 .20458 L
.17191 .20182 L
.17382 .19914 L
.17545 .19637 L
.17709 .19399 L
.17882 .19161 L
.18039 .18927 L
.18193 .18726 L
.18336 .18525 L
.1847 .18347 L
.18592 .18174 L
.18712 .18013 L
.18827 .17847 L
.1895 .17686 L
.19069 .17524 L
.19198 .17351 L
.19337 .17185 L
.19466 .17009 L
.19601 .16834 L
.19743 .1665 L
.19878 .16485 L
.20018 .16302 L
.20157 .16149 L
.2028 .15994 L
.20401 .15843 L
.20517 .15704 L
.20618 .15571 L
.20708 .15452 L
.20786 .15343 L
.20852 .1524 L
.20913 .15143 L
.20972 .15053 L
.21029 .14974 L
.21085 .14898 L
.2114 .14827 L
.21194 .14763 L
.21245 .14711 L
.21291 .14667 L
.21331 .14633 L
.21365 .14608 L
.21394 .14591 L
.21416 .14581 L
Mistroke
.21433 .14578 L
.21446 .1458 L
.21453 .14584 L
.21456 .14589 L
.21456 .14593 L
.21454 .14596 L
.2145 .14599 L
.21446 .14601 L
.21442 .14601 L
.21441 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.21441 .14601 L
.21442 .14598 L
.21445 .14591 L
.21449 .14581 L
.21453 .14571 L
.21455 .14567 L
.21454 .1457 L
Mistroke
.21448 .14584 L
.21438 .1461 L
.21422 .14651 L
.21402 .14704 L
.21379 .14766 L
.21354 .14834 L
.21327 .14905 L
.213 .14977 L
.21272 .15048 L
.21245 .1512 L
.21218 .15189 L
.21193 .1525 L
.21172 .15295 L
.21158 .15321 L
.21153 .15324 L
.21156 .15307 L
.21166 .15275 L
.21181 .15231 L
.212 .15178 L
.21221 .1512 L
.21242 .15057 L
.21267 .14991 L
.21294 .14918 L
.21326 .1484 L
.21361 .1476 L
.21402 .14679 L
.21448 .14599 L
.215 .14519 L
.21558 .14439 L
.21622 .1436 L
.21695 .14284 L
.21778 .14208 L
.2187 .14129 L
.21973 .14047 L
.2209 .13963 L
.22213 .13882 L
.22349 .138 L
.22486 .13717 L
.22634 .13633 L
.22779 .1355 L
.22913 .13469 L
.23048 .13392 L
.23173 .13323 L
.23288 .13265 L
.23392 .13217 L
.23481 .13173 L
.23562 .13132 L
.23631 .13094 L
.23696 .13056 L
.23755 .13022 L
Mistroke
.2381 .1299 L
.23862 .12959 L
.23917 .12926 L
.23974 .12887 L
.2404 .12842 L
.24119 .12789 L
.24209 .12722 L
.24313 .12643 L
.24432 .12554 L
.24562 .12459 L
.2471 .12365 L
.24863 .12263 L
.25038 .12161 L
.25209 .12061 L
.25403 .11957 L
.25609 .11844 L
.25825 .11726 L
.26071 .11609 L
.26283 .11489 L
.26552 .11372 L
.26772 .11257 L
.26998 .11143 L
.27239 .11036 L
.2748 .10933 L
.27729 .10825 L
.27963 .10706 L
.28204 .10591 L
.28447 .10467 L
.28693 .1033 L
.2894 .10188 L
.29191 .10028 L
.2945 .09884 L
.29719 .0973 L
.29988 .09567 L
.30268 .09402 L
.3052 .09254 L
.30809 .09105 L
.31069 .0894 L
.31355 .08786 L
.31622 .0863 L
.31894 .08478 L
.32161 .08349 L
.32419 .08217 L
.32693 .0809 L
.32907 .07977 L
.33157 .07863 L
.33347 .07757 L
.33544 .0765 L
.33735 .07546 L
.33931 .07449 L
Mistroke
.34092 .07363 L
.34254 .07281 L
.34426 .07198 L
.34602 .07111 L
.34784 .07017 L
.34996 .06919 L
.35213 .06808 L
.35475 .06682 L
.35702 .06547 L
.35974 .06397 L
.36273 .0625 L
.36556 .06094 L
.36859 .05933 L
.37159 .05786 L
.3746 .05642 L
.3772 .05513 L
.37968 .05396 L
.38193 .05298 L
.38378 .05221 L
.38538 .0516 L
.3867 .05117 L
.38768 .0509 L
.38844 .05076 L
.38897 .05075 L
.38929 .05079 L
.38944 .05087 L
.38946 .05097 L
.3894 .05104 L
.38929 .05105 L
.38916 .05095 L
.38905 .05072 L
.38897 .0504 L
.38892 .05 L
.3889 .04954 L
.38889 .04902 L
.38889 .04844 L
.38889 .04797 L
.38889 .0475 L
.38889 .04709 L
.38889 .04679 L
.38889 .04666 L
.38888 .04675 L
.38885 .04706 L
.38881 .04754 L
.38877 .0481 L
.38875 .04866 L
.38876 .04916 L
.38881 .0496 L
.38889 .04995 L
.38898 .05015 L
Mistroke
.38909 .05019 L
.38922 .05009 L
.38937 .04985 L
.38958 .0495 L
.38986 .04908 L
.39022 .04862 L
.39068 .04811 L
.39125 .04759 L
.39192 .04714 L
.39268 .04683 L
.39351 .04665 L
.39433 .04656 L
.39517 .04654 L
.39599 .04659 L
.39678 .04668 L
.39752 .04678 L
.39824 .04687 L
.39899 .04692 L
.39972 .04695 L
.40047 .04698 L
.40124 .04701 L
.40204 .04704 L
.4029 .04707 L
.40384 .0471 L
.40495 .04714 L
.4062 .04719 L
.40771 .04724 L
.40931 .0473 L
.41118 .04736 L
.41318 .04743 L
.41537 .04751 L
.4178 .04759 L
.42019 .04768 L
.42275 .04777 L
.42543 .04786 L
.4281 .04797 L
.43084 .04808 L
.43367 .0482 L
.43629 .04831 L
.439 .0484 L
.44163 .04847 L
.4443 .04853 L
.4465 .04857 L
.44866 .04857 L
.4507 .04852 L
.45264 .04843 L
.45451 .04832 L
.4563 .04821 L
.45811 .04811 L
.45985 .04801 L
Mistroke
.46167 .04793 L
.46351 .04786 L
.46538 .04783 L
.46734 .04784 L
.46924 .0479 L
.4712 .04799 L
.47314 .04812 L
.47504 .04828 L
.47702 .04847 L
.47891 .04867 L
.48087 .04888 L
.48274 .04906 L
.48455 .04925 L
.48626 .04942 L
.48783 .04958 L
.48914 .04973 L
.49029 .04984 L
.49143 .04995 L
.49241 .05004 L
.49339 .0501 L
.49438 .05012 L
.49541 .05007 L
.49651 .04996 L
.49774 .0498 L
.49915 .0496 L
.50076 .0494 L
.50243 .04921 L
.50413 .04904 L
.50633 .0489 L
.50843 .04881 L
.51093 .04877 L
.51357 .0488 L
.51626 .04889 L
.51873 .04904 L
.5211 .04926 L
.52332 .04952 L
.52523 .0498 L
.52696 .05009 L
.52845 .0504 L
.52972 .05064 L
.53078 .05085 L
.53162 .05101 L
.53224 .05112 L
.53267 .05118 L
.53293 .0512 L
.53307 .05121 L
.53312 .0512 L
.53313 .05119 L
.53309 .05118 L
.53304 .05117 L
Mistroke
.53297 .05117 L
.5329 .05115 L
.53284 .05115 L
.53281 .05114 L
.5328 .05115 L
.53283 .05116 L
.5329 .05119 L
.533 .05122 L
.5331 .05126 L
.53316 .05128 L
.53313 .05126 L
.533 .05121 L
.53274 .05112 L
.53235 .05098 L
.53185 .05079 L
.53126 .05058 L
.53065 .05034 L
.53003 .0501 L
.52938 .04985 L
.52872 .04961 L
.52801 .04936 L
.52725 .04914 L
.52649 .04893 L
.52575 .04877 L
.52507 .04865 L
.52445 .04858 L
.52393 .04854 L
.5235 .04853 L
.52319 .04853 L
.52293 .04853 L
.52264 .04851 L
.5223 .0485 L
.52191 .0485 L
.52149 .04854 L
.52102 .04861 L
.5205 .04873 L
.51994 .04888 L
.51934 .04906 L
.51873 .04927 L
.5181 .04948 L
.51748 .04969 L
.51687 .04991 L
.51627 .05013 L
.51571 .05034 L
.51521 .05054 L
.51478 .05071 L
.51441 .05081 L
.51409 .05085 L
.5138 .05081 L
.51352 .0507 L
Mistroke
.51324 .05053 L
.5129 .05031 L
.51242 .05006 L
.5118 .04978 L
.51101 .04948 L
.51001 .04919 L
.50889 .04892 L
.50761 .04867 L
.50611 .04847 L
.50435 .04833 L
.50232 .04826 L
.50038 .04827 L
.49794 .04836 L
.49549 .04849 L
.4926 .04864 L
.48962 .04877 L
.48671 .04887 L
.48339 .04891 L
.48038 .04889 L
.47734 .0488 L
.47425 .04867 L
.47176 .04848 L
.46936 .04826 L
.46721 .04801 L
.46538 .04773 L
.4638 .04745 L
.46256 .0472 L
.46163 .04698 L
.46094 .04683 L
.46046 .04672 L
.46014 .04666 L
.45995 .04664 L
.45986 .04664 L
.45986 .04667 L
.45993 .0467 L
.46006 .04674 L
.46024 .04676 L
.46045 .04676 L
.46068 .04677 L
.46095 .04678 L
.46127 .04679 L
.46166 .0468 L
.46213 .04682 L
.4627 .04682 L
.46338 .04682 L
.46419 .04681 L
.46514 .04681 L
.46624 .04682 L
.46747 .04688 L
.46889 .04697 L
Mistroke
.47046 .04711 L
.47221 .0473 L
.47417 .04753 L
.47623 .0478 L
.4785 .0481 L
.48083 .04844 L
.48323 .04878 L
.48559 .04912 L
.48788 .04942 L
.48995 .04969 L
.49187 .04988 L
.49339 .04997 L
.49467 .04995 L
.49568 .04982 L
.49636 .04962 L
.49674 .04937 L
.49683 .04912 L
.4967 .0489 L
.49644 .04872 L
.49614 .0486 L
.4959 .04855 L
.4958 .04857 L
.49595 .04865 L
.49639 .04879 L
.49716 .04899 L
.49822 .04923 L
.49964 .0495 L
.50135 .0498 L
.50342 .05008 L
.50597 .05033 L
.50852 .05052 L
.51152 .05067 L
.51479 .05078 L
.51853 .05086 L
.52186 .05093 L
.52556 .051 L
.52955 .05107 L
.53321 .05116 L
.53708 .05126 L
.54116 .05137 L
.54513 .05147 L
.5487 .05157 L
.5523 .05167 L
.55606 .05177 L
.56029 .05186 L
.56352 .05195 L
.56696 .05204 L
.57049 .05213 L
.57383 .05221 L
.57678 .05228 L
Mistroke
.57969 .05233 L
.58249 .05235 L
.58463 .05238 L
.58689 .05243 L
.58874 .05253 L
.59023 .05265 L
.59155 .05278 L
.59263 .05289 L
.59341 .05299 L
.59392 .05308 L
.59419 .05319 L
.59429 .05334 L
.59431 .05356 L
.59431 .05382 L
.59437 .05413 L
.59452 .05447 L
.59477 .05483 L
.59513 .05519 L
.59557 .05554 L
.59608 .05582 L
.59667 .05612 L
.59728 .0564 L
.59802 .05667 L
.5989 .05693 L
.59977 .05717 L
.60071 .05737 L
.60169 .05751 L
.60267 .05757 L
.60356 .05756 L
.6044 .05751 L
.60514 .05746 L
.6058 .05743 L
.60639 .05741 L
.60692 .05738 L
.60738 .05734 L
.60778 .0573 L
.60809 .05728 L
.6083 .05729 L
.60838 .05735 L
.60834 .05746 L
.60821 .05764 L
.60802 .0579 L
.6078 .05822 L
.60758 .05859 L
.60739 .059 L
.60724 .05943 L
.60714 .05985 L
.60707 .0603 L
.60703 .06069 L
.60702 .06107 L
Mistroke
.60706 .06141 L
.60714 .06168 L
.60729 .06187 L
.6075 .06198 L
.60777 .06202 L
.60808 .06202 L
.6084 .062 L
.60871 .06197 L
.609 .06194 L
.60927 .06193 L
.6095 .06192 L
.60971 .06191 L
.60991 .06191 L
.61009 .06191 L
.61025 .06192 L
.61039 .06192 L
.61049 .06192 L
.61055 .06193 L
.61056 .06193 L
.61055 .06193 L
.61051 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
Mistroke
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61045 .06193 L
.61047 .06195 L
.61051 .06196 L
.61054 .06196 L
.61056 .06197 L
.61055 .06199 L
.6105 .06202 L
.61041 .06203 L
.61027 .06199 L
.6101 .06187 L
.6099 .06166 L
.60968 .0614 L
.60944 .06111 L
.60921 .0608 L
.60898 .06058 L
.60875 .0604 L
.60854 .06027 L
.60836 .06021 L
.60821 .0602 L
.60811 .06023 L
.60805 .06032 L
.60804 .06043 L
.60808 .06061 L
.60816 .06085 L
.60827 .06112 L
.60836 .0614 L
.60841 .06166 L
Mistroke
.60839 .06186 L
.60829 .06201 L
.60811 .06208 L
.60785 .06206 L
.6075 .06199 L
.6071 .06192 L
.60665 .06187 L
.60617 .06187 L
.60569 .0619 L
.60522 .06193 L
.60478 .0619 L
.60437 .06183 L
.60404 .06173 L
.60379 .0616 L
.60365 .06146 L
.6036 .06132 L
.60363 .0612 L
.60371 .06111 L
.60381 .06106 L
.60391 .06103 L
.60397 .06103 L
.604 .06104 L
.604 .06104 L
.60398 .06108 L
.60395 .06117 L
.60391 .06131 L
.60388 .06149 L
.60385 .06171 L
.60382 .0619 L
.60378 .06204 L
.60373 .06209 L
.60365 .06202 L
.60354 .06183 L
.60339 .06152 L
.6032 .06115 L
.60299 .06073 L
.60278 .06028 L
.6026 .05983 L
.60245 .05937 L
.60235 .05893 L
.6023 .05849 L
.60229 .05808 L
.60233 .05772 L
.60241 .05744 L
.60254 .05724 L
.60271 .05713 L
.60292 .05711 L
.60315 .05716 L
.60337 .05728 L
.60355 .05742 L
Mistroke
.60368 .05754 L
.60376 .0576 L
.60377 .05758 L
.60376 .05749 L
.60372 .05732 L
.60369 .05705 L
.60366 .05672 L
.60364 .05632 L
.60364 .05589 L
.60364 .05543 L
.60364 .05495 L
.60363 .05445 L
.60363 .05396 L
.60363 .05349 L
.60363 .0531 L
.60363 .05284 L
.60363 .05273 L
.60363 .05279 L
.60363 .05302 L
.60363 .05337 L
.60363 .05382 L
.60363 .05432 L
.60364 .05483 L
.60364 .05531 L
.60364 .05577 L
.60364 .0562 L
.60364 .05661 L
.60364 .05697 L
.60364 .05726 L
.60364 .05746 L
.60364 .05758 L
.60364 .05761 L
.60364 .05759 L
.60364 .05753 L
.60364 .05745 L
.60364 .0574 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
Mistroke
.60364 .05737 L
.60364 .05737 L
.60366 .05737 L
.60371 .05737 L
.6038 .05737 L
.6039 .05737 L
.60395 .05737 L
.60393 .05737 L
.60382 .05737 L
.6036 .05736 L
.60324 .05735 L
.60274 .05734 L
.60214 .05733 L
.6015 .05731 L
.60089 .0573 L
.60034 .05728 L
.59979 .05727 L
.59917 .05725 L
.59848 .05723 L
.59778 .05722 L
.5971 .0572 L
.59648 .05719 L
.59591 .05718 L
.59538 .05717 L
.59492 .05716 L
.59454 .05715 L
.59423 .05714 L
.59385 .05713 L
.59342 .05714 L
.59303 .05718 L
.59271 .05724 L
.59248 .0573 L
.59232 .05733 L
.59222 .05731 L
.59215 .05722 L
.59209 .05704 L
.59202 .05675 L
.59193 .05636 L
.59177 .05595 L
.59156 .05558 L
.59132 .05525 L
.59109 .05495 L
.59085 .05468 L
.59062 .05444 L
.59041 .05421 L
.59023 .05397 L
.59008 .05372 L
.58996 .05347 L
.58988 .05328 L
.58983 .0532 L
Mistroke
.58981 .05323 L
.58983 .05336 L
.58988 .05353 L
.58997 .05371 L
.5901 .05392 L
.59026 .05418 L
.59045 .05449 L
.59066 .05483 L
.59086 .05514 L
.59104 .05546 L
.59118 .05578 L
.59128 .05601 L
.59132 .05605 L
.59131 .05588 L
.59125 .05561 L
.59118 .05531 L
.59109 .05503 L
.591 .05472 L
.59088 .05442 L
.59076 .05418 L
.59064 .05401 L
.59055 .05393 L
.59049 .05391 L
.59047 .05393 L
.59046 .05397 L
.59048 .05401 L
.59049 .05405 L
.59051 .05405 L
.5905 .05396 L
.59045 .05378 L
.59038 .0535 L
.59028 .05326 L
.59017 .05303 L
.59008 .05291 L
.59001 .05293 L
.58996 .05309 L
.58995 .05337 L
.58997 .0537 L
.59 .054 L
.59002 .05423 L
.59003 .05437 L
.59004 .05446 L
.59004 .05448 L
.59004 .05446 L
.59004 .05437 L
.59004 .05423 L
.59004 .054 L
.59003 .05371 L
.59003 .05339 L
.59003 .05307 L
Mistroke
.59003 .05279 L
.59003 .05259 L
.59003 .05247 L
.59003 .05243 L
.59003 .05245 L
.59003 .05249 L
.59003 .05256 L
.59003 .0526 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59002 .05261 L
.59001 .0526 L
.59 .05258 L
.59 .05255 L
.59 .05252 L
.59 .05249 L
.59 .05248 L
.59001 .05253 L
.59005 .05267 L
.59013 .05289 L
.59023 .05317 L
.59035 .05348 L
.59047 .05379 L
.59058 .05407 L
.59067 .05425 L
.59074 .05438 L
.59077 .05445 L
.59078 .05446 L
.59076 .05443 L
.59073 .05434 L
.59068 .05421 L
.59059 .05398 L
.59049 .0537 L
.59038 .0534 L
.59027 .05309 L
.59016 .05283 L
.59007 .05262 L
.59 .0525 L
.58995 .05245 L
.58994 .05248 L
.58996 .05256 L
.58999 .05263 L
.59002 .05269 L
.59003 .05271 L
.59003 .05272 L
.59003 .05272 L
.59003 .05271 L
.59003 .05271 L
Mistroke
.59003 .0527 L
.59003 .05268 L
.59003 .05267 L
.59003 .05265 L
.59003 .05263 L
.59003 .05262 L
.59003 .05261 L
.59003 .05261 L
.59003 .05262 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59004 .05262 L
.59005 .0526 L
.59008 .05255 L
.59011 .05248 L
.59015 .05242 L
.59016 .05239 L
.59015 .05241 L
.5901 .05251 L
.59001 .05269 L
.58986 .05295 L
.58966 .05329 L
.58943 .05371 L
.58919 .0542 L
.58894 .05473 L
.58871 .05523 L
.5885 .05571 L
.58833 .05612 L
.58821 .05644 L
.58816 .05663 L
.58818 .05666 L
.58827 .05651 L
.58842 .05619 L
.58863 .05574 L
.58888 .05522 L
.58917 .05471 L
.58945 .05424 L
Mistroke
.58969 .05381 L
.58987 .05345 L
.58996 .05319 L
.58999 .05302 L
.58996 .05294 L
.58988 .05292 L
.58979 .05294 L
.58969 .053 L
.5896 .05307 L
.58954 .05315 L
.5895 .05319 L
.58948 .05321 L
.58948 .05314 L
.58949 .05302 L
.58953 .05286 L
.58959 .05269 L
.58968 .05257 L
.58978 .05252 L
.58989 .05257 L
.58998 .05274 L
.59006 .05305 L
.59011 .0534 L
.59012 .05382 L
.59011 .05427 L
.59007 .05472 L
.59005 .05514 L
.59004 .05557 L
.59004 .05599 L
.59004 .05637 L
.59004 .05669 L
.59004 .05696 L
.59004 .05715 L
.59004 .05726 L
.59004 .05729 L
.59004 .05726 L
.59004 .05719 L
.59004 .05712 L
.59004 .05707 L
.59004 .05704 L
.59005 .05704 L
.59011 .05704 L
.59022 .05704 L
.59034 .05703 L
.59044 .05702 L
.59048 .057 L
.59043 .05699 L
.59027 .05701 L
.58992 .05704 L
.58938 .05708 L
.58861 .05713 L
Mistroke
.58763 .05718 L
.58646 .05721 L
.5852 .05723 L
.58413 .05724 L
.58291 .05722 L
.58146 .0572 L
.58035 .05716 L
.57926 .05714 L
.57827 .0571 L
.57759 .05705 L
.57714 .05698 L
.57689 .05691 L
.57683 .05684 L
.57694 .05678 L
.57718 .05673 L
.57747 .05669 L
.57778 .05668 L
.57809 .05669 L
.57836 .05672 L
.57856 .05675 L
.5787 .05676 L
.57878 .05677 L
.5788 .05677 L
.57879 .05677 L
.57875 .05676 L
.57872 .05676 L
.57868 .05676 L
.57867 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57867 .05676 L
.57868 .05674 L
.57871 .0567 L
.57874 .05664 L
.57878 .05658 L
.57879 .05656 L
.57878 .05663 L
.57873 .05677 L
Mistroke
.57864 .05698 L
.57851 .05723 L
.57833 .0575 L
.57813 .05775 L
.57791 .05799 L
.57767 .0582 L
.57744 .05836 L
.5772 .05846 L
.57697 .05849 L
.57676 .05842 L
.57658 .05827 L
.57643 .05797 L
.57634 .05754 L
.57631 .05698 L
.57633 .05635 L
.57638 .05567 L
.57643 .05499 L
.57645 .05434 L
.57643 .05374 L
.57636 .0532 L
.57622 .05271 L
.57605 .05225 L
.57585 .05181 L
.57562 .05141 L
.57539 .05106 L
.57515 .05079 L
.57491 .05058 L
.57469 .05041 L
.57447 .05028 L
.57429 .05015 L
.57414 .05004 L
.57404 .04995 L
.57398 .04987 L
.57396 .0498 L
.57398 .04971 L
.57401 .04965 L
.57405 .04963 L
.57408 .04968 L
.57409 .0498 L
.5741 .05001 L
.5741 .05032 L
.5741 .05074 L
.5741 .05126 L
.5741 .05188 L
.5741 .0526 L
.57413 .0534 L
.5742 .05422 L
.57431 .05509 L
.57441 .05603 L
.57445 .05698 L
Mistroke
.57442 .0579 L
.57428 .0587 L
.57402 .05934 L
.57362 .05988 L
.5731 .0603 L
.57248 .06063 L
.57181 .06087 L
.57111 .06105 L
.57043 .06116 L
.56977 .06121 L
.56911 .06121 L
.56847 .06115 L
.5679 .06108 L
.56745 .06102 L
.56717 .06102 L
.56703 .06106 L
.56701 .06113 L
.56706 .06118 L
.56714 .0612 L
.56721 .06116 L
.5672 .06103 L
.5671 .06079 L
.56693 .06043 L
.56673 .05994 L
.5665 .05934 L
.56626 .05863 L
.56602 .05791 L
.56578 .05713 L
.56553 .05628 L
.56529 .05537 L
.56507 .05443 L
.56489 .05359 L
.56477 .05279 L
.56472 .05206 L
.56476 .05145 L
.56486 .05099 L
.56503 .05071 L
.56524 .05061 L
.56548 .05066 L
.56572 .05086 L
.56596 .0512 L
.56619 .05164 L
.56643 .05217 L
.56666 .05277 L
.56688 .0534 L
.56706 .05403 L
.56721 .05462 L
.56731 .0552 L
.56737 .05573 L
.56739 .05616 L
Mistroke
.56737 .05646 L
.56734 .05665 L
.56734 .05674 L
.5674 .05676 L
.5675 .05673 L
.56759 .05667 L
.56765 .0566 L
.56765 .05653 L
.56756 .05649 L
.56732 .05648 L
.56692 .05647 L
.56635 .05646 L
.56562 .05644 L
.56475 .05642 L
.56376 .0564 L
.56276 .05637 L
.56171 .05635 L
.56065 .05632 L
.55962 .05629 L
.55869 .05627 L
.55793 .05625 L
.55725 .05623 L
.55664 .05621 L
.55609 .0562 L
.55559 .05619 L
.5551 .05617 L
.55458 .05616 L
.55404 .05615 L
.55347 .05613 L
.5529 .05612 L
.5523 .0561 L
.55167 .05609 L
.55093 .05607 L
.55011 .05605 L
.54927 .05603 L
.54845 .05601 L
.5477 .05599 L
.54703 .05597 L
.54647 .05596 L
.54602 .05595 L
.54564 .05594 L
.54529 .05592 L
.54496 .05589 L
.54466 .05584 L
.54444 .05576 L
.54429 .05569 L
.54423 .05566 L
.54423 .05568 L
.54429 .05578 L
.54436 .05595 L
Mistroke
.54439 .05622 L
.54432 .05655 L
.54412 .05694 L
.54377 .05737 L
.54328 .05781 L
.54265 .05824 L
.54191 .05867 L
.54107 .05908 L
.54019 .05947 L
.53934 .05981 L
.53856 .06005 L
.53786 .0602 L
.53718 .06026 L
.53655 .06027 L
.53602 .06024 L
.53558 .06021 L
.53522 .06022 L
.5349 .06029 L
.53454 .06042 L
.53408 .06061 L
.53349 .06081 L
.53274 .06102 L
.53182 .06123 L
.53069 .06143 L
.52938 .06162 L
.52794 .0618 L
.52647 .06194 L
.52502 .06204 L
.52348 .0621 L
.52183 .06212 L
.52039 .0621 L
.51899 .06205 L
.51766 .06198 L
.51645 .06192 L
.5154 .06186 L
.51455 .06182 L
.51381 .0618 L
.51319 .06178 L
.51267 .06177 L
.51224 .06176 L
.51191 .06175 L
.5117 .06174 L
.5116 .06174 L
.51158 .06174 L
.51163 .06174 L
.51174 .06174 L
.51185 .06175 L
.51192 .06175 L
.51195 .06175 L
.51195 .06175 L
Mistroke
.51195 .06175 L
.51196 .06175 L
.51198 .06173 L
.51204 .06168 L
.51214 .06162 L
.51224 .06155 L
.51234 .06151 L
.51242 .06152 L
.51246 .06161 L
.51237 .06178 L
.5121 .06203 L
.51166 .06234 L
.51104 .0627 L
.51021 .06313 L
.50915 .06362 L
.50801 .06414 L
.50673 .06461 L
.5054 .06503 L
.50395 .06539 L
.50235 .0657 L
.50075 .06583 L
.49925 .06583 L
.49771 .06567 L
.49608 .06535 L
.49437 .06487 L
.49264 .06426 L
.4911 .06354 L
.48932 .06278 L
.48738 .06194 L
.48558 .06102 L
.48368 .05999 L
.4816 .05893 L
.47962 .0578 L
.47747 .05662 L
.47546 .05553 L
.47378 .05449 L
.47223 .05349 L
.47086 .05253 L
.46976 .05166 L
.4689 .05091 L
.46822 .05027 L
.46774 .04975 L
.46745 .04935 L
.46732 .04905 L
.46734 .04885 L
.46747 .04873 L
.46767 .04871 L
.4679 .04876 L
.46809 .04888 L
.46816 .04906 L
Mistroke
.46804 .04932 L
.46768 .04965 L
.46703 .05007 L
.46603 .05059 L
.46462 .0512 L
.46302 .05188 L
.46081 .05259 L
.45839 .05333 L
.45524 .05408 L
.45194 .05482 L
.44819 .05549 L
.44495 .05607 L
.44049 .05657 L
.43687 .05695 L
.43217 .0572 L
.42873 .05729 L
.42451 .05723 L
.42126 .05702 L
.41756 .05669 L
.41487 .05629 L
.41208 .05583 L
.40948 .05531 L
.40748 .05474 L
.40562 .05412 L
.40408 .05349 L
.40271 .0528 L
.40152 .05207 L
.40048 .05131 L
.39957 .05055 L
.39887 .04984 L
.39819 .04919 L
.39758 .04866 L
.39704 .04819 L
.3966 .04778 L
.39626 .04742 L
.39607 .04711 L
.39606 .04686 L
.39624 .04669 L
.39661 .04661 L
.39715 .04661 L
.39779 .04666 L
.39851 .04676 L
.39925 .04686 L
.39999 .04695 L
.40071 .04702 L
.4014 .04709 L
.40202 .04715 L
.40254 .04718 L
.40294 .04718 L
.40321 .04715 L
Mistroke
.40334 .04706 L
.40333 .04692 L
.40321 .04675 L
.40301 .04654 L
.40275 .04631 L
.40245 .04606 L
.40215 .04582 L
.40185 .04557 L
.40158 .04533 L
.40133 .04511 L
.40112 .0449 L
.40094 .04472 L
.4008 .04458 L
.40072 .04446 L
.40071 .04437 L
.40077 .04433 L
.4009 .04435 L
.40106 .04443 L
.40126 .04456 L
.40147 .04478 L
.40166 .04511 L
.40178 .04558 L
.40182 .04619 L
.40176 .0469 L
.4016 .04774 L
.40132 .0487 L
.40096 .0497 L
.40049 .05068 L
.39995 .05168 L
.39935 .05265 L
.39874 .05357 L
.39813 .05431 L
.39752 .05493 L
.39694 .05541 L
.39644 .05574 L
.39605 .05595 L
.39582 .05608 L
.39573 .05617 L
.39576 .05623 L
.3959 .05628 L
.39611 .05632 L
.39636 .05636 L
.39664 .05641 L
.39691 .05646 L
.39717 .05652 L
.39742 .05656 L
.39767 .05658 L
.39792 .05657 L
.39814 .05653 L
.39833 .05645 L
Mistroke
.39849 .05635 L
.3986 .05625 L
.39866 .05615 L
.39867 .05608 L
.39864 .05607 L
.39857 .05612 L
.39848 .05624 L
.39837 .05643 L
.39828 .05668 L
.39822 .05695 L
.39823 .0572 L
.39832 .05743 L
.39852 .05765 L
.39883 .05784 L
.39924 .05801 L
.39976 .05815 L
.40036 .05825 L
.40101 .05832 L
.40175 .05837 L
.40253 .05841 L
.40338 .05844 L
.40418 .05847 L
.40495 .0585 L
.40566 .05851 L
.40628 .05852 L
.40679 .05849 L
.40719 .05841 L
.40751 .05828 L
.40778 .05811 L
.40802 .05791 L
.40827 .0577 L
.40853 .05748 L
.4088 .05725 L
.40908 .05699 L
.40934 .0567 L
.40957 .0564 L
.40979 .05612 L
.40999 .05588 L
.41017 .05564 L
.41035 .05546 L
.41048 .05525 L
.41056 .05502 L
.41058 .05475 L
.41055 .05446 L
.41048 .05413 L
.41042 .05377 L
.4104 .05343 L
.41044 .05314 L
.41056 .05294 L
.41076 .05275 L
Mistroke
.41101 .0526 L
.41131 .05247 L
.41166 .05233 L
.41206 .05214 L
.41255 .05189 L
.41313 .05156 L
.41382 .0512 L
.41458 .05082 L
.41542 .05044 L
.4163 .05006 L
.4172 .04966 L
.41804 .04924 L
.41887 .04882 L
.41961 .04842 L
.42033 .04808 L
.42094 .04781 L
.4215 .04762 L
.42198 .04753 L
.42236 .0475 L
.42263 .04754 L
.42277 .04761 L
.42279 .04768 L
.42272 .04773 L
.42261 .04776 L
.42251 .04776 L
.42245 .04775 L
.42245 .04775 L
.42253 .04776 L
.42267 .04776 L
.42286 .04776 L
.42311 .04776 L
.42338 .04776 L
.42367 .04776 L
.42393 .04776 L
.42417 .04773 L
.42436 .0477 L
.42449 .04768 L
.42454 .04769 L
.42451 .04776 L
.42441 .0479 L
.42423 .04812 L
.424 .0484 L
.42374 .04878 L
.42345 .04915 L
.42317 .04959 L
.42291 .05001 L
.42271 .05041 L
.42255 .05079 L
.42244 .05112 L
.42238 .05137 L
Mistroke
.42236 .05155 L
.42237 .05163 L
.42241 .05165 L
.42245 .05162 L
.42248 .05161 L
.4225 .05151 L
.4225 .05146 L
.4225 .05145 L
.4225 .0515 L
.4225 .05162 L
.4225 .05172 L
.4225 .05178 L
.4225 .05183 L
.42248 .05183 L
.42246 .05174 L
.42242 .05154 L
.42238 .05125 L
.42236 .05088 L
.42238 .05043 L
.42243 .04995 L
.42254 .04946 L
.42271 .04895 L
.42293 .04844 L
.42318 .04799 L
.42344 .04766 L
.42367 .04748 L
.42387 .04746 L
.42402 .04761 L
.42412 .0479 L
.42416 .0483 L
.42414 .04877 L
.42406 .04926 L
.42392 .04976 L
.42373 .05022 L
.4235 .05068 L
.42325 .05111 L
.42299 .05153 L
.42275 .05189 L
.42257 .05218 L
.42244 .05238 L
.42238 .0525 L
.42236 .05253 L
.42238 .05251 L
.42241 .05244 L
.42247 .05239 L
.42252 .05239 L
.42258 .05243 L
.42262 .0525 L
.42264 .05253 L
.42263 .05251 L
Mistroke
.42258 .05241 L
.42248 .05223 L
.42235 .05196 L
.42218 .05162 L
.422 .0512 L
.42181 .05074 L
.42159 .05027 L
.42136 .04981 L
.4211 .04935 L
.4208 .04888 L
.42048 .04845 L
.42015 .04807 L
.41981 .04777 L
.41949 .04756 L
.41919 .04743 L
.41892 .04738 L
.41868 .0474 L
.41847 .04746 L
.41827 .04753 L
.41808 .04759 L
.41791 .04761 L
.41776 .0476 L
.41766 .0476 L
.4176 .04759 L
.41758 .04759 L
.4176 .04758 L
.41765 .04758 L
.41772 .04757 L
.41778 .04757 L
.41783 .04757 L
.41785 .04757 L
.41783 .04758 L
.41775 .0476 L
.41762 .04762 L
.41744 .04765 L
.41725 .04768 L
.41705 .0477 L
.41688 .04772 L
.41674 .04774 L
.41663 .04775 L
.41657 .04776 L
.41654 .04776 L
.41656 .04775 L
.41661 .04774 L
.41669 .04773 L
.41683 .04771 L
.417 .04768 L
.4172 .04765 L
.4174 .04762 L
.41759 .04759 L
Mistroke
.41774 .04758 L
.41783 .04757 L
.41786 .04757 L
.41783 .04757 L
.41776 .04758 L
.41769 .04759 L
.41762 .0476 L
.41759 .04763 L
.4176 .04766 L
.41765 .0477 L
.41775 .04772 L
.41789 .04771 L
.41807 .04767 L
.41828 .04759 L
.41851 .04746 L
.41876 .0473 L
.41901 .0471 L
.41926 .04689 L
.4195 .04666 L
.41972 .04644 L
.41991 .04621 L
.42006 .04599 L
.42017 .04578 L
.42023 .0456 L
.42025 .04546 L
.42024 .04535 L
.4202 .0453 L
.42016 .04528 L
.42013 .04529 L
.42011 .04532 L
.42011 .04536 L
.42011 .04539 L
.4201 .04539 L
.42007 .04537 L
.42003 .04533 L
.41999 .04529 L
.41996 .04527 L
.41994 .04528 L
.41994 .04533 L
.41997 .04543 L
.42002 .04556 L
.42012 .04574 L
.42027 .04594 L
.42049 .04617 L
.42082 .04642 L
.42128 .04667 L
.42189 .04692 L
.42266 .04718 L
.42361 .04742 L
.42468 .04764 L
Mistroke
.42593 .04783 L
.42736 .04798 L
.42876 .04808 L
.43028 .04815 L
.43184 .04819 L
.43341 .04821 L
.43495 .04823 L
.43632 .04825 L
.43762 .04828 L
.43874 .04831 L
.4397 .04834 L
.44044 .04837 L
.44101 .04839 L
.44141 .0484 L
.44167 .04841 L
.44181 .04841 L
.44188 .04841 L
.44187 .04841 L
.44183 .04841 L
.44176 .04841 L
.44168 .04841 L
.44161 .0484 L
.44156 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44152 .0484 L
.44149 .0484 L
.44146 .0484 L
.44142 .0484 L
.4414 .0484 L
.44142 .0484 L
.44147 .0484 L
.44157 .0484 L
.44172 .04838 L
.44193 .04834 L
.44219 .04828 L
.44246 .04822 L
.44272 .0482 L
Mistroke
.44295 .04823 L
.44315 .04833 L
.4433 .04851 L
.44338 .04878 L
.44339 .04912 L
.44333 .04953 L
.4432 .04996 L
.44302 .05042 L
.44279 .05087 L
.44253 .05132 L
.44225 .05175 L
.44199 .05216 L
.44176 .05253 L
.44159 .05282 L
.44148 .05302 L
.44142 .05313 L
.4414 .05317 L
.44142 .05314 L
.44145 .05308 L
.44149 .05301 L
.44152 .05295 L
.44154 .05292 L
.44154 .05292 L
.44156 .05292 L
.44161 .05292 L
.44169 .05293 L
.44175 .05293 L
.44179 .05293 L
.44177 .05293 L
.44168 .05293 L
.4415 .05292 L
.44123 .05291 L
.44089 .05289 L
.44047 .05287 L
.44 .05285 L
.43952 .05283 L
.43909 .05282 L
.43874 .0528 L
.43839 .05279 L
.43799 .05277 L
.43756 .05276 L
.43713 .05274 L
.4367 .05271 L
.43626 .05265 L
.43576 .05257 L
.4352 .05249 L
.43458 .05244 L
.4339 .05244 L
.43312 .05251 L
.43229 .05266 L
Mistroke
.43138 .05289 L
.43042 .05319 L
.42947 .05357 L
.42858 .05399 L
.42776 .05444 L
.42704 .05487 L
.42637 .0553 L
.42573 .05573 L
.42512 .05613 L
.4245 .05648 L
.42387 .05674 L
.42329 .05691 L
.4228 .05697 L
.42237 .05695 L
.42193 .0569 L
.42147 .05683 L
.42095 .05678 L
.42034 .05679 L
.41964 .05688 L
.41887 .05702 L
.41807 .05719 L
.4173 .05739 L
.41661 .05758 L
.41606 .05775 L
.41557 .05789 L
.41503 .05803 L
.41442 .05818 L
.41383 .05836 L
.41334 .05855 L
.41296 .05876 L
.41265 .05899 L
.41234 .05927 L
.41201 .0596 L
.41164 .06001 L
.41114 .0605 L
.41044 .06108 L
.40957 .06175 L
.40852 .06252 L
.40732 .06335 L
.406 .06422 L
.40462 .06509 L
.40334 .06589 L
.40209 .06664 L
.40089 .06732 L
.39977 .06789 L
.39878 .06836 L
.39797 .06873 L
.39729 .06902 L
.39674 .06925 L
.39631 .06944 L
Mistroke
.39598 .0696 L
.39574 .06975 L
.39555 .06992 L
.39538 .07016 L
.39523 .0705 L
.39511 .07094 L
.39503 .07142 L
.39497 .07187 L
.3949 .07222 L
.39483 .07254 L
.39476 .07276 L
.39469 .07293 L
.39465 .07304 L
.39459 .07307 L
.39451 .07306 L
.39438 .07302 L
.39418 .07295 L
.39388 .07289 L
.39346 .0728 L
.39292 .07269 L
.39229 .0726 L
.39158 .07261 L
.39082 .07272 L
.39007 .07293 L
.38929 .07324 L
.38854 .07364 L
.38778 .07409 L
.38698 .07456 L
.38611 .07501 L
.38515 .07542 L
.38409 .07579 L
.38298 .07613 L
.38175 .07648 L
.38035 .07684 L
.37877 .07719 L
.37715 .07752 L
.37552 .0778 L
.37373 .07802 L
.37184 .07821 L
.3701 .07836 L
.36855 .07848 L
.3671 .07859 L
.36578 .0787 L
.36468 .07885 L
.36378 .07903 L
.36306 .07923 L
.36252 .07943 L
.36217 .0796 L
.362 .07973 L
.36199 .0798 L
Mistroke
.36211 .07981 L
.36229 .07976 L
.36247 .07968 L
.36257 .0796 L
.36256 .07954 L
.36239 .07954 L
.36199 .07964 L
.36137 .07986 L
.36054 .08019 L
.35953 .08063 L
.35833 .08118 L
.35707 .08185 L
.3555 .08257 L
.35388 .08337 L
.352 .08422 L
.34982 .08512 L
.34771 .08602 L
.34536 .08684 L
.34289 .08761 L
.34089 .0883 L
.33869 .08891 L
.3367 .08943 L
.3348 .08989 L
.33285 .09029 L
.33137 .09062 L
.33007 .09089 L
.32897 .09111 L
.32811 .09122 L
.3275 .09128 L
.32716 .09129 L
.32702 .09128 L
.32706 .09119 L
.32718 .09109 L
.32735 .09099 L
.32755 .09083 L
.32773 .09067 L
.32784 .09048 L
.3279 .0903 L
.32793 .09014 L
.32794 .09001 L
.32795 .08993 L
.32794 .08989 L
.32792 .08989 L
.32791 .08992 L
.32791 .08996 L
.32791 .08999 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
Mistroke
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32793 .08998 L
.32796 .08993 L
.328 .08986 L
.32803 .0898 L
.32805 .08977 L
.32804 .08979 L
.32799 .08988 L
.32789 .09006 L
.32774 .09032 L
.32755 .09066 L
.32733 .09106 L
.32709 .0915 L
.32684 .09197 L
.32658 .09242 L
.32632 .09285 L
.32607 .09326 L
.32584 .09362 L
.32563 .09393 L
.32544 .0942 L
.32529 .09443 L
.32519 .09462 L
.32516 .09482 L
.32518 .09504 L
.32527 .0953 L
.32541 .0956 L
.32559 .09592 L
.32577 .09629 L
.32597 .09668 L
.32618 .0971 L
.32641 .09755 L
.32668 .098 L
.327 .09845 L
.32735 .0989 L
.32772 .09937 L
.32808 .09985 L
.32841 .10039 L
.32869 .10102 L
.32887 .10176 L
.32893 .10264 L
.32887 .10373 L
.3287 .10505 L
.32844 .10664 L
Mistroke
.32812 .10833 L
.3277 .11009 L
.32719 .11212 L
.32659 .1142 L
.32591 .11638 L
.32518 .11877 L
.3244 .12075 L
.32364 .12307 L
.32292 .12491 L
.32228 .12675 L
.32176 .12851 L
.32138 .12999 L
.3211 .13114 L
.32094 .13208 L
.32088 .13281 L
.32092 .13333 L
.32103 .13366 L
.32121 .13384 L
.32144 .13389 L
.3217 .13388 L
.32199 .1338 L
.32231 .13368 L
.32264 .13352 L
.32295 .13336 L
.32323 .13322 L
.32343 .13311 L
.32355 .13302 L
.32357 .13299 L
.32349 .13305 L
.32329 .13322 L
.32295 .13357 L
.32248 .13413 L
.32183 .13492 L
.32098 .13598 L
.31995 .1372 L
.31871 .13874 L
.31717 .14062 L
.31527 .14254 L
.31323 .14455 L
.31076 .14689 L
.30817 .14898 L
.30513 .1514 L
.30205 .15322 L
.29833 .15493 L
.29525 .1565 L
.29171 .15773 L
.28803 .15861 L
.28482 .15915 L
.2812 .15936 L
.2785 .15926 L
Mistroke
.27586 .15888 L
.27334 .15828 L
.27121 .15748 L
.26954 .15663 L
.26817 .15572 L
.26717 .15481 L
.2665 .15393 L
.26606 .15313 L
.26581 .15239 L
.26564 .15181 L
.26553 .15128 L
.26543 .15078 L
.26532 .15025 L
.26519 .14966 L
.26501 .14898 L
.26472 .14819 L
.26432 .14732 L
.2638 .14636 L
.26312 .14534 L
.26223 .14433 L
.26112 .14327 L
.25977 .14217 L
.25846 .14108 L
.25685 .14014 L
.25489 .1393 L
.25315 .13859 L
.25127 .13799 L
.24911 .13754 L
.24693 .13722 L
.24471 .13703 L
.24229 .13694 L
.24009 .13699 L
.23794 .13716 L
.23562 .13747 L
.2333 .13791 L
.23132 .13846 L
.2292 .13912 L
.22698 .13989 L
.22495 .14067 L
.22308 .14151 L
.22115 .14238 L
.21925 .14325 L
.21757 .14403 L
.21594 .14475 L
.21443 .14538 L
.21312 .14591 L
.21213 .14628 L
.21131 .14648 L
.21067 .1465 L
.21019 .14637 L
Mistroke
.2099 .1461 L
.20979 .14574 L
.20984 .14532 L
.21004 .14486 L
.21037 .14441 L
.21081 .14399 L
.21132 .1436 L
.21186 .14321 L
.21235 .14279 L
.21274 .14234 L
.21305 .14186 L
.2133 .14138 L
.21352 .14088 L
.21373 .1404 L
.21394 .13992 L
.21418 .13945 L
.21444 .139 L
.21474 .13858 L
.21504 .13816 L
.21534 .13775 L
.2156 .13742 L
.21581 .13721 L
.21598 .13717 L
.21611 .1373 L
.2162 .13757 L
.21624 .13799 L
.21621 .13845 L
.21612 .13898 L
.21596 .13951 L
.21576 .14001 L
.21551 .14046 L
.21523 .14082 L
.21495 .14112 L
.21469 .14134 L
.21449 .14148 L
.21436 .14156 L
.21429 .14158 L
.21427 .14155 L
.21431 .14148 L
.21437 .14138 L
.21446 .14126 L
.21453 .14117 L
.21457 .14112 L
.21456 .14114 L
.2145 .14122 L
.21437 .14138 L
.2142 .14161 L
.21398 .14191 L
.21378 .14223 L
.21365 .14252 L
Mistroke
.21358 .14279 L
.21353 .14308 L
.21349 .14343 L
.21344 .14385 L
.21337 .14436 L
.2132 .14501 L
.21285 .1459 L
.21228 .14716 L
.21149 .1488 L
.21046 .15076 L
.20918 .15298 L
.20794 .15495 L
.20631 .15732 L
.20438 .16008 L
.20247 .16252 L
.20039 .16522 L
.19816 .16791 L
.19642 .16993 L
.19478 .1717 L
.19327 .1735 L
.19207 .17476 L
.19118 .17578 L
.19064 .17627 L
.19035 .17638 L
.19023 .17631 L
.19023 .17615 L
.19035 .17594 L
.19054 .17572 L
.19077 .17555 L
.191 .17548 L
.19126 .17547 L
.19154 .17546 L
.19184 .17542 L
.19217 .17536 L
.19247 .1753 L
.19277 .17528 L
.19302 .17531 L
.1932 .17541 L
.19331 .1756 L
.19332 .17587 L
.19324 .17622 L
.19307 .17663 L
.19283 .17708 L
.19254 .17755 L
.19222 .17802 L
.1919 .17849 L
.1916 .17894 L
.19134 .17937 L
.19113 .17974 L
.19096 .18003 L
Mistroke
.19083 .18024 L
.19077 .18036 L
.19075 .18039 L
.19076 .18037 L
.1908 .1803 L
.19085 .18022 L
.19088 .18016 L
.1909 .18014 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.19092 .1801 L
.19095 .18003 L
.19099 .17993 L
.19103 .17983 L
.19105 .17978 L
.19104 .17982 L
.19098 .17996 L
.19087 .18022 L
.19072 .18062 L
.19052 .18115 L
.19028 .18177 L
.19002 .18245 L
.18975 .18315 L
.18947 .18383 L
.18921 .1845 L
.18895 .18516 L
.18873 .18581 L
.18852 .18639 L
.18834 .18685 L
Mistroke
.18819 .18716 L
.18807 .18733 L
.188 .18739 L
.18795 .18736 L
.18794 .18726 L
.18793 .18714 L
.18793 .18706 L
.18792 .18703 L
.18791 .18705 L
.1879 .1871 L
.18787 .18717 L
.18784 .18724 L
.18784 .18728 L
.18787 .18725 L
.18793 .18716 L
.18805 .18698 L
.18821 .18671 L
.1884 .18637 L
.1886 .18596 L
.18881 .18551 L
.18902 .18503 L
.18926 .18457 L
.18954 .1841 L
.18987 .18365 L
.19025 .18324 L
.19068 .18289 L
.19114 .18262 L
.19159 .18243 L
.19199 .18231 L
.19232 .18224 L
.19256 .18222 L
.19271 .18223 L
.19278 .18223 L
.19279 .18222 L
.19273 .18219 L
.19262 .18215 L
.19245 .18212 L
.19224 .1821 L
.19199 .18209 L
.19171 .18209 L
.19143 .1821 L
.19116 .18213 L
.19096 .18218 L
.19083 .18224 L
.19076 .18232 L
.19074 .18239 L
.19075 .18245 L
.19079 .1825 L
.19083 .18252 L
.19087 .18252 L
Mistroke
.19088 .1825 L
.19089 .18247 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18245 L
.19089 .18243 L
.19089 .18238 L
.19089 .1823 L
.19089 .18224 L
.19089 .1822 L
.19089 .18223 L
.19089 .18233 L
.19089 .18251 L
.19088 .18279 L
.19088 .18314 L
.19088 .18356 L
.19087 .18401 L
.19087 .1845 L
.19088 .185 L
.19091 .1855 L
.19095 .186 L
.19098 .18648 L
.191 .18689 L
.19099 .18718 L
.19093 .18731 L
.19082 .18728 L
.19067 .18711 L
.19048 .18684 L
.19025 .18653 L
Mistroke
.19 .18623 L
.18973 .186 L
.18946 .18583 L
.18919 .18543 L
.18893 .18538 L
.18869 .18538 L
.18848 .18543 L
.18831 .18552 L
.18819 .18569 L
.18812 .18592 L
.1881 .1862 L
.18811 .18649 L
.18815 .18677 L
.18818 .187 L
.18818 .18716 L
.18815 .18724 L
.18812 .18724 L
.1881 .18719 L
.18811 .18712 L
.18817 .18707 L
.18827 .18704 L
.18843 .18704 L
.18863 .18705 L
.18888 .18707 L
.18917 .1871 L
.18948 .18713 L
.18978 .18715 L
.19005 .18716 L
.1903 .18714 L
.19049 .18709 L
.19059 .187 L
.19061 .18689 L
.19053 .18677 L
.19037 .18666 L
.19017 .18655 L
.18994 .18643 L
.18972 .18631 L
.18955 .18619 L
.18945 .18607 L
.18945 .18598 L
.18957 .18591 L
.18976 .18594 L
.18998 .1861 L
.19018 .18642 L
.19036 .18693 L
.19048 .18762 L
.19052 .18846 L
.19044 .18945 L
.19021 .19056 L
.18977 .19187 L
Mistroke
.18912 .19339 L
.18823 .19516 L
.18717 .19704 L
.18572 .19937 L
.18411 .20178 L
.18211 .20461 L
.1796 .20791 L
.17711 .2111 L
.17373 .21479 L
.17033 .21891 L
.16687 .22334 L
.16265 .22807 L
.15804 .23289 L
.15336 .2385 L
.14944 .24326 L
.14467 .24861 L
.13941 .25445 L
.13551 .25909 L
.13108 .2641 L
.12672 .26913 L
.12289 .27397 L
.11911 .27871 L
.11515 .28399 L
.11226 .28828 L
.10904 .29319 L
.10626 .29793 L
.10343 .30276 L
.10115 .30742 L
.09914 .31238 L
.09716 .31645 L
.09571 .32053 L
.09446 .32448 L
.09347 .3275 L
.09278 .33023 L
.09239 .3325 L
.09225 .33407 L
.09228 .33504 L
.0924 .33552 L
.09258 .33563 L
.09274 .33554 L
.09282 .33544 L
.09277 .33553 L
.09258 .336 L
.09223 .33697 L
.09174 .33852 L
.09113 .34086 L
.09044 .34354 L
.08964 .34724 L
.08877 .3512 L
.08787 .35572 L
Mistroke
.08698 .36039 L
.0861 .36552 L
.08529 .37077 L
.08457 .37648 L
.08397 .38068 L
.08347 .38524 L
.08311 .38927 L
.08286 .39277 L
.08271 .39541 L
.08264 .3976 L
.08262 .39928 L
.08264 .40038 L
.08269 .40098 L
.08273 .40124 L
.08277 .40124 L
.0828 .40108 L
.08281 .40082 L
.08282 .40054 L
.08283 .40028 L
.08283 .40013 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08284 .40008 L
.08286 .40007 L
.08292 .40004 L
.08301 .4 L
.08309 .39996 L
.08313 .39995 L
.0831 .39996 L
.08298 .40001 L
.08277 .40011 L
.08244 .40025 L
.08202 .40044 L
.08153 .40065 L
.08099 .40089 L
.08042 .40115 L
.07986 .4014 L
.0793 .40166 L
.07875 .4019 L
.07822 .40212 L
.07781 .40229 L
.07756 .40238 L
.07745 .40241 L
.07744 .40238 L
.07748 .40231 L
.07749 .40224 L
Mistroke
.0774 .40225 L
.07714 .40238 L
.07665 .40265 L
.07593 .40309 L
.07501 .40369 L
.07398 .40439 L
.07288 .40516 L
.07186 .40594 L
.07083 .4068 L
.06979 .40772 L
.06872 .40871 L
.06783 .4097 L
.06707 .41073 L
.06649 .4118 L
.06607 .41292 L
.06577 .41404 L
.06557 .41517 L
.06542 .4163 L
.06529 .41734 L
.06509 .41841 L
.06484 .41949 L
.06457 .42055 L
.06429 .42156 L
.06399 .42246 L
.06369 .42323 L
.06342 .42383 L
.06318 .42427 L
.063 .42453 L
.06287 .42465 L
.0628 .42467 L
.06281 .42459 L
.06283 .42453 L
.06287 .42444 L
.06291 .42432 L
.06295 .42418 L
.06296 .42407 L
.06297 .42399 L
.06297 .42394 L
.06297 .42395 L
.06297 .42406 L
.06296 .42431 L
.06295 .42468 L
.06293 .4252 L
.0629 .42589 L
.06287 .4267 L
.06284 .42774 L
.0628 .42889 L
.06277 .42997 L
.06272 .43114 L
.06268 .4326 L
Mistroke
.06264 .43378 L
.06259 .43491 L
.06255 .43603 L
.06252 .4371 L
.06249 .43807 L
.06246 .43887 L
.06244 .4395 L
.06243 .43998 L
.06242 .44025 L
.06242 .4405 L
.06241 .44072 L
.06241 .44091 L
.0624 .44104 L
.06239 .44118 L
.06236 .44141 L
.06227 .44171 L
.06217 .44207 L
.06209 .44254 L
.06205 .44322 L
.06204 .44413 L
.06212 .44511 L
.06231 .44615 L
.06263 .44734 L
.06311 .44878 L
.06378 .45048 L
.06455 .45229 L
.06524 .4538 L
.06586 .45564 L
.06633 .4578 L
.06684 .45945 L
.06748 .4613 L
.06784 .46338 L
.06808 .46513 L
.0682 .46666 L
.06822 .46818 L
.06815 .4696 L
.06801 .47064 L
.06776 .47149 L
.06748 .47212 L
.06724 .47256 L
.06704 .47285 L
.06687 .473 L
.06673 .47303 L
.06666 .47298 L
.06667 .47289 L
.06671 .4728 L
.06675 .47271 L
.06679 .47264 L
.0668 .4726 L
.06681 .47259 L
Mistroke
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06682 .47259 L
.06684 .47259 L
.06687 .4726 L
.06688 .47263 L
.06685 .47268 L
.0668 .47274 L
.06674 .47279 L
.06667 .47279 L
.0666 .47273 L
.06654 .47259 L
.0665 .47237 L
.0665 .47203 L
.0665 .47154 L
.06652 .47114 L
.06653 .47066 L
.06655 .47018 L
.06655 .46974 L
.06658 .46927 L
.06664 .46881 L
.06672 .46839 L
.06681 .46804 L
.06689 .4678 L
.06695 .46765 L
.067 .46759 L
.06701 .46758 L
.06698 .46765 L
.06692 .46775 L
.06686 .46783 L
.06683 .46785 L
.06684 .46779 L
Mistroke
.0669 .46764 L
.06702 .46741 L
.0672 .46707 L
.06742 .46663 L
.06769 .46612 L
.06798 .46552 L
.06828 .46485 L
.06858 .46414 L
.06886 .46344 L
.06915 .46278 L
.06942 .46219 L
.06967 .46165 L
.06987 .46116 L
.07 .46077 L
.07008 .46047 L
.07011 .46028 L
.07009 .46018 L
.07006 .46016 L
.07001 .46018 L
.06998 .46024 L
.06996 .46033 L
.06996 .46039 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06992 .46042 L
.06988 .46042 L
.06984 .46042 L
.06982 .46042 L
.06983 .46042 L
.06989 .46042 L
.06999 .46042 L
.07015 .46042 L
.07036 .46042 L
.07061 .46041 L
.07087 .46041 L
.07115 .4604 L
.07142 .4604 L
.07168 .46039 L
.07195 .46039 L
.0722 .46039 L
.07243 .46038 L
.07262 .46038 L
.07274 .46038 L
.07281 .46038 L
.07283 .46038 L
.07282 .46038 L
.07278 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07269 .4605 L
.07269 .46032 L
.0727 .46004 L
.07272 .45967 L
.07273 .45923 L
.07275 .45876 L
.07276 .45826 L
.07278 .45778 L
.0728 .45732 L
.07281 .45685 L
.07283 .4564 L
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07286 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
Mistroke
.07286 .45553 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
Mistroke
.07287 .45552 L
.0729 .45547 L
.07295 .45539 L
.07299 .45532 L
.073 .45529 L
.07298 .45532 L
.07292 .45541 L
.0728 .4556 L
.07262 .45588 L
.07236 .45626 L
.07202 .4567 L
.07167 .45718 L
.07134 .45768 L
.07107 .45816 L
.07084 .45863 L
.07064 .4591 L
.07051 .45955 L
.07048 .45996 L
.07054 .46028 L
.07069 .4605 L
.07091 .46062 L
.07118 .46065 L
.07146 .46063 L
.07179 .46055 L
.07212 .46047 L
.0724 .46041 L
.0726 .46038 L
.07273 .46038 L
.0728 .46038 L
.07283 .46038 L
.07282 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07268 .4605 L
.07269 .46032 L
.0727 .46004 L
.07271 .45967 L
.07272 .45923 L
.07274 .45876 L
.07275 .45826 L
.07277 .45778 L
.07279 .45732 L
.0728 .45685 L
.07282 .4564 L
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07287 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
.07286 .45553 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07287 .45554 L
.07289 .45554 L
.07293 .45554 L
.07297 .45554 L
.07299 .45554 L
.07298 .45554 L
.07293 .45554 L
.07282 .45554 L
.07266 .45554 L
.07245 .45554 L
.07221 .45555 L
.07194 .45555 L
.07166 .45555 L
.07139 .45556 L
.07113 .45556 L
Mistroke
.07087 .45557 L
.07061 .45557 L
.07038 .45557 L
.07019 .45558 L
.07007 .45558 L
.07 .45558 L
.06998 .45558 L
.06999 .45558 L
.07003 .45558 L
.07008 .45558 L
.07011 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .45558 L
.07009 .45558 L
.07005 .45558 L
.07 .45558 L
.06998 .45558 L
.06998 .45558 L
.07002 .45558 L
.07009 .45558 L
.07021 .45558 L
.07037 .45558 L
.07057 .45557 L
.07083 .45557 L
.07114 .45556 L
.0715 .45556 L
.07189 .45555 L
.07231 .45555 L
.07276 .45554 L
.07323 .45553 L
.07369 .45553 L
.07412 .45552 L
.07448 .45551 L
.07479 .45551 L
.07505 .45551 L
.07527 .4555 L
.07545 .4555 L
.07559 .4555 L
.07568 .4555 L
.07572 .4555 L
.07574 .45549 L
.07572 .4555 L
.07568 .4555 L
.07563 .4555 L
.0756 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45549 L
.07558 .45549 L
.07558 .45549 L
.07557 .4555 L
.07557 .4555 L
Mistroke
.07556 .45551 L
.07556 .45551 L
.07555 .45549 L
.07555 .45545 L
.07555 .45541 L
.07555 .45539 L
.07555 .4554 L
.07554 .45543 L
.07554 .45546 L
.07554 .45553 L
.07554 .45562 L
.07554 .45577 L
.07554 .45599 L
.07554 .4563 L
.07553 .45674 L
.07553 .45715 L
.07552 .45756 L
.07551 .45798 L
.07549 .45842 L
.07548 .45887 L
.07547 .4592 L
.07546 .45957 L
.07545 .45986 L
.07545 .46009 L
.07544 .46025 L
.07543 .46037 L
.07543 .46045 L
.07542 .46049 L
.07542 .4605 L
.07542 .46046 L
.07542 .46041 L
.07542 .46037 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46033 L
.07542 .46031 L
.07544 .46024 L
.07553 .46014 L
.07557 .46009 L
.07555 .46012 L
.07549 .46021 L
.07535 .46039 L
.07506 .46069 L
.07456 .46113 L
.0739 .46165 L
.07336 .46219 L
Mistroke
.07288 .4627 L
.07243 .46317 L
.07196 .46361 L
.07144 .46405 L
.07093 .46451 L
.07041 .46497 L
.06999 .46535 L
.06977 .46556 L
.06968 .46564 L
.06965 .46562 L
.06967 .46554 L
.06975 .46541 L
.06979 .46526 L
.06977 .46519 L
.06972 .46519 L
.06969 .46522 L
.06969 .46524 L
.06973 .46526 L
.06982 .46527 L
.06998 .46526 L
.07019 .46526 L
.07045 .46526 L
.07072 .46525 L
.07099 .46525 L
.07125 .46524 L
.07149 .46524 L
.07174 .46523 L
.072 .46523 L
.07224 .46523 L
.07244 .46522 L
.07256 .46522 L
.07262 .46522 L
.07265 .46522 L
.07264 .46522 L
.0726 .46522 L
.07256 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07252 .46522 L
.0725 .46522 L
.07246 .46522 L
.07242 .46523 L
.07241 .46523 L
.07242 .46523 L
.07246 .46522 L
.07256 .46522 L
.07271 .46522 L
.07293 .46522 L
.07318 .46521 L
.07346 .46521 L
.07373 .4652 L
.07399 .4652 L
.07423 .46519 L
.07448 .46519 L
.07474 .46519 L
.07498 .46518 L
.07517 .46518 L
.07529 .46518 L
.07536 .46518 L
.07538 .46518 L
Mistroke
.07537 .46518 L
.07534 .46518 L
.07529 .46518 L
.07527 .46518 L
.07526 .46518 L
.07526 .4652 L
.07528 .46525 L
.07532 .46532 L
.07536 .46539 L
.07537 .46542 L
.07536 .4654 L
.07532 .4653 L
.07523 .46512 L
.07508 .46484 L
.07488 .46447 L
.07464 .46404 L
.07439 .46357 L
.07413 .46308 L
.07388 .4626 L
.07365 .46213 L
.07341 .46166 L
.07317 .46121 L
.07294 .46083 L
.07277 .46057 L
.07266 .46043 L
.07263 .46038 L
.07265 .46037 L
.07268 .46038 L
.07271 .46035 L
.07273 .46023 L
.07272 .46 L
.07264 .45965 L
.07251 .45921 L
.07231 .45871 L
.07207 .45816 L
.07178 .45761 L
.07155 .45709 L
.07134 .45661 L
.07111 .45618 L
.07087 .45582 L
.07066 .45555 L
.07041 .45544 L
.07021 .45549 L
.07008 .45568 L
.07002 .45596 L
.06999 .45631 L
.06999 .45677 L
.07002 .45719 L
.07005 .45759 L
.07005 .45799 L
Mistroke
.07004 .4584 L
.07004 .45876 L
.07003 .45913 L
.07002 .45953 L
.07001 .45981 L
.07 .46 L
.07 .46017 L
.06998 .46029 L
.06995 .46039 L
.06991 .46046 L
.06986 .4605 L
.06984 .46051 L
.06985 .4605 L
.06989 .46047 L
.06999 .46046 L
.07014 .46044 L
.07036 .46043 L
.07061 .46042 L
.07089 .46041 L
.07116 .4604 L
.07142 .4604 L
.07166 .46039 L
.07191 .46039 L
.07217 .46039 L
.07241 .46038 L
.0726 .46038 L
.07272 .46038 L
.07279 .46038 L
.07281 .46038 L
.0728 .46038 L
.07276 .46038 L
.07274 .46038 L
.07276 .46038 L
.07279 .46038 L
.0728 .46041 L
.07279 .46046 L
.07274 .46053 L
.07264 .46059 L
.07247 .46061 L
.07226 .46056 L
.07201 .46042 L
.07173 .46019 L
.07143 .45981 L
.07115 .45946 L
.07089 .45903 L
.07064 .45857 L
.0704 .4581 L
.07018 .45766 L
.07004 .45719 L
.07003 .45672 L
Mistroke
.07014 .45629 L
.07035 .45592 L
.07061 .45563 L
.0709 .45542 L
.07121 .45531 L
.07152 .4553 L
.07179 .45534 L
.07205 .45541 L
.07231 .45548 L
.07255 .45552 L
.07275 .45554 L
.07288 .45554 L
.07295 .45554 L
.07298 .45554 L
.07297 .45554 L
.07294 .45554 L
.0729 .45554 L
.07287 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07292 .45554 L
.07296 .45554 L
.07298 .45553 L
.07296 .45553 L
.07292 .45553 L
.07282 .45551 L
.07266 .45548 L
.07245 .45543 L
.07219 .45538 L
.07192 .45536 L
.07164 .45538 L
.07137 .45549 L
.07112 .4557 L
.07086 .45598 L
.07059 .45634 L
.07035 .45664 L
.07015 .45704 L
.07001 .45747 L
.06994 .45792 L
.06992 .45829 L
.06992 .45859 L
.06995 .45884 L
.06999 .45905 L
.07001 .45915 L
.07002 .45915 L
.07002 .45905 L
.07003 .45882 L
Mistroke
.07003 .45846 L
.07004 .45806 L
.07005 .45762 L
.07006 .45714 L
.07007 .45676 L
.07008 .45648 L
.07008 .45615 L
.0701 .45583 L
.07011 .45556 L
.07012 .45537 L
.07012 .4553 L
.07012 .45535 L
.07012 .45551 L
.07011 .45578 L
.0701 .45613 L
.07009 .45655 L
.07007 .45709 L
.07005 .45756 L
.07003 .45807 L
.07002 .45852 L
.07 .45898 L
.06999 .45944 L
.06998 .45985 L
.06997 .46019 L
.06996 .46042 L
.06995 .46056 L
.06995 .46063 L
.06995 .46063 L
.06995 .46059 L
.06995 .46053 L
.06995 .46048 L
.06996 .46044 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06998 .46042 L
.06998 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06998 .46042 L
.06998 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
Mistroke
.06995 .46042 L
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46043 L
.06995 .46044 L
.06995 .46045 L
.06995 .46046 L
.06996 .46046 L
.06996 .46045 L
.06996 .46044 L
.06997 .46042 L
.06997 .46038 L
.06998 .46033 L
.06999 .46026 L
.06999 .4602 L
.07 .46013 L
.07001 .46007 L
.07001 .46004 L
.07002 .46003 L
.07002 .46002 L
.07002 .46002 L
.07002 .46004 L
.07001 .46007 L
Mistroke
.07 .4601 L
.06999 .46016 L
.06998 .46022 L
.06998 .46029 L
.06997 .46036 L
.06997 .4604 L
.06997 .46043 L
.06997 .46044 L
.06997 .46045 L
.06997 .46046 L
.06997 .46046 L
.06997 .46045 L
.06997 .46042 L
.06997 .46044 L
.06997 .46043 L
.06997 .46037 L
.06997 .46026 L
.06998 .46012 L
.06998 .45997 L
.06999 .45984 L
.06999 .45972 L
.06999 .45962 L
.07 .4595 L
.07 .45938 L
.07001 .45925 L
.07002 .45917 L
.07002 .45915 L
.07002 .4592 L
.07001 .45931 L
.07001 .45943 L
.07 .45955 L
.07 .45962 L
.07 .45959 L
.07 .45947 L
.07001 .45926 L
.07002 .45893 L
.07003 .45851 L
.07004 .45803 L
.07006 .45758 L
.07007 .45713 L
.07008 .45669 L
.0701 .45625 L
.07011 .45586 L
.07012 .45556 L
.07013 .45539 L
.07013 .45539 L
.07012 .45553 L
.07011 .45575 L
.0701 .45601 L
.07009 .45623 L
Mistroke
.07009 .45638 L
.07008 .45648 L
.07008 .45656 L
.07007 .45664 L
.07007 .45672 L
.07006 .45678 L
.07006 .4568 L
.07006 .45677 L
.07007 .45668 L
.07007 .45653 L
.07008 .45633 L
.07009 .45611 L
.0701 .45594 L
.0701 .45586 L
.0701 .45583 L
.0701 .45586 L
.0701 .45591 L
.0701 .45596 L
.07009 .45602 L
.07009 .45611 L
.07009 .4562 L
.07009 .45627 L
.07008 .45634 L
.07008 .45643 L
.07008 .45654 L
.07007 .45667 L
.07007 .45682 L
.07006 .45699 L
.07006 .45723 L
.07005 .45752 L
.07004 .45782 L
.07004 .4581 L
.07003 .45835 L
.07002 .4586 L
.07002 .4589 L
.07001 .4592 L
.07 .45945 L
.07 .45962 L
.07 .45972 L
.07 .45978 L
.07 .45978 L
.07 .45972 L
.07 .45961 L
.07001 .45947 L
.07001 .45937 L
.07001 .45934 L
.07001 .45941 L
.07 .45952 L
.07 .45964 L
.06999 .45979 L
Mistroke
.06998 .45993 L
.06998 .46007 L
.06997 .46019 L
.06996 .46029 L
.06996 .46038 L
.06996 .46046 L
.06995 .46051 L
.06995 .46053 L
.06996 .46049 L
.06996 .46042 L
.06996 .46036 L
.06997 .46035 L
.06997 .46036 L
.06997 .46036 L
.06997 .46032 L
.06997 .46026 L
.06998 .46019 L
.06998 .46012 L
.06998 .46006 L
.06999 .46002 L
.06999 .45997 L
.06999 .45988 L
.06999 .45975 L
.07 .45959 L
.07 .45942 L
.07001 .45927 L
.07001 .45912 L
.07002 .459 L
.07002 .45892 L
.07002 .4589 L
.07002 .45892 L
.07002 .45899 L
.07002 .45908 L
.07001 .45917 L
.07001 .45928 L
.07 .4594 L
.07 .45954 L
.06999 .45973 L
.06998 .4599 L
.06998 .46011 L
.06997 .46028 L
.06996 .46039 L
.06996 .46045 L
.06996 .46045 L
.06996 .46043 L
.06996 .4604 L
.06996 .46038 L
.06996 .46036 L
.06997 .46034 L
.06997 .46031 L
Mistroke
.06997 .46028 L
.06997 .46027 L
.06997 .4603 L
.06997 .46033 L
.06997 .46035 L
.06997 .46033 L
.06997 .4603 L
.06997 .46026 L
.06997 .4602 L
.06998 .46013 L
.06998 .46007 L
.06998 .46002 L
.06999 .45998 L
.06999 .45995 L
.06999 .45993 L
.06999 .45992 L
.06999 .45991 L
.06999 .45994 L
.06999 .45998 L
.06998 .46005 L
.06998 .46014 L
.06997 .46024 L
.06996 .46034 L
.06996 .46042 L
.06995 .46048 L
.06995 .46051 L
.06995 .46051 L
.06995 .46047 L
.06996 .46044 L
.06996 .46043 L
.06996 .46044 L
.06996 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46041 L
.06996 .46039 L
.06996 .46035 L
.06997 .46032 L
.06997 .4603 L
.06997 .46028 L
.06997 .46027 L
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46026 L
.06997 .46025 L
.06997 .46025 L
.06997 .46025 L
.06997 .46026 L
Mistroke
.06997 .46026 L
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46027 L
.06997 .46027 L
.06997 .46029 L
.06997 .46032 L
.06996 .46035 L
.06996 .46038 L
.06996 .46041 L
.06996 .46044 L
.06995 .46047 L
.06995 .46048 L
.06995 .46047 L
.06996 .46045 L
.06996 .46042 L
.06996 .46038 L
.06996 .46035 L
.06997 .46032 L
.06997 .46029 L
.06997 .46027 L
.06997 .46025 L
.06997 .46024 L
.06997 .46024 L
.06997 .46024 L
.06997 .46025 L
.06997 .46026 L
.06997 .46028 L
.06997 .46031 L
.06996 .46034 L
.06996 .46038 L
.06996 .46041 L
.06996 .46043 L
.06996 .46045 L
.06995 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46044 L
.06995 .46047 L
.06995 .4605 L
.06995 .46051 L
.06995 .46048 L
.06996 .46043 L
.06996 .46035 L
.06997 .46026 L
.06997 .46016 L
.06998 .46007 L
.06998 .46 L
Mistroke
.06999 .45995 L
.06999 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45989 L
.06997 .45995 L
.06997 .46004 L
.06997 .46012 L
.06997 .46019 L
.06996 .46024 L
.06996 .46027 L
.06996 .46026 L
.06996 .46022 L
.06997 .46015 L
.06997 .46007 L
.06997 .45998 L
.06998 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45988 L
.06998 .4599 L
.06997 .45995 L
.06997 .46003 L
.06997 .46012 L
.06996 .46023 L
.06996 .46033 L
.06996 .46042 L
.06996 .46048 L
.06995 .46052 L
.06995 .46054 L
.06995 .46056 L
.06995 .4606 L
.06995 .46066 L
.06995 .46069 L
.06995 .46067 L
.06995 .46056 L
.06996 .46037 L
.06997 .46008 L
.06998 .45971 L
.07 .45928 L
.07001 .4588 L
.07003 .45826 L
.07005 .45771 L
.07007 .45714 L
.07009 .45658 L
.0701 .4561 L
.07012 .45572 L
.07012 .45551 L
.07013 .45549 L
.07012 .45566 L
Mistroke
.07011 .45597 L
.07009 .4564 L
.07008 .45691 L
.07006 .45746 L
.07004 .458 L
.07002 .45853 L
.07 .45904 L
.06999 .45951 L
.06997 .45991 L
.06996 .46025 L
.06996 .46044 L
.06995 .46052 L
.06996 .46048 L
.06996 .46031 L
.06997 .46005 L
.06998 .45974 L
.06999 .45942 L
.07 .45914 L
.07001 .45889 L
.07002 .45871 L
.07002 .45857 L
.07002 .45849 L
.07002 .45848 L
.07002 .45855 L
.07002 .45868 L
.07001 .45895 L
.07 .45923 L
.06999 .45955 L
.06998 .45983 L
.06997 .46003 L
.06997 .46015 L
.06997 .46018 L
.06997 .46011 L
.06997 .46001 L
.06998 .45991 L
.06998 .45984 L
.06998 .4598 L
.06998 .45979 L
.06998 .45978 L
.06998 .45974 L
.06998 .45964 L
.06999 .4595 L
.07 .45932 L
.07 .45907 L
.07001 .45875 L
.07003 .45838 L
.07004 .45804 L
.07005 .45774 L
.07006 .45742 L
.07007 .45708 L
Mistroke
.07008 .45674 L
.07009 .45646 L
.0701 .4563 L
.0701 .45624 L
.0701 .45629 L
.07009 .45642 L
.07009 .45658 L
.07008 .45678 L
.07007 .45699 L
.07007 .45719 L
.07006 .45734 L
.07006 .45745 L
.07005 .45759 L
.07005 .45773 L
.07004 .4579 L
.07004 .45809 L
.07003 .45832 L
.07002 .45859 L
.07001 .45888 L
.07 .4592 L
.06999 .45948 L
.06998 .45969 L
.06998 .45985 L
.06997 .45991 L
.06997 .45993 L
.06998 .45991 L
.06998 .45983 L
.06998 .45972 L
.06999 .45956 L
.06999 .45935 L
.07 .45909 L
.07001 .45881 L
.07002 .4585 L
.07004 .45814 L
.07005 .45773 L
.07006 .45728 L
.07008 .45687 L
.07009 .45656 L
.0701 .45629 L
.0701 .45612 L
.07011 .45608 L
.0701 .45614 L
.0701 .45626 L
.07009 .45641 L
.07009 .45657 L
.07008 .45671 L
.07008 .45685 L
.07008 .45697 L
.07007 .45707 L
.07007 .45707 L
Mistroke
.07007 .45698 L
.07008 .45685 L
.07009 .45665 L
.07009 .45643 L
.0701 .4562 L
.07011 .45598 L
.07012 .45579 L
.07012 .45568 L
.07012 .4557 L
.07011 .45587 L
.0701 .45618 L
.07009 .45656 L
.07007 .45699 L
.07006 .45736 L
.07005 .45766 L
.07004 .45787 L
.07004 .45798 L
.07004 .45797 L
.07004 .4579 L
.07005 .45777 L
.07005 .45758 L
.07006 .45735 L
.07007 .45707 L
.07008 .45677 L
.07009 .4565 L
.0701 .45624 L
.07011 .45602 L
.07011 .45581 L
.07012 .45564 L
.07012 .45554 L
.07012 .45554 L
.07012 .45565 L
.07011 .45581 L
.07011 .45598 L
.0701 .45615 L
.0701 .45631 L
.07009 .45647 L
.07009 .45663 L
.07008 .45678 L
.07008 .45691 L
.07007 .45703 L
.07007 .45712 L
.07007 .45717 L
.07007 .45721 L
.07007 .4572 L
.07007 .45715 L
.07007 .45706 L
.07008 .45696 L
.07008 .4568 L
.07009 .45661 L
Mistroke
.07009 .45648 L
.0701 .45637 L
.0701 .45633 L
.0701 .45632 L
.0701 .45636 L
.0701 .45634 L
.0701 .45629 L
.0701 .45622 L
.0701 .45618 L
.0701 .45614 L
.0701 .4561 L
.07011 .45602 L
.07011 .45594 L
.07011 .45588 L
.07011 .45586 L
.07011 .45591 L
.07011 .45601 L
.0701 .45616 L
.0701 .45634 L
.07009 .45652 L
.07008 .45672 L
.07008 .4569 L
.07007 .45703 L
.07007 .45712 L
.07007 .45717 L
.07007 .45716 L
.07007 .45711 L
.07007 .457 L
.07008 .45683 L
.07009 .45657 L
.0701 .45634 L
.07011 .45607 L
.07011 .45583 L
.07012 .45567 L
.07012 .45561 L
.07012 .45566 L
.07011 .45581 L
.07011 .45601 L
.0701 .45621 L
.07009 .4564 L
.07009 .45656 L
.07008 .4567 L
.07008 .45682 L
.07008 .45689 L
.07008 .4569 L
.07008 .45689 L
.07008 .45681 L
.07008 .45668 L
.07009 .45648 L
.0701 .4563 L
Mistroke
.07011 .45608 L
.07011 .45588 L
.07012 .45572 L
.07012 .45562 L
.07012 .45557 L
.07012 .45555 L
.07012 .45554 L
.07012 .45552 L
.07012 .4555 L
.07013 .4555 L
.07012 .45551 L
.07012 .45555 L
.07012 .45558 L
.07012 .45561 L
.07012 .45563 L
.07012 .45566 L
.07012 .45569 L
.07012 .45574 L
.07012 .45579 L
.07011 .45582 L
.07011 .45583 L
.07011 .45581 L
.07011 .45581 L
.07011 .45585 L
.07011 .45594 L
.07011 .45607 L
.0701 .45622 L
.0701 .45638 L
.07009 .45652 L
.07009 .45664 L
.07008 .45672 L
.07008 .45677 L
.07008 .45677 L
.07008 .45675 L
.07008 .45669 L
.07009 .45663 L
.07009 .45653 L
.07009 .4564 L
.0701 .45624 L
.07011 .45605 L
.07011 .45585 L
.07012 .45567 L
.07012 .45552 L
.07013 .45543 L
.07013 .4554 L
.07013 .45544 L
.07013 .45549 L
.07012 .45552 L
.07013 .4555 L
.07013 .45546 L
Mistroke
.07013 .45544 L
.07013 .45547 L
.07012 .45556 L
.07012 .4557 L
.07011 .45587 L
.07011 .45604 L
.0701 .45621 L
.0701 .45636 L
.07009 .45648 L
.07009 .45658 L
.07009 .45665 L
.07008 .4567 L
.07008 .45673 L
.07008 .45672 L
.07009 .45663 L
.07009 .4565 L
.0701 .45635 L
.0701 .4562 L
.07011 .45605 L
.07011 .45596 L
.07011 .4559 L
.07011 .45589 L
.07011 .45592 L
.07011 .45594 L
.07011 .45592 L
.07011 .45587 L
.07011 .45585 L
.07011 .45591 L
.07011 .45606 L
.0701 .45626 L
.07009 .45649 L
.07008 .45672 L
.07008 .45693 L
.07007 .45707 L
.07007 .45715 L
.07007 .45717 L
.07007 .45716 L
.07007 .45715 L
.07007 .45713 L
.07007 .45711 L
.07008 .45697 L
.07008 .45675 L
.07009 .45647 L
.0701 .45615 L
.07011 .45584 L
.07012 .45558 L
.07013 .45539 L
.07013 .45531 L
.07013 .45531 L
.07013 .45537 L
Mistroke
.07013 .45544 L
.07012 .45552 L
.07012 .45559 L
.07012 .45568 L
.07012 .45578 L
.07011 .45593 L
.0701 .45616 L
.07009 .45646 L
.07008 .45675 L
.07006 .45707 L
.07005 .45736 L
.07005 .45758 L
.07004 .45774 L
.07004 .45783 L
.07004 .45782 L
.07004 .45773 L
.07005 .45759 L
.07006 .4574 L
.07006 .45719 L
.07007 .45691 L
.07008 .4566 L
.0701 .45628 L
.07011 .45596 L
.07012 .45568 L
.07013 .45545 L
.07013 .4553 L
.07014 .45521 L
.07014 .45523 L
.07013 .45536 L
.07012 .45559 L
.07011 .45588 L
.0701 .4562 L
.07009 .45654 L
.07007 .45687 L
.07006 .45716 L
.07005 .45741 L
.07005 .45757 L
.07004 .45767 L
.07004 .4577 L
.07004 .45766 L
.07005 .45757 L
.07006 .45737 L
.07007 .45714 L
.07008 .45683 L
.07009 .45648 L
.0701 .45614 L
.07011 .45584 L
.07012 .4556 L
.07013 .45545 L
.07013 .45538 L
Mistroke
.07013 .45537 L
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45559 L
.07012 .45561 L
.07012 .45563 L
.07011 .45569 L
.07011 .45575 L
.0701 .45583 L
.0701 .45594 L
.07009 .45603 L
.07009 .4561 L
.07008 .45617 L
.07008 .45624 L
.07007 .45634 L
.07007 .45647 L
.07007 .45663 L
.07006 .45684 L
.07006 .45712 L
.07005 .45745 L
.07003 .45779 L
.07003 .45812 L
.07003 .45839 L
.07003 .45856 L
.07003 .45866 L
.07004 .45869 L
.07004 .45869 L
.07004 .45861 L
.07004 .45846 L
.07004 .45821 L
.07004 .45789 L
.07006 .45751 L
.07007 .45711 L
.07008 .45671 L
.0701 .4563 L
.07011 .45602 L
.07011 .45579 L
.07012 .45564 L
.07012 .45555 L
.07012 .45551 L
.07012 .45552 L
.07012 .45554 L
.07012 .45556 L
.07012 .45555 L
.07012 .45554 L
.07013 .45554 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07013 .45553 L
.07013 .45549 L
.07013 .45548 L
.07013 .4555 L
.07012 .45557 L
.07012 .45565 L
.07011 .45574 L
.07011 .45582 L
.07011 .45589 L
.0701 .45597 L
.0701 .45607 L
.07009 .45618 L
.07008 .4563 L
.07008 .45642 L
.07007 .45651 L
.07007 .45658 L
.07007 .4566 L
.07007 .45655 L
.07007 .45645 L
.07008 .45629 L
.07009 .45615 L
.07009 .45604 L
.0701 .45594 L
.0701 .45589 L
.0701 .4559 L
.0701 .456 L
.07009 .45617 L
.07009 .45639 L
.07008 .45663 L
.07007 .45688 L
.07006 .45712 L
.07006 .45732 L
.07005 .4575 L
.07004 .4576 L
.07004 .4576 L
.07005 .45752 L
.07005 .45738 L
Mistroke
.07006 .4572 L
.07007 .45693 L
.07008 .45663 L
.07009 .45631 L
.07011 .45601 L
.07011 .45576 L
.07012 .45558 L
.07013 .45546 L
.07013 .45539 L
.07013 .45538 L
.07013 .45543 L
.07013 .4555 L
.07012 .45555 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07012 .45555 L
.07012 .45553 L
.07013 .45553 L
.07012 .45552 L
.07012 .45551 L
.07012 .4555 L
.07012 .45551 L
.07012 .45554 L
.07012 .45561 L
.07011 .45574 L
.0701 .45594 L
.07009 .45622 L
.07008 .45654 L
.07007 .45683 L
.07006 .45716 L
.07005 .45751 L
.07004 .45784 L
.07003 .45814 L
.07003 .4584 L
.07002 .45859 L
.07002 .45877 L
.07002 .45892 L
.07002 .45904 L
.07002 .45911 L
.07002 .45916 L
.07001 .45922 L
.07001 .45929 L
.07001 .45937 L
.07001 .45943 L
.07 .45945 L
.07 .45944 L
.07001 .45933 L
.07001 .45915 L
Mistroke
.07002 .45896 L
.07002 .45875 L
.07003 .45851 L
.07003 .45827 L
.07004 .45804 L
.07004 .45781 L
.07005 .45756 L
.07006 .45731 L
.07006 .45708 L
.07007 .45688 L
.07007 .4567 L
.07007 .45653 L
.07008 .45642 L
.07008 .45634 L
.07008 .4563 L
.07008 .45633 L
.07008 .45639 L
.07008 .45626 L
.07008 .45648 L
.07007 .45677 L
.07006 .45715 L
.07005 .45762 L
.07004 .45817 L
.07002 .45875 L
.07001 .45929 L
.07 .45974 L
.06999 .46007 L
.06998 .4603 L
.06998 .46036 L
.06998 .46027 L
.06999 .45999 L
.07 .45959 L
.07002 .45913 L
.07003 .45864 L
.07004 .45819 L
.07005 .45776 L
.07005 .45737 L
.07006 .457 L
.07006 .45663 L
.07007 .45636 L
.07008 .45613 L
.07008 .45596 L
.07009 .45584 L
.07009 .45578 L
.07009 .45578 L
.07009 .4558 L
.07009 .4558 L
.07009 .45579 L
.07009 .45578 L
.07009 .45577 L
Mistroke
.07009 .45576 L
.07009 .45576 L
.07009 .45576 L
.07009 .45575 L
.07009 .45576 L
.07009 .45578 L
.07009 .45579 L
.07009 .45578 L
.0701 .45575 L
.0701 .45571 L
.07011 .45566 L
.07012 .45562 L
.07012 .45558 L
.07013 .45555 L
.07013 .45554 L
.07013 .45554 L
.07013 .45556 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45557 L
.07013 .45555 L
.07013 .45554 L
.07013 .45553 L
.07013 .45555 L
.07012 .45558 L
.07012 .45562 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45562 L
.07012 .45557 L
.07013 .45552 L
.07013 .45549 L
.07013 .45549 L
.07013 .45552 L
.07012 .45557 L
.07012 .45561 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45563 L
.07012 .45558 L
.07013 .45555 L
.07013 .45553 L
Mistroke
.07013 .45553 L
.07013 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .4556 L
.07009 .45563 L
.07005 .45567 L
.07001 .4557 L
.06999 .45572 L
.07 .45571 L
.07006 .45565 L
.07016 .45556 L
.07032 .45541 L
.07054 .45522 L
.07079 .45501 L
.07107 .45476 L
.07136 .45451 L
.07163 .45425 L
.07189 .454 L
.07215 .45375 L
.07242 .45352 L
.07266 .45333 L
.07285 .45317 L
.07298 .45306 L
.07305 .45299 L
.07307 .45297 L
.07306 .45299 L
.07303 .45303 L
.07298 .45307 L
.07295 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07293 .4531 L
.0729 .45308 L
.07286 .45304 L
.07283 .453 L
.07281 .45298 L
.07282 .453 L
.07287 .45305 L
.07297 .45314 L
.07312 .45328 L
.07333 .45346 L
.07357 .45368 L
.07383 .45391 L
.0741 .45416 L
.07436 .4544 L
.0746 .45465 L
.07485 .45489 L
.0751 .45511 L
.07533 .4553 L
.07551 .45545 L
.07563 .45556 L
.0757 .45562 L
.07572 .45564 L
.07571 .45562 L
.07567 .45559 L
.07563 .45555 L
.0756 .45552 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45547 L
.07562 .45541 L
.07567 .45534 L
.07571 .45527 L
.07571 .45523 L
.07569 .45526 L
.07563 .45536 L
.0755 .45555 L
.0753 .45584 L
.07504 .45621 L
.07476 .45665 L
.07447 .45713 L
.07419 .45763 L
.07391 .45812 L
.07367 .45861 L
.07339 .45909 L
.07312 .45955 L
.07288 .45995 L
.07271 .46027 L
.07262 .46049 L
.07257 .46061 L
.07256 .46065 L
.07258 .46062 L
.07263 .46055 L
.07267 .46047 L
.07269 .46041 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46044 L
.07269 .4605 L
.07268 .46057 L
.07269 .46058 L
.07272 .46052 L
Mistroke
.07276 .46037 L
.07281 .46017 L
.07283 .45993 L
.07283 .45967 L
.07279 .45943 L
.07269 .45925 L
.07254 .45912 L
.07233 .45904 L
.07208 .45902 L
.0718 .45902 L
.07153 .45905 L
.07127 .45908 L
.07102 .4592 L
.07076 .45939 L
.07049 .45966 L
.07024 .45998 L
.07005 .46031 L
.06991 .4606 L
.06984 .4608 L
.06981 .46086 L
.06983 .46076 L
.06987 .46051 L
.06993 .46017 L
.06997 .45976 L
.06999 .4593 L
.07001 .45882 L
.07003 .45832 L
.07005 .45782 L
.07006 .45733 L
.07008 .45686 L
.0701 .45641 L
.07011 .45601 L
.07012 .45569 L
.07013 .45547 L
.07013 .45535 L
.07013 .45531 L
.07013 .45533 L
.07013 .45539 L
.07013 .45546 L
.07013 .4555 L
.07012 .45549 L
.07012 .45545 L
.07012 .45542 L
.07012 .45544 L
.07012 .45551 L
.07011 .45567 L
.0701 .4559 L
.07009 .45624 L
.07008 .45668 L
.07006 .45711 L
Mistroke
.07005 .4576 L
.07003 .4581 L
.07002 .45855 L
.07001 .45901 L
.07 .45946 L
.06999 .45987 L
.06998 .4602 L
.06998 .46041 L
.06998 .46048 L
.06998 .46036 L
.06999 .46012 L
.07 .45971 L
.07001 .45917 L
.07003 .45866 L
.07004 .45816 L
.07005 .45774 L
.07006 .45745 L
.07006 .45723 L
.07006 .45709 L
.07006 .45702 L
.07006 .45699 L
.07006 .45701 L
.07006 .45706 L
.07005 .4571 L
.07005 .45716 L
.07005 .4572 L
.07005 .45724 L
.07005 .45727 L
.07006 .45714 L
.07007 .45697 L
.07008 .45668 L
.07009 .45636 L
.0701 .45605 L
.07011 .45579 L
.07012 .45559 L
.07013 .45547 L
.07013 .45543 L
.07013 .45542 L
.07013 .45545 L
.07013 .4555 L
.07012 .45554 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .4556 L
.07013 .45562 L
.07017 .45566 L
.07026 .4557 L
.07029 .45571 L
.07027 .4557 L
.0702 .45565 L
Mistroke
.07005 .45556 L
.06976 .45542 L
.0693 .45524 L
.06872 .45503 L
.06817 .4548 L
.0677 .45456 L
.06725 .45432 L
.06679 .45407 L
.06631 .45384 L
.06582 .45362 L
.06532 .45342 L
.06492 .45325 L
.0647 .45308 L
.06461 .45292 L
.06458 .4528 L
.0646 .45277 L
.06467 .45284 L
.06473 .45302 L
.06474 .45332 L
.06472 .45375 L
.0647 .45431 L
.06468 .45497 L
.06465 .45568 L
.06463 .45642 L
.0646 .45713 L
.06457 .45782 L
.06455 .45851 L
.06453 .45919 L
.06451 .45981 L
.06449 .4603 L
.06448 .46063 L
.06447 .46081 L
.06447 .46087 L
.06447 .46084 L
.06445 .46075 L
.06442 .46063 L
.06438 .46055 L
.06436 .46052 L
.06437 .46051 L
.06441 .46051 L
.06449 .46051 L
.06463 .46051 L
.06482 .4605 L
.06506 .4605 L
.06533 .46049 L
.0656 .46049 L
.06584 .46049 L
.06605 .46048 L
.06629 .46048 L
.06656 .46048 L
Mistroke
.06684 .46049 L
.06711 .46051 L
.06738 .46054 L
.06766 .46059 L
.06796 .46064 L
.06823 .46066 L
.06848 .46061 L
.06871 .46049 L
.06893 .46028 L
.06918 .45999 L
.06944 .45964 L
.06967 .45925 L
.06988 .45891 L
.07004 .45862 L
.07014 .45844 L
.07019 .45828 L
.07019 .45815 L
.07016 .45801 L
.0701 .45787 L
.07007 .45772 L
.07005 .45759 L
.07004 .45749 L
.07005 .45735 L
.07007 .45728 L
.07009 .4572 L
.07009 .45712 L
.07008 .45692 L
.07008 .45663 L
.07009 .4563 L
.0701 .45597 L
.07012 .4557 L
.07012 .45551 L
.07013 .45541 L
.07013 .45538 L
.07013 .4554 L
.07013 .45545 L
.07013 .45551 L
.07012 .45556 L
.07011 .45558 L
.07007 .4556 L
.07003 .45563 L
.06999 .45567 L
.06997 .4557 L
.06998 .45572 L
.07004 .45571 L
.07015 .45565 L
.07032 .45555 L
.07053 .45541 L
.07078 .45522 L
.07106 .455 L
Mistroke
.07135 .45476 L
.07163 .45451 L
.07192 .45425 L
.07219 .454 L
.07246 .45375 L
.07269 .45352 L
.07287 .45332 L
.073 .45317 L
.07307 .45306 L
.0731 .45299 L
.07308 .45297 L
.07304 .45299 L
.07299 .45303 L
.07296 .45307 L
.07294 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07296 .45309 L
.07299 .45301 L
.07304 .4529 L
.07308 .4528 L
.0731 .45276 L
.07308 .4528 L
.07302 .45296 L
.0729 .45325 L
.07273 .45369 L
.0725 .45426 L
.07224 .45493 L
.07194 .4557 L
.07163 .45652 L
.07133 .45732 L
.07103 .45807 L
.07073 .45879 L
.07046 .45945 L
.07022 .45998 L
.07003 .46029 L
.0699 .46033 L
.06984 .46012 L
.06983 .45974 L
.06986 .45923 L
.06992 .45864 L
Mistroke
.06999 .45802 L
.07004 .45743 L
.07008 .4569 L
.0701 .45643 L
.07011 .45602 L
.07012 .45568 L
.07013 .4554 L
.07014 .4552 L
.07014 .45509 L
.07014 .45508 L
.07014 .45517 L
.07013 .45535 L
.07012 .45561 L
.07011 .45592 L
.0701 .45629 L
.07008 .45674 L
.07006 .45725 L
.07005 .45775 L
.07003 .45822 L
.07002 .45869 L
.07 .45916 L
.06999 .4596 L
.06999 .45997 L
.06998 .46024 L
.06998 .46042 L
.06998 .46052 L
.06998 .46056 L
.06998 .46052 L
.06999 .46045 L
.06999 .46036 L
.06999 .46029 L
.06999 .46027 L
.06998 .46029 L
.06998 .46032 L
.06997 .46036 L
.06996 .46039 L
.06996 .46042 L
.06995 .46044 L
.06995 .46046 L
.06995 .46045 L
.06995 .46044 L
.06996 .46043 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46044 L
.06995 .46048 L
.06995 .46054 L
.06995 .46061 L
.06995 .46064 L
.06995 .46059 L
.06996 .46047 L
.06997 .46027 L
.06998 .46004 L
.06999 .4598 L
.07 .45957 L
.07 .45935 L
.07001 .45915 L
.07002 .45891 L
.07003 .45871 L
.07003 .45854 L
.07004 .45842 L
.07004 .45837 L
.07004 .45837 L
.07004 .4584 L
.07004 .45845 L
.07003 .45854 L
.07002 .45865 L
.07 .45876 L
.06997 .45885 L
.06995 .45885 L
.06996 .45876 L
.07 .45859 L
.07006 .45839 L
.07014 .45819 L
.07023 .45799 L
.07032 .45776 L
.0704 .45751 L
.07046 .45721 L
.0705 .45693 L
.07052 .45664 L
.07054 .45639 L
.07054 .45619 L
.07054 .45597 L
.07052 .45581 L
.07048 .45562 L
.07041 .45545 L
.07032 .45534 L
.07024 .45534 L
.07015 .45545 L
.07008 .45564 L
.07003 .45592 L
.07001 .45621 L
.07002 .45657 L
.07004 .45698 L
Mistroke
.07004 .45743 L
.07004 .4579 L
.07002 .4584 L
.07001 .45895 L
.06999 .45941 L
.06998 .45988 L
.06997 .46026 L
.06996 .4605 L
.06996 .46059 L
.06997 .4605 L
.06997 .46028 L
.06998 .45998 L
.06999 .45967 L
.07 .45937 L
.07001 .45913 L
.07002 .45889 L
.07002 .45868 L
.07003 .45845 L
.07004 .45823 L
.07005 .45805 L
.07005 .45794 L
.07005 .45793 L
.07005 .45803 L
.07004 .4582 L
.07003 .45845 L
.07003 .45877 L
.07002 .45906 L
.07001 .45931 L
.07001 .45944 L
.07 .45958 L
.06999 .45974 L
.06999 .45993 L
.06998 .46013 L
.06997 .46032 L
.06996 .46045 L
.06995 .46054 L
.06995 .46057 L
.06995 .46057 L
.06995 .46053 L
.06995 .46047 L
.06996 .46044 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06997 .46042 L
.07001 .46042 L
.07005 .46042 L
.07009 .46042 L
.07011 .46042 L
.07009 .46042 L
.07003 .46043 L
.06992 .46044 L
.06976 .46044 L
Mistroke
.06956 .46044 L
.06932 .46046 L
.06905 .46051 L
.06877 .46057 L
.06849 .46062 L
.06821 .46064 L
.06795 .46059 L
.0677 .46045 L
.06748 .46022 L
.06731 .45987 L
.0672 .45953 L
.06714 .4591 L
.06714 .45863 L
.06717 .45816 L
.06722 .45771 L
.06728 .45723 L
.06733 .45677 L
.06736 .45635 L
.06737 .45599 L
.06738 .4557 L
.06739 .45549 L
.06739 .45537 L
.0674 .45535 L
.0674 .45539 L
.06739 .45546 L
.06739 .45554 L
.06739 .45559 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45564 L
.06739 .45567 L
.06738 .45571 L
.06738 .45574 L
.06738 .45576 L
.06738 .45575 L
.06738 .45569 L
.06739 .4556 L
Mistroke
.06739 .45545 L
.0674 .45527 L
.06741 .45506 L
.06741 .45482 L
.06742 .45457 L
.06743 .45432 L
.06744 .45407 L
.06745 .45382 L
.06746 .4536 L
.06746 .4534 L
.06747 .45325 L
.06747 .45314 L
.06747 .45308 L
.06746 .45306 L
.06743 .45307 L
.06738 .45311 L
.06734 .45315 L
.06732 .45318 L
.06733 .4532 L
.06739 .4532 L
.06749 .4532 L
.06765 .4532 L
.06785 .4532 L
.06809 .45319 L
.06834 .45319 L
.06858 .45318 L
.06881 .45318 L
.06905 .45318 L
.0693 .45317 L
.06955 .45317 L
.0698 .45317 L
.07006 .45316 L
.07033 .45316 L
.07062 .45315 L
.07094 .45315 L
.07129 .45314 L
.07167 .45314 L
.07205 .45313 L
.07247 .45313 L
.07294 .45312 L
.07343 .45311 L
.07394 .45311 L
.07441 .4531 L
.0749 .45309 L
.0754 .45308 L
.07591 .45308 L
.07642 .45307 L
.07694 .45306 L
.07747 .45305 L
.07795 .45303 L
Mistroke
.07843 .45299 L
.07889 .45295 L
.07935 .45291 L
.07978 .45288 L
.0802 .45289 L
.08062 .45293 L
.08101 .45302 L
.08137 .45316 L
.08169 .45334 L
.08198 .45355 L
.08224 .45378 L
.08249 .45403 L
.08271 .45428 L
.08293 .45453 L
.08315 .45476 L
.08337 .45498 L
.08357 .45518 L
.08373 .45533 L
.08384 .45544 L
.08391 .4555 L
.08392 .45551 L
.08391 .4555 L
.08387 .45546 L
.08382 .45542 L
.08379 .45539 L
.08378 .45538 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08377 .45537 L
.08376 .45537 L
.08373 .45537 L
.08369 .45538 L
.08365 .45537 L
.08363 .45535 L
.08363 .45529 L
.08367 .45522 L
.08374 .45514 L
.08386 .4551 L
.08402 .45511 L
.08423 .45518 L
.0845 .4553 L
.0848 .4555 L
.08516 .45579 L
.08554 .45619 L
.08598 .45668 L
Mistroke
.08647 .45729 L
.087 .45798 L
.08755 .45875 L
.08809 .45959 L
.08862 .46045 L
.08913 .4613 L
.0896 .46211 L
.09004 .46283 L
.09043 .46345 L
.09078 .46397 L
.09109 .46439 L
.09135 .4647 L
.09154 .46493 L
.09167 .46508 L
.09174 .46517 L
.09178 .46519 L
.09178 .46516 L
.09176 .46509 L
.09172 .46501 L
.09168 .46494 L
.09164 .46491 L
.09163 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.0916 .46489 L
Mistroke
.09157 .46486 L
.09153 .46482 L
.09147 .46479 L
.09142 .46477 L
.09139 .46479 L
.09141 .46484 L
.09147 .46494 L
.09158 .46508 L
.09174 .46526 L
.09196 .46547 L
.09226 .46572 L
.09265 .46599 L
.09313 .46627 L
.0937 .46655 L
.09439 .4668 L
.09521 .467 L
.09611 .46713 L
.09716 .46717 L
.09841 .46713 L
.0998 .46701 L
.10145 .46684 L
.10341 .46663 L
.10548 .46638 L
.10816 .46608 L
.11073 .46574 L
.1142 .46535 L
.11727 .46494 L
.12073 .4645 L
.1251 .46402 L
.12833 .46353 L
.13221 .46303 L
.13615 .46252 L
.14013 .46195 L
.14321 .4613 L
.14651 .46052 L
.14994 .45957 L
.15249 .45845 L
.1551 .45716 L
.15743 .45573 L
.15957 .45413 L
.16164 .45226 L
.16362 .4502 L
.16521 .4479 L
.16697 .44522 L
.16867 .44246 L
.17047 .43935 L
.17237 .43607 L
.1742 .4326 L
.17612 .42921 L
.17783 .42564 L
Mistroke
.1794 .42195 L
.18081 .41841 L
.18192 .41448 L
.18285 .41076 L
.18349 .40691 L
.18391 .40286 L
.18412 .39929 L
.18415 .3957 L
.18403 .39223 L
.18384 .38917 L
.18358 .38615 L
.1833 .38329 L
.1831 .38089 L
.18299 .37857 L
.18297 .37657 L
.18311 .37479 L
.18344 .37327 L
.18393 .37207 L
.18452 .37098 L
.18517 .36999 L
.18585 .36904 L
.18653 .36809 L
.18719 .36708 L
.18782 .36595 L
.18842 .36473 L
.18902 .36336 L
.18963 .36181 L
.19026 .36008 L
.19087 .35801 L
.19148 .35562 L
.19207 .35283 L
.19265 .34951 L
.19316 .34602 L
.19364 .34222 L
.19404 .33798 L
.19433 .33392 L
.1945 .3297 L
.19458 .32479 L
.19462 .32083 L
.19462 .31634 L
.19466 .31184 L
.19481 .30729 L
.19513 .30283 L
.19566 .29792 L
.19644 .29325 L
.19749 .28777 L
.1988 .28252 L
.20012 .27687 L
.20171 .27062 L
.20339 .2642 L
Mistroke
.20533 .25781 L
.20738 .25006 L
.20949 .24279 L
.21145 .23677 L
.21347 .22969 L
.21542 .22267 L
.2172 .21518 L
.21882 .2089 L
.22029 .2024 L
.22155 .19601 L
.22266 .19006 L
.22356 .18415 L
.22425 .17884 L
.22475 .17353 L
.22501 .16895 L
.22506 .1644 L
.2249 .16066 L
.22457 .15735 L
.22408 .15454 L
.22347 .15229 L
.22283 .15059 L
.22217 .14933 L
.2215 .14846 L
.22093 .14794 L
.22042 .14768 L
.22001 .14758 L
.21972 .14758 L
.21956 .14766 L
.21947 .14781 L
.21944 .14801 L
.21944 .14825 L
.21943 .1485 L
.21938 .14871 L
.21926 .14887 L
.21906 .14898 L
.21881 .14908 L
.21853 .14917 L
.21827 .14925 L
.21805 .14931 L
.21788 .14935 L
.21776 .14939 L
.2177 .14937 L
.2177 .14927 L
.21774 .1491 L
.21782 .14883 L
.21795 .14847 L
.21816 .14799 L
.21843 .1474 L
.21877 .14671 L
.21916 .14593 L
Mistroke
.2196 .14508 L
.22007 .14417 L
.2206 .14321 L
.22119 .14222 L
.22182 .14122 L
.22242 .14027 L
.22311 .13942 L
.22379 .13868 L
.2245 .13807 L
.2252 .13758 L
.22584 .13723 L
.22637 .137 L
.2268 .1369 L
.22712 .13691 L
.22733 .13697 L
.22745 .13705 L
.22748 .13712 L
.22745 .13714 L
.22738 .13711 L
.22731 .137 L
.22724 .13683 L
.22721 .13662 L
.22721 .1364 L
.22726 .13616 L
.22737 .13592 L
.22752 .13571 L
.22771 .13554 L
.22795 .13541 L
.22823 .1353 L
.22857 .1352 L
.22897 .13508 L
.22943 .13494 L
.22994 .13476 L
.23048 .13452 L
.23103 .13422 L
.23156 .13387 L
.23206 .13346 L
.23254 .13302 L
.23299 .13258 L
.23343 .13217 L
.23386 .13179 L
.23431 .13145 L
.2348 .13113 L
.23533 .13082 L
.23591 .13053 L
.23654 .13025 L
.23719 .12997 L
.23793 .12967 L
.23872 .12935 L
.2395 .12901 L
Mistroke
.2403 .12862 L
.24113 .12821 L
.24191 .12779 L
.24267 .12739 L
.24342 .12705 L
.24408 .12674 L
.24471 .12653 L
.2453 .12642 L
.24589 .12638 L
.24651 .12635 L
.24716 .12628 L
.24794 .12613 L
.2489 .12583 L
.25002 .12532 L
.25139 .12458 L
.25295 .1236 L
.2548 .12237 L
.25694 .12089 L
.25925 .11953 L
.26175 .11771 L
.26444 .11607 L
.26722 .1142 L
.27018 .11228 L
.27347 .11033 L
.27653 .10845 L
.27972 .10649 L
.28286 .10476 L
.28607 .10303 L
.28887 .10141 L
.29158 .09985 L
.294 .09863 L
.29613 .09744 L
.29808 .09635 L
.29972 .09552 L
.30095 .09481 L
.30198 .09425 L
.30277 .09382 L
.3033 .09353 L
.30359 .09337 L
.30369 .09334 L
.30362 .0934 L
.30344 .09354 L
.30322 .0937 L
.30302 .09382 L
.30292 .09387 L
.30295 .09383 L
.30314 .09368 L
.30349 .09344 L
.30395 .09315 L
.30451 .0928 L
Mistroke
.30516 .09242 L
.30588 .09199 L
.30659 .09152 L
.30737 .09104 L
.30826 .09053 L
.30907 .08999 L
.30988 .08947 L
.31062 .08898 L
.31125 .08856 L
.31175 .0882 L
.31211 .08793 L
.3124 .08772 L
.31262 .08755 L
.31282 .08742 L
.31303 .0873 L
.31327 .0872 L
.31353 .08712 L
.3138 .08708 L
.31406 .08707 L
.3143 .0871 L
.31451 .08714 L
.31472 .08719 L
.31494 .08723 L
.31515 .08725 L
.31535 .08726 L
.3155 .08726 L
.31561 .08727 L
.31568 .08727 L
.31569 .08727 L
.31567 .08727 L
.31562 .08727 L
.31555 .08727 L
.31548 .08726 L
.31543 .08726 L
.31541 .08726 L
.31542 .08726 L
.31547 .08726 L
.31557 .08727 L
.31572 .08727 L
.31591 .08728 L
.31613 .08729 L
.31637 .0873 L
.31663 .08731 L
.31689 .08732 L
.31715 .08732 L
.3174 .08733 L
.31765 .08734 L
.31787 .08735 L
.31809 .08736 L
.3183 .08737 L
Mistroke
.31845 .08738 L
.31849 .08738 L
.31842 .08738 L
.31822 .08737 L
.31786 .08736 L
.31733 .08734 L
.31662 .08731 L
.31579 .08729 L
.31495 .08726 L
.31416 .08723 L
.3135 .0872 L
.31291 .08717 L
.31235 .08715 L
.31185 .08716 L
.31153 .08721 L
.31148 .08729 L
.31176 .08736 L
.31229 .08743 L
.31306 .08747 L
.31401 .08746 L
.31503 .08737 L
.31613 .08716 L
.31719 .08684 L
.31818 .0864 L
.31915 .08584 L
.32008 .08516 L
.32112 .08443 L
.32218 .08363 L
.32337 .08275 L
.32469 .08181 L
.32602 .08085 L
.32758 .08001 L
.32908 .07923 L
.33062 .07855 L
.33227 .07798 L
.33369 .07756 L
.33517 .07724 L
.33656 .07701 L
.33768 .07681 L
.33867 .07662 L
.33948 .0764 L
.34007 .07613 L
.34042 .07581 L
.34058 .07539 L
.34065 .07499 L
.3407 .07451 L
.34077 .07406 L
.34085 .07357 L
.34097 .0732 L
.34114 .07283 L
Mistroke
.34134 .07257 L
.3415 .07246 L
.34161 .07251 L
.34167 .07271 L
.34168 .07304 L
.34164 .07345 L
.34154 .07394 L
.34141 .07445 L
.34122 .07497 L
.34099 .07547 L
.34075 .07592 L
.34051 .0763 L
.34031 .07659 L
.34016 .0768 L
.34009 .07692 L
.34007 .07696 L
.34008 .07694 L
.34012 .07688 L
.34016 .0768 L
.34019 .07674 L
.34019 .07671 L
.34014 .07671 L
.34007 .0767 L
.33998 .0767 L
.33991 .0767 L
.33988 .07669 L
.33995 .0767 L
.34012 .0767 L
.34041 .07671 L
.34083 .07673 L
.34137 .07675 L
.34202 .07677 L
.34273 .0768 L
.34339 .07682 L
.34411 .07685 L
.34488 .07688 L
.34556 .07691 L
.3462 .07693 L
.34679 .07695 L
.34726 .07697 L
.34759 .07698 L
.34777 .07699 L
.34782 .077 L
.34778 .07703 L
.3477 .07706 L
.34765 .07707 L
.34765 .07706 L
.34771 .07704 L
.34784 .07702 L
.348 .077 L
Mistroke
.34815 .07697 L
.34828 .0769 L
.34837 .07677 L
.34843 .07657 L
.34846 .07631 L
.34846 .07598 L
.34844 .07566 L
.3484 .07534 L
.34832 .07498 L
.3482 .07462 L
.34805 .07427 L
.34789 .07392 L
.34773 .07355 L
.34759 .07318 L
.34749 .07283 L
.34745 .07259 L
.34745 .07245 L
.34748 .07239 L
.34752 .07244 L
.34755 .07265 L
.34756 .073 L
.34757 .07343 L
.34757 .07389 L
.34757 .07436 L
.34757 .07481 L
.34757 .07525 L
.34757 .07572 L
.34757 .07618 L
.34757 .07657 L
.34757 .07687 L
.34757 .07707 L
.34757 .07719 L
.34757 .07723 L
.34757 .07721 L
.34757 .07714 L
.34757 .07707 L
.34757 .07701 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
Mistroke
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34756 .07698 L
.34754 .077 L
.34747 .07705 L
.34739 .07713 L
.3473 .0772 L
.34722 .07726 L
.34717 .07729 L
.34716 .07728 L
.34723 .0772 L
.34741 .07704 L
.34773 .07678 L
.34822 .07641 L
.34892 .0759 L
.34985 .07523 L
.35091 .0744 L
.35216 .07344 L
.35369 .07231 L
.35539 .07099 L
.35749 .06957 L
Mistroke
.35949 .06802 L
.3618 .06636 L
.36423 .06462 L
.36676 .06289 L
.36952 .06116 L
.37189 .05939 L
.37439 .05779 L
.37699 .0562 L
.37913 .05478 L
.38119 .0535 L
.3831 .0525 L
.38465 .05169 L
.38613 .05108 L
.3874 .05067 L
.3884 .05043 L
.38918 .05033 L
.38972 .05029 L
.39007 .05036 L
.39028 .0505 L
.3904 .05068 L
.39051 .05086 L
.39065 .05097 L
.39087 .05096 L
.39115 .05084 L
.39149 .05064 L
.39191 .05034 L
.3924 .05003 L
.39296 .04967 L
.39357 .04925 L
.39432 .04886 L
.39519 .04853 L
.39627 .04819 L
.39736 .04789 L
.39861 .04763 L
.4 .04728 L
.40149 .04712 L
.40282 .04699 L
.40424 .04693 L
.40557 .04695 L
.40687 .04703 L
.40805 .04714 L
.4092 .04724 L
.41022 .04731 L
.41119 .04736 L
.412 .04739 L
.41269 .04741 L
.41327 .04743 L
.41372 .04745 L
.41407 .04746 L
.41436 .04747 L
Mistroke
.41458 .04748 L
.41476 .04749 L
.41493 .04749 L
.41508 .0475 L
.41521 .0475 L
.41532 .04751 L
.41539 .04751 L
.41541 .04751 L
.41538 .04751 L
.41531 .04751 L
.41522 .0475 L
.41514 .0475 L
.41509 .0475 L
.41513 .0475 L
.41525 .0475 L
.41548 .04751 L
.4158 .04752 L
.4162 .04754 L
.41668 .04756 L
.4172 .04758 L
.41777 .0476 L
.4184 .04762 L
.41908 .04764 L
.41986 .04767 L
.42063 .0477 L
.4215 .04773 L
.42244 .04776 L
.42348 .04779 L
.42459 .04783 L
.42569 .04787 L
.4269 .04791 L
.42824 .04795 L
.42965 .048 L
.43118 .04805 L
.43284 .04811 L
.43452 .04817 L
.43631 .04823 L
.43816 .04829 L
.44002 .04835 L
.44186 .04841 L
.44368 .04847 L
.44549 .04853 L
.44727 .04859 L
.44898 .04865 L
.45064 .0487 L
.45222 .04875 L
.45362 .0488 L
.45487 .04884 L
.45599 .04888 L
.45692 .04892 L
Mistroke
.45774 .04895 L
.45849 .04898 L
.4592 .049 L
.45992 .04901 L
.46069 .04901 L
.46156 .04901 L
.46257 .04902 L
.46372 .04903 L
.4649 .04904 L
.46625 .04908 L
.46772 .04912 L
.46936 .04917 L
.4711 .04923 L
.4729 .04927 L
.47461 .04931 L
.47637 .04936 L
.47813 .04941 L
.47985 .04946 L
.48143 .04951 L
.48301 .04957 L
.4845 .04963 L
.48599 .04968 L
.4873 .04974 L
.48852 .04977 L
.48966 .0498 L
.49064 .04983 L
.49151 .04987 L
.4922 .04991 L
.49275 .04995 L
.49318 .04999 L
.49348 .05002 L
.49365 .05005 L
.4937 .05006 L
.49364 .05006 L
.49353 .05005 L
.4934 .05004 L
.4933 .05003 L
.49326 .05002 L
.49327 .05002 L
.49335 .05003 L
.49348 .05003 L
.49366 .05004 L
.49387 .05004 L
.4941 .05005 L
.49434 .05006 L
.49458 .05006 L
.49482 .05007 L
.49506 .05008 L
.49527 .05008 L
.49546 .05009 L
Mistroke
.49561 .05009 L
.49572 .0501 L
.49578 .0501 L
.4958 .0501 L
.49578 .0501 L
.49575 .0501 L
.49571 .0501 L
.49567 .0501 L
.49564 .05009 L
.49559 .05009 L
.49552 .05009 L
.49544 .05009 L
.49533 .05009 L
.49522 .05008 L
.49516 .05008 L
.49517 .05008 L
.49529 .05008 L
.49557 .05009 L
.49602 .0501 L
.49669 .05012 L
.49772 .05015 L
.4989 .05019 L
.50033 .05023 L
.50208 .05028 L
.5039 .05033 L
.50591 .05039 L
.50803 .05046 L
.51009 .05052 L
.51212 .05058 L
.51414 .05064 L
.51575 .05069 L
.51747 .05073 L
.51868 .05077 L
.51969 .0508 L
.5205 .05082 L
.5211 .05083 L
.52148 .05084 L
.52167 .05084 L
.52173 .05084 L
.5217 .05084 L
.52161 .05084 L
.52149 .05083 L
.52136 .05083 L
.52128 .05083 L
.52124 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
Mistroke
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52122 .05083 L
.52119 .05082 L
.52115 .05082 L
.5211 .05082 L
.52105 .05082 L
.521 .05082 L
.52095 .05082 L
.52091 .05082 L
.52092 .05082 L
.52103 .05082 L
.52125 .05083 L
.5216 .05084 L
.52214 .05085 L
.52289 .05087 L
.52385 .0509 L
.52509 .05093 L
.52642 .05097 L
.52815 .05102 L
.53 .05106 L
.53171 .05112 L
.53383 .05117 L
.53605 .05124 L
.53834 .0513 L
.54065 .05136 L
.54293 .05142 L
.54511 .05148 L
.54712 .05154 L
.54894 .05159 L
.55074 .05163 L
.55206 .05167 L
.55336 .0517 L
.55431 .05172 L
Mistroke
.55508 .05174 L
.55566 .05176 L
.55604 .05177 L
.55624 .05177 L
.55631 .05177 L
.55628 .05177 L
.55619 .05177 L
.55606 .05176 L
.55594 .05176 L
.55585 .05176 L
.55582 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.55577 .05176 L
.5557 .05175 L
.5556 .05175 L
.55549 .05175 L
.55542 .05174 L
.5554 .05174 L
.55546 .05175 L
.55562 .05175 L
.55588 .05176 L
.55628 .05177 L
.55684 .05178 L
.55758 .0518 L
.55852 .05182 L
.55949 .05185 L
.5608 .05188 L
.56208 .05191 L
.56371 .05195 L
.56539 .052 L
.56745 .05205 L
.56931 .0521 L
.57143 .05216 L
.57361 .0522 L
.57595 .05223 L
.57797 .05223 L
Mistroke
.58023 .05223 L
.5825 .05226 L
.58432 .05235 L
.58633 .05251 L
.58821 .05272 L
.58981 .05297 L
.59131 .05322 L
.59258 .05344 L
.5937 .05362 L
.59463 .05377 L
.59531 .05392 L
.59586 .05403 L
.59627 .05412 L
.59659 .05423 L
.59683 .05433 L
.597 .05439 L
.59709 .05439 L
.59713 .05432 L
.59711 .0542 L
.59706 .05403 L
.59698 .05386 L
.59691 .05368 L
.59686 .05351 L
.59684 .05349 L
.59684 .0534 L
.59684 .05334 L
.59684 .05323 L
.59684 .05314 L
.59684 .05311 L
.59684 .0532 L
.59684 .05341 L
.59684 .05374 L
.59686 .05419 L
.59688 .05471 L
.59692 .05523 L
.59696 .05575 L
.59697 .05626 L
.59696 .05669 L
.59691 .05698 L
.59682 .05709 L
.59669 .05702 L
.59652 .05676 L
.59632 .05633 L
.59609 .05579 L
.59586 .05519 L
.59562 .05463 L
.59538 .05413 L
.59514 .05373 L
.5949 .05346 L
.59468 .05334 L
Mistroke
.59451 .05339 L
.59439 .05358 L
.59434 .0539 L
.59437 .05433 L
.59448 .05482 L
.59465 .05533 L
.59486 .05586 L
.59509 .05635 L
.59533 .05675 L
.59556 .05705 L
.5958 .05727 L
.59604 .05739 L
.59627 .05744 L
.59649 .05744 L
.5967 .05743 L
.59688 .05743 L
.59702 .05744 L
.59709 .05745 L
.5971 .05742 L
.59703 .05733 L
.59691 .05715 L
.59674 .05689 L
.59654 .05655 L
.59632 .05615 L
.59609 .05572 L
.59586 .05526 L
.59562 .0548 L
.59539 .05436 L
.59516 .05391 L
.59495 .0535 L
.59476 .05314 L
.59461 .05284 L
.5945 .05264 L
.59441 .05253 L
.59436 .05249 L
.59434 .05251 L
.59436 .05258 L
.59441 .05265 L
.59449 .05271 L
.59459 .05274 L
.59473 .05274 L
.5949 .05275 L
.5951 .05275 L
.59532 .05276 L
.59556 .05277 L
.59579 .05277 L
.59603 .05278 L
.59626 .05278 L
.59647 .05279 L
.59665 .05279 L
Mistroke
.59679 .05279 L
.5969 .05279 L
.59695 .05278 L
.59697 .05278 L
.59695 .05277 L
.5969 .05276 L
.59686 .05274 L
.59683 .05272 L
.59683 .05272 L
.59685 .05275 L
.59687 .0528 L
.5969 .05287 L
.59693 .05298 L
.59697 .05315 L
.59702 .05342 L
.59708 .0537 L
.59712 .05405 L
.59714 .05439 L
.59713 .05468 L
.59707 .05485 L
.59697 .05494 L
.59682 .05496 L
.59662 .05494 L
.59639 .05492 L
.59613 .05491 L
.59587 .05492 L
.59561 .05496 L
.59536 .055 L
.59513 .05507 L
.59492 .05516 L
.59475 .05529 L
.59462 .05545 L
.59452 .05569 L
.59446 .05598 L
.59444 .05631 L
.59446 .05665 L
.59449 .05698 L
.59453 .05722 L
.59456 .05735 L
.59458 .05739 L
.59458 .05735 L
.59458 .05729 L
.59458 .05722 L
.59458 .05717 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
Mistroke
.59456 .05715 L
.59454 .05715 L
.5945 .05715 L
.59447 .05715 L
.59445 .05715 L
.59446 .05715 L
.59451 .05715 L
.5946 .05715 L
.59473 .05715 L
.59489 .05716 L
.59507 .05716 L
.59525 .05716 L
.59541 .05717 L
.59556 .05717 L
.59572 .05715 L
.59591 .05711 L
.59611 .05704 L
.59635 .05698 L
.59661 .05696 L
.59693 .05699 L
.59732 .05708 L
.59782 .05727 L
.59846 .05753 L
.59924 .05788 L
.60026 .05828 L
.60145 .05871 L
.6029 .05915 L
.60454 .05961 L
.60649 .06008 L
.60828 .06056 L
.61033 .06102 L
.61259 .06145 L
.61459 .06186 L
.61673 .06224 L
.61885 .06262 L
.62095 .063 L
.62304 .06342 L
.62499 .06387 L
.62686 .06438 L
.62851 .06497 L
.63008 .06559 L
.63141 .06619 L
.63258 .06674 L
.63369 .06724 L
.63474 .06772 L
.63562 .0682 L
.63649 .06866 L
.63735 .06909 L
.63823 .06951 L
.63914 .06991 L
Mistroke
.64006 .07032 L
.64091 .07073 L
.64178 .07115 L
.64273 .07156 L
.64368 .072 L
.64477 .07249 L
.64587 .07301 L
.64711 .07355 L
.64838 .07407 L
.64983 .07457 L
.65131 .07506 L
.65295 .07555 L
.65457 .07608 L
.65629 .07667 L
.65818 .07733 L
.66005 .07808 L
.66194 .07888 L
.66371 .0797 L
.66553 .08052 L
.66696 .08132 L
.66848 .0821 L
.66979 .08283 L
.67107 .08348 L
.6723 .08407 L
.67345 .08458 L
.67464 .08503 L
.6759 .08542 L
.677 .08576 L
.67818 .08612 L
.67949 .08652 L
.68082 .08698 L
.6824 .0875 L
.68411 .0881 L
.68582 .0888 L
.68767 .08963 L
.68948 .09047 L
.69128 .09133 L
.69311 .0922 L
.69476 .09308 L
.69645 .09396 L
.69814 .09475 L
.69979 .09553 L
.70145 .0963 L
.7031 .09703 L
.70473 .09773 L
.7063 .09843 L
.70792 .09917 L
.70954 .09998 L
.71124 .1009 L
.71306 .10182 L
Mistroke
.71505 .10279 L
.71726 .10388 L
.71979 .10512 L
.7224 .10633 L
.72539 .10761 L
.72872 .10915 L
.73213 .11047 L
.73573 .11188 L
.73945 .11338 L
.74362 .11491 L
.74688 .11622 L
.75035 .11748 L
.7539 .11866 L
.75648 .11977 L
.75907 .12079 L
.76147 .1216 L
.76322 .1223 L
.76465 .12289 L
.76564 .12333 L
.76619 .12362 L
.76635 .12377 L
.76623 .12381 L
.76591 .12377 L
.76549 .1237 L
.76503 .12361 L
.76461 .12353 L
.76423 .12345 L
.76391 .12341 L
.76364 .1234 L
.76342 .1234 L
.76323 .1234 L
.76309 .12339 L
.763 .12339 L
.76297 .12339 L
.76301 .12339 L
.76308 .12339 L
.76318 .12338 L
.76328 .12336 L
.76337 .12333 L
.76341 .1233 L
.7634 .12328 L
.76337 .12329 L
.76335 .12335 L
.76334 .12346 L
.76334 .12362 L
.76335 .12381 L
.76335 .12402 L
.76335 .12422 L
.76335 .12439 L
.76335 .12452 L
Mistroke
.76336 .1246 L
.76336 .12462 L
.76336 .12461 L
.76336 .12458 L
.76335 .12454 L
.76335 .12448 L
.76335 .1244 L
.76335 .12429 L
.76335 .12417 L
.76335 .12405 L
.76335 .12394 L
.76335 .12386 L
.76335 .12381 L
.76335 .1238 L
.76335 .12381 L
.76335 .12384 L
.76335 .12384 L
.76335 .12381 L
.76334 .12374 L
.76334 .12364 L
.76334 .12354 L
.76334 .12344 L
.76334 .12337 L
.76334 .12333 L
.76334 .12331 L
.76334 .12333 L
.76334 .12336 L
.76334 .12339 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .12339 L
.76332 .12338 L
.7633 .12338 L
.76326 .12338 L
.76323 .12339 L
.76322 .12341 L
.76323 .12343 L
.76328 .12346 L
.76336 .12348 L
.76349 .12351 L
.76365 .12353 L
.76385 .12355 L
.76406 .12356 L
.76428 .12356 L
.7645 .12357 L
.76473 .12356 L
.76494 .12356 L
Mistroke
.76514 .12354 L
.76532 .12352 L
.76546 .1235 L
.76555 .12347 L
.76561 .12345 L
.76562 .12343 L
.76561 .12342 L
.76558 .12341 L
.76554 .12342 L
.76551 .12343 L
.7655 .12344 L
.7655 .12344 L
.7655 .12343 L
.76548 .12342 L
.76546 .1234 L
.76542 .12336 L
.76539 .12333 L
.76536 .12331 L
.76535 .12332 L
.76536 .12337 L
.76542 .12345 L
.76552 .12357 L
.76568 .12373 L
.76589 .1239 L
.76614 .12406 L
.76643 .12422 L
.76676 .12438 L
.76712 .12458 L
.76751 .12481 L
.76793 .12506 L
.76841 .12535 L
.76893 .12567 L
.7695 .12604 L
.77015 .12648 L
.77087 .12699 L
.77164 .12757 L
.77255 .12821 L
.77362 .1289 L
.77485 .1297 L
.7763 .1306 L
.77776 .13158 L
.77947 .13257 L
.78125 .13353 L
.78318 .13455 L
.78518 .13559 L
.78736 .13662 L
.78911 .13767 L
.79112 .13873 L
.79289 .13971 L
.79436 .14064 L
Mistroke
.79582 .14152 L
.79714 .14234 L
.79831 .14309 L
.79924 .14374 L
.80004 .14435 L
.80073 .14491 L
.80132 .1454 L
.80182 .14582 L
.80222 .14616 L
.80262 .14645 L
.80302 .14671 L
.80339 .14693 L
.80372 .14713 L
.80398 .14729 L
.80419 .14742 L
.80435 .14752 L
.80444 .14756 L
.80446 .14752 L
.80444 .14741 L
.80437 .14723 L
.8043 .147 L
.80424 .14675 L
.80418 .14649 L
.80415 .14624 L
.80415 .14601 L
.80421 .14583 L
.80429 .1457 L
.80439 .14563 L
.80447 .14558 L
.80451 .14555 L
.80448 .14551 L
.80437 .14544 L
.80415 .1453 L
.80384 .14509 L
.80346 .14479 L
.80302 .14442 L
.80255 .14401 L
.8021 .14356 L
.80168 .14313 L
.80126 .14272 L
.80085 .1423 L
.80049 .1419 L
.80021 .14157 L
.80003 .14133 L
.79996 .1412 L
.79996 .14116 L
.79999 .14115 L
.80004 .14114 L
.80007 .14111 L
.80003 .141 L
Mistroke
.79993 .1408 L
.79976 .1405 L
.79957 .14012 L
.79935 .13969 L
.79912 .13925 L
.79888 .13881 L
.79864 .13839 L
.79842 .13797 L
.79825 .13757 L
.79817 .13722 L
.79814 .13693 L
.79809 .13674 L
.79802 .13663 L
.79791 .13659 L
.79773 .13661 L
.79741 .13666 L
.79696 .13673 L
.79639 .13677 L
.79578 .1368 L
.79519 .13681 L
.79462 .13684 L
.79407 .13686 L
.79349 .13686 L
.79287 .13684 L
.79225 .13679 L
.79171 .13669 L
.79127 .13656 L
.79091 .13639 L
.79061 .1362 L
.79036 .13598 L
.79019 .13576 L
.79005 .13552 L
.78987 .13527 L
.78967 .13504 L
.78952 .13483 L
.78946 .13468 L
.7895 .13458 L
.78965 .13453 L
.78988 .13453 L
.79019 .13456 L
.79055 .1346 L
.79096 .13466 L
.79139 .13469 L
.79182 .13471 L
.79225 .1347 L
.79265 .13469 L
.79304 .13473 L
.79343 .13484 L
.79382 .13504 L
.7942 .13535 L
Mistroke
.79459 .13578 L
.79498 .13633 L
.7954 .13701 L
.79585 .1378 L
.79636 .1387 L
.79695 .13968 L
.79763 .14081 L
.79843 .1422 L
.79935 .14355 L
.80033 .145 L
.80142 .14656 L
.80251 .1481 L
.80368 .14969 L
.80491 .15124 L
.80592 .15244 L
.80705 .15368 L
.80815 .15478 L
.80906 .1557 L
.80996 .15658 L
.8108 .15739 L
.81154 .15806 L
.81217 .15857 L
.81267 .15896 L
.8131 .15929 L
.81346 .1596 L
.81376 .15993 L
.81403 .16035 L
.81429 .16085 L
.81456 .16146 L
.81482 .16219 L
.81508 .16297 L
.81533 .16374 L
.81557 .16446 L
.8158 .16509 L
.81603 .16565 L
.81624 .16611 L
.81643 .16649 L
.81659 .16678 L
.81674 .16698 L
.81692 .16712 L
.81711 .1672 L
.81733 .16722 L
.81755 .1672 L
.81777 .16714 L
.81798 .16707 L
.81819 .16702 L
.81838 .16699 L
.81857 .16699 L
.81875 .16699 L
.81894 .167 L
Mistroke
.81914 .167 L
.81934 .167 L
.81951 .16701 L
.81964 .16701 L
.81973 .16701 L
.81979 .16701 L
.8198 .16701 L
.81979 .16701 L
.81976 .16701 L
.81972 .16701 L
.81969 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16699 L
.81968 .16697 L
.81968 .16693 L
.81967 .16687 L
.81965 .1668 L
.81959 .16674 L
.81952 .16671 L
.81945 .16671 L
.81941 .16679 L
.81941 .16698 L
.81947 .1673 L
.81962 .16774 L
.81987 .16832 L
.82023 .16901 L
.82069 .16982 L
.82125 .17073 L
.8219 .17168 L
.82258 .17269 L
.82332 .1738 L
.82414 .17504 L
Mistroke
.82502 .17624 L
.82587 .17751 L
.82672 .17882 L
.8275 .18009 L
.8282 .18136 L
.82881 .18259 L
.82932 .18365 L
.82973 .18468 L
.83006 .18566 L
.83032 .18649 L
.83052 .18725 L
.83065 .1879 L
.83072 .18841 L
.83074 .18873 L
.83074 .18885 L
.83072 .18877 L
.83071 .18854 L
.83072 .18817 L
.83076 .18769 L
.83086 .18722 L
.83103 .18669 L
.83124 .18617 L
.8315 .1857 L
.8318 .18524 L
.83214 .18483 L
.83252 .18449 L
.83292 .18424 L
.83335 .18413 L
.83379 .18417 L
.83424 .1844 L
.8347 .18484 L
.83516 .18549 L
.83561 .18635 L
.83608 .18734 L
.83657 .18851 L
.8371 .18988 L
.8377 .19149 L
.83839 .19317 L
.83917 .19506 L
.84006 .19723 L
.84103 .19938 L
.84209 .20169 L
.84324 .2042 L
.84432 .20638 L
.84543 .20867 L
.84659 .21093 L
.84766 .21289 L
.84884 .21488 L
.85008 .2169 L
.85121 .21865 L
Mistroke
.85241 .22043 L
.85371 .2223 L
.85497 .22415 L
.8564 .22615 L
.85776 .22838 L
.85924 .23068 L
.86104 .23312 L
.86267 .23574 L
.8646 .23878 L
.86666 .2423 L
.86881 .24543 L
.87105 .24904 L
.87329 .25267 L
.87559 .25644 L
.87799 .25996 L
.88026 .26345 L
.88264 .26688 L
.88524 .27044 L
.88751 .27346 L
.88997 .27667 L
.89239 .27969 L
.89473 .2827 L
.89685 .28542 L
.89898 .28811 L
.90112 .29068 L
.90279 .29319 L
.90451 .29547 L
.90626 .29774 L
.90765 .29982 L
.90902 .30175 L
.9103 .30365 L
.91134 .30534 L
.91236 .30691 L
.91325 .30834 L
.91404 .30956 L
.91477 .31065 L
.91548 .31158 L
.91616 .31233 L
.91677 .31289 L
.91733 .31336 L
.91782 .31377 L
.91823 .31415 L
.91857 .31452 L
.91885 .31493 L
.91908 .3154 L
.91928 .31594 L
.91945 .31653 L
.91957 .31714 L
.91965 .31773 L
.91969 .31829 L
Mistroke
.91969 .31886 L
.91969 .31945 L
.91967 .32003 L
.91966 .32054 L
.91964 .32096 L
.91964 .32127 L
.91965 .32145 L
.91965 .32152 L
.91965 .32152 L
.91965 .32145 L
.91965 .32138 L
.91965 .32132 L
.91965 .3213 L
.91965 .32129 L
.91965 .32129 L
.91965 .32128 L
.91965 .32127 L
.91964 .32125 L
.91964 .32123 L
.91964 .32119 L
.91964 .32116 L
.91963 .32113 L
.91963 .32111 L
.91963 .32109 L
.91963 .32109 L
.91963 .3211 L
.91963 .32111 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91964 .32112 L
.91965 .32115 L
.91967 .3212 L
.91971 .32126 L
.91974 .32133 L
.91976 .32138 L
.91975 .32138 L
.91971 .32133 L
.91964 .32122 L
.91954 .32104 L
.91941 .32078 L
.91926 .32042 L
.91907 .31997 L
.91886 .31943 L
.91861 .31881 L
.91834 .3181 L
.91804 .31732 L
Mistroke
.91772 .31646 L
.91736 .31554 L
.91697 .31456 L
.91654 .31351 L
.91609 .31242 L
.91559 .31133 L
.91504 .31017 L
.9144 .30889 L
.91369 .30755 L
.91286 .30608 L
.9119 .30442 L
.9109 .30272 L
.9098 .30091 L
.90871 .29908 L
.90756 .29713 L
.90648 .29542 L
.90535 .29351 L
.90425 .29178 L
.90313 .28998 L
.90197 .28805 L
.90095 .28643 L
.89993 .2848 L
.89892 .28316 L
.89796 .28157 L
.89708 .28014 L
.8964 .27906 L
.89573 .27796 L
.89511 .27691 L
.89459 .27606 L
.89413 .27529 L
.89373 .27462 L
.89342 .2741 L
.89321 .27375 L
.89311 .27357 L
.89311 .27357 L
.89321 .27372 L
.89338 .27399 L
.8936 .27433 L
.89385 .27471 L
.89411 .27511 L
.89438 .27557 L
.89465 .27605 L
.89497 .27662 L
.89535 .27731 L
.8958 .27813 L
.89638 .27913 L
.89702 .28026 L
.89776 .2816 L
.89863 .28321 L
.89967 .28489 L
Mistroke
.90092 .28695 L
.90215 .28905 L
.90351 .29145 L
.90508 .29408 L
.90665 .29691 L
.90838 .29954 L
.91022 .30212 L
.91189 .3048 L
.91345 .30681 L
.91483 .30875 L
.91617 .31079 L
.91713 .31235 L
.91794 .31374 L
.91856 .31493 L
.919 .31594 L
.91929 .3168 L
.91946 .31756 L
.91952 .31823 L
.91952 .31881 L
.91947 .31939 L
.91941 .32008 L
.91933 .32088 L
.91928 .3217 L
.91931 .32248 L
.9194 .32319 L
.91951 .32376 L
.91962 .32425 L
.91971 .32464 L
.91978 .32495 L
.91983 .3252 L
.91985 .3254 L
.91984 .32554 L
.91981 .32562 L
.91979 .32564 L
.91978 .32561 L
.91978 .32555 L
.91978 .32547 L
.91978 .32542 L
.91978 .3254 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91978 .3254 L
.91977 .32542 L
.91976 .32547 L
.91974 .32554 L
.91971 .3256 L
.91968 .32563 L
.91967 .32561 L
Mistroke
.91967 .32552 L
.91971 .32535 L
.91979 .32509 L
.9199 .32477 L
.92004 .32439 L
.92021 .32397 L
.92039 .32353 L
.92059 .32309 L
.92079 .32266 L
.92098 .32224 L
.92117 .32184 L
.92135 .32149 L
.92151 .32121 L
.92163 .32102 L
.92172 .32091 L
.92177 .32087 L
.92178 .3209 L
.92177 .32096 L
.92174 .32103 L
.92171 .32109 L
.92169 .32111 L
.92169 .32114 L
.92171 .32119 L
.92175 .32125 L
.92178 .32132 L
.92179 .32135 L
.92178 .32133 L
.92174 .32124 L
.92165 .32108 L
.92153 .32083 L
.92137 .32051 L
.92119 .32015 L
.921 .31976 L
.92081 .31936 L
.92062 .31895 L
.92041 .31853 L
.92017 .31809 L
.91992 .31764 L
.91966 .3172 L
.91939 .31678 L
.91913 .31639 L
.91888 .31603 L
.91864 .31571 L
.91843 .31542 L
.91825 .31521 L
.91807 .31507 L
.91789 .31501 L
.91771 .31503 L
.91756 .31518 L
.91744 .31548 L
Mistroke
.91737 .31591 L
.91734 .31646 L
.91734 .31705 L
.91738 .31771 L
.91743 .31842 L
.91749 .31907 L
.91754 .3197 L
.91757 .32025 L
.91758 .32072 L
.91759 .32107 L
.9176 .3213 L
.9176 .32142 L
.9176 .32144 L
.9176 .32139 L
.9176 .32131 L
.91759 .32123 L
.91759 .32116 L
.91759 .32113 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91758 .32112 L
.91755 .32112 L
.91752 .32112 L
.91749 .32112 L
.91748 .32112 L
.91749 .32112 L
.91753 .32112 L
.91761 .32112 L
.91773 .32112 L
.91789 .32112 L
.91807 .32112 L
.91827 .32112 L
.91848 .32112 L
.91869 .32112 L
.9189 .32112 L
.91911 .32112 L
.9193 .32112 L
.91946 .32112 L
.91959 .32112 L
.91968 .32112 L
.91974 .32112 L
.91975 .32112 L
.91974 .32112 L
.91971 .32112 L
.91967 .32112 L
Mistroke
.91965 .32112 L
.91964 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32113 L
.91964 .32114 L
.91964 .32113 L
.91963 .32113 L
.91963 .32111 L
.91963 .3211 L
.91963 .32109 L
.91963 .32108 L
.91962 .32108 L
.91962 .32106 L
.91962 .32105 L
.91962 .32103 L
.91962 .32101 L
.91961 .32098 L
.91961 .32094 L
.91961 .32091 L
.91961 .32087 L
.9196 .32085 L
.9196 .32083 L
.9196 .32083 L
.9196 .32083 L
.91961 .32084 L
.91961 .32075 L
.91961 .32078 L
.91961 .3208 L
.91961 .32083 L
.91962 .32089 L
.91962 .32095 L
.91962 .32101 L
.91963 .32107 L
.91963 .32111 L
.91963 .32114 L
.91963 .32115 L
.91964 .32115 L
.91964 .32115 L
.91963 .32114 L
.91963 .32113 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91965 .32112 L
Mistroke
.91972 .32112 L
.91982 .32112 L
.9199 .32111 L
.91994 .32109 L
.91994 .32104 L
.91985 .32098 L
.91965 .32091 L
.91932 .32088 L
.91886 .3209 L
.91826 .32099 L
.91752 .32115 L
.91668 .32137 L
.91589 .32166 L
.9151 .322 L
.9142 .32241 L
.91315 .32287 L
.91192 .32336 L
.91089 .32387 L
.90985 .32438 L
.90879 .32487 L
.90778 .32535 L
.9069 .3258 L
.9062 .32625 L
.90564 .32667 L
.90514 .32709 L
.90472 .32749 L
.90439 .32789 L
.90417 .3283 L
.90412 .32873 L
.90422 .32918 L
.90446 .32962 L
.9048 .33007 L
.90524 .33055 L
.90579 .33106 L
.90637 .33164 L
.90693 .33232 L
.90753 .3331 L
.90825 .33401 L
.90911 .335 L
.91006 .33611 L
.91119 .33736 L
.91251 .33877 L
.91369 .34023 L
.91511 .34175 L
.91651 .3434 L
.91811 .3451 L
.91941 .34681 L
.92075 .34844 L
.92202 .35008 L
.92321 .35166 L
Mistroke
.92418 .35318 L
.92506 .35477 L
.9258 .35633 L
.9264 .35791 L
.92689 .35962 L
.9273 .36139 L
.92767 .36309 L
.92798 .36485 L
.92826 .36657 L
.92851 .3681 L
.92872 .3694 L
.92891 .37055 L
.9291 .37164 L
.92928 .37268 L
.92944 .37362 L
.92957 .37445 L
.92968 .37524 L
.92975 .37601 L
.92979 .37682 L
.9298 .37765 L
.92979 .37843 L
.92979 .37908 L
.9298 .37994 L
.92982 .38098 L
.92986 .38203 L
.92989 .38299 L
.92992 .38379 L
.92994 .38446 L
.92996 .38499 L
.92998 .38538 L
.92999 .38564 L
.92999 .3858 L
.92999 .38588 L
.92999 .38592 L
.92999 .38592 L
.92999 .38586 L
.92999 .38573 L
.92998 .38554 L
.92998 .38531 L
.93 .38502 L
.93002 .38466 L
.93003 .38424 L
.93003 .38374 L
.93 .38317 L
.92994 .38253 L
.92983 .3818 L
.92968 .381 L
.9295 .38015 L
.9293 .37927 L
.9291 .37838 L
Mistroke
.9289 .37746 L
.92871 .3765 L
.92853 .37548 L
.92835 .37433 L
.92817 .37294 L
.92798 .37144 L
.92776 .36963 L
.92749 .36738 L
.9272 .36502 L
.92683 .36218 L
.92639 .35912 L
.92585 .35555 L
.92525 .35173 L
.92454 .34784 L
.9237 .34328 L
.9228 .33947 L
.92174 .33444 L
.92075 .33061 L
.91967 .32647 L
.91851 .32184 L
.91736 .3183 L
.9161 .31452 L
.91489 .31102 L
.91359 .30772 L
.91223 .30463 L
.91088 .30188 L
.90948 .2993 L
.90812 .29691 L
.90675 .29477 L
.90548 .29277 L
.90424 .29093 L
.90314 .28929 L
.90212 .28777 L
.90121 .28645 L
.90044 .2853 L
.89978 .28432 L
.89925 .28348 L
.89882 .2828 L
.89851 .28224 L
.89827 .28174 L
.8981 .28129 L
.89797 .28088 L
.89786 .28049 L
.89777 .28014 L
.89771 .2798 L
.89766 .2795 L
.89763 .27922 L
.89761 .27898 L
.8976 .27876 L
.89762 .2786 L
Mistroke
.89765 .27851 L
.89771 .27851 L
.8978 .27862 L
.89792 .27886 L
.89809 .27924 L
.89829 .27971 L
.89851 .28024 L
.89873 .28084 L
.89894 .28151 L
.89914 .28223 L
.89934 .28295 L
.89954 .2837 L
.89974 .28445 L
.89995 .28521 L
.90017 .28593 L
.9004 .28659 L
.90062 .28715 L
.90082 .28759 L
.90099 .28798 L
.90113 .28831 L
.90124 .28857 L
.90133 .28876 L
.90139 .28885 L
.90141 .28884 L
.90139 .28873 L
.90134 .28852 L
.90126 .2882 L
.90113 .28782 L
.90096 .28738 L
.90075 .2869 L
.90053 .28644 L
.90031 .28593 L
.90008 .28536 L
.89982 .28471 L
.89949 .28396 L
.89906 .28308 L
.8985 .28211 L
.89776 .28101 L
.89683 .27975 L
.89575 .27837 L
.8945 .27682 L
.89319 .2752 L
.89177 .27347 L
.89031 .27163 L
.88897 .26979 L
.88762 .26794 L
.8863 .26613 L
.88508 .26446 L
.88402 .26291 L
.8831 .26148 L
Mistroke
.88234 .26027 L
.88174 .25924 L
.88131 .25839 L
.88099 .25774 L
.88077 .25725 L
.88062 .25692 L
.88052 .25673 L
.88046 .25666 L
.88045 .25668 L
.88048 .25678 L
.88056 .25691 L
.88073 .25709 L
.88096 .25737 L
.8812 .25768 L
.88138 .25798 L
.88146 .2582 L
.8814 .25827 L
.88112 .25812 L
.88051 .25759 L
.87951 .25653 L
.87803 .25487 L
.876 .25248 L
.87396 .24985 L
.87107 .24612 L
.86864 .24263 L
.86549 .23873 L
.8614 .23302 L
.85828 .22876 L
.85438 .22314 L
.85004 .21641 L
.84644 .21082 L
.84266 .20541 L
.83875 .19938 L
.83545 .19407 L
.8322 .18857 L
.829 .18382 L
.82588 .17872 L
.8232 .17438 L
.82083 .17074 L
.8184 .16697 L
.81629 .16356 L
.81434 .16045 L
.81268 .1578 L
.81132 .15556 L
.81018 .15366 L
.80925 .15208 L
.80843 .15072 L
.80771 .14955 L
.80704 .14854 L
.8063 .14758 L
Mistroke
.80543 .14663 L
.80444 .14568 L
.80332 .14472 L
.80201 .14373 L
.80048 .14272 L
.79908 .14177 L
.79746 .14082 L
.79573 .1399 L
.79427 .13903 L
.79253 .13827 L
.79122 .13759 L
.78992 .13702 L
.78893 .1366 L
.78802 .13632 L
.78733 .13618 L
.78691 .13617 L
.78674 .13626 L
.78674 .13641 L
.78682 .13655 L
.78693 .13665 L
.78704 .13669 L
.7871 .13664 L
.78706 .13652 L
.7869 .13635 L
.78669 .13615 L
.78645 .13592 L
.78619 .13569 L
.78593 .13547 L
.78567 .13524 L
.78542 .13502 L
.78521 .13482 L
.78504 .13464 L
.78494 .13451 L
.78493 .13441 L
.78501 .13436 L
.7852 .13434 L
.7855 .13436 L
.78588 .13439 L
.78632 .13441 L
.78681 .13441 L
.78735 .1344 L
.78792 .13439 L
.78851 .13442 L
.78913 .13447 L
.78976 .13457 L
.79036 .13471 L
.79094 .13488 L
.79147 .13508 L
.79194 .13529 L
.79236 .13552 L
Mistroke
.79271 .13575 L
.79301 .13598 L
.79325 .1362 L
.79343 .1364 L
.79356 .13657 L
.79365 .13671 L
.79371 .13681 L
.79374 .13686 L
.79375 .13685 L
.79376 .13679 L
.79376 .13669 L
.79375 .13659 L
.79373 .13653 L
.79367 .13654 L
.79359 .13662 L
.79348 .13679 L
.79334 .13704 L
.7932 .13736 L
.79306 .13774 L
.79295 .13816 L
.79286 .1386 L
.79281 .13903 L
.79278 .13947 L
.79279 .13989 L
.79282 .14029 L
.7929 .14064 L
.79304 .14092 L
.79323 .14112 L
.79344 .14123 L
.79362 .14126 L
.79375 .14124 L
.79379 .14118 L
.79371 .1411 L
.7935 .14105 L
.79319 .14104 L
.79281 .14108 L
.79239 .14114 L
.79195 .1412 L
.79151 .14122 L
.79105 .1412 L
.79059 .14112 L
.79013 .14097 L
.78969 .14076 L
.78928 .14047 L
.78893 .14013 L
.78864 .13975 L
.7884 .13932 L
.78818 .13885 L
.78796 .13832 L
.78772 .13774 L
Mistroke
.78741 .13712 L
.78702 .13646 L
.78656 .13578 L
.78604 .13512 L
.78545 .13447 L
.78475 .13382 L
.78392 .13314 L
.78291 .1324 L
.78171 .13161 L
.78025 .1307 L
.77847 .12967 L
.7764 .12848 L
.77397 .12721 L
.77115 .12583 L
.76768 .12428 L
.76407 .12261 L
.75958 .12071 L
.7548 .1187 L
.74951 .1164 L
.74362 .11405 L
.73715 .11128 L
.73093 .10867 L
.72399 .10568 L
.71705 .10286 L
.70917 .09961 L
.7023 .0968 L
.69552 .09367 L
.68732 .09044 L
.68096 .08756 L
.6741 .08445 L
.66711 .08138 L
.66024 .07829 L
.65273 .0755 L
.6462 .07257 L
.64025 .07016 L
.63411 .0677 L
.62828 .06547 L
.62255 .06338 L
.61714 .06132 L
.61266 .05968 L
.60831 .05817 L
.60462 .05684 L
.60137 .05571 L
.59883 .05479 L
.59669 .05411 L
.59505 .05359 L
.59379 .0532 L
.59274 .05292 L
.59183 .05271 L
.59103 .05255 L
Mistroke
.59022 .05243 L
.5894 .05236 L
.58858 .05233 L
.58776 .05235 L
.58694 .0524 L
.58614 .05245 L
.58537 .05249 L
.58468 .05249 L
.58408 .05248 L
.5836 .05247 L
.58325 .05246 L
.583 .05245 L
.58287 .05245 L
.58282 .05245 L
.58286 .05245 L
.58297 .05245 L
.58308 .05245 L
.58317 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58322 .05245 L
.58324 .05243 L
.58329 .05238 L
.58337 .05231 L
.58344 .05225 L
.58347 .05222 L
.58345 .05224 L
.58336 .05233 L
.5832 .05251 L
.58298 .05276 L
.58272 .05309 L
.58243 .05347 L
.58209 .0539 L
.58167 .05435 L
.58117 .05479 L
.58059 .05522 L
.57992 .05565 L
.57915 .05604 L
.5783 .05637 L
.57736 .05664 L
.57637 .05681 L
.57533 .0569 L
.57432 .05691 L
Mistroke
.57331 .05686 L
.57232 .05677 L
.57137 .05669 L
.57047 .05662 L
.56964 .05657 L
.5689 .05653 L
.56825 .0565 L
.56769 .05646 L
.56721 .05641 L
.56682 .05637 L
.56647 .05632 L
.56616 .05624 L
.56588 .05614 L
.56563 .05605 L
.56543 .05599 L
.56526 .05596 L
.56516 .05597 L
.56513 .05602 L
.56517 .05611 L
.56527 .05627 L
.56542 .05652 L
.56557 .05688 L
.56564 .05739 L
.56551 .05821 L
.56507 .05924 L
.56429 .06057 L
.56311 .06225 L
.56148 .06437 L
.55939 .06689 L
.5572 .06916 L
.55449 .07191 L
.55136 .07509 L
.54782 .07787 L
.54409 .08098 L
.5396 .08407 L
.53547 .08673 L
.5307 .08911 L
.52571 .09099 L
.52036 .09224 L
.51502 .09283 L
.50942 .09272 L
.50355 .09195 L
.49712 .09057 L
.49127 .08874 L
.48518 .08642 L
.47849 .0837 L
.47286 .08073 L
.46672 .07746 L
.46108 .07398 L
.45559 .07048 L
Mistroke
.45049 .06693 L
.44561 .06354 L
.44091 .06029 L
.43672 .05736 L
.43261 .05468 L
.42878 .05236 L
.42503 .05038 L
.42141 .04884 L
.41767 .04776 L
.41366 .04716 L
.40996 .04704 L
.40578 .0474 L
.40102 .04823 L
.39678 .0495 L
.39138 .05114 L
.38624 .05314 L
.38034 .05545 L
.3731 .0582 L
.36713 .06115 L
.36001 .06448 L
.35232 .06808 L
.34391 .07211 L
.33632 .07613 L
.32791 .08056 L
.31957 .08515 L
.31018 .08993 L
.30263 .09473 L
.29425 .09969 L
.28472 .10474 L
.27755 .1096 L
.26937 .11462 L
.2606 .1199 L
.25363 .1245 L
.24614 .12936 L
.23891 .13423 L
.23188 .13922 L
.22468 .14424 L
.2185 .14942 L
.21183 .15473 L
.20577 .16046 L
.19995 .1663 L
.19407 .17269 L
.18821 .17886 L
.18246 .18574 L
.17712 .19224 L
.17167 .19993 L
.16677 .20644 L
.16182 .21272 L
.1571 .21973 L
.15235 .22781 L
Mistroke
.14775 .23462 L
.14353 .24122 L
.13918 .24868 L
.13496 .25661 L
.13064 .26548 L
.12696 .27285 L
.12307 .28154 L
.11906 .2914 L
.11542 .29965 L
.11162 .30942 L
.10795 .31882 L
.10436 .32944 L
.10077 .33757 L
.09749 .34657 L
.09436 .3556 L
.09157 .36293 L
.08905 .37013 L
.08678 .3768 L
.0849 .38209 L
.08327 .38694 L
.08195 .39075 L
.08096 .39387 L
.08026 .39633 L
.07982 .39815 L
.0796 .39947 L
.07953 .40037 L
.07956 .40092 L
.07965 .40118 L
.07977 .40123 L
.07988 .40112 L
.07997 .40092 L
.08003 .40068 L
.08007 .40044 L
.0801 .40026 L
.0801 .40015 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
.08019 .40006 L
.08026 .40002 L
.08031 .39998 L
Mistroke
.08031 .39996 L
.08026 .39998 L
.08014 .40003 L
.07995 .40013 L
.07971 .40027 L
.07943 .40046 L
.07912 .40067 L
.0788 .40091 L
.07848 .40116 L
.07817 .40141 L
.07788 .40167 L
.07761 .40191 L
.07737 .40213 L
.07719 .40233 L
.07706 .40248 L
.07701 .40259 L
.07701 .40265 L
.07707 .40267 L
.07716 .40265 L
.07725 .40261 L
.07732 .40257 L
.07735 .40254 L
.07735 .40252 L
.07732 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07725 .40252 L
.07719 .40252 L
.07711 .40252 L
.07703 .40252 L
.07697 .40252 L
.07697 .40252 L
.07703 .40249 L
Mistroke
.07718 .40243 L
.07744 .40235 L
.07782 .40228 L
.07832 .40224 L
.07896 .40225 L
.0797 .40232 L
.0806 .40245 L
.08163 .40265 L
.0828 .40293 L
.08409 .40331 L
.08546 .4038 L
.08688 .40439 L
.08827 .40508 L
.08963 .40585 L
.09089 .40668 L
.09204 .40755 L
.09305 .40842 L
.09394 .40927 L
.09468 .41002 L
.0953 .41065 L
.09578 .41113 L
.09613 .41146 L
.09635 .41166 L
.09645 .41176 L
.09646 .41182 L
.09641 .41184 L
.09633 .41182 L
.09625 .41173 L
.09617 .41157 L
.09612 .41135 L
.09611 .41108 L
.09611 .41077 L
.09612 .41045 L
.09613 .41011 L
.09614 .40975 L
.09615 .4094 L
.09616 .40906 L
.09617 .40871 L
.09618 .40837 L
.09619 .40802 L
.0962 .40769 L
.09621 .40737 L
.09622 .40711 L
.09623 .40695 L
.09623 .40689 L
.09623 .40692 L
.09623 .407 L
.09622 .40708 L
.09622 .40713 L
.09622 .40714 L
Mistroke
.09622 .4071 L
.09622 .40705 L
.09622 .40704 L
.09622 .40707 L
.09622 .40712 L
.09619 .40719 L
.09611 .40726 L
.09596 .40735 L
.09576 .40745 L
.09555 .40757 L
.09535 .40771 L
.0952 .40787 L
.09514 .40806 L
.09527 .40832 L
.09567 .40866 L
.09644 .40912 L
.09764 .40972 L
.09936 .41041 L
.10157 .41125 L
.10437 .41222 L
.10771 .41335 L
.11175 .41463 L
.11628 .41611 L
.12195 .41772 L
.12707 .41945 L
.13317 .42124 L
.13965 .42295 L
.14675 .42453 L
.15294 .42593 L
.15933 .42707 L
.16666 .42797 L
.172 .42853 L
.17784 .42869 L
.18351 .42841 L
.18899 .42763 L
.19321 .42633 L
.19753 .42438 L
.20135 .42164 L
.20497 .4185 L
.20836 .41436 L
.21156 .40987 L
.21462 .40436 L
.2179 .39853 L
.22112 .39142 L
.22422 .38537 L
.22749 .37824 L
.23095 .37018 L
.23435 .36308 L
.23798 .35474 L
.2413 .34834 L
Mistroke
.24479 .34084 L
.24813 .3341 L
.2514 .32806 L
.25469 .32212 L
.25776 .31701 L
.26086 .31229 L
.26409 .30806 L
.26712 .30433 L
.27042 .30083 L
.27393 .29773 L
.27759 .29488 L
.28167 .29227 L
.28571 .28984 L
.29009 .28783 L
.29441 .28595 L
.29901 .28431 L
.30375 .28291 L
.30869 .28178 L
.31365 .28096 L
.31852 .28052 L
.32321 .28048 L
.32791 .28082 L
.33208 .28151 L
.33596 .28249 L
.33957 .28367 L
.34244 .285 L
.34497 .28637 L
.34705 .28764 L
.34869 .28893 L
.34989 .29003 L
.35073 .29104 L
.35123 .29193 L
.35148 .29265 L
.35155 .29317 L
.35151 .29348 L
.35142 .29361 L
.35135 .29361 L
.35134 .29351 L
.35141 .29337 L
.35154 .29323 L
.35174 .29311 L
.35201 .29299 L
.3523 .29288 L
.35259 .29276 L
.35286 .29266 L
.35308 .29263 L
.35322 .29271 L
.35328 .29292 L
.35325 .29326 L
.35313 .29376 L
Mistroke
.35294 .29443 L
.35269 .29526 L
.3524 .29624 L
.35211 .29735 L
.35183 .29859 L
.35158 .30001 L
.35137 .30164 L
.3512 .30335 L
.35109 .30519 L
.35104 .30715 L
.35104 .30914 L
.35107 .31119 L
.35116 .31336 L
.35128 .31552 L
.35139 .31782 L
.35143 .32021 L
.35134 .3226 L
.35109 .32518 L
.35063 .32773 L
.34995 .33042 L
.34904 .333 L
.34794 .3357 L
.3467 .33819 L
.34537 .34073 L
.34403 .34328 L
.34286 .34567 L
.34184 .34797 L
.34099 .3504 L
.34041 .35302 L
.34021 .35551 L
.34047 .35822 L
.34121 .36102 L
.34245 .36406 L
.34409 .36716 L
.34613 .37069 L
.34841 .37411 L
.35096 .37765 L
.35368 .38158 L
.35638 .38561 L
.35913 .38986 L
.36189 .39454 L
.36458 .39871 L
.36723 .40323 L
.36982 .40779 L
.37237 .41242 L
.37485 .41717 L
.3773 .42184 L
.37976 .4265 L
.38222 .43114 L
.38478 .43564 L
Mistroke
.38731 .44006 L
.38987 .44426 L
.39244 .44835 L
.39496 .45197 L
.3975 .45538 L
.4001 .45861 L
.40273 .4614 L
.40545 .46408 L
.40828 .46659 L
.41127 .46904 L
.41428 .47142 L
.4175 .47389 L
.42089 .47648 L
.42445 .47927 L
.4283 .48234 L
.43255 .48584 L
.43724 .48972 L
.44217 .49379 L
.44757 .49834 L
.45341 .50319 L
.45958 .50816 L
.46625 .51325 L
.47295 .51834 L
.48037 .52398 L
.48813 .5292 L
.4953 .53408 L
.50365 .53947 L
.51202 .54477 L
.5212 .55013 L
.5302 .55542 L
.53866 .5607 L
.54728 .56588 L
.5562 .57163 L
.5652 .57691 L
.57378 .58299 L
.58234 .58861 L
.59134 .5952 L
.59973 .60149 L
.60765 .60776 L
.61602 .6145 L
.6232 .62084 L
.63051 .62749 L
.6381 .63459 L
.64436 .64098 L
.6509 .64775 L
.65718 .65464 L
.66333 .66205 L
.66904 .66893 L
.67461 .67627 L
.67997 .68402 L
Mistroke
.68496 .69108 L
.68984 .69869 L
.69453 .70608 L
.69918 .71391 L
.70357 .72104 L
.70801 .72826 L
.71255 .7355 L
.71718 .7429 L
.72196 .74882 L
.72712 .75516 L
.73219 .76111 L
.73821 .76695 L
.7439 .77192 L
.74962 .77648 L
.75593 .78068 L
.76257 .78446 L
.7695 .78791 L
.77645 .79105 L
.78354 .79387 L
.79074 .7963 L
.79808 .79839 L
.80532 .80006 L
.8133 .80125 L
.81962 .80194 L
.82635 .80222 L
.83324 .80213 L
.83864 .80175 L
.84412 .80111 L
.84899 .80027 L
.85343 .79931 L
.85679 .79825 L
.85959 .79713 L
.86171 .79598 L
.8632 .79491 L
.86412 .79394 L
.86452 .79317 L
.86457 .79266 L
.86442 .79242 L
.86415 .79241 L
.86388 .79254 L
.86365 .79272 L
.86354 .79286 L
.86361 .79286 L
.86389 .79261 L
.86439 .79204 L
.86512 .79112 L
.86606 .78985 L
.86719 .78827 L
.8685 .78632 L
.86995 .78418 L
Mistroke
.87144 .78175 L
.87296 .77919 L
.87443 .7766 L
.87579 .7741 L
.87702 .77161 L
.87804 .76951 L
.87887 .76759 L
.87948 .76588 L
.87989 .76437 L
.88014 .76306 L
.88026 .76183 L
.88032 .7606 L
.88038 .75924 L
.88049 .75768 L
.88073 .75597 L
.88115 .75393 L
.88175 .75152 L
.8826 .74868 L
.88368 .74539 L
.88496 .74159 L
.88645 .73761 L
.8881 .73324 L
.88989 .72864 L
.89178 .72385 L
.89375 .71892 L
.8957 .71398 L
.89768 .70903 L
.89959 .70389 L
.90147 .69918 L
.9033 .69382 L
.90503 .68934 L
.9067 .6845 L
.90827 .67989 L
.90977 .67532 L
.9112 .67099 L
.91258 .66656 L
.91395 .66204 L
.91533 .65747 L
.91676 .65259 L
.91825 .6472 L
.91978 .64205 L
.92136 .6365 L
.923 .63039 L
.92465 .62496 L
.92626 .61904 L
.92787 .61297 L
.92941 .60745 L
.93091 .60183 L
.93241 .59633 L
.93369 .59129 L
Mistroke
.93495 .58664 L
.93609 .58229 L
.93713 .57844 L
.93803 .57506 L
.93883 .5721 L
.93951 .56955 L
.94008 .56747 L
.9406 .56572 L
.94105 .56426 L
.94145 .5631 L
.94177 .56223 L
.94202 .56161 L
.94217 .56125 L
.9422 .56114 L
.94211 .56124 L
.9419 .56149 L
.94159 .56183 L
.94119 .56222 L
.94075 .56261 L
.9403 .56296 L
.93986 .56325 L
.93944 .56351 L
.93904 .56376 L
.93867 .56398 L
.93835 .56419 L
.93808 .56437 L
.9379 .56451 L
.9378 .56461 L
.93777 .56464 L
.93779 .56461 L
.93784 .56453 L
.93791 .56441 L
.93794 .56428 L
.93794 .56418 L
.93791 .5641 L
.93787 .56403 L
.93785 .56392 L
.93785 .56379 L
.93786 .56362 L
.93791 .56338 L
.93798 .56301 L
.93811 .56248 L
.93828 .56173 L
.93849 .56074 L
.93875 .55945 L
.93903 .55784 L
.93933 .5558 L
.93964 .55338 L
.93994 .55049 L
.94021 .54718 L
Mistroke
.94045 .54358 L
.94066 .53953 L
.94081 .53539 L
.9409 .53096 L
.94092 .52635 L
.94086 .52155 L
.94073 .51648 L
.94053 .51177 L
.94028 .50675 L
.93998 .5016 L
.93962 .49659 L
.93921 .49148 L
.93875 .48594 L
.93825 .48017 L
.93772 .4751 L
.93717 .46962 L
.9366 .46352 L
.93606 .45825 L
.93556 .45232 L
.9351 .44676 L
.93468 .44078 L
.93428 .43444 L
.93389 .42888 L
.93348 .42354 L
.93305 .41759 L
.93257 .41146 L
.93202 .40464 L
.93143 .39846 L
.93078 .39186 L
.93012 .38511 L
.9294 .37801 L
.92866 .37188 L
.92792 .3657 L
.92719 .35954 L
.92649 .35435 L
.92583 .34942 L
.92525 .345 L
.92474 .34152 L
.92431 .33861 L
.92396 .33642 L
.92369 .33486 L
.92349 .33384 L
.92334 .33326 L
.92321 .333 L
.92305 .33287 L
.92285 .33271 L
.92256 .33242 L
.92215 .33189 L
.92158 .33107 L
.92085 .32991 L
Mistroke
.91996 .32838 L
.91904 .32661 L
.91795 .32454 L
.91689 .32227 L
.91569 .31981 L
.91458 .31718 L
.91345 .31447 L
.91236 .31176 L
.91135 .30914 L
.91053 .30677 L
.9098 .30465 L
.90918 .30286 L
.90864 .30137 L
.90819 .30006 L
.9077 .29886 L
.90712 .29764 L
.90638 .29631 L
.90545 .29475 L
.90428 .29285 L
.90295 .29068 L
.90132 .28809 L
.89945 .28499 L
.89731 .28167 L
.89493 .2779 L
.89237 .27402 L
.88956 .26968 L
.88679 .26516 L
.88379 .2604 L
.88062 .25577 L
.87759 .25106 L
.87436 .24629 L
.87108 .24176 L
.86817 .23741 L
.86492 .2329 L
.86176 .22838 L
.85834 .22365 L
.85506 .21898 L
.85189 .21424 L
.84853 .2093 L
.8449 .20392 L
.84173 .19927 L
.83822 .19419 L
.83446 .18881 L
.83124 .184 L
.82765 .17894 L
.8239 .17381 L
.82085 .16939 L
.81767 .16498 L
.8147 .16104 L
.81206 .15755 L
Mistroke
.80967 .15445 L
.8077 .15191 L
.80592 .14973 L
.80462 .14809 L
.80354 .14678 L
.80272 .1458 L
.80214 .14514 L
.8018 .14475 L
.80167 .14461 L
.80171 .14467 L
.80186 .14484 L
.80206 .14503 L
.80224 .14521 L
.80236 .14535 L
.80236 .14542 L
.80224 .14539 L
.80199 .14528 L
.80166 .1451 L
.80127 .14486 L
.80085 .14456 L
.80041 .14422 L
.79996 .14385 L
.79952 .14348 L
.79909 .14311 L
.79869 .14276 L
.79834 .14245 L
.79806 .14216 L
.79786 .14192 L
.79775 .14172 L
.79771 .14156 L
.79773 .14145 L
.7978 .14136 L
.79787 .14131 L
.79792 .14129 L
.79795 .14131 L
.79795 .14135 L
.79795 .14141 L
.79795 .14144 L
.79795 .14138 L
.79795 .14124 L
.79795 .14102 L
.79795 .14072 L
.79797 .14034 L
.798 .1399 L
.79802 .13943 L
.79803 .13896 L
.79802 .13855 L
.79796 .13822 L
.79787 .138 L
.79775 .13793 L
Mistroke
.79759 .13797 L
.7974 .13811 L
.79719 .13831 L
.79697 .13854 L
.79675 .13878 L
.79654 .13899 L
.79636 .13916 L
.79623 .13926 L
.79614 .13924 L
.79605 .1391 L
.79595 .13886 L
.79585 .13853 L
.79575 .13815 L
.79562 .13775 L
.79546 .13737 L
.79524 .13707 L
.79494 .13688 L
.79454 .1368 L
.79399 .13677 L
.79342 .13675 L
.79266 .13668 L
.79173 .13654 L
.79061 .13628 L
.7893 .13589 L
.78781 .13536 L
.78635 .13475 L
.78474 .13399 L
.78298 .13313 L
.78142 .13221 L
.77987 .13133 L
.77825 .13043 L
.77697 .12953 L
.77575 .12866 L
.77456 .12788 L
.77356 .12721 L
.77266 .12665 L
.77187 .12617 L
.77113 .12575 L
.77036 .12539 L
.7695 .12505 L
.76853 .12471 L
.76754 .12434 L
.76644 .1239 L
.76507 .12339 L
.76336 .12279 L
.76152 .12209 L
.75972 .12127 L
.75769 .12042 L
.75561 .11952 L
.75343 .11859 L
Mistroke
.75168 .11764 L
.74967 .11671 L
.74811 .11587 L
.7466 .11507 L
.74518 .11434 L
.74396 .11371 L
.74301 .11321 L
.74226 .11282 L
.74173 .11254 L
.74137 .11233 L
.74117 .11217 L
.7411 .11206 L
.74113 .11197 L
.74121 .11191 L
.74128 .11188 L
.74136 .11191 L
.74144 .11204 L
.7415 .11227 L
.74154 .11261 L
.74155 .11304 L
.74155 .11357 L
.74156 .11417 L
.74155 .11475 L
.74153 .1154 L
.74149 .11607 L
.74143 .11667 L
.74136 .11726 L
.74131 .11781 L
.7413 .11828 L
.74135 .11864 L
.74147 .11889 L
.74168 .11901 L
.74201 .11902 L
.74244 .11895 L
.74297 .11882 L
.74359 .11869 L
.74433 .1186 L
.7452 .11858 L
.74624 .11864 L
.74736 .11878 L
.74864 .11899 L
.75003 .11926 L
.75154 .11961 L
.75313 .12005 L
.7549 .12059 L
.75665 .12123 L
.75858 .12193 L
.76042 .12272 L
.76246 .1236 L
.76457 .12453 L
Mistroke
.76663 .12542 L
.76868 .1263 L
.77056 .12712 L
.7723 .12785 L
.77376 .12846 L
.77508 .12899 L
.77623 .12944 L
.77713 .12981 L
.77787 .13009 L
.77847 .13028 L
.77894 .13036 L
.77928 .13037 L
.77953 .13033 L
.7797 .13026 L
.77983 .13019 L
.77993 .13014 L
.78006 .13012 L
.7802 .13011 L
.78035 .13012 L
.7805 .13012 L
.78063 .13012 L
.78072 .13012 L
.78077 .13012 L
.78077 .1301 L
.78072 .13005 L
.78065 .12999 L
.78058 .12992 L
.78053 .12989 L
.7805 .12991 L
.78051 .13 L
.78057 .13016 L
.78069 .13042 L
.78087 .13075 L
.78111 .13114 L
.78142 .13156 L
.78177 .13201 L
.78216 .13244 L
.78258 .13287 L
.78301 .1333 L
.78343 .1337 L
.78383 .13406 L
.7842 .13435 L
.78451 .13455 L
.78477 .13466 L
.78496 .1347 L
.78508 .13468 L
.78515 .13462 L
.78517 .13455 L
.78515 .1345 L
.78513 .13447 L
Mistroke
.78509 .13447 L
.78506 .13447 L
.78503 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78499 .13447 L
.78495 .13445 L
.78488 .13443 L
.78481 .13439 L
.78474 .13436 L
.78469 .13434 L
.7847 .13435 L
.78479 .1344 L
.78498 .13449 L
.78528 .13462 L
.78571 .13479 L
.78626 .13499 L
.78694 .13521 L
.78769 .13544 L
.78857 .13568 L
.78952 .13592 L
.79053 .13615 L
.79153 .13636 L
.79248 .13655 L
.79332 .1367 L
.79403 .13681 L
.79458 .13688 L
.79495 .1369 L
.79516 .13689 L
.79521 .13686 L
.79514 .13682 L
.79497 .13679 L
.79474 .13677 L
.79448 .13677 L
.79421 .13677 L
.79398 .13679 L
.7938 .13683 L
.79371 .13686 L
.79371 .13687 L
.7938 .13686 L
.79397 .13682 L
.79419 .13674 L
.79444 .13662 L
.7947 .13646 L
.79495 .13627 L
.79517 .13607 L
Mistroke
.79537 .13585 L
.79554 .13563 L
.79568 .13541 L
.79577 .1352 L
.79582 .135 L
.79585 .13483 L
.7959 .1347 L
.79597 .1346 L
.79602 .13455 L
.79604 .13453 L
.79599 .13455 L
.79586 .13457 L
.79562 .13461 L
.79525 .13463 L
.79476 .13463 L
.79418 .13463 L
.79355 .13461 L
.7929 .1346 L
.79227 .13459 L
.79166 .13458 L
.79104 .13457 L
.79044 .13456 L
.7899 .13455 L
.78947 .13454 L
.78918 .13454 L
.78905 .13453 L
.78904 .13453 L
.78914 .13454 L
.78928 .13454 L
.7894 .13454 L
.78945 .13454 L
.78937 .13454 L
.78916 .13454 L
.78887 .13453 L
.78849 .13453 L
.78809 .13452 L
.78768 .13451 L
.78731 .13451 L
.78699 .1345 L
.78676 .13438 L
.78657 .13438 L
.78642 .13437 L
.78638 .13436 L
.78647 .13435 L
.78678 .13434 L
.78726 .13435 L
.78795 .13438 L
.7887 .13443 L
.78958 .13448 L
.79055 .13453 L
Mistroke
.79154 .13459 L
.79234 .13468 L
.79311 .13481 L
.79388 .13504 L
.79473 .13538 L
.79544 .13587 L
.79617 .1365 L
.79693 .13731 L
.79773 .13829 L
.79857 .13944 L
.79947 .14064 L
.80035 .14206 L
.80145 .14367 L
.80274 .14537 L
.80395 .14728 L
.80541 .14943 L
.80683 .15151 L
.80845 .15383 L
.8102 .15602 L
.81182 .15825 L
.81331 .16051 L
.81477 .16256 L
.81619 .16471 L
.81753 .16674 L
.81861 .16858 L
.81963 .17035 L
.82054 .17189 L
.82131 .17317 L
.82189 .17417 L
.82239 .17489 L
.82278 .17534 L
.82308 .17558 L
.8233 .17564 L
.82347 .17555 L
.82362 .17535 L
.82372 .17503 L
.82379 .17461 L
.82385 .17414 L
.8239 .17369 L
.82399 .17333 L
.82412 .1731 L
.82434 .17303 L
.82463 .17311 L
.825 .17337 L
.82542 .17375 L
.82589 .17416 L
.8264 .17473 L
.82694 .17538 L
.82749 .17615 L
.82803 .1769 L
Mistroke
.82855 .17779 L
.82901 .1787 L
.8294 .17956 L
.82973 .1804 L
.83001 .1812 L
.83026 .18194 L
.83048 .18263 L
.8307 .18331 L
.83093 .184 L
.83116 .18469 L
.8314 .18537 L
.83161 .18602 L
.8318 .18659 L
.83194 .18704 L
.83204 .18741 L
.8321 .18768 L
.83209 .18785 L
.83204 .18789 L
.83194 .18778 L
.83182 .18751 L
.83169 .1871 L
.83156 .18668 L
.83145 .18622 L
.83137 .1858 L
.83134 .18541 L
.83138 .18513 L
.83149 .185 L
.83165 .18498 L
.83185 .18504 L
.83207 .18522 L
.83229 .18558 L
.83247 .18609 L
.83262 .18677 L
.83273 .18762 L
.8328 .18865 L
.83287 .18986 L
.83294 .19125 L
.83303 .19279 L
.83316 .19438 L
.83334 .19589 L
.83358 .19738 L
.83389 .19902 L
.83424 .20084 L
.83462 .20285 L
.83502 .2046 L
.83542 .20634 L
.83581 .20798 L
.83617 .2095 L
.83652 .21099 L
.83686 .21244 L
Mistroke
.8372 .21376 L
.83752 .21506 L
.83782 .21643 L
.83809 .21784 L
.83832 .21922 L
.8385 .22061 L
.83863 .22206 L
.8387 .22344 L
.83873 .22476 L
.83873 .22602 L
.83871 .22718 L
.83868 .2282 L
.83862 .22906 L
.83853 .22982 L
.83842 .23045 L
.83829 .23094 L
.83816 .23129 L
.83804 .23149 L
.83796 .23158 L
.83792 .23159 L
.83792 .23153 L
.83795 .23144 L
.83798 .23133 L
.83801 .23124 L
.83802 .23121 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .23122 L
.83802 .23125 L
.83802 .2313 L
.83802 .23133 L
.83802 .23132 L
.83802 .23125 L
.83802 .23115 L
.83801 .23102 L
.838 .23087 L
.83799 .23073 L
.83796 .2306 L
.83792 .23051 L
.83788 .23045 L
.83787 .23041 L
.83788 .23041 L
Mistroke
.83792 .23041 L
.83801 .23042 L
.83814 .23047 L
.8383 .23056 L
.83849 .23068 L
.83871 .23084 L
.83893 .23099 L
.83915 .23114 L
.83937 .23125 L
.83959 .23133 L
.83979 .23135 L
.83996 .23132 L
.84009 .23127 L
.84018 .23123 L
.84024 .23122 L
.84025 .23121 L
.84024 .23121 L
.84021 .23121 L
.84017 .23121 L
.84015 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84014 .23118 L
.84017 .23112 L
.8402 .23102 L
.84023 .23093 L
.84024 .23089 L
.84023 .23092 L
.84019 .23105 L
.84011 .23129 L
.84 .23166 L
.83985 .23215 L
.83967 .23273 L
.83948 .23336 L
.83928 .23401 L
.83908 .23465 L
.83888 .23527 L
.83868 .23588 L
.8385 .23648 L
.83834 .23702 L
.83821 .23744 L
.83813 .23773 L
.83808 .2379 L
.83806 .23795 L
.83807 .23792 L
Mistroke
.8381 .23783 L
.83813 .23773 L
.83816 .23765 L
.83817 .23762 L
.83817 .23762 L
.83817 .23762 L
.83817 .23761 L
.83817 .2376 L
.83817 .23756 L
.83817 .2375 L
.83817 .23746 L
.83817 .23745 L
.83817 .2375 L
.83818 .23761 L
.83818 .23778 L
.83819 .23799 L
.83819 .23822 L
.8382 .23844 L
.83821 .23863 L
.83821 .23877 L
.83822 .23886 L
.83822 .2389 L
.8382 .23892 L
.83818 .23891 L
.83814 .23884 L
.83811 .23876 L
.83809 .2386 L
.83809 .23837 L
.83813 .2381 L
.83822 .23785 L
.83836 .23764 L
.83856 .23751 L
.83878 .23746 L
.83901 .2375 L
.83922 .23761 L
.8394 .23773 L
.83954 .23782 L
.83963 .2379 L
.83967 .23795 L
.83965 .23797 L
.83958 .23798 L
.83946 .23798 L
.83929 .23798 L
.83909 .23796 L
.83886 .23793 L
.83863 .23788 L
.83841 .23782 L
.83824 .23774 L
.83813 .23767 L
.83807 .23762 L
Mistroke
.83805 .23757 L
.83806 .23755 L
.83809 .23753 L
.83813 .2375 L
.83815 .23745 L
.83817 .2374 L
.83818 .23735 L
.83821 .23733 L
.83824 .23736 L
.83827 .23748 L
.8383 .23771 L
.83829 .23806 L
.83826 .23853 L
.83819 .23913 L
.83808 .23982 L
.83794 .24056 L
.83777 .24135 L
.83758 .24218 L
.83738 .24301 L
.83719 .2438 L
.83699 .2445 L
.83679 .24511 L
.83661 .24562 L
.83644 .246 L
.83631 .24627 L
.83622 .24641 L
.83617 .24646 L
.83615 .24645 L
.83616 .2464 L
.83619 .24634 L
.83623 .24626 L
.83625 .2462 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
Mistroke
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24616 L
.8363 .24615 L
.83636 .24613 L
.83643 .24609 L
.83648 .24606 L
.83651 .24602 L
.83651 .24598 L
.83646 .24596 L
.8363 .24599 L
.83601 .24608 L
.83564 .24626 L
.83519 .24653 L
.83465 .24691 L
.83405 .24737 L
.83348 .24791 L
.8329 .2485 L
.83231 .24913 L
.83173 .24976 L
.83115 .25038 L
.83072 .25095 L
.83036 .25147 L
.83008 .25193 L
.82988 .25231 L
.82978 .25258 L
.82976 .25275 L
Mistroke
.8298 .25283 L
.82986 .25284 L
.82992 .25281 L
.82998 .25274 L
.83004 .25267 L
.83009 .25261 L
.8301 .25258 L
.83008 .25258 L
.83007 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83007 .25258 L
.8301 .25258 L
.83019 .25258 L
.83028 .25258 L
.83032 .25258 L
.8303 .25258 L
.8302 .25258 L
.82998 .25258 L
.82963 .25258 L
.82912 .25258 L
.82852 .25258 L
.82787 .25257 L
.82724 .25257 L
.82665 .25257 L
.82609 .25257 L
.82551 .25256 L
.82491 .25254 L
.82434 .25252 L
.82388 .25249 L
.82358 .25246 L
Mistroke
.82339 .25242 L
.8233 .25241 L
.82329 .25244 L
.82337 .25252 L
.8235 .25267 L
.82363 .2529 L
.82376 .25319 L
.82394 .25354 L
.82416 .25396 L
.82436 .25435 L
.82459 .25474 L
.82482 .25508 L
.82505 .25541 L
.82528 .25576 L
.8255 .25616 L
.82569 .25658 L
.82585 .25702 L
.82597 .25746 L
.82605 .25789 L
.82608 .25828 L
.82608 .25861 L
.82606 .25887 L
.82602 .25909 L
.826 .25926 L
.82599 .25944 L
.82599 .25962 L
.826 .25979 L
.82599 .25985 L
.82599 .25981 L
.82598 .25967 L
.82598 .25948 L
.82597 .25928 L
.82596 .25908 L
.82596 .25893 L
.82596 .25886 L
.82596 .25888 L
.82596 .25896 L
.82596 .25903 L
.82597 .25908 L
.82597 .2591 L
.82597 .25911 L
.82597 .25911 L
.82596 .25911 L
.82593 .25911 L
.82589 .25908 L
.82586 .25902 L
.82584 .25893 L
.82583 .25885 L
.82585 .25877 L
.82589 .25872 L
Mistroke
.82597 .25873 L
.82609 .25882 L
.82626 .25901 L
.82649 .25931 L
.82678 .25974 L
.82711 .26027 L
.82748 .26093 L
.8279 .26167 L
.82836 .2625 L
.82886 .26344 L
.8294 .26447 L
.82996 .26557 L
.83058 .26667 L
.83129 .26782 L
.83203 .26898 L
.83291 .27011 L
.83394 .27124 L
.83504 .27234 L
.83633 .27342 L
.83779 .27454 L
.83936 .27571 L
.8411 .27684 L
.84301 .27794 L
.84525 .27904 L
.84722 .28009 L
.84981 .28106 L
.85195 .28196 L
.85416 .28274 L
.85655 .28343 L
.85899 .28402 L
.86134 .28449 L
.86374 .2848 L
.86612 .28496 L
.86847 .28499 L
.871 .2849 L
.87311 .28467 L
.87534 .28443 L
.87769 .2842 L
.87941 .28401 L
.88125 .28387 L
.88294 .2838 L
.88422 .28378 L
.88534 .28379 L
.88634 .28381 L
.88716 .28389 L
.88779 .284 L
.88822 .28416 L
.8885 .28435 L
.88869 .28454 L
.88881 .28472 L
Mistroke
.88889 .28486 L
.88895 .28494 L
.88905 .28497 L
.88921 .28493 L
.8894 .28488 L
.88955 .28483 L
.88968 .28481 L
.88976 .28481 L
.88981 .28481 L
.88983 .28481 L
.88981 .28481 L
.88978 .28481 L
.88975 .28481 L
.88972 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28483 L
.88971 .28487 L
.88971 .28493 L
.88971 .28496 L
.88971 .28495 L
.88971 .28487 L
.8897 .28474 L
.8897 .28458 L
.88969 .2844 L
.88968 .28422 L
.88968 .28406 L
.88967 .28393 L
.88967 .28385 L
.88967 .2838 L
.88967 .28378 L
.88967 .28379 L
.88967 .28381 L
.88967 .28386 L
.88966 .28393 L
.88964 .28403 L
.88961 .28415 L
.88957 .28431 L
.88954 .2845 L
.88953 .28473 L
.88956 .28498 L
.88964 .28525 L
.88978 .28554 L
.88999 .28586 L
.89027 .28624 L
.8906 .28667 L
.89099 .28711 L
.89139 .28755 L
Mistroke
.89181 .28798 L
.89224 .28838 L
.89266 .28872 L
.89304 .289 L
.89339 .28919 L
.89368 .2893 L
.8939 .28934 L
.89406 .28933 L
.89416 .28932 L
.89421 .28932 L
.89421 .28932 L
.89417 .28933 L
.89409 .2893 L
.89399 .28921 L
.89388 .28903 L
.89376 .28878 L
.89366 .28845 L
.89357 .28807 L
.8935 .28763 L
.89347 .28713 L
.89346 .28662 L
.89347 .28612 L
.89345 .28566 L
.8934 .28527 L
.89333 .28498 L
.89323 .28482 L
.89312 .28479 L
.89301 .28486 L
.89293 .28502 L
.89288 .28529 L
.89289 .28567 L
.893 .28619 L
.8932 .28682 L
.89351 .28761 L
.89399 .28859 L
.89461 .28983 L
.89549 .2914 L
.89658 .29331 L
.89785 .29538 L
.89931 .29757 L
.90078 .29992 L
.90237 .30257 L
.9038 .30511 L
.90526 .30783 L
.90653 .31029 L
.90778 .31271 L
.90885 .31489 L
.9099 .31699 L
.91084 .31871 L
.91177 .3203 L
Mistroke
.91269 .32175 L
.91357 .32309 L
.91436 .3244 L
.91515 .32558 L
.91594 .32681 L
.91672 .32805 L
.91745 .32926 L
.91817 .33042 L
.91877 .33156 L
.91928 .33264 L
.91968 .33361 L
.91995 .33436 L
.92011 .33494 L
.92017 .3354 L
.92019 .33582 L
.92023 .33624 L
.92031 .33674 L
.92047 .33737 L
.92071 .33818 L
.92103 .33911 L
.92143 .34018 L
.92188 .34129 L
.92232 .34232 L
.92279 .34364 L
.92323 .34483 L
.92366 .34604 L
.92405 .34724 L
.92439 .34838 L
.92465 .34938 L
.92482 .35023 L
.92492 .3509 L
.92494 .35142 L
.92492 .3518 L
.92487 .35212 L
.92482 .3524 L
.92479 .35267 L
.92478 .35295 L
.92479 .35319 L
.9248 .35338 L
.9248 .35352 L
.92481 .35361 L
.92481 .35364 L
.92481 .35361 L
.9248 .35351 L
.9248 .35337 L
.92479 .35317 L
.92478 .35291 L
.92477 .35258 L
.92476 .35217 L
.92474 .3517 L
Mistroke
.92472 .35118 L
.92471 .35067 L
.92469 .35019 L
.92468 .34978 L
.92466 .34946 L
.92466 .34927 L
.92466 .34923 L
.92466 .34934 L
.92467 .34962 L
.9247 .34996 L
.92474 .35029 L
.92479 .35064 L
.92486 .35098 L
.92491 .35131 L
.92496 .35169 L
.92499 .35213 L
.92497 .35274 L
.92489 .35365 L
.92473 .35491 L
.92447 .35657 L
.92411 .35868 L
.92364 .36101 L
.9231 .36301 L
.92248 .36518 L
.92181 .36802 L
.92112 .37017 L
.92042 .37235 L
.91977 .37505 L
.91919 .37683 L
.91865 .37831 L
.91818 .37943 L
.91779 .3802 L
.91749 .38056 L
.91728 .38056 L
.91716 .38038 L
.9171 .38012 L
.91711 .37982 L
.9172 .37953 L
.91735 .37927 L
.91756 .379 L
.91781 .37872 L
.91811 .37841 L
.91846 .37805 L
.91884 .37764 L
.91922 .37721 L
.91962 .37676 L
.92003 .37631 L
.9204 .37587 L
.92075 .37547 L
.92106 .37512 L
Mistroke
.92131 .37484 L
.92149 .37464 L
.92159 .37453 L
.92164 .37449 L
.92163 .37452 L
.92158 .37459 L
.9215 .37466 L
.92143 .37472 L
.92137 .37474 L
.92134 .37475 L
.92135 .37475 L
.92139 .37475 L
.92147 .37475 L
.92159 .37475 L
.92175 .37475 L
.92193 .37474 L
.92213 .37474 L
.92234 .37474 L
.92255 .37474 L
.92276 .37473 L
.92296 .37473 L
.92315 .37473 L
.92332 .37473 L
.92345 .37473 L
.92354 .37473 L
.92359 .37473 L
.92361 .37472 L
.92361 .3747 L
.92361 .37465 L
.92364 .37458 L
.92367 .37452 L
.9237 .37448 L
.92371 .37449 L
.92368 .37457 L
.9236 .37472 L
.92347 .37491 L
.92327 .37514 L
.923 .3754 L
.92265 .3757 L
.92218 .37607 L
.92157 .37656 L
.9209 .37718 L
.92013 .37796 L
.91925 .37888 L
.91827 .37993 L
.91724 .38107 L
.91626 .38227 L
.91541 .38342 L
.91464 .38454 L
.9139 .38562 L
Mistroke
.91319 .38667 L
.91261 .38759 L
.91215 .38843 L
.91181 .38915 L
.9116 .38971 L
.91148 .39009 L
.91142 .39033 L
.91144 .39044 L
.91148 .39046 L
.91151 .39044 L
.91156 .39043 L
.91163 .39045 L
.91174 .39049 L
.91188 .39056 L
.91204 .39067 L
.91223 .39077 L
.91244 .39084 L
.91265 .39087 L
.91286 .39082 L
.91307 .39067 L
.91326 .39041 L
.91344 .39005 L
.91359 .38961 L
.91371 .3891 L
.91378 .38857 L
.91382 .38803 L
.91382 .38753 L
.91379 .38707 L
.91374 .38665 L
.91369 .38629 L
.91366 .38597 L
.91364 .38571 L
.91363 .38551 L
.91362 .3854 L
.91362 .38537 L
.91362 .3854 L
.91362 .38546 L
.91363 .38554 L
.91363 .3856 L
.91363 .38565 L
.91362 .38571 L
.91359 .38578 L
.91356 .38586 L
.91352 .38595 L
.91348 .38602 L
.91346 .38606 L
.91345 .38604 L
.91349 .38593 L
.91358 .38572 L
.91374 .38536 L
Mistroke
.91398 .38484 L
.9143 .38414 L
.91474 .38322 L
.91522 .38204 L
.91576 .38053 L
.91634 .37862 L
.91691 .37624 L
.91745 .37346 L
.91793 .37027 L
.91829 .36664 L
.91856 .36278 L
.91873 .35828 L
.91883 .35461 L
.91887 .35105 L
.91887 .34684 L
.91884 .34372 L
.9188 .34062 L
.91877 .33759 L
.91876 .33522 L
.91879 .33318 L
.91888 .3316 L
.919 .33046 L
.91915 .32968 L
.91933 .32919 L
.91952 .32892 L
.9197 .32878 L
.91984 .32864 L
.91993 .32844 L
.91997 .32815 L
.91998 .32784 L
.91995 .32754 L
.91991 .32726 L
.91987 .327 L
.91984 .3268 L
.91982 .32665 L
.91981 .32654 L
.91981 .32646 L
.91981 .32637 L
.9198 .32625 L
.9198 .32611 L
.91981 .32592 L
.91983 .32567 L
.91985 .32535 L
.91988 .32496 L
.91992 .3245 L
.91995 .32397 L
.91997 .32337 L
.91994 .32267 L
.91985 .32183 L
.91965 .3208 L
Mistroke
.91934 .31954 L
.9189 .31814 L
.91832 .31657 L
.91767 .31484 L
.9169 .31298 L
.91603 .31101 L
.91519 .30915 L
.91419 .30716 L
.91306 .30503 L
.912 .30296 L
.9107 .30076 L
.90949 .29841 L
.90817 .2962 L
.90671 .29377 L
.90523 .29132 L
.90365 .28882 L
.90192 .28625 L
.90024 .28387 L
.89844 .28144 L
.89662 .27904 L
.89484 .2767 L
.89316 .2747 L
.89157 .27284 L
.89019 .2711 L
.88912 .26991 L
.88827 .26898 L
.88766 .26828 L
.88728 .2678 L
.8871 .26757 L
.88709 .26757 L
.88715 .26764 L
.8872 .26765 L
.8872 .26749 L
.88705 .26705 L
.88668 .26627 L
.88602 .26506 L
.88501 .26344 L
.88372 .26119 L
.88208 .25859 L
.88011 .25553 L
.8778 .25217 L
.87518 .24839 L
.87218 .24429 L
.86923 .24008 L
.86606 .2357 L
.86233 .23063 L
.85938 .22654 L
.85617 .22191 L
.85279 .21713 L
.84964 .21246 L
Mistroke
.84646 .20774 L
.84322 .20296 L
.84014 .19835 L
.83692 .19392 L
.83395 .18932 L
.83091 .18485 L
.82785 .18038 L
.82444 .17565 L
.82159 .17159 L
.81863 .16756 L
.8153 .16328 L
.81279 .1599 L
.81013 .15645 L
.80757 .15322 L
.80506 .15024 L
.80315 .14766 L
.80128 .14538 L
.79963 .1434 L
.79822 .14178 L
.79697 .14041 L
.79588 .13931 L
.79503 .13849 L
.79435 .13794 L
.79388 .13766 L
.79363 .13762 L
.79358 .13776 L
.7937 .13803 L
.79397 .13837 L
.79434 .13874 L
.79478 .13907 L
.79525 .13933 L
.79577 .13952 L
.79629 .13961 L
.79676 .13957 L
.79717 .1394 L
.7975 .13913 L
.79777 .13881 L
.79796 .13843 L
.79807 .13808 L
.79811 .13772 L
.79809 .13739 L
.79804 .13709 L
.79797 .13687 L
.79792 .13674 L
.79789 .13669 L
.79788 .13668 L
.79789 .13668 L
.79791 .13666 L
.79794 .13661 L
.79798 .13657 L
Mistroke
.79799 .13656 L
.79798 .1366 L
.79794 .1367 L
.79785 .13687 L
.79773 .13712 L
.79758 .13744 L
.79739 .13781 L
.79719 .13823 L
.79698 .13867 L
.79676 .1391 L
.79655 .13954 L
.79634 .13996 L
.79615 .14035 L
.79598 .1407 L
.79585 .14097 L
.79576 .14116 L
.7957 .14127 L
.79569 .1413 L
.7957 .14128 L
.79573 .14121 L
.79577 .14114 L
.79579 .14109 L
.79581 .14106 L
.7958 .14105 L
.79577 .14105 L
.79574 .14105 L
.7957 .14105 L
.79569 .14105 L
.7957 .14105 L
.79575 .14105 L
.79583 .14106 L
.79596 .14106 L
.79612 .14106 L
.79631 .14106 L
.79652 .14106 L
.79674 .14104 L
.79696 .141 L
.79718 .14094 L
.7974 .14088 L
.79759 .14085 L
.79777 .14087 L
.7979 .14098 L
.798 .1412 L
.79806 .14153 L
.79809 .14192 L
.79808 .14233 L
.79805 .14272 L
.79802 .14305 L
.798 .14331 L
.79799 .14348 L
Mistroke
.79799 .14357 L
.79799 .14359 L
.79799 .14353 L
.79798 .14337 L
.79798 .14315 L
.79797 .14284 L
.79797 .14245 L
.79796 .14203 L
.79795 .14161 L
.79795 .14126 L
.79794 .14101 L
.79794 .14088 L
.79794 .14085 L
.79794 .14088 L
.79794 .14094 L
.79795 .14101 L
.79796 .14109 L
.79799 .14116 L
.79802 .14123 L
.79806 .14129 L
.79807 .14133 L
.79806 .1413 L
.79801 .14121 L
.79792 .14104 L
.79779 .14079 L
.79763 .14046 L
.79743 .14008 L
.79721 .13966 L
.79698 .13921 L
.79675 .13877 L
.79652 .13834 L
.79634 .13792 L
.79622 .13753 L
.79617 .1372 L
.79615 .13696 L
.79612 .1368 L
.79604 .13671 L
.79587 .13666 L
.79559 .13664 L
.79518 .13661 L
.79463 .13654 L
.79396 .13643 L
.79318 .13625 L
.7923 .13602 L
.79142 .13579 L
.79044 .13555 L
.78949 .13531 L
.78854 .13508 L
.78763 .13486 L
.78684 .13468 L
Mistroke
.78618 .13453 L
.78569 .13442 L
.78536 .13436 L
.78515 .13434 L
.78504 .13435 L
.78499 .13439 L
.78495 .13442 L
.7849 .13445 L
.78486 .13446 L
.78485 .13447 L
.78487 .13447 L
.78491 .13447 L
.78496 .13447 L
.785 .13447 L
.78502 .13447 L
.78502 .13447 L
.78501 .13447 L
.78501 .13447 L
.78504 .13447 L
.78511 .13447 L
.7852 .13447 L
.78528 .13447 L
.7853 .13447 L
.78525 .13447 L
.7851 .13447 L
.78487 .13446 L
.78454 .13446 L
.78413 .13445 L
.78368 .13444 L
.7832 .13444 L
.78273 .13443 L
.78229 .13442 L
.78193 .13441 L
.78161 .13441 L
.78132 .1344 L
.78104 .1344 L
.78079 .1344 L
.78057 .1344 L
.78035 .13441 L
.78012 .13446 L
.77985 .13452 L
.77949 .13458 L
.77902 .1346 L
.77838 .13457 L
.77755 .13447 L
.77659 .13428 L
.77554 .13401 L
.77443 .13367 L
.77332 .13327 L
.77224 .13283 L
Mistroke
.77125 .13237 L
.7704 .13193 L
.76966 .13148 L
.76904 .13105 L
.76853 .13064 L
.76814 .13028 L
.76787 .13003 L
.76773 .1299 L
.76772 .12987 L
.7678 .12994 L
.76794 .13006 L
.76805 .13018 L
.76804 .13022 L
.76786 .13013 L
.76747 .12989 L
.76685 .12946 L
.76602 .12886 L
.76499 .12809 L
.76384 .12713 L
.76244 .12613 L
.76084 .12496 L
.75903 .1237 L
.75687 .12224 L
.75479 .12093 L
.7525 .11952 L
.74996 .11805 L
.74747 .11659 L
.74488 .11521 L
.74211 .11382 L
.73961 .11248 L
.73675 .11113 L
.7342 .10975 L
.73151 .1085 L
.72879 .10723 L
.72605 .10594 L
.72362 .1048 L
.72113 .10366 L
.71871 .10253 L
.71632 .10139 L
.71389 .10033 L
.71135 .09924 L
.70881 .09812 L
.70593 .09692 L
.70302 .09573 L
.69979 .09439 L
.69639 .09301 L
.69246 .09146 L
.68854 .08974 L
.68404 .08807 L
.67883 .08622 L
Mistroke
.67444 .08431 L
.66874 .08218 L
.66344 .08006 L
.65807 .07815 L
.6525 .07615 L
.64689 .07407 L
.64133 .07194 L
.63572 .06973 L
.63121 .06792 L
.62684 .066 L
.62246 .06421 L
.61923 .06269 L
.61633 .06127 L
.61376 .06002 L
.61181 .05907 L
.61033 .05835 L
.60923 .05786 L
.60844 .05754 L
.60786 .05736 L
.60745 .05728 L
.60714 .05722 L
.60683 .0571 L
.60648 .05689 L
.60606 .05664 L
.6056 .05635 L
.60516 .05599 L
.60477 .05556 L
.60444 .05508 L
.60417 .05462 L
.60398 .05422 L
.60384 .05391 L
.60373 .0537 L
.60364 .05363 L
.60357 .0537 L
.60351 .05388 L
.6035 .0542 L
.60352 .05461 L
.60355 .05508 L
.60359 .05554 L
.60362 .05599 L
.60364 .0564 L
.60364 .05676 L
.60364 .0571 L
.60364 .05741 L
.60364 .05766 L
.60364 .0578 L
.60364 .05782 L
.60364 .05766 L
.60364 .05743 L
.60364 .05712 L
Mistroke
.60364 .05675 L
.60364 .05633 L
.60364 .05588 L
.60364 .05541 L
.60365 .05493 L
.60368 .05445 L
.60371 .05397 L
.60376 .05351 L
.60384 .05313 L
.60397 .05286 L
.60412 .05275 L
.60424 .05284 L
.60429 .05312 L
.60422 .05356 L
.60399 .05409 L
.60351 .05462 L
.60277 .05509 L
.60166 .05545 L
.60012 .0557 L
.59804 .05583 L
.59551 .05585 L
.5932 .05576 L
.5901 .05555 L
.587 .05522 L
.58359 .05479 L
.57999 .05431 L
.57601 .05376 L
.57277 .05316 L
.56919 .05258 L
.56521 .05213 L
.56203 .05182 L
.55896 .05162 L
.55555 .05151 L
.5522 .05144 L
.54842 .05141 L
.54532 .05139 L
.54176 .05135 L
.53777 .05127 L
.53386 .05116 L
.52964 .05105 L
.52516 .05092 L
.51967 .05079 L
.51536 .05065 L
.50977 .05049 L
.50376 .05033 L
.49804 .05016 L
.49211 .04998 L
.48588 .04979 L
.47937 .04959 L
.47167 .04938 L
Mistroke
.46594 .04916 L
.45916 .04894 L
.45142 .04872 L
.4458 .0485 L
.43933 .04829 L
.43255 .04808 L
.42759 .04788 L
.42234 .04771 L
.41772 .04755 L
.41318 .04741 L
.40992 .04729 L
.40666 .04718 L
.40397 .0471 L
.40187 .04702 L
.40006 .04696 L
.39861 .04691 L
.3976 .04688 L
.39683 .04685 L
.39631 .04683 L
.39599 .04682 L
.3958 .04681 L
.39572 .04681 L
.39572 .04682 L
.3958 .04685 L
.39594 .04689 L
.3961 .04693 L
.39622 .04695 L
.39628 .04694 L
.39623 .04689 L
.39607 .04679 L
.39579 .04665 L
.39542 .04646 L
.39499 .04625 L
.39452 .04601 L
.39402 .04575 L
.39353 .0455 L
.39302 .04523 L
.39252 .04496 L
.39204 .0447 L
.39161 .04447 L
.39128 .04429 L
.39107 .04419 L
.391 .04418 L
.39106 .04426 L
.39122 .04441 L
.39147 .04462 L
.39176 .04487 L
.39206 .04513 L
.39234 .04539 L
.3926 .04564 L
Mistroke
.39285 .04588 L
.3931 .04612 L
.39332 .04634 L
.39352 .04653 L
.39367 .04668 L
.39378 .04679 L
.39384 .04685 L
.39386 .04687 L
.39384 .04686 L
.39381 .04685 L
.39376 .04684 L
.39372 .04683 L
.39367 .04681 L
.39363 .04676 L
.39358 .04669 L
.39353 .04661 L
.39351 .04651 L
.39353 .04642 L
.39361 .04634 L
.39377 .04628 L
.394 .04625 L
.39431 .04624 L
.39469 .04624 L
.39512 .04626 L
.39558 .04629 L
.39606 .04634 L
.39655 .04642 L
.39703 .04652 L
.39747 .04663 L
.39786 .04675 L
.39819 .04685 L
.39845 .04693 L
.39862 .04698 L
.39872 .047 L
.39874 .04698 L
.39872 .04695 L
.39868 .04693 L
.39863 .04691 L
.39858 .04691 L
.39855 .04691 L
.39854 .04689 L
.39853 .04684 L
.39853 .04677 L
.39853 .04671 L
.39853 .04668 L
.39853 .0467 L
.39853 .04679 L
.39853 .04696 L
.39853 .04723 L
.39853 .04757 L
Mistroke
.39853 .04798 L
.39852 .04843 L
.39849 .04889 L
.39845 .04934 L
.39841 .04977 L
.39839 .05021 L
.39841 .05064 L
.39846 .05102 L
.39856 .05133 L
.39872 .05154 L
.39893 .05165 L
.39919 .0517 L
.39946 .05169 L
.39973 .05164 L
.39997 .05158 L
.40017 .05154 L
.40032 .05152 L
.4004 .05152 L
.40042 .05152 L
.40036 .05152 L
.40023 .05151 L
.40004 .05151 L
.3998 .0515 L
.39954 .05149 L
.39926 .05148 L
.39899 .05147 L
.39876 .05146 L
.39859 .05145 L
.39848 .05145 L
.39841 .05145 L
.39839 .05144 L
.39841 .05144 L
.39844 .05145 L
.39848 .05145 L
.39851 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39854 .05145 L
.39855 .05143 L
.39858 .05138 L
.39862 .05131 L
.39865 .05125 L
.39867 .05122 L
Mistroke
.39866 .05124 L
.3986 .05133 L
.39851 .0515 L
.39837 .05176 L
.39818 .0521 L
.39797 .0525 L
.39773 .05294 L
.39748 .0534 L
.39723 .05384 L
.39697 .05428 L
.39673 .05471 L
.39654 .05511 L
.39643 .05546 L
.39636 .05575 L
.39629 .05597 L
.39623 .05611 L
.39614 .05619 L
.39599 .05622 L
.39574 .05621 L
.3954 .05618 L
.39498 .05616 L
.39452 .05616 L
.39404 .05616 L
.39354 .05615 L
.39313 .05613 L
.39266 .05612 L
.3922 .05608 L
.39178 .05604 L
.39145 .05598 L
.39123 .05591 L
.39111 .05584 L
.39106 .05578 L
.39108 .05573 L
.39114 .05569 L
.39123 .05568 L
.39128 .05568 L
.3913 .0557 L
.39131 .05573 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
Mistroke
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.3913 .05574 L
.39129 .05574 L
.39126 .05574 L
Mistroke
.39122 .05573 L
.39119 .05573 L
.39117 .05573 L
.39118 .05573 L
.39124 .05573 L
.39133 .05574 L
.39147 .05574 L
.39166 .05575 L
.39187 .05576 L
.39211 .05577 L
.39236 .05577 L
.3926 .05578 L
.39285 .05579 L
.39309 .0558 L
.39332 .05581 L
.39351 .05582 L
.39367 .05582 L
.39378 .05583 L
.39384 .05583 L
.39386 .05583 L
.39384 .05583 L
.39381 .05583 L
.39377 .05582 L
.39374 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.3937 .05582 L
.39367 .05582 L
.39363 .05582 L
.3936 .05582 L
Mistroke
.39358 .05582 L
.39358 .05582 L
.3936 .05582 L
.39366 .05582 L
.39377 .05582 L
.39393 .05583 L
.39416 .05584 L
.39445 .05585 L
.3948 .05586 L
.39519 .05587 L
.39562 .05589 L
.39607 .05591 L
.39652 .05592 L
.39696 .05594 L
.39737 .05595 L
.39773 .05597 L
.39803 .05598 L
.39827 .05598 L
.39845 .05599 L
.39857 .056 L
.39865 .056 L
.39868 .056 L
.39868 .056 L
.39866 .056 L
.39863 .056 L
.39858 .056 L
.39855 .05599 L
.39854 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
Mistroke
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39854 .05599 L
.39855 .05599 L
.3986 .05598 L
.39868 .05598 L
.39874 .05598 L
.39877 .05599 L
.39875 .05601 L
.39866 .05603 L
.39847 .05605 L
.39819 .05606 L
.39783 .05607 L
.39739 .05607 L
.39692 .05607 L
.39643 .05606 L
.39595 .05604 L
.39549 .05603 L
.39503 .056 L
.39458 .05598 L
.39417 .05595 L
.39385 .05591 L
.39363 .05588 L
.39351 .05585 L
.39347 .05582 L
.39349 .0558 L
.39356 .0558 L
.39363 .0558 L
.39369 .0558 L
.39371 .05581 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
Mistroke
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39374 .05581 L
.39379 .05577 L
.39386 .05567 L
.39393 .05558 L
.39396 .05553 L
.39393 .05555 L
.39381 .05566 L
.39358 .05588 L
.39325 .05625 L
.39283 .05676 L
.39235 .05737 L
.39186 .05804 L
.39139 .05872 L
.39101 .05936 L
.3907 .05995 L
.39043 .06056 L
.39024 .0612 L
.39016 .0618 L
.39022 .06229 L
.39043 .06262 L
.39078 .0628 L
.39122 .06288 L
.39172 .06289 L
.39225 .06282 L
Mistroke
.39273 .06272 L
.39314 .06266 L
.39344 .06264 L
.39365 .06264 L
.39379 .06265 L
.39386 .06265 L
.39389 .06265 L
.39388 .06265 L
.39385 .06265 L
.39382 .06265 L
.39377 .06265 L
.39374 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39374 .06265 L
.39376 .06265 L
.3938 .06265 L
.39384 .06265 L
.39386 .06265 L
.39384 .06265 L
.39379 .06265 L
.39369 .06265 L
.39353 .06264 L
.39332 .06263 L
.39306 .06263 L
.39278 .06262 L
.39251 .06261 L
.39228 .0626 L
.39208 .06259 L
.39193 .06259 L
.39184 .06258 L
.39182 .06258 L
.39188 .06257 L
.39201 .06254 L
.39219 .06248 L
.39239 .06241 L
.39262 .06237 L
.39286 .06236 L
.39312 .0624 L
.39336 .06248 L
.39357 .06261 L
Mistroke
.39375 .06282 L
.39392 .0631 L
.39409 .0635 L
.39427 .06402 L
.39448 .06474 L
.39473 .06552 L
.39503 .06643 L
.39536 .0675 L
.39569 .06875 L
.39601 .07015 L
.39632 .07155 L
.39664 .07273 L
.397 .07403 L
.39737 .07563 L
.39779 .07691 L
.39829 .07821 L
.39893 .07967 L
.39972 .08103 L
.40068 .08248 L
.40182 .08392 L
.40294 .08507 L
.40444 .08628 L
.40593 .08748 L
.40771 .0886 L
.40968 .08961 L
.41173 .09057 L
.41415 .09146 L
.41613 .09222 L
.41833 .09287 L
.4204 .09338 L
.42259 .09373 L
.42499 .0939 L
.42721 .0939 L
.42923 .09373 L
.43149 .09338 L
.43378 .09284 L
.43627 .09204 L
.43875 .09105 L
.44118 .08976 L
.44418 .0883 L
.44672 .0867 L
.44966 .08473 L
.45299 .08294 L
.45564 .08096 L
.45813 .0789 L
.46083 .07717 L
.46395 .07519 L
.46599 .07377 L
.46804 .07239 L
.46952 .07131 L
Mistroke
.47076 .07042 L
.47173 .06976 L
.47241 .06934 L
.4728 .06913 L
.47296 .06909 L
.47294 .06915 L
.47284 .06926 L
.47268 .0694 L
.4725 .06953 L
.47236 .0696 L
.47228 .06964 L
.47225 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47225 .06964 L
.4723 .06961 L
.47237 .06958 L
.47245 .06954 L
.47249 .06953 L
.47248 .06954 L
.47239 .06958 L
.47222 .06967 L
.47195 .06979 L
.4716 .06995 L
.47118 .07014 L
.47072 .07035 L
.47024 .07057 L
.46973 .07079 L
.4693 .07101 L
.46883 .07122 L
.46838 .07142 L
.46798 .07159 L
.46766 .07173 L
.46744 .07182 L
.46732 .07188 L
.46727 .0719 L
.46729 .07188 L
.46736 .07185 L
Mistroke
.46745 .07182 L
.46751 .07179 L
.46753 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07179 L
.46754 .07181 L
.46754 .07185 L
.46754 .07188 L
.46754 .0719 L
.46754 .07189 L
.46754 .07184 L
.46754 .07175 L
.46754 .07162 L
.46754 .07145 L
.46754 .07125 L
.46754 .07103 L
.46754 .07082 L
.46754 .07065 L
.46754 .07049 L
.46754 .07033 L
.46754 .07017 L
.46754 .07001 L
.46754 .06983 L
.46754 .06962 L
.46755 .06934 L
.46758 .069 L
.46762 .06858 L
.46765 .06807 L
.46767 .06745 L
.46766 .06674 L
.46761 .0659 L
.46751 .06492 L
.46737 .0638 L
.46717 .0626 L
.46694 .06143 L
.46666 .06023 L
.46638 .05905 L
.46612 .058 L
.46587 .05702 L
.46565 .05615 L
.46547 .05543 L
Mistroke
.46536 .05481 L
.46533 .05431 L
.46542 .05396 L
.46562 .05374 L
.46596 .05364 L
.46639 .05361 L
.46691 .05361 L
.46749 .05359 L
.46809 .05353 L
.4687 .05337 L
.46928 .05311 L
.46984 .05275 L
.47039 .05233 L
.47092 .05188 L
.47145 .05144 L
.472 .05101 L
.47259 .05058 L
.47323 .05018 L
.47396 .04984 L
.47484 .04957 L
.47587 .0494 L
.47702 .04932 L
.47838 .04933 L
.47984 .0494 L
.48144 .04951 L
.4831 .04964 L
.48478 .04975 L
.48638 .04982 L
.48792 .04987 L
.48945 .04992 L
.49069 .04996 L
.49181 .04999 L
.49279 .05002 L
.49361 .05004 L
.49427 .05006 L
.49478 .05007 L
.49515 .05008 L
.49542 .05008 L
.4956 .05006 L
.49568 .05001 L
.49571 .04993 L
.49572 .04987 L
.49572 .04982 L
.49571 .04981 L
.49574 .04985 L
.49585 .04999 L
.49607 .05024 L
.49642 .05062 L
.49693 .05112 L
.49764 .05176 L
Mistroke
.4985 .05252 L
.49959 .05331 L
.50088 .05416 L
.50238 .05506 L
.50413 .05598 L
.50627 .05691 L
.50838 .05773 L
.51085 .0585 L
.51344 .05916 L
.51627 .05968 L
.51906 .06004 L
.52209 .06023 L
.52518 .06025 L
.52853 .06013 L
.53159 .05986 L
.53491 .05945 L
.53821 .05892 L
.54097 .05829 L
.54382 .0576 L
.54647 .05686 L
.54896 .05604 L
.55105 .05517 L
.55293 .05433 L
.55452 .05359 L
.55599 .05297 L
.55733 .05252 L
.55859 .05226 L
.55985 .05223 L
.56118 .05236 L
.56262 .05268 L
.56407 .05312 L
.56562 .05362 L
.56733 .05416 L
.56905 .05468 L
.57082 .0552 L
.57262 .05564 L
.57427 .05595 L
.57586 .05609 L
.57725 .0561 L
.57835 .05601 L
.57928 .05587 L
.58002 .05564 L
.58052 .05539 L
.5808 .05509 L
.5809 .05477 L
.58089 .05447 L
.58083 .05421 L
.58079 .05397 L
.58083 .05374 L
.581 .05356 L
Mistroke
.58136 .05344 L
.58195 .05342 L
.58269 .05345 L
.58357 .05354 L
.58455 .05369 L
.58556 .05392 L
.58659 .05422 L
.58757 .05454 L
.58847 .0549 L
.58927 .05526 L
.58999 .05562 L
.5906 .05605 L
.59113 .05645 L
.59162 .05675 L
.59213 .05696 L
.59266 .0571 L
.59326 .05719 L
.59393 .05725 L
.5947 .05726 L
.59548 .05723 L
.5964 .05716 L
.59736 .05708 L
.59842 .05703 L
.59965 .05706 L
.60098 .05716 L
.60225 .05734 L
.60355 .05759 L
.60487 .05792 L
.6061 .05832 L
.60735 .05879 L
.60855 .05933 L
.60981 .0599 L
.61117 .06051 L
.61255 .06111 L
.61401 .06169 L
.61547 .06223 L
.61701 .06271 L
.61849 .06314 L
.62002 .06354 L
.62166 .06389 L
.62319 .06423 L
.62486 .06457 L
.62652 .06495 L
.62831 .06539 L
.63017 .06592 L
.63182 .06653 L
.63337 .06719 L
.63494 .06789 L
.63629 .06863 L
.63759 .06941 L
Mistroke
.63879 .0702 L
.63982 .07096 L
.64064 .07161 L
.64125 .07216 L
.64167 .07261 L
.64193 .07297 L
.64207 .07325 L
.64212 .07348 L
.64216 .07366 L
.64223 .07383 L
.64232 .07398 L
.64244 .07412 L
.64257 .07426 L
.64274 .0744 L
.64294 .07457 L
.64316 .07478 L
.64339 .07501 L
.64362 .07523 L
.64382 .07544 L
.644 .07562 L
.64415 .07576 L
.64425 .07586 L
.64431 .07592 L
.64432 .07594 L
.64431 .07592 L
.64428 .07589 L
.64424 .07585 L
.64421 .07582 L
.64419 .07581 L
.64419 .0758 L
.6442 .07577 L
.64421 .07572 L
.64423 .07564 L
.64423 .07556 L
.64424 .07549 L
.64424 .07546 L
.64421 .07549 L
.64415 .07563 L
.64406 .07589 L
.64394 .07625 L
.6438 .07671 L
.64366 .07729 L
.64354 .07799 L
.64346 .07876 L
.64344 .07965 L
.6435 .08064 L
.64361 .08176 L
.64383 .08283 L
.64412 .08395 L
.6445 .0851 L
Mistroke
.64495 .08628 L
.64547 .08739 L
.64602 .08859 L
.6466 .08969 L
.64718 .09085 L
.64775 .09208 L
.64832 .09339 L
.64888 .09463 L
.64944 .09593 L
.65001 .09726 L
.6506 .09861 L
.65124 .09999 L
.65198 .10127 L
.65282 .10258 L
.65383 .10391 L
.65506 .10514 L
.65657 .10628 L
.65834 .10733 L
.66037 .10826 L
.66262 .10906 L
.66511 .10972 L
.66781 .1103 L
.67004 .11077 L
.6725 .11113 L
.67495 .11138 L
.67702 .11154 L
.67911 .11161 L
.68087 .11162 L
.68228 .11158 L
.68343 .11153 L
.68427 .11147 L
.68483 .11142 L
.68511 .11142 L
.68516 .11146 L
.68507 .11153 L
.68493 .1116 L
.68476 .11164 L
.6846 .11164 L
.68445 .11161 L
.68434 .11151 L
.68427 .11134 L
.68421 .1111 L
.68419 .11075 L
.68423 .11027 L
.68435 .10965 L
.68457 .10891 L
.68488 .10806 L
.68527 .1071 L
.68574 .10603 L
.68625 .1049 L
Mistroke
.68683 .10384 L
.68745 .1028 L
.6881 .10181 L
.6888 .10091 L
.68949 .10018 L
.69017 .09954 L
.69085 .09902 L
.69153 .09863 L
.69222 .09835 L
.69292 .0982 L
.69369 .09815 L
.69454 .09819 L
.69546 .09825 L
.69644 .09828 L
.69746 .09829 L
.69857 .09828 L
.69972 .09825 L
.70094 .09825 L
.70224 .09832 L
.70354 .09849 L
.70496 .0988 L
.70641 .09926 L
.70796 .09988 L
.7096 .10067 L
.71118 .1016 L
.71279 .10251 L
.71435 .10355 L
.71599 .10475 L
.71762 .10585 L
.71939 .10699 L
.7211 .10818 L
.72294 .10944 L
.72486 .11059 L
.72698 .11175 L
.72921 .11293 L
.73165 .11413 L
.73434 .11525 L
.73757 .11645 L
.74036 .1175 L
.7436 .1186 L
.74747 .11986 L
.75062 .12098 L
.75429 .12214 L
.7585 .12335 L
.76213 .12463 L
.76579 .12596 L
.76963 .12736 L
.77348 .1288 L
.77747 .13029 L
.7805 .13159 L
Mistroke
.78364 .13302 L
.7867 .13447 L
.7892 .13583 L
.79165 .13717 L
.79369 .1384 L
.79539 .13939 L
.79666 .1402 L
.79758 .14081 L
.79821 .14123 L
.79857 .14146 L
.79869 .14152 L
.79865 .14149 L
.79852 .1414 L
.79835 .14127 L
.79816 .14112 L
.79799 .14098 L
.79787 .14087 L
.79781 .14083 L
.7978 .14088 L
.79784 .14099 L
.79792 .14117 L
.79805 .14143 L
.79824 .14179 L
.79849 .14225 L
.79883 .1428 L
.79926 .14345 L
.79978 .14419 L
.80039 .14505 L
.80107 .14602 L
.80179 .14706 L
.80254 .14816 L
.80328 .14928 L
.80398 .15036 L
.80462 .15138 L
.80519 .15232 L
.80566 .15315 L
.80604 .15384 L
.80634 .15441 L
.80656 .1549 L
.80668 .1553 L
.80671 .15563 L
.80669 .15594 L
.80667 .1563 L
.8067 .15673 L
.80683 .15728 L
.80712 .15797 L
.80758 .15879 L
.80823 .15969 L
.80906 .16075 L
.81007 .16192 L
Mistroke
.81127 .16326 L
.81256 .16469 L
.81401 .1662 L
.8156 .16767 L
.81722 .16921 L
.81894 .17081 L
.82071 .17238 L
.82248 .17398 L
.82424 .17567 L
.82603 .17734 L
.82777 .17917 L
.82937 .18111 L
.83096 .1831 L
.83254 .18514 L
.83398 .18719 L
.83538 .18919 L
.83667 .19107 L
.83783 .19283 L
.83882 .19434 L
.83965 .19569 L
.84033 .19685 L
.84086 .19776 L
.84126 .19849 L
.84154 .19903 L
.84171 .19939 L
.84178 .19959 L
.84177 .19967 L
.84173 .19966 L
.84168 .19959 L
.84162 .19949 L
.84157 .19939 L
.84153 .19928 L
.8415 .19919 L
.84148 .19912 L
.84147 .19907 L
.84144 .19902 L
.8414 .19898 L
.84136 .19896 L
.84132 .199 L
.8413 .19912 L
.84132 .19938 L
.8414 .19978 L
.84155 .20035 L
.84177 .20105 L
.84206 .20187 L
.84241 .20278 L
.84281 .20376 L
.84323 .2047 L
.84367 .20565 L
.84394 .20636 L
Mistroke
.84434 .20716 L
.84469 .2079 L
.845 .20852 L
.84529 .20913 L
.84556 .20949 L
.8458 .20976 L
.84602 .2099 L
.84623 .20996 L
.84646 .20994 L
.84672 .20989 L
.84702 .20987 L
.84731 .20991 L
.84762 .21006 L
.84801 .21042 L
.84853 .21088 L
.8491 .21141 L
.84958 .212 L
.8501 .21268 L
.85087 .21329 L
.85151 .21414 L
.85208 .21569 L
.85304 .2171 L
.85412 .21853 L
.85523 .22012 L
.8563 .22178 L
.85738 .2235 L
.8589 .22525 L
.86016 .22603 L
.8615 .22914 L
.86281 .23048 L
.86434 .23325 L
.86627 .23533 L
.8676 .23682 L
.86936 .23968 L
.8709 .24193 L
.8724 .24414 L
.87328 .24577 L
.8751 .24818 L
.87671 .2511 L
.87843 .25313 L
.88001 .25571 L
.88163 .25804 L
.88293 .26104 L
.88446 .26295 L
.88711 .2665 L
.88862 .2688 L
.89126 .27239 L
.89344 .27508 L
.89565 .27859 L
.89735 .28125 L
Mistroke
.90004 .28401 L
.90167 .28759 L
.90374 .29006 L
.90621 .29401 L
.90808 .29677 L
.90982 .29949 L
.9115 .302 L
.91254 .30405 L
.91444 .30648 L
.91569 .30845 L
.91651 .30966 L
.91745 .31148 L
.9182 .31278 L
.91865 .31372 L
.91903 .31472 L
.91934 .31576 L
.91954 .31655 L
.91966 .31751 L
.91978 .31866 L
.91994 .31969 L
.92012 .32054 L
.92032 .32155 L
.92052 .32268 L
.92071 .32363 L
.92089 .32442 L
.92108 .32515 L
.92129 .32584 L
.9215 .32644 L
.92169 .32689 L
.92184 .32726 L
.92193 .32752 L
.92199 .32768 L
.92201 .32779 L
.92201 .32785 L
.92199 .32788 L
.92196 .32786 L
.92194 .32782 L
.92193 .32776 L
.92193 .32768 L
.92193 .32759 L
.92192 .32754 L
.92191 .32753 L
.9219 .32753 L
.9219 .32753 L
.92189 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
Mistroke
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92188 .32753 L
.92188 .32753 L
.92186 .32753 L
.92182 .32753 L
.9218 .32753 L
.92179 .32753 L
.92181 .32753 L
.92185 .32753 L
.92194 .32753 L
.92206 .32753 L
.92223 .32753 L
.92245 .32752 L
.92272 .32752 L
.92297 .32752 L
.92318 .32752 L
.92336 .32752 L
.92353 .32752 L
.92366 .32752 L
.92374 .32752 L
.92371 .32752 L
.9236 .32752 L
.92343 .32752 L
.92323 .32752 L
.92301 .32752 L
.92279 .32752 L
.92253 .32752 L
.92231 .32752 L
.92212 .32753 L
.92198 .32753 L
.92188 .32753 L
.92182 .32753 L
.92179 .32753 L
.92179 .32753 L
.92181 .32753 L
.92184 .32753 L
.92187 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92187 .32753 L
.92184 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92184 .32753 L
.92191 .32753 L
.92203 .32753 L
.92219 .32753 L
.92237 .32752 L
.92258 .32752 L
.92278 .32752 L
.92297 .32752 L
.92316 .32752 L
.92335 .32752 L
.92354 .32752 L
.92372 .32752 L
.92386 .32752 L
.92395 .32752 L
Mistroke
.924 .32752 L
.92402 .32752 L
.92401 .32752 L
.92398 .32752 L
.92395 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92393 .32752 L
.92395 .32752 L
.92398 .32752 L
.924 .32752 L
.92402 .32752 L
.924 .32752 L
.92397 .32752 L
.92389 .32752 L
.92377 .32752 L
.92362 .32752 L
.92343 .32752 L
.92323 .32752 L
.92302 .32752 L
.92283 .32752 L
.92264 .32752 L
.92245 .32752 L
.92227 .32753 L
.92209 .32753 L
.92195 .32753 L
.92186 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92183 .32753 L
.92186 .32753 L
.92188 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92187 .32753 L
.92184 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92184 .32753 L
.92191 .32753 L
.92203 .32753 L
.92219 .32753 L
.92237 .32752 L
.92258 .32752 L
.92278 .32752 L
.92297 .32752 L
.92316 .32752 L
.92335 .32752 L
.92354 .32752 L
.92372 .32752 L
.92386 .32752 L
.92395 .32752 L
.924 .32752 L
Mistroke
.92402 .32752 L
.92401 .32752 L
.92398 .32752 L
.92395 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92393 .32752 L
.92394 .32752 L
.92397 .32752 L
.924 .32752 L
.92401 .32752 L
.924 .32752 L
.92397 .32752 L
.92389 .32752 L
.92378 .32752 L
.92362 .32752 L
.92343 .32752 L
.92322 .32752 L
.92301 .32752 L
.92283 .32752 L
.92264 .32752 L
.92246 .32753 L
.92227 .32753 L
.92209 .32753 L
.92195 .32753 L
.92185 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92183 .32753 L
.92186 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92185 .32753 L
.92182 .32753 L
.92179 .32753 L
.92179 .32753 L
.9218 .32753 L
.92185 .32753 L
.92194 .32753 L
.92208 .32753 L
.92225 .32753 L
.92245 .32752 L
Mistroke
.92265 .32752 L
.92286 .32752 L
.92297 .32752 L
.92314 .32752 L
.92332 .32752 L
.92352 .32752 L
.9237 .32752 L
.92385 .32752 L
.92393 .32752 L
.92396 .32752 L
.92397 .32752 L
.92396 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32753 L
.92393 .32755 L
.92396 .32759 L
.92397 .3276 L
.92396 .32759 L
.92394 .32756 L
.92389 .32749 L
.92379 .32737 L
.92359 .3272 L
.92334 .32699 L
.92314 .32677 L
.92297 .32657 L
.9228 .32638 L
.92263 .3262 L
.92244 .32601 L
.92223 .32581 L
.92204 .32562 L
.92189 .32546 L
.92181 .32537 L
.92178 .32533 L
.92177 .32531 L
.92177 .32532 L
.92181 .32534 L
.92181 .32538 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92182 .3254 L
.92185 .32545 L
.92186 .32549 L
.92186 .32547 L
.92183 .32543 L
.92178 .32533 L
.92167 .32511 L
.92146 .32469 L
.92121 .32421 L
.92101 .32381 L
.92083 .32346 L
.92066 .32312 L
.92048 .32278 L
.92028 .32239 L
.92007 .32196 L
.91987 .32158 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
Mistroke
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
Mistroke
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
Mistroke
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
Mistroke
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
Mistroke
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
Mistroke
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
Mistroke
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
Mistroke
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
Mistroke
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
Mistroke
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
Mistroke
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
Mistroke
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
Mistroke
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
Mistroke
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
Mistroke
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
Mistroke
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
Mistroke
.07393 .49306 L
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
Mistroke
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
Mistroke
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
Mistroke
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
Mistroke
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
Mistroke
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
Mistroke
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
Mistroke
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
Mistroke
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
Mistroke
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
Mistroke
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
Mistroke
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
Mistroke
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
Mistroke
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
Mistroke
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
Mistroke
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
Mistroke
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
Mistroke
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mistroke
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
.08376 .46683 L
Mistroke
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
Mistroke
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
Mistroke
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
Mistroke
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
Mistroke
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
Mistroke
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
Mistroke
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
Mistroke
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
Mistroke
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
Mistroke
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
Mistroke
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
Mistroke
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
Mistroke
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
Mistroke
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
Mistroke
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
Mistroke
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
Mistroke
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
Mistroke
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
Mistroke
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
Mistroke
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
Mistroke
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
Mistroke
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
Mistroke
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
Mistroke
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
Mistroke
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
Mistroke
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
Mistroke
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
Mistroke
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
Mistroke
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
Mistroke
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
Mistroke
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
Mistroke
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
Mistroke
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
Mistroke
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
Mistroke
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
Mistroke
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
Mistroke
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
Mistroke
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
Mistroke
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
Mistroke
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
Mistroke
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
Mistroke
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
Mistroke
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
Mistroke
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
Mistroke
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
Mistroke
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
Mistroke
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
Mistroke
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
Mistroke
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
Mistroke
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
Mistroke
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
Mistroke
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
Mistroke
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
Mistroke
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
Mistroke
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
Mistroke
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
Mistroke
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
Mistroke
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
Mistroke
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
Mistroke
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
Mistroke
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
Mistroke
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
Mistroke
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
Mistroke
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
Mistroke
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
Mistroke
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
Mistroke
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
Mistroke
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
Mistroke
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
Mistroke
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
Mistroke
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
Mistroke
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
Mistroke
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
Mistroke
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
Mistroke
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
Mistroke
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
Mistroke
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
Mistroke
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
Mistroke
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
Mistroke
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
Mistroke
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
Mistroke
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
Mistroke
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
Mistroke
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
Mistroke
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
Mistroke
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
Mistroke
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
Mistroke
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
Mistroke
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
Mistroke
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
Mistroke
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
Mistroke
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mistroke
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
Mistroke
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
Mistroke
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
.09393 .45432 L
Mistroke
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
Mistroke
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
Mistroke
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
Mistroke
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
Mistroke
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
Mistroke
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
Mistroke
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
Mistroke
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
Mistroke
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
Mistroke
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
Mistroke
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
Mistroke
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
Mistroke
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
Mistroke
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
Mistroke
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
Mistroke
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
Mistroke
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
Mistroke
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
Mistroke
.08428 .40668 L
.08427 .40697 L
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
Mistroke
.08421 .41107 L
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
Mistroke
.09066 .41137 L
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
Mistroke
.08437 .41135 L
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
Mistroke
.08681 .41124 L
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
Mistroke
.0895 .41368 L
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
Mistroke
.0854 .41367 L
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
Mistroke
.08582 .40999 L
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
Mistroke
.08465 .4004 L
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
Mistroke
.08419 .41151 L
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
Mistroke
.08939 .41368 L
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
Mistroke
.08705 .41367 L
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
Mistroke
.08679 .41367 L
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
Mistroke
.08687 .41379 L
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
Mistroke
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
Mistroke
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
Mistroke
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
Mistroke
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
Mistroke
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
Mistroke
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
Mistroke
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
Mistroke
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
Mistroke
.08659 .41123 L
.08664 .41128 L
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
Mistroke
.09321 .45392 L
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
Mistroke
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
Mistroke
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
Mistroke
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
Mistroke
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
Mistroke
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
Mistroke
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
Mistroke
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
Mistroke
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
Mistroke
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
Mistroke
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
Mistroke
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
Mistroke
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
Mistroke
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
Mistroke
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
Mistroke
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
Mistroke
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
Mistroke
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
Mistroke
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
Mistroke
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mistroke
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
Mistroke
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
Mistroke
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
Mistroke
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
Mistroke
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
Mistroke
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
Mistroke
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
Mistroke
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
Mistroke
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
Mistroke
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
Mistroke
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
Mistroke
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
Mistroke
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
Mistroke
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
Mistroke
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
Mistroke
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
Mistroke
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
Mistroke
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
Mistroke
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
Mistroke
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
Mistroke
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
Mistroke
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
Mistroke
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
Mistroke
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
Mistroke
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
Mistroke
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
Mistroke
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
Mistroke
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
Mistroke
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
Mistroke
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
Mistroke
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
Mistroke
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
Mistroke
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
Mistroke
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
Mistroke
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
Mistroke
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
Mistroke
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
Mistroke
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
Mistroke
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
Mistroke
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
Mistroke
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
Mistroke
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
Mistroke
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
Mistroke
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
Mistroke
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
Mistroke
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
Mistroke
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
Mistroke
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
Mistroke
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
Mistroke
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
.37468 .03856 L
Mistroke
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
.34922 .0546 L
Mistroke
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
.30139 .08594 L
.30082 .08671 L
Mistroke
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
Mistroke
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
Mistroke
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
Mistroke
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
Mistroke
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
Mistroke
.20691 .16282 L
.20713 .16263 L
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
Mistroke
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
.24049 .12506 L
.24062 .12497 L
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
Mistroke
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
Mistroke
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
Mistroke
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
Mistroke
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
Mistroke
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
Mistroke
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
Mistroke
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
Mistroke
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
Mistroke
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
Mistroke
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
Mistroke
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
Mistroke
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
Mistroke
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
Mistroke
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
.38497 .03476 L
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
Mistroke
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
Mistroke
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
Mistroke
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
Mistroke
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
Mistroke
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
.29017 .08361 L
.29021 .08358 L
Mistroke
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
Mistroke
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
Mistroke
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
Mistroke
.18524 .17179 L
.18368 .17374 L
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
Mistroke
.13419 .25132 L
.13266 .25432 L
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
Mistroke
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
Mistroke
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
Mistroke
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
Mistroke
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
Mistroke
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
Mistroke
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
Mistroke
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
Mistroke
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
Mistroke
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
Mistroke
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
Mistroke
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
Mistroke
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
Mistroke
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
Mistroke
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
Mistroke
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
Mistroke
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
Mistroke
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
Mistroke
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
Mistroke
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
Mistroke
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
Mistroke
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
Mistroke
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
.09956 .71632 L
Mistroke
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
Mistroke
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
Mistroke
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
Mistroke
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
Mistroke
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
.07148 .49316 L
.07151 .49313 L
Mistroke
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
Mistroke
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
Mistroke
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
Mistroke
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
Mistroke
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
Mistroke
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
Mistroke
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
Mistroke
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
.08023 .60563 L
.08022 .60606 L
Mistroke
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
Mistroke
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
Mistroke
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
Mistroke
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
Mistroke
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
Mistroke
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
Mistroke
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
Mistroke
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
Mistroke
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
Mistroke
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
Mistroke
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
Mistroke
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
Mistroke
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
Mistroke
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
Mistroke
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
Mistroke
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
Mistroke
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
Mistroke
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
Mistroke
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
Mistroke
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
Mistroke
.687 .92341 L
.68712 .92334 L
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
Mistroke
.6875 .92598 L
.68731 .92601 L
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
Mistroke
.67651 .93258 L
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
Mistroke
.67402 .93246 L
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
Mistroke
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
Mistroke
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
Mistroke
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
Mistroke
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
Mistroke
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
Mistroke
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
Mistroke
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
Mistroke
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
Mistroke
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
Mistroke
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
Mistroke
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
Mistroke
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
Mistroke
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
Mistroke
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
Mistroke
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
Mistroke
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
Mistroke
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
Mistroke
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
Mistroke
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
Mistroke
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
Mistroke
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
Mistroke
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
Mistroke
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
Mistroke
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
Mistroke
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
Mistroke
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
Mistroke
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
Mistroke
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
Mistroke
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
Mistroke
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
Mistroke
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
Mistroke
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
Mistroke
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
Mistroke
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
Mistroke
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
Mistroke
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
Mistroke
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
Mistroke
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
Mistroke
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
Mistroke
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
Mistroke
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
Mistroke
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
Mistroke
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
Mistroke
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
Mistroke
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
Mistroke
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
Mistroke
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
Mistroke
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
Mistroke
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
Mistroke
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
Mistroke
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
Mistroke
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
Mistroke
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
Mistroke
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
Mistroke
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
Mistroke
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
Mistroke
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
Mistroke
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
Mistroke
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
Mistroke
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
Mistroke
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
Mistroke
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
Mistroke
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
Mistroke
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
Mistroke
.67231 .93392 L
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
Mistroke
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
Mistroke
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
Mistroke
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
Mistroke
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
Mistroke
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
Mistroke
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
Mistroke
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
.85306 .80019 L
.85302 .80022 L
Mistroke
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
Mistroke
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
Mistroke
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
.8538 .79278 L
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
Mistroke
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
Mistroke
.8738 .75155 L
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
Mistroke
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
Mistroke
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
Mistroke
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
Mistroke
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
Mistroke
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
Mistroke
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
Mistroke
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
Mistroke
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
Mistroke
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
Mistroke
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
Mistroke
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
Mistroke
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
Mistroke
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
Mistroke
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
Mistroke
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
Mistroke
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
Mistroke
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
Mistroke
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
Mistroke
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
Mistroke
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
Mistroke
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
Mistroke
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
Mistroke
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
Mistroke
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
Mistroke
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
Mistroke
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
Mistroke
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
Mistroke
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
Mistroke
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
Mistroke
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
.08937 .41149 L
.08908 .41118 L
.08868 .41073 L
.08821 .41015 L
.08771 .40943 L
.0872 .4086 L
.08671 .4078 L
.08625 .40694 L
.08578 .40606 L
.0853 .40516 L
.08486 .40443 L
.0845 .4038 L
.08425 .40328 L
.08409 .40289 L
.084 .40259 L
.08399 .40236 L
.08407 .40215 L
.0842 .40189 L
.08434 .40146 L
.0845 .40079 L
.08468 .39986 L
.08488 .39859 L
.08512 .39692 L
.08539 .39515 L
.08568 .39276 L
.08601 .39019 L
.08637 .3874 L
.08678 .38417 L
.08722 .38054 L
.08769 .37667 L
.08815 .37239 L
.08863 .36874 L
.08911 .36398 L
.08963 .36015 L
.0902 .35568 L
.09085 .351 L
.09157 .34648 L
.09229 .34188 L
Mistroke
.09304 .33794 L
.09381 .33363 L
.09457 .33014 L
.09523 .32673 L
.09598 .32352 L
.09662 .32057 L
.09724 .31839 L
.09785 .31632 L
.09843 .31466 L
.09894 .31324 L
.09937 .31212 L
.09972 .31147 L
.09999 .31095 L
.1002 .31061 L
.10036 .3104 L
.10049 .31032 L
.10059 .31026 L
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
.10062 .30982 L
.10056 .30963 L
.10053 .30937 L
.10055 .30906 L
.10063 .30868 L
.10078 .30827 L
.10096 .30785 L
.10118 .30744 L
.1014 .30709 L
.10158 .3068 L
.10172 .30662 L
.10187 .30646 L
.10204 .30632 L
.10227 .3062 L
.10255 .30602 L
.1029 .30572 L
.10333 .30524 L
.10386 .30449 L
.10454 .30339 L
.10539 .3019 L
.10643 .30015 L
.10752 .29802 L
.10892 .29582 L
.11039 .29324 L
.11209 .2902 L
.11384 .28711 L
.11574 .28413 L
.11752 .28085 L
.11941 .2775 L
.12129 .27414 L
Mistroke
.12307 .27098 L
.1249 .26778 L
.12671 .2647 L
.12853 .26157 L
.13049 .25844 L
.1324 .25523 L
.13444 .25188 L
.13649 .24866 L
.1386 .24501 L
.14076 .24164 L
.14299 .23805 L
.14531 .23434 L
.1475 .23089 L
.14976 .22731 L
.15224 .22351 L
.15436 .22016 L
.15671 .21649 L
.15906 .21276 L
.16165 .20913 L
.1639 .20533 L
.16633 .2017 L
.16879 .1981 L
.17113 .19446 L
.17346 .19099 L
.17579 .18749 L
.17798 .18398 L
.17999 .18071 L
.18202 .17732 L
.18397 .1738 L
.18584 .17083 L
.18755 .16781 L
.18925 .16488 L
.19079 .16256 L
.19232 .16023 L
.19363 .15828 L
.19484 .15646 L
.19604 .15493 L
.197 .15367 L
.19786 .15264 L
.19859 .15187 L
.19917 .15136 L
.19957 .1511 L
.19978 .15106 L
.19982 .15116 L
.19975 .15133 L
.19964 .15145 L
.19956 .15143 L
.1996 .15123 L
.19979 .1508 L
.20016 .15014 L
Mistroke
.20073 .14926 L
.20149 .14819 L
.20247 .14694 L
.20371 .1455 L
.20515 .14393 L
.20678 .14223 L
.20874 .14038 L
.21096 .13837 L
.21312 .13637 L
.2157 .13425 L
.21838 .13218 L
.22103 .13014 L
.22393 .12818 L
.22664 .1263 L
.22936 .12468 L
.23195 .12312 L
.2343 .12185 L
.23642 .12069 L
.23828 .11976 L
.23985 .11901 L
.24105 .11846 L
.242 .11811 L
.24272 .11794 L
.24322 .1179 L
.24355 .11796 L
.24375 .11809 L
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
.24425 .11881 L
.24447 .11856 L
.24481 .11814 L
.24533 .11754 L
.24608 .11676 L
.2471 .1158 L
.24843 .11478 L
.24997 .11356 L
.25179 .11211 L
.25405 .11064 L
.25651 .10894 L
.25932 .10708 L
.2627 .10514 L
.26561 .10319 L
.26893 .10107 L
.27257 .09909 L
.27569 .09696 L
Mistroke
.27906 .09495 L
.28232 .09285 L
.28565 .09059 L
.28874 .08849 L
.29197 .08615 L
.2954 .08397 L
.29875 .08165 L
.30248 .0792 L
.30607 .07692 L
.30991 .07448 L
.31399 .07207 L
.318 .06956 L
.32208 .06703 L
.32671 .06433 L
.33062 .06172 L
.33505 .05898 L
.33922 .0563 L
.34365 .0536 L
.34758 .05118 L
.35139 .04886 L
.35495 .04663 L
.35829 .04472 L
.36117 .04318 L
.36375 .0418 L
.36607 .04063 L
.36783 .03972 L
.36939 .03905 L
.37057 .03862 L
.37147 .0384 L
.37209 .03831 L
.37245 .03834 L
.37259 .03844 L
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
Mistroke
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
.37178 .03891 L
.37207 .03897 L
.37251 .03905 L
.37313 .03913 L
.37392 .03919 L
.37491 .0392 L
.3761 .03914 L
.3775 .03901 L
.37906 .0388 L
.38089 .03852 L
.38273 .03818 L
.38483 .03781 L
.38699 .03742 L
.38932 .03704 L
.39142 .03666 L
.39365 .03628 L
.39576 .03594 L
.39777 .03564 L
.39958 .03541 L
.40122 .03526 L
.40265 .03519 L
.40388 .03519 L
.40483 .03524 L
.40557 .03533 L
.40612 .03542 L
.40648 .03549 L
.40666 .03552 L
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
Mistroke
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
.40813 .03792 L
.4081 .03768 L
.40811 .03738 L
.40821 .03705 L
.40842 .03673 L
.40879 .03646 L
.40934 .03633 L
.41011 .0364 L
.41111 .03666 L
.41241 .03706 L
.41393 .03753 L
.4158 .03803 L
.41784 .03852 L
.4202 .03894 L
.42281 .03923 L
.42581 .03939 L
.42851 .03942 L
.43164 .03934 L
.435 .03915 L
Mistroke
.43803 .03889 L
.44126 .0386 L
.44449 .03828 L
.44801 .03803 L
.4509 .03779 L
.45414 .03762 L
.45758 .0375 L
.46068 .0374 L
.46394 .03726 L
.46717 .03704 L
.47057 .03673 L
.47423 .03637 L
.47754 .03598 L
.48106 .03559 L
.48474 .03528 L
.48809 .03504 L
.49179 .03489 L
.49522 .03485 L
.49887 .03495 L
.50249 .03524 L
.50586 .03571 L
.50943 .03633 L
.51277 .03706 L
.51608 .03792 L
.51945 .03887 L
.52288 .03985 L
.52618 .04078 L
.52948 .0416 L
.53279 .04234 L
.53611 .04304 L
.53938 .04371 L
.54263 .04441 L
.54579 .04515 L
.54897 .04595 L
.55192 .04682 L
.55474 .04777 L
.5574 .04875 L
.55975 .04973 L
.56187 .05057 L
.5637 .05148 L
.56524 .05242 L
.5664 .05323 L
.56725 .05396 L
.56783 .0546 L
.56816 .05512 L
.56829 .0555 L
.56832 .05573 L
.56836 .05583 L
.56851 .05583 L
.56884 .05579 L
Mistroke
.56941 .05577 L
.57029 .05578 L
.57153 .0558 L
.57308 .05584 L
.57513 .05588 L
.57758 .05586 L
.58033 .05577 L
.58339 .0556 L
.5867 .05534 L
.58988 .055 L
.59311 .05459 L
.59606 .05415 L
.59896 .05374 L
.60141 .05336 L
.60382 .05304 L
.60608 .05283 L
.608 .05277 L
.60989 .0529 L
.61179 .05325 L
.61374 .05382 L
.61579 .05462 L
.61783 .05558 L
.62 .05673 L
.62215 .05807 L
.62451 .05946 L
.62708 .06095 L
.63 .06241 L
.63257 .06381 L
.63533 .06515 L
.63805 .06633 L
.6409 .06734 L
.64344 .06823 L
.64607 .06899 L
.64869 .06963 L
.65132 .0702 L
.6542 .07073 L
.65707 .07125 L
.66011 .07179 L
.66342 .0724 L
.66668 .07308 L
.67012 .07385 L
.67371 .07464 L
.6771 .07557 L
.68062 .07666 L
.68395 .07793 L
.68741 .07922 L
.69048 .08062 L
.69368 .08213 L
.69688 .08364 L
.69977 .08512 L
Mistroke
.70295 .08662 L
.70566 .0879 L
.70825 .08922 L
.71068 .09037 L
.71285 .09144 L
.71491 .09237 L
.7164 .09311 L
.71767 .09366 L
.7187 .09397 L
.71942 .09407 L
.71984 .09398 L
.71998 .09373 L
.71989 .09338 L
.71965 .09302 L
.71935 .09273 L
.71907 .09253 L
.7188 .09243 L
.71862 .09244 L
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
.71997 .09534 L
.71983 .09519 L
.71969 .095 L
.71961 .09475 L
.71967 .09454 L
.71992 .09443 L
.72042 .09447 L
.7212 .09469 L
.72227 .09511 L
.72366 .09572 L
.72525 .09651 L
.72702 .0974 L
.72906 .09839 L
.73131 .09949 L
.73377 .10061 L
.73614 .10165 L
.7384 .10261 L
.74059 .10348 L
.74258 .10421 L
.74426 .10479 L
.7457 .10522 L
.74687 .1055 L
Mistroke
.74775 .10567 L
.74843 .10575 L
.74895 .10577 L
.74936 .10577 L
.74965 .10573 L
.74986 .1057 L
.75002 .10567 L
.75013 .10563 L
.75023 .10561 L
.75033 .10558 L
.75045 .10555 L
.75057 .10551 L
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
.75054 .10576 L
.75039 .10589 L
.75026 .10607 L
.75018 .10632 L
.75019 .10666 L
.75032 .10707 L
.75061 .10755 L
.75109 .10811 L
.7518 .10871 L
.75274 .10942 L
.75389 .11023 L
.75538 .11118 L
.75705 .11227 L
.75895 .11349 L
.76111 .11487 L
.76346 .11636 L
.76585 .11795 L
.76824 .11961 L
.77057 .12111 L
.77271 .12261 L
.77456 .12388 L
.77625 .12505 L
.77777 .12618 L
.77895 .12714 L
.77995 .12799 L
.78078 .12878 L
.78146 .12961 L
.78204 .13052 L
.78253 .13147 L
.78295 .13248 L
.78334 .13351 L
.78372 .13467 L
Mistroke
.78404 .1357 L
.78429 .13685 L
.78451 .13788 L
.78474 .13891 L
.785 .14004 L
.78531 .14095 L
.78573 .14184 L
.78629 .14271 L
.7871 .14361 L
.7882 .1445 L
.7896 .14547 L
.79116 .14649 L
.79296 .14787 L
.79495 .14946 L
.79702 .15126 L
.79939 .15325 L
.80206 .15544 L
.80438 .15771 L
.80677 .16011 L
.80905 .16251 L
.8111 .16499 L
.81293 .16729 L
.81464 .16968 L
.81613 .17194 L
.8175 .17423 L
.81883 .17656 L
.8201 .17879 L
.82136 .18079 L
.82263 .18278 L
.82387 .18466 L
.82514 .1865 L
.82644 .18818 L
.82771 .18985 L
.82905 .19145 L
.83039 .19303 L
.8317 .19457 L
.83308 .19619 L
.83449 .19798 L
.83592 .19981 L
.8375 .20194 L
.83922 .20411 L
.84081 .2066 L
.84256 .20898 L
.8443 .21164 L
.84609 .21425 L
.84792 .21689 L
.84954 .21937 L
.85111 .22168 L
.85248 .22379 L
.85364 .22535 L
Mistroke
.85451 .22663 L
.85516 .2276 L
.85557 .22825 L
.8557 .22855 L
.8556 .22852 L
.85533 .22823 L
.85492 .22775 L
.85442 .22716 L
.8539 .22655 L
.85338 .22594 L
.85289 .22538 L
.85249 .22496 L
.85219 .22467 L
.852 .22448 L
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
.8518 .2244 L
.85206 .22475 L
.85247 .22526 L
.85305 .22596 L
.8538 .22684 L
.85467 .22788 L
.85571 .22917 L
.85693 .23063 L
.85824 .23236 L
.85977 .23429 L
.86154 .23655 L
.86315 .23888 L
.86487 .24155 L
.86681 .24426 L
.86891 .24721 L
.87071 .25019 L
.87266 .25337 L
.8746 .25667 L
.87647 .25971 L
.8783 .2629 L
.88015 .26622 L
.88189 .26916 L
.8835 .27198 L
.88513 .27497 L
.88668 .27778 L
.88814 .28035 L
.88958 .28294 L
Mistroke
.89089 .28552 L
.89216 .28784 L
.89342 .29021 L
.89455 .29226 L
.89563 .29432 L
.89663 .29603 L
.89753 .29764 L
.89835 .29907 L
.89901 .3002 L
.89954 .3011 L
.89994 .30176 L
.90019 .30219 L
.90031 .30241 L
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
Mistroke
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
.89967 .30148 L
.89971 .30188 L
.89986 .30248 L
.90011 .30327 L
.9005 .30425 L
.901 .30543 L
Mistroke
.90161 .30667 L
.9023 .30815 L
.90301 .30987 L
.90382 .31174 L
.90459 .31371 L
.90536 .31588 L
.9061 .31802 L
.90678 .32055 L
.90735 .3225 L
.90782 .32486 L
.9082 .32728 L
.90851 .32942 L
.90876 .33159 L
.90898 .3339 L
.90918 .33618 L
.90941 .33834 L
.90962 .34036 L
.90981 .34222 L
.90993 .34377 L
.91 .345 L
.91005 .34605 L
.91008 .34692 L
.91008 .34761 L
.91007 .34811 L
.91006 .34847 L
.91004 .34869 L
.91002 .34885 L
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
.91079 .34958 L
.91068 .34937 L
.9105 .34902 L
.91028 .34851 L
.91007 .34786 L
.90987 .34712 L
.90968 .34635 L
.90949 .34562 L
.9093 .345 L
.90911 .34453 L
.9089 .34427 L
.90868 .34425 L
.90843 .34449 L
.90815 .345 L
Mistroke
.90784 .34578 L
.90751 .34677 L
.90718 .3478 L
.90684 .34891 L
.9065 .35002 L
.90621 .35107 L
.90599 .35188 L
.90586 .35246 L
.90585 .35276 L
.90597 .35281 L
.90621 .35264 L
.90654 .35228 L
.90691 .35176 L
.9073 .3511 L
.90767 .35035 L
.90798 .34955 L
.90821 .3488 L
.90836 .34807 L
.90845 .3474 L
.90848 .34679 L
.90845 .34621 L
.90837 .34564 L
.90826 .34511 L
.90816 .34457 L
.90807 .34401 L
.90802 .34339 L
.90804 .34274 L
.90812 .34204 L
.90828 .3413 L
.90852 .34051 L
.90881 .33964 L
.90911 .33868 L
.90942 .33764 L
.90971 .33658 L
.90996 .33542 L
.91015 .33426 L
.91029 .33308 L
.91036 .3319 L
.91036 .33076 L
.91031 .32962 L
.91019 .32853 L
.91002 .32744 L
.90981 .32637 L
.90956 .32537 L
.90931 .32447 L
.90906 .32369 L
.90884 .32295 L
.90865 .32223 L
.90848 .32151 L
.90833 .32077 L
Mistroke
.9082 .32001 L
.90808 .31922 L
.90796 .31839 L
.90784 .31757 L
.90772 .31679 L
.90758 .31606 L
.90743 .31542 L
.90725 .31479 L
.90704 .31421 L
.90683 .31367 L
.90663 .31321 L
.90642 .3128 L
.90624 .31246 L
.90608 .31222 L
.90595 .31206 L
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
Mistroke
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
.90599 .31404 L
.90598 .31389 L
.90598 .31373 L
.90597 .31359 L
.90597 .31343 L
.90596 .31325 L
.90598 .31304 L
.90603 .31281 L
.90608 .31254 L
.90613 .31224 L
.90615 .31188 L
.90615 .31147 L
.90608 .311 L
.90592 .31043 L
.90564 .30975 L
.90524 .30896 L
.90474 .30811 L
.90415 .3072 L
.9035 .30627 L
.90289 .30542 L
.90222 .30462 L
.90151 .3039 L
.90073 .30327 L
.9001 .30276 L
.89954 .30236 L
.89905 .30205 L
.89866 .30187 L
.89847 .3018 L
.89848 .30184 L
.89861 .30206 L
.89884 .30231 L
.8991 .30254 L
.89931 .30274 L
.89943 .30292 L
.89943 .30311 L
.8993 .30332 L
.89903 .30357 L
.89858 .3039 L
.89795 .30429 L
.89717 .30474 L
.89638 .30525 L
.89554 .30576 L
.89464 .30625 L
.89372 .30667 L
Mistroke
.89291 .30703 L
.8925 .30728 L
.89224 .30737 L
.89221 .30731 L
.8924 .30712 L
.89273 .3068 L
.89313 .30643 L
.89367 .30604 L
.89439 .30573 L
.89503 .30555 L
.89571 .3056 L
.89643 .30593 L
.89706 .30659 L
.89763 .30759 L
.8982 .30887 L
.89881 .31045 L
.89948 .31243 L
.90021 .31473 L
.90097 .31725 L
.90189 .31999 L
.90294 .3227 L
.90395 .32564 L
.90517 .32869 L
.90647 .33192 L
.9077 .33535 L
.90902 .33876 L
.9103 .34242 L
.9115 .34636 L
.91257 .34999 L
.91354 .35378 L
.9144 .35802 L
.91517 .36144 L
.91589 .36549 L
.91653 .36902 L
.91714 .37285 L
.9177 .37674 L
.9182 .38039 L
.91864 .38415 L
.91901 .38805 L
.91933 .39178 L
.91962 .39544 L
.91988 .3993 L
.92012 .40302 L
.92033 .40693 L
.92052 .41056 L
.92071 .41421 L
.92088 .41765 L
.92105 .42099 L
.92122 .42426 L
.92141 .42729 L
Mistroke
.92163 .43041 L
.92187 .43319 L
.92214 .4359 L
.92243 .43866 L
.92271 .44108 L
.92298 .44347 L
.92324 .44559 L
.92348 .44739 L
.92368 .44893 L
.92384 .45003 L
.92395 .45079 L
.92401 .45119 L
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
.92083 .44535 L
.9209 .4452 L
.92105 .44508 L
.92123 .44504 L
.92139 .44512 L
.92151 .44541 L
.92155 .44597 L
.92145 .44683 L
.92122 .448 L
.92087 .44953 L
Mistroke
.92045 .45121 L
.91996 .45322 L
.91941 .45552 L
.91884 .45789 L
.91832 .46022 L
.91784 .46281 L
.91743 .46585 L
.91712 .46843 L
.91694 .47107 L
.91691 .47382 L
.91702 .47667 L
.9173 .47923 L
.91769 .48205 L
.91815 .48482 L
.9187 .48774 L
.91929 .49088 L
.9199 .49384 L
.92054 .49694 L
.92119 .49974 L
.92183 .50242 L
.92249 .50482 L
.92311 .50683 L
.92373 .50853 L
.92432 .51001 L
.9249 .51133 L
.92546 .51245 L
.92601 .51355 L
.92658 .51469 L
.92716 .51583 L
.92775 .51719 L
.92836 .51881 L
.92899 .52058 L
.92962 .52279 L
.93024 .52526 L
.93081 .52817 L
.9313 .53113 L
.93168 .53453 L
.93196 .53753 L
.93211 .5407 L
.93215 .54386 L
.93209 .54678 L
.93193 .54963 L
.93171 .55209 L
.93146 .55436 L
.9312 .55628 L
.93093 .55798 L
.93069 .55938 L
.9305 .56045 L
.93037 .56124 L
.9303 .56176 L
Mistroke
.9303 .56203 L
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
.93141 .56043 L
.93121 .56074 L
.93093 .56128 L
.93058 .5621 L
.93015 .56321 L
.92965 .56464 L
.92909 .56627 L
.92845 .56815 L
.92773 .57031 L
.92693 .57259 L
.92607 .57519 L
.92524 .57772 L
.92438 .58051 L
.92362 .58335 L
.92287 .5864 L
.92223 .58928 L
.92161 .59236 L
.92101 .59535 L
.92042 .59841 L
.91983 .60138 L
.91923 .60431 L
.91861 .60715 L
.91803 .60974 L
.91746 .61212 L
.91694 .61425 L
.91648 .61606 L
.91608 .61766 L
.91573 .61886 L
.91544 .61978 L
.91524 .62043 L
.91514 .62081 L
.91516 .62094 L
.91527 .62087 L
.91547 .62067 L
.91571 .62042 L
.91597 .62021 L
.9162 .6201 L
.91638 .62013 L
.91644 .62031 L
.91636 .62067 L
.91612 .62121 L
Mistroke
.91567 .62194 L
.91503 .62288 L
.91422 .62402 L
.91328 .62533 L
.91215 .62684 L
.9108 .62849 L
.90954 .63015 L
.90812 .63184 L
.90667 .63357 L
.90556 .63524 L
.90426 .63714 L
.90325 .63887 L
.90234 .64068 L
.90152 .6426 L
.90084 .64465 L
.90036 .64683 L
.90005 .64891 L
.89986 .65121 L
.89972 .65378 L
.89958 .6563 L
.89944 .65912 L
.89926 .66214 L
.89895 .66521 L
.89854 .66856 L
.89805 .67156 L
.89759 .67446 L
.89714 .67711 L
.89672 .67944 L
.89635 .68152 L
.89603 .6832 L
.89578 .68463 L
.8956 .68578 L
.89548 .68661 L
.89542 .68711 L
.8954 .68734 L
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
.89542 .68653 L
.89515 .68679 L
.89483 .68709 L
.89451 .68741 L
.89421 .68774 L
.89395 .68805 L
.89371 .68835 L
Mistroke
.89349 .68867 L
.89329 .68905 L
.8931 .68952 L
.89295 .69011 L
.89285 .69084 L
.8928 .69176 L
.89275 .69298 L
.89267 .69459 L
.89251 .69652 L
.89222 .69888 L
.89177 .70178 L
.89112 .70498 L
.89027 .70847 L
.88923 .71261 L
.8881 .71663 L
.88687 .72084 L
.8856 .72542 L
.8843 .72946 L
.88295 .73409 L
.88157 .7381 L
.88015 .74245 L
.87874 .74658 L
.87731 .75081 L
.8759 .75486 L
.87453 .75907 L
.87325 .76258 L
.87202 .76618 L
.87086 .76967 L
.86974 .77273 L
.86868 .77583 L
.86768 .77844 L
.86672 .78094 L
.86579 .7833 L
.86496 .78527 L
.86416 .78708 L
.86344 .78861 L
.86285 .78981 L
.86241 .79066 L
.86204 .7914 L
.8617 .79203 L
.86134 .79265 L
.86105 .79316 L
.86074 .79366 L
.86046 .79413 L
.86026 .79451 L
.86012 .79482 L
.86002 .79504 L
.85993 .79518 L
.8598 .79528 L
.85962 .79544 L
Mistroke
.85931 .79569 L
.85889 .79603 L
.85841 .79643 L
.8579 .79685 L
.8574 .79722 L
.85697 .79751 L
.85662 .7977 L
.85636 .7978 L
.85619 .79785 L
.85603 .79789 L
.85593 .79794 L
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
.85437 .79941 L
.8541 .79961 L
.85373 .79993 L
.85324 .80039 L
.85262 .80097 L
.85187 .80169 L
.85099 .80255 L
.85003 .80351 L
.849 .80455 L
.848 .80559 L
.8469 .80647 L
.84567 .8077 L
Mistroke
.84438 .80899 L
.84309 .81021 L
.84189 .81126 L
.8408 .81211 L
.83987 .81278 L
.83905 .81331 L
.83832 .81375 L
.83764 .81412 L
.83703 .81444 L
.83641 .81477 L
.83587 .81504 L
.83546 .81522 L
.8352 .81526 L
.83509 .81517 L
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
.83583 .81428 L
.83577 .81451 L
.83565 .81484 L
.83544 .8153 L
.83513 .81586 L
.83474 .81646 L
.83435 .81689 L
.83395 .81724 L
.83353 .81751 L
.83303 .81776 L
.83259 .81797 L
.83209 .81819 L
.83161 .81841 L
.83112 .81861 L
.83063 .81884 L
.83014 .81909 L
.82967 .81936 L
.82917 .81967 L
.82856 .82007 L
.82794 .82058 L
.82731 .8212 L
.82651 .822 L
.82566 .82294 L
.82476 .82394 L
.82394 .82487 L
.82305 .82575 L
.82217 .82655 L
Mistroke
.82136 .82725 L
.82055 .82789 L
.81995 .82848 L
.8194 .82903 L
.819 .82948 L
.81878 .8298 L
.81872 .82997 L
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
.81963 .82919 L
.81952 .82892 L
.81933 .82861 L
.81907 .82826 L
.81874 .82789 L
.81836 .82751 L
.81801 .82715 L
.81773 .82678 L
.81755 .82642 L
.81752 .82608 L
.81764 .82577 L
.81787 .82552 L
.81818 .82533 L
.81856 .8252 L
.81902 .82514 L
.81952 .82515 L
.82005 .82519 L
.82059 .8252 L
.82115 .82516 L
.82172 .82501 L
.8223 .82476 L
.82291 .82439 L
.82352 .8239 L
.82416 .82325 L
.82492 .82243 L
.82588 .82142 L
.82705 .82025 L
.82852 .81895 L
.83023 .8175 L
.83218 .81592 L
.83442 .81426 L
.83674 .81254 L
.83926 .81076 L
.84192 .80896 L
.84449 .80712 L
.84703 .80535 L
Mistroke
.84965 .80356 L
.85191 .80177 L
.85418 .80012 L
.85622 .79847 L
.85806 .79687 L
.85969 .79526 L
.86114 .79372 L
.86228 .79223 L
.86327 .79077 L
.86411 .78941 L
.86478 .78815 L
.86533 .78697 L
.86575 .78586 L
.86605 .78486 L
.86624 .78385 L
.86634 .78292 L
.86635 .78193 L
.86627 .78105 L
.86613 .78016 L
.86597 .77932 L
.86579 .77854 L
.86562 .77788 L
.86546 .7773 L
.86533 .77683 L
.86523 .77644 L
.86519 .77615 L
.86519 .77598 L
.86524 .77593 L
.86535 .77602 L
.86554 .77619 L
.86579 .77644 L
.86612 .77669 L
.86657 .77685 L
.867 .77687 L
.86753 .77666 L
.86814 .77615 L
.86883 .77528 L
.86963 .77402 L
.8705 .77239 L
.8715 .77032 L
.87255 .76784 L
.87371 .76473 L
.87487 .76187 L
.87611 .75815 L
.8773 .75491 L
.87855 .75096 L
.87983 .74688 L
.88105 .74316 L
.88231 .73938 L
.8835 .73559 L
Mistroke
.88465 .73191 L
.88573 .72837 L
.88673 .72506 L
.88757 .72201 L
.88832 .71933 L
.88899 .71676 L
.88953 .71471 L
.88998 .71287 L
.89032 .71131 L
.89057 .71013 L
.89074 .70927 L
.89085 .70871 L
.89089 .70838 L
.89087 .70824 L
.8908 .70822 L
.89066 .70825 L
.89046 .70824 L
.89018 .70813 L
.88982 .7079 L
.88938 .70753 L
.88887 .70706 L
.88828 .70649 L
.8877 .70588 L
.88709 .70525 L
.88648 .70466 L
.8859 .70412 L
.88542 .70367 L
.88506 .7033 L
.88484 .70304 L
.88478 .70287 L
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
Mistroke
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
.88236 .70926 L
.88242 .70908 L
.88257 .70876 L
.8828 .70828 L
.88307 .70767 L
.88343 .7069 L
.88388 .70597 L
.88438 .70484 L
.885 .70346 L
.8857 .70182 L
.88649 .6999 L
.8874 .69781 L
.88837 .69538 L
.88944 .69276 L
.8905 .68991 L
.89158 .68674 L
.89268 .68371 L
.89372 .68038 L
.89479 .67707 L
.89578 .67363 L
.89684 .67025 L
.8978 .66675 L
.89892 .66323 L
.89997 .65976 L
.90113 .65614 L
.90243 .65252 L
.90366 .64886 L
.90496 .64507 L
.90646 .64134 L
.90765 .63756 L
.90917 .63368 L
.91063 .62977 L
.91198 .62593 L
.9135 .62196 L
Mistroke
.91497 .61798 L
.91631 .61402 L
.91757 .61014 L
.91874 .60634 L
.91974 .60253 L
.92073 .59875 L
.92165 .59506 L
.92252 .59134 L
.92346 .58749 L
.92438 .58402 L
.92537 .58032 L
.9263 .57664 L
.92723 .57272 L
.92804 .56919 L
.9288 .56542 L
.92944 .56144 L
.92995 .55776 L
.93037 .55379 L
.93069 .5498 L
.93092 .54546 L
.93103 .54157 L
.93104 .5373 L
.93094 .53288 L
.93076 .52856 L
.93053 .52417 L
.93028 .51978 L
.93003 .51521 L
.92979 .51104 L
.92957 .50655 L
.92937 .50205 L
.92916 .49767 L
.92891 .49345 L
.92862 .48895 L
.9283 .48449 L
.92795 .47991 L
.92759 .47562 L
.92724 .47162 L
.9269 .46781 L
.92658 .46399 L
.92627 .46065 L
.92598 .45747 L
.92566 .45408 L
.92535 .45148 L
.92503 .44905 L
.92471 .44671 L
.92438 .44446 L
.92405 .44232 L
.92371 .44037 L
.92335 .43836 L
.92297 .43618 L
Mistroke
.9226 .43384 L
.92223 .43135 L
.92188 .4286 L
.92155 .42567 L
.92125 .42253 L
.92099 .41919 L
.92078 .41569 L
.9206 .4123 L
.92041 .40862 L
.92019 .40483 L
.91992 .40103 L
.91957 .39691 L
.91916 .39279 L
.91868 .38851 L
.91811 .3838 L
.91749 .37957 L
.91681 .37503 L
.91611 .37042 L
.9154 .36583 L
.91469 .36124 L
.914 .35683 L
.91334 .35265 L
.91271 .34864 L
.91211 .34488 L
.91155 .34142 L
.91102 .33832 L
.91054 .33556 L
.9101 .33322 L
.90971 .3312 L
.90937 .32955 L
.90909 .3282 L
.90884 .32715 L
.90864 .32635 L
.90848 .32572 L
.90836 .32521 L
.90829 .32473 L
.90825 .32426 L
.90822 .32377 L
.90821 .32326 L
.9082 .32262 L
.90819 .32183 L
.90816 .32087 L
.90808 .31977 L
.90793 .31851 L
.90768 .31704 L
.90733 .31545 L
.90688 .31365 L
.90632 .31172 L
.90565 .30963 L
.90487 .30753 L
Mistroke
.90399 .30528 L
.90297 .3029 L
.90182 .30036 L
.90043 .29758 L
.89902 .29481 L
.89741 .29175 L
.89565 .28849 L
.89375 .28507 L
.89163 .28156 L
.88962 .27792 L
.88745 .27435 L
.88504 .27063 L
.88294 .26712 L
.88062 .26341 L
.87813 .25957 L
.87581 .25592 L
.87339 .2522 L
.87101 .24853 L
.86849 .24499 L
.86629 .24171 L
.86402 .23833 L
.86184 .2351 L
.85951 .23176 L
.85736 .22866 L
.85514 .22543 L
.85295 .22217 L
.8508 .21895 L
.84871 .21584 L
.8467 .21267 L
.84462 .20944 L
.84267 .20656 L
.84061 .20332 L
.83847 .20003 L
.83642 .19699 L
.83422 .194 L
.83188 .19062 L
.82975 .18749 L
.82742 .1843 L
.82513 .18109 L
.82279 .17797 L
.82039 .17474 L
.81814 .17172 L
.81586 .16864 L
.81365 .16557 L
.81149 .16266 L
.80948 .15978 L
.80751 .15706 L
.80555 .15425 L
.80366 .15173 L
.80169 .14907 L
Mistroke
.79972 .1465 L
.79777 .14387 L
.79578 .14132 L
.79385 .13882 L
.79195 .13633 L
.79017 .13422 L
.78852 .13228 L
.787 .13048 L
.78567 .12885 L
.78459 .12758 L
.78373 .12653 L
.78313 .12573 L
.78279 .1252 L
.78268 .1249 L
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
Mistroke
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
.78498 .12519 L
.78479 .12517 L
.78451 .12515 L
.78411 .12516 L
.78358 .12522 L
.78292 .12534 L
.78212 .12555 L
.78121 .12585 L
.78022 .12623 L
.77917 .12671 L
.77812 .12726 L
.77717 .12787 L
.77623 .12853 L
.77543 .1292 L
.77476 .12986 L
.77422 .13042 L
.77381 .13087 L
.77354 .13113 L
.77341 .1312 L
.77338 .13105 L
.77343 .13067 L
.7735 .13009 L
.77353 .12932 L
.7734 .12832 L
.77305 .12708 L
.77246 .12573 L
.77161 .12414 L
.77054 .1224 L
.76922 .12062 L
.76764 .11865 L
.76591 .11687 L
.76406 .11503 L
.76205 .11325 L
.76001 .11162 L
.75752 .1099 L
.75539 .10851 L
.75322 .10716 L
.75084 .10583 L
Mistroke
.74828 .10455 L
.74552 .10329 L
.74241 .10199 L
.73956 .10063 L
.73628 .09934 L
.73284 .09788 L
.72919 .09629 L
.72534 .09477 L
.72125 .09303 L
.71657 .09115 L
.71253 .0892 L
.70763 .08704 L
.70333 .08521 L
.6996 .08335 L
.69515 .08142 L
.69123 .0797 L
.68712 .07795 L
.68341 .0765 L
.67955 .07491 L
.67612 .07358 L
.67254 .07228 L
.66967 .07101 L
.66683 .06983 L
.66404 .06875 L
.6619 .06779 L
.65999 .06697 L
.65838 .06633 L
.65716 .06581 L
.65623 .06539 L
.65558 .06505 L
.65518 .06476 L
.65501 .06455 L
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
Mistroke
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
.65572 .06477 L
.65532 .06459 L
.65476 .06433 L
.65406 .06399 L
.65321 .06358 L
.65223 .06314 L
.65124 .06267 L
.6501 .0622 L
.64899 .06174 L
.64785 .06128 L
.64673 .06085 L
.64572 .06047 L
.6449 .06016 L
.64429 .05995 L
.64386 .05982 L
.64359 .05978 L
.64339 .05979 L
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
Mistroke
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
Mistroke
.63692 .05734 L
.63684 .05739 L
.6367 .05755 L
.63649 .05785 L
.63621 .05828 L
.63584 .0588 L
.63539 .0594 L
.63485 .06009 L
.63428 .06077 L
.63368 .0615 L
.63311 .06212 L
.6326 .06264 L
.63219 .06304 L
.6319 .06332 L
.63175 .06345 L
.63174 .06346 L
.63183 .06335 L
.63198 .06315 L
.63213 .0629 L
.63234 .06264 L
.63259 .06244 L
.63292 .06234 L
.63336 .06237 L
.63398 .06264 L
.63482 .0629 L
.63588 .06327 L
.63717 .06378 L
.63863 .06441 L
.64037 .0651 L
.64224 .0658 L
.64419 .06648 L
.64648 .06712 L
.64877 .06768 L
.65142 .06817 L
.65379 .06863 L
.65625 .0691 L
.65864 .06957 L
.66092 .07005 L
.66303 .07054 L
.665 .07105 L
.66682 .07157 L
.66854 .07212 L
.6701 .0727 L
.67152 .0733 L
.67283 .07387 L
.67399 .07439 L
.67496 .07485 L
.67574 .07526 L
.67632 .07559 L
.67672 .07584 L
Mistroke
.67697 .07601 L
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
.67668 .07597 L
.67685 .07627 L
.67707 .07666 L
.67733 .07707 L
.67762 .07747 L
.67791 .07782 L
.67822 .07812 L
.67854 .07836 L
.67888 .07854 L
.67918 .07865 L
.67943 .07868 L
.67959 .0786 L
.67965 .0784 L
.67959 .07806 L
.67942 .07758 L
.67911 .077 L
.67865 .07634 L
.67799 .07566 L
.67711 .07496 L
.67598 .07423 L
.67457 .07346 L
.67294 .07265 L
.67098 .07173 L
.66864 .0707 L
.6663 .06958 L
.66339 .06832 L
.66041 .0669 L
.65722 .06555 L
.6533 .06383 L
.64998 .06238 L
.64613 .06087 L
.64215 .05919 L
.63772 .05739 L
.63365 .0558 L
.62937 .05425 L
.62459 .05238 L
.62057 .05088 L
.61573 .04936 L
Mistroke
.61158 .04774 L
.6065 .04618 L
.60254 .04458 L
.59804 .04301 L
.59401 .04179 L
.59 .04058 L
.5864 .03946 L
.58317 .03859 L
.58025 .0378 L
.57763 .03713 L
.57526 .03659 L
.57365 .03623 L
.57224 .03602 L
.57115 .03591 L
.57035 .03591 L
.56984 .03597 L
.56957 .03605 L
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
.57246 .03635 L
.57223 .03635 L
Mistroke
.57191 .03634 L
.57148 .03632 L
.57095 .0363 L
.57031 .03628 L
.56958 .03626 L
.56877 .03623 L
.56788 .0362 L
.56689 .03617 L
.56581 .03613 L
.56465 .03609 L
.56346 .03605 L
.56222 .036 L
.56096 .03596 L
.55969 .03592 L
.55849 .03588 L
.55728 .03584 L
.55605 .0358 L
.55472 .03576 L
.55344 .03572 L
.55209 .03567 L
.55065 .03563 L
.54914 .03558 L
.54757 .03553 L
.54604 .03548 L
.54482 .03543 L
.54358 .03539 L
.54242 .03536 L
.54154 .03533 L
.5407 .03533 L
.53992 .03534 L
.53921 .03535 L
.53856 .03533 L
.53787 .03528 L
.53704 .03517 L
.53597 .03503 L
.53457 .03485 L
.53286 .03466 L
.53052 .03445 L
.52755 .03425 L
.52476 .03406 L
.52105 .03386 L
.51654 .0337 L
.51267 .03355 L
.50794 .03343 L
.5033 .03333 L
.4993 .03327 L
.49487 .03325 L
.49121 .03327 L
.48752 .03331 L
.4847 .03336 L
Mistroke
.48218 .03341 L
.4801 .03344 L
.47858 .03344 L
.47734 .0334 L
.47639 .03334 L
.47572 .03329 L
.4752 .03325 L
.47473 .03322 L
.47427 .0332 L
.4738 .03319 L
.4733 .03318 L
.47276 .03316 L
.47221 .03314 L
.47164 .03312 L
.47103 .0331 L
.47042 .03308 L
.46989 .03307 L
.46947 .03306 L
.46917 .03305 L
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
.46966 .03306 L
.46939 .03305 L
.4689 .03304 L
.46815 .03302 L
.46712 .03299 L
.46584 .03295 L
.46431 .0329 L
.46253 .03285 L
.46054 .03279 L
.45868 .03272 L
.45662 .03266 L
.45473 .0326 L
.45288 .03254 L
.45115 .03249 L
.44977 .03244 L
.44865 .03238 L
.44779 .03231 L
.4472 .03222 L
Mistroke
.44682 .03214 L
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
.44046 .03656 L
.44008 .03649 L
.43947 .03641 L
.43857 .03632 L
.43733 .03622 L
.43574 .03612 L
.43377 .03602 L
.43133 .03593 L
.42862 .03582 L
.4254 .03573 L
.42215 .03563 L
.41865 .03551 L
.41497 .03538 L
.41097 .03525 L
.4075 .03512 L
.40366 .03502 L
.40003 .03496 L
.3964 .03494 L
.39311 .03499 L
.38963 .03512 L
.38645 .03534 L
.3832 .03567 L
.38012 .03614 L
.37691 .03676 L
.37412 .03746 L
.37144 .03824 L
.36879 .03907 L
Mistroke
.36651 .03996 L
.36426 .04087 L
.36238 .04181 L
.36063 .04275 L
.35914 .04363 L
.35786 .04447 L
.35679 .04527 L
.35593 .046 L
.35529 .04667 L
.35481 .04727 L
.35445 .04778 L
.35416 .04824 L
.35393 .04862 L
.35371 .04895 L
.3535 .04921 L
.35334 .04942 L
.35324 .04958 L
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
.354 .04888 L
.35369 .04881 L
.35315 .04884 L
Mistroke
.35232 .04902 L
.35115 .04942 L
.34964 .05007 L
.3477 .05101 L
.34527 .05223 L
.34269 .05361 L
.33959 .05519 L
.3363 .05708 L
.33265 .05912 L
.32896 .06132 L
.32485 .06377 L
.3211 .06601 L
.31713 .06847 L
.31302 .07078 L
.30937 .07299 L
.30547 .07529 L
.30211 .07726 L
.29864 .07928 L
.29567 .08109 L
.29277 .08291 L
.29025 .08456 L
.28803 .08611 L
.28616 .08746 L
.28458 .08868 L
.28336 .08971 L
.28245 .09049 L
.28177 .09112 L
.28127 .09163 L
.28087 .09207 L
.28049 .09246 L
.28007 .09287 L
.2796 .0933 L
.27909 .09379 L
.27851 .09432 L
.27787 .09488 L
.27725 .09542 L
.27662 .09604 L
.27609 .09662 L
.27563 .09719 L
.27524 .09772 L
.27492 .09816 L
.27468 .09848 L
.27446 .09864 L
.27415 .0987 L
.27367 .09873 L
.27293 .09876 L
.27185 .09889 L
.27033 .09922 L
.26834 .09983 L
.2663 .10078 L
Mistroke
.26346 .10196 L
.26065 .10344 L
.2572 .1053 L
.25351 .10746 L
.24949 .10981 L
.24575 .11216 L
.24106 .1148 L
.23718 .11756 L
.2324 .1206 L
.22875 .12339 L
.22455 .12638 L
.22062 .1293 L
.21651 .13231 L
.21297 .13501 L
.20922 .13773 L
.20633 .14018 L
.20353 .14255 L
.20112 .14463 L
.1991 .14645 L
.19746 .14808 L
.19625 .14936 L
.19535 .15037 L
.19474 .15111 L
.19436 .15159 L
.19418 .15185 L
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
.19471 .15121 L
.19443 .15165 L
.19406 .15228 L
.19363 .15307 L
.19315 .15401 L
Mistroke
.19265 .15507 L
.19215 .15611 L
.19166 .15722 L
.19118 .15834 L
.19073 .15945 L
.19034 .16043 L
.19002 .1613 L
.1898 .16202 L
.18969 .16254 L
.18969 .16283 L
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
.19037 .16208 L
.19013 .1624 L
.18972 .163 L
.18908 .16393 L
.18817 .16523 L
.18696 .16696 L
.18559 .16886 L
.1839 .17132 L
.182 .17398 L
.17981 .17718 L
.17758 .18036 L
.17527 .1839 L
.17277 .18781 L
.17036 .1914 L
.16782 .19534 L
.16535 .19956 L
.16295 .20341 L
.16052 .2075 L
.15802 .2119 L
.15562 .21601 L
.15325 .22006 L
.15074 .22467 L
.14837 .22852 L
.14581 .233 L
.14335 .2369 L
.1408 .24113 L
.13817 .24544 L
.13566 .24941 L
.13314 .2534 L
.13068 .25729 L
.12822 .26124 L
.12592 .26485 L
.12363 .26855 L
.12132 .27246 L
Mistroke
.11904 .27624 L
.11688 .27975 L
.11461 .2837 L
.11236 .28755 L
.11015 .29105 L
.10791 .29492 L
.10592 .2984 L
.10397 .30193 L
.10217 .30535 L
.10057 .30841 L
.09909 .31131 L
.09791 .31373 L
.09692 .31593 L
.09611 .3178 L
.09552 .31925 L
.09513 .32038 L
.09495 .32117 L
.09493 .32164 L
.09503 .32184 L
.09518 .32181 L
.09535 .32164 L
.09549 .32138 L
.09557 .32112 L
.09557 .32091 L
.09548 .32084 L
.09532 .32098 L
.09508 .32138 L
.09478 .32211 L
.09438 .32326 L
.09389 .32488 L
.0933 .32698 L
.09261 .32974 L
.09183 .3328 L
.091 .33662 L
.09014 .34117 L
.08926 .34566 L
.08842 .35113 L
.08762 .35606 L
.08689 .36169 L
.08625 .36762 L
.08569 .37342 L
.08521 .37823 L
.08483 .38335 L
.08453 .38859 L
.08433 .39282 L
.08422 .39615 L
.08416 .39929 L
.08415 .40209 L
.08417 .40407 L
.0842 .4056 L
Mistroke
.08423 .40667 L
.08425 .40734 L
.08426 .40768 L
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
.08422 .41159 L
.08438 .41176 L
.08458 .41195 L
.08483 .41213 L
.08513 .41228 L
.08548 .41241 L
.08589 .41253 L
.08638 .41265 L
Mistroke
.08698 .41281 L
.08769 .41301 L
.08848 .41327 L
.08934 .41361 L
.09027 .41406 L
.09123 .41463 L
.09212 .41537 L
.09304 .41627 L
.0939 .41729 L
.09478 .41851 L
.09551 .41996 L
.09616 .42158 L
.09669 .42341 L
.09709 .42547 L
.09732 .42781 L
.09738 .43036 L
.09727 .43317 L
.09701 .43617 L
.09659 .43946 L
.09603 .44253 L
.09532 .44586 L
.09445 .44943 L
.09335 .45287 L
.092 .45647 L
.09051 .46027 L
.08874 .46404 L
.08675 .46757 L
.08434 .47139 L
.08251 .47519 L
.08008 .4793 L
.07828 .48308 L
.07594 .48713 L
.07407 .49136 L
.07243 .49569 L
.07099 .49994 L
.06969 .5043 L
.06866 .50799 L
.06793 .51165 L
.06748 .51482 L
.06726 .51758 L
.06721 .51978 L
.06725 .52145 L
.06733 .52266 L
.06743 .52348 L
.06745 .52401 L
.0674 .52433 L
.06735 .52457 L
.06735 .52489 L
.06741 .52544 L
.06753 .52631 L
Mistroke
.0677 .52755 L
.06794 .52932 L
.06824 .53177 L
.06863 .53473 L
.0691 .53839 L
.06967 .5425 L
.07035 .54705 L
.07106 .55225 L
.07183 .55708 L
.0726 .56291 L
.07331 .56802 L
.07401 .57374 L
.0747 .5799 L
.07537 .58514 L
.07608 .5915 L
.07679 .59671 L
.07753 .60276 L
.07834 .6082 L
.0792 .61357 L
.0801 .61908 L
.08099 .62433 L
.08159 .62952 L
.08248 .6353 L
.08334 .63999 L
.08422 .64523 L
.0851 .65021 L
.08591 .65472 L
.08662 .65931 L
.08718 .66295 L
.08759 .66638 L
.08789 .66968 L
.08808 .67215 L
.0882 .67436 L
.0883 .67634 L
.08841 .67798 L
.08857 .67933 L
.08877 .68044 L
.08903 .68143 L
.08933 .68241 L
.08969 .68339 L
.09008 .68452 L
.09051 .68584 L
.09097 .6874 L
.09144 .68911 L
.09187 .69097 L
.09226 .69285 L
.09259 .69466 L
.09286 .69632 L
.09306 .69774 L
.09318 .69899 L
Mistroke
.09324 .70003 L
.09324 .70085 L
.09321 .70143 L
.09316 .70178 L
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
.09321 .70088 L
.09344 .70151 L
.09375 .7025 L
.09413 .70386 L
.09458 .70556 L
.0951 .70768 L
.09571 .71018 L
.09638 .71256 L
.09708 .71564 L
.09782 .71849 L
.09856 .7216 L
.09928 .72482 L
.09995 .72775 L
.10056 .73056 L
.10111 .73293 L
.10158 .73499 L
.10197 .73663 L
.10229 .73798 L
.10254 .73906 L
.10272 .73989 L
.10282 .74053 L
.10287 .74102 L
.10289 .74136 L
.10287 .74162 L
.10283 .74185 L
.10278 .74208 L
.10274 .74234 L
.1027 .74268 L
.10267 .7431 L
.10266 .74357 L
.10265 .74401 L
.10265 .74437 L
.10264 .74468 L
.10264 .74492 L
.10264 .74509 L
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
Mistroke
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
.10247 .74294 L
.10262 .74313 L
.10287 .74344 L
.10321 .74387 L
.10368 .74441 L
.1043 .74506 L
.10509 .74585 L
.10608 .74679 L
.10724 .74791 L
.10864 .74923 L
.11017 .75064 L
.11198 .75227 L
.11392 .75419 L
.11612 .75637 L
.11846 .7589 L
.12125 .76172 L
.12417 .76481 L
.12691 .76815 L
.12995 .77172 L
.13309 .77529 L
.13626 .77909 L
.1395 .78304 L
.14289 .78682 L
.14633 .79084 L
.14996 .79486 L
.1533 .79868 L
.15706 .80255 L
.16064 .80647 L
.16442 .81051 L
.16821 .8141 L
.17204 .81798 L
.17613 .82183 L
.18001 .82589 L
.18408 .82982 L
Mistroke
.18814 .83384 L
.19236 .83795 L
.19642 .84192 L
.20051 .84582 L
.20478 .84976 L
.2088 .85366 L
.21297 .85729 L
.21701 .86104 L
.22109 .8649 L
.22497 .86829 L
.22888 .87194 L
.23236 .87509 L
.2357 .87803 L
.23855 .88073 L
.24118 .88313 L
.24338 .88526 L
.24512 .88715 L
.24647 .88853 L
.24739 .8896 L
.24791 .89036 L
.2481 .89081 L
.24802 .89097 L
.24775 .89083 L
.24735 .89055 L
.24696 .89022 L
.24668 .88994 L
.24659 .88979 L
.24677 .88983 L
.24725 .8901 L
.24804 .89057 L
.24914 .89131 L
.25057 .89221 L
.25232 .89327 L
.25419 .89441 L
.25649 .89569 L
.25898 .89714 L
.26162 .8986 L
.26462 .90022 L
.26775 .90186 L
.27116 .90357 L
.27464 .90531 L
.27862 .9069 L
.28251 .90862 L
.28619 .91029 L
.2903 .91199 L
.29485 .91374 L
.29884 .91547 L
.3036 .91719 L
.30788 .91892 L
.31246 .92056 L
Mistroke
.31702 .92218 L
.32145 .92378 L
.32583 .92536 L
.33026 .9269 L
.33471 .92847 L
.33901 .92997 L
.34341 .93151 L
.34799 .93302 L
.35218 .9346 L
.35669 .93607 L
.3612 .93771 L
.36562 .93917 L
.37015 .94067 L
.37472 .94219 L
.37928 .94376 L
.38383 .94534 L
.38824 .94683 L
.39271 .94818 L
.39712 .94957 L
.40157 .951 L
.406 .95237 L
.41005 .95371 L
.41409 .95503 L
.41824 .95639 L
.42224 .95772 L
.42609 .95899 L
.43003 .96023 L
.43382 .96141 L
.43765 .96258 L
.44139 .96361 L
.44525 .96455 L
.44895 .96536 L
.45254 .96601 L
.4561 .96653 L
.45955 .96693 L
.46266 .9672 L
.46566 .96734 L
.46827 .96735 L
.47065 .96726 L
.47275 .96708 L
.47446 .96686 L
.47588 .96665 L
.47697 .96646 L
.47774 .9663 L
.47822 .96618 L
.4785 .9661 L
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
Mistroke
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
.47597 .96608 L
.4759 .96594 L
.47585 .96579 L
.47581 .96567 L
.47581 .96558 L
.47589 .96551 L
.47617 .96544 L
.47671 .96536 L
.47757 .96527 L
.47876 .96518 L
.48039 .96509 L
.48239 .96501 L
.4849 .96496 L
.48782 .96491 L
.4911 .96482 L
.49492 .96465 L
.49912 .96435 L
.5037 .96389 L
.50854 .96325 L
.51372 .96243 L
.5191 .96147 L
.52438 .96046 L
.5301 .95941 L
.53546 .95834 L
.54136 .95728 L
.54686 .95623 L
.55274 .95518 L
Mistroke
.5582 .95417 L
.56412 .9532 L
.56989 .9523 L
.57564 .95145 L
.58143 .95066 L
.58668 .94989 L
.59227 .94911 L
.59757 .9483 L
.60304 .94742 L
.60815 .94661 L
.61344 .94568 L
.61807 .94467 L
.62294 .94368 L
.62756 .94268 L
.63235 .94168 L
.6363 .94072 L
.6402 .93983 L
.64405 .93902 L
.64765 .93828 L
.65114 .93762 L
.65468 .93699 L
.65778 .93639 L
.66071 .93577 L
.66365 .9351 L
.6665 .93433 L
.66936 .93345 L
.67199 .93244 L
.67474 .93131 L
.67757 .93006 L
.68057 .92867 L
.68376 .92707 L
.68708 .92524 L
.69067 .92333 L
.69428 .92115 L
.69824 .91882 L
.70216 .9163 L
.7061 .91381 L
.71002 .91107 L
.71401 .90846 L
.7178 .90586 L
.72179 .90298 L
.72573 .90007 L
.72959 .89751 L
.73326 .89475 L
.73699 .89202 L
.74073 .88921 L
.74445 .88644 L
.74838 .88346 L
.75192 .88079 L
.75572 .87794 L
Mistroke
.75967 .87506 L
.76346 .87216 L
.76737 .8693 L
.7713 .86638 L
.77537 .86332 L
.77909 .86047 L
.78286 .85746 L
.78667 .85456 L
.79005 .85174 L
.79354 .84897 L
.79697 .84624 L
.80046 .84354 L
.80385 .8408 L
.80736 .83809 L
.8108 .83534 L
.81423 .83253 L
.81779 .82978 L
.82121 .82696 L
.82459 .82425 L
.82794 .82159 L
.83111 .81894 L
.8342 .81641 L
.83717 .81405 L
.83978 .81178 L
.84222 .80965 L
.84433 .80769 L
.84615 .80596 L
.84769 .80445 L
.84893 .80318 L
.84995 .80215 L
.85075 .80134 L
.85142 .80071 L
.85195 .80021 L
.85237 .79981 L
.8527 .79946 L
.85294 .79914 L
.85314 .79881 L
.85325 .79846 L
.85333 .79805 L
.8534 .79757 L
.85348 .79697 L
.85359 .79627 L
.85367 .79555 L
.85371 .79488 L
.85369 .79428 L
.85363 .79379 L
.85355 .79348 L
.85345 .79336 L
.85337 .79343 L
.85333 .79366 L
Mistroke
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
.85295 .79839 L
.8533 .79833 L
.85389 .79807 L
.85452 .79766 L
.8554 .79693 L
.85646 .79586 L
.85765 .79438 L
.85911 .79246 L
.86074 .79002 L
.86257 .78714 L
.86455 .78379 L
.86664 .77986 L
.86873 .77599 L
.87084 .77154 L
.87287 .76678 L
.87479 .76219 L
.87656 .75737 L
.8782 .75268 L
.87969 .74824 L
.88099 .74412 L
.88214 .74051 L
.88312 .73704 L
.88393 .73431 L
.8846 .73169 L
.88516 .72947 L
.88564 .7274 L
.88606 .72545 L
.88643 .72362 L
.8868 .72185 L
.88724 .71996 L
.8878 .7178 L
.88849 .71533 L
.88935 .71251 L
Mistroke
.8903 .70909 L
.89144 .7054 L
.89266 .7011 L
.89399 .69669 L
.89549 .69164 L
.89694 .68691 L
.89868 .68164 L
.90036 .67572 L
.90197 .67049 L
.90378 .66468 L
.90545 .65876 L
.90721 .65249 L
.90882 .64688 L
.91043 .64093 L
.91205 .63459 L
.91341 .62926 L
.91483 .62355 L
.91628 .61783 L
.9176 .61214 L
.91898 .60648 L
.92027 .60095 L
.92151 .59586 L
.92268 .59096 L
.9238 .58634 L
.92481 .58227 L
.9257 .57866 L
.9265 .57546 L
.92716 .57271 L
.92767 .5706 L
.92805 .56901 L
.92828 .56787 L
.92839 .56718 L
.92841 .5669 L
.92835 .56694 L
.92823 .56718 L
.92808 .56752 L
.92793 .56791 L
.92779 .56827 L
.92769 .56854 L
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
.92768 .56796 L
.92766 .5678 L
Mistroke
.92765 .56762 L
.92766 .56739 L
.92771 .56705 L
.92779 .5666 L
.92791 .56603 L
.92807 .56539 L
.92826 .56468 L
.9285 .56393 L
.92876 .56316 L
.92905 .56238 L
.92936 .56161 L
.92968 .56086 L
.92998 .56014 L
.93026 .55948 L
.9305 .55888 L
.93071 .55836 L
.93087 .55799 L
.931 .55772 L
.93108 .55755 L
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
.93103 .55653 L
Mistroke
.9311 .55607 L
.93119 .55526 L
.9313 .55392 L
.93142 .55197 L
.93154 .54939 L
.93164 .54643 L
.93172 .54298 L
.93176 .53899 L
.93177 .53458 L
.93175 .52994 L
.93166 .52488 L
.9315 .52034 L
.93126 .51545 L
.93095 .51071 L
.93059 .50622 L
.93016 .50201 L
.92967 .49764 L
.92922 .49331 L
.92874 .48874 L
.92826 .48428 L
.92782 .47999 L
.92738 .47545 L
.927 .47067 L
.92666 .46666 L
.92638 .4624 L
.92613 .45846 L
.92594 .45532 L
.9258 .45227 L
.9257 .44999 L
.92562 .44807 L
.92555 .44663 L
.92546 .44568 L
.92534 .44497 L
.92516 .44425 L
.92491 .44336 L
.9246 .44216 L
.92425 .44059 L
.92386 .43845 L
.92342 .43584 L
.92297 .43266 L
.92253 .429 L
.92211 .42511 L
.92171 .42092 L
.92132 .41653 L
.92095 .41256 L
.92059 .40822 L
.92023 .40385 L
.91985 .39957 L
.91943 .39543 L
.91894 .39113 L
Mistroke
.91839 .38676 L
.9178 .38214 L
.91722 .3782 L
.91657 .37398 L
.91591 .36984 L
.91525 .36577 L
.91462 .36198 L
.91406 .3583 L
.91358 .35503 L
.91319 .35228 L
.91286 .3498 L
.91263 .34775 L
.91249 .34613 L
.91243 .34498 L
.91244 .34428 L
.91249 .34387 L
.91255 .34368 L
.91261 .34366 L
.91266 .34371 L
.91267 .34374 L
.91264 .34366 L
.91256 .34343 L
.91243 .343 L
.91226 .34235 L
.91207 .34147 L
.91185 .34035 L
.91163 .33906 L
.91139 .33757 L
.91114 .336 L
.91092 .33449 L
.9107 .33291 L
.91051 .33146 L
.91035 .33002 L
.91023 .32874 L
.91016 .32762 L
.91013 .32672 L
.91013 .32606 L
.91015 .32561 L
.91018 .3253 L
.91019 .32503 L
.91018 .32473 L
.91014 .32428 L
.91005 .32364 L
.9099 .32276 L
.90968 .32165 L
.90939 .32035 L
.90902 .31887 L
.90859 .31735 L
.90811 .31572 L
.90757 .31405 L
Mistroke
.90701 .31237 L
.90645 .3107 L
.9059 .30913 L
.90539 .30766 L
.90492 .30637 L
.90453 .30533 L
.90421 .30454 L
.90396 .304 L
.90378 .30368 L
.90366 .30353 L
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
Mistroke
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
.89591 .30151 L
.89609 .3013 L
.89632 .30095 L
.89659 .30041 L
.89681 .29963 L
.89696 .29858 L
.89695 .29722 L
.89673 .2955 L
.89631 .29358 L
.89566 .2913 L
.89472 .28869 L
.89351 .28576 L
.89202 .28266 L
.8902 .27887 L
.88834 .27559 L
.88615 .27182 L
Mistroke
.88382 .26788 L
.88147 .26375 L
.87878 .25932 L
.87638 .25527 L
.87372 .25103 L
.87084 .24635 L
.86826 .24245 L
.86549 .23818 L
.86274 .23389 L
.85979 .22991 L
.85737 .22577 L
.85479 .22212 L
.85236 .21847 L
.8499 .21506 L
.84766 .21176 L
.84546 .20852 L
.84327 .20546 L
.8411 .20236 L
.83889 .19927 L
.83666 .19611 L
.83438 .19291 L
.83197 .18941 L
.82958 .1861 L
.82701 .18252 L
.82444 .17926 L
.82153 .17544 L
.81886 .17169 L
.81617 .16786 L
.81352 .16428 L
.81069 .16038 L
.80795 .1566 L
.80518 .15285 L
.80256 .14919 L
.79999 .14574 L
.79755 .14241 L
.79539 .13934 L
.79333 .13649 L
.79146 .13388 L
.78982 .13161 L
.78841 .1297 L
.78724 .12809 L
.78635 .12689 L
.78565 .12598 L
.78514 .12535 L
.7848 .12498 L
.78461 .12481 L
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
Mistroke
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
.78487 .12528 L
.78473 .12507 L
.78458 .12482 L
.78446 .12456 L
.78435 .12428 L
.78424 .12399 L
.78407 .12367 L
.78382 .12329 L
.78348 .12286 L
.78305 .1224 L
.7825 .1219 L
.78185 .12149 L
.78112 .12107 L
.78034 .12067 L
.77955 .12028 L
.77888 .11988 L
.77812 .11947 L
.77739 .11908 L
.77662 .1187 L
.77583 .11837 L
.77507 .11816 L
.77437 .1181 L
.7737 .11816 L
.77299 .11839 L
.77219 .11874 L
.77123 .11916 L
.77005 .11963 L
.76879 .12019 L
.76728 .1208 L
.76546 .12144 L
Mistroke
.76347 .12215 L
.76143 .12289 L
.75911 .12373 L
.75679 .12465 L
.75425 .12563 L
.75199 .12667 L
.74956 .1277 L
.74708 .1288 L
.74504 .12993 L
.74297 .13111 L
.7409 .13235 L
.73896 .13357 L
.73712 .13495 L
.73542 .13624 L
.73375 .13755 L
.73225 .1388 L
.73086 .13993 L
.7296 .1409 L
.72852 .14165 L
.72769 .14214 L
.727 .1424 L
.72645 .14247 L
.72606 .1424 L
.72584 .14224 L
.7258 .142 L
.72593 .14177 L
.72624 .14153 L
.72668 .14141 L
.72725 .14145 L
.72794 .14172 L
.72872 .14231 L
.72957 .14329 L
.73053 .14456 L
.73159 .14636 L
.73282 .14836 L
.73423 .15081 L
.73565 .15344 L
.73727 .15638 L
.73899 .15916 L
.74078 .16231 L
.74268 .16522 L
.74463 .16835 L
.7466 .17146 L
.7487 .17466 L
.7508 .17797 L
.75287 .18118 L
.75505 .18458 L
.75707 .18802 L
.75915 .19152 L
.76127 .19527 L
Mistroke
.76321 .19849 L
.76515 .2018 L
.76707 .20511 L
.76876 .20786 L
.77039 .21054 L
.77182 .21286 L
.77305 .21495 L
.77406 .21652 L
.77484 .21785 L
.7754 .2187 L
.77577 .2193 L
.77601 .2196 L
.77612 .21965 L
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
.77541 .21886 L
.77552 .21916 L
.77579 .21962 L
.77624 .22027 L
.7769 .22112 L
.77778 .22211 L
.77887 .22326 L
.78015 .22456 L
.78137 .22591 L
.78295 .22728 L
.78442 .2286 L
.78594 .22975 L
.78744 .23079 L
.7888 .23162 L
.78998 .23233 L
.79104 .23298 L
.79188 .23344 L
.79264 .23388 L
.79334 .23428 L
.79403 .23469 L
.79478 .23515 L
.79566 .23571 L
.79672 .23642 L
.79794 .23727 L
.7994 .2384 L
.80114 .23973 L
.80316 .24134 L
.80549 .24318 L
.80817 .24516 L
.81094 .24736 L
.81401 .24946 L
Mistroke
.81702 .25162 L
.82028 .25389 L
.82364 .25606 L
.82685 .25806 L
.83032 .26008 L
.83374 .26199 L
.83725 .26378 L
.8408 .26531 L
.8447 .26664 L
.84788 .26776 L
.85135 .26862 L
.8549 .26929 L
.85797 .2698 L
.86101 .27017 L
.86384 .27041 L
.86644 .27055 L
.86861 .27063 L
.87061 .27065 L
.87232 .27063 L
.87377 .27058 L
.87508 .27055 L
.87625 .27056 L
.87737 .27064 L
.87846 .27083 L
.87949 .27113 L
.88055 .27151 L
.88154 .27195 L
.88257 .27244 L
.88358 .27295 L
.88457 .27349 L
.88546 .27406 L
.88625 .27465 L
.88689 .27524 L
.88739 .27586 L
.88776 .2765 L
.88802 .27716 L
.88819 .27782 L
.88831 .27849 L
.88843 .27916 L
.88857 .2798 L
.88872 .28042 L
.88887 .281 L
.88905 .2815 L
.88923 .2819 L
.88939 .2822 L
.8895 .28239 L
.88953 .28248 L
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
Mistroke
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
.88668 .28544 L
.88683 .28543 L
.88704 .28527 L
.88725 .28494 L
.88744 .28451 L
.88753 .28394 L
.88749 .28325 L
.88731 .28242 L
.88697 .2814 L
.88648 .28012 L
.88586 .27853 L
.88511 .27673 L
.88415 .27449 L
.88293 .27195 L
.88149 .26902 L
.87983 .26586 L
.87791 .26238 L
.87595 .25887 L
.87381 .25531 L
.87177 .25184 L
.86986 .24844 L
.86813 .24552 L
.86655 .24283 L
.86513 .24032 L
.86405 .23849 L
.86318 .23694 L
.86253 .23566 L
.86213 .23485 L
.86196 .23433 L
.86199 .23411 L
.86218 .23412 L
.86247 .23427 L
.8628 .2345 L
.86312 .23473 L
.86341 .23494 L
.86365 .2351 L
.86384 .23518 L
.86399 .23519 L
.86414 .23519 L
Mistroke
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
.86385 .23539 L
.86348 .23536 L
.86298 .23526 L
.86237 .23508 L
.86167 .23483 L
.86092 .2345 L
.86019 .23412 L
.85943 .2337 L
.85867 .23325 L
.85793 .23281 L
.85727 .23236 L
.85671 .23191 L
.85628 .23147 L
.85599 .23107 L
.85582 .23074 L
.85576 .23052 L
.8558 .23044 L
.85588 .2305 L
.85597 .2307 L
.85605 .23101 L
.85613 .23139 L
.8562 .23184 L
.85625 .23233 L
.85627 .23283 L
.85626 .23333 L
.85624 .23381 L
.85622 .23428 L
.85619 .23469 L
.85613 .23502 L
.85603 .2352 L
.85588 .23522 L
.85563 .23503 L
.85534 .2346 L
.8549 .23391 L
.85417 .23297 L
.85351 .23181 L
.85274 .23037 L
.85187 .22861 L
.85091 .22661 L
.84979 .22419 L
.84854 .22175 L
.84713 .21887 L
.84556 .21584 L
.84382 .21247 L
.84194 .20909 L
.83992 .2055 L
Mistroke
.83777 .20165 L
.83546 .19768 L
.83291 .19358 L
.83025 .18899 L
.82742 .18487 L
.82438 .18022 L
.82116 .17544 L
.81791 .17086 L
.81461 .16597 L
.81118 .16103 L
.80779 .15616 L
.80444 .15158 L
.80091 .14651 L
.79763 .14232 L
.79419 .13795 L
.79078 .13393 L
.78725 .13026 L
.78406 .12706 L
.78077 .12414 L
.77764 .12145 L
.77466 .11935 L
.77169 .1174 L
.76854 .11561 L
.7658 .11398 L
.76293 .11242 L
.7599 .11099 L
.75695 .10952 L
.75375 .10797 L
.75062 .10639 L
.74706 .10468 L
.74354 .10287 L
.73949 .10087 L
.73545 .0989 L
.73103 .09673 L
.7259 .09457 L
.72143 .09248 L
.71609 .09028 L
.71118 .08818 L
.70575 .08596 L
.70078 .0839 L
.69564 .08179 L
.69063 .07974 L
.68597 .07769 L
.68151 .07588 L
.6773 .07406 L
.67317 .07241 L
.66971 .07083 L
.66631 .06938 L
.66298 .06802 L
.66022 .06686 L
Mistroke
.65754 .06578 L
.65495 .06478 L
.65262 .06383 L
.65028 .06292 L
.64786 .062 L
.64552 .06108 L
.64283 .06004 L
.64019 .05891 L
.63723 .05773 L
.63396 .05646 L
.63066 .05513 L
.62697 .05374 L
.62336 .05225 L
.61938 .05071 L
.61566 .04921 L
.61178 .04768 L
.60789 .04618 L
.60399 .0447 L
.60037 .04326 L
.59674 .042 L
.59316 .04081 L
.58992 .03972 L
.58679 .0388 L
.58372 .03798 L
.58088 .03728 L
.57796 .03671 L
.57523 .03629 L
.5724 .03601 L
.56944 .03586 L
.56659 .0358 L
.56341 .0358 L
.56019 .03581 L
.55691 .03581 L
.55316 .03575 L
.54972 .03561 L
.54595 .03541 L
.54162 .03517 L
.53797 .0349 L
.53379 .03463 L
.52953 .03436 L
.52515 .03411 L
.5207 .03389 L
.51631 .03369 L
.51153 .03353 L
.50736 .03339 L
.50264 .03328 L
.49839 .0332 L
.49461 .03316 L
.49059 .03316 L
.48731 .03318 L
Mistroke
.48399 .03323 L
.48158 .03328 L
.47948 .03333 L
.47767 .03336 L
.47628 .03335 L
.47511 .03332 L
.4741 .03327 L
.4732 .03321 L
.47225 .03316 L
.4711 .03311 L
.46959 .03307 L
.46781 .03301 L
.46549 .03294 L
.46255 .03286 L
.45948 .03275 L
.45581 .03264 L
.45192 .03251 L
.44795 .03237 L
.44401 .03222 L
.4402 .03207 L
.43661 .03196 L
.43372 .03187 L
.43073 .03183 L
.4285 .03181 L
.42657 .03179 L
.425 .03177 L
.42385 .03174 L
.42311 .03173 L
.42266 .03174 L
.42244 .0318 L
.42238 .03192 L
.4224 .03209 L
.42244 .0323 L
.42241 .03255 L
.4223 .03282 L
.42214 .0331 L
.42196 .0334 L
.42177 .03371 L
.42156 .03404 L
.42128 .03437 L
.42091 .03472 L
.42039 .035 L
.41971 .0353 L
.41886 .03557 L
.41789 .0357 L
.41684 .03575 L
.41573 .03571 L
.41461 .03562 L
.41353 .0355 L
.41247 .03537 L
Mistroke
.41144 .03527 L
.41045 .03517 L
.40955 .03509 L
.40875 .03502 L
.40806 .03497 L
.40752 .03495 L
.40712 .03495 L
.40684 .03496 L
.40664 .03502 L
.40651 .0351 L
.4064 .03519 L
.4063 .03529 L
.4062 .03538 L
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
.40694 .03536 L
.40664 .03526 L
.40604 .03518 L
.40505 .03514 L
.40361 .03515 L
.40162 .03523 L
.39931 .0354 L
.39654 .03565 L
.39312 .03599 L
.3897 .03645 L
.38557 .03704 L
.38185 .03774 L
.37767 .03858 L
.37372 .03958 L
.37024 .04064 L
.36679 .0418 L
.36397 .04301 L
.36131 .04412 L
.35931 .0452 L
.35775 .04619 L
.35662 .04707 L
Mistroke
.35588 .04781 L
.35545 .04843 L
.35524 .04895 L
.35518 .04936 L
.35521 .04965 L
.35529 .04982 L
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
.35571 .04931 L
.35534 .04924 L
.35486 .04921 L
.35428 .04925 L
.35362 .04938 L
.35289 .04961 L
.35212 .04996 L
.35134 .0504 L
.35053 .05094 L
.34971 .05152 L
.34893 .05216 L
.34823 .05282 L
.34763 .05349 L
.34717 .05412 L
.34682 .05475 L
.3466 .05532 L
.34649 .0558 L
.34648 .05613 L
.34653 .05628 L
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
Mistroke
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
.34666 .05386 L
.34629 .05392 L
.34581 .05407 L
.34514 .05437 L
.34428 .05481 L
.34321 .05535 L
.34193 .05598 L
.34047 .05667 L
.33893 .0574 L
.33721 .05817 L
.33532 .05897 L
.33346 .05979 L
.33153 .06063 L
.32957 .06148 L
.32776 .06229 L
.32602 .06313 L
.32435 .06394 L
.32283 .06469 L
.32143 .06541 L
.32029 .06611 L
.31934 .06678 L
.3186 .06747 L
.31807 .06805 L
.31774 .0686 L
.31759 .06907 L
.31759 .06941 L
.31767 .06974 L
.31781 .07004 L
.31798 .07032 L
.31816 .07056 L
.31833 .07075 L
.31848 .07088 L
.3186 .07096 L
.3187 .07095 L
Mistroke
.31879 .07085 L
.31885 .07063 L
.31891 .07037 L
.31896 .07003 L
.31901 .06968 L
.31906 .06934 L
.31915 .06902 L
.31925 .06871 L
.31932 .06845 L
.3193 .06828 L
.31913 .06821 L
.31878 .06828 L
.31819 .06851 L
.3173 .06901 L
.31604 .06971 L
.31432 .07073 L
.31218 .07206 L
.30952 .07368 L
.30614 .07567 L
.30307 .0777 L
.29929 .08004 L
.29484 .08244 L
.29103 .08495 L
.28657 .08742 L
.28236 .09004 L
.27752 .09253 L
.27389 .095 L
.26981 .09743 L
.26584 .09993 L
.26231 .10211 L
.25849 .10436 L
.2553 .10653 L
.25194 .10861 L
.24872 .11072 L
.2456 .11274 L
.24235 .11472 L
.23942 .11669 L
.23634 .11858 L
.23328 .12046 L
.2301 .12235 L
.2273 .12414 L
.22434 .12595 L
.2215 .1277 L
.21892 .12938 L
.21635 .13102 L
.21394 .13259 L
.21202 .13398 L
.2103 .13526 L
.20877 .13642 L
.20744 .13745 L
Mistroke
.20638 .1383 L
.2055 .13902 L
.20482 .1396 L
.20433 .14005 L
.20397 .14038 L
.20373 .14061 L
.20355 .14077 L
.20342 .14089 L
.20326 .14103 L
.20306 .14123 L
.20282 .14149 L
.20256 .14182 L
.20223 .14226 L
.20184 .14279 L
.20144 .14342 L
.20101 .1441 L
.20059 .14485 L
.20018 .14562 L
.19978 .14645 L
.1994 .14728 L
.19903 .14809 L
.19868 .14883 L
.19834 .14946 L
.19801 .14998 L
.19772 .15034 L
.19748 .15055 L
.1973 .15061 L
.19717 .15051 L
.19713 .15027 L
.19718 .14994 L
.1973 .14957 L
.19744 .14923 L
.19755 .14894 L
.19758 .14878 L
.19749 .1488 L
.19725 .14904 L
.19683 .14956 L
.19624 .15032 L
.19549 .15135 L
.1946 .15262 L
.1936 .15412 L
.19259 .15569 L
.19159 .15729 L
.19057 .15887 L
.18954 .1604 L
.1886 .16183 L
.18774 .16321 L
.18697 .16461 L
.18628 .16588 L
.18558 .16722 L
Mistroke
.18483 .16866 L
.18396 .17029 L
.18294 .17216 L
.18166 .17434 L
.18024 .17663 L
.17847 .17933 L
.17643 .18242 L
.1742 .18578 L
.17176 .18956 L
.16904 .19359 L
.16644 .19778 L
.16367 .20211 L
.16085 .20645 L
.15814 .2109 L
.15554 .21502 L
.15289 .21921 L
.15033 .22385 L
.14779 .22768 L
.1451 .23198 L
.14257 .23625 L
.13994 .24068 L
.13727 .24545 L
.13459 .24977 L
.13192 .25431 L
.12919 .25922 L
.12661 .26337 L
.1239 .26793 L
.12116 .27263 L
.11836 .27717 L
.11573 .28162 L
.1131 .28608 L
.11058 .29056 L
.1081 .29521 L
.10591 .29943 L
.10377 .30384 L
.10167 .30872 L
.09984 .31276 L
.09806 .31744 L
.09638 .32198 L
.09482 .32629 L
.0934 .3308 L
.09209 .33521 L
.09092 .3395 L
.0899 .3437 L
.08896 .34797 L
.08812 .35248 L
.08734 .35665 L
.08663 .3615 L
.08599 .36571 L
.08548 .37044 L
Mistroke
.08507 .37492 L
.08475 .37942 L
.08452 .38355 L
.08438 .38778 L
.0843 .39114 L
.08426 .3943 L
.08425 .39716 L
.08426 .39943 L
.08427 .4012 L
.0843 .40239 L
.08433 .40305 L
.08433 .4033 L
.08432 .40327 L
.08429 .40308 L
.08423 .40289 L
.08414 .40274 L
.08405 .40274 L
.08396 .40291 L
.08391 .4032 L
.08394 .40361 L
.08413 .40415 L
.08448 .40483 L
.085 .40569 L
.08574 .40675 L
.08672 .40803 L
.08777 .40948 L
.08906 .41116 L
.09025 .41305 L
.09145 .4152 L
.09278 .41747 L
.09377 .42008 L
.09465 .42291 L
.09537 .42611 L
.09586 .42939 L
.0961 .43303 L
.09607 .43668 L
.09574 .44058 L
.09516 .44419 L
.0944 .44796 L
.0934 .45178 L
.09235 .4552 L
.09114 .45866 L
.0898 .46202 L
.08829 .46525 L
.08678 .46844 L
.08496 .47167 L
.08331 .47488 L
.0814 .47826 L
.07955 .48173 L
.0775 .48562 L
Mistroke
.0755 .4896 L
.07386 .49374 L
.07227 .4985 L
.07078 .50315 L
.06959 .50823 L
.0687 .51338 L
.0681 .51858 L
.06779 .5238 L
.06771 .52895 L
.06781 .53383 L
.06806 .53836 L
.06843 .54243 L
.0689 .54626 L
.0694 .54933 L
.06992 .5523 L
.07043 .5548 L
.07094 .55719 L
.07145 .55967 L
.07194 .56227 L
.07244 .56479 L
.07292 .56762 L
.07341 .57082 L
.07391 .57386 L
.07442 .57733 L
.07494 .58102 L
.07543 .58402 L
.07593 .58745 L
.0764 .59065 L
.07681 .59315 L
.07715 .59534 L
.07741 .59715 L
.07761 .59847 L
.07777 .59927 L
.07789 .59962 L
.07799 .59966 L
.07807 .59954 L
.07814 .59937 L
.07824 .5992 L
.07838 .59912 L
.07857 .59919 L
.07884 .59941 L
.07916 .59969 L
.07954 .59992 L
.07996 .60008 L
.0804 .60015 L
.08084 .60018 L
.08126 .60016 L
.08164 .60011 L
.08195 .60009 L
.0822 .60014 L
Mistroke
.08238 .60034 L
.0825 .60074 L
.08257 .60142 L
.08263 .60245 L
.08266 .60389 L
.08267 .60571 L
.08265 .60805 L
.08263 .61079 L
.08262 .61409 L
.08267 .61763 L
.0828 .62172 L
.08302 .62593 L
.08333 .63046 L
.0837 .63521 L
.08414 .6401 L
.08463 .64522 L
.08519 .65058 L
.08579 .65595 L
.08646 .66132 L
.0872 .66705 L
.08797 .67244 L
.0888 .6776 L
.08967 .68325 L
.09053 .68798 L
.09142 .69295 L
.09229 .69773 L
.09313 .70177 L
.09396 .7058 L
.09474 .7094 L
.09551 .7127 L
.09627 .71541 L
.09699 .71784 L
.09764 .71983 L
.09818 .72153 L
.09861 .72296 L
.09893 .72412 L
.09915 .72503 L
.09931 .72574 L
.0994 .72625 L
.09947 .72657 L
.09954 .72674 L
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
Mistroke
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
.10294 .72838 L
.10292 .72867 L
.10291 .72911 L
.1029 .72974 L
.10288 .73038 L
.10287 .73118 L
.10285 .732 L
.10284 .73291 L
.10281 .73385 L
.10276 .73477 L
.10271 .73561 L
.10265 .73638 L
.10262 .73705 L
.10263 .73761 L
.10268 .73805 L
.10278 .73835 L
.10293 .73851 L
.10312 .73854 L
.10336 .73851 L
.10361 .73844 L
.10389 .73834 L
.10416 .73825 L
.10443 .73817 L
.10468 .7381 L
.10487 .73806 L
.10501 .73804 L
.1051 .73803 L
.10514 .73802 L
.10516 .73802 L
.10518 .73803 L
.10527 .73805 L
.10547 .73808 L
.10579 .73816 L
.10623 .73831 L
.10681 .73853 L
.10751 .73882 L
.10825 .7392 L
.10908 .7396 L
.10989 .74005 L
Mistroke
.11073 .74049 L
.11155 .74088 L
.1124 .74123 L
.11319 .74152 L
.114 .74172 L
.11486 .74187 L
.11577 .74193 L
.11675 .74187 L
.11786 .74164 L
.11903 .74128 L
.12046 .74072 L
.12192 .73999 L
.12351 .73913 L
.12536 .7382 L
.12699 .73724 L
.12874 .73631 L
.13053 .73536 L
.13211 .73447 L
.13346 .73365 L
.13462 .73294 L
.1355 .73236 L
.13609 .73197 L
.13637 .73177 L
.13632 .73173 L
.13596 .73185 L
.13539 .73214 L
.1348 .73258 L
.13431 .73319 L
.13392 .73398 L
.13366 .7349 L
.13352 .73596 L
.13351 .73715 L
.13369 .73848 L
.13417 .73987 L
.13481 .7411 L
.13585 .74243 L
.13694 .74385 L
.13822 .74546 L
.1395 .7472 L
.14082 .74902 L
.14207 .75109 L
.14314 .75351 L
.14409 .75622 L
.145 .75929 L
.14589 .76286 L
.1468 .76659 L
.14773 .77007 L
.1488 .77373 L
.15005 .77799 L
.15144 .78255 L
Mistroke
.15298 .78705 L
.15458 .79127 L
.15626 .79552 L
.15786 .79941 L
.15942 .80275 L
.16093 .80595 L
.16229 .80851 L
.16356 .81076 L
.16462 .81238 L
.16555 .81365 L
.16631 .81459 L
.16687 .81522 L
.16722 .81556 L
.16739 .81568 L
.16741 .81563 L
.16738 .8155 L
.16737 .81532 L
.16744 .81514 L
.16762 .815 L
.16796 .81496 L
.16845 .81503 L
.16905 .81517 L
.16974 .81535 L
.17049 .81556 L
.17125 .81581 L
.17203 .81609 L
.1728 .81639 L
.1735 .81668 L
.17411 .81695 L
.17457 .81711 L
.17488 .81715 L
.17501 .81707 L
.17502 .81694 L
.17493 .81678 L
.17479 .81664 L
.17464 .8166 L
.17456 .81674 L
.17462 .81714 L
.17488 .81782 L
.1754 .8188 L
.17621 .82008 L
.1773 .82169 L
.1786 .82338 L
.18015 .82539 L
.1819 .82757 L
.18381 .82979 L
.1857 .83194 L
.18761 .83402 L
.18942 .83571 L
.191 .83715 L
Mistroke
.19245 .83829 L
.19362 .8391 L
.19454 .83957 L
.19518 .83971 L
.19556 .83963 L
.19572 .83938 L
.19575 .83907 L
.19567 .83872 L
.19553 .83839 L
.19539 .83813 L
.19527 .83797 L
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
.19462 .8378 L
.19476 .83818 L
.19506 .83875 L
.19554 .83951 L
.19623 .84044 L
.19713 .84153 L
.19822 .84286 L
.19958 .84435 L
.20113 .84617 L
.20297 .8481 L
.20498 .85033 L
.20731 .85281 L
.20988 .85549 L
.21268 .85835 L
.21579 .86152 L
.21894 .86445 L
.22226 .8677 L
.22574 .87122 L
.22955 .87459 L
.23298 .87806 L
.23668 .88154 L
.24068 .88462 L
.24397 .88765 L
.24754 .89048 L
.25125 .89325 L
Mistroke
.2544 .89566 L
.25771 .898 L
.261 .9 L
.2643 .90193 L
.26782 .90377 L
.27114 .90561 L
.27464 .90718 L
.27833 .90889 L
.28223 .91045 L
.28601 .91203 L
.29001 .91354 L
.29393 .91502 L
.29775 .91631 L
.30153 .91755 L
.30495 .91867 L
.30816 .9196 L
.31108 .92039 L
.31368 .92106 L
.31596 .92159 L
.31793 .92199 L
.31959 .92228 L
.32096 .92246 L
.32207 .92255 L
.32296 .92256 L
.32364 .92253 L
.32415 .92249 L
.32452 .92247 L
.32476 .92245 L
.32489 .92245 L
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
.32406 .92214 L
.32468 .92244 L
.32565 .92286 L
.32703 .92342 L
.32887 .92412 L
.33105 .92499 L
.33351 .92594 L
.33664 .92722 L
.33995 .92849 L
.34385 .92992 L
Mistroke
.3482 .93154 L
.35276 .93329 L
.35721 .93516 L
.36208 .93683 L
.36707 .93864 L
.3721 .94035 L
.37676 .94206 L
.38164 .94382 L
.38642 .94542 L
.39114 .94709 L
.39584 .94871 L
.40045 .95029 L
.40499 .95178 L
.40917 .95323 L
.41354 .95455 L
.4179 .95585 L
.42252 .95716 L
.42626 .95841 L
.4304 .95967 L
.43433 .96086 L
.43841 .96203 L
.44212 .96311 L
.44584 .96406 L
.44941 .96493 L
.45264 .96567 L
.45573 .96625 L
.45833 .96671 L
.46074 .96705 L
.46278 .96731 L
.46445 .96746 L
.46577 .96754 L
.46678 .96757 L
.46746 .96754 L
.46787 .96748 L
.4681 .9674 L
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
Mistroke
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
.46546 .96059 L
.46553 .96078 L
.46562 .96102 L
.46567 .96127 L
.46569 .96148 L
.4657 .96171 L
.46572 .96193 L
.46576 .96214 L
.46581 .96235 L
.4659 .96255 L
.46599 .96279 L
.46606 .96305 L
.46612 .96325 L
.46621 .96345 L
.46636 .96365 L
.46657 .96382 L
.4668 .96396 L
.46704 .96405 L
.46728 .96406 L
.46746 .96399 L
Mistroke
.46752 .96381 L
.46747 .96355 L
.46727 .96323 L
.46694 .96283 L
.46651 .96243 L
.46607 .96212 L
.4657 .96194 L
.46537 .96193 L
.46511 .96207 L
.46493 .96231 L
.46491 .96255 L
.46504 .96298 L
.4654 .96356 L
.46604 .96426 L
.46699 .96498 L
.46828 .96567 L
.46996 .96626 L
.47199 .96672 L
.47439 .96701 L
.47719 .96709 L
.48039 .96696 L
.48401 .96663 L
.48783 .96618 L
.49238 .96563 L
.49663 .96505 L
.50143 .96443 L
.50687 .96379 L
.51156 .96315 L
.51674 .96251 L
.52197 .9619 L
.52765 .96131 L
.53252 .96074 L
.53789 .96017 L
.54335 .95959 L
.5485 .95896 L
.55386 .95826 L
.55927 .95746 L
.56478 .95658 L
.5702 .9556 L
.57584 .95455 L
.58135 .95348 L
.5869 .95236 L
.59201 .95127 L
.59707 .95019 L
.60189 .94916 L
.60627 .94824 L
.61018 .94747 L
.6137 .94687 L
.61672 .94641 L
.61908 .94609 L
Mistroke
.62106 .94589 L
.62257 .94578 L
.62363 .94572 L
.62431 .94569 L
.62466 .94569 L
.62471 .94571 L
.62453 .94573 L
.62418 .94574 L
.62375 .94575 L
.6233 .94575 L
.62287 .9457 L
.62248 .9456 L
.62218 .94545 L
.62197 .94523 L
.62197 .94496 L
.62224 .94463 L
.62279 .94426 L
.62367 .94383 L
.62487 .94336 L
.62645 .94286 L
.62846 .94236 L
.63094 .94179 L
.63381 .94121 L
.63697 .94059 L
.64052 .93994 L
.64436 .93925 L
.64833 .93856 L
.65227 .93786 L
.65627 .93718 L
.65979 .93652 L
.66333 .93591 L
.66649 .93537 L
.66912 .93487 L
.67152 .9344 L
.67363 .93396 L
.67535 .93358 L
.67689 .9333 L
.67817 .93313 L
.67927 .93304 L
.68009 .93302 L
.68069 .93303 L
.68122 .93304 L
.68174 .933 L
.68229 .93285 L
.68291 .93254 L
.6835 .93209 L
.6841 .93151 L
.68463 .93081 L
.68507 .93004 L
.68549 .9292 L
Mistroke
.68585 .9283 L
.68615 .92738 L
.68641 .9265 L
.68664 .92572 L
.68683 .92513 L
.68702 .92467 L
.68714 .92442 L
.68725 .92427 L
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
.68542 .92679 L
.68555 .92666 L
.68579 .92638 L
.68607 .92596 L
.68639 .92548 L
.68669 .92501 L
.68696 .92458 L
.68718 .92425 L
.68731 .92395 L
.68735 .92362 L
.68726 .92328 L
.68705 .92297 L
.68671 .92266 L
.68626 .92228 L
.68569 .9218 L
.68501 .92118 L
.68424 .92031 L
.68336 .91937 L
.68236 .91809 L
.68128 .91671 L
.68006 .91543 L
.67872 .91379 L
.67727 .91214 L
.67571 .91042 L
Mistroke
.67423 .90875 L
.67267 .90721 L
.67109 .90575 L
.6696 .90437 L
.66808 .90308 L
.6668 .90185 L
.66559 .90075 L
.66448 .8998 L
.66351 .89895 L
.6627 .89813 L
.66206 .89737 L
.66155 .89663 L
.66113 .89591 L
.66079 .89522 L
.66051 .89456 L
.66029 .89395 L
.66007 .8934 L
.65985 .89289 L
.65965 .89245 L
.65949 .89208 L
.65939 .89177 L
.65933 .89151 L
.6593 .89128 L
.65929 .89107 L
.6593 .89088 L
.65931 .89071 L
.65931 .89055 L
.65932 .89037 L
.65934 .89017 L
.65939 .88996 L
.65946 .88977 L
.65956 .88961 L
.65967 .8895 L
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
.66007 .88978 L
.66027 .88973 L
.66053 .88961 L
.66087 .88938 L
Mistroke
.66127 .88907 L
.6617 .88868 L
.66212 .88823 L
.66253 .88773 L
.66293 .8872 L
.66331 .88667 L
.66363 .88618 L
.66387 .88573 L
.664 .88536 L
.66399 .88508 L
.66382 .8849 L
.66348 .8848 L
.66297 .88475 L
.66231 .8847 L
.66153 .88464 L
.66068 .88454 L
.65984 .88435 L
.65902 .88414 L
.65822 .88385 L
.65744 .88352 L
.65674 .8832 L
.65615 .88287 L
.6557 .88252 L
.65535 .88216 L
.65507 .88174 L
.6548 .88125 L
.65453 .88067 L
.65422 .88002 L
.65381 .87929 L
.65329 .87848 L
.65272 .87762 L
.6521 .87668 L
.65149 .87576 L
.6509 .8748 L
.65032 .87382 L
.64981 .87294 L
.64936 .87212 L
.64897 .87132 L
.64864 .87055 L
.64838 .86978 L
.64818 .86902 L
.64802 .86826 L
.64788 .86746 L
.64776 .86664 L
.64762 .86572 L
.64745 .86475 L
.64723 .86367 L
.64695 .86247 L
.64664 .86129 L
.6463 .86013 L
Mistroke
.64597 .85904 L
.64565 .85806 L
.64536 .85723 L
.64511 .85657 L
.6449 .85609 L
.64471 .85571 L
.64453 .85539 L
.64436 .8551 L
.64419 .85481 L
.64406 .85451 L
.64396 .85422 L
.6439 .85395 L
.64389 .85372 L
.6439 .85352 L
.64393 .85335 L
.64397 .85319 L
.644 .853 L
.64401 .8528 L
.64401 .85259 L
.64401 .85241 L
.64401 .85226 L
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
Mistroke
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
.64213 .84433 L
.64208 .84458 L
.64202 .84495 L
.64194 .8454 L
.64175 .84592 L
.64142 .84648 L
.64096 .84704 L
.64036 .84754 L
.63961 .84794 L
.63873 .84825 L
.63781 .84847 L
.63686 .84861 L
.63586 .84869 L
.63485 .84873 L
.63386 .84875 L
.63295 .84877 L
.63227 .84876 L
.63176 .84871 L
.63138 .84859 L
.63115 .84844 L
.63102 .84835 L
.63095 .84835 L
.63087 .84849 L
.63071 .84879 L
.63043 .84927 L
.63003 .84996 L
.6295 .85086 L
.6288 .85198 L
.62787 .85334 L
.62688 .85475 L
.62557 .85656 L
.62439 .8583 L
.62316 .86013 L
.62188 .86203 L
Mistroke
.62061 .8639 L
.61941 .86562 L
.61839 .86705 L
.61749 .86827 L
.6167 .86928 L
.61601 .87009 L
.61541 .87071 L
.61488 .87115 L
.61444 .87141 L
.61411 .87149 L
.61392 .87139 L
.61382 .87123 L
.61378 .87106 L
.61375 .87097 L
.61369 .87104 L
.61359 .87131 L
.61344 .87179 L
.61325 .87251 L
.61303 .8735 L
.61281 .87482 L
.61259 .87652 L
.61238 .87862 L
.61211 .88085 L
.6118 .88348 L
.61148 .88658 L
.61117 .88965 L
.61091 .8932 L
.61073 .89659 L
.61063 .90017 L
.61063 .9039 L
.61073 .90704 L
.61095 .91028 L
.61123 .91342 L
.61162 .91612 L
.61208 .91866 L
.61259 .92093 L
.61317 .92296 L
.61379 .92483 L
.61442 .92662 L
.61504 .92845 L
.61565 .92984 L
.61625 .93136 L
.61683 .93273 L
.61736 .93402 L
.6178 .9352 L
.61814 .93635 L
.61835 .93736 L
.61843 .93823 L
.61835 .93897 L
.61809 .93961 L
Mistroke
.61765 .94009 L
.61714 .94043 L
.61655 .94071 L
.61593 .94097 L
.61527 .94119 L
.6148 .94147 L
.61434 .94184 L
.61397 .94225 L
.61368 .94264 L
.61354 .94305 L
.61357 .94348 L
.61371 .94389 L
.61395 .94424 L
.61424 .94451 L
.61454 .94469 L
.61473 .94478 L
.61479 .94477 L
.61466 .9447 L
.61437 .94461 L
.61393 .94444 L
.61334 .94421 L
.61261 .94401 L
.6118 .94383 L
.61095 .94363 L
.61011 .94344 L
.60932 .94324 L
.60864 .94312 L
.60805 .94297 L
.6076 .94283 L
.60727 .94275 L
.60706 .94269 L
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
Mistroke
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
.61203 .94337 L
.61171 .94336 L
.61121 .94331 L
.61053 .94319 L
.60979 .94307 L
.60905 .94297 L
.60826 .94282 L
.60758 .94263 L
.60707 .94244 L
.60675 .94225 L
.60665 .94212 L
.60674 .94204 L
.607 .94202 L
.60742 .94205 L
.60794 .9421 L
.60855 .94217 L
.60922 .94227 L
.60988 .94237 L
.61053 .9424 L
.61113 .94239 L
.61176 .94235 L
.61238 .94233 L
.61306 .94232 L
.61377 .94234 L
.61454 .94241 L
.61539 .94255 L
.61629 .94276 L
.61718 .94304 L
.61802 .94336 L
.61885 .9437 L
.61964 .94402 L
.62042 .94429 L
.62114 .9445 L
.62186 .94464 L
.62263 .94468 L
.6234 .94458 L
.62423 .94435 L
.62512 .94403 L
.62606 .94367 L
.62695 .94323 L
.62794 .94279 L
.62901 .94235 L
.63014 .94196 L
Mistroke
.63131 .94165 L
.63242 .94141 L
.63343 .94122 L
.63428 .94107 L
.63494 .94092 L
.6354 .9408 L
.6357 .94069 L
.63581 .9405 L
.63581 .94022 L
.63572 .93981 L
.63557 .93926 L
.63527 .93857 L
.63484 .9377 L
.63424 .93666 L
.63347 .93545 L
.63254 .93414 L
.63146 .93274 L
.63022 .93106 L
.62897 .92969 L
.62761 .92807 L
.62622 .92642 L
.62492 .92483 L
.62359 .92326 L
.62238 .92184 L
.62124 .92054 L
.62018 .91935 L
.61928 .91843 L
.61851 .91768 L
.61791 .91716 L
.61751 .91688 L
.61731 .91684 L
.61726 .91695 L
.61735 .91712 L
.61754 .91731 L
.61783 .91748 L
.61819 .91763 L
.61867 .91777 L
.6193 .91791 L
.62009 .91812 L
.62107 .91838 L
.62225 .91868 L
.62369 .91907 L
.62541 .91958 L
.62735 .92023 L
.62951 .921 L
.63184 .92179 L
.63439 .92263 L
.63681 .92349 L
.63945 .9244 L
.64195 .92516 L
Mistroke
.64451 .92581 L
.64712 .92644 L
.6495 .92694 L
.65169 .92733 L
.65381 .92765 L
.65574 .92784 L
.65746 .92801 L
.65904 .92818 L
.6604 .92835 L
.66162 .92856 L
.6627 .92879 L
.66365 .92906 L
.66436 .92938 L
.66499 .92969 L
.6655 .92998 L
.66588 .93023 L
.66614 .93045 L
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
.66554 .93161 L
.66541 .93182 L
.66526 .93211 L
.66513 .93247 L
.66509 .93288 L
.66514 .93326 L
.66532 .93356 L
.66562 .93382 L
.666 .934 L
.66652 .93409 L
Mistroke
.66712 .93403 L
.66784 .9338 L
.66867 .93336 L
.66956 .93272 L
.6705 .93189 L
.67143 .9309 L
.67234 .92983 L
.67316 .92868 L
.67384 .92752 L
.67432 .92642 L
.67461 .92546 L
.6748 .92463 L
.67491 .92395 L
.67494 .92344 L
.67493 .92312 L
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
.67365 .92482 L
.67374 .92497 L
.67393 .92509 L
.67425 .92515 L
.67473 .92516 L
.67536 .92517 L
.67614 .92519 L
.67707 .92518 L
.67819 .92518 L
.67954 .9251 L
Mistroke
.68115 .92491 L
.68314 .92453 L
.68537 .92394 L
.68796 .92314 L
.69086 .92214 L
.69396 .92093 L
.69744 .91953 L
.7011 .91793 L
.70454 .9162 L
.70837 .9142 L
.71221 .9119 L
.71631 .90933 L
.72061 .90669 L
.72432 .90387 L
.72835 .90099 L
.7324 .89805 L
.73626 .8951 L
.73982 .89221 L
.74351 .88918 L
.74714 .88613 L
.75048 .88324 L
.75404 .88025 L
.75725 .87738 L
.76017 .87467 L
.76307 .8721 L
.76558 .8698 L
.76788 .86767 L
.76984 .8657 L
.77146 .86404 L
.77283 .86256 L
.7739 .86126 L
.77467 .86017 L
.77517 .85927 L
.7754 .85854 L
.77541 .85798 L
.77525 .85751 L
.77499 .8571 L
.77466 .85675 L
.77431 .85642 L
.77395 .8561 L
.7736 .85578 L
.77325 .85548 L
.77294 .85519 L
.7727 .85492 L
.77254 .85466 L
.77244 .85438 L
.77234 .85404 L
.77226 .85359 L
.77215 .85304 L
.77197 .8524 L
Mistroke
.77168 .85167 L
.77125 .85085 L
.77067 .84995 L
.76993 .84897 L
.76906 .84796 L
.7681 .84692 L
.76711 .84602 L
.76607 .84516 L
.76505 .84449 L
.76406 .84389 L
.76321 .84348 L
.76248 .8431 L
.7619 .84281 L
.76149 .84265 L
.76124 .8426 L
.76111 .84263 L
.76104 .84273 L
.76097 .84282 L
.76081 .84298 L
.76051 .84315 L
.76003 .84333 L
.75937 .84348 L
.75846 .8437 L
.75727 .84406 L
.7558 .84461 L
.75418 .84543 L
.75238 .84643 L
.75037 .84744 L
.7482 .8488 L
.74581 .8498 L
.74378 .85103 L
.74179 .85223 L
.73972 .85329 L
.73794 .85426 L
.73662 .85516 L
.73534 .85592 L
.73437 .85654 L
.73362 .85698 L
.73309 .85724 L
.73275 .85732 L
.73255 .85723 L
.73241 .85703 L
.73218 .8567 L
.73176 .8563 L
.73111 .85582 L
.73018 .85528 L
.7288 .85465 L
.72717 .85388 L
.72511 .85296 L
.72291 .85193 L
Mistroke
.72052 .85077 L
.71785 .84951 L
.71532 .84824 L
.71241 .84691 L
.70988 .84557 L
.70726 .84419 L
.70468 .84282 L
.70258 .8416 L
.70049 .84042 L
.69876 .83944 L
.69717 .8386 L
.69569 .8379 L
.6943 .83734 L
.69299 .83687 L
.69165 .83651 L
.69024 .83623 L
.68874 .83603 L
.68713 .83589 L
.68561 .8358 L
.6838 .83571 L
.68173 .83559 L
.67967 .83539 L
.6774 .83513 L
.67497 .83479 L
.67268 .83441 L
.67028 .83401 L
.66804 .83359 L
.66603 .8332 L
.66415 .83284 L
.66256 .83252 L
.66117 .83224 L
.66002 .83199 L
.65905 .83174 L
.65828 .83146 L
.65769 .83118 L
.65725 .83094 L
.65695 .83079 L
.65678 .8307 L
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
.65678 .83132 L
.65645 .83107 L
.65605 .83059 L
Mistroke
.6556 .82989 L
.65511 .82898 L
.65459 .82793 L
.654 .82676 L
.65333 .82558 L
.65259 .82452 L
.65179 .8234 L
.65097 .82245 L
.65015 .82159 L
.64934 .82085 L
.64852 .82023 L
.64767 .81974 L
.64678 .81937 L
.64583 .81913 L
.64473 .81896 L
.64348 .81881 L
.64211 .81862 L
.64066 .81833 L
.63917 .81789 L
.63767 .8173 L
.63634 .81657 L
.63495 .8158 L
.63365 .81501 L
.63235 .81424 L
.63106 .8135 L
.62988 .81281 L
.62877 .8122 L
.62775 .81163 L
.62684 .81111 L
.62604 .81064 L
.62537 .81022 L
.62476 .80987 L
.62418 .80958 L
.62364 .80934 L
.62314 .80913 L
.62272 .80896 L
.62235 .80882 L
.62205 .80869 L
.62183 .80856 L
.62169 .80842 L
.62161 .80828 L
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
Mistroke
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
.62185 .80852 L
.62162 .80856 L
.62131 .80856 L
.62089 .80847 L
.62035 .80827 L
.6197 .80795 L
.61896 .8075 L
.61815 .80694 L
.6173 .80628 L
.61645 .80557 L
.61561 .80481 L
.61475 .80402 L
.6139 .80323 L
.61303 .80249 L
.61217 .80182 L
.61125 .80121 L
.61026 .80064 L
.60918 .80012 L
.608 .79964 L
.60674 .79918 L
.60555 .79873 L
.60425 .79826 L
.60304 .79776 L
.60184 .79725 L
.6007 .79673 L
.59966 .79622 L
.59877 .7957 L
.59803 .7952 L
.59748 .79476 L
.59711 .79439 L
.59693 .7941 L
.59691 .79387 L
.59699 .7937 L
.59715 .79361 L
.59735 .7936 L
.59757 .79368 L
.59773 .79384 L
.59776 .79408 L
.59758 .79438 L
.59717 .79474 L
.5965 .79518 L
.59553 .79568 L
.59422 .79626 L
.59275 .79688 L
.59094 .79756 L
.58882 .79828 L
Mistroke
.58671 .79903 L
.58446 .79978 L
.58171 .8005 L
.57928 .80116 L
.57666 .80175 L
.57405 .80224 L
.57158 .80266 L
.56924 .80301 L
.56735 .80331 L
.56566 .80358 L
.56419 .80382 L
.56295 .80401 L
.56201 .80414 L
.56126 .80422 L
.56069 .80425 L
.56031 .80425 L
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
.56161 .80363 L
.56133 .80378 L
.56084 .80409 L
Mistroke
.56011 .8046 L
.55912 .80534 L
.55783 .80636 L
.55637 .80765 L
.55465 .80922 L
.55263 .81113 L
.55038 .81324 L
.54806 .81561 L
.54542 .81833 L
.54274 .82083 L
.53982 .82396 L
.53712 .82656 L
.53413 .82935 L
.53118 .83228 L
.52823 .83505 L
.52506 .83792 L
.52235 .84036 L
.51927 .84307 L
.51665 .84533 L
.51394 .84765 L
.51143 .85006 L
.50876 .85248 L
.50657 .85479 L
.5044 .85729 L
.5023 .85978 L
.50028 .86236 L
.49828 .86511 L
.49645 .86752 L
.49458 .87029 L
.49262 .8729 L
.49058 .87577 L
.48864 .87863 L
.48679 .88107 L
.48482 .88357 L
.48273 .88609 L
.4807 .88827 L
.47878 .89026 L
.47692 .8921 L
.47523 .8937 L
.47372 .89504 L
.47232 .89619 L
.47103 .89717 L
.46984 .89794 L
.46877 .89853 L
.46769 .89897 L
.46655 .89925 L
.46536 .89941 L
.46409 .89945 L
.46274 .89942 L
.46133 .89932 L
Mistroke
.46008 .89918 L
.45876 .89902 L
.45746 .89885 L
.45624 .89867 L
.45504 .8985 L
.45399 .89834 L
.45307 .8982 L
.45234 .89808 L
.45181 .89797 L
.45152 .89784 L
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
.45211 .89744 L
.45177 .89779 L
.45121 .89835 L
.4504 .89916 L
.44939 .90031 L
.44815 .90183 L
.44682 .90352 L
.4453 .90551 L
.44354 .90787 L
.44161 .91037 L
.43955 .91343 L
.43747 .91623 L
.43522 .91936 L
.43301 .92274 L
.43097 .92585 L
.42892 .9292 L
.42692 .93252 L
.42523 .93513 L
.42371 .93769 L
.42238 .94017 L
.42123 .94248 L
.42039 .94418 L
.41974 .94566 L
.41922 .94691 L
.41879 .94786 L
.41837 .94853 L
.41783 .94894 L
.41708 .94914 L
.41605 .94918 L
.41466 .94907 L
.41289 .94884 L
.41121 .94844 L
.40913 .94796 L
.40647 .94747 L
Mistroke
.40414 .94695 L
.40147 .94642 L
.39836 .94583 L
.39579 .94519 L
.3931 .94453 L
.39065 .94386 L
.3884 .94321 L
.38634 .94258 L
.38467 .94199 L
.3833 .94148 L
.38214 .94107 L
.38117 .94077 L
.38043 .94054 L
.37992 .94035 L
.37961 .94018 L
.3795 .94002 L
.37954 .93988 L
.3797 .93974 L
.37994 .9396 L
.38021 .93948 L
.3805 .9394 L
.38078 .93936 L
.38104 .93936 L
.38128 .93938 L
.38148 .9394 L
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
Mistroke
.38195 .93988 L
.38163 .93965 L
.38113 .93925 L
.38044 .93864 L
.37954 .93782 L
.37844 .93679 L
.37726 .93562 L
.37584 .93421 L
.37419 .93259 L
.37251 .93082 L
.37064 .92886 L
.36869 .92669 L
.36675 .92451 L
.3647 .92217 L
.36274 .91978 L
.36072 .91743 L
.35873 .91494 L
.35676 .91252 L
.35478 .90996 L
.35279 .90735 L
.3508 .90464 L
.34888 .90186 L
.34693 .89896 L
.3451 .89609 L
.34323 .89316 L
.34137 .89027 L
.33958 .88731 L
.33774 .88444 L
.33599 .88156 L
.3343 .87869 L
.33266 .8758 L
.33111 .873 L
.32967 .87021 L
.3282 .86746 L
.32689 .86464 L
.32555 .86188 L
.32418 .85901 L
.32285 .8562 L
.32154 .85338 L
.32027 .85043 L
.31909 .84787 L
.31794 .84538 L
.31684 .84299 L
.3159 .84098 L
.31495 .83906 L
.31411 .83754 L
.31332 .83618 L
.31264 .83497 L
.31211 .83388 L
.31177 .83284 L
Mistroke
.31162 .83183 L
.31165 .83071 L
.3118 .82934 L
.31203 .82764 L
.31228 .82562 L
.31251 .82364 L
.3127 .82128 L
.31281 .81843 L
.31296 .81559 L
.31312 .81256 L
.31329 .8099 L
.31345 .8073 L
.31359 .80504 L
.31371 .80286 L
.31379 .80113 L
.31384 .79961 L
.31391 .79835 L
.31403 .79729 L
.31421 .79634 L
.31449 .79544 L
.31486 .79456 L
.31532 .79365 L
.31584 .79275 L
.31637 .79181 L
.31685 .79083 L
.31734 .78977 L
.31782 .78865 L
.31827 .78758 L
.31869 .78666 L
.31908 .78591 L
.3194 .78533 L
.31963 .78497 L
.31981 .78482 L
.31994 .78484 L
.32 .78497 L
.32002 .78512 L
.32002 .78523 L
.32 .78524 L
.31994 .78507 L
.31981 .78465 L
.31958 .78393 L
.3192 .78285 L
.31863 .78148 L
.31785 .77972 L
.31693 .77777 L
.31573 .77542 L
.31438 .77291 L
.31271 .76997 L
.31103 .76702 L
.30904 .76373 L
Mistroke
.30693 .76026 L
.30495 .75698 L
.30271 .75348 L
.30043 .74999 L
.29806 .74641 L
.29581 .74309 L
.29357 .73975 L
.29135 .7364 L
.28931 .73334 L
.28727 .73017 L
.28529 .72699 L
.28336 .72373 L
.28158 .7206 L
.27984 .71732 L
.27816 .71402 L
.2766 .71053 L
.2751 .70721 L
.27364 .70372 L
.27229 .70023 L
.27097 .69694 L
.2698 .69352 L
.26869 .68996 L
.26775 .68706 L
.26688 .68413 L
.2661 .68125 L
.26544 .67882 L
.26487 .67652 L
.26438 .6744 L
.26396 .6726 L
.26364 .67089 L
.26338 .66927 L
.26318 .66768 L
.26303 .66616 L
.26289 .66467 L
.26275 .6632 L
.26263 .66181 L
.26252 .66053 L
.26243 .65935 L
.26237 .65829 L
.26233 .65736 L
.26232 .65654 L
.26233 .65582 L
.26237 .65518 L
.26241 .65464 L
.26245 .65419 L
.26246 .65383 L
.26247 .65353 L
.26247 .6533 L
.26247 .6531 L
.26247 .65293 L
Mistroke
.26248 .65279 L
.26248 .65266 L
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
.26247 .65286 L
.26248 .65253 L
.26248 .65199 L
.26249 .65119 L
.2625 .65013 L
.26252 .64878 L
.26253 .64738 L
.26254 .64555 L
.26253 .64372 L
.2625 .64163 L
.26246 .63942 L
.26244 .63712 L
.26244 .63489 L
.26251 .6326 L
.26265 .6304 L
.26288 .62833 L
.2632 .62621 L
.26359 .62423 L
.26405 .62231 L
.26455 .62039 L
.26504 .61868 L
.26555 .61702 L
.26604 .6155 L
.26649 .61412 L
.2669 .61292 L
.26728 .61197 L
.26762 .61123 L
.26793 .61076 L
.26823 .61057 L
.26852 .61063 L
.26881 .6109 L
.26914 .61134 L
.2695 .61189 L
.26991 .61252 L
Mistroke
.2704 .61316 L
.27095 .61382 L
.27152 .61447 L
.27207 .61505 L
.27255 .61552 L
.27289 .61584 L
.27304 .61596 L
.27297 .61587 L
.27268 .61553 L
.27217 .61495 L
.2715 .61409 L
.27069 .61295 L
.2698 .61151 L
.26893 .60996 L
.26799 .60789 L
.26712 .60567 L
.2663 .60303 L
.26555 .60005 L
.26494 .59688 L
.26444 .59361 L
.26411 .5901 L
.26388 .58613 L
.26374 .58291 L
.26365 .57915 L
.26355 .5756 L
.26342 .5718 L
.26324 .56827 L
.26303 .56452 L
.26281 .56068 L
.26255 .55739 L
.26227 .55381 L
.26197 .55024 L
.26164 .54658 L
.26129 .5429 L
.26093 .5393 L
.26056 .53548 L
.26019 .53166 L
.25983 .5283 L
.25947 .52464 L
.25908 .52092 L
.25865 .51779 L
.25817 .51447 L
.25766 .51135 L
.25716 .5084 L
.25671 .50586 L
.25635 .50361 L
.2561 .50164 L
.25592 .50001 L
.25573 .49875 L
.25547 .49767 L
Mistroke
.25509 .49673 L
.25454 .49593 L
.25379 .49524 L
.25286 .4946 L
.25177 .494 L
.25058 .49343 L
.24936 .4929 L
.24834 .49245 L
.24705 .492 L
.246 .49152 L
.24499 .49096 L
.24407 .49038 L
.24334 .48988 L
.24284 .4895 L
.24255 .48929 L
.2424 .48924 L
.24227 .48936 L
.24208 .48963 L
.2417 .49001 L
.24099 .49048 L
.23992 .49101 L
.23845 .49157 L
.23673 .49216 L
.23468 .49279 L
.23223 .49346 L
.22961 .49415 L
.22693 .49482 L
.22382 .49544 L
.22074 .49597 L
.21787 .49639 L
.21437 .49671 L
.21149 .49693 L
.20839 .49707 L
.20523 .49713 L
.202 .49711 L
.19854 .49704 L
.19566 .49688 L
.19221 .49662 L
.18918 .49623 L
.18578 .49572 L
.18254 .4951 L
.17904 .49437 L
.17587 .49355 L
.17236 .49266 L
.16926 .49169 L
.16597 .49061 L
.163 .48942 L
.15999 .48819 L
.15704 .48685 L
.15416 .48552 L
Mistroke
.15136 .48415 L
.14858 .48276 L
.14579 .48148 L
.14322 .48024 L
.14047 .47905 L
.13773 .47792 L
.13509 .47686 L
.13222 .47582 L
.12952 .47478 L
.12668 .47376 L
.12397 .4727 L
.12115 .47161 L
.1187 .47054 L
.11609 .46945 L
.11397 .4683 L
.11195 .46706 L
.11012 .46579 L
.10852 .46433 L
.10717 .46279 L
.10604 .46104 L
.10511 .45915 L
.10434 .45718 L
.10367 .45497 L
.1031 .45283 L
.10259 .45051 L
.10211 .44801 L
.10164 .44572 L
.10116 .44332 L
.10072 .44087 L
.10031 .43883 L
.0999 .43682 L
.09956 .43501 L
.09927 .43346 L
.09905 .43224 L
.09892 .43135 L
.0989 .43071 L
.09898 .43026 L
.09912 .42995 L
.09933 .42972 L
.09964 .42949 L
.10007 .42922 L
.10066 .42889 L
.1014 .42848 L
.10231 .42802 L
.10335 .42751 L
.10445 .42694 L
.10563 .42629 L
.10682 .42559 L
.10791 .42489 L
.109 .42425 L
Mistroke
.10992 .42369 L
.11073 .42325 L
.11143 .42292 L
.11201 .42273 L
.11249 .42267 L
.1129 .42276 L
.11329 .42295 L
.11367 .42325 L
.11407 .42367 L
.11452 .42421 L
.11503 .42486 L
.11565 .42561 L
.11637 .42643 L
.11715 .4273 L
.11796 .42816 L
.11873 .42901 L
.11945 .42982 L
.12009 .43057 L
.12067 .43128 L
.12118 .43187 L
.12165 .43242 L
.12214 .43301 L
.12269 .43358 L
.12334 .43423 L
.12412 .43496 L
.12503 .43583 L
.12617 .43687 L
.12755 .43816 L
.12903 .4397 L
.13079 .44123 L
.13253 .44301 L
.13451 .44483 L
.13655 .44689 L
.13857 .44868 L
.14071 .45045 L
.14253 .45208 L
.14433 .45355 L
.14596 .45478 L
.14731 .45574 L
.14849 .45648 L
.14946 .45701 L
.1502 .45734 L
.15074 .45753 L
.15109 .45762 L
.15128 .45764 L
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
Mistroke
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
.15076 .45723 L
.15102 .45723 L
.15139 .45723 L
.1519 .45723 L
.15256 .45722 L
.15336 .45722 L
.15438 .45722 L
.15557 .45721 L
.15697 .45721 L
.15844 .4572 L
.16008 .45719 L
.16171 .45718 L
.16336 .45712 L
.16497 .45701 L
.16639 .45686 L
.16767 .45667 L
.16881 .45651 L
.1697 .45641 L
.17041 .45642 L
.17095 .45661 L
.17131 .45704 L
.17151 .45776 L
.17161 .45883 L
.17165 .46031 L
.17169 .46224 L
.17176 .46409 L
.17188 .46671 L
.17208 .46961 L
.17245 .47238 L
.17298 .47567 L
.17374 .4795 L
.17461 .48256 L
.17563 .48608 L
.17682 .48924 L
.17807 .4924 L
.17945 .49505 L
.18084 .49752 L
.18231 .49974 L
.18387 .50157 L
.18545 .50324 L
.18721 .50472 L
.18916 .506 L
.19119 .50715 L
.19351 .50819 L
.19565 .50908 L
.198 .5099 L
Mistroke
.2005 .51065 L
.2028 .51131 L
.20525 .51192 L
.20784 .51244 L
.21008 .51283 L
.21257 .51308 L
.21468 .51314 L
.21689 .51307 L
.21895 .51275 L
.22091 .51224 L
.22281 .51156 L
.22467 .51077 L
.22644 .50989 L
.22819 .50899 L
.2299 .508 L
.23161 .50699 L
.2331 .50589 L
.23463 .50474 L
.2361 .50357 L
.23737 .50245 L
.23857 .50147 L
.23966 .50061 L
.24061 .49992 L
.24139 .4994 L
.24205 .49902 L
.24258 .49876 L
.24301 .49861 L
.24335 .49855 L
.24364 .49859 L
.24389 .49876 L
.24412 .49903 L
.24429 .49936 L
.2444 .4997 L
.24446 .5 L
.24446 .50024 L
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
Mistroke
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
.2438 .50047 L
.24377 .50027 L
.24385 .49994 L
.24405 .49944 L
.24441 .49876 L
.24498 .49788 L
.24579 .49681 L
.24687 .49551 L
.24812 .494 L
.24964 .49223 L
.2514 .49028 L
.25336 .48806 L
.25546 .48569 L
.25779 .48297 L
.26002 .48042 L
.26233 .47757 L
.26459 .47477 L
.26684 .47182 L
.26878 .46892 L
.2707 .46596 L
.27244 .46276 L
.27409 .45955 L
.27563 .45666 L
.27711 .45348 L
.27855 .45003 L
.27995 .44643 L
.28141 .44353 L
.28283 .44019 L
.28428 .43664 L
.28577 .43349 L
.28729 .43014 L
.28883 .42656 L
.29038 .42357 L
.29192 .4203 L
.29345 .41729 L
.29498 .41422 L
.29648 .41153 L
Mistroke
.2979 .40878 L
.29928 .40624 L
.30057 .40371 L
.30183 .40121 L
.30296 .39896 L
.30402 .39675 L
.30501 .39482 L
.30591 .39304 L
.30675 .39151 L
.30754 .39017 L
.3083 .3891 L
.30909 .38823 L
.30991 .38756 L
.31077 .38709 L
.31172 .38678 L
.31276 .38659 L
.31392 .38652 L
.31507 .3865 L
.31633 .38653 L
.31766 .38659 L
.31893 .38667 L
.32019 .3867 L
.3213 .38669 L
.32237 .38656 L
.32325 .38652 L
.32395 .38651 L
.32447 .38653 L
.32479 .38658 L
.32491 .38665 L
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
.32441 .38688 L
.32504 .3867 L
.326 .38643 L
.32728 .38607 L
.32883 .38562 L
.33065 .38511 L
.33266 .38455 L
.33488 .38396 L
.33728 .38334 L
.33979 .38268 L
.34241 .38198 L
.34501 .38123 L
.34762 .38043 L
.3502 .37957 L
.35276 .37865 L
Mistroke
.35528 .37768 L
.35784 .37667 L
.36043 .37562 L
.36307 .37458 L
.36576 .3735 L
.36845 .37242 L
.37105 .3714 L
.3735 .37047 L
.37574 .36963 L
.37773 .36891 L
.37939 .36833 L
.38074 .36791 L
.38177 .36769 L
.38247 .36766 L
.38287 .36782 L
.38297 .3681 L
.38285 .36844 L
.38255 .36876 L
.38214 .36904 L
.38167 .36927 L
.38119 .36947 L
.38074 .36966 L
.38033 .36984 L
.37997 .37002 L
.37969 .3702 L
.37956 .37035 L
.37962 .37054 L
.37992 .37075 L
.38049 .37101 L
.38132 .37133 L
.38237 .37178 L
.38359 .37237 L
.38493 .37308 L
.38629 .3739 L
.38762 .3748 L
.38883 .37569 L
.38993 .37656 L
.3909 .37732 L
.39172 .37794 L
.39244 .37839 L
.3931 .37863 L
.39379 .37863 L
.39455 .37836 L
.39547 .37776 L
.39662 .37682 L
.39804 .37555 L
.3997 .37402 L
.40161 .37229 L
.40373 .37051 L
.40596 .36868 L
Mistroke
.4082 .36678 L
.41035 .36486 L
.41234 .36291 L
.41415 .36103 L
.41572 .35912 L
.41703 .35734 L
.41818 .35562 L
.41932 .35381 L
.42062 .35183 L
.4222 .34967 L
.42415 .34722 L
.42652 .34434 L
.42922 .34084 L
.43226 .33686 L
.43556 .33218 L
.43889 .32824 L
.44227 .32366 L
.4456 .31974 L
.44862 .31609 L
.4514 .31286 L
.45383 .30981 L
.45584 .30693 L
.45737 .30463 L
.4584 .30314 L
.45898 .30236 L
.45918 .30205 L
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
.45847 .30371 L
.45876 .30382 L
.45925 .30384 L
.46007 .30373 L
.46138 .30345 L
.46327 .30298 L
.4657 .30232 L
.46873 .30149 L
.47231 .30049 L
.47639 .29939 L
.48054 .29831 L
.48486 .29721 L
.48901 .29621 L
.49324 .29523 L
.49796 .29421 L
.50243 .29321 L
.50716 .29219 L
Mistroke
.51214 .29118 L
.51732 .29014 L
.52261 .28908 L
.52746 .28802 L
.53224 .28695 L
.53677 .2859 L
.54087 .28489 L
.54437 .2839 L
.54769 .28291 L
.55093 .28195 L
.55391 .28109 L
.55634 .28037 L
.55817 .27984 L
.55948 .27948 L
.56042 .27923 L
.56123 .27907 L
.56222 .27894 L
.56353 .27876 L
.56528 .27841 L
.56791 .27782 L
.57124 .27697 L
.57537 .27589 L
.58055 .27456 L
.58704 .27301 L
.59455 .27133 L
.60315 .26954 L
.61209 .26772 L
.61954 .26593 L
.62673 .26428 L
.63349 .26281 L
.63972 .26142 L
.64615 .26014 L
.6525 .25903 L
.65733 .25818 L
.66003 .25763 L
.66113 .25736 L
.66138 .25729 L
.66118 .25737 L
.66051 .25752 L
.65976 .25766 L
.65982 .25773 L
.66052 .25771 L
.66167 .25767 L
.66321 .2577 L
.66517 .25785 L
.66753 .25811 L
.67029 .2585 L
.67346 .259 L
.67697 .25959 L
.6807 .26023 L
Mistroke
.68442 .26091 L
.68807 .26159 L
.69147 .26228 L
.69461 .26296 L
.6974 .26363 L
.69979 .26425 L
.70176 .26482 L
.70339 .26527 L
.70475 .26556 L
.7059 .26564 L
.70692 .2655 L
.70788 .26513 L
.70894 .26454 L
.71023 .26374 L
.71182 .26274 L
.71368 .26153 L
.71579 .26017 L
.71821 .25856 L
.72093 .25679 L
.72382 .2549 L
.7268 .25288 L
.7298 .25087 L
.73286 .24877 L
.73593 .24663 L
.73905 .24456 L
.74221 .24249 L
.74545 .24049 L
.74878 .23848 L
.75219 .23646 L
.75568 .23443 L
.75921 .23239 L
.76263 .23032 L
.76594 .22825 L
.76897 .22631 L
.7718 .22436 L
.77439 .22239 L
.77675 .22043 L
.77885 .21854 L
.78073 .21667 L
.78239 .21473 L
.78387 .21266 L
.78521 .21052 L
.78647 .2083 L
.78771 .20596 L
.78901 .20355 L
.79035 .20109 L
.79169 .19873 L
.79295 .19648 L
.7941 .19447 L
.79513 .19261 L
Mistroke
.79603 .19109 L
.79677 .18983 L
.79734 .18886 L
.79778 .18817 L
.79819 .18773 L
.79864 .18749 L
.79922 .18741 L
.79998 .18744 L
.80098 .18752 L
.80223 .18758 L
.80372 .18755 L
.80539 .18739 L
.80721 .1871 L
.8091 .18673 L
.811 .18633 L
.81286 .18593 L
.81462 .18558 L
.81622 .18533 L
.81762 .18518 L
.81881 .18516 L
.8198 .18531 L
.8206 .18563 L
.82123 .18608 L
.82172 .18661 L
.8221 .18718 L
.82243 .18777 L
.82275 .18836 L
.8231 .18893 L
.82346 .18945 L
.82372 .18967 L
.82402 .18993 L
.82426 .19007 L
.82443 .19011 L
.82454 .19004 L
.82458 .18987 L
.82454 .18965 L
.82446 .1894 L
.82438 .18922 L
.82429 .18905 L
.8242 .18893 L
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
.8241 .18908 L
Mistroke
.82395 .18887 L
.82374 .18851 L
.82348 .18797 L
.82319 .18723 L
.82285 .18629 L
.82252 .18517 L
.82212 .18384 L
.82168 .18232 L
.82119 .18075 L
.82069 .17911 L
.82016 .1774 L
.81962 .17571 L
.81907 .17412 L
.81855 .17269 L
.81804 .17138 L
.81758 .17023 L
.81716 .16932 L
.81675 .1686 L
.81633 .16807 L
.81587 .16774 L
.81537 .16756 L
.81481 .16749 L
.81414 .16749 L
.81353 .16752 L
.81285 .16758 L
.81215 .16762 L
.81146 .16762 L
.81076 .16758 L
.8101 .16751 L
.80944 .16743 L
.80883 .1674 L
.80832 .16744 L
.80793 .16754 L
.80768 .16769 L
.80757 .16791 L
.80758 .1682 L
.80763 .16858 L
.80769 .16906 L
.80774 .16965 L
.80774 .17033 L
.80767 .17111 L
.80757 .17196 L
.80746 .17284 L
.80738 .17373 L
.80731 .17458 L
.80725 .17532 L
.80722 .17596 L
.80721 .17647 L
.80722 .17688 L
.80725 .17719 L
Mistroke
.80732 .17741 L
.80743 .17756 L
.80759 .1777 L
.80777 .17787 L
.80796 .17815 L
.80818 .17857 L
.80846 .17919 L
.80881 .18008 L
.80925 .18127 L
.80987 .18256 L
.81071 .18416 L
.81185 .18606 L
.81323 .18801 L
.81485 .19031 L
.81679 .1926 L
.81904 .19516 L
.82094 .19757 L
.82327 .2 L
.82554 .20231 L
.82784 .20448 L
.83001 .20643 L
.83212 .20819 L
.83372 .20984 L
.83516 .21115 L
.83644 .2123 L
.83744 .21322 L
.83818 .21388 L
.83863 .21426 L
.83885 .2144 L
.83896 .21436 L
.83901 .21424 L
.839 .2141 L
.83897 .21404 L
.839 .21412 L
.83911 .21437 L
.83929 .21482 L
.8395 .21544 L
.83977 .21622 L
.84007 .21714 L
.84039 .21813 L
.84072 .21926 L
.84106 .22054 L
.84139 .22197 L
.84169 .22335 L
.84195 .22473 L
.84218 .22604 L
.84236 .2272 L
.84249 .22811 L
.8426 .22885 L
.84269 .22944 L
Mistroke
.84276 .22987 L
.84279 .23014 L
.84278 .23028 L
.84274 .23027 L
.84266 .23011 L
.84257 .22979 L
.84247 .22932 L
.84237 .22872 L
.84226 .22804 L
.84211 .22733 L
.84194 .22664 L
.84174 .22598 L
.84148 .22529 L
.84116 .22454 L
.84076 .22371 L
.84032 .22277 L
.83987 .22179 L
.83936 .22065 L
.83878 .21934 L
.83826 .21789 L
.83768 .21634 L
.83704 .21486 L
.83642 .21334 L
.83575 .21171 L
.83512 .21025 L
.8345 .20876 L
.83395 .20744 L
.8335 .20621 L
.83312 .20524 L
.83281 .20436 L
.83256 .20379 L
.83238 .20332 L
.83224 .20307 L
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
Mistroke
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
Mistroke
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
.82987 .19484 L
.82988 .19449 L
.82983 .19397 L
.8297 .19328 L
.82947 .19239 L
.82914 .19128 L
.8287 .19006 L
.82813 .18864 L
.82741 .18692 L
.82653 .18521 L
.82555 .18326 L
.82438 .18112 L
.82309 .17894 L
.82171 .17654 L
.82014 .17423 L
.81856 .17179 L
.81688 .16928 L
.81522 .16688 L
.8136 .16456 L
.81205 .16234 L
.81061 .16024 L
Mistroke
.80937 .15846 L
.80821 .15677 L
.80733 .15555 L
.80658 .15452 L
.80598 .1537 L
.80553 .15311 L
.80523 .15275 L
.80506 .15256 L
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
.80575 .15345 L
.80545 .15323 L
.80492 .15282 L
.80414 .15217 L
.80311 .15119 L
.8018 .14986 L
.80015 .14816 L
.79828 .14616 L
.7966 .14434 L
.79452 .14205 L
.79236 .1398 L
.79012 .13723 L
.78751 .13443 L
.78551 .13196 L
.78354 .12962 L
.78149 .12709 L
.77975 .1249 L
.7783 .12319 L
.77701 .1216 L
.77594 .12021 L
.77512 .11914 L
.77448 .11837 L
.77395 .1177 L
.77354 .11725 L
.77318 .11687 L
.77282 .11658 L
.77245 .11636 L
.77202 .11618 L
Mistroke
.77149 .11601 L
.77083 .11582 L
.77004 .11563 L
.76931 .11545 L
.76847 .11528 L
.7676 .11509 L
.76677 .1149 L
.76608 .11474 L
.76554 .11461 L
.76513 .1145 L
.76484 .11444 L
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
Mistroke
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
Mistroke
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
Mistroke
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
Mistroke
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
Mistroke
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
Mistroke
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
Mistroke
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
Mistroke
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
.76851 .11563 L
.76862 .11554 L
.76876 .11551 L
.76897 .11555 L
.76922 .11568 L
.76952 .11589 L
.76984 .11617 L
.7702 .11651 L
.77061 .11692 L
Mistroke
.77109 .11739 L
.77165 .11793 L
.7723 .11855 L
.77305 .11923 L
.77391 .11998 L
.77486 .12082 L
.77592 .12172 L
.77706 .12266 L
.77811 .1236 L
.77922 .12444 L
.78034 .12531 L
.78131 .12617 L
.78225 .127 L
.78313 .12771 L
.78391 .12839 L
.78456 .129 L
.78513 .1295 L
.78561 .12991 L
.78603 .13025 L
.78643 .13054 L
.78686 .13086 L
.78737 .13127 L
.78801 .13188 L
.78877 .13271 L
.78972 .13384 L
.79078 .13516 L
.79206 .1368 L
.79355 .1388 L
.79526 .14104 L
.79724 .14366 L
.79924 .14656 L
.80149 .14979 L
.80398 .15344 L
.8065 .15683 L
.80909 .16072 L
.81184 .16421 L
.81451 .16811 L
.81737 .17156 L
.82028 .17535 L
.8229 .179 L
.82536 .18235 L
.82799 .18588 L
.83057 .18947 L
.8331 .19281 L
.83582 .1966 L
.83826 .20002 L
.84112 .20427 L
.84373 .20785 L
.84634 .21216 L
.8492 .21652 L
Mistroke
.85201 .22124 L
.85528 .22665 L
.85798 .23087 L
.86098 .23564 L
.86398 .24063 L
.86659 .24445 L
.86919 .24842 L
.87164 .25218 L
.87372 .2554 L
.87545 .25792 L
.87698 .26015 L
.87821 .26193 L
.87912 .2633 L
.87976 .26427 L
.88015 .26488 L
.88034 .26522 L
.8804 .2654 L
.88038 .2655 L
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
.88164 .26609 L
.88177 .26645 L
.88203 .26701 L
.88247 .26786 L
.88312 .26906 L
.88401 .27059 L
.88504 .27225 L
.88624 .27428 L
.8876 .2764 L
.88907 .27877 L
.89051 .28111 L
.89198 .28358 L
.89336 .2857 L
.89455 .28771 L
.89567 .28949 L
.89658 .29098 L
.8973 .29215 L
Mistroke
.89781 .29304 L
.89811 .29366 L
.89824 .29403 L
.89827 .29422 L
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
.89769 .29343 L
.89775 .29376 L
.89786 .29422 L
.89804 .29481 L
.89827 .29551 L
.89855 .29627 L
.89889 .2971 L
.89925 .29796 L
.89964 .2988 L
.90004 .2996 L
.90043 .30031 L
.9008 .30093 L
.90113 .30141 L
Mistroke
.90141 .30177 L
.90164 .302 L
.90181 .30213 L
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
Mistroke
.90361 .30418 L
.90345 .30423 L
.90325 .30419 L
.90302 .30401 L
.90272 .30362 L
.90233 .30297 L
.90184 .30203 L
.90121 .3008 L
.90043 .29919 L
.89944 .29718 L
.89822 .29465 L
.89678 .29193 L
.89506 .2883 L
.89308 .28494 L
.89076 .28079 L
.88831 .27657 L
.88551 .27199 L
.88254 .2668 L
.87943 .26229 L
.87615 .25691 L
.87282 .25169 L
.86959 .24721 L
.86627 .24211 L
.86288 .23653 L
.8597 .232 L
.85648 .22691 L
.85327 .22218 L
.85011 .21742 L
.84679 .21239 L
.84358 .20782 L
.84027 .2031 L
.83683 .19806 L
.83326 .19324 L
.82969 .18808 L
.82609 .18332 L
.82224 .17786 L
.81864 .17315 L
.81487 .16799 L
.81097 .16224 L
.80736 .15763 L
.80369 .15248 L
.80006 .14716 L
.79648 .14261 L
.79314 .13806 L
.78981 .13401 L
.7865 .12999 L
.78342 .12688 L
.78026 .12376 L
.77714 .12093 L
.77414 .11865 L
Mistroke
.7711 .11657 L
.76854 .11477 L
.76605 .11332 L
.76387 .11207 L
.76175 .11101 L
.75967 .11016 L
.75778 .10923 L
.756 .10836 L
.75416 .10742 L
.75219 .10638 L
.75001 .10525 L
.74757 .10405 L
.74483 .1028 L
.74232 .10156 L
.73909 .10026 L
.73564 .09886 L
.73169 .09729 L
.72676 .09549 L
.72253 .09366 L
.71737 .09161 L
.71217 .0894 L
.70663 .08715 L
.70094 .08474 L
.69503 .08243 L
.68954 .08003 L
.68362 .07759 L
.67764 .07518 L
.672 .07277 L
.66569 .07038 L
.66051 .06801 L
.65482 .06568 L
.64916 .06331 L
.64373 .06119 L
.63887 .0591 L
.63392 .05711 L
.6292 .05517 L
.62475 .05339 L
.62023 .05163 L
.6162 .04999 L
.61205 .0484 L
.60851 .04694 L
.60486 .04552 L
.60153 .04418 L
.59841 .04296 L
.59547 .04184 L
.59297 .04084 L
.59064 .03996 L
.58867 .03923 L
.58688 .0386 L
.58529 .03809 L
Mistroke
.58391 .03762 L
.58271 .03723 L
.5817 .03692 L
.58091 .0367 L
.58033 .03656 L
.57987 .03647 L
.57952 .03641 L
.57925 .03639 L
.57903 .03641 L
.57887 .03645 L
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
.57891 .03657 L
Mistroke
.57852 .03656 L
.57803 .03654 L
.57745 .03652 L
.57681 .0365 L
.57618 .03647 L
.57556 .03645 L
.57501 .03643 L
.57444 .03641 L
.57392 .0364 L
.57346 .03638 L
.57304 .03637 L
.57263 .03636 L
.57221 .03634 L
.57172 .03633 L
.57117 .03631 L
.57055 .03629 L
.56981 .03626 L
.56898 .03623 L
.56796 .0362 L
.56683 .03616 L
.56565 .03612 L
.56449 .03608 L
.56332 .03604 L
.56219 .036 L
.56115 .03597 L
.56023 .03594 L
.55947 .03592 L
.55889 .0359 L
.55843 .03588 L
.55807 .03587 L
.55778 .03586 L
.55755 .03586 L
.55737 .03585 L
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
.5577 .03586 L
.55723 .03585 L
.55649 .03583 L
.55546 .0358 L
.55415 .03575 L
.55255 .0357 L
Mistroke
.55088 .03564 L
.54897 .03557 L
.54684 .0355 L
.54468 .03543 L
.54261 .03535 L
.54054 .03528 L
.5386 .03522 L
.53706 .03517 L
.53572 .03512 L
.53461 .03509 L
.53377 .03506 L
.53322 .03504 L
.53293 .03501 L
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
.53341 .03493 L
.53343 .03522 L
.53343 .03563 L
.53344 .03617 L
.53344 .03683 L
.53345 .0376 L
.53346 .03837 L
.5335 .03919 L
.5336 .03998 L
.53374 .04076 L
.53387 .04141 L
.53393 .04204 L
.53389 .04261 L
.53372 .04311 L
.53338 .04357 L
.53286 .04407 L
.53219 .0446 L
.5314 .04517 L
.53053 .04577 L
.5296 .0464 L
.52869 .04699 L
.52781 .04763 L
.52692 .04828 L
.52608 .04894 L
.52534 .04955 L
.52479 .0501 L
.52446 .05047 L
.52434 .05069 L
.5244 .05072 L
.52464 .05054 L
.52502 .0502 L
Mistroke
.52553 .04973 L
.52616 .04921 L
.52692 .04868 L
.52789 .04815 L
.52918 .04765 L
.53087 .04722 L
.53298 .04685 L
.53546 .04656 L
.53836 .0464 L
.54147 .04637 L
.54516 .04651 L
.54884 .0468 L
.55322 .04731 L
.55718 .04802 L
.56155 .0489 L
.5662 .04981 L
.57052 .05085 L
.57444 .05194 L
.57843 .05303 L
.58219 .05409 L
.58575 .05508 L
.58911 .05602 L
.59238 .05685 L
.59568 .05748 L
.59885 .05794 L
.60227 .05827 L
.60576 .05849 L
.60948 .05866 L
.61351 .05883 L
.61768 .05907 L
.6219 .05941 L
.62692 .0599 L
.63115 .06058 L
.63605 .0615 L
.64119 .06269 L
.6471 .064 L
.65185 .06563 L
.65755 .06748 L
.66309 .06951 L
.66875 .07159 L
.6741 .07393 L
.67954 .07609 L
.68474 .07841 L
.68914 .0805 L
.6936 .08252 L
.69779 .08446 L
.70126 .08607 L
.70411 .08751 L
.70675 .08877 L
.7087 .0898 L
Mistroke
.71025 .09059 L
.71133 .09118 L
.71195 .09158 L
.71226 .09183 L
.71236 .09197 L
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
.71245 .09177 L
.71258 .09176 L
.71275 .09175 L
.71295 .09173 L
.7132 .09172 L
.71349 .09171 L
.71382 .09172 L
.71414 .09173 L
.71446 .09174 L
.71477 .09176 L
.71507 .09181 L
.71538 .09191 L
.7157 .09208 L
.71609 .09236 L
.71658 .09275 L
.71722 .09329 L
.71806 .09402 L
.71915 .09494 L
.72049 .09608 L
.72217 .09742 L
.72409 .09874 L
.72638 .10035 L
.7291 .10194 L
.73196 .10368 L
.7352 .10546 L
.73878 .10735 L
.7425 .10917 L
.7465 .11113 L
.75035 .11289 L
.75433 .11465 L
.75843 .11637 L
.76188 .11788 L
.76527 .11928 L
.76827 .12054 L
.77091 .12165 L
.77326 .1226 L
.77515 .12335 L
.77668 .12402 L
.77796 .12461 L
Mistroke
.77897 .12513 L
.77972 .12557 L
.78028 .12597 L
.7807 .12632 L
.781 .12666 L
.78125 .12701 L
.78145 .12736 L
.78165 .12771 L
.78189 .12806 L
.7822 .12842 L
.78254 .12878 L
.78286 .12909 L
.78315 .12932 L
.78341 .12948 L
.78364 .12957 L
.78386 .12963 L
.78409 .1297 L
.78437 .12982 L
.78474 .13003 L
.78519 .13035 L
.78575 .1308 L
.78637 .13134 L
.78705 .13194 L
.78777 .13258 L
.7885 .13322 L
.78921 .13384 L
.7899 .13442 L
.79055 .13495 L
.79115 .13541 L
.7917 .13579 L
.79216 .13606 L
.79256 .13623 L
.79286 .1363 L
.79308 .13626 L
.79322 .13616 L
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
.79275 .13592 L
.79284 .13625 L
.79305 .13676 L
.79343 .13753 L
.79399 .13867 L
.79474 .14012 L
.79574 .14196 L
.79692 .14407 L
.79841 .14642 L
Mistroke
.80012 .14927 L
.80205 .15205 L
.8041 .15506 L
.80634 .15804 L
.8084 .16087 L
.81056 .16382 L
.81241 .16639 L
.81417 .16841 L
.81574 .17028 L
.81708 .17197 L
.81814 .17327 L
.81898 .17422 L
.8196 .17482 L
.81999 .17512 L
.82019 .17521 L
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
.81772 .17386 L
.81787 .17382 L
.81804 .17381 L
.81821 .17384 L
.81838 .1739 L
.81854 .17401 L
Mistroke
.81874 .17421 L
.81898 .17452 L
.81927 .17497 L
.81963 .17561 L
.82004 .17646 L
.82051 .17747 L
.82106 .17868 L
.82163 .18009 L
.82228 .18165 L
.82297 .1831 L
.82366 .18466 L
.8244 .18627 L
.82511 .18767 L
.82581 .18902 L
.82646 .1903 L
.82702 .19134 L
.82749 .19222 L
.82784 .19291 L
.82808 .19338 L
.82822 .19361 L
.82824 .19361 L
.82817 .19341 L
.82801 .19308 L
.82779 .19262 L
.82754 .19207 L
.82725 .19143 L
.82694 .19069 L
.82661 .1899 L
.82625 .18904 L
.82585 .18805 L
.82534 .18691 L
.82477 .18569 L
.82407 .18431 L
.82322 .18274 L
.82219 .18095 L
.82109 .17904 L
.81975 .17687 L
.81838 .17455 L
.81677 .17187 L
.81505 .16905 L
.81316 .16618 L
.81124 .16332 L
.80938 .16039 L
.80751 .15753 L
.80566 .15453 L
.80411 .15218 L
.80259 .14982 L
.80125 .1478 L
.79994 .14592 L
.7989 .1445 L
Mistroke
.79794 .14332 L
.79707 .1424 L
.79629 .14176 L
.79562 .14137 L
.79505 .14117 L
.79461 .14112 L
.79423 .14117 L
.79392 .14127 L
.79366 .1414 L
.79346 .14154 L
.7933 .14167 L
.79318 .14178 L
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
.79336 .14219 L
.793 .14246 L
.7925 .14284 L
.79187 .14335 L
.79115 .144 L
.79034 .14478 L
.78954 .14558 L
.78872 .14644 L
.78785 .14731 L
.78695 .14814 L
.78613 .14886 L
.78542 .14947 L
.78485 .1499 L
.78449 .15012 L
.78422 .15011 L
.78404 .14983 L
.78392 .14929 L
.78383 .14846 L
.78367 .14744 L
.78338 .14618 L
.78293 .14462 L
.78234 .14289 L
.7816 .14092 L
.78072 .13879 L
.77985 .13652 L
Mistroke
.77877 .13409 L
.7776 .13169 L
.7764 .12925 L
.77517 .12682 L
.774 .12457 L
.7728 .12244 L
.77168 .12041 L
.77059 .11883 L
.76956 .11744 L
.7686 .11627 L
.76778 .11539 L
.76698 .11476 L
.76622 .11435 L
.76552 .11412 L
.76488 .11402 L
.7643 .114 L
.76378 .11404 L
.76335 .11411 L
.76302 .11417 L
.7628 .11422 L
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
Mistroke
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
.76297 .11454 L
.76264 .11446 L
.76219 .11431 L
.76161 .1141 L
.7609 .11384 L
.76008 .11357 L
.7592 .11331 L
.75826 .11309 L
.75724 .11291 L
.75618 .11279 L
.75515 .11272 L
.75418 .11268 L
.75331 .11268 L
.7526 .1127 L
.75201 .1128 L
.75156 .11297 L
.75123 .1132 L
.751 .11347 L
.75086 .11376 L
.75079 .11403 L
.75077 .11424 L
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
Mistroke
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
.75067 .10967 L
.75076 .10987 L
.75093 .11019 L
.75121 .11062 L
.75163 .11121 L
.75223 .11195 L
.75304 .11285 L
.75406 .11395 L
.7553 .11528 L
.7567 .11677 L
.75823 .11857 L
.75998 .12051 L
.76186 .12278 L
.76385 .12502 L
.76592 .1275 L
.76799 .13005 L
.77004 .1326 L
.77201 .1353 L
.77382 .13752 L
.77549 .13991 L
.77699 .1424 L
.77829 .14486 L
.77932 .14691 L
.78014 .14895 L
.78076 .15114 L
.78124 .15348 L
.78163 .15587 L
.782 .15788 L
Mistroke
.7824 .16048 L
.78291 .16294 L
.78359 .16599 L
.78449 .16896 L
.78566 .17195 L
.78712 .17526 L
.7888 .17848 L
.79081 .18177 L
.79316 .18501 L
.79582 .18783 L
.79875 .1907 L
.80213 .1933 L
.80535 .19571 L
.80901 .19783 L
.81252 .19972 L
.81597 .20133 L
.81916 .20264 L
.82209 .20374 L
.82516 .20459 L
.82751 .20522 L
.82944 .20564 L
.83122 .20586 L
.83251 .20588 L
.83347 .20571 L
.83413 .2054 L
.83455 .20494 L
.83475 .20435 L
.8348 .20363 L
.83471 .20273 L
.83417 .20164 L
.83392 .2004 L
.83368 .19895 L
.83342 .19729 L
.83304 .19552 L
.83253 .19355 L
.83192 .19145 L
.83126 .18953 L
.83042 .18741 L
.82945 .18545 L
.82828 .18346 L
.82702 .18147 L
.82568 .17969 L
.82432 .17797 L
.82296 .17632 L
.82161 .1748 L
.82028 .17331 L
.819 .17183 L
.81778 .17041 L
.81655 .16896 L
.81533 .16743 L
Mistroke
.81408 .16582 L
.81284 .16424 L
.81166 .16262 L
.81058 .16103 L
.8096 .15948 L
.80873 .1581 L
.80798 .15685 L
.80736 .15575 L
.80687 .15487 L
.80646 .15417 L
.80611 .15364 L
.80582 .15325 L
.80559 .15301 L
.80545 .15289 L
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
.80597 .15368 L
.80553 .15323 L
.80477 .1524 L
.8037 .15116 L
.80235 .14953 L
.80065 .1474 L
.79855 .14475 L
.79633 .1421 L
.79344 .13917 L
.79056 .13611 L
.78718 .13263 L
.78356 .1285 L
.7799 .12527 L
.77585 .12208 L
.77234 .11891 L
.76835 .11605 L
.76456 .11339 L
.76036 .11102 L
.75598 .10875 L
.75199 .10675 L
.74722 .10466 L
.74262 .10251 L
.73764 .10026 L
.73205 .0979 L
.72738 .09578 L
.72249 .09357 L
.71694 .0912 L
.71264 .08924 L
.70794 .0873 L
.70359 .08546 L
Mistroke
.69942 .08384 L
.696 .08249 L
.6929 .08136 L
.6904 .08045 L
.68824 .07979 L
.68649 .07937 L
.68509 .07913 L
.68398 .079 L
.6831 .07896 L
.68243 .07899 L
.68191 .07903 L
.68153 .07911 L
.68124 .07919 L
.68099 .07925 L
.68079 .07935 L
.68066 .07948 L
.68058 .07965 L
.68055 .07983 L
.68058 .08002 L
.68064 .08018 L
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
Mistroke
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
.67716 .08038 L
.67665 .08011 L
.67587 .07963 L
.67476 .07893 L
.67327 .07797 L
.67151 .07679 L
.66925 .07537 L
.66675 .07372 L
.66375 .07185 L
.66048 .07003 L
.65695 .0678 L
.65314 .0659 L
.64935 .0638 L
.64546 .06169 L
.64141 .05966 L
.63773 .05783 L
.63389 .05602 L
.63007 .05443 L
.62628 .05299 L
.62263 .05169 L
.61899 .05055 L
.61563 .04959 L
.6122 .04872 L
.60896 .04794 L
.60561 .04721 L
.60204 .0465 L
.59853 .04576 L
.59462 .04499 L
.59069 .04416 L
.58637 .04328 L
.58241 .04236 L
.57818 .04151 L
.57428 .0406 L
Mistroke
.5706 .03967 L
.56706 .03873 L
.56365 .03793 L
.561 .03719 L
.55861 .03654 L
.55652 .03602 L
.555 .03564 L
.55381 .03541 L
.55299 .03533 L
.55245 .03536 L
.55202 .03546 L
.55156 .03558 L
.5509 .03569 L
.54993 .03577 L
.54862 .03579 L
.54684 .03576 L
.54449 .0357 L
.54169 .0356 L
.53845 .03549 L
.53467 .03538 L
.53106 .03525 L
.52725 .0351 L
.52351 .03494 L
.51997 .03477 L
.51643 .0346 L
.51372 .03445 L
.51129 .03433 L
.50915 .03423 L
.50767 .03416 L
.50661 .03414 L
.50604 .03414 L
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
.51004 .0341 L
.5097 .03418 L
.50907 .03434 L
.50807 .03456 L
.50665 .03484 L
Mistroke
.50481 .03517 L
.50273 .03552 L
.50016 .03589 L
.49735 .03624 L
.49426 .03658 L
.49122 .03691 L
.48815 .03722 L
.4855 .03749 L
.48299 .0377 L
.48115 .03784 L
.47966 .03791 L
.4786 .03792 L
.47798 .03788 L
.47776 .03781 L
.47778 .03774 L
.47791 .03767 L
.47801 .0376 L
.47801 .03753 L
.47786 .03746 L
.47752 .03741 L
.47689 .03739 L
.47601 .0374 L
.47486 .03746 L
.47359 .03758 L
.47234 .03779 L
.47109 .0381 L
.46992 .03855 L
.46888 .03913 L
.46804 .03985 L
.46736 .04067 L
.46685 .04159 L
.46647 .04262 L
.46618 .04371 L
.46595 .04477 L
.46575 .04566 L
.46558 .04638 L
.46548 .04694 L
.46546 .04733 L
.46549 .04756 L
.46559 .0476 L
.46567 .04749 L
.46562 .04729 L
.46538 .04708 L
.4649 .04689 L
.46414 .04677 L
.46306 .04666 L
.46161 .0466 L
.45984 .04663 L
.45805 .04642 L
.45586 .04654 L
Mistroke
.45351 .04663 L
.4506 .04664 L
.44804 .04655 L
.44516 .04632 L
.44205 .04594 L
.43886 .0454 L
.43602 .04473 L
.43322 .04396 L
.43069 .04316 L
.42868 .04238 L
.42687 .0417 L
.42527 .04113 L
.42401 .04069 L
.42298 .04037 L
.42227 .04018 L
.42196 .04009 L
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
.42511 .04048 L
.42455 .04046 L
.4235 .04043 L
.42196 .04039 L
.4199 .04032 L
.41757 .0402 L
.41467 .04 L
.41131 .03974 L
.40785 .03946 L
.40379 .03919 L
.39961 .03897 L
.39508 .03886 L
.39006 .03893 L
.38562 .03921 L
.38071 .03974 L
.37584 .04054 L
.37115 .04164 L
.36602 .04306 L
.36154 .04465 L
.35644 .04661 L
.35191 .04874 L
.3469 .05114 L
.34209 .05369 L
.33733 .05644 L
.33274 .05915 L
.32764 .06206 L
.32308 .06498 L
Mistroke
.31791 .06799 L
.31342 .07095 L
.30843 .07406 L
.30366 .07702 L
.29869 .08014 L
.29345 .08331 L
.28862 .08648 L
.2831 .08987 L
.27837 .09303 L
.27307 .09643 L
.26773 .09984 L
.26285 .10312 L
.25741 .10655 L
.25247 .1097 L
.24743 .11287 L
.24245 .116 L
.23751 .11907 L
.23277 .12228 L
.22788 .12562 L
.22333 .12896 L
.21868 .13255 L
.21421 .13625 L
.20985 .1401 L
.20554 .14429 L
.20165 .1483 L
.19784 .15262 L
.19409 .15738 L
.19072 .16177 L
.18736 .16668 L
.18417 .1718 L
.18105 .17661 L
.17805 .18165 L
.17511 .18664 L
.17221 .19179 L
.16936 .1964 L
.16645 .20151 L
.16364 .20611 L
.16079 .2108 L
.1578 .21535 L
.15487 .22008 L
.15181 .2251 L
.14885 .22955 L
.14576 .23461 L
.14264 .23968 L
.13961 .2442 L
.13642 .24946 L
.13326 .25456 L
.13034 .25995 L
.1271 .2654 L
.12363 .27086 L
Mistroke
.1205 .27627 L
.11703 .28193 L
.11422 .28673 L
.11118 .29154 L
.10853 .29597 L
.10615 .30008 L
.1042 .30337 L
.10246 .30645 L
.10102 .30928 L
.09993 .3116 L
.09901 .31384 L
.09821 .31611 L
.09749 .31852 L
.09679 .3212 L
.09605 .32396 L
.09527 .32737 L
.09449 .33073 L
.09357 .33469 L
.09263 .33911 L
.0916 .34388 L
.0905 .34926 L
.08946 .35431 L
.08843 .36008 L
.08748 .36509 L
.08664 .37071 L
.08596 .37535 L
.08545 .38014 L
.08508 .38446 L
.08482 .3882 L
.08463 .3916 L
.08449 .39448 L
.08437 .39691 L
.08425 .39879 L
.08415 .40024 L
.08409 .40125 L
.08405 .40189 L
.08404 .40223 L
.08404 .40236 L
.08404 .40238 L
.08409 .40237 L
.08424 .40239 L
.08452 .40251 L
.08498 .40283 L
.08563 .40338 L
.08645 .4042 L
.08744 .40524 L
.08857 .40653 L
.08981 .4081 L
.091 .40994 L
.09225 .41212 L
Mistroke
.09341 .41461 L
.09455 .41744 L
.09552 .42061 L
.09633 .42391 L
.09694 .42767 L
.0973 .43157 L
.09736 .43516 L
.09712 .43921 L
.09656 .44335 L
.09567 .44781 L
.09448 .45209 L
.09305 .45604 L
.09134 .46036 L
.08956 .46433 L
.08766 .46819 L
.08557 .47184 L
.08372 .47499 L
.08163 .47785 L
.07998 .48023 L
.07841 .48231 L
.07693 .48408 L
.07576 .48542 L
.07484 .48642 L
.0742 .48706 L
.07383 .48739 L
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
.07439 .48531 L
.07426 .48572 L
.07403 .48643 L
.07371 .48749 L
.07329 .48897 L
.07278 .49093 L
.07222 .49309 L
.07162 .49599 L
.07102 .49904 L
.07044 .50272 L
.06993 .50664 L
.06952 .51086 L
.06924 .51575 L
.06911 .52005 L
.06917 .52462 L
.06936 .52973 L
.06973 .53433 L
.07028 .5398 L
.07097 .54434 L
.07176 .54921 L
.07263 .5538 L
.07348 .55853 L
.07431 .56315 L
.07509 .56764 L
.07579 .57205 L
.07642 .57608 L
.077 .57999 L
.07752 .58361 L
.078 .58678 L
.07843 .58975 L
.07881 .59212 L
.07913 .59417 L
Mistroke
.0794 .59584 L
.07962 .59709 L
.07982 .598 L
.08001 .59862 L
.08018 .59896 L
.08033 .59909 L
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
.08068 .59837 L
.08088 .59835 L
.08113 .59829 L
.08141 .59817 L
.08172 .59799 L
.082 .59778 L
.08225 .59758 L
.08248 .59741 L
.08265 .59732 L
.08276 .59741 L
.0828 .59775 L
.08279 .59841 L
.08274 .59945 L
.08268 .60097 L
.08262 .60301 L
.08258 .60522 L
.0826 .60819 L
.08269 .61149 L
.08289 .6154 L
.08319 .61969 L
.08357 .62468 L
.08403 .629 L
.08454 .63458 L
.08511 .63956 L
.08569 .6448 L
Mistroke
.08628 .65013 L
.08689 .65494 L
.08748 .65978 L
.08804 .66432 L
.0886 .66855 L
.08919 .67279 L
.08981 .6765 L
.09042 .68021 L
.09105 .68336 L
.09169 .68649 L
.09231 .68917 L
.0929 .69169 L
.09348 .69393 L
.09402 .69558 L
.0945 .69721 L
.0949 .69848 L
.09524 .69957 L
.09549 .70047 L
.09566 .70117 L
.09576 .70164 L
.09582 .70188 L
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
Mistroke
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
.10072 .70348 L
.10087 .70392 L
.1011 .70451 L
.10143 .70524 L
.10185 .7061 L
.10238 .70702 L
.10301 .70808 L
.10376 .70925 L
.10462 .71056 L
.10555 .712 L
.10664 .7135 L
.10773 .71514 L
.10893 .71692 L
.11019 .71884 L
.11149 .7207 L
.1129 .72278 L
.11428 .72487 L
.11564 .72712 L
.11707 .72947 L
.11843 .73176 L
.11977 .73414 L
.121 .73625 L
.12216 .73827 L
.12317 .74004 L
.12407 .74157 L
.12479 .74276 L
.12537 .74367 L
.12582 .74434 L
.12614 .7448 L
.12633 .74507 L
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
Mistroke
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
.12507 .74378 L
.12509 .74422 L
.12526 .74492 L
.12563 .74595 L
.12625 .74734 L
.12716 .74914 L
.12837 .75109 L
.12993 .75366 L
.13198 .75631 L
.13408 .75952 L
.13628 .76283 L
.13892 .7666 L
.14189 .77046 L
.14486 .77447 L
.14808 .77865 L
.1512 .78287 L
.15423 .78695 L
.15727 .79113 L
.16018 .79538 L
.163 .79954 L
.1657 .80361 L
.16834 .80771 L
.17099 .81176 L
.17371 .81557 L
.17653 .81955 L
.17955 .82341 L
.18267 .82714 L
.18624 .83112 L
.1898 .8351 L
.19357 .83895 L
.19762 .84318 L
.20172 .84719 L
.20601 .85159 L
.21043 .85519 L
.21483 .85955 L
.21927 .86337 L
.22376 .86784 L
.22827 .87161 L
.23267 .87539 L
.23706 .87923 L
Mistroke
.24167 .88296 L
.24577 .88667 L
.25031 .89012 L
.25448 .89314 L
.25883 .89618 L
.26307 .89871 L
.26729 .90121 L
.27154 .90352 L
.27561 .90551 L
.27981 .90739 L
.28391 .9091 L
.28813 .91072 L
.29215 .91226 L
.29659 .9138 L
.30094 .91537 L
.30549 .91688 L
.31061 .9186 L
.31504 .92034 L
.32001 .9222 L
.32534 .92417 L
.33036 .92608 L
.33568 .92815 L
.34181 .93021 L
.34674 .93222 L
.35229 .93429 L
.35786 .93618 L
.36336 .93805 L
.36865 .93975 L
.3738 .94143 L
.3788 .94308 L
.38371 .94468 L
.38848 .94624 L
.39323 .94778 L
.39782 .94919 L
.40211 .95057 L
.40634 .9519 L
.41046 .95324 L
.41424 .95452 L
.4182 .95583 L
.42175 .95719 L
.4253 .95851 L
.42888 .95984 L
.4326 .96114 L
.43639 .96236 L
.44008 .96347 L
.44408 .96445 L
.44785 .9653 L
.45154 .96599 L
.45556 .96653 L
.45906 .96694 L
Mistroke
.46274 .96721 L
.46645 .96734 L
.47034 .96732 L
.47387 .96714 L
.47765 .96682 L
.4815 .9664 L
.48535 .96596 L
.4895 .9655 L
.49393 .96507 L
.49842 .9646 L
.50323 .9641 L
.50841 .96352 L
.5138 .96284 L
.5195 .96205 L
.52528 .96113 L
.53122 .96012 L
.53713 .95904 L
.54315 .95794 L
.5491 .95682 L
.55473 .95576 L
.56017 .95475 L
.56556 .9538 L
.57044 .95292 L
.57513 .95216 L
.57952 .9515 L
.58353 .95094 L
.58719 .95043 L
.59043 .95008 L
.59332 .94977 L
.59582 .94949 L
.59803 .94917 L
.6 .94886 L
.60174 .94845 L
.60336 .94801 L
.6049 .94752 L
.60649 .94696 L
.60822 .9464 L
.61002 .94579 L
.61206 .94511 L
.61443 .94439 L
.61697 .9436 L
.61991 .94272 L
.62301 .94168 L
.62647 .94061 L
.62975 .93964 L
.63328 .93852 L
.63717 .93736 L
.6405 .93616 L
.64396 .93484 L
.64745 .93381 L
Mistroke
.65088 .93261 L
.6542 .93132 L
.65752 .92984 L
.66052 .92842 L
.66342 .92684 L
.66638 .92534 L
.66932 .92362 L
.67232 .92172 L
.67525 .91982 L
.67841 .91789 L
.6813 .91582 L
.68426 .91384 L
.68726 .91191 L
.69022 .91009 L
.69329 .90843 L
.69628 .90698 L
.69941 .90577 L
.7026 .90474 L
.70585 .90382 L
.70925 .90292 L
.71257 .90201 L
.7161 .90099 L
.71977 .89978 L
.72363 .89834 L
.7276 .8967 L
.73172 .89479 L
.73594 .89259 L
.74024 .89018 L
.74451 .88755 L
.74881 .88464 L
.75322 .88167 L
.75754 .87856 L
.76179 .87537 L
.76605 .87209 L
.77026 .86887 L
.77462 .86551 L
.77883 .86208 L
.78338 .85861 L
.78738 .8552 L
.79163 .85174 L
.79583 .8483 L
.8002 .84476 L
.80436 .84125 L
.80854 .83783 L
.8133 .83415 L
.81729 .83074 L
.82169 .82717 L
.82609 .8237 L
.83071 .82018 L
.83488 .81698 L
Mistroke
.83901 .81369 L
.84322 .81042 L
.84707 .80709 L
.85079 .8036 L
.85442 .80007 L
.85778 .79635 L
.86078 .79217 L
.86365 .78809 L
.86622 .78372 L
.86853 .77929 L
.87059 .77456 L
.87235 .77044 L
.87393 .7662 L
.87536 .76215 L
.87658 .75838 L
.8777 .75515 L
.87868 .75221 L
.87955 .7499 L
.8803 .74804 L
.88089 .74669 L
.88134 .74581 L
.88164 .74535 L
.88183 .74523 L
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
.88195 .74656 L
.88161 .74653 L
.88111 .74642 L
.88048 .74625 L
.87975 .74606 L
.87896 .74589 L
.87816 .74578 L
.87744 .74576 L
.87675 .74583 L
.87612 .74599 L
.87564 .74621 L
.87529 .74642 L
.87511 .74654 L
.87515 .74653 L
.87546 .74632 L
.87604 .74575 L
.87689 .74472 L
.87799 .74317 L
.87939 .74117 L
.88081 .73848 L
.88234 .73514 L
Mistroke
.88406 .73086 L
.88576 .72651 L
.88742 .72141 L
.88918 .71596 L
.89092 .71038 L
.89268 .70447 L
.89451 .69913 L
.89605 .69424 L
.89757 .68898 L
.89908 .68385 L
.90045 .67909 L
.90183 .67454 L
.90319 .66957 L
.90443 .66522 L
.90575 .66046 L
.90714 .6553 L
.90854 .65038 L
.90998 .64522 L
.9114 .63981 L
.9129 .63442 L
.91433 .62856 L
.91574 .62292 L
.91705 .61796 L
.91837 .61197 L
.91962 .60705 L
.92085 .60174 L
.92207 .59617 L
.92325 .59113 L
.92443 .58606 L
.9256 .58088 L
.92671 .57576 L
.92775 .5705 L
.92873 .56516 L
.92961 .55997 L
.93038 .55463 L
.93101 .54954 L
.93147 .54456 L
.93178 .54017 L
.93195 .536 L
.93198 .53228 L
.93189 .52904 L
.93169 .52617 L
.93143 .52353 L
.93114 .5213 L
.93084 .51918 L
.93057 .51711 L
.93032 .51504 L
.9301 .51278 L
.9299 .51025 L
.92971 .50768 L
Mistroke
.92951 .50481 L
.9293 .50192 L
.92906 .49879 L
.92879 .49556 L
.92849 .49224 L
.92816 .489 L
.92779 .48581 L
.92736 .48281 L
.92687 .48011 L
.92633 .4777 L
.92573 .47556 L
.92513 .47379 L
.92452 .4723 L
.92391 .47103 L
.92334 .47 L
.92281 .46914 L
.92231 .46843 L
.92188 .46786 L
.9215 .46739 L
.92122 .46699 L
.92105 .46662 L
.92098 .46631 L
.92098 .46608 L
.92101 .46596 L
.92103 .46594 L
.92098 .46604 L
.92084 .4663 L
.92055 .46672 L
.9201 .46731 L
.91948 .4681 L
.9187 .4691 L
.91776 .47031 L
.91681 .47165 L
.91571 .47321 L
.91437 .47498 L
.91306 .47686 L
.91158 .47892 L
.90999 .48109 L
.90843 .48322 L
.9068 .48538 L
.90531 .48751 L
.90382 .48954 L
.90243 .49163 L
.90121 .49371 L
.90005 .49584 L
.89889 .49816 L
.89789 .5004 L
.89699 .50286 L
.8962 .50536 L
.89554 .50805 L
Mistroke
.895 .51067 L
.89457 .51351 L
.89423 .5162 L
.89395 .51915 L
.8937 .52193 L
.89346 .52488 L
.89318 .52788 L
.89287 .5306 L
.89254 .53355 L
.89222 .53635 L
.89194 .53912 L
.8917 .54205 L
.89149 .54476 L
.89131 .54729 L
.89116 .54996 L
.89103 .55253 L
.89092 .55509 L
.89082 .55745 L
.89074 .5596 L
.89068 .56152 L
.89064 .56308 L
.89061 .56444 L
.89061 .56567 L
.8906 .56665 L
.89062 .56751 L
.89065 .56833 L
.89067 .56911 L
.89068 .56983 L
.89066 .57047 L
.89063 .57103 L
.89061 .5715 L
.89059 .57185 L
.89059 .57212 L
.89058 .57234 L
.89055 .5725 L
.8905 .57255 L
.89046 .57243 L
.89042 .57214 L
.89039 .57168 L
.89039 .57115 L
.89044 .57064 L
.89055 .57023 L
.89072 .57004 L
.89096 .57016 L
.89127 .57063 L
.89163 .57138 L
.89201 .57235 L
.89242 .57343 L
.89283 .57458 L
.89323 .57562 L
Mistroke
.89361 .57673 L
.89398 .5777 L
.89434 .57863 L
.89468 .57945 L
.89495 .58009 L
.89514 .58049 L
.89522 .58068 L
.89518 .58075 L
.89504 .58077 L
.89479 .58081 L
.89443 .58097 L
.89393 .58133 L
.8933 .58193 L
.89252 .58279 L
.8916 .58386 L
.89055 .58524 L
.88932 .58697 L
.88792 .58905 L
.88639 .59126 L
.88475 .59385 L
.88318 .59653 L
.8816 .59952 L
.88005 .60223 L
.87865 .60509 L
.87735 .60763 L
.8762 .61016 L
.87519 .61247 L
.87437 .6143 L
.87371 .61593 L
.87322 .61731 L
.87289 .61835 L
.87271 .61902 L
.87264 .61937 L
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
Mistroke
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
.87537 .61866 L
.87503 .61876 L
.87451 .61882 L
.8738 .61884 L
.87287 .61877 L
.87174 .61855 L
.87063 .61821 L
.86937 .6178 L
.86798 .61736 L
.86654 .61692 L
.86491 .61655 L
.8633 .61637 L
.8617 .6164 L
.85997 .61669 L
.85797 .61727 L
.85573 .61817 L
.85342 .61944 L
.85133 .62086 L
.84886 .62273 L
.84595 .62481 L
.843 .62715 L
.8398 .62968 L
.83624 .63237 L
.833 .63479 L
.8295 .63727 L
.82595 .63966 L
.82272 .64188 L
.81954 .64392 L
.81665 .64579 L
.81392 .64741 L
.81164 .64882 L
.80961 .65005 L
.80795 .6511 L
.80638 .65198 L
.80513 .65273 L
.80403 .65336 L
.80305 .65387 L
.80213 .65426 L
.80119 .65454 L
.80014 .65475 L
.79892 .65495 L
Mistroke
.7975 .65517 L
.79603 .65544 L
.79426 .65581 L
.79238 .65627 L
.79019 .65686 L
.78795 .65752 L
.78557 .6582 L
.7834 .65884 L
.78151 .65939 L
.77963 .65983 L
.77827 .66014 L
.7771 .66033 L
.77625 .66041 L
.77574 .66037 L
.77549 .66025 L
.77543 .66004 L
.77548 .65976 L
.77556 .65939 L
.77557 .65899 L
.77542 .6586 L
.77508 .65826 L
.77453 .65801 L
.77378 .65787 L
.77286 .65784 L
.77193 .65788 L
.77096 .65799 L
.77002 .65816 L
.76919 .65836 L
.76848 .65852 L
.76789 .65863 L
.76737 .65867 L
.76689 .65862 L
.76643 .65845 L
.76595 .65815 L
.7654 .65771 L
.76476 .65713 L
.76406 .65643 L
.7632 .65563 L
.7622 .65472 L
.76112 .65375 L
.75996 .6527 L
.75864 .65158 L
.75718 .6504 L
.75575 .64925 L
.75438 .6481 L
.75315 .647 L
.75213 .646 L
.75128 .64508 L
.75059 .64428 L
.75004 .6436 L
Mistroke
.74962 .64302 L
.74926 .64253 L
.74896 .64213 L
.74874 .64181 L
.7486 .64158 L
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
.74936 .642 L
.74929 .64162 L
.74916 .641 L
.74898 .64012 L
.74876 .63899 L
.74851 .63762 L
.74824 .63618 L
.74794 .63449 L
.74768 .63273 L
.74748 .63095 L
.74733 .62916 L
.7472 .62759 L
.74706 .62612 L
.74689 .62477 L
.74663 .62363 L
.74624 .62262 L
.74569 .62175 L
.74493 .62101 L
.74394 .62034 L
.74271 .61968 L
.7413 .61898 L
.73998 .61827 L
.73847 .61753 L
.73699 .61676 L
.73549 .61596 L
.73399 .61512 L
.73283 .61437 L
.73181 .61364 L
.73105 .61304 L
.73053 .61254 L
.73024 .61214 L
.73015 .61185 L
.73023 .61163 L
.73039 .61152 L
.7306 .61144 L
.73085 .61138 L
.73115 .61137 L
.73146 .6114 L
Mistroke
.73176 .61149 L
.732 .61163 L
.73217 .61178 L
.73221 .61191 L
.73207 .612 L
.73171 .61204 L
.73111 .61199 L
.73024 .61179 L
.72909 .61139 L
.72771 .61079 L
.72632 .60999 L
.72475 .60901 L
.7231 .60791 L
.72143 .60672 L
.71996 .60558 L
.71856 .6045 L
.71727 .60351 L
.71619 .60256 L
.71531 .60173 L
.71465 .60094 L
.71418 .60014 L
.71388 .5993 L
.71369 .59833 L
.71357 .59713 L
.7135 .59559 L
.71345 .59365 L
.71338 .59157 L
.71329 .58905 L
.7132 .58593 L
.71312 .5826 L
.71305 .57869 L
.71301 .57432 L
.713 .56983 L
.71302 .56522 L
.71305 .56039 L
.71309 .556 L
.71312 .55138 L
.7131 .54686 L
.71304 .54236 L
.71293 .538 L
.71277 .53393 L
.71259 .52992 L
.71241 .52617 L
.71222 .5229 L
.71201 .5199 L
.7118 .51741 L
.7116 .51522 L
.71144 .51353 L
.71134 .51204 L
.71135 .51068 L
Mistroke
.71154 .50936 L
.71193 .50812 L
.71254 .50693 L
.71342 .5055 L
.71459 .50385 L
.7161 .50177 L
.71783 .49948 L
.71977 .49675 L
.72183 .49343 L
.72412 .48986 L
.72629 .48587 L
.72854 .48184 L
.73047 .47796 L
.73228 .47402 L
.73383 .47015 L
.73519 .46668 L
.73618 .46338 L
.73693 .4606 L
.73747 .45829 L
.7378 .45625 L
.73796 .45452 L
.73802 .45306 L
.73801 .45181 L
.73799 .45062 L
.73803 .44944 L
.73817 .44815 L
.73844 .44664 L
.73889 .44481 L
.73954 .44281 L
.74037 .44037 L
.74139 .4375 L
.74261 .43403 L
.74397 .43035 L
.74553 .42654 L
.74724 .4224 L
.74906 .41793 L
.75101 .41362 L
.75304 .40917 L
.75516 .40459 L
.75732 .40026 L
.75944 .39595 L
.76179 .3913 L
.76398 .3872 L
.76636 .38285 L
.76882 .37852 L
.77151 .37398 L
.77416 .37019 L
.77705 .36622 L
.7802 .3623 L
.78339 .35883 L
Mistroke
.78692 .35536 L
.79042 .35204 L
.79437 .34893 L
.798 .34591 L
.8021 .3431 L
.80618 .34042 L
.81 .33788 L
.81397 .3355 L
.81785 .33323 L
.82178 .33098 L
.82532 .32884 L
.82876 .32677 L
.83242 .3247 L
.83556 .32279 L
.83867 .3209 L
.84188 .31914 L
.84493 .31747 L
.84813 .31588 L
.85115 .31449 L
.85453 .31317 L
.85798 .312 L
.86174 .31095 L
.86528 .31003 L
.86905 .30927 L
.87325 .30866 L
.87664 .30819 L
.88041 .30788 L
.88378 .3077 L
.88711 .30763 L
.88999 .30764 L
.8925 .30771 L
.89441 .3078 L
.89606 .30789 L
.89739 .30797 L
.89833 .30803 L
.8989 .30807 L
.89917 .30807 L
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
Mistroke
.89837 .30859 L
.89833 .30856 L
.89831 .30843 L
.8983 .30815 L
.89829 .30769 L
.89825 .30698 L
.89814 .30596 L
.89793 .30467 L
.89762 .30302 L
.8972 .30105 L
.89664 .29877 L
.89594 .29623 L
.8951 .29331 L
.89418 .29075 L
.89313 .28762 L
.89199 .28506 L
.89079 .28241 L
.88956 .27986 L
.88836 .27774 L
.88713 .27581 L
.88591 .27422 L
.88467 .27288 L
.88354 .27181 L
.88244 .27092 L
.88137 .2702 L
.88033 .26962 L
.87933 .26911 L
.87838 .26864 L
.87759 .26822 L
.8768 .26786 L
.87613 .26752 L
.87554 .26719 L
.87505 .26688 L
.87464 .26661 L
.87435 .26637 L
.87416 .26619 L
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
Mistroke
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
.87346 .26838 L
.87324 .26836 L
.87287 .26841 L
.87232 .26857 L
.87166 .26883 L
.87086 .26921 L
.86995 .26966 L
.86897 .27015 L
.86804 .27061 L
.86714 .271 L
.86633 .27131 L
.86564 .27151 L
.86513 .27158 L
.86477 .27155 L
.86457 .27146 L
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
Mistroke
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
.86948 .27075 L
.86948 .27033 L
.86951 .26963 L
.86952 .26857 L
.86948 .26713 L
.86933 .26525 L
.86905 .26295 L
.86855 .26019 L
.86783 .25705 L
.86689 .25369 L
.86571 .24979 L
.86426 .24612 L
.86265 .24196 L
.86086 .2376 L
.85892 .23332 L
.85684 .22913 L
.85472 .22519 L
.85259 .22146 L
.8505 .21802 L
.84859 .21517 L
.84695 .21261 L
.84538 .21041 L
.84418 .20879 L
.8432 .20748 L
.84247 .2065 L
.84199 .20584 L
.84172 .20548 L
.84159 .20536 L
.84154 .20536 L
.84147 .20531 L
.84131 .2051 L
.84093 .20459 L
.84027 .20369 L
.83927 .20234 L
.83789 .20042 L
.8362 .19813 L
.83411 .19531 L
.83156 .19184 L
.82915 .18835 L
Mistroke
.82613 .18388 L
.82313 .17998 L
.81989 .17543 L
.81643 .17067 L
.81302 .1658 L
.81 .16142 L
.80675 .15681 L
.80338 .15196 L
.8004 .14762 L
.79753 .14376 L
.79452 .1397 L
.79153 .13591 L
.78823 .13209 L
.78516 .12902 L
.78179 .12598 L
.77838 .12286 L
.77537 .12047 L
.77175 .1182 L
.76859 .11606 L
.76532 .11417 L
.76244 .11253 L
.75954 .1112 L
.7571 .11029 L
.75527 .10958 L
.75381 .1091 L
.75279 .10883 L
.75216 .10867 L
.75188 .1086 L
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
Mistroke
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
.75677 .10992 L
.7564 .1099 L
.75594 .10987 L
.75541 .10986 L
.75482 .1099 L
.75421 .11002 L
.75359 .11021 L
.75298 .11047 L
.75238 .11078 L
.75183 .11112 L
.7514 .11144 L
.75113 .11173 L
.75107 .11195 L
.75118 .11209 L
.7514 .11214 L
.75166 .11207 L
.75183 .11183 L
.75179 .11142 L
.75142 .11078 L
.75064 .1099 L
.74937 .10876 L
.74752 .10736 L
.74504 .10576 L
.74237 .10393 L
.73908 .10199 L
.73509 .09995 L
.73108 .09784 L
.72641 .09564 L
.72084 .09335 L
.71607 .09099 L
.71062 .08855 L
.70465 .086 L
.69923 .0836 L
.69285 .0811 L
.6877 .07868 L
.68187 .07632 L
.67547 .07389 L
.67027 .07158 L
.66432 .06922 L
.65827 .0668 L
.65263 .06448 L
.64681 .06207 L
.64059 .05976 L
.63535 .05754 L
.62946 .05527 L
.62443 .05319 L
.61915 .05107 L
Mistroke
.61416 .04912 L
.60928 .04717 L
.60447 .04534 L
.59964 .04361 L
.59514 .04209 L
.5907 .04071 L
.5863 .03951 L
.58241 .03852 L
.57857 .03771 L
.57511 .03705 L
.57164 .03654 L
.56871 .03616 L
.56572 .03588 L
.56251 .0357 L
.55965 .03559 L
.55658 .03553 L
.55326 .03549 L
.54969 .03545 L
.54656 .03541 L
.54272 .03535 L
.5389 .03525 L
.53466 .03511 L
.52981 .03497 L
.52536 .03481 L
.5204 .03465 L
.51522 .03448 L
.51043 .03432 L
.50528 .03417 L
.50113 .03403 L
.49665 .0339 L
.49297 .03378 L
.48934 .03367 L
.48628 .03356 L
.48323 .03346 L
.48095 .03337 L
.479 .0333 L
.47744 .03325 L
.47625 .03324 L
.47544 .03325 L
.4749 .03328 L
.47461 .03332 L
.47448 .03336 L
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
Mistroke
.47595 .03318 L
.47598 .03325 L
.47592 .03343 L
.47577 .03373 L
.47553 .03416 L
.4752 .03472 L
.47478 .03539 L
.47426 .03613 L
.47366 .03695 L
.473 .03781 L
.47231 .03866 L
.47165 .03945 L
.47103 .04016 L
.47048 .04077 L
.47001 .04128 L
.46963 .04165 L
.46935 .0419 L
.46918 .04203 L
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
.46913 .0413 L
.46928 .04167 L
.46952 .04226 L
.46987 .04311 L
.47032 .04426 L
.4709 .04574 L
.47159 .04742 L
.47244 .04961 L
.47344 .05196 L
.47461 .05473 L
.47592 .05773 L
.47733 .06102 L
.4788 .06409 L
.48031 .06749 L
.48176 .07086 L
.48318 .07429 L
Mistroke
.48451 .07753 L
.48577 .08068 L
.48696 .0837 L
.48802 .0864 L
.489 .08886 L
.48986 .09079 L
.49059 .09249 L
.49118 .09376 L
.49161 .09477 L
.49188 .09552 L
.49198 .09613 L
.49193 .09669 L
.49175 .09733 L
.49144 .09816 L
.49101 .09925 L
.49046 .10063 L
.4898 .10233 L
.48907 .10401 L
.48825 .1062 L
.48738 .10843 L
.48649 .11093 L
.48569 .11345 L
.48494 .11558 L
.48429 .11761 L
.48377 .11944 L
.48338 .12087 L
.48313 .12195 L
.483 .12264 L
.483 .12298 L
.48313 .12309 L
.48341 .12312 L
.48386 .12321 L
.48454 .12342 L
.48548 .12382 L
.48672 .12447 L
.48825 .12536 L
.49007 .12651 L
.4922 .12793 L
.4945 .12952 L
.49693 .13133 L
.49943 .13316 L
.50196 .13505 L
.50436 .13685 L
.50667 .13849 L
.50858 .13983 L
.51026 .14088 L
.51161 .14163 L
.51259 .14206 L
.51325 .14227 L
.51362 .1423 L
Mistroke
.51372 .14224 L
.51361 .14221 L
.51337 .14229 L
.51306 .14259 L
.51275 .14318 L
.51249 .14417 L
.51233 .14552 L
.51225 .14752 L
.51223 .14995 L
.51227 .15296 L
.51232 .15642 L
.51236 .16036 L
.51233 .16478 L
.51223 .16897 L
.51203 .17367 L
.51174 .17851 L
.51136 .18368 L
.5109 .18825 L
.51037 .19348 L
.50979 .19761 L
.50918 .20216 L
.50858 .20595 L
.508 .2095 L
.50747 .21312 L
.50701 .21563 L
.50665 .21774 L
.5064 .2194 L
.50627 .22061 L
.50624 .22136 L
.50628 .22169 L
.50632 .2217 L
.5063 .22154 L
.50616 .22134 L
.50582 .22123 L
.50525 .22128 L
.5044 .2216 L
.50326 .22229 L
.50178 .22336 L
.49997 .22468 L
.49802 .22606 L
.49577 .22761 L
.49331 .2292 L
.49087 .23073 L
.48833 .23223 L
.48597 .23364 L
.48386 .2348 L
.48198 .23572 L
.48045 .23636 L
.47934 .23675 L
.4786 .23689 L
Mistroke
.47822 .2368 L
.47822 .23661 L
.47858 .23643 L
.47927 .2364 L
.48031 .23667 L
.48167 .23734 L
.48328 .2384 L
.48511 .23988 L
.48704 .2417 L
.48901 .24381 L
.49097 .24627 L
.49291 .24888 L
.49468 .25108 L
.49642 .25358 L
.49795 .25576 L
.49935 .25821 L
.50052 .26016 L
.50145 .262 L
.50207 .2637 L
.50237 .26529 L
.50232 .26691 L
.50198 .2687 L
.50138 .27075 L
.50057 .27287 L
.49963 .27531 L
.49858 .27817 L
.49749 .28149 L
.49639 .28463 L
.49524 .28819 L
.49411 .29157 L
.49302 .29502 L
.49205 .29818 L
.49127 .30081 L
.49067 .30316 L
.49023 .30507 L
.48993 .30647 L
.48973 .30752 L
.48953 .30833 L
.48922 .30895 L
.4887 .30945 L
.48795 .30989 L
.4869 .31033 L
.48547 .31078 L
.4836 .31126 L
.48159 .31183 L
.47904 .31244 L
.47619 .31314 L
.47275 .31393 L
.46938 .31481 L
.46534 .31574 L
Mistroke
.46185 .31669 L
.45785 .31768 L
.4537 .3187 L
.44902 .3197 L
.44506 .32068 L
.44051 .32164 L
.43609 .32255 L
.43142 .32339 L
.42628 .32412 L
.42186 .3247 L
.41702 .32513 L
.41157 .32538 L
.40725 .32542 L
.40225 .32522 L
.39751 .32477 L
.39297 .32404 L
.38799 .32304 L
.3841 .32178 L
.3799 .32034 L
.37637 .31875 L
.37286 .3171 L
.36999 .3155 L
.36713 .31399 L
.36502 .3126 L
.36318 .31131 L
.36163 .31021 L
.36041 .30926 L
.35957 .30851 L
.3591 .30799 L
.35891 .30775 L
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
Mistroke
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
Mistroke
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
Mistroke
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
.36221 .31241 L
.36216 .31249 L
.36206 .31266 L
.36193 .31291 L
.36175 .31326 L
.36154 .31365 L
.36131 .31405 L
.36107 .31442 L
.36083 .31476 L
.36059 .31504 L
.36035 .31526 L
.36014 .31541 L
.35995 .31546 L
.35981 .31542 L
.35972 .31529 L
.35969 .3151 L
.35972 .31485 L
.3598 .31454 L
.35994 .31413 L
.36008 .31375 L
.36018 .31334 L
Mistroke
.36022 .31297 L
.36015 .31264 L
.35997 .31232 L
.35964 .31198 L
.35914 .31161 L
.35845 .31118 L
.35759 .31063 L
.35653 .30998 L
.35528 .30922 L
.35385 .30837 L
.3523 .30741 L
.35052 .30634 L
.34851 .30519 L
.34623 .30386 L
.3439 .30245 L
.34126 .30085 L
.3386 .29907 L
.33581 .29723 L
.3327 .29515 L
.32989 .29303 L
.32669 .2909 L
.32327 .28854 L
.31991 .28632 L
.31602 .28392 L
.31286 .28141 L
.30942 .27905 L
.30593 .27658 L
.30329 .27451 L
.30057 .27257 L
.29836 .27087 L
.29642 .26955 L
.29479 .26835 L
.29366 .26757 L
.29284 .26695 L
.29231 .2665 L
.29213 .26621 L
.29224 .26615 L
.29257 .26627 L
.29304 .26655 L
.29355 .2669 L
.29403 .26724 L
.29446 .26755 L
.29481 .26779 L
.29508 .26793 L
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
Mistroke
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
Mistroke
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
.29774 .27233 L
.29744 .27233 L
.297 .27233 L
.29642 .27236 L
.29571 .27241 L
.29488 .27249 L
.29391 .27256 L
.29281 .27261 L
.29152 .27264 L
.29002 .27262 L
.2883 .27253 L
.2865 .27233 L
.28445 .27201 L
.28214 .27156 L
.27992 .27098 L
.2774 .27025 L
.27476 .26942 L
.2718 .26847 L
.26916 .26738 L
.26614 .26615 L
.26311 .2648 L
.25988 .26338 L
.25664 .2618 L
.25397 .26017 L
.25135 .25843 L
.24893 .25677 L
.24683 .25512 L
.24501 .25347 L
.24357 .252 L
.24224 .25052 L
.24116 .24916 L
.24013 .24778 L
.2392 .24664 L
.23809 .24555 L
.23678 .24448 L
.2352 .24343 L
.23329 .24238 L
Mistroke
.23113 .24133 L
.22924 .24033 L
.22673 .23919 L
.22389 .2379 L
.22084 .23645 L
.21729 .23475 L
.21384 .23295 L
.20989 .23076 L
.20666 .2287 L
.20311 .2264 L
.1998 .22404 L
.1964 .22147 L
.19357 .21924 L
.19074 .21685 L
.18801 .21432 L
.18566 .21217 L
.18346 .20991 L
.18146 .20772 L
.17973 .20559 L
.1783 .20362 L
.17718 .2017 L
.17639 .20004 L
.17587 .19852 L
.1756 .19716 L
.17552 .19601 L
.1756 .19493 L
.1758 .19403 L
.17608 .19327 L
.17639 .19267 L
.17671 .19223 L
.17699 .19195 L
.17723 .19181 L
.1774 .19178 L
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
.17717 .19235 L
.17739 .19212 L
.17776 .19179 L
.17827 .19136 L
.17894 .19083 L
Mistroke
.17977 .1902 L
.18076 .18947 L
.18198 .1886 L
.18337 .18759 L
.18498 .18644 L
.18666 .1852 L
.18846 .18387 L
.19028 .18254 L
.19201 .18125 L
.19366 .18 L
.19511 .17883 L
.19638 .17783 L
.19745 .17688 L
.19829 .17609 L
.19895 .1754 L
.19945 .17484 L
.1998 .17444 L
.20002 .1742 L
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
.19939 .17468 L
.19942 .17415 L
.19954 .17336 L
.19976 .17229 L
.2001 .17092 L
.20055 .16947 L
.20112 .16764 L
.20176 .16577 L
.20249 .1637 L
.20331 .1614 L
.20422 .15928 L
.20525 .15688 L
.20645 .15459 L
.20775 .15237 L
.20918 .15004 L
.21074 .14787 L
.21237 .14572 L
.2141 .14357 L
.21579 .14178 L
.21747 .13999 L
.21913 .13828 L
.2207 .13678 L
.22229 .13528 L
.2237 .13407 L
.22503 .13301 L
Mistroke
.22624 .13213 L
.2273 .13147 L
.22822 .13099 L
.22904 .13068 L
.22982 .13051 L
.23067 .13041 L
.23167 .13036 L
.23291 .13031 L
.23446 .13025 L
.23629 .13016 L
.23842 .13008 L
.24087 .13 L
.24343 .12996 L
.24598 .12994 L
.24855 .12995 L
.25103 .12997 L
.25345 .12999 L
.25558 .13002 L
.25743 .13005 L
.25912 .1301 L
.26051 .13018 L
.26162 .13029 L
.26245 .13042 L
.26301 .13059 L
.26336 .1308 L
.26357 .13105 L
.26369 .13135 L
.26376 .13166 L
.26382 .132 L
.26394 .13233 L
.2641 .13263 L
.26425 .13288 L
.26438 .13307 L
.26448 .13321 L
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
Mistroke
.26484 .13259 L
.26501 .1324 L
.26517 .13216 L
.26527 .1319 L
.26522 .13168 L
.26496 .13152 L
.26444 .13145 L
.2636 .13151 L
.26239 .13174 L
.26077 .13219 L
.25884 .13286 L
.25642 .1338 L
.25336 .13497 L
.25024 .13631 L
.24633 .13787 L
.24219 .13953 L
.23816 .14135 L
.23315 .1433 L
.22886 .14532 L
.22362 .14752 L
.2191 .14972 L
.21422 .15209 L
.20907 .15463 L
.2047 .1574 L
.20006 .16023 L
.19586 .16327 L
.19157 .16663 L
.18789 .17012 L
.18423 .17388 L
.18076 .17791 L
.17761 .18211 L
.17462 .18644 L
.17166 .19099 L
.16879 .19569 L
.16585 .20069 L
.16301 .20544 L
.15997 .21054 L
.15698 .21606 L
.15412 .22085 L
.15095 .22622 L
.14786 .23151 L
.14451 .23706 L
.14148 .24224 L
.1383 .2475 L
.13529 .25286 L
.13233 .25768 L
.12927 .26285 L
.12656 .26755 L
.12363 .27229 L
.12087 .27693 L
Mistroke
.11802 .28164 L
.11516 .28656 L
.11238 .29107 L
.10949 .29604 L
.10691 .30078 L
.1042 .30575 L
.10184 .31055 L
.09955 .31546 L
.09746 .32029 L
.09552 .32555 L
.09384 .33005 L
.09231 .33494 L
.09097 .33987 L
.08983 .34509 L
.08887 .35024 L
.08804 .35564 L
.08736 .36104 L
.08674 .36695 L
.08619 .37231 L
.08571 .37741 L
.0853 .3828 L
.08495 .38737 L
.08466 .39187 L
.0844 .39632 L
.08416 .39955 L
.08393 .40236 L
.0838 .40412 L
.08372 .4059 L
.08376 .40723 L
.08396 .40815 L
.08429 .40867 L
.08475 .40903 L
.0854 .40935 L
.08637 .40975 L
.08761 .41023 L
.08867 .41089 L
.09005 .4119 L
.09098 .41324 L
.09239 .41486 L
.09365 .41678 L
.09476 .41888 L
.09572 .42141 L
.09661 .42413 L
.09731 .42719 L
.09774 .43094 L
.09792 .43439 L
.09783 .43803 L
.09751 .44165 L
.09696 .44573 L
.09615 .45059 L
Mistroke
.09499 .45443 L
.09351 .45861 L
.09211 .46291 L
.09044 .46722 L
.0882 .47147 L
.08635 .47535 L
.08415 .47927 L
.08236 .48294 L
.07994 .48682 L
.07807 .48999 L
.07647 .49295 L
.0747 .49627 L
.07337 .49885 L
.07225 .50148 L
.0714 .50378 L
.07085 .50581 L
.07052 .50755 L
.07038 .50891 L
.07036 .51002 L
.07043 .51099 L
.07054 .51181 L
.07065 .51253 L
.0707 .51307 L
.07074 .51357 L
.07079 .51399 L
.07079 .51434 L
.07076 .51462 L
.07072 .51484 L
.07067 .51509 L
.07059 .51538 L
.07047 .51569 L
.0703 .51604 L
.07015 .5163 L
.07003 .51652 L
.06998 .51667 L
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
Mistroke
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
.07318 .51663 L
.07301 .51698 L
.07279 .51749 L
.07253 .51815 L
.07224 .51894 L
.07194 .51985 L
.07161 .52087 L
.07134 .52197 L
.07102 .52322 L
.07069 .5246 L
.07037 .52614 L
.07009 .52765 L
.06988 .52927 L
.06976 .53097 L
.06972 .5327 L
.06977 .53424 L
.06989 .5358 L
.07006 .53737 L
.07027 .53888 L
.0705 .5403 L
.07073 .54162 L
.07095 .54278 L
.07118 .54373 L
.07141 .5445 L
.07163 .5451 L
.07182 .54551 L
.07199 .54575 L
Mistroke
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
.07476 .5472 L
Mistroke
.07474 .54703 L
.07467 .54694 L
.07459 .54704 L
.07449 .54742 L
.07441 .5481 L
.07434 .54915 L
.0743 .55066 L
.07429 .55269 L
.07433 .5548 L
.07442 .55739 L
.07458 .56084 L
.07481 .56386 L
.0751 .56809 L
.07544 .57215 L
.07584 .57649 L
.0763 .58022 L
.07682 .58473 L
.07732 .58971 L
.07787 .59382 L
.07846 .59836 L
.07909 .60313 L
.0797 .60776 L
.08035 .61312 L
.08106 .61713 L
.08172 .62207 L
.08244 .62822 L
.08321 .63271 L
.08394 .63873 L
.08485 .64356 L
.08565 .65021 L
.08651 .65577 L
.08748 .66073 L
.08839 .66645 L
.08938 .67323 L
.09047 .67815 L
.09142 .68389 L
.09249 .68981 L
.09355 .69606 L
.09467 .7017 L
.09575 .70612 L
.09692 .7113 L
.09793 .71536 L
.09899 .71999 L
.09986 .72305 L
.10067 .72607 L
.10138 .7287 L
.10193 .73053 L
.10236 .73195 L
.10269 .73301 L
.10291 .73368 L
Mistroke
.10305 .73396 L
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
.10239 .73886 L
.10242 .73908 L
.10253 .73941 L
.10276 .73984 L
.10311 .74035 L
.1036 .74092 L
.10426 .74155 L
.10505 .74228 L
.10579 .74316 L
.10677 .74411 L
.10778 .74518 L
.109 .74655 L
.11037 .74775 L
.11155 .74921 L
.11279 .75072 L
.11422 .75191 L
.1156 .75371 L
.11723 .7553 L
.11864 .75709 L
.1202 .75928 L
.12218 .76139 L
.12406 .76388 L
.12612 .76654 L
.12842 .76929 L
.13081 .77232 L
.13347 .77562 L
.13621 .77848 L
.13908 .78196 L
.14208 .7852 L
.14523 .78894 L
.14846 .79261 L
.15192 .79643 L
.15546 .8002 L
.15923 .80394 L
.16302 .80782 L
.16702 .81167 L
.17142 .81604 L
Mistroke
.17552 .81976 L
.17996 .82404 L
.18445 .8284 L
.18895 .83282 L
.1936 .83737 L
.19852 .84209 L
.20298 .84659 L
.20768 .85112 L
.21233 .8557 L
.21706 .86041 L
.22138 .86481 L
.22582 .86921 L
.2301 .87348 L
.23407 .87765 L
.23812 .88144 L
.24185 .88487 L
.2455 .88822 L
.24916 .89113 L
.25256 .8939 L
.25604 .89646 L
.25938 .89859 L
.26275 .90057 L
.26626 .90235 L
.26967 .90399 L
.27342 .90553 L
.27693 .90689 L
.28066 .90831 L
.28428 .90967 L
.28798 .91107 L
.29177 .91246 L
.29569 .91389 L
.29999 .91529 L
.3039 .91671 L
.30829 .91819 L
.31279 .91964 L
.31784 .92119 L
.3222 .92281 L
.3273 .92458 L
.33262 .92639 L
.33768 .92838 L
.34314 .93036 L
.34871 .93242 L
.35499 .93454 L
.36004 .93664 L
.36584 .93881 L
.37172 .94091 L
.37703 .94296 L
.38257 .94493 L
.38806 .94676 L
.39337 .94849 L
Mistroke
.39865 .95009 L
.40389 .95163 L
.40895 .95315 L
.41427 .9546 L
.41916 .95608 L
.42428 .95755 L
.42935 .95897 L
.4342 .9604 L
.43902 .96172 L
.44374 .96294 L
.44847 .964 L
.45299 .96494 L
.45753 .96568 L
.46207 .96621 L
.46665 .96655 L
.47132 .96669 L
.47589 .96664 L
.48053 .96646 L
.48501 .96612 L
.48939 .96568 L
.49362 .96515 L
.49773 .96461 L
.50145 .96409 L
.50496 .96361 L
.50819 .96319 L
.51081 .96285 L
.51308 .96259 L
.5149 .96238 L
.51625 .96221 L
.51721 .96209 L
.51784 .96199 L
.51824 .96191 L
.51843 .96185 L
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
.5178 .96202 L
.51818 .96205 L
.5189 .96203 L
.52007 .96198 L
.52174 .96188 L
.52385 .96176 L
.52605 .96159 L
.52895 .96135 L
.53246 .961 L
.5365 .96054 L
.54102 .95997 L
Mistroke
.54588 .95926 L
.55101 .95844 L
.55654 .95753 L
.56209 .95658 L
.56794 .95559 L
.57356 .95453 L
.57965 .95342 L
.58535 .95231 L
.59129 .95112 L
.5977 .9499 L
.60335 .94865 L
.60941 .94741 L
.61567 .9462 L
.6215 .945 L
.62739 .94383 L
.63329 .94266 L
.63863 .94158 L
.64378 .94051 L
.64839 .93936 L
.65265 .93846 L
.65616 .93761 L
.65939 .93692 L
.66212 .93635 L
.6645 .93587 L
.66675 .93542 L
.66891 .93491 L
.67107 .93428 L
.67334 .93347 L
.67573 .93245 L
.67841 .93126 L
.68115 .92978 L
.68437 .92803 L
.68769 .92627 L
.69145 .92415 L
.69537 .92184 L
.69935 .91947 L
.70359 .91684 L
.7073 .9144 L
.71111 .91188 L
.71453 .90955 L
.71767 .90737 L
.7204 .90543 L
.72277 .90369 L
.72472 .90222 L
.72637 .90094 L
.72766 .89982 L
.72871 .89884 L
.72952 .898 L
.73011 .89733 L
.73049 .89679 L
Mistroke
.73074 .89635 L
.73089 .89603 L
.73098 .89582 L
.73105 .89565 L
.73112 .89553 L
.7312 .89545 L
.73133 .89537 L
.73148 .8953 L
.73164 .89524 L
.73177 .89518 L
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
.73191 .89524 L
.73219 .89506 L
.73254 .8948 L
.73296 .89447 L
.73345 .89405 L
.734 .89356 L
.73465 .89301 L
.73536 .89241 L
.73611 .89178 L
.73684 .8911 L
.73752 .89041 L
.73809 .88973 L
.73852 .88905 L
.7388 .88848 L
.73894 .888 L
.73894 .88764 L
.73885 .88742 L
.7387 .88729 L
.73852 .88722 L
.73836 .88719 L
.73822 .88713 L
.73811 .88704 L
.73804 .8869 L
.73807 .88669 L
.73824 .88642 L
.73862 .88607 L
.7392 .88565 L
.74002 .88512 L
Mistroke
.74108 .88447 L
.74237 .8837 L
.74394 .88278 L
.74577 .88167 L
.74791 .88042 L
.75042 .87902 L
.75322 .87746 L
.75643 .87575 L
.7599 .87384 L
.76376 .87165 L
.76769 .8693 L
.772 .86662 L
.77635 .86365 L
.78077 .86059 L
.78559 .85725 L
.78988 .85392 L
.79429 .85039 L
.79862 .84699 L
.80302 .84317 L
.80702 .84001 L
.81109 .83664 L
.81493 .83322 L
.8187 .83009 L
.82239 .8268 L
.82602 .8238 L
.82965 .82069 L
.83319 .81784 L
.83678 .81487 L
.84011 .81219 L
.84331 .80961 L
.84633 .80716 L
.84901 .80499 L
.85157 .80313 L
.85356 .80158 L
.8551 .80026 L
.85646 .79915 L
.85748 .7983 L
.85829 .79762 L
.85887 .79718 L
.85924 .79698 L
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
Mistroke
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
.86125 .79251 L
.86134 .79209 L
.86141 .79144 L
.86148 .7905 L
.86158 .78921 L
.8617 .78764 L
.86185 .78567 L
.86201 .78342 L
.86217 .78088 L
.86234 .77835 L
.86249 .77563 L
.86263 .77291 L
.86274 .77034 L
.86283 .76786 L
.86289 .76578 L
.86291 .76395 L
.8629 .76238 L
Mistroke
.86287 .76117 L
.86282 .76019 L
.86278 .75953 L
.86275 .75908 L
.86276 .75883 L
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
.85723 .75963 L
.85739 .75962 L
.85756 .7596 L
.85772 .75959 L
.85788 .75958 L
.85805 .75959 L
.85821 .75964 L
.85838 .75973 L
.85854 .75985 L
.85869 .75998 L
.85884 .76008 L
.85902 .76012 L
.85923 .76006 L
.85952 .75988 L
Mistroke
.85991 .75952 L
.86045 .75894 L
.86118 .7581 L
.86215 .75694 L
.86338 .7554 L
.86487 .75338 L
.86662 .75091 L
.86853 .74803 L
.87066 .74468 L
.87289 .74098 L
.87532 .73689 L
.87768 .7327 L
.88028 .72808 L
.88251 .72346 L
.88506 .71849 L
.88763 .71324 L
.88983 .70793 L
.89222 .70244 L
.89433 .69673 L
.89648 .69089 L
.89858 .68455 L
.90059 .67892 L
.90267 .67266 L
.90456 .66657 L
.90661 .65994 L
.90846 .65324 L
.91031 .64634 L
.91212 .64015 L
.9139 .63344 L
.91562 .62667 L
.9173 .6198 L
.91895 .6123 L
.92057 .60594 L
.92214 .5989 L
.92365 .59182 L
.92507 .58468 L
.92642 .57833 L
.92765 .57204 L
.92883 .56568 L
.92979 .56089 L
.93066 .55642 L
.93136 .5525 L
.93192 .54952 L
.93233 .54718 L
.93261 .5456 L
.93276 .54468 L
.93284 .5443 L
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
Mistroke
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
.93278 .54769 L
.93278 .54709 L
.93273 .54594 L
.93263 .54421 L
.93246 .54186 L
.93221 .53885 L
.93188 .53509 L
.93146 .53052 L
.93095 .5255 L
.93038 .51955 L
.92976 .51342 L
.92908 .50669 L
.92837 .49945 L
.92764 .4923 L
.9269 .48496 L
.92617 .47773 L
.92545 .46983 L
.92479 .46302 L
.92418 .45617 L
.92362 .4495 L
.92312 .44303 L
.92266 .43661 L
.92225 .43089 L
.92185 .42528 L
.92146 .42002 L
.92104 .41493 L
.9206 .40993 L
.92012 .40497 L
.91959 .39988 L
.919 .39503 L
.91836 .38992 L
.91765 .38476 L
.91688 .37915 L
.91606 .37397 L
.91517 .36837 L
.91423 .36248 L
.91329 .35698 L
.91237 .35141 L
.91152 .34622 L
.91074 .3413 L
.91007 .33716 L
.90951 .33349 L
.90906 .33037 L
.90873 .32783 L
.90851 .32593 L
.90841 .3245 L
Mistroke
.90838 .32346 L
.9084 .32265 L
.90843 .32195 L
.90841 .32119 L
.90828 .32017 L
.90796 .3188 L
.90745 .317 L
.90671 .31503 L
.90574 .31255 L
.90453 .30956 L
.90309 .30626 L
.9015 .30252 L
.89973 .29898 L
.8978 .29522 L
.89573 .29134 L
.89351 .28753 L
.89133 .28386 L
.88901 .28008 L
.88665 .27637 L
.88426 .27263 L
.88187 .26884 L
.87941 .26497 L
.87687 .26098 L
.87421 .25665 L
.87151 .25245 L
.86862 .24758 L
.86573 .24314 L
.86274 .23849 L
.85971 .23367 L
.85665 .22893 L
.85355 .22404 L
.85044 .21936 L
.84733 .21466 L
.84417 .20982 L
.8411 .20536 L
.83805 .20076 L
.83502 .19645 L
.83199 .19208 L
.82905 .18794 L
.8261 .18384 L
.82311 .17958 L
.82007 .17567 L
.81705 .17171 L
.81392 .16761 L
.81072 .16348 L
.80733 .15916 L
.80426 .15513 L
.80096 .15098 L
.79766 .14677 L
.79471 .14294 L
Mistroke
.79165 .13905 L
.78875 .1353 L
.78598 .13192 L
.78354 .12881 L
.78131 .12609 L
.77945 .12382 L
.77794 .12205 L
.77672 .12071 L
.77581 .1198 L
.77516 .11925 L
.77471 .11897 L
.77444 .11893 L
.77432 .11905 L
.77431 .11928 L
.77438 .11958 L
.77448 .11991 L
.77462 .12023 L
.77475 .12052 L
.77486 .12075 L
.77494 .12091 L
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
.77555 .12105 L
.77547 .1208 L
.77524 .12046 L
.77481 .12003 L
.77415 .11953 L
.77324 .11897 L
.7721 .11834 L
.77074 .11769 L
.7692 .11701 L
.76759 .11631 L
.76585 .11568 L
.76404 .11517 L
.76208 .1148 L
.76005 .11459 L
Mistroke
.75797 .11455 L
.75599 .11465 L
.75411 .11487 L
.75237 .11516 L
.7509 .11551 L
.74981 .11588 L
.74892 .11623 L
.74812 .11653 L
.74745 .11671 L
.74683 .11676 L
.74621 .11657 L
.74555 .11612 L
.74483 .11536 L
.74399 .11426 L
.74287 .11282 L
.74143 .11103 L
.73955 .10892 L
.73733 .10686 L
.73442 .1045 L
.73113 .10201 L
.72699 .09934 L
.72253 .09649 L
.71733 .09364 L
.71228 .09073 L
.70662 .08779 L
.70054 .08481 L
.69471 .08196 L
.68856 .07914 L
.68237 .07646 L
.67591 .07375 L
.67005 .07122 L
.66402 .06869 L
.65772 .0662 L
.65181 .06366 L
.64647 .0614 L
.64071 .05907 L
.63503 .0568 L
.62904 .0545 L
.62354 .05243 L
.61816 .05031 L
.61272 .04832 L
.60711 .04633 L
.6018 .04446 L
.59618 .04279 L
.59089 .04122 L
.58563 .0398 L
.58052 .03859 L
.57538 .03761 L
.57083 .03684 L
.56609 .03627 L
Mistroke
.56191 .03585 L
.55735 .03555 L
.55338 .03534 L
.54912 .03521 L
.54486 .03512 L
.5404 .03504 L
.53579 .03497 L
.53099 .03489 L
.52596 .03478 L
.52079 .03465 L
.51539 .03448 L
.50971 .0343 L
.50365 .03412 L
.49798 .03392 L
.49191 .03371 L
.48577 .03347 L
.47953 .03321 L
.47344 .03295 L
.46749 .03274 L
.46138 .03258 L
.45595 .0325 L
.45032 .03251 L
.44486 .0326 L
.43937 .03276 L
.43417 .03299 L
.42902 .03326 L
.42387 .03356 L
.4191 .03386 L
.41422 .03415 L
.40985 .0344 L
.40562 .0346 L
.40142 .03477 L
.39816 .03489 L
.39512 .03498 L
.39232 .03503 L
.38998 .03504 L
.38788 .03503 L
.38602 .03505 L
.38432 .03516 L
.38261 .03544 L
.38079 .03592 L
.37882 .03664 L
.37648 .0376 L
.37363 .03884 L
.37062 .04037 L
.36697 .04217 L
.36295 .04425 L
.35866 .04641 L
.354 .04876 L
.34885 .05141 L
Mistroke
.34402 .05401 L
.33882 .05683 L
.33361 .05975 L
.32812 .06285 L
.32319 .06583 L
.31806 .0689 L
.31301 .07192 L
.30784 .07502 L
.30304 .07787 L
.29773 .08089 L
.2927 .08401 L
.28785 .08707 L
.28222 .09036 L
.2773 .09364 L
.27184 .09703 L
.26636 .10045 L
.26086 .10386 L
.25531 .10731 L
.2503 .1107 L
.24503 .11405 L
.23987 .1174 L
.23452 .12084 L
.23 .12407 L
.22538 .12739 L
.22105 .13067 L
.21695 .13394 L
.21315 .13724 L
.20948 .1406 L
.20595 .14413 L
.20269 .14769 L
.19937 .15144 L
.19596 .15553 L
.19272 .15962 L
.18947 .16391 L
.18614 .16843 L
.18289 .17312 L
.17967 .178 L
.17652 .18294 L
.1734 .18786 L
.17015 .1932 L
.16716 .19796 L
.16404 .20304 L
.16085 .20811 L
.15772 .21349 L
.1546 .21822 L
.15134 .22353 L
.14828 .22849 L
.14506 .23382 L
.14201 .23905 L
.13883 .24442 L
Mistroke
.13564 .24972 L
.13256 .25493 L
.12958 .26001 L
.12686 .26509 L
.12423 .27007 L
.12167 .27439 L
.1193 .27878 L
.11685 .28338 L
.11476 .28716 L
.11263 .29096 L
.11047 .29485 L
.1086 .2984 L
.10666 .3021 L
.10487 .30563 L
.10308 .30921 L
.10134 .31307 L
.09977 .31692 L
.09821 .32109 L
.09667 .32547 L
.09526 .33014 L
.09389 .33492 L
.09267 .33998 L
.09153 .34527 L
.09047 .35042 L
.08945 .35618 L
.08849 .36108 L
.08759 .36664 L
.08675 .37131 L
.08603 .37607 L
.08548 .38008 L
.08507 .3839 L
.0848 .38691 L
.08466 .38968 L
.08467 .39188 L
.08484 .39377 L
.0852 .39539 L
.08577 .39683 L
.08653 .39817 L
.08746 .39956 L
.08855 .40106 L
.08968 .40257 L
.09087 .40445 L
.09206 .40667 L
.09314 .40936 L
.09423 .41241 L
.09519 .41582 L
.09606 .41945 L
.09677 .42334 L
.09727 .42743 L
.0975 .43183 L
Mistroke
.0974 .43579 L
.09698 .44008 L
.09625 .44443 L
.09527 .44879 L
.09411 .45309 L
.0928 .45693 L
.09157 .46071 L
.09021 .46398 L
.08873 .46697 L
.08738 .46952 L
.08604 .47171 L
.08474 .47347 L
.08362 .47488 L
.08264 .47606 L
.0818 .47708 L
.08113 .47797 L
.08062 .47878 L
.08022 .47959 L
.0799 .48045 L
.07962 .48137 L
.07938 .48232 L
.07915 .48327 L
.07892 .48419 L
.07868 .48507 L
.07843 .48593 L
.07814 .48679 L
.07778 .48766 L
.07736 .4886 L
.07687 .4897 L
.07626 .49094 L
.07555 .49243 L
.07478 .49404 L
.07394 .49589 L
.07301 .498 L
.07206 .5002 L
.0711 .50286 L
.07018 .50582 L
.06939 .50911 L
.06877 .51263 L
.06835 .51613 L
.06811 .5199 L
.06804 .52358 L
.06812 .52733 L
.06834 .53103 L
.06858 .53455 L
.06897 .53817 L
.06951 .54184 L
.07007 .54538 L
.07069 .5493 L
.07136 .55321 L
Mistroke
.07206 .55698 L
.07276 .56122 L
.07343 .56547 L
.0741 .56966 L
.07476 .57448 L
.07538 .57892 L
.07599 .58367 L
.07662 .58869 L
.07721 .59318 L
.0778 .59823 L
.07836 .60269 L
.07887 .60723 L
.07935 .61156 L
.07981 .61613 L
.08028 .61986 L
.08078 .62374 L
.0813 .62756 L
.08186 .63115 L
.08248 .63474 L
.08316 .63827 L
.08384 .64178 L
.08455 .64533 L
.08527 .64856 L
.08593 .65173 L
.08657 .65457 L
.08715 .65724 L
.08765 .65932 L
.08806 .66104 L
.08838 .66236 L
.08864 .66331 L
.08881 .66388 L
.08891 .66413 L
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
.08862 .66173 L
.08862 .66212 L
.08866 .66289 L
.08875 .66407 L
.08889 .66564 L
.0891 .66767 L
.08939 .6703 L
.08978 .67331 L
.09025 .67692 L
.09082 .68089 L
.09146 .68555 L
Mistroke
.09217 .69009 L
.0929 .69424 L
.09368 .69885 L
.0945 .70309 L
.09525 .70711 L
.09605 .71086 L
.09675 .71379 L
.09742 .71641 L
.09804 .71837 L
.0986 .7199 L
.09909 .721 L
.09949 .72164 L
.09982 .72185 L
.10008 .72181 L
.10028 .7217 L
.10041 .72156 L
.1005 .72145 L
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
.10016 .72074 L
.10033 .72121 L
.10064 .72206 L
.10111 .72334 L
.10176 .72509 L
.10257 .72708 L
.10359 .7294 L
.10484 .73195 L
.1063 .73452 L
.10754 .73712 L
.10914 .73965 L
.11068 .74217 L
.11254 .74457 L
.11404 .74657 L
.1156 .74837 L
.11714 .74989 L
.11854 .75114 L
.11982 .75212 L
Mistroke
.12098 .75293 L
.12206 .75359 L
.12298 .75411 L
.1239 .75456 L
.12466 .75493 L
.12539 .75528 L
.12601 .75554 L
.12658 .75579 L
.12709 .75604 L
.12753 .75619 L
.12788 .75628 L
.12816 .75634 L
.12837 .75636 L
.12851 .75634 L
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
.12667 .75548 L
.12681 .75592 L
.12712 .75652 L
.1277 .75744 L
.12853 .75868 L
.12966 .76026 L
.13117 .76199 L
.13299 .7641 L
.13476 .76643 L
.13667 .76884 L
.13881 .77143 L
.14075 .77391 L
.14305 .77634 L
.14516 .77867 L
.1472 .78073 L
.14892 .78236 L
.15044 .78374 L
.15175 .78485 L
.15277 .78566 L
.15359 .78621 L
.15413 .78652 L
.15445 .78666 L
.15461 .78663 L
.15465 .78649 L
Mistroke
.15461 .78627 L
.15452 .78602 L
.15441 .78582 L
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
.1565 .78514 L
.15678 .78583 L
.1572 .78687 L
.15777 .78824 L
.15849 .78994 L
.15935 .79194 L
.16018 .7939 L
.16117 .79612 L
.16218 .79833 L
.16319 .80064 L
.16417 .80284 L
.16503 .80501 L
.16579 .80668 L
.16641 .80809 L
.16687 .80921 L
.16717 .80995 L
.16731 .81028 L
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
.1663 .80419 L
.16628 .80459 L
.1664 .80523 L
Mistroke
.1667 .80612 L
.16723 .80729 L
.16803 .80867 L
.16917 .81044 L
.17066 .8128 L
.17253 .81518 L
.17484 .81812 L
.17758 .82139 L
.18089 .82528 L
.18424 .82894 L
.18817 .83308 L
.19243 .8376 L
.1968 .84206 L
.20137 .84684 L
.20607 .8514 L
.21118 .85676 L
.21571 .8612 L
.22061 .86634 L
.22594 .87114 L
.23039 .87542 L
.2352 .87974 L
.23998 .88381 L
.24472 .8878 L
.24958 .89114 L
.25399 .89441 L
.2588 .8975 L
.26353 .90024 L
.26811 .90279 L
.27295 .90517 L
.27787 .90737 L
.28311 .9095 L
.28792 .91138 L
.29307 .91329 L
.29856 .91518 L
.30375 .91703 L
.3091 .91896 L
.31517 .92087 L
.32078 .92278 L
.32642 .9248 L
.33243 .92671 L
.33833 .92869 L
.34405 .93058 L
.34972 .93255 L
.35582 .93444 L
.36146 .93633 L
.36723 .93834 L
.37296 .94027 L
.3782 .94215 L
.38373 .94407 L
.38895 .94582 L
Mistroke
.39396 .94756 L
.39868 .9491 L
.40325 .95059 L
.40752 .95199 L
.41161 .95336 L
.41551 .95457 L
.41901 .95575 L
.42231 .9569 L
.42546 .95795 L
.42837 .95899 L
.43119 .96001 L
.43396 .96098 L
.43675 .96196 L
.43963 .96292 L
.44277 .96381 L
.44596 .96467 L
.44942 .96544 L
.45333 .96609 L
.45684 .96658 L
.46064 .96691 L
.46459 .96709 L
.46851 .96715 L
.47214 .96709 L
.47554 .96695 L
.47873 .96676 L
.48123 .9665 L
.48355 .9662 L
.48532 .9659 L
.48675 .96561 L
.48785 .96536 L
.48854 .9652 L
.48892 .96513 L
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
Mistroke
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
.487 .96548 L
.4872 .96548 L
.48751 .96544 L
.48794 .96534 L
.48848 .96519 L
.48911 .96493 L
.48977 .96455 L
.49045 .96404 L
.49113 .9634 L
.49189 .96263 L
.4925 .96182 L
.49321 .9609 L
.49389 .95993 L
.4945 .95896 L
.49504 .95804 L
.4955 .9572 L
.49588 .95647 L
.49622 .95584 L
.49648 .95533 L
.49674 .95493 L
.49701 .95467 L
.4973 .95455 L
.49755 .95454 L
.49782 .95459 L
.49805 .95469 L
Mistroke
.49826 .95477 L
.49847 .95475 L
.49875 .95456 L
.49915 .95419 L
.49969 .95367 L
.50044 .95303 L
.50147 .95231 L
.50276 .95151 L
.50425 .95066 L
.50588 .94975 L
.50743 .9488 L
.5091 .94784 L
.51094 .9468 L
.51257 .94582 L
.51419 .94486 L
.51555 .94401 L
.51696 .9431 L
.51824 .94219 L
.5196 .94117 L
.52066 .94029 L
.52174 .93923 L
.5229 .93789 L
.52392 .93679 L
.52514 .93549 L
.52648 .93421 L
.52808 .93282 L
.52937 .93168 L
.5309 .93058 L
.53223 .92957 L
.53359 .92858 L
.53473 .92777 L
.53574 .92706 L
.53654 .9265 L
.53715 .92603 L
.53762 .92575 L
.53796 .92554 L
.53819 .92539 L
.53835 .92528 L
.53847 .92521 L
.53859 .92513 L
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
Mistroke
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
.53847 .92516 L
.53823 .92528 L
.53797 .9254 L
.53772 .92549 L
.53752 .92559 L
.5374 .92572 L
.5374 .92589 L
.5376 .92609 L
.53805 .92627 L
.53882 .9264 L
.53999 .92643 L
.54164 .92637 L
.54383 .92624 L
.54647 .926 L
.5496 .92563 L
.55305 .92515 L
.55699 .9247 L
.56069 .92431 L
.56454 .92391 L
.56839 .92357 L
.57161 .92332 L
.57469 .92313 L
.57738 .92302 L
.57947 .92306 L
.58118 .92327 L
.58245 .92355 L
.58323 .92352 L
.58372 .92368 L
.58395 .9238 L
.584 .92376 L
.58398 .92349 L
.58394 .92299 L
.58393 .92232 L
.58396 .92156 L
.58407 .9206 L
.58427 .91973 L
.58453 .91893 L
.58484 .91797 L
.58516 .91704 L
.58552 .91629 L
.58593 .91584 L
Mistroke
.58646 .91558 L
.58718 .91544 L
.58815 .91536 L
.58947 .91524 L
.59121 .91502 L
.59344 .91468 L
.59598 .91415 L
.59904 .91343 L
.60245 .91255 L
.6065 .91153 L
.61051 .91041 L
.6149 .90919 L
.61936 .90792 L
.62408 .90663 L
.62859 .90537 L
.63318 .90418 L
.63749 .90312 L
.6414 .9022 L
.64504 .90147 L
.64827 .90091 L
.65081 .90051 L
.65309 .90023 L
.65497 .90007 L
.65642 .90002 L
.65754 .90011 L
.65841 .90028 L
.65915 .90054 L
.6599 .9008 L
.66077 .90102 L
.66185 .90113 L
.66317 .90111 L
.6649 .90093 L
.66693 .90058 L
.66929 .90008 L
.67178 .89946 L
.6747 .89871 L
.67767 .8978 L
.68085 .89672 L
.68395 .89555 L
.68699 .89428 L
.68988 .89297 L
.69247 .89165 L
.69478 .89038 L
.69678 .88923 L
.69847 .88821 L
.69983 .88733 L
.7009 .8866 L
.7017 .88601 L
.70224 .88552 L
.70253 .88513 L
Mistroke
.70261 .88483 L
.70254 .88463 L
.70236 .88455 L
.70216 .88457 L
.70203 .88465 L
.70204 .88478 L
.70225 .88491 L
.7027 .88504 L
.70339 .88516 L
.70433 .88527 L
.70551 .88537 L
.70681 .88546 L
.7082 .88553 L
.70973 .88559 L
.71128 .88564 L
.71296 .88568 L
.71434 .8857 L
.71556 .8857 L
.71656 .88569 L
.71732 .88567 L
.71788 .88566 L
.71827 .88567 L
.71852 .8857 L
.71877 .88575 L
.71922 .8858 L
.72 .8858 L
.7212 .88571 L
.72285 .88546 L
.72515 .88503 L
.72789 .88438 L
.73071 .88351 L
.73454 .8824 L
.73815 .88102 L
.74249 .87945 L
.74733 .87758 L
.7524 .87547 L
.757 .87305 L
.76211 .87035 L
.76729 .86758 L
.77213 .86454 L
.77688 .86144 L
.78166 .85817 L
.78662 .85492 L
.79071 .85161 L
.7951 .84824 L
.79958 .84476 L
.80368 .84119 L
.80751 .83777 L
.81156 .8341 L
.81518 .83067 L
Mistroke
.81881 .82716 L
.82228 .82376 L
.82554 .82044 L
.82875 .81714 L
.8318 .81416 L
.83472 .81116 L
.83757 .80821 L
.84052 .80524 L
.8431 .80252 L
.84586 .79971 L
.84848 .79688 L
.8511 .79403 L
.85379 .79106 L
.8563 .78812 L
.85876 .78511 L
.86116 .78202 L
.86329 .77921 L
.8653 .77645 L
.86717 .7738 L
.86871 .77153 L
.87007 .76941 L
.87121 .76757 L
.87206 .76614 L
.87264 .7651 L
.87294 .76446 L
.873 .76417 L
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
Mistroke
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
.86994 .76937 L
.86981 .7696 L
.86961 .7699 L
.86933 .77028 L
.86897 .77069 L
.86851 .77122 L
.86799 .77185 L
.86746 .77258 L
.86691 .77343 L
.86638 .77444 L
.86587 .77558 L
.86544 .77693 L
.86503 .77811 L
.86467 .77923 L
.86439 .78018 L
.8642 .78096 L
.86407 .78163 L
.86398 .7822 L
.86392 .78268 L
.86388 .78308 L
.86382 .78341 L
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
.86367 .78375 L
.86392 .78345 L
.86431 .78286 L
.86489 .78194 L
.86571 .78052 L
.86661 .77887 L
.86778 .77665 L
.86909 .77393 L
.87053 .77086 L
.87204 .76737 L
.87359 .76357 L
.87521 .75929 L
.87687 .75461 L
.87874 .74952 L
.88044 .74402 L
.88232 .73821 L
.88426 .73212 L
.8862 .72573 L
Mistroke
.88828 .71883 L
.89029 .71227 L
.89249 .70528 L
.89463 .69774 L
.89652 .69121 L
.8985 .68431 L
.90039 .67774 L
.90217 .67153 L
.9037 .66617 L
.90504 .66123 L
.90618 .65653 L
.90715 .65283 L
.90806 .64936 L
.90889 .6461 L
.90972 .64306 L
.91056 .63993 L
.91145 .63674 L
.91232 .63328 L
.91328 .62939 L
.91421 .62533 L
.91522 .62111 L
.91631 .61629 L
.91741 .61085 L
.91858 .60531 L
.91974 .59945 L
.92085 .59371 L
.92194 .58794 L
.92296 .58222 L
.92392 .57663 L
.92484 .57138 L
.92571 .5663 L
.92655 .56133 L
.92732 .55663 L
.92803 .55182 L
.9286 .54723 L
.92906 .54248 L
.92935 .53772 L
.92951 .53303 L
.92953 .52835 L
.92943 .52379 L
.92921 .51944 L
.92893 .51538 L
.9286 .51164 L
.92825 .50825 L
.92791 .50536 L
.92761 .50286 L
.92736 .50083 L
.9272 .49926 L
.92711 .49812 L
.92709 .49743 L
Mistroke
.92713 .49716 L
.92723 .49722 L
.92737 .4975 L
.92753 .49794 L
.92767 .49845 L
.92775 .499 L
.92777 .49958 L
.92769 .50024 L
.92751 .50106 L
.92724 .50213 L
.92688 .50355 L
.92644 .5054 L
.92593 .50772 L
.92535 .51054 L
.92474 .51357 L
.92409 .51721 L
.92344 .52153 L
.92282 .52576 L
.92228 .53081 L
.92181 .53669 L
.92147 .54196 L
.92125 .54815 L
.92112 .55475 L
.92103 .56068 L
.92093 .56752 L
.92074 .5737 L
.92042 .58069 L
.91993 .5868 L
.91925 .59381 L
.91842 .6003 L
.91739 .60699 L
.91617 .61363 L
.91478 .62039 L
.91322 .62734 L
.9115 .63414 L
.90967 .64098 L
.90773 .64778 L
.90572 .65492 L
.90369 .66181 L
.90163 .6689 L
.89954 .67621 L
.89744 .68403 L
.89535 .69105 L
.89329 .69852 L
.89129 .70592 L
.88933 .71315 L
.88738 .72058 L
.88544 .72748 L
.88353 .73458 L
.88162 .74102 L
Mistroke
.87967 .7477 L
.87769 .75405 L
.87561 .76002 L
.87335 .76632 L
.87099 .77148 L
.86837 .77689 L
.86538 .78218 L
.86213 .78698 L
.85846 .79205 L
.85464 .79663 L
.8503 .80135 L
.84629 .80563 L
.84197 .8098 L
.83738 .81382 L
.83322 .81759 L
.82877 .82124 L
.82436 .82483 L
.81949 .82863 L
.81529 .83216 L
.81058 .83593 L
.80585 .83979 L
.80056 .84385 L
.796 .84755 L
.79053 .85162 L
.78565 .8556 L
.77986 .85993 L
.77458 .86411 L
.76888 .86846 L
.76294 .87304 L
.75743 .87725 L
.75158 .88163 L
.7458 .88599 L
.7402 .89032 L
.73441 .89447 L
.72887 .89843 L
.72324 .90253 L
.71762 .90638 L
.71237 .91016 L
.70742 .91367 L
.70258 .91706 L
.69823 .92013 L
.69383 .92307 L
.69034 .92541 L
.68719 .92751 L
.68447 .9293 L
.68235 .93069 L
.68078 .93178 L
.67972 .93261 L
.67907 .93319 L
.67873 .93356 L
Mistroke
.67856 .93374 L
.67844 .93377 L
.67824 .93366 L
.67783 .93344 L
.67716 .93313 L
.67618 .93277 L
.67483 .93239 L
.67301 .93203 L
.67061 .93174 L
.66767 .93154 L
.6643 .93145 L
.66023 .93146 L
.65544 .93157 L
.65079 .93179 L
.64555 .93208 L
.64069 .93252 L
.63501 .93321 L
.62971 .93389 L
.62377 .9348 L
.61839 .93584 L
.61245 .937 L
.60678 .93807 L
.60157 .93923 L
.59596 .94041 L
.59079 .94152 L
.58548 .94271 L
.58033 .94396 L
.57514 .9454 L
.57024 .94663 L
.56497 .94806 L
.56013 .94954 L
.5548 .95106 L
.54958 .95253 L
.54434 .95401 L
.53847 .9555 L
.53314 .95697 L
.52724 .95845 L
.52115 .95991 L
.51497 .9613 L
.50838 .96261 L
.50251 .96377 L
.4958 .96475 L
.48943 .96549 L
.48349 .96599 L
.47709 .96624 L
.47136 .96623 L
.46549 .96597 L
.45966 .96545 L
.45429 .9647 L
.44888 .96374 L
Mistroke
.44377 .96259 L
.43859 .96133 L
.43404 .95994 L
.42948 .95849 L
.42512 .95699 L
.4209 .95555 L
.41689 .9541 L
.41303 .9527 L
.40928 .95133 L
.40562 .95003 L
.40224 .94873 L
.39889 .94746 L
.39574 .94628 L
.39269 .94515 L
.38998 .94411 L
.38747 .94319 L
.38533 .94235 L
.38348 .9416 L
.38193 .94095 L
.38069 .9404 L
.37974 .93997 L
.37907 .93965 L
.37864 .93946 L
.37844 .93936 L
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
Mistroke
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
.38043 .94034 L
.38009 .94021 L
.37946 .93997 L
.37847 .9396 L
.37705 .9391 L
.37517 .93848 L
.37305 .93773 L
.37044 .93689 L
.36738 .93593 L
.36402 .93483 L
.36012 .93364 L
.35611 .93236 L
.35146 .93095 L
.34713 .92946 L
.34199 .9279 L
.33746 .92635 L
.3322 .92474 L
.32772 .92315 L
.32277 .9215 L
.3181 .91982 L
.31345 .91801 L
.3087 .9163 L
.30446 .91446 L
.3002 .91275 L
.29601 .91105 L
.29221 .90942 L
.28852 .90785 L
.28493 .90645 L
.28162 .905 L
.2783 .90376 L
.27543 .90257 L
.2726 .90144 L
.26992 .9004 L
.26773 .89949 L
.26563 .89864 L
.26379 .89789 L
.26222 .89728 L
.26098 .89676 L
.25999 .89632 L
.25927 .89595 L
.25877 .89563 L
.25848 .89537 L
.25836 .8952 L
Mistroke
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
.25955 .89601 L
.25903 .89564 L
.2582 .895 L
.25703 .89403 L
.2555 .8927 L
.25359 .89097 L
.25165 .88918 L
.24917 .88686 L
.24661 .8845 L
.24367 .88163 L
.24054 .87856 L
.23745 .87553 L
.23439 .87243 L
.23123 .86914 L
.22811 .8658 L
.22512 .86268 L
.22223 .85959 L
.21945 .85672 L
.21672 .85388 L
.21397 .85128 L
.21126 .8487 L
.20844 .84618 L
.20573 .84357 L
.20287 .84129 L
.20014 .8389 L
.19735 .83653 L
.19466 .83407 L
.19198 .83189 L
.18934 .82959 L
.1866 .82728 L
.18412 .82488 L
.18156 .82249 L
.17901 .81992 L
.17654 .81758 L
.17406 .815 L
.17184 .81243 L
.1696 .80967 L
.16751 .80725 L
Mistroke
.16541 .80466 L
.16335 .80193 L
.16131 .79914 L
.1593 .79628 L
.15725 .7932 L
.1553 .79058 L
.15343 .78763 L
.15165 .78482 L
.15006 .78197 L
.14861 .77917 L
.14736 .77658 L
.14623 .77405 L
.14535 .7717 L
.14464 .7697 L
.14412 .76794 L
.1438 .76642 L
.14366 .76517 L
.14366 .76405 L
.14371 .76304 L
.14372 .76202 L
.14364 .76094 L
.14337 .75974 L
.14287 .75833 L
.14213 .75677 L
.14114 .75485 L
.13991 .75253 L
.13851 .75009 L
.13683 .7471 L
.13491 .74363 L
.13302 .74023 L
.13086 .73634 L
.12868 .73232 L
.12638 .72804 L
.12395 .72396 L
.12167 .71983 L
.11941 .71567 L
.1174 .7118 L
.11543 .70807 L
.11364 .70438 L
.11215 .70119 L
.11086 .69797 L
.10987 .69501 L
.1092 .69246 L
.10881 .69003 L
.10869 .68784 L
.10877 .68586 L
.10904 .68421 L
.10942 .68277 L
.10986 .68155 L
.11032 .68055 L
Mistroke
.11077 .67975 L
.11119 .67911 L
.11153 .67861 L
.1118 .67825 L
.11198 .67801 L
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
.11229 .6785 L
.11246 .67867 L
.11257 .67887 L
.11257 .67906 L
.11233 .6792 L
.11183 .67922 L
.11106 .67904 L
.10995 .67858 L
.1085 .67779 L
.10671 .67664 L
.10479 .67511 L
.10325 .67328 L
.10111 .67111 L
.09867 .66841 L
.09668 .66535 L
.09415 .66179 L
.09215 .6578 L
.09015 .65347 L
.08823 .64925 L
.08651 .64388 L
.08519 .63921 L
.08397 .63365 L
.08292 .62844 L
.08196 .62253 L
.08107 .61705 L
.08024 .61154 L
.07944 .60597 L
.07871 .60032 L
.07805 .5942 L
.07746 .58907 L
Mistroke
.07693 .58295 L
.07643 .57794 L
.07594 .57268 L
.07542 .56744 L
.07489 .56235 L
.07434 .55761 L
.07378 .5525 L
.07322 .54849 L
.0727 .54427 L
.07219 .54054 L
.0717 .53752 L
.07126 .5347 L
.07088 .53233 L
.07055 .53065 L
.0703 .52948 L
.07012 .52874 L
.07 .52832 L
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
Mistroke
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
Mistroke
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
.07573 .51733 L
.07578 .51685 L
.0758 .51596 L
.07583 .51463 L
.07593 .51277 L
.0761 .51058 L
.07638 .50763 L
.07674 .50461 L
.07719 .50106 L
.07772 .49712 L
.07828 .49331 L
.07888 .48922 L
.0795 .48538 L
.08012 .4821 L
.08072 .47888 L
.08125 .47612 L
.08171 .47373 L
.0821 .47205 L
.0824 .47079 L
.08263 .47006 L
.08277 .46972 L
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
Mistroke
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
.08255 .47159 L
.08273 .47127 L
.08301 .47087 L
.0834 .47043 L
.08389 .46997 L
.08449 .46937 L
.0851 .46869 L
.08581 .46797 L
.08658 .46724 L
.08731 .46656 L
.08804 .46594 L
.08874 .46542 L
.08936 .465 L
Mistroke
.08987 .46467 L
.09029 .46446 L
.0906 .46438 L
.0908 .46439 L
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
.09098 .46469 L
.09121 .46469 L
.09147 .46466 L
.09174 .46459 L
.09206 .46451 L
.09243 .46441 L
.09289 .4643 L
.09343 .46422 L
.09415 .4642 L
.09491 .46425 L
.09585 .4644 L
.09705 .46468 L
.09856 .46514 L
.10029 .46581 L
.10199 .46669 L
.10363 .46777 L
.10574 .46908 L
.10811 .47061 L
.11037 .47231 L
.11279 .47422 L
.11562 .4763 L
.11775 .47872 L
.12072 .48137 L
.123 .48419 L
.12532 .48715 L
.12745 .49055 L
.12945 .49389 L
.13135 .49736 L
.1332 .50118 L
Mistroke
.1349 .50443 L
.13647 .50784 L
.13794 .51105 L
.13929 .51371 L
.14048 .51629 L
.14151 .51841 L
.14232 .52003 L
.14295 .5212 L
.1434 .52189 L
.14371 .52217 L
.14388 .5221 L
.14396 .52182 L
.14396 .52141 L
.1439 .52096 L
.14383 .52053 L
.14375 .52015 L
.14368 .51986 L
.14363 .51964 L
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
.14337 .51863 L
.14322 .51896 L
.1431 .51961 L
.14303 .52066 L
.14304 .5222 L
.14311 .52434 L
.14326 .52669 L
.14345 .52983 L
.14364 .5332 L
.14389 .53697 L
Mistroke
.14418 .54138 L
.14453 .54555 L
.14497 .55009 L
.14544 .55527 L
.14598 .55932 L
.14654 .56385 L
.14714 .56859 L
.14775 .57251 L
.1484 .57687 L
.14904 .58088 L
.14977 .58479 L
.15056 .58882 L
.15143 .59288 L
.15233 .59687 L
.15321 .60091 L
.154 .60502 L
.15465 .60889 L
.1552 .61331 L
.15563 .6168 L
.15599 .6205 L
.1563 .62417 L
.15663 .62758 L
.15701 .63116 L
.15752 .63445 L
.1582 .63795 L
.15908 .64153 L
.16022 .64551 L
.1615 .649 L
.16312 .65282 L
.16497 .65683 L
.16703 .66089 L
.16926 .66484 L
.17156 .66889 L
.17383 .67231 L
.17569 .67548 L
.17734 .67844 L
.17883 .68105 L
.18009 .68304 L
.18123 .68458 L
.18215 .68557 L
.18303 .68608 L
.18397 .68624 L
.18507 .68608 L
.18643 .68565 L
.18808 .68503 L
.19003 .68427 L
.1919 .68342 L
.19427 .68247 L
.19667 .68148 L
.19945 .68043 L
Mistroke
.20251 .67934 L
.20577 .67821 L
.20865 .67707 L
.21184 .67599 L
.21484 .67495 L
.21784 .67398 L
.22083 .6731 L
.22379 .67232 L
.22673 .67167 L
.22991 .67112 L
.23308 .67072 L
.23641 .67049 L
.23987 .6705 L
.24363 .67076 L
.24711 .67128 L
.25088 .67204 L
.25495 .67305 L
.25847 .67434 L
.26223 .67581 L
.2661 .67749 L
.26964 .67941 L
.27329 .68131 L
.27692 .68337 L
.28059 .68558 L
.284 .68763 L
.28767 .68977 L
.29145 .69182 L
.29542 .69378 L
.29954 .69558 L
.30385 .69725 L
.30773 .69868 L
.31172 .69994 L
.31554 .70101 L
.31909 .7019 L
.32216 .70261 L
.32483 .70319 L
.32741 .70363 L
.32939 .70393 L
.33099 .7041 L
.33208 .70419 L
.33264 .7042 L
.33271 .70416 L
.3324 .70408 L
.33187 .70401 L
.33123 .70395 L
.33056 .70391 L
.32997 .70391 L
.32947 .70392 L
.3291 .70394 L
.32878 .70395 L
Mistroke
.32855 .70396 L
.32839 .70397 L
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
.32885 .70422 L
.32919 .7043 L
.3298 .70434 L
.33067 .70432 L
.33181 .70421 L
.33317 .70397 L
.33478 .70355 L
.33664 .70296 L
.33855 .70218 L
.34062 .7012 L
.34287 .70006 L
.34502 .69872 L
.34742 .69711 L
.34966 .69522 L
.35198 .69317 L
.35427 .69085 L
.35655 .68821 L
.35888 .68552 L
.36138 .68243 L
.36389 .67951 L
.36664 .6763 L
.36972 .67277 L
.37276 .66971 L
.37614 .6663 L
.37966 .66274 L
.3834 .65929 L
.38686 .65592 L
.39043 .6525 L
.39422 .64923 L
.39741 .64598 L
.40077 .64285 L
.40396 .63962 L
.40719 .6364 L
.41001 .63302 L
.4128 .62963 L
Mistroke
.41532 .62611 L
.41769 .62249 L
.41979 .61894 L
.42173 .61572 L
.42339 .61261 L
.42487 .60966 L
.42614 .60698 L
.42718 .60455 L
.42801 .60254 L
.42867 .60093 L
.42919 .59968 L
.42958 .59878 L
.42986 .59821 L
.43008 .59792 L
.43027 .59786 L
.43045 .59794 L
.43064 .59809 L
.43083 .59826 L
.431 .59844 L
.43118 .59857 L
.43138 .59864 L
.43158 .59866 L
.43177 .59865 L
.43192 .59865 L
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
.43194 .5986 L
.43179 .59833 L
.4316 .59797 L
.43137 .59756 L
.43112 .5971 L
.43086 .59661 L
.4306 .59612 L
.43033 .59563 L
.43006 .59513 L
.42979 .59463 L
.42953 .59419 L
.42926 .59386 L
Mistroke
.42901 .59369 L
.42878 .5937 L
.42862 .59388 L
.42855 .59422 L
.42858 .59468 L
.42877 .59519 L
.42914 .59567 L
.42976 .59604 L
.43073 .59622 L
.43212 .59611 L
.43398 .59571 L
.43628 .59506 L
.43898 .59414 L
.44218 .59279 L
.44579 .591 L
.44969 .58891 L
.45389 .58642 L
.45851 .58359 L
.463 .58063 L
.46789 .57735 L
.47296 .57392 L
.47752 .57076 L
.48251 .56736 L
.48734 .564 L
.49227 .56064 L
.49721 .55699 L
.50197 .55373 L
.50678 .55026 L
.51157 .54667 L
.51653 .54302 L
.52113 .5392 L
.52571 .53553 L
.5301 .53173 L
.53422 .52795 L
.5381 .52415 L
.54184 .52021 L
.54504 .5165 L
.54815 .51263 L
.55107 .50865 L
.55388 .50443 L
.5565 .5005 L
.5591 .49622 L
.56167 .49195 L
.56434 .48768 L
.56689 .48317 L
.56958 .47894 L
.57254 .47458 L
.57547 .47038 L
.5787 .46607 L
.5823 .46137 L
Mistroke
.58568 .45755 L
.58953 .45334 L
.59344 .44928 L
.59752 .44517 L
.60207 .44102 L
.60634 .43714 L
.61096 .43317 L
.61578 .42922 L
.62103 .42524 L
.62603 .42146 L
.63135 .41765 L
.63734 .41374 L
.64254 .41026 L
.64842 .40666 L
.6542 .40319 L
.66061 .39967 L
.66609 .39644 L
.67204 .39325 L
.67856 .38999 L
.68396 .38686 L
.6898 .38364 L
.69565 .38042 L
.70186 .37716 L
.70704 .37377 L
.71259 .37055 L
.71794 .36715 L
.723 .36376 L
.72794 .36041 L
.73312 .35691 L
.73784 .35341 L
.7424 .35018 L
.74707 .34673 L
.75183 .34338 L
.75634 .33989 L
.76112 .33661 L
.76543 .33326 L
.77008 .32969 L
.7747 .32647 L
.77881 .32278 L
.7833 .31947 L
.78766 .31598 L
.79186 .31299 L
.79605 .30973 L
.8003 .30668 L
.80415 .30406 L
.8081 .30148 L
.81191 .29928 L
.8158 .29741 L
.81956 .2958 L
.82354 .29457 L
Mistroke
.82722 .29365 L
.831 .29302 L
.83473 .29264 L
.83848 .29246 L
.84226 .29242 L
.84602 .2925 L
.84986 .29264 L
.85344 .29281 L
.85705 .29298 L
.8607 .29312 L
.86406 .29322 L
.86746 .29327 L
.87081 .29328 L
.87388 .29326 L
.87682 .29322 L
.8795 .29318 L
.88189 .29317 L
.88398 .29319 L
.8859 .29325 L
.88765 .29337 L
.88919 .29359 L
.89061 .29391 L
.89188 .29432 L
.89302 .29484 L
.89401 .29544 L
.89485 .2961 L
.89553 .29681 L
.8961 .29753 L
.89659 .2982 L
.89704 .2988 L
.89744 .29932 L
.89776 .29974 L
.898 .30007 L
.89815 .30033 L
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
.89803 .30187 L
.89788 .30175 L
.8977 .30152 L
Mistroke
.89752 .30117 L
.89735 .30071 L
.89719 .30011 L
.89703 .29938 L
.89686 .29849 L
.89668 .29742 L
.89647 .29618 L
.89624 .29478 L
.89598 .2934 L
.89567 .29184 L
.8953 .2902 L
.89484 .2886 L
.89424 .28691 L
.89348 .28513 L
.89258 .28331 L
.89149 .28148 L
.89021 .27956 L
.88885 .27769 L
.88738 .2758 L
.8858 .27388 L
.88425 .2721 L
.88273 .27031 L
.88117 .26852 L
.87957 .26689 L
.87818 .26528 L
.87678 .26392 L
.87531 .26271 L
.87382 .26168 L
.87234 .26088 L
.87076 .26028 L
.86902 .25988 L
.86737 .25965 L
.86559 .25956 L
.86375 .25957 L
.86201 .25963 L
.86074 .25971 L
.8593 .25973 L
.85823 .25964 L
.85736 .25948 L
.85672 .2593 L
.85639 .25914 L
.85641 .25906 L
.85674 .25916 L
.85736 .2595 L
.85811 .26012 L
.85903 .26106 L
.86 .26238 L
.86099 .2641 L
.86193 .2662 L
.86277 .26818 L
Mistroke
.86353 .27057 L
.86418 .27335 L
.86473 .2759 L
.86517 .27881 L
.8656 .28125 L
.86601 .28366 L
.86644 .28578 L
.8669 .28767 L
.86742 .28914 L
.86806 .29031 L
.8689 .29116 L
.87 .29174 L
.87127 .29215 L
.87285 .29244 L
.87446 .29264 L
.87637 .29276 L
.87847 .29286 L
.88063 .29294 L
.8827 .29303 L
.88488 .29312 L
.88661 .29325 L
.88836 .29337 L
.88972 .29349 L
.89087 .29358 L
.89177 .29366 L
.89238 .29373 L
.89273 .29378 L
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
Mistroke
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
.89221 .29136 L
.89247 .29158 L
.89282 .29189 L
.89322 .29226 L
.89367 .29269 L
.89415 .29317 L
.89469 .29371 L
.89526 .2943 L
.89588 .29496 L
.89652 .29566 L
.89716 .29646 L
.89781 .29739 L
.89844 .29843 L
.89906 .29957 L
.89965 .30081 L
.90019 .30203 L
.90073 .30335 L
.90126 .30468 L
.90178 .30603 L
.90228 .30729 L
.90275 .30857 L
.90316 .30963 L
.90351 .31056 L
.90378 .31131 L
.90397 .31186 L
.90409 .31221 L
.90415 .31237 L
.90419 .31242 L
.9042 .31249 L
.90422 .31266 L
.90422 .31296 L
.90421 .31343 L
.90419 .31408 L
.90418 .3149 L
.90418 .3158 L
.90419 .31668 L
.90423 .31751 L
.90432 .31816 L
.90444 .31872 L
Mistroke
.90458 .31905 L
.90471 .31913 L
.9048 .31899 L
.90483 .31829 L
.90473 .31702 L
.90443 .31529 L
.90388 .31298 L
.90308 .31014 L
.90199 .30695 L
.90058 .30309 L
.89897 .29935 L
.897 .29502 L
.89473 .29072 L
.89219 .28588 L
.88936 .28075 L
.88614 .27566 L
.88313 .27032 L
.87985 .265 L
.87653 .25953 L
.87313 .25429 L
.87003 .2492 L
.86684 .24395 L
.86388 .23922 L
.86097 .23473 L
.85806 .23015 L
.85522 .22568 L
.85229 .22098 L
.84941 .21692 L
.8464 .21251 L
.84338 .20809 L
.8403 .20364 L
.83712 .19887 L
.834 .19421 L
.83068 .18955 L
.82741 .18519 L
.82395 .18017 L
.8202 .17531 L
.81681 .1701 L
.81348 .16591 L
.81013 .16145 L
.8071 .15738 L
.80423 .15359 L
.80197 .15068 L
.79989 .14786 L
.79809 .1457 L
.79669 .14399 L
.79541 .14245 L
.79423 .14104 L
.79318 .13973 L
.79226 .13849 L
Mistroke
.79144 .13726 L
.79069 .13601 L
.78998 .13481 L
.78932 .13381 L
.78858 .13275 L
.78759 .13136 L
.78653 .13002 L
.78529 .12854 L
.78389 .12702 L
.78232 .12552 L
.78057 .1241 L
.77864 .12276 L
.77677 .12158 L
.77465 .1204 L
.77221 .11918 L
.76973 .11789 L
.76675 .11644 L
.76388 .11487 L
.7605 .11311 L
.75708 .11126 L
.7532 .10935 L
.74962 .10735 L
.74556 .10541 L
.74139 .10341 L
.73715 .10134 L
.73244 .09933 L
.72821 .09726 L
.72378 .09525 L
.71962 .09327 L
.71545 .09137 L
.7113 .08958 L
.70713 .08801 L
.70389 .08663 L
.70077 .08548 L
.69771 .0846 L
.69516 .08395 L
.69278 .08354 L
.69064 .08335 L
.68891 .08339 L
.68734 .0836 L
.68595 .0839 L
.68477 .08425 L
.6838 .08462 L
.68298 .08501 L
.68228 .08543 L
.68168 .08586 L
.68116 .08628 L
.68072 .08667 L
.68034 .08705 L
.68002 .08744 L
Mistroke
.67973 .08782 L
.67948 .08818 L
.67926 .08853 L
.67908 .08887 L
.67888 .08919 L
.67864 .08946 L
.6784 .08964 L
.67817 .08971 L
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
.67785 .08839 L
.67823 .0886 L
.67884 .08908 L
.67972 .08985 L
.68091 .09095 L
.68238 .09245 L
.68418 .09429 L
.68631 .09668 L
.68873 .0991 L
.69143 .10191 L
.69442 .10524 L
.69727 .10847 L
.70035 .112 L
.70349 .11573 L
.70629 .11896 L
.70904 .12217 L
.71157 .12529 L
.71394 .12846 L
.71595 .13086 L
.71792 .13312 L
Mistroke
.71964 .13539 L
.72134 .13736 L
.72306 .1394 L
.72474 .14149 L
.72644 .14346 L
.72825 .1456 L
.72996 .14741 L
.73175 .14937 L
.73351 .15132 L
.73524 .15333 L
.7369 .15531 L
.7384 .15692 L
.73966 .15846 L
.74074 .15974 L
.74158 .16081 L
.74218 .16163 L
.74254 .16214 L
.74269 .16235 L
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
.74189 .15984 L
.74202 .15997 L
.74221 .16016 L
Mistroke
.74246 .1604 L
.74276 .16066 L
.74312 .16092 L
.74353 .16115 L
.74396 .16132 L
.74445 .16143 L
.74494 .16148 L
.74542 .16149 L
.74587 .16145 L
.74627 .16142 L
.74662 .16142 L
.7469 .1615 L
.74714 .16171 L
.74736 .16209 L
.74759 .16269 L
.74786 .16354 L
.74822 .16468 L
.74863 .1662 L
.74911 .16818 L
.74962 .17041 L
.7501 .17301 L
.75057 .17589 L
.75099 .17909 L
.75137 .1822 L
.7517 .18539 L
.75199 .1885 L
.75223 .19138 L
.75243 .1941 L
.75254 .19652 L
.75259 .19835 L
.75259 .19987 L
.75252 .20099 L
.75233 .20164 L
.75199 .20187 L
.75145 .20171 L
.75066 .20128 L
.74952 .20067 L
.74807 .19997 L
.74615 .19924 L
.74402 .19853 L
.74141 .19791 L
.73814 .19743 L
.73517 .19711 L
.7313 .19693 L
.72796 .1969 L
.72395 .19701 L
.71928 .19726 L
.71549 .1976 L
.7108 .19801 L
.70677 .19845 L
Mistroke
.70226 .19891 L
.69767 .19938 L
.69336 .19988 L
.6886 .20039 L
.68389 .20088 L
.67984 .20134 L
.67525 .20172 L
.67098 .20203 L
.66671 .20224 L
.66269 .20236 L
.65902 .20236 L
.65529 .20226 L
.65216 .20207 L
.64896 .20182 L
.64627 .20149 L
.64388 .20112 L
.64187 .20072 L
.64008 .20026 L
.63857 .19974 L
.63733 .19905 L
.63632 .19823 L
.63542 .19717 L
.63459 .19584 L
.63379 .19415 L
.63299 .19204 L
.63219 .18985 L
.63141 .18715 L
.63054 .18383 L
.62969 .18107 L
.62883 .17734 L
.62797 .17324 L
.62712 .16978 L
.6263 .16559 L
.62561 .16134 L
.62516 .15698 L
.62499 .15302 L
.62514 .14899 L
.62562 .14491 L
.62642 .1411 L
.62755 .13727 L
.62889 .13341 L
.63045 .12964 L
.63221 .12607 L
.6341 .12253 L
.63612 .11944 L
.63811 .11668 L
.64006 .11416 L
.64191 .11202 L
.64356 .11014 L
.64495 .10874 L
Mistroke
.64614 .10763 L
.64706 .10682 L
.64773 .10629 L
.64817 .106 L
.64841 .10591 L
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
.64827 .10653 L
.6484 .10647 L
.64856 .10645 L
.64875 .10647 L
.64896 .10655 L
.64919 .1067 L
.64946 .10692 L
.64977 .10722 L
.65016 .10759 L
.65064 .10803 L
.65122 .10853 L
.6519 .10908 L
.65268 .10966 L
.65355 .11026 L
.65446 .11086 L
.65542 .11144 L
.65642 .11196 L
.65739 .11237 L
.65835 .11268 L
.65919 .11288 L
.6599 .11301 L
.66044 .1131 L
.66078 .11319 L
.66091 .11333 L
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
Mistroke
.65642 .11745 L
.65648 .11754 L
.65656 .1177 L
.65662 .11798 L
.65665 .11839 L
.65667 .11896 L
.65668 .11965 L
.6567 .12039 L
.65672 .12121 L
.65676 .12207 L
.65681 .12292 L
.65686 .12372 L
.65688 .12445 L
.65686 .12508 L
.6568 .12557 L
.65672 .12589 L
.65662 .12602 L
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
Mistroke
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
.65675 .12602 L
.65651 .12639 L
.6562 .12687 L
.65584 .12743 L
.65544 .12804 L
.65502 .12868 L
.6546 .12931 L
.65418 .12993 L
.65377 .13055 L
.65339 .13113 L
.65306 .13165 L
.6528 .13206 L
.65261 .13234 L
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
Mistroke
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
.65315 .13854 L
.65299 .13832 L
.65272 .13806 L
.65234 .1378 L
.65189 .1376 L
.65137 .13749 L
.65082 .13749 L
.65026 .13765 L
.6497 .13799 L
.64915 .13855 L
.64864 .1394 L
.64816 .1405 L
.64773 .1419 L
.64733 .14367 L
.64694 .14578 L
.64656 .14823 L
.64614 .15105 L
.64569 .15398 L
.64518 .15716 L
.64461 .16072 L
.64391 .16403 L
.64312 .16765 L
.6422 .1716 L
.64119 .17526 L
.64007 .17916 L
.63888 .18322 L
.63765 .18721 L
.63643 .19105 L
.63522 .19544 L
.63408 .19884 L
.63293 .20301 L
.63183 .20649 L
.63066 .21032 L
Mistroke
.62941 .21424 L
.62813 .21787 L
.62673 .22151 L
.62516 .22523 L
.6235 .22856 L
.62168 .23168 L
.61962 .23491 L
.61739 .23799 L
.615 .24065 L
.61214 .24335 L
.60901 .24593 L
.60523 .24832 L
.60176 .25054 L
.59717 .25259 L
.59314 .25432 L
.58849 .25591 L
.58427 .25727 L
.57942 .25843 L
.57444 .25934 L
.56893 .25996 L
.56415 .26028 L
.55889 .26027 L
.55346 .25994 L
.54873 .25935 L
.54378 .25853 L
.5391 .25752 L
.53415 .25631 L
.5303 .25501 L
.52603 .2536 L
.52219 .25207 L
.51802 .25043 L
.51452 .24877 L
.51069 .24701 L
.50709 .24518 L
.50327 .24328 L
.49974 .2415 L
.49582 .23964 L
.49225 .23762 L
.48847 .23544 L
.48475 .23313 L
.48072 .23058 L
.47688 .22794 L
.47342 .22518 L
.46954 .22208 L
.46598 .21907 L
.46235 .21585 L
.45875 .21266 L
.45538 .20924 L
.45204 .20565 L
.44896 .20235 L
Mistroke
.44597 .19893 L
.44322 .19561 L
.44041 .19224 L
.43808 .18926 L
.43581 .18623 L
.43369 .18322 L
.43173 .1804 L
.42977 .17735 L
.42781 .1742 L
.42604 .17104 L
.42417 .16774 L
.42241 .16417 L
.42061 .16053 L
.41892 .15671 L
.4173 .1526 L
.41581 .14858 L
.41453 .14415 L
.41354 .13987 L
.4129 .1359 L
.41261 .13158 L
.41269 .12723 L
.41314 .12305 L
.41394 .11859 L
.41499 .11442 L
.41627 .11014 L
.41766 .10585 L
.41911 .1016 L
.42053 .09803 L
.42192 .09425 L
.42311 .09091 L
.42414 .08783 L
.42503 .0852 L
.42576 .08317 L
.42634 .08156 L
.42675 .08041 L
.42699 .07972 L
.42708 .07944 L
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
.4263 .08073 L
.42662 .08035 L
.42704 .07984 L
.42757 .07923 L
.42818 .07852 L
.42885 .07777 L
Mistroke
.42956 .07698 L
.4303 .07622 L
.43104 .07551 L
.43176 .07489 L
.43243 .0744 L
.43304 .07403 L
.43359 .07378 L
.43407 .07361 L
.43451 .07351 L
.43491 .07349 L
.4353 .07351 L
.43569 .07356 L
.43608 .07362 L
.43647 .07367 L
.43685 .07371 L
.43725 .07375 L
.43764 .07377 L
.43801 .07379 L
.43831 .0738 L
.4385 .07383 L
.43853 .07392 L
.4384 .07404 L
.43812 .07419 L
.43772 .07432 L
.43723 .07441 L
.43667 .0744 L
.43605 .07426 L
.4354 .07395 L
.4347 .07342 L
.43392 .07265 L
.43306 .0716 L
.43215 .07023 L
.43121 .06861 L
.43028 .06665 L
.42938 .06443 L
.42854 .06198 L
.42778 .05939 L
.42707 .05676 L
.4264 .05422 L
.42578 .05183 L
.4252 .04964 L
.42472 .04774 L
.4244 .04606 L
.4243 .0447 L
.42444 .04359 L
.42479 .04271 L
.42532 .04205 L
.42599 .04159 L
.42672 .0413 L
.42748 .04114 L
Mistroke
.42823 .04106 L
.42894 .04101 L
.4296 .04095 L
.43019 .04087 L
.43068 .04078 L
.43106 .04068 L
.43133 .0406 L
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
.43307 .04064 L
.43335 .04048 L
.43382 .04025 L
.43448 .03998 L
.43534 .0397 L
.43637 .03943 L
.43754 .03921 L
Mistroke
.43885 .03905 L
.44024 .03894 L
.44171 .03892 L
.44321 .03899 L
.44467 .03912 L
.44602 .03931 L
.44724 .03955 L
.44832 .03984 L
.44927 .04015 L
.45016 .04047 L
.45102 .04078 L
.45191 .04105 L
.45286 .04128 L
.45388 .04146 L
.45496 .0416 L
.45608 .04169 L
.45722 .04172 L
.45835 .04171 L
.45947 .04171 L
.46055 .04173 L
.46156 .04175 L
.46246 .04178 L
.46324 .04178 L
.46389 .04175 L
.46439 .04168 L
.46475 .04157 L
.46498 .04146 L
.46509 .04137 L
.46512 .04134 L
.4651 .04143 L
.46505 .04163 L
.46498 .04196 L
.46486 .04242 L
.46469 .04297 L
.46448 .04359 L
.46425 .04426 L
.46407 .04499 L
.46395 .04574 L
.46385 .04646 L
.46374 .0471 L
.46359 .04762 L
.46339 .04798 L
.4631 .04813 L
.46273 .04809 L
.46225 .04786 L
.46166 .04752 L
.46099 .04711 L
.46029 .04665 L
.45951 .04617 L
.45835 .04563 L
Mistroke
.4567 .04502 L
.45449 .04433 L
.45164 .04356 L
.44811 .04269 L
.44385 .04176 L
.43894 .0408 L
.43404 .03986 L
.4288 .03894 L
.42284 .038 L
.41795 .03703 L
.41344 .03615 L
.40839 .03549 L
.40265 .03513 L
.39665 .03518 L
.39067 .03577 L
.38493 .03701 L
.37922 .03878 L
.37305 .04089 L
.36755 .04324 L
.36178 .04578 L
.35587 .04856 L
.34996 .05128 L
.34411 .05408 L
.33826 .05703 L
.33245 .06012 L
.32698 .06319 L
.32216 .06607 L
.31799 .06872 L
.31434 .07102 L
.31078 .07338 L
.30743 .07547 L
.30411 .07756 L
.30036 .0799 L
.29585 .08257 L
.29084 .08546 L
.28594 .08831 L
.28065 .09136 L
.27527 .09448 L
.26979 .09772 L
.26435 .1009 L
.25891 .10423 L
.25335 .10776 L
.2482 .11112 L
.24337 .11445 L
.23907 .11748 L
.23546 .1202 L
.23243 .1226 L
.23001 .12462 L
.22812 .12627 L
.22673 .12756 L
Mistroke
.22583 .1285 L
.22535 .12913 L
.2252 .12952 L
.22526 .12972 L
.22545 .12979 L
.22564 .12981 L
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
Mistroke
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
.22685 .13587 L
.22657 .13606 L
.22601 .1364 L
.22512 .13692 L
.22387 .13764 L
.22223 .13858 L
.22017 .13978 L
.21766 .14134 L
.21476 .1433 L
.21143 .14569 L
.20776 .1485 L
.20384 .15173 L
.19974 .15541 L
.1955 .15952 L
.19137 .16386 L
.18725 .1688 L
.18328 .17352 L
.1794 .17904 L
.17569 .18416 L
.17208 .19002 L
.16862 .19535 L
.16522 .20125 L
.16193 .20671 L
.15865 .2127 L
.15536 .21809 L
.15198 .224 L
.14861 .22949 L
.14512 .23553 L
.14158 .24104 L
.13787 .24721 L
.13409 .25297 L
.13027 .2593 L
.12638 .2652 L
.12267 .27145 L
.11878 .27764 L
.11528 .28391 L
.1118 .29009 L
.10852 .29607 L
.10561 .30191 L
Mistroke
.10274 .30735 L
.10054 .31248 L
.09851 .31725 L
.09674 .32163 L
.09527 .32558 L
.09407 .32947 L
.09309 .33317 L
.09227 .33665 L
.09155 .34037 L
.09091 .34439 L
.09034 .34823 L
.08975 .35266 L
.0891 .35774 L
.08842 .36232 L
.08772 .3678 L
.08706 .37299 L
.08643 .37881 L
.08586 .38386 L
.08536 .38892 L
.08493 .39315 L
.08457 .39715 L
.0843 .4003 L
.08408 .40287 L
.08391 .40475 L
.08379 .40611 L
.08376 .40698 L
.08382 .40749 L
.08397 .40777 L
.08425 .40789 L
.08467 .40798 L
.08523 .40818 L
.08594 .40853 L
.08678 .40902 L
.08777 .40967 L
.08887 .41044 L
.09002 .41129 L
.09118 .41219 L
.09235 .41314 L
.09346 .41411 L
.09447 .41517 L
.09536 .41629 L
.09608 .41751 L
.09665 .41888 L
.09708 .42046 L
.09738 .42222 L
.09757 .42426 L
.09768 .4265 L
.0977 .42895 L
.09762 .43165 L
.09744 .43452 L
Mistroke
.09712 .43771 L
.09662 .44116 L
.09589 .44496 L
.09491 .4488 L
.0937 .45294 L
.09216 .45691 L
.0903 .46114 L
.08845 .46515 L
.0863 .4692 L
.08416 .47324 L
.08196 .47715 L
.07955 .48127 L
.07759 .48487 L
.07569 .48851 L
.07387 .49211 L
.07232 .4957 L
.07098 .49913 L
.0699 .50264 L
.06907 .50611 L
.0685 .50979 L
.06812 .51369 L
.06794 .51766 L
.06794 .52185 L
.06808 .52619 L
.06836 .53076 L
.06877 .53483 L
.06936 .53883 L
.06991 .54256 L
.07058 .54588 L
.07123 .54894 L
.07194 .55177 L
.07255 .55373 L
.07309 .55548 L
.07355 .55681 L
.07393 .5577 L
.0742 .5582 L
.07438 .55838 L
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
Mistroke
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
.07398 .55638 L
.07393 .55686 L
.07392 .55776 L
.07397 .5592 L
.07409 .56129 L
.07427 .56419 L
.07455 .56731 L
.07491 .57126 L
.07537 .57647 L
.07588 .58107 L
.07654 .58759 L
.07727 .59304 L
.07811 .5996 L
.07906 .60644 L
.08005 .6132 L
.08111 .61957 L
.08212 .62642 L
.08317 .63318 L
.08415 .6395 L
.08515 .64597 L
.08608 .65203 L
Mistroke
.08705 .65792 L
.0879 .66382 L
.08874 .6695 L
.08957 .6738 L
.09031 .67799 L
.09101 .68135 L
.09169 .68501 L
.0923 .6876 L
.09288 .68977 L
.09343 .69129 L
.09393 .69214 L
.09439 .69251 L
.09479 .69253 L
.09515 .69232 L
.09544 .69193 L
.09566 .69153 L
.09579 .69121 L
.09585 .69097 L
.09586 .69085 L
.09582 .69091 L
.09576 .69116 L
.09573 .69161 L
.09575 .69225 L
.09586 .69307 L
.09608 .69404 L
.0964 .69514 L
.09685 .69638 L
.09741 .69772 L
.09802 .69923 L
.09876 .70094 L
.09962 .7028 L
.10054 .70481 L
.10165 .70691 L
.10276 .7091 L
.10397 .71139 L
.10525 .71369 L
.10637 .71567 L
.10747 .71777 L
.10846 .71967 L
.10938 .72148 L
.11012 .72308 L
.11079 .72439 L
.11122 .72536 L
.11151 .72606 L
.11166 .72653 L
.11167 .72679 L
.1115 .72686 L
.11119 .72679 L
.11079 .72668 L
.1104 .7266 L
Mistroke
.11009 .72657 L
.10987 .72659 L
.10975 .72668 L
.10975 .72684 L
.10989 .72708 L
.11015 .72731 L
.11051 .72755 L
.11095 .72772 L
.11144 .72781 L
.11194 .72784 L
.11239 .72784 L
.11282 .72784 L
.11319 .72784 L
.11344 .72789 L
.11352 .72801 L
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
Mistroke
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
Mistroke
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
Mistroke
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
Mistroke
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
Mistroke
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
Mistroke
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
Mistroke
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
.10805 .7255 L
.10777 .72574 L
.10738 .72611 L
.10694 .72661 L
.10651 .72724 L
.10617 .72798 L
.10574 .72864 L
.10538 .72942 L
.10505 .73018 L
.10469 .73085 L
.10437 .73147 L
.10408 .73197 L
.10381 .73232 L
.1036 .73252 L
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
Mistroke
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
.10543 .73301 L
.10527 .73344 L
.10506 .73406 L
.10481 .73486 L
.10454 .73582 L
.10425 .73691 L
.10394 .73803 L
.10362 .7392 L
.10329 .74041 L
.10299 .74161 L
.10272 .74272 L
.10252 .74364 L
.1024 .74438 L
.10237 .74494 L
.10244 .74535 L
.1026 .74563 L
.10284 .74579 L
.10316 .74589 L
.10356 .74601 L
.10405 .74623 L
.10465 .74657 L
Mistroke
.10538 .74704 L
.10624 .74764 L
.10719 .7484 L
.10822 .7493 L
.10932 .75031 L
.11038 .75137 L
.11142 .75244 L
.11232 .75338 L
.11315 .75422 L
.11381 .75485 L
.11436 .75534 L
.1148 .7557 L
.11512 .7559 L
.11532 .75601 L
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
Mistroke
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
.11503 .75556 L
.11528 .75611 L
.11577 .75703 L
.11655 .75833 L
.11762 .76011 L
.1191 .76215 L
.12092 .76468 L
.12337 .76775 L
.12595 .77102 L
.12931 .7742 L
.13301 .77804 L
.1369 .78178 L
.14116 .78643 L
.14575 .79057 L
.15027 .7951 L
.15487 .79971 L
.15947 .80419 L
.16398 .8087 L
.16831 .81339 L
.17274 .81765 L
.17675 .82193 L
.1807 .82589 L
.18462 .82986 L
.18827 .83371 L
.19179 .83736 L
.19519 .84085 L
.19824 .84386 L
.20111 .84665 L
.20377 .84906 L
.20595 .85097 L
.20788 .85259 L
.20949 .85388 L
.21076 .85478 L
.21166 .85534 L
.21222 .85558 L
.21248 .85562 L
.21254 .85555 L
.2125 .85544 L
Mistroke
.21241 .85535 L
.21234 .85531 L
.21234 .85536 L
.21246 .85552 L
.2127 .85583 L
.21305 .85626 L
.21353 .85684 L
.21411 .85752 L
.2148 .85826 L
.21557 .85899 L
.21639 .85972 L
.21729 .86045 L
.21831 .86117 L
.21951 .86194 L
.22089 .86288 L
.22255 .86407 L
.22444 .86548 L
.2266 .8671 L
.22903 .86903 L
.23176 .87136 L
.23479 .87377 L
.23816 .87665 L
.24175 .87968 L
.24592 .88304 L
.24975 .8863 L
.25405 .89002 L
.25866 .8932 L
.2634 .89649 L
.26822 .89967 L
.2733 .90284 L
.2787 .906 L
.28419 .90866 L
.28996 .91136 L
.29576 .91399 L
.30197 .91645 L
.30834 .91896 L
.31442 .92127 L
.32071 .92357 L
.32658 .92576 L
.33245 .9279 L
.33814 .92993 L
.34353 .93188 L
.34908 .93381 L
.35384 .93555 L
.35895 .93725 L
.36371 .93887 L
.36876 .94041 L
.3733 .94192 L
.37804 .94338 L
.383 .94485 L
Mistroke
.38783 .94636 L
.39314 .94796 L
.39826 .94958 L
.40365 .9513 L
.40883 .95312 L
.41423 .95491 L
.41999 .95678 L
.42483 .95848 L
.43002 .96017 L
.43503 .96173 L
.44003 .96311 L
.44511 .96428 L
.45001 .96526 L
.45504 .96601 L
.46025 .96649 L
.46542 .96676 L
.4708 .96681 L
.47637 .96666 L
.48219 .96633 L
.48774 .96587 L
.49358 .96535 L
.4992 .96477 L
.5049 .96415 L
.5104 .96349 L
.51587 .96279 L
.52192 .96202 L
.52701 .96121 L
.53274 .96033 L
.53837 .95938 L
.54465 .95837 L
.54992 .95735 L
.55592 .9563 L
.56221 .95521 L
.56793 .95414 L
.57424 .95298 L
.58069 .95175 L
.5874 .95049 L
.5936 .94922 L
.60012 .94799 L
.60672 .94681 L
.61294 .94568 L
.61914 .94463 L
.62533 .94363 L
.63127 .94264 L
.63736 .94167 L
.64301 .94062 L
.64885 .93952 L
.65433 .93837 L
.65973 .93715 L
.66496 .93582 L
Mistroke
.67018 .93434 L
.67553 .93261 L
.68036 .9305 L
.68548 .92816 L
.69071 .92545 L
.69625 .92216 L
.7009 .91934 L
.70593 .91582 L
.71085 .91259 L
.71579 .90881 L
.72025 .90602 L
.72441 .90292 L
.72814 .90006 L
.73129 .89793 L
.73397 .89586 L
.73594 .8943 L
.73735 .89307 L
.7382 .89224 L
.73856 .89181 L
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
Mistroke
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
.73413 .89364 L
.73439 .89364 L
.7348 .89353 L
.73535 .89332 L
.73604 .89302 L
.73684 .89266 L
.7377 .89223 L
.73855 .89175 L
.7394 .8912 L
.74023 .89058 L
.74104 .88988 L
.74179 .8891 L
.74244 .88826 L
.74297 .88738 L
.74336 .88649 L
.74363 .88563 L
.74378 .88482 L
.74385 .88408 L
.74386 .88339 L
.74383 .88274 L
.74377 .88214 L
.74369 .8816 L
.74362 .88112 L
.74358 .88072 L
.74359 .88044 L
.74368 .88029 L
.74382 .88028 L
.74399 .88037 L
.74414 .88055 L
.74424 .88076 L
.74429 .88099 L
.74424 .88119 L
.74409 .88136 L
.74386 .88149 L
.74357 .8816 L
.74327 .88168 L
.74294 .88174 L
.74269 .88182 L
.74249 .88194 L
.74235 .88206 L
.74229 .88216 L
.74232 .88219 L
.74251 .88213 L
.74288 .88196 L
Mistroke
.74349 .88166 L
.74437 .88117 L
.74556 .88044 L
.74708 .87942 L
.74896 .87798 L
.75117 .8761 L
.75394 .87393 L
.75687 .87155 L
.76054 .86871 L
.76423 .86557 L
.76849 .86225 L
.77314 .85865 L
.77813 .85496 L
.78303 .85135 L
.78804 .84783 L
.79315 .84409 L
.79746 .84119 L
.80159 .83827 L
.80533 .8356 L
.80826 .83324 L
.81082 .83145 L
.8127 .82991 L
.81402 .82891 L
.81491 .82821 L
.81538 .82777 L
.81544 .82761 L
.81521 .82769 L
.81481 .82794 L
.81432 .82829 L
.81382 .82872 L
.81336 .82916 L
.81299 .82959 L
.81275 .82998 L
.81264 .83023 L
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
Mistroke
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
Mistroke
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
Mistroke
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
.81302 .83034 L
.81254 .83043 L
.8119 .83049 L
.81114 .83054 L
.81032 .8306 L
.80948 .8307 L
.80866 .83084 L
.80784 .83104 L
.80701 .8313 L
.8062 .83163 L
.80543 .83201 L
.80475 .83243 L
.80418 .83287 L
.80375 .83333 L
.80345 .83377 L
.80327 .83421 L
.80321 .83467 L
.80323 .83512 L
.80328 .83556 L
.80336 .83592 L
.80348 .83614 L
.80365 .83618 L
.80388 .83601 L
.80414 .83566 L
.80447 .83519 L
.80485 .83466 L
.80525 .83414 L
.80564 .83367 L
.80598 .83329 L
.80621 .83303 L
.80626 .83291 L
.80609 .83299 L
.80568 .83331 L
.80496 .83392 L
.80389 .83486 L
.80246 .83615 L
.80064 .83779 L
.79855 .83982 L
.79601 .84219 L
Mistroke
.79301 .84491 L
.78964 .84792 L
.78576 .85125 L
.78159 .85476 L
.77711 .85848 L
.77236 .86238 L
.76741 .86625 L
.76239 .87045 L
.75739 .8745 L
.75225 .87883 L
.74653 .88321 L
.74167 .88729 L
.73622 .89162 L
.7309 .89561 L
.72536 .89973 L
.7195 .90383 L
.71494 .90716 L
.70987 .91072 L
.70471 .91401 L
.69991 .91724 L
.69491 .92046 L
.69068 .92304 L
.68654 .92573 L
.68208 .9282 L
.67801 .93022 L
.674 .93201 L
.67007 .93354 L
.66611 .93481 L
.66221 .93587 L
.65807 .93678 L
.65413 .93756 L
.65 .93821 L
.64589 .93868 L
.64196 .93903 L
.63785 .93925 L
.63419 .93935 L
.6304 .93938 L
.62686 .93934 L
.62324 .93921 L
.62007 .93899 L
.61691 .93867 L
.61376 .93825 L
.6109 .93775 L
.60796 .93715 L
.60483 .93649 L
.60171 .93577 L
.59851 .93501 L
.59524 .93418 L
.59173 .93331 L
.58838 .93242 L
Mistroke
.58493 .93153 L
.58136 .93061 L
.5782 .92967 L
.5751 .92868 L
.57194 .92762 L
.56925 .92653 L
.56669 .92547 L
.56435 .92439 L
.56233 .92334 L
.56073 .9223 L
.55964 .92129 L
.55894 .92035 L
.55855 .91951 L
.55838 .9188 L
.55836 .91826 L
.55839 .91793 L
.55838 .91783 L
.55823 .91796 L
.5578 .91834 L
.55702 .91905 L
.55589 .92013 L
.55433 .92159 L
.55242 .92328 L
.54995 .92529 L
.54693 .92752 L
.54347 .92983 L
.5395 .93213 L
.53523 .93458 L
.53063 .93686 L
.5253 .939 L
.52102 .94121 L
.51576 .94276 L
.51101 .94386 L
.50579 .94497 L
.50071 .94566 L
.49549 .94606 L
.49007 .94637 L
.48447 .94635 L
.47908 .94626 L
.47316 .94618 L
.46739 .94613 L
.46178 .94617 L
.45541 .94632 L
.45006 .94657 L
.44417 .94693 L
.4387 .94733 L
.43314 .94775 L
.42772 .94818 L
.42249 .94864 L
.41785 .94897 L
Mistroke
.41333 .94911 L
.40916 .94896 L
.40512 .94844 L
.40138 .94752 L
.3975 .94628 L
.3938 .94472 L
.38984 .94292 L
.38594 .94101 L
.38197 .93895 L
.37776 .93682 L
.37326 .93473 L
.36884 .9327 L
.36421 .93079 L
.35903 .92906 L
.3545 .92763 L
.34939 .92641 L
.34419 .92533 L
.33925 .92436 L
.33408 .92346 L
.32903 .92253 L
.32424 .92146 L
.31903 .92019 L
.31439 .91869 L
.3096 .91696 L
.3046 .91494 L
.30017 .91263 L
.29553 .91017 L
.29126 .90766 L
.28684 .90497 L
.28294 .90221 L
.27895 .89944 L
.27507 .89671 L
.2714 .89412 L
.26762 .8916 L
.26412 .88927 L
.26067 .88715 L
.25718 .88512 L
.25407 .88319 L
.25098 .88149 L
.24839 .87998 L
.24607 .87866 L
.24404 .87757 L
.24238 .8767 L
.24106 .87602 L
.24007 .87552 L
.23941 .87517 L
.23901 .87493 L
.23882 .87478 L
.23876 .87471 L
.2388 .87473 L
Mistroke
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
.24006 .8739 L
.24006 .87414 L
.24004 .87443 L
.24002 .87474 L
.23992 .87497 L
.23965 .87506 L
.2391 .87493 L
.23823 .87459 L
.23699 .87395 L
.23527 .87298 L
Mistroke
.23323 .87164 L
.23067 .86989 L
.22763 .86774 L
.22465 .86548 L
.22154 .86292 L
.21771 .86007 L
.2145 .85722 L
.21104 .85419 L
.20764 .85125 L
.20442 .84843 L
.20154 .8458 L
.19905 .84334 L
.19708 .84123 L
.19549 .83938 L
.1943 .83789 L
.19345 .83668 L
.19289 .83574 L
.1925 .83502 L
.19225 .83449 L
.19213 .83408 L
.1921 .83373 L
.19211 .83336 L
.19211 .83291 L
.19205 .83228 L
.1919 .83144 L
.19166 .83033 L
.1913 .82898 L
.19075 .82725 L
.18995 .82508 L
.18884 .82262 L
.18743 .81962 L
.18569 .81644 L
.18366 .81288 L
.18136 .80915 L
.17872 .80525 L
.17581 .80121 L
.1732 .79733 L
.17024 .79337 L
.16692 .78932 L
.16391 .78564 L
.16068 .78189 L
.1574 .77826 L
.1543 .77486 L
.15116 .7716 L
.14828 .76862 L
.1455 .76584 L
.14281 .76335 L
.14049 .76111 L
.13816 .75912 L
.13615 .75738 L
Mistroke
.13428 .7558 L
.13259 .75436 L
.13118 .75304 L
.13006 .75169 L
.12926 .75024 L
.12868 .74887 L
.12834 .7475 L
.12818 .74611 L
.12816 .74476 L
.12825 .74364 L
.12838 .74249 L
.12854 .74147 L
.12874 .74047 L
.12896 .73946 L
.12918 .73862 L
.12935 .73787 L
.12944 .73707 L
.12945 .73626 L
.12934 .73541 L
.12905 .73444 L
.12853 .73328 L
.12774 .73164 L
.12665 .72953 L
.12531 .72717 L
.12364 .72438 L
.12165 .72122 L
.11932 .71766 L
.11686 .71401 L
.1142 .71017 L
.11138 .70639 L
.10849 .70267 L
.10599 .69891 L
.10341 .69522 L
.10102 .69194 L
.09882 .68857 L
.09686 .68527 L
.09517 .68195 L
.09375 .67876 L
.09258 .67538 L
.09169 .67192 L
.091 .66808 L
.0905 .66432 L
.09015 .66034 L
.08992 .65602 L
.08977 .65135 L
.08967 .64651 L
.08961 .6421 L
.08961 .63725 L
.08963 .63254 L
.08969 .62794 L
Mistroke
.08981 .62372 L
.09 .61949 L
.09028 .61571 L
.09068 .61225 L
.09123 .60889 L
.09196 .60597 L
.09289 .60309 L
.09398 .60056 L
.09529 .5982 L
.09675 .59601 L
.09833 .59408 L
.09992 .59233 L
.10147 .59077 L
.10297 .58946 L
.10437 .58835 L
.10562 .58739 L
.10678 .58658 L
.10785 .5859 L
.10883 .58533 L
.10979 .58485 L
.11078 .58442 L
.11183 .58403 L
.11295 .58368 L
.11422 .58332 L
.11559 .58293 L
.11712 .58248 L
.1188 .58192 L
.12058 .58124 L
.12244 .58047 L
.12434 .57967 L
.12627 .57887 L
.12816 .57806 L
.13007 .57726 L
.13202 .57646 L
.13403 .5756 L
.13621 .57465 L
.13836 .57357 L
.14067 .57238 L
.14306 .57104 L
.14545 .56959 L
.1478 .56812 L
.15002 .5668 L
.152 .56546 L
.15384 .56419 L
.15542 .56307 L
.1567 .56203 L
.15776 .56113 L
.15861 .56047 L
.15931 .5601 L
.15995 .56006 L
Mistroke
.1606 .56037 L
.16139 .56103 L
.16249 .56204 L
.16398 .56337 L
.16564 .56491 L
.1677 .56669 L
.17022 .56874 L
.17286 .57076 L
.17592 .57317 L
.17886 .57526 L
.18169 .57743 L
.18448 .57964 L
.18709 .58161 L
.18958 .58335 L
.19162 .58493 L
.19347 .58624 L
.19514 .58724 L
.19661 .58801 L
.19795 .58857 L
.19915 .58892 L
.20029 .58911 L
.20138 .58917 L
.2024 .58912 L
.20338 .58899 L
.20433 .58883 L
.20522 .58865 L
.20606 .58846 L
.20677 .58828 L
.20734 .58814 L
.20777 .58804 L
.20808 .588 L
.20833 .58801 L
.20853 .58809 L
.20871 .58823 L
.20896 .58847 L
.20932 .58884 L
.20985 .58937 L
.21059 .59009 L
.21157 .59101 L
.21287 .59209 L
.21449 .59338 L
.21651 .59483 L
.21895 .59641 L
.22188 .59814 L
.22504 .59977 L
.22873 .60162 L
.23262 .60349 L
.23709 .6053 L
.24151 .60721 L
.24629 .60917 L
Mistroke
.25126 .6111 L
.25648 .61314 L
.26153 .61507 L
.26704 .61709 L
.27218 .61918 L
.27757 .62126 L
.28284 .62358 L
.28813 .62577 L
.29367 .62822 L
.2987 .63075 L
.30407 .63327 L
.30926 .63595 L
.31449 .63855 L
.31985 .64126 L
.32461 .64396 L
.32972 .64664 L
.33448 .64925 L
.33921 .65181 L
.34378 .65439 L
.34818 .65676 L
.35241 .65921 L
.35674 .66148 L
.36072 .66385 L
.36472 .66605 L
.36873 .6683 L
.37274 .6706 L
.37691 .67295 L
.38079 .67498 L
.38486 .67714 L
.38913 .67973 L
.39321 .682 L
.39748 .68452 L
.40188 .68722 L
.40658 .69002 L
.41073 .69309 L
.4154 .69607 L
.41997 .69942 L
.42429 .70283 L
.42885 .70648 L
.43326 .71041 L
.43771 .71478 L
.44186 .71899 L
.44599 .72355 L
.45 .72823 L
.45403 .73327 L
.45764 .7383 L
.46131 .74323 L
.4648 .74859 L
.46824 .75347 L
.47141 .75861 L
Mistroke
.4745 .76343 L
.47744 .76861 L
.4803 .77285 L
.48292 .77724 L
.48543 .78128 L
.48775 .7848 L
.48988 .78805 L
.49177 .79069 L
.49336 .79292 L
.49462 .7946 L
.49551 .79576 L
.4961 .7965 L
.49643 .7969 L
.4966 .79705 L
.49667 .79705 L
.49674 .79699 L
.49692 .79695 L
.49726 .79698 L
.49782 .79708 L
.4987 .7973 L
.49994 .79767 L
.50167 .79829 L
.50379 .79916 L
.50644 .8002 L
.50949 .80144 L
.5129 .80285 L
.51666 .80424 L
.52069 .8057 L
.52494 .80723 L
.52909 .80872 L
.53342 .81018 L
.5378 .81177 L
.54158 .81324 L
.54547 .81475 L
.54915 .81625 L
.55279 .81767 L
.55606 .81903 L
.55945 .82016 L
.5626 .82126 L
.56572 .82217 L
.56898 .82297 L
.57233 .82372 L
.57589 .82443 L
.57982 .82512 L
.5833 .82577 L
.5873 .82639 L
.59147 .82698 L
.59565 .82753 L
.59997 .82811 L
.60431 .82873 L
Mistroke
.60854 .8294 L
.61242 .83009 L
.61604 .83076 L
.61946 .83138 L
.62229 .83188 L
.62504 .83223 L
.62745 .83238 L
.62962 .83234 L
.63172 .8321 L
.6337 .83166 L
.63576 .83102 L
.6378 .83015 L
.63965 .82906 L
.64181 .82771 L
.64438 .82615 L
.64699 .8244 L
.65015 .8223 L
.65356 .8202 L
.65751 .81785 L
.66115 .81546 L
.66521 .81283 L
.66944 .81017 L
.6733 .80771 L
.6774 .805 L
.68151 .80228 L
.68573 .79944 L
.68975 .79657 L
.69382 .7936 L
.6979 .79051 L
.70163 .78724 L
.70536 .78412 L
.70885 .78076 L
.71224 .77771 L
.71548 .7743 L
.71856 .77117 L
.72162 .76782 L
.72462 .76442 L
.72745 .76147 L
.7304 .75822 L
.73338 .75526 L
.73642 .75218 L
.73952 .74937 L
.74261 .74688 L
.74581 .74445 L
.7492 .74223 L
.75267 .74015 L
.75632 .73838 L
.76011 .73673 L
.76394 .73532 L
.76801 .73411 L
Mistroke
.77212 .73318 L
.77654 .73252 L
.78047 .73215 L
.78467 .73201 L
.78896 .73209 L
.79316 .73234 L
.79741 .73273 L
.80161 .73324 L
.80584 .73386 L
.8097 .73459 L
.81348 .7354 L
.81694 .73628 L
.82014 .73721 L
.82326 .73808 L
.82617 .7388 L
.82879 .73934 L
.83125 .73964 L
.8337 .7397 L
.83588 .73945 L
.83806 .73888 L
.84025 .738 L
.84246 .73682 L
.84472 .73535 L
.84715 .73366 L
.84944 .73176 L
.85195 .72958 L
.85459 .72723 L
.85747 .72468 L
.86011 .72209 L
.86295 .7194 L
.86589 .71667 L
.86848 .71396 L
.8712 .71121 L
.8739 .7085 L
.87673 .70571 L
.8792 .70281 L
.88182 .69969 L
.88441 .69634 L
.88695 .69285 L
.88948 .68913 L
.89196 .68526 L
.89432 .68119 L
.89666 .67687 L
.89883 .67254 L
.90088 .66813 L
.90271 .66369 L
.90433 .65927 L
.90579 .65455 L
.90705 .65022 L
.90809 .64595 L
Mistroke
.90899 .64177 L
.9098 .63772 L
.91054 .63371 L
.91127 .62967 L
.91205 .62553 L
.91296 .62119 L
.91403 .61638 L
.91532 .6116 L
.91678 .6062 L
.91841 .60069 L
.92023 .59441 L
.92202 .58868 L
.92385 .58225 L
.92557 .57528 L
.92714 .56903 L
.92845 .56214 L
.92953 .55515 L
.93034 .54762 L
.93088 .54105 L
.93116 .53382 L
.93119 .52656 L
.93098 .51961 L
.93056 .51231 L
.92996 .50483 L
.92921 .49747 L
.92839 .48992 L
.92752 .48245 L
.92664 .47559 L
.9258 .46888 L
.92503 .46244 L
.92437 .45669 L
.92377 .45152 L
.92325 .44732 L
.9228 .44344 L
.9224 .44041 L
.92207 .43796 L
.92179 .43597 L
.92159 .43436 L
.92144 .43298 L
.92135 .43158 L
.92128 .42989 L
.92124 .42781 L
.92118 .42534 L
.92108 .42216 L
.9209 .41846 L
.92061 .4142 L
.9202 .40912 L
.91964 .40353 L
.91895 .39708 L
.91812 .39089 L
Mistroke
.91719 .38409 L
.91616 .37651 L
.9151 .37013 L
.91402 .36326 L
.91295 .35631 L
.91195 .35053 L
.91102 .34481 L
.91018 .3394 L
.90947 .33504 L
.90888 .33107 L
.90843 .32783 L
.90811 .32529 L
.90793 .32348 L
.90786 .32231 L
.90787 .32172 L
.90793 .32161 L
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
.90869 .32632 L
.90847 .32593 L
.90807 .32516 L
.90745 .32394 L
.90661 .32223 L
.90554 .32003 L
.9043 .31736 L
.90286 .3143 L
.90117 .31067 L
.89927 .30657 L
.89707 .30232 L
.89469 .2973 L
.89213 .29208 L
.88927 .28621 L
.88626 .28037 L
.88296 .27415 L
.87971 .2678 L
.87636 .26154 L
.87284 .25509 L
.86947 .24927 L
.86608 .24352 L
.86275 .23799 L
.85968 .23335 L
.85704 .22909 L
Mistroke
.85455 .22521 L
.85234 .22178 L
.8505 .21907 L
.84887 .21681 L
.8475 .21493 L
.84618 .21323 L
.84479 .21154 L
.84327 .2098 L
.84158 .20782 L
.83989 .20556 L
.83775 .20281 L
.83544 .19963 L
.83289 .19621 L
.83014 .19232 L
.82732 .18823 L
.82412 .18368 L
.82119 .17933 L
.81826 .17515 L
.81526 .17054 L
.81231 .16603 L
.80939 .16143 L
.8065 .15729 L
.80361 .15291 L
.80105 .14916 L
.79845 .14551 L
.79595 .14208 L
.79356 .13885 L
.79122 .13579 L
.7891 .1332 L
.78707 .13079 L
.7852 .12861 L
.78348 .12676 L
.78186 .12508 L
.78034 .1236 L
.77888 .12234 L
.77731 .1212 L
.77553 .12011 L
.77344 .11902 L
.77106 .1179 L
.76841 .11664 L
.76531 .11519 L
.76186 .11359 L
.75827 .11181 L
.75435 .10993 L
.75038 .1079 L
.74624 .10586 L
.7418 .10373 L
.73769 .10155 L
.73332 .0994 L
.72875 .09721 L
Mistroke
.72448 .09517 L
.72003 .09314 L
.71535 .09114 L
.71092 .08918 L
.70637 .08727 L
.70176 .08537 L
.69704 .08356 L
.69237 .08175 L
.68782 .07998 L
.68336 .07822 L
.67891 .07654 L
.67491 .07487 L
.67095 .07326 L
.66697 .07171 L
.66361 .07028 L
.66022 .06889 L
.65676 .06755 L
.6534 .06627 L
.64992 .06501 L
.64629 .06374 L
.64219 .06242 L
.63808 .06106 L
.63374 .05962 L
.62877 .05803 L
.62419 .05633 L
.61883 .05449 L
.61397 .05258 L
.60883 .05058 L
.60369 .04862 L
.59861 .04666 L
.59387 .04477 L
.58905 .043 L
.58425 .0414 L
.57963 .03997 L
.575 .03872 L
.57041 .03769 L
.56556 .03684 L
.56088 .03617 L
.55559 .03566 L
.55048 .03529 L
.54565 .03504 L
.54007 .03487 L
.53482 .03475 L
.52884 .03463 L
.52369 .03449 L
.51782 .03432 L
.5125 .03413 L
.50653 .03395 L
.50133 .0338 L
.4955 .03373 L
Mistroke
.49023 .03373 L
.48474 .03383 L
.47952 .03399 L
.47417 .03421 L
.46879 .03448 L
.46361 .03477 L
.45845 .03506 L
.45283 .03536 L
.44796 .03563 L
.44241 .03585 L
.43738 .03599 L
.43209 .03604 L
.42656 .03601 L
.42146 .03592 L
.41616 .03579 L
.41074 .03566 L
.40585 .03559 L
.40049 .03561 L
.39595 .03575 L
.39101 .03603 L
.38688 .03642 L
.38271 .03689 L
.37911 .0374 L
.37573 .03794 L
.37294 .0385 L
.37049 .03905 L
.36847 .03957 L
.3669 .04005 L
.3657 .04047 L
.36486 .04081 L
.36437 .04104 L
.36416 .04116 L
.36417 .0412 L
.36436 .04117 L
.36467 .04113 L
.36502 .0411 L
.36538 .04114 L
.36567 .04125 L
.36596 .04144 L
.36622 .04167 L
.36647 .04193 L
.36672 .04221 L
.36697 .04252 L
.36721 .04284 L
.36741 .04317 L
.36761 .04343 L
.36783 .0436 L
.36807 .04367 L
.36832 .04365 L
.36855 .04355 L
Mistroke
.36871 .04337 L
.36873 .04316 L
.3685 .04297 L
.36796 .04286 L
.36708 .04288 L
.3658 .04307 L
.36409 .04351 L
.36195 .04422 L
.35968 .04514 L
.35688 .04645 L
.35352 .04795 L
.35018 .04974 L
.34629 .05185 L
.34206 .0541 L
.33798 .05657 L
.33338 .05915 L
.32895 .06178 L
.32455 .06445 L
.31996 .06708 L
.31561 .06974 L
.31113 .07243 L
.30661 .07521 L
.30204 .07797 L
.2976 .08074 L
.29313 .08347 L
.28891 .08621 L
.28486 .08876 L
.28107 .09125 L
.2776 .09357 L
.27447 .09571 L
.27175 .09759 L
.26938 .0993 L
.26752 .10065 L
.26599 .10178 L
.26484 .10265 L
.26406 .10326 L
.26361 .10363 L
.26343 .10379 L
.26345 .10379 L
.2636 .10369 L
.26382 .10356 L
.26404 .1034 L
.26423 .10327 L
.26435 .10317 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
Mistroke
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.2644 .10313 L
.26446 .10311 L
.26458 .10306 L
.26477 .10296 L
.26499 .10283 L
.26522 .10267 L
.26541 .10251 L
.26549 .10241 L
.26538 .1024 L
.265 .10252 L
.26427 .10283 L
.26307 .10343 L
.26136 .10434 L
.25911 .10557 L
.25656 .10709 L
.25335 .10895 L
.24953 .1112 L
.24543 .11372 L
.24085 .11658 L
.23577 .11961 L
.23105 .12295 L
.22614 .12626 L
.22098 .12991 L
.21674 .13312 L
.21232 .13661 L
.2082 .14015 L
.20431 .14383 L
.20087 .14737 L
.19751 .15107 L
.1943 .15511 L
.19138 .15904 L
.18851 .16293 L
.18561 .16758 L
.1829 .17202 L
.18013 .17672 L
.1773 .18134 L
.17435 .18661 L
.17119 .1921 L
.1683 .19719 L
.16496 .20315 L
.1619 .20816 L
.15861 .21405 L
.15555 .21926 L
Mistroke
.15234 .22515 L
.14911 .23024 L
.14588 .2356 L
.14279 .24104 L
.13961 .2459 L
.13637 .25122 L
.1335 .25558 L
.13043 .26021 L
.1277 .2646 L
.12504 .26858 L
.12234 .27266 L
.12009 .27623 L
.11788 .27967 L
.11582 .28297 L
.11397 .28583 L
.11217 .2887 L
.1105 .29137 L
.1089 .29408 L
.10743 .29672 L
.10605 .2994 L
.10468 .30217 L
.1033 .30508 L
.1019 .3083 L
.10059 .3114 L
.09923 .31485 L
.09782 .31844 L
.09645 .32226 L
.09517 .32588 L
.09399 .32968 L
.09299 .33303 L
.09212 .33645 L
.09141 .33923 L
.09084 .3418 L
.09042 .34409 L
.09014 .34585 L
.08996 .34722 L
.08985 .34825 L
.08982 .34897 L
.08985 .34942 L
.08992 .34962 L
.09 .34966 L
.09008 .34958 L
.09013 .34947 L
.09015 .34936 L
.09016 .34926 L
.09016 .34917 L
.09016 .3491 L
.09016 .34906 L
.09016 .34903 L
.09016 .34903 L
Mistroke
.09016 .34902 L
.09016 .34898 L
.09016 .3489 L
.09018 .34878 L
.09022 .34857 L
.09028 .34823 L
.09035 .34786 L
.09041 .34765 L
.09043 .34768 L
.09039 .34804 L
.09027 .34886 L
.09005 .35028 L
.08973 .35255 L
.08932 .35583 L
.08883 .35931 L
.08829 .364 L
.08773 .36867 L
.08713 .37356 L
.08653 .37866 L
.08596 .38364 L
.08542 .38909 L
.08495 .39451 L
.08456 .39878 L
.08427 .40275 L
.08408 .40595 L
.08399 .40831 L
.08398 .41003 L
.08402 .41113 L
.08408 .41164 L
.08414 .41164 L
.08418 .41136 L
.08421 .41093 L
.08422 .41048 L
.08423 .41004 L
.08423 .40969 L
.08423 .4095 L
.08423 .40944 L
.08423 .40955 L
.08423 .40974 L
.08422 .41001 L
.08422 .4103 L
.08421 .41061 L
.08421 .4109 L
.0842 .41115 L
.0842 .41134 L
.08419 .41149 L
.08419 .41162 L
.08419 .4117 L
.08419 .41171 L
.08419 .41166 L
Mistroke
.08419 .41157 L
.0842 .41145 L
.0842 .41127 L
.0842 .41103 L
.08421 .41074 L
.08421 .4104 L
.08422 .41002 L
.08423 .4096 L
.08424 .40916 L
.08424 .40871 L
.08425 .40831 L
.08426 .40797 L
.08426 .40777 L
.08426 .4077 L
.08426 .40777 L
.08426 .40795 L
.08425 .40824 L
.08425 .40859 L
.08424 .40898 L
.08423 .40936 L
.08423 .40973 L
.08422 .41007 L
.08422 .41039 L
.08421 .4107 L
.08421 .411 L
.0842 .4114 L
.0842 .41159 L
.08419 .41169 L
.08419 .41167 L
.0842 .4115 L
.0842 .41123 L
.08421 .41087 L
.08422 .41042 L
.08423 .40988 L
.08424 .40929 L
.08424 .40874 L
.08422 .40829 L
.08419 .4079 L
.08415 .40757 L
.08413 .4074 L
.08412 .40736 L
.08413 .40746 L
.08416 .4077 L
.08421 .40808 L
.0843 .40856 L
.08443 .40909 L
.08464 .40962 L
.08496 .41011 L
.08545 .41054 L
.08605 .4109 L
Mistroke
.08679 .41119 L
.08768 .41142 L
.08872 .41169 L
.08985 .41207 L
.09081 .41262 L
.09182 .41335 L
.09293 .4143 L
.09384 .41551 L
.09483 .41696 L
.09559 .41868 L
.09628 .42072 L
.09684 .42295 L
.09723 .4255 L
.09742 .42835 L
.09741 .43145 L
.0972 .43474 L
.09681 .43829 L
.09626 .4419 L
.09557 .44587 L
.09479 .44925 L
.09402 .45304 L
.09316 .4561 L
.09226 .45923 L
.09145 .462 L
.09056 .4645 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{617, 293.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009Y00019A000`40O003h00OogooogooJgoo003o
OoooOom[Ool00?mooomoof]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00ogooogoo
Jgoo003oOoooOom[Ool00?mooomoof]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00
ogooogooJgoo002?OolG003oOolMOolG002@Ool008Moo`P001Moo`T00?moo`]oo`T000=oo`80019o
o`P008Qoo`00PGoo1P00:7oo1P00nGoo0P000goo7`000goo00<007ooOol00goo0P000Woo2000PWoo
001nOol3000dOol3003cOoli0003Ool3001oOol007]oo`@00003Ool007oo03Ioo`<00>iooaT0009o
o`D000Eoo`T000Ioo`T000Aoo`<007aoo`00MGoo1P000Woo1@000Woo10000goo00H007ooOol007oo
000:Ool20002Ool00`00Oomoo`0IOol5003XOol:00000goo000000020002OolF00000goo001oo`02
Ool60008Ool70004Ool6001fOol0079oo`<000QoobL00003Ool0000000<000=oo`H000eoo`<00>9o
o`L00003Ool00000009oo`H0009oo`<0009oo`/000Yoo`/000Qoo`H000Moo`<007=oo`00Kgoo0`00
27oo50000Woo9P003Goo0`00g7oo30001Woo1`002goo00<007ooOol02Woo00<007ooOol01Woo1P00
1Woo1P0027oo0`00L7oo001]Ool2000:OolG00000goo000000020002Ool60009OolA000?Ool2003H
Ool7000COol00`00Oomoo`09Ool00`00Oomoo`0EOol:0002Ool70008Ool2001^Ool006]oo`8000Yo
oaD000Eoo`80009oo`80009oo`800003Ool0000000P000Eoo`03001oo`0000/000moo`800=Aoo`80
0004Ool00000000FOol00`00Oomoo`0:Ool00`00Oomoo`0LOol>0007Ool2001/Ool006Uoo`8000Yo
o`H000=oo`80009oo`D0009oo`@000Eoo`03001oo`0000@00003Ool007oo00P000Ioo`@000Ioo`P0
00ioo`800=1oo`800003Ool00000008001Moo`8000]oo`03001oogoo02Aoo`P000Moo`8006Yoo`00
IWoo0`002Goo1P0000=oo`00Ool017oo0`000Woo0`001Goo10000Woo0P001Goo100037oo00<007oo
Ool02Woo20003Woo0`00bWoo20006Woo00<007ooOol02Woo00<007ooOol09Goo20001goo0P00J7oo
001TOol2000;Ool500000goo00000006Ool20005Ool00`00Oomoo`06Ool50006Ool00`00Oomoo`0;
Ool2000>Ool200000goo00000004000>Ool30034Ool30003Ool4000KOol3000:Ool00`00Oomoo`0X
Ool80006Ool3001UOol0069oo`8000aoo`D00003Ool007oo00Aoo`D000Eoo`03001oogoo00Moo`80
00Qoo`03001oogoo00Yoo`03001oogoo011oo`80009oo`L000eoo`03001oogoo0<1oo`03001oogoo
00=oo`@001aoo`<000Yoo`03001oogoo02eoo`D000Moo`8006=oo`00H7oo0P002Woo4@000goo00<0
07ooOol00goo00<007ooOol01Woo0P0000=oo`00Ool01Woo00<007ooOol02Goo00<007ooOol04goo
00<007ooOol01`003Goo0P00_Woo0P0000=oo`0000001`006goo0P003Goo00<007ooOol0;Goo1P00
1goo0P00HGoo001NOol2000:Ool700000goo000000030009Ool20003Ool20007Ool20003Ool30004
Ool00`00Oomoo`07Ool3000FOol300000goo00000005000=Ool2002jOol20004Ool6000MOol00`00
Oomoo`0<Ool00`00Oomoo`0^Ool80006Ool2001OOol005eoo`03001oogoo00Uoo``000aoo`800003
Ool0000000Ioo`8000Qoo`80009oo`03001oogoo00Ioo`03001oogoo01Yoo`@0009oo`D000aoo`80
0;Ioo`8000Aoo`H001ioo`03001oogoo00ioo`03001oogoo02ioo`<0009oo`@000Ioo`03001oogoo
05aoo`00Fgoo0P002Woo2`0047oo0`001Goo0`002goo0`001Goo0`007Goo00@007ooOomoo`T000ao
o`03001oogoo0;9oo`03001oogoo00=oo`H001moo`03001oogoo00ioo`03001oogoo02ioo`8000Eo
o`D000Aoo`8005aoo`00FWoo00<007ooOol02Goo1P0000Aoo`00000001=oo`P000moo`H0021oo`80
00=oo`X0009oo`03001oogoo00Ioo`03001oogoo0;1oo`03001oogoo009oo`D0009oo`03001oogoo
01eoo`03001oogoo00ioo`80031oo`03001oogoo00Eoo`D000Aoo`03001oogoo05Uoo`00F7oo0P00
2Woo2`004Woo0P005goo00<007ooOol097oo00<007ooOol00goo00<007ooOol020002Goo0P00[Woo
0P000goo1P000Woo00<007ooOol07Goo00<007ooOol03goo0P00<Goo0P001goo1@000goo0P00FGoo
001FOol2000;Ool70003Ool2000AOol2000HOol2000UOol20005Ool400000goo000000050009Ool2
002ZOol20004Ool9000POol00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`08Ool00`00Oomo
o`06Ool800000goo0000001GOol005Eoo`03001oogoo00Uoo`H000Ioo`8000moo`8001]oo`03001o
ogoo02Aoo`8000Eoo`8000Aoo`P000Qoo`800:Ioo`8000Aoo`X0025oo`03001oogoo00moo`03001o
ogoo02Ioo`8000Yoo`03001oogoo00Moo`L0009oo`03001oogoo05Aoo`00Dgoo0P002Woo1@0027oo
00<007oo00003Woo0P0077oo00<007ooOol09Goo1P0000=oo`0000001Goo200027oo00<007ooOol0
XWoo00<007ooOol00Woo1P000Woo00<007ooOol08Goo00<007ooOol03goo0P009goo1@002Goo00<0
07ooOol027oo2P00E7oo001BOol00`00Oomoo`08Ool60008Ool00`00Ool0000>Ool00`00Oomoo`0M
Ool00`00Oomoo`0XOol400000goo00000005Ool90006Ool00`00Oomoo`2POol01000Oomoogoo2`00
8goo00<007ooOol03goo00<007ooOol09Goo0P000Woo0P002Woo00<007ooOol027oo1`000Woo00<0
07ooOol0DGoo001AOol00`00Oomoo`07Ool5000;Ool00`00Ool0000=Ool00`00Oomoo`0NOol00`00
Oomoo`0XOol00`00Oomoo`03Ool20007Ool70006Ool2002NOol20004Ool4000ZOol00`00Oomoo`0?
Ool00`00Oomoo`0UOol01000Oomoogoo0P002Woo00<007ooOol027oo2@0000=oo`00Ool0DGoo001@
Ool00`00Oomoo`06Ool4000=Ool01000Oomoo`0037oo00<007ooOol07goo0P009goo0P001goo0P00
1goo2@001Goo00<007ooOol0VWoo00<007ooOol00Woo1@00:goo00<007ooOol03Woo0P009Goo0P00
17oo00<007ooOol02Woo0P0037oo2000DGoo001>Ool20005Ool6000>Ool00`00Oomoo`02000;Ool0
0`00Oomoo`0QOol00`00Oomoo`0TOol00`00Oomoo`09Ool20006Ool200000goo0000000500001Goo
001oogoo0000VWoo00<007ooOol00Woo1@00:goo00<007ooOol03goo0`0097oo00<007ooOol00goo
00<007ooOol037oo00<007ooOol027oo0`0000=oo`0000001@00Cgoo001=Ool00`00Oomoo`05Ool5
000?Ool01000Oomoo`002goo00<007ooOol08goo00<007ooOol08Goo0P003Goo4`000goo00<007oo
Ool0UWoo00@007ooOomoo`d002Eoo`03001oogoo019oo`03001oogoo025oo`03001oogoo009oo`80
00ioo`03001oogoo00Eoo`<000=oo`H0009oo`03001oogoo04aoo`00C7oo00<007ooOol00goo1`00
3goo00D007ooOomoo`0000]oo`03001oogoo02=oo`80021oo`8001Qoo`03001oogoo009oo`X009Io
o`03001oogoo00L000Eoo`<002Eoo`03001oogoo01=oo`80021oo`03001oogoo00=oo`8000moo`03
001oogoo00=oo`8000Ioo`L00003Ool007oo04aoo`00Bgoo00<007ooOol00Woo2`0037oo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol09Goo0P006Woo1@006Woo00<007ooOol00goo00<007oo
00001`00U7oo00<007oo00001`000goo0`00:7oo00<007ooOol057oo0P007goo00<007ooOol00goo
00<007ooOol03goo00<007ooOol00P0027oo1`000Woo00<007ooOol0BWoo001:Ool00`00Oomoo`03
Ool70003Ool30009Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0WOol3000DOol4000O
Ool00`00Oomoo`03Ool20003Ool7002@Ool20002Ool70002Ool2000[Ool00`00Oomoo`0FOol2000M
Ool00`00Oomoo`02Ool2000BOol3000:Ool70002Ool00`00Oomoo`19Ool004Uoo`03001oogoo009o
o`L000Moo`8000Qoo`05001oogooOol0000:Ool00`00Oomoo`0ZOol4000<Ool5000QOol20007Ool0
0`00Oomoo`02Ool40002Ool00`00Oomoo`2<Ool00`00Oomoo`060002Ool3000^Ool00`00Oomoo`0F
Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0AOol2000;Ool70003Ool00`00Oomoo`18
Ool004Moo`8000Eoo`H000Uoo`03001oogoo00Ioo`04001oogoo000:Ool00`00Oomoo`0_Ool<000V
Ool00`00Oomoo`06Ool20004Ool40002Ool00`00Oomoo`2:Ool01000Oomoogoo1@0000=oo`000000
<Goo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol00goo00<007ooOol04Woo0P002goo2000
0Woo0P00B7oo0016Ool00`00Oomoo`05Ool60009Ool20006Ool01000Ool000002goo00<007ooOol0
Ggoo0P002Woo0P0017oo0`000goo00<007ooOol0R7oo00<007ooOol00Woo1P00<goo00<007ooOol0
5Woo00<007ooOol06Woo00<007ooOol00goo00<007ooOol04goo0P002Woo0P000goo0`0017oo00<0
07ooOol0AGoo0015Ool00`00Oomoo`06Ool30002Ool00`00Oomoo`08Ool20004Ool3000<Ool00`00
Oomoo`1OOol00`00Oomoo`0;Ool20003Ool40003Ool00`00Oomoo`26Ool00`00Oomoo`02Ool6000e
Ool00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0EOol2000:Ool00`00
Oomoo`02Ool30004Ool00`00Oomoo`14Ool004Aoo`03001oogoo00Ioo`<000=oo`03001oogoo00Yo
o`D000ioo`03001oogoo05eoo`8000moo`80009oo`D000=oo`03001oogoo08Aoo`03001oogoo00=o
o`D003Ioo`03001oogoo01Eoo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01Ioo`<000Qo
o`03001oogoo00=oo`8000Eoo`03001oogoo04=oo`00@goo00<007ooOol01Woo0`0017oo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol0G7oo00<007ooOol047oo00@007ooOomoo`D000=oo`03
001oogoo089oo`03001oogoo00=oo`<00003Ool0000003Moo`03001oogoo01Aoo`03001oogoo01Yo
o`03001oogoo009oo`03001oogoo01Ioo`<000Qoo`03001oogoo00Aoo`8000Eoo`03001oogoo049o
o`00@Woo00<007ooOol01Woo0`001Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0G7oo
00<007ooOol04Woo0P0000=oo`0000000`0017oo00<007ooOol0P7oo00<007ooOol00goo100000=o
o`00Ool0=goo00<007ooOol057oo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol05goo0P00
27oo00<007ooOol00goo10001Goo00<007ooOol0@Goo0011Ool00`00Oomoo`06Ool30006Ool00`00
Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`1LOol00`00Oomoo`0EOol01000Ool007oo0`0017oo
00<007ooOol0OWoo00<007ooOol017oo0`0000=oo`00Ool0>Goo00<007ooOol04goo00<007ooOol0
6goo00D007ooOomoo`0001Yoo`8000Qoo`03001oogoo009oo`03001oo`00008000Eoo`03001oogoo
041oo`00@7oo00<007ooOol01Goo1@001Woo00<007ooOol02goo00<007ooOol03Goo00<007ooOol0
Fgoo00<007ooOol05Woo0P0000=oo`0000000`0017oo00<007ooOol0O7oo00<007ooOol017oo1P00
>Woo00<007ooOol04goo00<007ooOol06goo00@007ooOol001]oo`8000Qoo`03001oogoo009oo`03
001oogoo008000Ioo`03001oogoo03moo`00?goo00<007ooOol01Woo1@001Woo00<007ooOol02Woo
00<007ooOol03Goo00<007ooOol0G7oo00<007ooOol067oo00@007oo001oo`8000Eoo`03001oogoo
07Yoo`03001oogoo00Aoo`<00003Ool0000003aoo`03001oogoo019oo`03001oogoo01]oo`04001o
ogoo000LOol00`00Oomoo`07Ool01000Oomoogoo0P000Woo0P001Woo00<007ooOol0?Woo000oOol0
0`00Oomoo`06Ool40007Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomo
o`0HOol00`00Oomoo`050003Ool00`00Oomoo`1iOol00`00Oomoo`05Ool200000goo0000000nOol0
0`00Oomoo`0AOol00`00Oomoo`0KOol200000goo001oo`0KOol20008Ool00`00Oomoo`02Ool00`00
Oomoo`030005Ool00`00Oomoo`0nOol003ioo`03001oogoo00Moo`<000Qoo`03001oogoo00Uoo`03
001oogoo00eoo`03001oogoo05aoo`03001oogoo01Yoo`800003Ool00000008000Aoo`03001oogoo
07Moo`03001oogoo00Eoo`H003ioo`03001oogoo015oo`03001oogoo01aoo`8001eoo`8000Uoo`X0
00Ioo`03001oogoo03eoo`00?Goo00<007ooOol01goo10001goo00<007ooOol02Woo00<007ooOol0
37oo00<007ooOol0G7oo00<007ooOol07Goo00<007oo00000P001Goo00<007ooOol0MGoo00<007oo
Ool01Woo1000@Goo00<007ooOol047oo00<007ooOol077oo0P007Goo00<007oo000027oo0P000goo
00<007oo00000`001Woo00<007ooOol0?7oo000lOol00`00Oomoo`07Ool50007Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`1MOol00`00Oomoo`0MOol60005Ool00`00Oomoo`1cOol00`00
Oomoo`06Ool30014Ool00`00Oomoo`0>Ool00`00Oomoo`0MOol2000MOol00`00Ool00008Ool01000
Ool000000Woo00<007ooOol00`001Woo00<007ooOol0>goo000kOol00`00Oomoo`07Ool300000goo
001oo`07Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`1MOol00`00Oomoo`0POol50005
Ool00`00Oomoo`1bOol00`00Oomoo`05Ool200000goo001oo`14Ool00`00Oomoo`0=Ool00`00Oomo
o`0MOol3000=Ool@0002Ool00`00Oomoo`04Ool20003Ool200000goo001oo`030007Ool00`00Oomo
o`0jOol003Yoo`03001oogoo00Qoo`@000Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
05ioo`03001oogoo025oo`@000Ioo`03001oogoo071oo`03001oogoo00Ioo`800003Ool0000004Eo
o`03001oogoo00aoo`03001oogoo01eoo`03001oo`0000d000ioo`80009oo`03001oogoo00Aoo`03
001oogoo00Aoo`<00004Ool000000007Ool00`00Oomoo`0iOol003Uoo`03001oogoo00Qoo`<00003
Ool007oo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo05ioo`03001oogoo02=oo`04
001oo`000006Ool00`00Oomoo`1^Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`13Ool00`00Oomo
o`0<Ool00`00Oomoo`0MOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`07Ool300000goo
00000007Ool00`00Oomoo`0hOol003Uoo`03001oogoo00Qoo`@000Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo05ioo`03001oogoo025oo`<00004Ool000000005Ool00`00Oomoo`1^Ool0
0`00Oomoo`05Ool30004Ool00`00Oomoo`13Ool00`00Oomoo`0;Ool00`00Oomoo`0MOol00`00Oomo
o`0POol20003Ool00`00Oomoo`09Ool50006Ool00`00Oomoo`0hOol003Qoo`03001oogoo00Qoo`@0
00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo05moo`03001oogoo025oo`03001oo`00
009oo`8000Ioo`03001oogoo06aoo`03001oogoo00Ioo`<000Eoo`03001oogoo04=oo`03001oogoo
00Yoo`03001oogoo01aoo`03001oogoo029oo`800003Ool007oo00aoo`@000Moo`03001oogoo03Mo
o`00=goo00<007ooOol027oo10002goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0H7oo
00<007ooOol07goo0P000goo0P0000=oo`0000001Woo00<007ooOol0JWoo00<007ooOol01Woo1@00
1Goo0P00A7oo0P002Goo0P007Woo00<007ooOol08goo0P003Woo1@001goo00<007ooOol0=Woo000f
Ool00`00Oomoo`08Ool200000goo0000000;Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`1QOol00`00Oomoo`0OOol00`00Oomoo`02Ool2000017oo000000001Woo00<007ooOol0J7oo00<0
07ooOol01goo1@001Woo00<007ooOol0A7oo00<007ooOol01Woo00<007ooOol07Goo00<007ooOol0
8goo0P003goo00<007oo00000P001goo00<007ooOol0=Goo000eOol00`00Oomoo`09Ool4000<Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`1QOol00`00Oomoo`0OOol00`00Oomoo`02Ool2
00000goo001oo`020007Ool00`00Oomoo`1VOol00`00Oomoo`07Ool40009Ool20015Ool00`00Oomo
o`03Ool2000OOol00`00Oomoo`0ROol200000goo0000000>Ool00`00Ool000020008Ool00`00Oomo
o`0dOol003Eoo`03001oogoo00Qoo`800003Ool0000000]oo`03001oogoo00Yoo`03001oogoo00Ao
o`8006Aoo`03001oogoo01eoo`8000Eoo`80009oo`04001oo`000006Ool00`00Oomoo`1VOol00`00
Oomoo`07Ool3000<Ool20014Ool2000017oo0000000087oo00<007ooOol08Goo0P000goo0P003Goo
00<007ooOol00`001goo00<007ooOol0=7oo000dOol00`00Oomoo`08Ool5000<Ool00`00Oomoo`0:
Ool00`00Oomoo`03Ool00`00Oomoo`1TOol00`00Oomoo`0LOol00`00Oomoo`05Ool20002Ool00`00
Ool000020006Ool00`00Oomoo`1TOol00`00Oomoo`07Ool4000>Ool20012Ool01000Ool000008Goo
00<007ooOol087oo0P001goo0P003Woo10001goo00<007ooOol0<goo000dOol00`00Oomoo`07Ool4
00000goo001oo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`1UOol00`00Oomoo`0K
Ool00`00Oomoo`06Ool20003Ool01000Ool000001goo00<007ooOol0HWoo00<007ooOol01goo1000
4Goo00<007ooOol0?goo0P0000=oo`0000007goo0P0087oo0P002Woo0P003Woo0`0027oo00<007oo
Ool0<Woo000cOol00`00Oomoo`08Ool400000goo001oo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02
001XOol00`00Oomoo`0JOol00`00Oomoo`06Ool30003Ool00`00Ool000020007Ool00`00Oomoo`1P
Ool00`00Oomoo`08Ool3000COol30010Ool00`00Oomoo`02000MOol00`00Oomoo`0MOol2000>Ool0
0`00Oomoo`0=Ool20007Ool00`00Oomoo`0bOol0039oo`03001oogoo00Qoo`@0009oo`03001oogoo
00Uoo`03001oogoo00]oo`03001oo`0006Uoo`03001oogoo01Uoo`8000Uoo`8000Eoo`D000Ioo`03
001oogoo061oo`03001oogoo00Moo`<001Ioo`80041oo`04001oogooOol2000IOol2000POol00`00
Oomoo`0>Ool2000=Ool30007Ool00`00Oomoo`0aOol0039oo`03001oogoo00Qoo`H000]oo`03001o
ogoo00aoo`8006Yoo`03001oogoo01Qoo`03001oogoo00Moo`@000Ioo`D000Ioo`03001oogoo05io
o`03001oogoo00Moo`<001Qoo`80041oo`03001oogoo009oo`8001Ioo`03001oogoo01ioo`80019o
o`8000aoo`<000Moo`03001oogoo035oo`00<Goo00<007ooOol027oo100000=oo`0000002goo00<0
07ooOol037oo00<007ooOol0JGoo00<007ooOol05goo00<007ooOol027oo0`0027oo10001Woo00<0
07ooOol0GWoo00<007ooOol01goo0P006Woo0P00?goo0P0017oo10004Goo0P007goo0P005Woo0P00
2goo0P0027oo00<007ooOol0<7oo000`Ool00`00Oomoo`08Ool40002Ool2000;Ool00`00Oomoo`0;
Ool00`00Oomoo`1ZOol00`00Oomoo`0FOol00`00Oomoo`09Ool20009Ool00`00Ool000020006Ool0
0`00Oomoo`1LOol00`00Oomoo`07Ool3000KOol2000oOol00`00Oomoo`06Ool3000:Ool4000@Ool3
000=Ool2000IOol00`00Oomoo`05Ool00`00Oomoo`030007Ool00`00Oomoo`0`Ool002moo`03001o
ogoo00Qoo`@0009oo`800003Ool007oo00Uoo`03001oogoo00Yoo`8006aoo`03001oogoo01Eoo`03
001oogoo00Yoo`8000Uoo`03001oo`0000<000Eoo`03001oogoo05]oo`03001oogoo00Qoo`<001eo
o`8003ioo`03001oogoo00Qoo`X000ioo`L00003Ool0000000@000Ioo`8001aoo`03001oogoo00Ao
o`L000Moo`03001oogoo02moo`00;goo00<007ooOol027oo0P0000Eoo`00Oomoo`00009oo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oo`0006eoo`03001oogoo01Aoo`03001oogoo00]oo`03001o
ogoo00Moo`03001oo`0000<000Ioo`03001oogoo05Yoo`03001oogoo00Moo`@001moo`8000Moo`03
001oogoo039oo`03001oogoo01eoo`<000ioo`L001ioo`<000Aoo`03001oo`0000<000Moo`03001o
ogoo02moo`00;Woo00<007ooOol027oo10000goo00@007ooOol000Uoo`03001oogoo00Yoo`03001o
o`0006eoo`03001oogoo01=oo`03001oogoo00aoo`8000Qoo`03001oogoo00@000Ioo`03001oogoo
05Qoo`03001oogoo00Moo`D0021oo`@000=oo`8003Aoo`03001oogoo01Ioo`L003Uoo`/000Moo`03
001oogoo02ioo`00;Woo00<007ooOol01goo100017oo00@007ooOol000Uoo`03001oogoo00Uoo`03
001oo`0006ioo`03001oogoo019oo`03001oogoo00eoo`<000Moo`05001oogoo001oo`030005Ool0
0`00Oomoo`1HOol00`00Oomoo`07Ool5000SOol7000cOol00`00Oomoo`0COol30013Ool90007Ool0
0`00Oomoo`0]Ool002ioo`03001oogoo00Moo`<000Ioo`03001oo`0000Uoo`03001oogoo00Uoo`03
001oo`0006ioo`03001oogoo011oo`80011oo`04001oo`000006Ool01000Oomoogoo1@001Goo00<0
07ooOol0EWoo00<007ooOol01goo0P0000=oo`000000:goo0P00<Goo00<007ooOol03goo1000B7oo
00<007ooOol00Woo0P001goo00<007ooOol0;Goo000]Ool00`00Oomoo`07Ool40006Ool00`00Ool0
0009Ool00`00Oomoo`09Ool00`00Ool0000>Ool5001LOol00`00Oomoo`0>Ool00`00Oomoo`0@Ool0
1000Oomoogoo0`000Woo00<007ooOol00Woo1@001Goo00<007ooOol0EWoo00<007ooOol01goo1000
;Woo00<007ooOol0;Goo00<007ooOol037oo1000C7oo00<007ooOol00goo0P001goo00<007ooOol0
;7oo000]Ool00`00Oomoo`06Ool40007Ool30008Ool00`00Oomoo`09Ool01000Oomoo`002Woo1000
1Goo0`00FWoo00<007ooOol02goo0P004goo00<007ooOol00goo3P001Goo00<007ooOol0E7oo00<0
07ooOol01goo0P0000=oo`000000;Woo0P00;Woo00<007ooOol027oo1000D7oo00<007ooOol00goo
0`001Woo00<007ooOol0;7oo000/Ool00`00Oomoo`07Ool40008Ool20008Ool00`00Oomoo`09Ool0
0`00Ool00009Ool2000<Ool2001IOol20007Ool4000EOol00`00Oomoo`06Ool00`00Oomoo`03Ool6
0004Ool00`00Oomoo`1DOol00`00Oomoo`07Ool4000aOol2000/Ool00`00Oomoo`05Ool3001EOol0
0`00Oomoo`02Ool40006Ool00`00Oomoo`0[Ool002aoo`03001oogoo00Ioo`D000Qoo`8000Qoo`03
001oogoo00Qoo`04001oogoo0007Ool2000?Ool2001JOol7000IOol00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Ool000030005Ool00`00Oomoo`1BOol00`00Oomoo`07Ool3000eOol00`00Oomoo`0X
Ool00`00Oomoo`06001?Ool60003Ool40002Ool30006Ool00`00Oomoo`0[Ool002]oo`03001oogoo
00Ioo`<00003Ool007oo00Qoo`8000Qoo`03001oogoo00Qoo`04001oogoo0006Ool00`00Oomoo`0@
Ool00`00Oomoo`1hOol00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`040004Ool00`00Oomo
o`1BOol00`00Oomoo`06Ool3000gOol2000WOol4001AOol40006Ool<0007Ool00`00Oomoo`0ZOol0
02]oo`03001oogoo00Ioo`800003Ool0000000Uoo`8000Moo`03001oogoo00Qoo`05001oogooOol0
0005Ool00`00Oomoo`0AOol00`00Oomoo`1hOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`040005Ool00`00Oomoo`1AOol00`00Oomoo`06Ool3000hOol2000NOol01000Oomoogoo100000=o
o`00Ool0D7oo0P0057oo0`001goo00<007ooOol0:Goo000ZOol00`00Oomoo`06Ool5000:Ool20007
Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo0P0057oo00<007ooOol0N7oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol0100017oo00<007ooOol0D7oo00<007ooOol01Woo1000>Woo0P00
0Woo00<007ooOol05goo100017oo0P00Cgoo0`0057oo10001goo00<007ooOol0:Goo000ZOol00`00
Oomoo`05Ool5000<Ool00`00Oomoo`05Ool00`00Oomoo`08Ool01000Oomoo`000goo00<007ooOol0
57oo00<007ooOol0NGoo00<007ooOol017oo00<007ooOol01Goo00@007ooOomoo`<000Eoo`03001o
ogoo04ioo`03001oogoo00Ioo`@003eoo`@001Moo`8000Moo`03001oogoo04eoo`03001oogoo015o
o`T000Ioo`03001oogoo02Uoo`00:Goo00<007ooOol01Woo1@0037oo00<007ooOol01Goo00<007oo
Ool01goo00D007ooOomoo`0000=oo`03001oogoo01Aoo`03001oogoo07Uoo`03001oogoo00Aoo`03
001oogoo00Eoo`04001oogooOol50003Ool00`00Oomoo`1>Ool00`00Oomoo`06Ool200000goo001o
o`0mOol3000GOol00`00Oomoo`04Ool3001>Ool00`00Oomoo`0=Ool50006Ool30007Ool00`00Oomo
o`0XOol002Uoo`03001oogoo00Eoo`<0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`0EOol00`00Oomoo`1iOol00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool40004Ool00`00Oomoo`1<Ool00`00Oomoo`07Ool30011Ool3000D
Ool01000Oomoogoo1000Cgoo0P003Woo0`002Woo0`001goo00<007ooOol0:7oo000XOol00`00Oomo
o`06Ool300000goo001oo`0<Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Ool0000HOol00`00Oomoo`1jOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool40004
Ool00`00Oomoo`1<Ool00`00Oomoo`06Ool40014Ool2000AOol5001BOol00`00Oomoo`0<Ool2000>
Ool30006Ool00`00Oomoo`0XOol002Qoo`03001oogoo00Ioo`80009oo`03001oogoo00]oo`03001o
ogoo00Eoo`03001oogoo00Eoo`8000Aoo`03001oo`0001Qoo`03001oogoo07Yoo`05001oogooOol0
0009Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`1:Ool00`00Oomoo`06Ool40017Ool3000:Ool5
001EOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool30007Ool00`00Oomoo`0WOol002Moo`03001oogoo
00Moo`800003Ool007oo00eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo000HOol00`00Oomoo`1kOol01000Oomoo`002Goo00@007ooOomoo`H000Aoo`03001oogoo04Yo
o`03001oogoo00Moo`8004]oo`X000=oo`03001oogoo05=oo`03001oogoo00]oo`80015oo`<000Mo
o`03001oogoo02Moo`009goo00<007ooOol01goo10003Woo0P001Woo00<007ooOol017oo00<007oo
Ool00goo00<007oo000067oo00<007ooOol0O7oo00@007oo000000Uoo`05001oogooOol00002Ool3
0004Ool00`00Oomoo`1:Ool00`00Oomoo`06Ool4001FOol00`00Oomoo`1BOol2000<Ool2000DOol2
0008Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Moo`D000ioo`8000Ioo`03001oogoo00=oo`03
001oogoo00Aoo`8001Uoo`03001oogoo07aoo`03001oo`0000Yoo`04001oogooOol2000017oo0000
00001Goo00<007ooOol0B7oo00<007ooOol01goo0`00EWoo00<007ooOol0DWoo00<007ooOol02goo
00<007ooOol057oo0P0027oo00<007ooOol09Woo000VOol00`00Oomoo`07Ool5000>Ool20006Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool2000HOol2001nOol2000;Ool00`00Oomoo`02Ool50005Ool0
0`00Oomoo`18Ool00`00Oomoo`07Ool3001EOol00`00Oomoo`1BOol00`00Oomoo`0:Ool2000HOol0
0`00Oomoo`07Ool00`00Oomoo`0UOol002Ioo`03001oogoo00Moo`@000ioo`03001oo`0000Ioo`05
001oogooOol00008Ool00`00Oomoo`0GOol00`00Oomoo`1mOol2000;Ool00`00Oomoo`03Ool40005
Ool00`00Oomoo`18Ool00`00Oomoo`07Ool2001FOol00`00Oomoo`1AOol00`00Oomoo`09Ool2000I
Ool20009Ool00`00Oomoo`0UOol002Eoo`03001oogoo00Qoo`@000ioo`03001oo`0000Ioo`03001o
ogoo008000Qoo`03001oogoo01Ioo`8007ioo`03001oo`0000]oo`03001oogoo00Aoo`<000Ioo`03
001oogoo04Ioo`03001oogoo00Qoo`8005Eoo`03001oogoo051oo`8000]oo`03001oogoo01Uoo`<0
00Uoo`03001oogoo02Aoo`009Goo00<007ooOol027oo10003Goo0P0000=oo`00Ool01Goo00@007oo
Ool000Qoo`8001Qoo`03001oogoo07eoo`04001oogoo0009Ool00`00Oomoo`05Ool40005Ool00`00
Oomoo`16Ool00`00Oomoo`07Ool3001DOol00`00Oomoo`1?Ool2000<Ool00`00Oomoo`0JOol30009
Ool00`00Oomoo`0TOol002Eoo`03001oogoo00Moo`D000eoo`04001oogoo0005Ool01000Oomoo`00
27oo0P006Goo00<007ooOol0O7oo00D007ooOomoo`0000Uoo`03001oogoo00Eoo`04001oo`000005
Ool00`00Oomoo`16Ool00`00Oomoo`07Ool2001DOol00`00Oomoo`1?Ool00`00Oomoo`0;Ool00`00
Oomoo`0KOol30009Ool00`00Oomoo`0TOol002Aoo`03001oogoo00Qoo`D000aoo`04001oogoo0006
Ool00`00Ool00007Ool3000JOol00`00Oomoo`1kOol20003Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool01000Ool000001Woo00<007ooOol0A7oo00<007ooOol027oo0P00Dgoo0P00D7oo00<007ooOol0
2goo00<007ooOol07Woo00<007ooOol027oo00<007ooOol08goo000TOol00`00Oomoo`08Ool5000<
Ool01000Oomoo`001Woo00<007oo00001Woo0`006goo00<007ooOol0Ngoo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol01Goo00@007oo000000Ioo`03001oogoo04Aoo`03001oogoo00Qoo`80
05=oo`03001oogoo04eoo`8000aoo`80025oo`03001oogoo00Qoo`03001oogoo02=oo`0097oo00<0
07ooOol027oo1@002goo00D007ooOomoo`0000Eoo`800003Ool007oo00=oo`80009oo`03001oogoo
01Uoo`03001oogoo07]oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Eoo`@000Ioo`03
001oogoo04Aoo`03001oogoo00Qoo`80059oo`03001oogoo04eoo`03001oogoo00]oo`03001oogoo
025oo`03001oogoo00Qoo`03001oogoo02=oo`0097oo00<007ooOol027oo100037oo00D007ooOomo
o`0000Eoo`03001oo`0000Aoo`8000=oo`03001oogoo01Yoo`03001oogoo07Yoo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00Eoo`@000Moo`03001oogoo049oo`03001oogoo00Uoo`8004Uo
o`<000Aoo`8004moo`03001oogoo00aoo`03001oogoo025oo`8000Uoo`03001oogoo02=oo`0097oo
00<007ooOol01goo1P002Woo00D007ooOomoo`0000Eoo`800004Ool007ooOol20005Ool00`00Oomo
o`0JOol00`00Oomoo`1jOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`05Ool40007Ool0
0`00Oomoo`12Ool00`00Oomoo`09Ool20016Ool300000goo00000003Ool2001=Ool3000>Ool00`00
Oomoo`0ROol20009Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Moo`H000Uoo`05001oogooOol0
0006Ool00`00Ool00002Ool20005Ool00`00Oomoo`0LOol2001jOol00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`12Ool00`00Oomoo`08Ool30013Ool30006Ool3
001=Ool2000AOol00`00Oomoo`0ROol20009Ool00`00Oomoo`0SOol002=oo`03001oogoo00Qoo`H0
00Qoo`800003Ool0000000Moo`05001oo`00Ool00007Ool00`00Oomoo`0MOol00`00Oomoo`1hOol0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06Ool200000goo00000006Ool00`00Oomoo`11
Ool00`00Oomoo`09Ool30011Ool30009Ool2001<Ool00`00Oomoo`0@Ool00`00Oomoo`0TOol00`00
Oomoo`08Ool00`00Oomoo`0ROol002=oo`03001oogoo00Qoo`H000Qoo`<000Uoo`04001oo`000007
Ool00`00Oomoo`0OOol00`00Oomoo`1hOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool20002Ool20006Ool00`00Oomoo`11Ool00`00Oomoo`09Ool2000lOol00`00Ool00003001HOol2
000COol00`00Oomoo`0TOol00`00Oomoo`08Ool00`00Oomoo`0ROol002=oo`03001oogoo00Moo`H0
0003Ool007oo00Eoo`8000]oo`<000Qoo`03001oogoo021oo`03001oogoo07Moo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Aoo`8000=oo`8000Ioo`03001oogoo045oo`03001oogoo00Uo
o`8003Qoo`H005]oo`03001oogoo019oo`03001oogoo02Eoo`03001oogoo00Qoo`03001oogoo029o
o`008Woo00<007ooOol027oo0P0000Ioo`00000007oo0005Ool2000<Ool20008Ool00`00Oomoo`0Q
Ool00`00Oomoo`1gOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoogoo
0P001goo00<007ooOol0@7oo00<007ooOol02Goo0`00=goo00<007ooOol0Fgoo0`005Goo00<007oo
Ool09Goo00<007ooOol02Goo00<007ooOol08Goo000ROol00`00Oomoo`08Ool600000goo001oo`03
Ool2000=Ool20008Ool00`00Oomoo`0QOol00`00Oomoo`1hOol00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0:Ool20007Ool00`00Oomoo`10Ool00`00Oomoo`09Ool3000fOol00`00Oomoo`1J
Ool2000GOol00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0QOol0029oo`03001oogoo00Mo
o`L00003Ool007oo009oo`8000aoo`<000Qoo`03001oogoo02=oo`03001oogoo07Moo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Yoo`8000Qoo`03001oogoo03moo`03001oogoo00Uoo`80
03Moo`03001oogoo05Uoo`03001oogoo01Ioo`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo
025oo`008Goo00<007ooOol027oo1`0000Aoo`00Oomoo`<000]oo`800003Ool007oo00Ioo`03001o
ogoo02Eoo`03001oogoo07Ioo`8000Aoo`03001oogoo009oo`03001oogoo00Yoo`8000Qoo`03001o
ogoo03ioo`03001oogoo00Yoo`D003=oo`8005Uoo`8001Uoo`03001oogoo02Moo`8000]oo`03001o
ogoo021oo`008Goo00<007ooOol01Woo100000=oo`0000000P0000Eoo`00Oomoo`0000aoo`03001o
ogoo008000Moo`03001oogoo02Eoo`03001oogoo07Moo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Yoo`8000Qoo`03001oogoo03ioo`03001oogoo00Yoo`D003=oo`03001oogoo05Moo`03
001oogoo01Uoo`03001oogoo02Moo`8000]oo`03001oogoo021oo`008Goo00<007ooOol01Goo1@00
0Woo1@0000=oo`0000002goo00@007ooOomoo`8000Moo`03001oogoo02Ioo`03001oogoo07Moo`05
001oogooOol00003Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`0:
Ool4000cOol00`00Oomoo`1FOol2000KOol00`00Oomoo`0XOol2000;Ool00`00Oomoo`0POol0025o
o`03001oogoo00Eoo`D0009oo`<00003Ool00000008000Yoo`03001oogoo009oo`8000Ioo`03001o
ogoo02Qoo`03001oogoo07Moo`04001oogoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00
Oomoo`0nOol00`00Oomoo`0:Ool5000bOol00`00Oomoo`1EOol00`00Oomoo`0KOol00`00Oomoo`0Y
Ool00`00Oomoo`09Ool00`00Oomoo`0POol0025oo`03001oogoo00Eoo`@000=oo`80009oo`80009o
o`<000Ioo`03001oogoo009oo`03001oo`0000Eoo`03001oogoo02Uoo`03001oogoo07Qoo`03001o
o`0000=oo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo03ioo`03001oogoo00aoo`@0031o
o`03001oogoo05Aoo`8001eoo`03001oogoo02Yoo`03001oogoo00Uoo`03001oogoo021oo`008Goo
00<007ooOol01Goo0`0017oo0P0000=oo`0000001Woo100000=oo`00Ool017oo0P001Goo00<007oo
Ool0:Woo00<007ooOol0N7oo0`000goo00<007ooOol037oo00<007ooOol01Woo00<007ooOol0?Goo
00<007ooOol03Woo1P00;Goo00<007ooOol0Dgoo00<007ooOol07Goo00<007ooOol0:Woo00<007oo
Ool02Goo00<007ooOol087oo000QOol00`00Oomoo`05Ool30004Ool200000goo0000000:Ool90000
0goo00000002000^Ool00`00Oomoo`1hOol20002Ool00`00Oomoo`0=Ool20008Ool00`00Oomoo`0l
Ool00`00Oomoo`0>Ool7000[Ool00`00Oomoo`1COol00`00Oomoo`0MOol00`00Oomoo`0[Ool00`00
Oomoo`0:Ool00`00Oomoo`0OOol0021oo`03001oogoo00Ioo`80009oo`H00003Ool007oo00Qoo`03
001oogoo00Aoo`@003=oo`03001oogoo07Moo`80009oo`03001oogoo00eoo`8000Qoo`03001oogoo
03aoo`03001oogoo00ioo`<00003Ool0000000<002Uoo`03001oogoo059oo`03001oogoo01ioo`03
001oogoo02]oo`03001oogoo00Yoo`03001oogoo01moo`0087oo00<007ooOol01Woo1@000Woo0`00
00=oo`00Ool01goo0P001Woo0P00=Goo00<007ooOol0Mgoo00D007oo001oo`0000moo`8000Qoo`03
001oogoo03aoo`03001oogoo00ioo`T002Qoo`03001oogoo055oo`80025oo`03001oogoo02]oo`03
001oogoo00Yoo`03001oogoo01moo`0087oo00<007ooOol01Woo0P000Woo00<007oo00000`0000=o
o`00Ool01goo00<007ooOol017oo0P00=goo00<007ooOol0MWoo00<007oo00000P003Woo0`0027oo
00<007ooOol0?7oo00<007ooOol03Woo100000=oo`0000000`009goo00<007ooOol0D7oo00<007oo
Ool087oo00<007ooOol0;7oo00<007ooOol02Woo00<007ooOol07goo000POol00`00Oomoo`06Ool<
0007Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1fOol01000Oomoo`003goo0`0027oo
00<007ooOol0?7oo00<007ooOol03Woo1`000Woo0P009Goo0P00DGoo00<007ooOol08Goo00<007oo
Ool0;7oo0P002goo00<007ooOol07goo000POol00`00Oomoo`06Ool30003Ool70006Ool00`00Oomo
o`04Ool2000iOol00`00Oomoo`1dOol01000Oomoogoo0P003Woo0`002Goo00<007ooOol0>Woo00<0
07ooOol03goo1@000goo00@007oo000002Aoo`03001oogoo04moo`03001oogoo025oo`8002ioo`80
00]oo`03001oogoo01moo`0087oo00<007ooOol01Woo100000=oo`0000000P0000=oo`00Ool00P00
1Goo00<007ooOol017oo0P00>Goo00<007ooOol0M7oo00H007ooOol007oo000>Ool30009Ool00`00
Oomoo`0jOol00`00Oomoo`0?Ool600000goo00000002Ool2000SOol00`00Oomoo`1>Ool00`00Oomo
o`0ROol00`00Oomoo`0]Ool2000;Ool00`00Oomoo`0OOol0021oo`03001oogoo00Ioo`T00003Ool0
0000009oo`8000=oo`03001oogoo00=oo`8003]oo`03001oogoo07=oo`04001oogoo0002Ool2000<
Ool30009Ool00`00Oomoo`0jOol00`00Oomoo`0>Ool40002Ool;000OOol00`00Oomoo`1>Ool00`00
Oomoo`0SOol00`00Oomoo`0/Ool3000;Ool00`00Oomoo`0OOol001moo`03001oogoo00Moo`P000=o
o`04001oogooOol20003Ool00`00Oomoo`03000mOol00`00Oomoo`1bOol01000Oomoo`000goo00<0
07ooOol02Woo0`002Goo00<007ooOol0>Woo00<007ooOol02Woo00<007oo00000`0000=oo`000000
0P0017oo00@007ooOomoo`L001Yoo`03001oogoo04eoo`03001oogoo02Aoo`03001oogoo02aoo`03
001oo`0000aoo`03001oogoo01ioo`007goo00<007ooOol01goo1P0000=oo`00Ool00Woo00<007oo
Ool00Woo0P0000=oo`0000001000?goo00<007ooOol0L7oo00@007ooOol000Eoo`8000Yoo`<000Uo
o`03001oogoo03Yoo`03001oogoo00Uoo`l00003Ool0000000Qoo`03001oogoo01Moo`03001oogoo
04eoo`03001oogoo02Eoo`03001oogoo02aoo`<000aoo`03001oogoo01ioo`007goo00<007ooOol0
27oo100000Eoo`00000007oo00T0009oo`04001oogoo0010Ool00`00Oomoo`1^Ool01000Oomoo`00
1goo0P0027oo00@007oo000000Uoo`03001oogoo03Yoo`03001oogoo00Uoo``000=oo`@000Moo`03
001oogoo01Moo`03001oogoo04aoo`03001oogoo02Ioo`03001oogoo02aoo`<000aoo`03001oogoo
01ioo`007goo00<007ooOol027oo100000=oo`0000000`0000=oo`00Ool017oo00H007ooOol007oo
0012Ool00`00Oomoo`1]Ool01000Oomoo`002Goo00<007ooOol01Goo00@007oo000000Uoo`03001o
ogoo03Yoo`03001oogoo00Uoo`L00003Ool0000000<000Eoo`<000Eoo`03001oogoo01Ioo`03001o
ogoo04aoo`03001oogoo02Ioo`03001oogoo02eoo`<000aoo`03001oogoo01ioo`007goo00<007oo
Ool027oo1`0017oo0P0017oo00@007ooOomoo`8004=oo`8006aoo`04001oogoo000:Ool20006Ool0
1000Ool000002Goo00<007ooOol0>Woo00<007ooOol02Goo1P0017oo1@000goo0P0000=oo`000000
0P0000=oo`00Ool05goo00<007ooOol0C7oo00<007ooOol09Woo00<007ooOol0;7oo100037oo00<0
07ooOol07Woo000OOol00`00Oomoo`08Ool400000goo001oo`05Ool20003Ool01@00Oomoogoo0000
AWoo00<007ooOol0J7oo00@007ooOol000eoo`03001oogoo00=oo`04001oo`000009Ool00`00Oomo
o`0jOol00`00Oomoo`09Ool50006Ool00`00Ool0000400000goo00000003Ool00`00Ool0000FOol2
001?Ool00`00Oomoo`0UOol00`00Oomoo`0]Ool200000goo001oo`0;Ool00`00Oomoo`0NOol001mo
o`03001oogoo00Qoo`@00003Ool007oo00Ioo`80009oo`04001oogooOol20016Ool00`00Oomoo`1W
Ool00`00Ool0000?Ool00`00Oomoo`02Ool01000Ool000002Goo00<007ooOol0>Woo00<007ooOol0
2Goo100027oo0`000goo2@005Woo00<007ooOol0CGoo00<007ooOol09Woo00<007ooOol0;7oo00D0
07oo001oo`0000aoo`03001oogoo01ioo`007goo00<007ooOol01goo0`000goo00<007ooOol01Woo
10000goo0P00Agoo0P00IWoo0`004Goo00H007ooOomoo`00Ool30008Ool00`00Oomoo`0jOol00`00
Oomoo`09Ool80005Ool20005Ool20005Ool00`00Oomoo`0>Ool01@00Oomoogoo0000Cgoo00<007oo
Ool09Woo00<007ooOol0;7oo00D007ooOol007oo008000]oo`03001oogoo01ioo`007goo00<007oo
Ool01goo0`000goo00<007ooOol027oo0`000Woo0P00BGoo00<007ooOol0HWoo0P0057oo00D007oo
Ool007oo00<000Qoo`03001oogoo03Yoo`03001oogoo00Uoo`<000Aoo`H00004Ool000000005Ool3
0002Ool00`00Oomoo`0>Ool01000Oomoo`00Cgoo00<007ooOol09goo00<007ooOol0:goo0P000Woo
00@007oo000000]oo`03001oogoo01ioo`007goo00<007ooOol01goo0P0017oo00<007ooOol02Goo
1@0000=oo`00Ool0B7oo00<007ooOol0HGoo0P005Goo0`0000Aoo`00000000Qoo`03001oogoo03Yo
o`03001oogoo00Uoo`<000Yoo`@000Moo`D000eoo`H004moo`03001oogoo02Ioo`03001oogoo02ao
o`06001oogooOol007oo0P002goo00<007ooOol07Woo000OOol00`00Oomoo`07Ool7000<Ool00`00
Oomoo`03001:Ool00`00Oomoo`1LOol4000HOol60008Ool00`00Oomoo`0jOol00`00Oomoo`08Ool4
000<Ool2000;Ool>0002Ool5001=Ool00`00Oomoo`0WOol00`00Oomoo`0[Ool00`00Oomoo`03Ool3
000;Ool00`00Oomoo`0NOol001moo`03001oogoo00Moo`<0009oo`8000aoo`05001oogoo001oo`03
0019Ool00`00Oomoo`1GOol40003Ool00`00Oomoo`0GOol00`00Ool000020008Ool00`00Oomoo`0j
Ool00`00Oomoo`08Ool3000=Ool2000<Ool00`00Oomoo`0;Ool30002Ool00`00Oomoo`1:Ool00`00
Oomoo`0WOol00`00Oomoo`0/Ool00`00Oomoo`03Ool3000;Ool00`00Oomoo`0NOol001moo`03001o
ogoo00Ioo`<000Aoo`03001oogoo00Yoo`08001oogoo001oo`00Ool004Yoo`8005Eoo`8000Ioo`03
001oogoo01Qoo`03001oo`00008000Qoo`03001oogoo03Yoo`03001oogoo00Qoo`<000eoo`8000ao
o`8000]oo`8000Aoo`03001oogoo04Yoo`03001oogoo02Ioo`8002eoo`03001oogoo00Aoo`<000]o
o`03001oogoo01ioo`007goo00<007ooOol01Woo0`0017oo0P002goo00@007ooOol0009oo`8004ao
o`03001oogoo055oo`8000Moo`03001oogoo01Qoo`03001oo`00008000Qoo`03001oogoo03Yoo`03
001oogoo00Qoo`<000eoo`<000aoo`<000Qoo`8000Eoo`03001oogoo04Uoo`03001oogoo02Moo`03
001oogoo02aoo`03001oogoo00Aoo`<000]oo`03001oogoo01ioo`007goo00<007ooOol01Goo0`00
1Goo00<007oo00002Woo00@007ooOol0009oo`8004eoo`03001oogoo04moo`03001oogoo00Moo`03
001oogoo01Qoo`03001oo`00008000Qoo`03001oogoo03Yoo`03001oogoo00Qoo`<000eoo`03001o
o`0000moo`P000Moo`03001oogoo04Qoo`03001oogoo02Moo`03001oogoo02eoo`03001oogoo00Eo
o`8000]oo`03001oogoo01ioo`007goo00<007ooOol01Woo0P001Goo00<007oo00002Woo00@007oo
Ool0009oo`03001oo`0004eoo`03001oogoo04eoo`03001oogoo00Qoo`03001oogoo01Qoo`03001o
o`00008000Qoo`03001oogoo03Yoo`03001oogoo00Qoo`<000eoo`03001oo`00008001aoo`03001o
ogoo04Moo`03001oogoo02Uoo`03001oogoo02aoo`03001oogoo00Eoo`8000]oo`03001oogoo01io
o`007goo00<007ooOol01Woo0P001Goo00<007oo00002goo00<007oo00000Woo00<007oo0000CWoo
0P00Bgoo0P002goo00<007ooOol067oo00<007oo00000P0027oo00<007ooOol0>Woo00<007ooOol0
27oo0`003Goo1@0077oo0P00B7oo00<007ooOol0:Goo00<007ooOol0;7oo00<007ooOol01Goo0P00
2goo00<007ooOol07Woo000OOol00`00Oomoo`06Ool30004Ool01000Oomoo`002Woo0P000goo00<0
07oo0000D7oo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol06Goo00<007oo00000P0027oo
00<007ooOol0>Woo00<007ooOol027oo0`0047oo0`0077oo00<007ooOol0AGoo00<007ooOol0:Woo
00<007ooOol0;7oo00<007ooOol017oo00<007oo00002goo00<007ooOol07Woo000OOol00`00Oomo
o`07Ool20004Ool01000Oomoo`002Woo0P000Woo00<007ooOol00P00D7oo00<007ooOol0AWoo00<0
07ooOol02Woo00<007ooOol06Goo00<007oo00000P0027oo00<007ooOol0>Woo00<007ooOol027oo
0P004Woo00<007oo00006goo00<007ooOol0A7oo00<007ooOol0:goo00<007ooOol0;7oo00<007oo
Ool017oo00<007oo00002goo00<007ooOol07Woo000OOol00`00Oomoo`07Ool20004Ool01@00Oomo
ogoo00002Goo0P000Woo00D007ooOomoo`00055oo`8004Eoo`03001oogoo00]oo`03001oogoo01Yo
o`@000Qoo`03001oogoo03Yoo`03001oogoo00Qoo`80019oo`03001oo`0001]oo`03001oogoo049o
o`8002ioo`03001oogoo02]oo`03001oogoo00Eoo`04001oo`00000:Ool00`00Oomoo`0NOol001mo
o`03001oogoo00Moo`8000Aoo`05001oogooOol0000:Ool01000Oomoo`000goo00<007ooOol0DGoo
0P00@Woo00<007ooOol037oo00<007ooOol06Woo1@001goo00<007ooOol0>Woo00<007ooOol027oo
0P004Woo00@007ooOol001Yoo`03001oogoo045oo`03001oogoo02ioo`03001oogoo02]oo`03001o
ogoo00Eoo`04001oo`00000:Ool00`00Oomoo`0NOol001moo`03001oogoo00Moo`8000Aoo`03001o
ogoo009oo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`1COol00`00Oomoo`0oOol00`00
Oomoo`0<Ool00`00Oomoo`0JOol50007Ool00`00Oomoo`0jOol00`00Oomoo`08Ool2000BOol01000
Oomoo`006Woo00<007ooOol0@7oo00<007ooOol0;goo00<007ooOol0:goo00<007ooOol01Goo00@0
07oo000000Yoo`03001oogoo01ioo`007goo00<007ooOol01goo0P0017oo00<007ooOol00Woo00<0
07ooOol01goo00@007ooOol000=oo`8005Eoo`03001oogoo03eoo`03001oogoo00eoo`03001oogoo
01Yoo`D000Moo`03001oogoo03Yoo`03001oogoo00Qoo`<0015oo`04001oogoo000JOol00`00Oomo
o`0oOol00`00Oomoo`0`Ool00`00Oomoo`0[Ool00`00Oomoo`05Ool01000Ool000002Woo00<007oo
Ool07Woo000POol00`00Oomoo`06Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00000goo00<007ooOol0E7oo0P00?7oo00<007ooOol03Woo00<007ooOol06Woo1@001goo00<0
07ooOol0>Woo00<007ooOol027oo0`004Goo0P000Woo00<007ooOol05goo00<007ooOol0?Woo00<0
07ooOol0<Goo00<007ooOol0:goo00<007ooOol01Goo00@007oo000000Uoo`03001oogoo01moo`00
87oo00<007ooOol01Woo0P001Goo00<007ooOol00Woo00<007ooOol01Goo0P000goo00D007ooOomo
o`0005Qoo`<003Qoo`03001oogoo00moo`03001oogoo01Yoo`D000Moo`03001oogoo03Yoo`03001o
ogoo00Qoo`<0015oo`80009oo`03001oogoo01Moo`03001oogoo03aoo`8003Aoo`03001oogoo02]o
o`03001oogoo00Eoo`04001oo`000009Ool00`00Oomoo`0OOol0021oo`03001oogoo00Moo`8000Ao
o`03001oogoo00=oo`03001oogoo00Aoo`8000=oo`05001oogooOol0001KOol00`00Oomoo`0dOol0
0`00Oomoo`0@Ool00`00Oomoo`0JOol50007Ool00`00Oomoo`0jOol00`00Oomoo`09Ool2000AOol3
00000goo001oo`0HOol00`00Oomoo`0kOol00`00Oomoo`0dOol00`00Oomoo`0[Ool00`00Oomoo`05
Ool00`00Ool0000:Ool00`00Oomoo`0OOol0021oo`03001oogoo00Moo`8000Aoo`03001oogoo00=o
o`03001oogoo00=oo`03001oo`0000=oo`05001oogooOol0001LOol00`00Oomoo`0bOol00`00Oomo
o`0AOol00`00Oomoo`0JOol50006Ool00`00Oomoo`0lOol00`00Oomoo`08Ool2000AOol00`00Ool0
0003000HOol00`00Oomoo`0jOol00`00Oomoo`0eOol00`00Oomoo`0[Ool00`00Oomoo`05Ool3000:
Ool00`00Oomoo`0OOol0021oo`03001oogoo00Moo`8000Aoo`03001oogoo00=oo`03001oogoo00=o
o`03001oo`0000=oo`05001oogooOol0001MOol2000bOol00`00Oomoo`0AOol00`00Oomoo`0IOol5
0007Ool00`00Oomoo`0lOol00`00Oomoo`08Ool2000AOol00`00Oomoo`05000FOol00`00Oomoo`0i
Ool00`00Oomoo`0fOol00`00Oomoo`0[Ool00`00Oomoo`05Ool3000:Ool00`00Oomoo`0OOol0021o
o`03001oogoo00Moo`<000=oo`03001oogoo00Aoo`04001oogooOol200000goo001oo`02Ool01@00
Oomoogoo0000Ggoo00<007ooOol0;Woo00<007ooOol04Woo00<007ooOol06Goo00<007oo00000P00
1goo00<007ooOol0?7oo00<007ooOol027oo0P004Goo1`0067oo00<007ooOol0=Goo0`00>Goo00<0
07ooOol0:goo00<007ooOol01Goo0`002Woo00<007ooOol07goo000POol00`00Oomoo`07Ool30003
Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`03001oogoo05ioo`80
02ioo`03001oogoo019oo`03001oogoo01Uoo`03001oo`00008000Moo`03001oogoo03aoo`03001o
ogoo00Qoo`80011oo`<000Eoo`03001oogoo01Eoo`03001oogoo03Aoo`03001oogoo03Yoo`03001o
ogoo02]oo`03001oogoo00Eoo`<000Yoo`03001oogoo01moo`0087oo00<007ooOol01goo0P0000Eo
o`00Oomoo`0000Ioo`05001oogooOol00002Ool01@00Oomoogoo00000goo00<007ooOol0H7oo0P00
;7oo00<007ooOol04goo00<007ooOol067oo00<007oo00000P001goo00<007ooOol0?7oo00<007oo
Ool02Goo00<007ooOol03Goo0P0000=oo`00Ool01Goo00<007ooOol057oo00<007ooOol0<goo00<0
07ooOol0>goo00<007ooOol0:goo00<007ooOol01Goo0P002goo00<007ooOol07goo000QOol00`00
Oomoo`06Ool200001Goo001oogoo00001goo00@007ooOol0009oo`05001oogooOol00003Ool00`00
Oomoo`1ROol00`00Oomoo`0XOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Ool000020007Ool0
0`00Oomoo`0mOol00`00Oomoo`08Ool00`00Oomoo`0:Ool30003Ool00`00Oomoo`05Ool00`00Oomo
o`0COol00`00Oomoo`0aOol2000nOol00`00Oomoo`0/Ool00`00Oomoo`04Ool2000:Ool00`00Oomo
o`0POol0025oo`03001oogoo00Ioo`80009oo`04001oogoo0006Ool01P00Oomoo`00Ool000Aoo`05
001oogooOol0001UOol00`00Oomoo`0WOol00`00Oomoo`0DOol00`00Oomoo`0GOol200000goo0000
0007Ool00`00Oomoo`0nOol00`00Oomoo`08Ool20009Ool30005Ool00`00Oomoo`06Ool2000COol0
0`00Oomoo`0`Ool00`00Oomoo`0nOol00`00Oomoo`0[Ool20006Ool2000:Ool00`00Oomoo`0POol0
025oo`03001oogoo00Moo`07001oogooOol007oo00001goo00D007oo001oo`0000Aoo`05001oogoo
Ool0001VOol2000VOol00`00Oomoo`0EOol00`00Oomoo`0GOol200000goo00000007Ool00`00Oomo
o`0nOol00`00Oomoo`08Ool20006Ool30008Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`0<Ool0
0`00Oomoo`0^Ool20011Ool00`00Oomoo`0[Ool00`00Oomoo`05Ool2000:Ool00`00Oomoo`0POol0
025oo`03001oogoo00Moo`07001oogooOol007oo00001goo200000Eoo`00Oomoo`0006Uoo`03001o
ogoo02=oo`03001oogoo01Eoo`03001oogoo01Moo`800003Ool0000000Moo`03001oogoo03ioo`03
001oogoo00Qoo`<000Aoo`8000Yoo`03001oogoo00Uoo`D000eoo`03001oogoo02eoo`03001oogoo
045oo`03001oogoo02Yoo`8000Ioo`<000Yoo`03001oogoo021oo`008Goo00<007ooOol01goo00<0
07ooOol00Woo0P001Goo10000Woo00@007ooOomoo`D006Yoo`8002=oo`03001oogoo01Eoo`03001o
ogoo01Moo`800003Ool007oo00Moo`03001oogoo03ioo`03001oogoo00Qoo`<000=oo`8000aoo`03
001oogoo00aoo`8000aoo`03001oogoo02Moo`800004Ool000000014Ool00`00Oomoo`0YOol20007
Ool2000;Ool00`00Oomoo`0POol0025oo`03001oogoo00Moo`03001oogoo009oo`8000=oo`<00003
Ool00000009oo`03001oogoo009oo`03001oo`0006eoo`80025oo`03001oogoo01Eoo`03001oogoo
01Moo`@000Qoo`03001oogoo03ioo`03001oogoo00Qoo`<0009oo`8000eoo`03001oogoo00eoo`<0
00Yoo`03001oogoo02Moo`<004Moo`03001oogoo02Uoo`03001oogoo00Ioo`8000]oo`03001oogoo
021oo`008Woo00<007ooOol01Woo0P0017oo0P0000=oo`0000000goo0P000Woo00D007ooOomoo`00
079oo`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo01Moo`@000Moo`03001oogoo041oo`03
001oogoo00Qoo`80009oo`03001oogoo00aoo`03001oogoo011oo`8000Qoo`03001oogoo02Moo`80
04Qoo`8002Yoo`03001oogoo00Ioo`8000Yoo`03001oogoo025oo`008Woo00<007ooOol01Woo0P00
17oo0`001Woo00@007ooOol000=oo`03001oogoo075oo`03001oogoo01eoo`03001oogoo01Eoo`03
001oogoo01Moo`@000Moo`03001oogoo041oo`03001oogoo00Qoo`800003Ool0000000ioo`03001o
ogoo019oo`8000Ioo`8002Qoo`03001oogoo04Qoo`8002Qoo`03001oogoo00Moo`8000Yoo`03001o
ogoo025oo`008Woo00<007ooOol01Woo0P001Goo00<007ooOol01Goo00@007ooOol000=oo`03001o
ogoo079oo`03001oogoo01aoo`03001oogoo01Eoo`03001oogoo01Ioo`03001oo`00008000Moo`03
001oogoo041oo`03001oogoo00Qoo`800003Ool007oo00ioo`03001oogoo01Aoo`8000Eoo`03001o
ogoo02Eoo`8004]oo`@002Aoo`03001oogoo00Qoo`8000Yoo`03001oogoo025oo`008goo00<007oo
Ool01Goo0P0017oo0`001Woo00<007oo00000goo00<007ooOol0M7oo00<007ooOol06goo00<007oo
Ool05Goo00<007ooOol05Woo10001goo00<007ooOol0@Goo00<007ooOol027oo0P0000=oo`00Ool0
3goo00<007ooOol05Goo0`000Woo0P009Woo00<007ooOol0Bgoo0`0097oo00<007ooOol01goo0P00
2Woo00<007ooOol08Woo000SOol00`00Oomoo`05Ool30003Ool30006Ool00`00Ool00002Ool2001g
Ool2000KOol00`00Oomoo`0EOol00`00Oomoo`0FOol40007Ool00`00Oomoo`11Ool00`00Oomoo`08
Ool200000goo001oo`0?Ool00`00Oomoo`0HOol4000VOol00`00Oomoo`1=Ool2000NOol60009Ool2
000:Ool00`00Oomoo`0ROol002=oo`03001oogoo00Ioo`8000=oo`03001oo`0000Ioo`03001oo`00
009oo`03001oogoo07Qoo`03001oogoo01Qoo`03001oogoo01Eoo`03001oogoo01Ioo`@000Moo`03
001oogoo045oo`03001oogoo00Qoo`800003Ool007oo00moo`03001oogoo01Uoo`03001oo`000080
02=oo`03001oogoo051oo`8001]oo`80009oo`<000Uoo`8000Yoo`03001oogoo029oo`0097oo00<0
07ooOol01Goo0P000Woo0P0000=oo`0000001Goo00<007oo00000Woo00<007ooOol0NGoo00<007oo
Ool05goo00<007ooOol05Goo00<007ooOol05Woo0`0027oo00<007ooOol0@Woo00<007ooOol01goo
0P0000=oo`00Ool03goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol087oo00<007ooOol0
DGoo0P0067oo0P0047oo0P002Goo00<007ooOol08goo000TOol00`00Oomoo`05Ool20002Ool00`00
Oomoo`020004Ool2000017oo001oo`00OGoo00<007ooOol05Woo00<007ooOol057oo00<007ooOol0
5goo0`0027oo00<007ooOol0@Woo00<007ooOol01goo0P0000=oo`00Ool03goo00<007ooOol067oo
0P001Goo0`007Woo00<007ooOol0Dgoo00<007ooOol05Woo00<007ooOol03Woo0P002Woo00<007oo
Ool08goo000TOol00`00Oomoo`05Ool3000017oo001oogoo0P0017oo0`000Woo00<007ooOol0O7oo
00<007ooOol05Goo00<007ooOol057oo00<007ooOol05Woo100027oo00<007ooOol0@Woo00<007oo
Ool027oo00<007oo000047oo00<007ooOol067oo00<007ooOol01goo00<007ooOol06Woo00<007oo
Ool0E7oo00<007ooOol057oo0P0047oo0`002Woo00<007ooOol08goo000TOol00`00Oomoo`05Ool8
00000goo001oo`070020Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol50008Ool0
0`00Oomoo`14Ool00`00Oomoo`07Ool00`00Ool0000@Ool00`00Oomoo`0HOol00`00Oomoo`08Ool3
000HOol00`00Oomoo`1EOol00`00Oomoo`0COol00`00Oomoo`0@Ool3000:Ool00`00Oomoo`0SOol0
02Aoo`03001oogoo00Eoo`<00003Ool007oo00800003Ool0000000800003Ool00000008000Ioo`P0
07=oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo015oo`<000=oo`8000Qoo`03001oogoo
04Aoo`03001oogoo00Moo`<0011oo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo01Aoo`03
001oogoo05Ioo`03001oogoo015oo`80019oo`<000]oo`03001oogoo02=oo`0097oo00<007ooOol0
1Woo0P0000=oo`00Ool010000Woo00H007oo000007oo0005Ool20006Ool00`00Oomoo`1aOol2000D
Ool00`00Oomoo`0DOol00`00Oomoo`0@Ool20004Ool30008Ool00`00Oomoo`14Ool00`00Oomoo`07
Ool3000AOol00`00Oomoo`0GOol00`00Oomoo`0<Ool3000BOol00`00Oomoo`1GOol2000@Ool2000C
Ool4000;Ool00`00Oomoo`0SOol002Eoo`03001oogoo00Eoo`80009oo`800006Ool007oo001oo`00
0Woo00<007oo000017oo0P001goo0P00M7oo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
3Woo0P001Woo0`001goo00<007ooOol0AWoo00<007ooOol01Woo0`004Goo00<007ooOol05goo00<0
07ooOol03goo00<007ooOol03Woo00<007ooOol0FGoo0P003Woo0P0057oo00@007oo000000Yoo`03
001oogoo02Aoo`009Goo00<007ooOol01Goo0P000Woo0`000goo0P0000=oo`0000001Woo00<007oo
Ool01goo00<007ooOol0Lgoo00<007ooOol04Goo00<007ooOol04goo00<007ooOol03Goo00<007oo
Ool01Woo0P0027oo00<007ooOol0AWoo00<007ooOol01Woo0`004Goo00<007ooOol05goo00<007oo
Ool047oo0P003Goo00<007ooOol0Fgoo0P002goo0P005Woo10002Woo00<007ooOol097oo000UOol0
0`00Oomoo`05Ool20002Ool30003Ool50006Ool00`00Oomoo`07Ool2001eOol00`00Oomoo`0@Ool0
0`00Oomoo`0COol00`00Oomoo`0;Ool20008Ool30008Ool00`00Oomoo`16Ool00`00Oomoo`07Ool2
000BOol00`00Oomoo`0FOol00`00Oomoo`0BOol2000:Ool00`00Oomoo`1MOol20006Ool5000GOol3
000;Ool00`00Oomoo`0TOol002Ioo`03001oogoo00Aoo`80009oo`8000=oo`80009oo`8000Eoo`03
001oogoo00Uoo`03001oogoo07Aoo`03001oogoo00moo`03001oogoo019oo`03001oogoo00]oo`03
001oogoo00Qoo`<000Moo`03001oogoo04Qoo`03001oogoo00Ioo`80019oo`03001oogoo01Ioo`03
001oogoo01Aoo`8000Moo`03001oogoo05moo`P001]oo`<000Yoo`03001oogoo02Eoo`009Woo00<0
07ooOol01Goo00<007ooOol00P000goo0P000Woo10000goo00<007ooOol02Woo00<007ooOol0Lgoo
00<007ooOol03goo00<007ooOol04Woo00<007ooOol02goo00<007ooOol027oo0P0027oo00<007oo
Ool0B7oo00<007ooOol01Woo0`004Woo00<007ooOol05Goo00<007ooOol05Woo0P0017oo00<007oo
Ool0Hgoo00<007ooOol07Goo0`002Woo00<007ooOol09Goo000VOol00`00Oomoo`04Ool300000goo
001oo`03Ool01P00Ool007oo001oo`@00003Ool007oo00]oo`03001oogoo07Aoo`03001oogoo00eo
o`03001oogoo01=oo`03001oogoo00Uoo`8000Yoo`<000Qoo`03001oogoo04Qoo`03001oogoo00Io
o`800003Ool007oo011oo`03001oogoo01Eoo`8001Uoo`04001oogoo0026Ool2000:Ool00`00Oomo
o`0VOol002Moo`03001oogoo00=oo`D000Aoo`05001oo`00001oo`020002Ool3000=Ool00`00Oomo
o`1dOol00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`09Ool30007Ool0
0`00Oomoo`1:Ool00`00Oomoo`05Ool200000goo0000000AOol00`00Oomoo`0;Ool60004Ool00`00
Oomoo`0HOol20022Ool01000Oomoogoo0`002Woo00<007ooOol09Woo000WOol00`00Oomoo`04Ool5
0002Ool00`00Oomoo`040004Ool4000<Ool00`00Oomoo`1dOol00`00Oomoo`0;Ool00`00Oomoo`0C
Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool20008Ool00`00Oomoo`1:Ool00`00Oomoo`05Ool20002
Ool3000?Ool20009Ool30006Ool300000goo001oo`0IOol01000Ool00000P7oo1`002Goo00<007oo
Ool09goo000XOol00`00Oomoo`03Ool50002Ool00`00Oomoo`030005Ool00`00Oomoo`02000;Ool0
0`00Oomoo`1dOol00`00Oomoo`0;Ool00`00Oomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0:Ool3
0008Ool00`00Oomoo`1:Ool00`00Oomoo`05Ool30002Ool3000?Ool00`00Oomoo`04Ool3000<Ool3
000HOol00`00Oomoo`02Ool00`00Oomoo`1mOol01000Oomoogoo0P002Woo00<007ooOol09goo000X
Ool00`00Oomoo`03Ool3000017oo001oo`000goo0P001Woo00D007ooOomoo`0000aoo`03001oogoo
07Aoo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00Qoo`03001oogoo00Yoo`<000Moo`03
001oogoo04aoo`03001oogoo00Aoo`<000=oo`03001oogoo00moo`04001oogooOol2000@Ool01000
Ool000005Goo00<007ooOol017oo0P00OGoo00@007ooOomoo`8000Uoo`03001oogoo02Qoo`00:Goo
00<007ooOol00Woo0`0000Aoo`000000009oo`8000Eoo`8000Eoo`03001oogoo00Yoo`03001oogoo
03aoo`T002moo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00]oo`80
00Qoo`03001oogoo04aoo`03001oogoo00Eoo`<0009oo`03001oogoo00moo`@001=oo`04001oogoo
000COol00`00Oomoo`07Ool3001jOol00`00Oomoo`030009Ool00`00Oomoo`0XOol002Uoo`03001o
ogoo009oo`@00004Ool00000Ool30005Ool20006Ool00`00Oomoo`09Ool00`00Oomoo`0hOol40009
Ool6000ZOol00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00Oomoo`0;Ool30007
Ool00`00Oomoo`1>Ool00`00Oomoo`04Ool30002Ool00`00Oomoo`0VOol01000Oomoogoo0P0047oo
0P0037oo00<007ooOol0Mgoo00<007ooOol00`002Goo00<007ooOol0:7oo000ZOol01000Oomoogoo
100000Aoo`00001oo`<000=oo`<000Moo`03001oogoo00Uoo`03001oogoo03Aoo`@001=oo`@002Mo
o`03001oogoo00Moo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo00]oo`<000Moo`03001o
ogoo04ioo`03001oogoo00Aoo`800004Ool007oo000XOol00`00Oomoo`03Ool2000>Ool00`00Oomo
o`0<Ool00`00Oomoo`1fOol00`00Ool000020009Ool00`00Oomoo`0YOol002Yoo`04001oogooOol4
0002Ool50002Ool2000:Ool00`00Oomoo`09Ool00`00Oomoo`0cOol00`00Oomoo`0HOol3000TOol0
0`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`0;Ool20007Ool00`00Oomo
o`1@Ool00`00Oomoo`03Ool400000goo001oo`0XOol00`00Oomoo`04Ool30009Ool2000@Ool00`00
Oomoo`1eOol50009Ool00`00Oomoo`0YOol002]oo`04001oogooOol<000<Ool00`00Oomoo`09Ool0
0`00Oomoo`0cOol2000LOol2000SOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`06Ool0
0`00Oomoo`0;Ool30007Ool00`00Oomoo`1AOol00`00Oomoo`03Ool2000017oo00000000:7oo00<0
07ooOol01goo1P0000=oo`0000004goo00<007ooOol0Lgoo1P002Goo00<007ooOol0:Goo000[Ool0
1000Oomoogoo2@0047oo00<007ooOol02Goo00<007ooOol0<goo00<007ooOol077oo00<007ooOol0
87oo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol02goo0`001Woo00<0
07ooOol0DWoo00<007ooOol00goo0`0000=oo`000000:7oo00<007ooOol02goo10005Goo0`00LGoo
1P002Goo00<007ooOol0:Woo000/Ool00`00Oomoo`08000AOol00`00Oomoo`09Ool00`00Oomoo`0d
Ool00`00Oomoo`0LOol3000POol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00
Oomoo`0;Ool20007Ool00`00Oomoo`1BOol00`00Oomoo`03Ool30002Ool00`00Oomoo`0WOol00`00
Oomoo`0VOol00`00Oomoo`1]Ool70009Ool00`00Oomoo`0ZOol002aoo`04001oogooOol6000COol0
0`00Oomoo`08Ool00`00Oomoo`0eOol00`00Oomoo`0NOol2000OOol00`00Oomoo`03Ool00`00Oomo
o`0BOol00`00Oomoo`06Ool00`00Oomoo`0:Ool30007Ool00`00Oomoo`1COol00`00Oomoo`02Ool4
0002Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`1[Ool300000goo001oo`020008Ool0
0`00Oomoo`0[Ool002eoo`03001oogoo00H001=oo`03001oogoo00Uoo`03001oogoo03Eoo`03001o
ogoo01moo`03001oogoo01eoo`03001oogoo009oo`03001oogoo015oo`03001oogoo00Moo`03001o
ogoo00Yoo`<000Ioo`03001oogoo05Aoo`03001oogoo009oo`D00003Ool007oo02Qoo`03001oogoo
02Ioo`03001oogoo06Ioo`03001oo`0000<000=oo`04001oo`000007Ool00`00Oomoo`0/Ool002eo
o`03001oogoo00L001=oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo01moo`03001oogoo
01aoo`03001oogoo009oo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo00Yoo`<000Ioo`03
001oogoo05Ioo`03001oogoo009oo`D00003Ool007oo02Moo`03001oogoo02Moo`03001oogoo06Eo
o`8000=oo`04001oogooOol30008Ool00`00Oomoo`0/Ool002ioo`H00003Ool0000001=oo`03001o
ogoo00Qoo`03001oogoo03Ioo`03001oogoo01moo`8001ioo`05001oogooOol0000COol00`00Oomo
o`06Ool00`00Oomoo`0:Ool30006Ool00`00Oomoo`1FOol00`00Oomoo`02Ool8000XOol00`00Oomo
o`0WOol00`00Oomoo`1UOol01000Ool0000017oo0`001goo00<007ooOol0;Goo000^Ool60002Ool0
0`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`0gOol00`00Oomoo`0POol00`00Oomoo`0KOol0
1@00Oomoogoo00004Woo00<007ooOol01goo00<007ooOol02Woo0`001Goo00<007ooOol0F7oo00@0
07ooOomoo`H00005Ool007ooOol0000UOol00`00Oomoo`0XOol00`00Oomoo`1SOol01000Ool00000
1Goo0`001goo00<007ooOol0;Goo000^Ool00`00Oomoo`0400000goo0000000COol00`00Oomoo`07
Ool00`00Oomoo`0hOol00`00Oomoo`0POol2000LOol01000Oomoo`004Woo00<007ooOol01goo00<0
07ooOol02Goo0`001Woo00<007ooOol0F7oo00@007ooOomoo`<0009oo`800004Ool00000000VOol0
0`00Oomoo`0XOol00`00Oomoo`1?Ool9000:Ool20006Ool40006Ool00`00Oomoo`0^Ool002moo`03
001oogoo00H001Aoo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo025oo`03001oogoo01Uo
o`04001oogoo000BOol00`00Oomoo`07Ool00`00Oomoo`09Ool30005Ool00`00Oomoo`1JOol00`00
Oomoo`030002Ool5000XOol00`00Oomoo`0XOol00`00Oomoo`1;Ool30009Ool50004Ool30006Ool3
0007Ool00`00Oomoo`0^Ool002moo`04001oogooOol5000EOol00`00Oomoo`05Ool00`00Oomoo`0j
Ool00`00Oomoo`0QOol00`00Oomoo`0IOol00`00Ool0000AOol00`00Oomoo`09Ool00`00Oomoo`08
Ool30005Ool00`00Oomoo`1JOol01000Oomoogoo2@00:7oo00<007ooOol0:7oo00<007ooOol0BGoo
0P0047oo1P001goo00@007oo000000Ioo`03001oogoo02moo`00<7oo00<007ooOol00Woo100057oo
00<007ooOol01Woo00<007ooOol0>Woo00<007ooOol087oo0P006Woo0`004Goo00<007ooOol02Goo
00<007ooOol01goo0`001Goo00<007ooOol0G7oo00<007ooOol01@0000=oo`0000000P00:7oo00<0
07ooOol0:7oo00<007ooOol0AWoo0P005goo0P001Woo10001Woo00<007ooOol0;goo000aOol01000
Oomoogoo1@0057oo00<007ooOol01Goo00<007ooOol0>goo00<007ooOol08Goo00<007ooOol06Goo
0P0047oo00<007ooOol02Goo00<007ooOol01goo0`0017oo00<007ooOol0GWoo00<007oo00000`00
0Woo0P0000=oo`000000:7oo00<007ooOol0:7oo00<007ooOol0AGoo00<007ooOol05Woo0P001Goo
1@001Goo00<007ooOol0<7oo000bOol01000Oomoogoo10005Goo00<007ooOol017oo00<007ooOol0
?7oo00<007ooOol08Goo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol02Goo0P001goo1000
17oo00<007ooOol0GWoo00<007ooOol01`0000=oo`000000:7oo00<007ooOol0:Goo00<007ooOol0
@Woo0P006Goo00<007ooOol017oo10001Goo00<007ooOol0<Goo000bOol00`00Oomoo`02Ool4000E
Ool00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`0POol2000JOol00`00Oomoo`0>Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool40004Ool00`00Oomoo`1POol00`00Oomoo`0700000goo0000000X
Ool00`00Oomoo`0XOol00`00Oomoo`11Ool00`00Oomoo`0HOol20003Ool01000Ool007oo0`001Goo
00<007ooOol0<Goo000cOol00`00Oomoo`02Ool4000EOol20002Ool00`00Oomoo`0oOol00`00Oomo
o`0QOol00`00Oomoo`0GOol2000>Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool01000Ool0000017oo
00<007ooOol0H7oo00@007ooOomoo`<00003Ool0000000<002Qoo`8002Uoo`03001oogoo041oo`03
001oogoo01Uoo`03001oogoo009oo`<00003Ool0000000Eoo`03001oogoo039oo`00=7oo00<007oo
Ool00Woo10005Woo0`00@Woo0P008Woo00<007ooOol05Woo0`003Goo00<007ooOol037oo0P000Woo
1P000goo00<007ooOol0HWoo00@007ooOomoo`P002Uoo`03001oogoo02Qoo`03001oogoo03ioo`80
01]oo`03001oogoo00Aoo`04001oo`000005Ool00`00Oomoo`0bOol003Aoo`03001oogoo00=oo`<0
01Moo`<004=oo`03001oogoo01moo`03001oogoo01Ioo`04001oogoo000<Ool00`00Oomoo`0=Ool0
0`00Oomoo`0200000goo00000003Ool00`00Oomoo`1TOol01000Oomoogoo1@0000=oo`00Ool0:Goo
00<007ooOol0:7oo00<007ooOol0?7oo00<007ooOol06Woo00<007ooOol01Goo100017oo00<007oo
Ool0<goo000eOol00`00Oomoo`03Ool3000GOol01000Ool00000@Woo00<007ooOol07goo00<007oo
Ool05Woo00@007ooOol000]oo`03001oogoo00aoo`T0009oo`03001oogoo06Ioo`03001oogoo00<0
0003Ool0000000<002Qoo`03001oogoo02Qoo`03001oogoo03]oo`03001oogoo01]oo`03001oogoo
00Eoo`<000Aoo`03001oogoo03Aoo`00=Goo00<007ooOol017oo0`005Woo00@007ooOomoo`80041o
o`80021oo`03001oogoo01Ioo`05001oogooOol0000:Ool00`00Oomoo`0:Ool20002Ool00`00Oomo
o`040002Ool00`00Oomoo`1VOol00`00Oomoo`02Ool7000YOol00`00Oomoo`0XOol00`00Oomoo`0j
Ool00`00Oomoo`0JOol20007Ool30004Ool00`00Oomoo`0dOol003Ioo`03001oogoo00Aoo`<001Eo
o`03001oogoo00=oo`80041oo`8001moo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00Uoo`8000=oo`<00004Ool000000002Ool00`00Oomoo`1XOol01000Oomoogoo1P00
00=oo`00Ool09goo0P00:Goo00<007ooOol0>Goo00<007ooOol06goo00<007ooOol01Woo0P0017oo
00<007ooOol0=Goo000gOol00`00Oomoo`04Ool2000EOol00`00Oomoo`05Ool2000nOol3000OOol0
0`00Oomoo`0DOol00`00Oomoo`03Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Ool0
07oo100000=oo`00Ool0Jgoo00@007ooOomoo`P002Qoo`03001oogoo02Qoo`03001oogoo03Moo`03
001oogoo01]oo`8000Moo`<000=oo`03001oogoo03Ioo`00>7oo00<007ooOol017oo0P0057oo00<0
07ooOol01goo0P00>Goo100000=oo`0000000P0077oo00<007ooOol057oo00<007ooOol01Goo0P00
17oo00<007ooOol01goo00<007ooOol00Woo0P0000Aoo`00001oo`@006ioo`03001oogoo009oo`D0
0003Ool007oo02Ioo`03001oogoo02Uoo`03001oogoo03Aoo`8001ioo`03001oogoo00Ioo`<0009o
o`03001oogoo03Moo`00>Goo00<007ooOol017oo0P004goo00<007ooOol02Goo00<007ooOol0=7oo
0P0027oo0`004goo100017oo00<007ooOol04goo00<007ooOol01goo0`0000=oo`00Ool01Woo0`00
0Woo0P000goo1P00L7oo00<007ooOol00Woo1@0000=oo`00Ool097oo0P00:goo0P006Woo00<007oo
Ool05goo00<007ooOol07Goo0P001Woo10000Woo00<007ooOol0>7oo000iOol00`00Oomoo`04Ool3
000BOol00`00Oomoo`0:Ool2000bOol2000<Ool2000<Ool60004Ool5000EOol00`00Oomoo`0:Ool2
0005Ool300000goo000000020004Ool400000goo001oo`1_Ool00`00Oomoo`02Ool50002Ool00`00
Oomoo`0ROol00`00Oomoo`0[Ool2000IOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`04
Ool50002Ool00`00Oomoo`0hOol003Yoo`03001oogoo00Eoo`80019oo`03001oogoo00Yoo`03001o
ogoo031oo`03001oogoo00aoo`d000moo`03001oogoo019oo`03001oogoo00]oo`P000Uoo`@00003
Ool007oo075oo`03001oogoo00=oo`@00003Ool007oo02=oo`03001oogoo02aoo`<001Aoo`H001Eo
o`03001oogoo01moo`03001oogoo009oo`H0009oo`03001oogoo03Uoo`00>goo00<007ooOol017oo
0`004Goo00<007ooOol02goo0P00;goo00<007ooOol03goo0P0067oo0`004Woo00<007ooOol02goo
00<007ooOol00Woo3`0000=oo`00Ool0Lgoo00<007ooOol00goo0`000Woo00<007ooOol08Goo00<0
07ooOol0;Woo0`0037oo00<007oo000010001Goo0P004Goo0P008Goo0P0017oo1@000Woo00<007oo
Ool0>Woo000lOol00`00Oomoo`04Ool3000@Ool00`00Oomoo`0=Ool00`00Oomoo`0[Ool00`00Oomo
o`0BOol00`00Oomoo`0FOol00`00Ool00002000>Ool00`00Oomoo`0<Ool01`00Oomoogoo001oo`00
00Eoo`<00006Ool00000001oo`00MGoo00<007ooOol00goo10000Woo00<007ooOol087oo00<007oo
Ool0<Goo0P002Goo0`002goo0`003Woo00<007ooOol08Goo00<007ooOol00goo10000Woo00<007oo
Ool0>goo000mOol00`00Oomoo`05Ool2000?Ool00`00Oomoo`0>Ool00`00Oomoo`0ZOol00`00Oomo
o`0COol00`00Oomoo`0FOol01000Oomoogoo0P0037oo00<007ooOol037oo00H007ooOol007oo0004
Ool20003Ool300000goo001oo`1fOol00`00Oomoo`03Ool30002Ool00`00Oomoo`0POol00`00Oomo
o`0cOol40004Ool00`00Oomoo`0>Ool2000;Ool2000TOol00`00Oomoo`02Ool30003Ool00`00Oomo
o`0lOol003eoo`03001oogoo00Ioo`8000moo`03001oogoo00ioo`8002Yoo`03001oogoo01Aoo`80
01Ioo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00aoo`03001oo`00009oo`03001oo`00
008000Aoo`03001oogoo009oo`03001oogoo07Eoo`03001oogoo00Aoo`@00003Ool007oo01moo`03
001oogoo03Qoo`@001=oo`8000Moo`8002Eoo`8000=oo`<000Aoo`03001oogoo03aoo`00?Woo00<0
07ooOol01Woo0P003Woo00<007ooOol047oo00<007ooOol09goo00<007ooOol05Goo0P005Woo00<0
07ooOol00goo0P0027oo00<007ooOol03Goo0P000Woo0`001Goo0P0017oo00<007ooOol0Mgoo00<0
07ooOol017oo0`000Woo00<007ooOol07Goo00<007ooOol0>Woo0P0057oo10000goo00<007ooOol0
9Goo00@007ooOomoo`<000Aoo`03001oogoo03eoo`00?goo00<007ooOol01Woo0P003Woo00<007oo
Ool03goo00<007ooOol09goo00<007ooOol05Woo0P005Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol03Goo00<007ooOol00P001Goo0`0017oo00<007ooOol0NGoo0P001Goo0`0000=oo`00
Ool07Woo00<007ooOol0>Goo00<007ooOol010004goo1000:7oo00<007ooOol00P001Goo00<007oo
Ool0?Woo0010Ool00`00Oomoo`06Ool3000<Ool00`00Oomoo`0@Ool2000WOol00`00Oomoo`0GOol2
000EOol00`00Oomoo`05Ool20005Ool00`00Oomoo`0<Ool400000goo001oo`03Ool20005Ool00`00
Oomoo`1lOol00`00Oomoo`04Ool4000NOol00`00Oomoo`0hOol00`00Oomoo`05Ool5000>Ool3000X
Ool60004Ool00`00Oomoo`0oOol0045oo`03001oogoo00Ioo`8000aoo`03001oogoo019oo`03001o
ogoo02Aoo`03001oogoo01Uoo`03001oogoo01=oo`03001oogoo00Ioo`05001oogooOol0000=Ool3
000017oo001oo`000Woo00@007oo000000Eoo`03001oogoo07ioo`03001oogoo00Aoo`<001ioo`03
001oogoo03Moo`03001oogoo00]oo`L000Eoo`8000=oo`03001oogoo02Eoo`@000Eoo`03001oogoo
041oo`00@Woo00<007ooOol01Woo0P002goo00<007ooOol04goo0P009Goo00<007ooOol06Goo0`00
4goo00<007ooOol01Woo0`002goo0`0000=oo`00Ool00Woo0P0000=oo`0000000P001Goo00<007oo
Ool0P7oo00<007ooOol00goo1@0077oo00<007ooOol0=Woo00<007ooOol04goo1P0017oo1@008Goo
1@001Goo00<007ooOol0@Goo0013Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0DOol4000QOol0
0`00Oomoo`02Ool3000FOol3000BOol00`00Oomoo`07Ool600000goo000000030003Ool00`00Oomo
o`03Ool50005Ool00`00Oomoo`22Ool00`00Oomoo`03Ool7000IOol2000eOol2000TOol7000IOol0
0`00Ool000030005Ool00`00Oomoo`12Ool004Aoo`03001oogoo00Ioo`8000Yoo`03001oogoo01Qo
oa80011oo`03001oo`0000800003Ool00000008001Ioo`<0011oo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo009oo`@000Ioo`03001oogoo08Aoo`03001oogoo00=oo`@0
0003Ool0000001Uoo`03001oogoo03=oo`03001oogoo01]oo`03001oogoo00aoo`8001Moo`D000Eo
o`03001oogoo04=oo`00AGoo00<007ooOol01Woo0P002Goo00<007ooOol0:Woo0P003Woo0P0027oo
0P005goo0P003goo0P001Goo00<007ooOol037oo00@007ooOomoo`D000Ioo`03001oogoo08Ioo`03
001oogoo00=oo`@00003Ool0000001Qoo`80039oo`8001moo`03001oogoo00eoo`8000]oo`@000Eo
o`@000Ioo`03001oogoo04Aoo`00AWoo00<007ooOol01Woo0P0027oo00<007ooOol0;7oo0P002Woo
0P000Woo00<007ooOol01goo0P005Woo0P0047oo00<007ooOol00Woo00<007ooOol037oo00<007oo
Ool01@001Woo00<007ooOol0R7oo00<007ooOol00goo100000=oo`00Ool067oo00<007ooOol0;goo
00<007ooOol077oo10004Goo0P001goo0P000goo0P000Woo1@001Woo00<007ooOol0AGoo0017Ool2
0007Ool20007Ool00`00Oomoo`0^Ool20007Ool20003Ool90002Ool2000GOol2000?Ool4000>Ool7
0007Ool00`00Oomoo`2:Ool00`00Oomoo`03Ool6000HOol2000_Ool2000MOol01@00Oomoogoo0000
4goo0P000goo0P001Woo00<007oo000010001Goo0P00B7oo0019Ool00`00Oomoo`05Ool30005Ool0
0`00Oomoo`0`Ool00`00Oomoo`04Ool00`00Oomoo`020002Ool00`00Oomoo`04Ool4000IOol2000?
Ool3000<Ool01000Oomoogoo0`001goo00<007ooOol0S7oo00<007ooOol00goo1@006Goo00<007oo
Ool0;7oo0P007Goo0P000goo00<007ooOol04goo0`0027oo1P001Goo00<007ooOol0B7oo001:Ool0
0`00Oomoo`05Ool40003Ool00`00Oomoo`0aOol20004Ool00`00Ool00005Ool20008Ool2000HOol2
000>Ool00`00Oomoo`020008Ool3000017oo000000001goo0P00T7oo0P001Goo100067oo00<007oo
Ool0:goo00<007ooOol07Goo00<007ooOol00Woo0P007goo1@001Goo00<007ooOol0BGoo001;Ool0
0`00Oomoo`03Ool60002Ool00`00Oomoo`0bOol00`00Oomoo`02Ool20008Ool00`00Oomoo`05Ool0
0`00Ool0000IOol00`00Oomoo`0;Ool00`00Oomoo`02Ool200000goo0000000300000goo001oo`03
0007Ool00`00Oomoo`2BOol00`00Oomoo`02Ool4000IOol00`00Oomoo`0ZOol00`00Oomoo`0LOol0
0`00Oomoo`04Ool00`00Oomoo`0LOol40006Ool00`00Oomoo`1:Ool004aoo`03001oogoo00=oo`P0
03Eoo`05001oogooOol0000:Ool30003Ool20002Ool2000GOol2000;Ool00`00Oomoo`02Ool60002
Ool50008Ool00`00Oomoo`2DOol00`00Oomoo`02Ool4000HOol00`00Oomoo`0YOol00`00Oomoo`0K
Ool30006Ool00`00Oomoo`0JOol50006Ool00`00Oomoo`1;Ool004eoo`03001oogoo00Eoo`L003Ao
o`@000eoo`@000Eoo`8001Moo`03001oogoo00Qoo`D000Eoo`H000Uoo`03001oogoo09Ioo`03001o
ogoo00=oo`@001Moo`03001oogoo02Moo`03001oogoo01aoo`8000Moo`03001oogoo01Uoo`D000Io
o`03001oogoo04aoo`00CWoo0P001Woo0`0000=oo`0000000P00=7oo0P0067oo0P005Woo00<007oo
Ool01Goo0P002Woo1@0027oo0P00VWoo00<007ooOol00goo10005Woo0P009goo0P007Woo00<007oo
Ool01goo00<007ooOol05goo10001Woo0P00Cgoo001@Ool00`00Oomoo`05Ool30002Ool3000aOol0
1000Ool000006Goo0P0057oo00@007ooOomoo`@00003Ool007oo00Moo`D000Uoo`03001oogoo09]o
o`03001oogoo00=oo`D001Eoo`03001oogoo02Eoo`03001oogoo01eoo`03001oogoo00Moo`8001Eo
o`H000Ioo`03001oogoo04moo`00DGoo00<007ooOol01Woo0`0000Aoo`000000031oo`03001oo`00
008001Yoo`03001oogoo019oo`<000Eoo`03001oogoo00Aoo`800003Ool0000000Yoo`03001oogoo
09eoo`8000Aoo`D001Aoo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo00Qoo`8000Yoo`03
001oogoo00Aoo`L000Moo`03001oogoo051oo`00DWoo00<007ooOol01Woo2000;Woo00<007ooOol0
10006Goo00<007ooOol047oo0P0000=oo`00Ool00goo00<007ooOol00goo1P002Woo00<007ooOol0
X7oo00<007ooOol00Woo1P004goo00<007ooOol08Woo00<007ooOol07goo00<007ooOol02Goo0P00
27oo20000Woo10001goo00<007ooOol0DGoo001COol20009Ool7000[Ool00`00Oomoo`02Ool20000
0goo001oo`0HOol00`00Oomoo`0=Ool20004Ool01@00Oomoogoo000017oo00<007oo00000`002Woo
00<007ooOol0XWoo00<007ooOol00Woo1`004Woo00<007ooOol087oo00<007ooOol087oo00<007oo
Ool02Goo0P001goo0P001Goo1`001Woo0P00E7oo001EOol00`00Oomoo`09Ool6000YOol00`00Oomo
o`03Ool01000Oomoo`006Goo0P0037oo00<007ooOol01Goo00<007oo00000goo0P000Woo0P002goo
00<007ooOol0Y7oo00<007ooOol00Woo1@0000=oo`00Ool047oo00<007ooOol06Goo00<007ooOol0
0goo00<007ooOol08Goo00<007ooOol02Goo00<007ooOol00goo0`001Woo1`001Woo00<007ooOol0
E7oo001FOol00`00Oomoo`09Ool7000WOol00`00Oomoo`04Ool00`00Oomoo`02000IOol00`00Oomo
o`09Ool00`00Oomoo`06Ool3000017oo001oogoo10002Goo0P00Z7oo0P0017oo100000=oo`000000
47oo00<007ooOol067oo1`008Woo00<007ooOol02goo00<007oo00000`0027oo1@001goo00<007oo
Ool0EGoo001GOol2000<Ool6000UOol00`00Oomoo`04Ool20003Ool00`00Oomoo`0GOol00`00Oomo
o`06Ool2000:Ool7000:Ool2002/Ool20003Ool500000goo001oo`0?Ool00`00Oomoo`0FOol2000X
Ool00`00Oomoo`04Ool:0009Ool60006Ool2001HOol005Uoo`8000eoo`D0029oo`03001oogoo00Io
o`8000=oo`8001Moo`03001oogoo00Eoo`03001oogoo00Uoo`L000Uoo`800;1oo`8000=oo`H0009o
o`03001oogoo00Yoo`8001Moo`03001oogoo02Moo`04001oogooOol30009Ool00`00Oomoo`04Ool8
0005Ool2001JOol005]oo`8000eoo`H001moo`03001oogoo00Moo`03001oogoo00=oo`8001Ioo`03
001oogoo00=oo`03001oogoo00Qoo`<00003Ool0000000]oo`03001oogoo0;9oo`03001oogoo009o
o`P000aoo`03001oogoo01Aoo`03001oogoo02Qoo`@000eoo`04001oogooOol200000goo00000003
0005Ool2001LOol005eoo`8000ioo`H001]oo`03001oogoo00Qoo`8000Ioo`8001Eoo`05001oogoo
Ool00009Ool3000017oo000000002Woo0P00]Woo0P0017oo1`0037oo00<007ooOol04Woo00<007oo
Ool077oo00<007ooOol01Goo1@0000=oo`0000003goo0`000Woo1@0017oo0P00GWoo001OOol00`00
Oomoo`0>Ool5000IOol00`00Oomoo`09Ool20007Ool3000BOolC000:Ool2002jOol20006Ool70009
Ool00`00Oomoo`0AOol00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`04Ool4000=Ool20000
0goo000000030005Ool00`00Oomoo`1NOol0061oo`80011oo`D001Ioo`03001oogoo00]oo`8000Uo
o`@000aoo`80009oo`03001oogoo00Eoo`L000Yoo`800;ioo`8000Ioo`L000Moo`80011oo`8001Yo
o`04001oogooOol30003Ool30006Ool00`00Ool000040008Ool200000goo000000040004Ool2001Q
Ool0069oo`80015oo`H0019oo`03001oogoo00aoo`8000aooad000Yoo`800<9oo`8000Moo`T000=o
o`8000moo`03001oogoo01Qoo`/00003Ool0000000Ioo`04001oogoo0002Ool40003Ool90004Ool2
001SOol006Aoo`<0015oo`T000aoo`03001oogoo00eoo`<001=oo``00003Ool00000008000]oo`80
0<Ioo`8000Qoo``000Eoo`03001oogoo00Eoo`03001oogoo01Qoo`800003Ool0000000Eoo`@000Qo
o`04001oogoo0002Ool200000goo000000090002Ool3001UOol006Moo`03001oogoo011oo`T000Uo
o`03001oogoo015oo`@000]ooa4000eoo`800<Yoo`8000Uoo`H00004Ool000000003Ool20007Ool0
0`00Oomoo`0GOol01000Ool000002goo0`001Goo00<007ooOol03`000Woo0P00J7oo001XOol2000B
Ool;0003Ool2000AOolK000COol2003>Ool20009Ool=0006Ool00`00Oomoo`0GOol3000@Ool80000
0goo000000090004Ool00`00Oomoo`1XOol006Yoo`8001=oo`L00003Ool0000001H000Eoo`d001Qo
o`800=9oo`8000Yoo`L00004Ool000000005Ool00`00Oomoo`0FOol2000@OolC0005Ool2001[Ool0
06aoo`<001=oo`l000Uoo`d001moo`<00=Ioo`<000]oo`L000Aoo`8000Qoo`L0009oo`L000ioo`@0
00Aoo`X000Moo`<006eoo`00Kgoo0`0057oo5@00:7oo0`00g7oo0`002goo4P001goo0P000goo0`00
2goo100000=oo`00000030001goo0`00L7oo001bOol3000EOol6000`Ool3003ROol3000;Ool8000@
Ool40009OolC0008Ool3001cOol007Eoo`<0019oo`D002ioo`<00>Qoo`<000]ooaX000Aoo`h000io
o`<007Ioo`00N7oo1P00>Woo1@00kWoo1@002Goo400000=oo`00000040003Woo1P00NGoo001nOol3
000dOol3003hOol30009OolI000BOol3001oOol0085oo`D002Qoo`L00?ioo`H000Moo`/001Ioo`H0
089oo`00QWoo20006Goo1`00ogoo37oo20006Goo1`00R7oo002>OolI003oOolKOolI002?Ool00?mo
oomoof]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00ogooogooJgoo003oOoooOom[
Ool00?mooomoof]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00/goo2000ogoo=7oo
2000Lgoo003oOoooOom[Ool00?mooomoof]oo`00Y7oo00@007ooOol00?moocQoo`04001oogoo0026
Ool006]oo`<000Aoo`@000Ioo`04001oogooOol30003Ool20002Ool3000017oo000007oo1`000Woo
1@001Goo00@007ooOol000Eoo`<000ioo`D000Aoo`800==oo`D000Aoo`<00004Ool00000Ool90000
17oo000000000Woo0`000goo0P000Woo0`0000Aoo`00001oo`L0009oo`D000Eoo`04001oogoo0007
Ool3000<Ool5001[Ool006Yoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool00003Ool20005Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool01000Oomoo`000goo00D007ooOomoo`0000moo`03001oogoo00Aoo`800=Aoo`05001oogoo
Ool00002Ool01000Oomoogoo0P001Goo00<007ooOol00Woo0P000goo00@007ooOol000Eoo`03001o
o`0000=oo`8000Eoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo0007Ool00`00Oomoo`0=
Ool00`00Oomoo`1[Ool006Uoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo009oo`04001o
ogoo0002Ool00`00Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`08Ool60006
Ool00`00Oomoo`0=Ool00`00Oomoo`3JOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`0017oo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo1P001Woo00<007ooOol03Goo00<007oo
Ool0Jgoo001YOol00`00Oomoo`0:Ool00`00Oomoo`04Ool02`00Oomoogoo001oo`00Ool007oo0000
0Woo1@001Goo00<007ooOol00Woo1P001Woo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo
0=Yoo`05001oogooOol00003Ool50005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool02P00Oomoo`00
Ool007oo001oo`000Woo1@001Goo00<007ooOol00Woo1P001Woo00@007ooOol000=oo`H000ioo`03
001oogoo06]oo`00JGoo00<007ooOol02Woo00<007ooOol017oo00d007ooOomoo`00Ool007oo001o
o`00Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
1000Oomoo`001Goo0P0047oo00<007ooOol0fWoo10000goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo0P000goo00`007ooOol007oo001oo`00Ool007oo0004Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`0017oo00@007ooOol000mo
o`03001oogoo06]oo`00JGoo00<007ooOol01Woo10001goo00/007ooOomoo`00Ool007oo001oo`00
009oo`@000Ioo`03001oogoo00=oo`@000Ioo`H000Ioo`03001oogoo00eoo`03001oogoo0=Yoo`05
001oogooOol00003Ool40006Ool00`00Oomoo`02Ool00`00Ool000020003Ool01`00Ool007oo001o
o`00009oo`@000Ioo`03001oogoo00=oo`@000Ioo`H000=oo`04001oogoo000?Ool00`00Oomoo`1[
Ool006Yoo`03001oogoo008000=oo`03001oogoo00Uoo`03001oogoo008000=oo`8000aoo`03001o
ogoo00ioo`04001oogoo0007Ool00`00Oomoo`0=Ool00`00Oomoo`3JOol01@00Oomoogoo00003Goo
00<007ooOol00Woo00<007ooOol01Goo0P000goo0P0037oo00<007ooOol03Woo00@007ooOol000Eo
o`03001oo`0000moo`03001oogoo06]oo`00Jgoo0P0000=oo`00Ool00Woo00<007ooOol017oo00<0
07ooOol00Woo00<007oo00000P000goo0P0037oo00<007ooOol03goo00@007ooOol0009oo`05001o
ogooOol0000=Ool3003KOol5000>Ool00`00Oomoo`02Ool00`00Oomoo`04Ool30003Ool2000<Ool0
0`00Oomoo`0?Ool01000Oomoo`0017oo00<007oo00003Goo0`00KGoo001bOol50002Ool6000DOol2
000AOol01000Oomoo`000goo0`0047oo00<007ooOol0jgoo0P000goo0P006Goo0P004Goo00@007oo
Ool000Eoo`8000moo`03001oogoo06]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00
ogooogooJgoo003oOoooOom[Ool00?mooomoof]oo`00ogooogooJgoo003oOoooOom[Ool00?mooomo
of]oo`00ogooogooJgoo0000\
\>"],
  ImageRangeCache->{{{0, 616}, {292.75, 0}} -> {-0.0521017, -0.0238146, \
0.00341592, 0.00341592}, {{15.25, 294}, {285.75, 6.9375}} -> {-213.429, \
-188.164, 1.3803, 1.3803}, {{321.938, 600.688}, {285.75, 6.9375}} -> \
{-636.75, -188.164, 1.3803, 1.3803}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
As shown, both mice tend to move along the walls,and the paths of both \
converge to(or diverge from) the home base, here located at approximately 9  \
o'clock.\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\

 We can calculate  the mileage covered by the two animals, again by using \
Script:  \
\>", "Text",
  PageWidth->WindowWidth,
  TextJustification->0,
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Script[{"\<Activity[{1,37500}]*0.01meters\>"}, twofiles]\)], "Input"],

Cell[BoxData[
    \({{163.15016323731493`\ meters}, {94.08452489126152`\ meters}}\)], \
"Output"]
}, Open  ]],

Cell["Or in a more dynamical version (in meters !):", "Text",
  PageWidth->PaperWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(activitybyslice = 
      Script[{"\<Map[Activity,TimeSlice[{1,(300*25*5)},7500]]*0.01\>"}, 
        twofiles]\)], "Input"],

Cell[BoxData[
    \({{{49.371792157791226`, 43.37151141928933`, 26.33262010599173`, 
          23.533383691819786`, 20.54051837919499`}}, {{5.175231211089207`, 
          5.844754604562171`, 22.625051622288012`, 20.031092389782657`, 
          40.402769292609314`}}}\)], "Output"]
}, Open  ]],

Cell["\<\
Note that by naming the resultant list we can later call it by its name. \
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
We can now compare the dynamics of activity in the two mice: to do this we \
first have to  flatten out the list by one level:\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(actbyslc = Flatten[activitybyslice, 1]\)], "Input"],

Cell[BoxData[
    \({{49.371792157791226`, 43.37151141928933`, 26.33262010599173`, 
        23.533383691819786`, 20.54051837919499`}, {5.175231211089207`, 
        5.844754604562171`, 22.625051622288012`, 20.031092389782657`, 
        40.402769292609314`}}\)], "Output"]
}, Open  ]],

Cell["\<\
The  command before last asks for the activity by slices of 5mn (=300*25 data \
points given our time unit of one video frame). The result can easily be \
visualised:\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[actbyslc[\([1]\)], PlotRange -> All, PlotJoined\  -> True, 
      AxesOrigin -> {0, 0}, Frame -> True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.404629 0.0204155 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00368 -12 -4.5 ]
[-0.0125 .00368 0 4.5 ]
[-0.0125 .10576 -12 -4.5 ]
[-0.0125 .10576 0 4.5 ]
[-0.0125 .20783 -12 -4.5 ]
[-0.0125 .20783 0 4.5 ]
[-0.0125 .30991 -12 -4.5 ]
[-0.0125 .30991 0 4.5 ]
[-0.0125 .41199 -12 -4.5 ]
[-0.0125 .41199 0 4.5 ]
[-0.0125 .51407 -12 -4.5 ]
[-0.0125 .51407 0 4.5 ]
[-0.0125 .61614 -12 -4.5 ]
[-0.0125 .61614 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(4)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00368 m
.00625 .00368 L
s
[(20)] -0.0125 .00368 1 0 Mshowa
0 .10576 m
.00625 .10576 L
s
[(25)] -0.0125 .10576 1 0 Mshowa
0 .20783 m
.00625 .20783 L
s
[(30)] -0.0125 .20783 1 0 Mshowa
0 .30991 m
.00625 .30991 L
s
[(35)] -0.0125 .30991 1 0 Mshowa
0 .41199 m
.00625 .41199 L
s
[(40)] -0.0125 .41199 1 0 Mshowa
0 .51407 m
.00625 .51407 L
s
[(45)] -0.0125 .51407 1 0 Mshowa
0 .61614 m
.00625 .61614 L
s
[(50)] -0.0125 .61614 1 0 Mshowa
.125 Mabswid
0 .0241 m
.00375 .0241 L
s
0 .04451 m
.00375 .04451 L
s
0 .06493 m
.00375 .06493 L
s
0 .08534 m
.00375 .08534 L
s
0 .12617 m
.00375 .12617 L
s
0 .14659 m
.00375 .14659 L
s
0 .167 m
.00375 .167 L
s
0 .18742 m
.00375 .18742 L
s
0 .22825 m
.00375 .22825 L
s
0 .24867 m
.00375 .24867 L
s
0 .26908 m
.00375 .26908 L
s
0 .2895 m
.00375 .2895 L
s
0 .33033 m
.00375 .33033 L
s
0 .35074 m
.00375 .35074 L
s
0 .37116 m
.00375 .37116 L
s
0 .39157 m
.00375 .39157 L
s
0 .4324 m
.00375 .4324 L
s
0 .45282 m
.00375 .45282 L
s
0 .47324 m
.00375 .47324 L
s
0 .49365 m
.00375 .49365 L
s
0 .53448 m
.00375 .53448 L
s
0 .5549 m
.00375 .5549 L
s
0 .57531 m
.00375 .57531 L
s
0 .59573 m
.00375 .59573 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00368 m
1 .00368 L
s
.99375 .10576 m
1 .10576 L
s
.99375 .20783 m
1 .20783 L
s
.99375 .30991 m
1 .30991 L
s
.99375 .41199 m
1 .41199 L
s
.99375 .51407 m
1 .51407 L
s
.99375 .61614 m
1 .61614 L
s
.125 Mabswid
.99625 .0241 m
1 .0241 L
s
.99625 .04451 m
1 .04451 L
s
.99625 .06493 m
1 .06493 L
s
.99625 .08534 m
1 .08534 L
s
.99625 .12617 m
1 .12617 L
s
.99625 .14659 m
1 .14659 L
s
.99625 .167 m
1 .167 L
s
.99625 .18742 m
1 .18742 L
s
.99625 .22825 m
1 .22825 L
s
.99625 .24867 m
1 .24867 L
s
.99625 .26908 m
1 .26908 L
s
.99625 .2895 m
1 .2895 L
s
.99625 .33033 m
1 .33033 L
s
.99625 .35074 m
1 .35074 L
s
.99625 .37116 m
1 .37116 L
s
.99625 .39157 m
1 .39157 L
s
.99625 .4324 m
1 .4324 L
s
.99625 .45282 m
1 .45282 L
s
.99625 .47324 m
1 .47324 L
s
.99625 .49365 m
1 .49365 L
s
.99625 .53448 m
1 .53448 L
s
.99625 .5549 m
1 .5549 L
s
.99625 .57531 m
1 .57531 L
s
.99625 .59573 m
1 .59573 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.2619 .48082 L
.5 .13296 L
.7381 .07582 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000IOol5
000iOol4000kOol2000lOol3000jOol2000=Ool001]oo`03001oogoo03Uoo`03001oogoo03]oo`04
001oogoo000lOol00`00Oomoo`0hOol01000Oomoo`0037oo000KOol00`00Oomoo`0jOol00`00Oomo
o`0lOol00`00Oomoo`0hOol5000lOol00`00Oomoo`0:Ool001]oo`03001oogoo03]oo`03001oogoo
03aoo`03001oogoo03Moo`04001oogoo000kOol2000=Ool001]oo`03001oogoo03Uoo`04001oogoo
000jOol01000Oomoo`00>Woo00<007oo0000>goo00<007ooOol037oo000JOol2000lOol2000lOol2
000lOol2000kOol3000<Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`001Woo10000goo
0P00ogoo4Woo0006Ool00`00Oomoo`03Ool01000Oomoo`001Gooo`001P001Woo0007Ool00`00Oomo
o`02Ool01000Oomoo`001Goo0P0017oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol00Woo0`001Woo0008Ool01@00Oomoogoo0000
0Woo00<007ooOol00goo00<007ooOol0ogoo0Woo00<007ooOol017oo0006Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo0?moo`9oo`03001oogoo00Aoo`001goo0P0017oo0P001Woo00<0
07ooOol0nGoo0P001Woo00<007ooOol017oo000EOol00`00Oomoo`3eOol40008Ool00`00Oomoo`04
Ool001Eoo`800?9oo`@000]oo`8000Ioo`005Goo00<007ooOol0kGoo100047oo00<007ooOol017oo
000EOol00`00Oomoo`3YOol4000DOol00`00Oomoo`04Ool001Eoo`03001oogoo0>Eoo`@001Qoo`03
001oogoo00Aoo`005Goo00<007ooOol0hGoo100077oo00<007ooOol017oo000EOol2003NOol4000O
Ool20006Ool001Eoo`03001oogoo0=Yoo`<002Aoo`03001oogoo00Aoo`005Goo00<007ooOol0eWoo
10009goo00<007ooOol017oo000EOol00`00Oomoo`3BOol4000[Ool00`00Oomoo`04Ool001Eoo`03
001oogoo0<ioo`@002moo`03001oogoo00Aoo`005Goo00<007ooOol0bWoo1000<goo00<007ooOol0
17oo000EOol20037Ool4000fOol20006Ool001Eoo`03001oogoo0<9oo`@003]oo`03001oogoo00Ao
o`005Goo00<007ooOol0_Woo1000?goo00<007ooOol017oo000EOol00`00Oomoo`2jOol40013Ool0
0`00Oomoo`04Ool001Eoo`03001oogoo0;Ioo`@004Moo`03001oogoo00Aoo`005Goo0P00/goo1000
BWoo0P001Woo000EOol00`00Oomoo`2]Ool5001?Ool00`00Oomoo`04Ool001Eoo`03001oogoo0:Uo
o`@005Aoo`03001oogoo00Aoo`001Woo10000goo0P001Woo00<007ooOol0YGoo1000F7oo00<007oo
Ool017oo0006Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol0X7oo1@00G7oo00<007oo
Ool017oo0007Ool00`00Oomoo`05Ool00`00Oomoo`03Ool2002MOol4001OOol30006Ool000Qoo`03
001oogoo009oo`8000Ioo`03001oogoo09Moo`D006Eoo`03001oogoo00Aoo`001Woo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo09=oo`@006Yoo`03001oogoo00Aoo`001goo0P0017oo0`00
1Goo00<007ooOol0Sgoo1000KWoo00<007ooOol017oo000EOol00`00Oomoo`2:Ool5001bOol00`00
Oomoo`04Ool001Eoo`03001oogoo08Ioo`@007Moo`03001oogoo00Aoo`005Goo0P00Pgoo1000NWoo
0P001Woo000EOol00`00Oomoo`1oOol3001oOol00`00Oomoo`04Ool001Eoo`03001oogoo07ioo`03
001oogoo081oo`03001oogoo00Aoo`005Goo00<007ooOol0OWoo00<007ooOol0P7oo00<007ooOol0
17oo000EOol00`00Oomoo`1mOol00`00Oomoo`21Ool00`00Oomoo`04Ool001Eoo`8007eoo`03001o
ogoo085oo`8000Ioo`005Goo00<007ooOol0O7oo00<007ooOol0PWoo00<007ooOol017oo000EOol0
0`00Oomoo`1kOol00`00Oomoo`23Ool00`00Oomoo`04Ool001Eoo`03001oogoo07Yoo`03001oogoo
08Aoo`03001oogoo00Aoo`005Goo00<007ooOol0NWoo00<007ooOol0Q7oo00<007ooOol017oo000E
Ool2001jOol00`00Oomoo`24Ool20006Ool001Eoo`03001oogoo07Qoo`03001oogoo08Ioo`03001o
ogoo00Aoo`005Goo00<007ooOol0N7oo00<007ooOol0QWoo00<007ooOol017oo000EOol00`00Oomo
o`1gOol00`00Oomoo`27Ool00`00Oomoo`04Ool001Eoo`03001oogoo07Ioo`03001oogoo08Qoo`03
001oogoo00Aoo`005Goo00<007ooOol0MGoo00<007ooOol0RGoo00<007ooOol017oo000EOol2001f
Ool00`00Oomoo`28Ool20006Ool001Eoo`03001oogoo07Aoo`03001oogoo08Yoo`03001oogoo00Ao
o`005Goo00<007ooOol0Lgoo00<007ooOol0Rgoo00<007ooOol017oo0007Ool20004Ool20006Ool0
0`00Oomoo`1cOol00`00Oomoo`2;Ool00`00Oomoo`04Ool000Ioo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol0LWoo00<007ooOol0S7oo00<007ooOol017oo0008Ool01@00Oomoogoo0000
0Woo00<007ooOol00goo0P00LWoo00<007ooOol0Rgoo0`001Woo0009Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol0LGoo00<007ooOol0SGoo00<007ooOol017oo0006Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo071oo`03001oogoo08ioo`03001oogoo00Aoo`001goo0P00
17oo0P001Woo00<007ooOol0Kgoo00<007ooOol0Sgoo00<007ooOol017oo000EOol00`00Oomoo`1_
Ool00`00Oomoo`2?Ool00`00Oomoo`04Ool001Eoo`8006moo`03001oogoo08moo`8000Ioo`005Goo
00<007ooOol0KGoo00<007ooOol0TGoo00<007ooOol017oo000EOol00`00Oomoo`1]Ool00`00Oomo
o`2AOol00`00Oomoo`04Ool001Eoo`03001oogoo06aoo`03001oogoo099oo`03001oogoo00Aoo`00
5Goo00<007ooOol0Jgoo00<007ooOol0Tgoo00<007ooOol017oo000EOol2001/Ool00`00Oomoo`2B
Ool20006Ool001Eoo`03001oogoo06Yoo`03001oogoo09Aoo`03001oogoo00Aoo`005Goo00<007oo
Ool0JGoo00<007ooOol0UGoo00<007ooOol017oo000EOol00`00Oomoo`1YOol00`00Oomoo`2EOol0
0`00Oomoo`04Ool001Eoo`03001oogoo06Qoo`03001oogoo09Ioo`03001oogoo00Aoo`005Goo00<0
07ooOol0Igoo00<007ooOol0Ugoo00<007ooOol017oo000EOol2001WOol00`00Oomoo`2GOol20006
Ool001Eoo`03001oogoo06Ioo`03001oogoo09Qoo`03001oogoo00Aoo`005Goo00<007ooOol0IGoo
00<007ooOol0VGoo00<007ooOol017oo000EOol00`00Oomoo`1TOol00`00Oomoo`2JOol00`00Oomo
o`04Ool001Eoo`03001oogoo06Aoo`03001oogoo09Yoo`03001oogoo00Aoo`005Goo0P00I7oo00<0
07ooOol0VWoo0P001Woo000EOol00`00Oomoo`1ROol00`00Oomoo`2LOol00`00Oomoo`04Ool001Eo
o`03001oogoo069oo`03001oogoo09aoo`03001oogoo00Aoo`001goo0P0017oo0P001Woo00<007oo
Ool0HGoo00<007ooOol0WGoo00<007ooOol017oo0006Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo061oo`03001oogoo09ioo`03001oogoo00Aoo`0027oo00<007ooOol017oo00<007oo
Ool00goo0P00HGoo00<007ooOol0W7oo0`001Woo0009Ool01000Oomoogoo0P001Woo00<007ooOol0
Ggoo00<007ooOol0Wgoo00<007ooOol017oo0006Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0GWoo00<007ooOol0X7oo00<007ooOol017oo0007Ool20004Ool30005Ool00`00Oomoo`1N
Ool00`00Oomoo`2POol00`00Oomoo`04Ool001Eoo`03001oogoo05eoo`03001oogoo0:5oo`03001o
ogoo00Aoo`005Goo00<007ooOol0G7oo00<007ooOol0XWoo00<007ooOol017oo000EOol2001MOol0
0`00Oomoo`2QOol20006Ool001Eoo`03001oogoo05]oo`03001oogoo0:=oo`03001oogoo00Aoo`00
5Goo00<007ooOol0FWoo00<007ooOol0Y7oo00<007ooOol017oo000EOol00`00Oomoo`1JOol00`00
Oomoo`2TOol00`00Oomoo`04Ool001Eoo`03001oogoo05Uoo`03001oogoo0:Eoo`03001oogoo00Ao
o`005Goo0P00FGoo00<007ooOol0YGoo0P001Woo000EOol00`00Oomoo`1GOol00`00Oomoo`2WOol0
0`00Oomoo`04Ool001Eoo`03001oogoo05Moo`03001oogoo0:Moo`03001oogoo00Aoo`005Goo00<0
07ooOol0EWoo00<007ooOol0Z7oo00<007ooOol017oo000EOol00`00Oomoo`1EOol00`00Oomoo`2Y
Ool00`00Oomoo`04Ool001Eoo`8005Ioo`03001oogoo0:Qoo`8000Ioo`005Goo00<007ooOol0E7oo
00<007ooOol0ZWoo00<007ooOol017oo000EOol00`00Oomoo`1COol00`00Oomoo`2[Ool00`00Oomo
o`04Ool001Eoo`03001oogoo05=oo`03001oogoo0:]oo`03001oogoo00Aoo`005Goo00<007ooOol0
DWoo00<007ooOol0[7oo00<007ooOol017oo000EOol00`00Oomoo`1AOol00`00Oomoo`2]Ool00`00
Oomoo`04Ool001Eoo`80059oo`03001oogoo0:aoo`8000Ioo`005Goo00<007ooOol0D7oo00<007oo
Ool0[Woo00<007ooOol017oo000EOol00`00Oomoo`1?Ool00`00Oomoo`2_Ool00`00Oomoo`04Ool0
00Qoo`<0009oo`8000Ioo`03001oogoo04moo`03001oogoo0:moo`03001oogoo00Aoo`002Goo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo04ioo`03001oogoo0;1oo`03001oogoo00Aoo`00
1Woo1@0000Eoo`00Oomoo`0000Eoo`8004ioo`03001oogoo0:moo`<000Ioo`001Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`1=Ool00`00Oomoo`2aOol00`00Oomoo`04Ool000Moo`03
001oo`00009oo`04001oogoo0005Ool00`00Oomoo`1<Ool00`00Oomoo`2bOol00`00Oomoo`04Ool0
00Qoo`8000=oo`8000Ioo`03001oogoo04]oo`03001oogoo0;=oo`03001oogoo00Aoo`005Goo00<0
07ooOol0Bgoo00<007ooOol0/goo00<007ooOol017oo000EOol2001;Ool00`00Oomoo`2cOol20006
Ool001Eoo`03001oogoo04Uoo`03001oogoo0;Eoo`03001oogoo00Aoo`005Goo00<007ooOol0B7oo
00<007ooOol0]Woo00<007ooOol017oo000EOol00`00Oomoo`18Ool00`00Oomoo`2fOol00`00Oomo
o`04Ool001Eoo`03001oogoo04Moo`03001oogoo0;Moo`03001oogoo00Aoo`005Goo00<007ooOol0
AWoo00<007ooOol0^7oo00<007ooOol017oo000EOol20017Ool00`00Oomoo`2gOol20006Ool001Eo
o`03001oogoo04Eoo`03001oogoo0;Uoo`03001oogoo00Aoo`005Goo00<007ooOol0A7oo00<007oo
Ool0^Woo00<007ooOol017oo000EOol00`00Oomoo`14Ool00`00Oomoo`2jOol00`00Oomoo`04Ool0
01Eoo`03001oogoo04=oo`03001oogoo0;]oo`03001oogoo00Aoo`005Goo0P00@goo00<007ooOol0
^goo0P001Woo000EOol00`00Oomoo`12Ool00`00Oomoo`2lOol00`00Oomoo`04Ool001Eoo`03001o
ogoo045oo`03001oogoo0;eoo`03001oogoo00Aoo`005Goo00<007ooOol0?goo0P00`7oo00<007oo
Ool017oo000EOol00`00Oomoo`0mOol20032Ool00`00Oomoo`04Ool001Eoo`8003aoo`800<=oo`80
00Ioo`005Goo00<007ooOol0>Goo0P00aWoo00<007ooOol017oo000EOol00`00Oomoo`0gOol20038
Ool00`00Oomoo`04Ool000Qoo`<0009oo`8000Ioo`03001oogoo03Eoo`800<Yoo`03001oogoo00Ao
o`002Goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo03=oo`800<aoo`03001oogoo00Ao
o`001Woo1@0017oo00<007ooOol00goo0P00<Woo0P00c7oo0`001Woo0006Ool01000Oomoo`000goo
0P001Woo00<007ooOol0;goo0P00d7oo00<007ooOol017oo0007Ool00`00Ool00003Ool00`00Oomo
o`05Ool00`00Oomoo`0]Ool2003BOol00`00Oomoo`04Ool000Qoo`8000=oo`<000Eoo`03001oogoo
02]oo`800=Aoo`03001oogoo00Aoo`005Goo00<007ooOol0:Goo0P00eWoo00<007ooOol017oo000E
Ool00`00Oomoo`0WOol2003HOol00`00Oomoo`04Ool001Eoo`8002Ioo`800=Uoo`8000Ioo`005Goo
00<007ooOol08goo0P00g7oo00<007ooOol017oo000EOol00`00Oomoo`0ROol00`00Oomoo`3LOol0
0`00Oomoo`04Ool001Eoo`03001oogoo021oo`800=moo`03001oogoo00Aoo`005Goo00<007ooOol0
7Woo0P00hGoo00<007ooOol017oo000EOol2000MOol2003ROol20006Ool001Eoo`03001oogoo01Yo
o`800>Eoo`03001oogoo00Aoo`005Goo00<007ooOol067oo0P00igoo00<007ooOol017oo000EOol0
0`00Oomoo`0FOol2003YOol00`00Oomoo`04Ool001Eoo`03001oogoo01Aoo`800>]oo`03001oogoo
00Aoo`005Goo0P004goo0P00k7oo0P001Woo000EOol00`00Oomoo`0@Ool2003_Ool00`00Oomoo`04
Ool001Eoo`03001oogoo00ioo`800?5oo`03001oogoo00Aoo`005Goo00<007ooOol037oo0P00lgoo
00<007ooOol017oo000EOol00`00Oomoo`0:Ool2003eOol00`00Oomoo`04Ool001Eoo`03001oogoo
00Qoo`800?Moo`03001oogoo00Aoo`005Goo0P001goo0P00n7oo0P001Woo000EOol00`00Oomoo`04
Ool2003kOol00`00Oomoo`04Ool001Eoo`03001oogoo00=oo`03001oogoo0?]oo`03001oogoo00Ao
o`001goo0P0017oo0P001Woo00<007ooOol0ogoo0Woo00<007ooOol017oo0006Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo03]oo`03001oogoo03]oo`03001oogoo
03Yoo`03001oogoo03]oo`03001oogoo00Aoo`03001oogoo00Aoo`002Goo00@007ooOol0009oo`03
001oogoo00=oool000H000Ioo`001goo0P000goo00@007ooOol00?mooa5oo`001goo00<007ooOol0
0Woo00@007ooOol00?mooa5oo`001goo0`000goo0P00ogoo4Woo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.559606, 17.5116, \
0.0161549, 0.188406}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
To obtain a more informative graph we can use the Mathematica ListPlot \
options:\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
If one wants to know all the options for a certain function, one has to use \
the command \"Options\":\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[ListPlot]\)], "Input"],

Cell[BoxData[
    \({AspectRatio \[Rule] 1\/GoldenRatio, Axes \[Rule] Automatic, 
      AxesLabel \[Rule] None, AxesOrigin \[Rule] Automatic, 
      AxesStyle \[Rule] Automatic, Background \[Rule] Automatic, 
      ColorOutput \[Rule] Automatic, DefaultColor \[Rule] Automatic, 
      Epilog \[Rule] {}, Frame \[Rule] False, FrameLabel \[Rule] None, 
      FrameStyle \[Rule] Automatic, FrameTicks \[Rule] Automatic, 
      GridLines \[Rule] None, ImageSize \[Rule] Automatic, 
      PlotJoined \[Rule] False, PlotLabel \[Rule] None, 
      PlotRange \[Rule] Automatic, PlotRegion \[Rule] Automatic, 
      PlotStyle \[Rule] Automatic, Prolog \[Rule] {}, 
      RotateLabel \[Rule] True, Ticks \[Rule] Automatic, 
      DefaultFont \[RuleDelayed] $DefaultFont, 
      DisplayFunction \[RuleDelayed] $DisplayFunction, 
      FormatType \[RuleDelayed] $FormatType, 
      TextStyle \[RuleDelayed] $TextStyle}\)], "Output"]
}, Open  ]],

Cell["\<\
Some of the options are used in the following graphs, in which we first show \
the two graphs separately and then together :\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell[BoxData[
    \(Load[balbfiles[\([1]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"we", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{\(actbyslc[\([2]\)]\), ",", \(PlotRange -> All\), 
          ",", \(PlotLabel -> sessionname2\), ",", \(AxesOrigin -> {0, 0}\), 
          ",", \(Frame -> True\), ",", \(PlotJoined -> True\), 
          ",", \(RotateLabel -> True\), 
          ",", \(GridLines -> {None, Automatic}\), ",", 
          RowBox[{"FrameLabel", "->", 
            RowBox[{
              StyleBox["{",
                FontColor->GrayLevel[
                0]], \("\<Successive 5min intervals\>", "\<Activity per \
TimeSlice (meters)\>"\), 
              StyleBox["}",
                FontSlant->"Italic"]}]}], 
          ",", \(TextStyle -> {FontSize -> 14}\), 
          ",", \(Background \[Rule] GrayLevel[0.9]\), 
          ",", \(FrameStyle \[Rule] Thickness[0.008]\), 
          ",", \(FrameTicks -> {{1, 2, 3, 4, 5}, {10, 20, 30, 40, 50}, None, 
              None}\), ",", \(PlotStyle -> {Hue[0.6], Thickness[0.01]}\)}], 
        "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.9 g
MFill
% Scaling calculations
-0.214286 0.238095 -0.0717559 0.0167086 [
[.02381 -0.0125 -6.1875 -16.9375 ]
[.02381 -0.0125 6.1875 0 ]
[.2619 -0.0125 -6.1875 -16.9375 ]
[.2619 -0.0125 6.1875 0 ]
[.5 -0.0125 -6.1875 -16.9375 ]
[.5 -0.0125 6.1875 0 ]
[.7381 -0.0125 -6.1875 -16.9375 ]
[.7381 -0.0125 6.1875 0 ]
[.97619 -0.0125 -6.1875 -16.9375 ]
[.97619 -0.0125 6.1875 0 ]
[.5 -0.0125 -106.688 -33.875 ]
[.5 -0.0125 106.688 -16.9375 ]
[-0.0125 .09533 -20.75 -8.46875 ]
[-0.0125 .09533 0 8.46875 ]
[-0.0125 .26242 -20.75 -8.46875 ]
[-0.0125 .26242 0 8.46875 ]
[-0.0125 .4295 -20.75 -8.46875 ]
[-0.0125 .4295 0 8.46875 ]
[-0.0125 .59659 -20.75 -8.46875 ]
[-0.0125 .59659 0 8.46875 ]
[-0.01875 .30902 -37.6875 -131.813 ]
[-0.01875 .30902 -20.75 131.813 ]
[.5 .63053 -52.25 0 ]
[.5 .63053 52.25 16.9375 ]
[ -0.004 -0.004 0 0 ]
[ 1.004 .62203 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .09533 m
1 .09533 L
s
0 .17887 m
1 .17887 L
s
0 .26242 m
1 .26242 L
s
0 .34596 m
1 .34596 L
s
0 .4295 m
1 .4295 L
s
0 .51305 m
1 .51305 L
s
0 .59659 m
1 .59659 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.008 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -167.688 -37.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Successive) show
155.125 16.188 moveto
(5) show
163.500 16.188 moveto
(min) show
197.000 16.188 moveto
(intervals) show
272.375 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .09533 m
.00625 .09533 L
s
gsave
-0.0125 .09533 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .26242 m
.00625 .26242 L
s
gsave
-0.0125 .26242 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .4295 m
.00625 .4295 L
s
gsave
-0.0125 .4295 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .59659 m
.00625 .59659 L
s
gsave
-0.0125 .59659 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.008 w
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -222.031 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
192.813 12.4688 translate
90 rotate
-192.813 -12.4688 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Activity) show
138.375 16.188 moveto
(per) show
171.875 16.188 moveto
(TimeSlice) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
255.625 16.188 moveto
(H) show
264.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
314.250 16.188 moveto
(L) show
322.625 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.01 w
.02381 .01472 m
.2619 .0259 L
.5 .30628 L
.7381 .26294 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450.375, 278.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007200015Q000`40O003h00Oogoo`goo003oLic2
Li`1Ool00?mcW<9cW05oo`00og>L`W>L0Goo003oLic2Li`1Ool00?mcW<9cW05oo`00SW>L00<007>L
00000P001G>L0P0000=cW00000000W>L100017>L100017>L1@000W>L1@000g>L1@000g>L1`000g>L
0P001G>L1@003g>L10000W>L0`0000IcW000001cW000Li`700001G>L00000000Li`00`002g>L1`00
00EcW000000007>L00<000=cW0<000AcW0D0009cW0D000EcW08000EcW0<00004Li`00000Li`70000
0g>L00000003001XLi`1Ool008icW08000=cW005001cW7>LLi`00002Li`20002Li`00`00LiacW002
Li`01000LiacW00017>L00@007>LLi`000McW003001cW7>L009cW004001cW7>L0004Li`00`00Liac
W003Li`00`00LiacW004Li`20004Li`00`00LiacW00ALi`00`00LiacW002Li`01000LiacW0000W>L
00@007>LLi`000AcW003001cW7>L00=cW005001cW7>LLi`0000?Li`00`00LiacW003Li`01@00Liac
W7>L00000g>L00D007>LLiacW000009cW003001cW7>L00IcW003001cW7>L00IcW08000AcW004001c
W7>LLi`20005Li`00`00LiacW002Li`00`00LiacW002Li`00`00LiacW01ULi`1Ool009=cW005001c
W7>LLi`00003Li`01000LiacW0001g>L00<007>LLi`01G>L00<007>LLi`02W>L00<007>LLi`01G>L
00<007>LLi`00g>L00<007>LLi`00g>L00@007>LLi`000=cW003001cW7>L01IcW004001cW7>L0002
Li`01000LiacW00017>L00<007>LLi`00g>L00D007>LLiacW00000mcW003001cW7>L00=cW005001c
W7>LLi`00003Li`00`00LiacW004Li`00`00LiacW006Li`00`00LiacW005Li`01000LiacW0000g>L
00<007>LLi`00W>L00<007>LLi`00g>L00<007>LLi`01g>L00<007>LLi`0IG>L0Goo002CLi`01@00
LiacW7>L00000g>L00@007>LLi`000McW003001cW7>L00EcW0H000=cW0@000AcW0@000IcW003001c
W7>L00=cW004001cW7>L0003Li`6000CLi`01000LiacW0000W>L00@007>LLi`000AcW003001cW7>L
00=cW005001cW7>LLi`0000?Li`00`00LiacW003Li`01@00LiacW7>L00000g>L00<007>LLi`017>L
1P000g>L00<007>LLi`01G>L00@007>LLi`000AcW0D000EcW003001cW7>L00=cW0@006QcW05oo`00
Sg>L100017>L00D007>LLiacW000009cW004001cW7>LLi`20002Li`01000LiacW7>L0P000W>L00<0
07>LLi`00W>L00@007>LLi`000AcW004001cW7>L0004Li`00`00LiacW003Li`00`00LiacW002Li`0
0`00LiacW002Li`01000LiacW00017>L00<007>LLi`04G>L00<007>LLi`00P0000EcW000001cW000
00AcW003001cW7>L00=cW080009cW003001cW7>L00ecW003001cW7>L00=cW080009cW005001cW7>L
Li`00006Li`00`00LiacW002Li`01000LiacW7>L0P001G>L00<007>LLi`00W>L00@007>LLi`000Ac
W003001cW7>L00=cW003001cW7>L009cW003001cW7>L009cW003001cW7>L06EcW05oo`00SW>L00<0
07>LLi`01G>L0P000W>L0P000g>L0`0000=cW000Li`00W>L0`0000=cW000Li`00W>L100017>L1@00
0g>L1@000g>L0`000g>L0`000W>L0`000W>L100047>L10000W>L0P0000EcW000LiacW00000=cW0<0
00AcW0800003Li`0000000icW0<000AcW0800003Li`0000000=cW0H000=cW0@000=cW0800005Li`0
0000001cW0030002Li`30002Li`40006Li`00`00LiacW003Li`5001WLi`1Ool008icW004001cW7>L
Li`2001GLi`00`00LiacW00gLi`00`00LiacW00WLi`00`00LiacW01_Li`1Ool008mcW0<00003Li`0
07>L03AcW003001cW7>L01mcW003001cW7>L00mcW003001cW7>L01McW003001cW7>L00]cW003001c
W7>L02McW003001cW7>L06mcW05oo`00jg>L1@00GW>L0P00LG>L0Goo003oLic2Li`1Ool00?mcW<9c
W05oo`009g>L00<007>LLi`0og>LV7>L0Goo000VLi`2003oLibJLi`1Ool0021cW003001cW7>L00<0
0003Li`007>L0?mcW9UcW05oo`0087>L0`000W>L00<007>LLi`0og>LVW>L0Goo000PLi`30002Li`0
0`00LiacW03oLibJLi`1Ool002=cW0<00003Li`007>L0?mcW9UcW05oo`009W>L0P009W>L1@00CG>L
1@00CW>L0`00DW>L0`00CW>L100097>L0Goo000WLi`00`00LiacW00VLi`00`00LiacW01=Li`01@00
LiacW7>L0000CG>L00D007>LLiacW000059cW003001cW7>L04acW003001cW7>L009cW003001cW7>L
025cW05oo`00D7>L00<007>LLi`0CW>L00<007>LLi`0DW>L00<007>LLi`0D7>L00<007>LLi`0DG>L
00<007>LLi`08G>L0Goo000SLi`4000YLi`00`00LiacW01?Li`00`00LiacW01ALi`00`00LiacW01<
Li`6001BLi`00`00LiacW00QLi`1Ool0029cW003001cW7>L009cW003001cW7>L02IcW003001cW7>L
051cW003001cW7>L04icW080051cW004001cW7>L001CLi`00`00LiacW00QLi`1Ool0029cW003001c
W7>L009cW003001cW7>L02IcW003001cW7>L051cW003001cW7>L051cW003001cW7>L04ecW004001c
W7>L001?Li`4000TLi`1Ool0029cW003001cW7>L009cW003001cW7>L02IcW003001cW7>L055cW003
001cW7>L04mcW003001cW7>L04icW003001cW00004mcW003001cW7>L02EcW05oo`008W>L00<007>L
Li`00W>L00<007>LLi`097>L0`00Cg>L00D007>LLiacW00004ecW005001cW7>LLi`0001@Li`00`00
Li`0001?Li`00`00LiacW00ULi`1Ool0029cW080009cW003001cW7>L02McW003001cW7>L04icW0<0
04mcW0<0059cW08004mcW0D002=cW05oo`00og>L`W>L0Goo003oLic2Li`1Ool0029cW003001cW7>L
0?mcW9ecW05oo`0087>L1`00og>LVg>L0Goo000RLi`00`00LiacW002Li`00`00LiacW03oLibHLi`1
Ool0029cW003001cW7>L009cW003001cW7>L0?mcW9QcW05oo`008W>L00<007>LLi`00W>L00<007>L
Li`07G>Lo`00GP007G>L0Goo000RLi`01@00LiacW7>L000087>Lo`00GP007G>L0Goo0017Li`20007
Li`00`00LiacW01@Li`00`00LiacW01@Li`00`00LiacW01?Li`00`00LiacW01@Li`00`00LiacW004
Li`2000MLi`1Ool004McW08000McW003001cW7>L051cW003001cW7>L051cW003001cW7>L04mcW003
001cW7>L051cW003001cW7>L00AcW08001ecW05oo`009g>L00<007>LLi`07G>L0P001W>L306Oog>L
B7>L0P007G>L0Goo000RLi`00`00LiacW002Li`00`00LiacW00MLi`20006Li`P0IooLi`dLi`2000M
Li`1Ool0029cW003001cW7>L009cW003001cW7>L01ecW08000IcW3D1WomcW1mcW08001ecW05oo`00
87>L00<007>L00001@007g>L0P004W>L?P6Oog>L2W>L0P007G>L0Goo000WLi`00`00LiacW00MLi`2
000VLi`e0IonLi`2000MLi`1Ool002McW003001cW7>L01ecW08003]cW241WoecW08001ecW05oo`00
9g>L00<007>LLi`07G>L0P00D7>L3@6Oo7>L0P007G>L0Goo000RLi`00`00LiacW00RLi`2001JLi`4
0IokLi`2000MLi`1Ool0029cW08002=cW08005]cW0@1WoYcW08001ecW05oo`008W>L00@007>L0000
025cW08005acW0@1WoUcW08001ecW05oo`009W>L0P007g>L0P00GG>L106On7>L0P007G>L0Goo000V
Li`2000OLi`2001NLi`30IohLi`2000MLi`1Ool0029cW004001cW000000QLi`2001OLi`30IogLi`2
000MLi`1Ool0029cW08002=cW08005mcW0@1WoIcW08001ecW05oo`008W>L00<007>LLi`08W>L0P00
H7>L106OmG>L0P007G>L0Goo0017Li`2001QLi`40IodLi`2000MLi`1Ool002McW003001cW7>L01ec
W080069cW0@1Wo=cW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`07G>L0P00Hg>L106O
lW>L0P007G>L0Goo000RLi`00`00LiacW002Li`00`00LiacW00MLi`2001TLi`30IobLi`2000MLi`1
Ool0021cW003001cW00000D001mcW08006EcW0<1Wo5cW08001ecW05oo`009g>L00<007>LLi`07G>L
0P00IG>L106Ol7>L0P007G>L0Goo000WLi`00`00LiacW00MLi`2001VLi`40Io_Li`2000MLi`1Ool0
02McW003001cW7>L01ecW08006McW0@1WnicW08001ecW05oo`00Ag>L0P00J7>L106OkG>L0P007G>L
0Goo000RLi`00`00LiacW00RLi`2001YLi`30Io]Li`2000MLi`1Ool0021cW0L0021cW08006YcW0<1
WnacW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`07G>L0P00JW>L106Ojg>L0P007G>L
0Goo000RLi`00`00LiacW002Li`00`00LiacW009Li`50003Li`40008Li`2001[Li`40IoZLi`2000M
Li`1Ool0029cW003001cW7>L009cW003001cW7>L00]cW003001cW7>L009cW003001cW7>L009cW003
001cW7>L00EcW08006acW0@1WnUcW08001ecW05oo`008W>L00D007>LLiacW00000icW003001cW7>L
009cW003001cW7>L009cW003001cW7>L00EcW0@006/03`@1WnP03`8001ecW05oo`00=G>L00<007>L
Li`00W>L00<007>LLi`00W>L00<007>LLi`01G>L0P00KW>L106Oig>L0P007G>L0Goo000eLi`00`00
LiacW002Li`00`00LiacW002Li`00`00LiacW005Li`2001_Li`30IoWLi`2000MLi`1Ool0029cW003
001cW7>L011cW003001cW7>L009cW003001cW7>L009cW003001cW7>L00EcW080071cW0<1WnIcW080
01ecW05oo`008W>L0`001G>L00<007>LLi`027>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>L
Li`01G>L0P00L7>L106OiG>L0P007G>L0Goo000RLi`00`00LiacW0020002Li`20008Li`30004Li`0
0`00LiacW002Li`00`00LiacW005Li`2001aLi`40IoTLi`2000MLi`1Ool002McW0800003Li`007>L
00UcW003001cW7>L00=cW0@000QcW080079cW0@1Wn=cW08001ecW05oo`008W>L00<007>LLi`00P00
87>L0P00Lg>L106OhW>L0P007G>L0Goo000RLi`3000RLi`2001dLi`30IoRLi`2000MLi`1Ool0029c
W003001cW7>L029cW08007EcW0<1Wn5cW08001ecW05oo`00Ag>L0P00MG>L106Oh7>L0P007G>L0Goo
0017Li`2001fLi`40IoOLi`2000MLi`1Ool004McW08007McW0@1WmicW08001ecW05oo`00Ag>L0P00
N7>L106OgG>L0P007G>L0Goo0017Li`2001iLi`40IoLLi`2000MLi`1Ool004McW08007YcW0<1Wmac
W08001ecW05oo`00Ag>L0P00Ng>L0`6Ofg>L0P007G>L0Goo0017Li`2001kLi`40IoJLi`2000MLi`1
Ool004McW08007acW0@1WmUcW08001ecW05oo`00Ag>L0P00OG>L106Of7>L0P007G>L0Goo0017Li`2
001nLi`40IoGLi`2000MLi`1Ool004McW08007mcW0<1WmMcW08001ecW05oo`008W>L00<007>LLi`0
1G>L00<007>LLi`06W>L0P00P7>L0`6OeW>L0P007G>L0Goo000RLi`9000LLi`20020Li`40IoELi`2
000MLi`1Ool0029cW005001cW7>LLi`00003Li`00`00LiacW00JLi`20021Li`40IoDLi`2000MLi`1
Ool0029cW003001cW7>L009cW003001cW7>L01ecW080089cW0@1Wm=cW08001ecW05oo`008W>L00<0
07>LLi`00W>L00<007>LLi`07G>L0P00Pg>L106OdW>L0P007G>L0Goo000SLi`4000PLi`20024Li`4
0IoALi`2000MLi`1Ool004McW08008EcW0<1Wm5cW08001ecW05oo`00Ag>L0P00QP0?0`6Od00?0P00
7G>L0Goo000SLi`4000PLi`20026Li`40Io?Li`2000MLi`1Ool0029cW003001cW000009cW003001c
W7>L01ecW08008McW0@1WlicW08001ecW05oo`008W>L00<007>L00000W>L00<007>LLi`07G>L0P00
R7>L106OcG>L0P007G>L0Goo000RLi`00`00Li`00002Li`00`00LiacW00MLi`20029Li`40Io<Li`2
000MLi`1Ool0029cW003001cW000009cW003001cW7>L01ecW08008YcW0<1WlacW08001ecW05oo`00
8g>L0P000W>L00<007>LLi`07G>L0P00Rg>L0`6Obg>L0P007G>L0Goo0017Li`2002;Li`40Io:Li`2
000MLi`1Ool004McW08008acW0@1WlUcW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`0
7G>L0P00SG>L106Ob7>L0P007G>L0Goo000RLi`6000OLi`2002>Li`40Io7Li`2000MLi`1Ool002=c
W005001cW7>LLi`0000OLi`2002?Li`40Io6Li`2000MLi`1Ool0029cW003001cW7>L009cW003001c
W7>L01ecW080091cW0<1WlIcW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`07G>L0P00
TG>L0`6OaG>L0P007G>L0Goo000RLi`00`00LiacW00RLi`2002ALi`40Io4Li`2000MLi`1Ool004Mc
W080099cW0@1Wl=cW08001ecW05oo`00Ag>L0P00Tg>L106O`W>L0P007G>L0Goo0017Li`2002DLi`4
0Io1Li`2000MLi`1Ool004McW08009EcW0<1Wl5cW08001ecW05oo`00Ag>L0P00UW>L0`6O`7>L0P00
7G>L0Goo0017Li`2002FLi`40InoLi`2000MLi`1Ool004McW08009McW0@1WkicW08001ecW05oo`00
Ag>L0P00V7>L106O_G>L0P007G>L0Goo0017Li`2002ILi`40InlLi`2000MLi`1Ool004McW08009Yc
W0@1Wk]cW08001ecW05oo`00Ag>L0P00Vg>L0`6O^g>L0P007G>L0Goo0017Li`2002LLi`30InjLi`2
000MLi`1Ool0021cW0<000mcW0D000AcW0@000QcW08009acW0@1WkUcW08001ecW05oo`0087>L00<0
07>LLi`017>L00<007>LLi`027>L00D007>LLiacW00000=cW003001cW7>L009cW003001cW7>L00Ec
W08009ecW0@1WkQcW08001ecW05oo`0087>L00<007>LLi`017>L00<007>LLi`02G>L00<007>LLi`0
17>L00<007>LLi`00W>L00<007>LLi`01G>L1000W00?106OF`0?106OF00?0P007G>L0Goo000PLi`8
000<Li`00`00LiacW003Li`00`00LiacW002Li`00`00LiacW005Li`2002OLi`40ImDLi`:0ImHLi`2
000MLi`1Ool0021cW003001cW7>L00AcW003001cW7>L00]cW003001cW7>L009cW003001cW7>L009c
W003001cW7>L00EcW0800:1cW0<1WdmcW101WeMcW08001ecW05oo`0087>L00<007>LLi`017>L00<0
07>LLi`02g>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>LLi`01G>L0P00XG>L0`6OB7>L4@6O
0W>L106OEW>L0P007G>L0Goo000PLi`3000CLi`01@00LiacW7>L000017>L00<007>LLi`01G>L0P00
XG>L106O@W>L406O2G>L0`6OEW>L0P007G>L0Goo000bLi`01@00LiacW7>L00000g>L00<007>LLi`0
0W>L00<007>LLi`01G>L0P00XW>L106O>g>L4@6O3W>L106OEG>L0P007G>L0Goo000WLi`00`00Liac
W009Li`30005Li`40008Li`2002SLi`40IleLi`@0IlELi`40ImDLi`2000MLi`1Ool0029cW003001c
W7>L009cW003001cW7>L01ecW0800:AcW0@1WbicW141Wa]cW0@1We=cW08001ecW05oo`008W>L00<0
07>LLi`00W>L00<007>LLi`07G>L0P00YG>L106O:7>L406O8W>L0`6ODg>L0P007G>L0Goo000PLi`0
0`00Li`00005000OLi`2002VLi`30IlSLi`@0IlWLi`40ImBLi`2000MLi`1Ool002McW003001cW7>L
01ecW0800:McW0<1WaacW101WbicW0@1We5cW08001ecW05oo`009g>L00<007>LLi`07G>L0P00Yg>L
106O5W>L406O=7>L0`6ODG>L0P007G>L0Goo000WLi`00`00LiacW00MLi`2002XLi`40Il?Li`A0Ili
Li`40Im@Li`2000MLi`1Ool0029cW003001cW7>L009cW003001cW7>L01ecW0800:UcW0@1W`UcW101
Wd1cW0@1WdmcW08001ecW05oo`008W>L1P007g>L0P00ZW>L106O0W>L4@6OAW>L0`6OCg>L0P007G>L
0Goo000RLi`00`00LiacW002Li`00`00LiacW00MLi`2002[Li`@0Im<Li`40Im>Li`2000MLi`1Ool0
029cW003001cW7>L029cW0800:acW0X1We9cW0@1WdecW08001ecW05oo`008g>L1@007g>L0P00[7>L
106OFG>L106OC7>L0P007G>L0Goo000SLi`01@00LiacW7>L00007g>L0P00og>L2g>L0`6OC7>L0P00
7G>L0Goo000RLi`00`00LiacW00RLi`2003oLi`;Li`40Im;Li`2000MLi`1Ool002=cW0D001mcW080
0?mcW0acW0@1WdYcW08001ecW05oo`00Ag>L0P00og>L3G>L0`6OBW>L0P007G>L0Goo000SLi`4000P
Li`2003oLi`=Li`40Im9Li`2000MLi`1Ool0029cW003001cW000009cW003001cW7>L01ecW0800?mc
W0icW0@1WdQcW08001ecW05oo`008W>L00<007>L00000W>L00<007>LLi`07G>L0P00og>L3g>L106O
Ag>L0P007G>L0Goo000RLi`00`00Li`00002Li`00`00LiacW00MLi`2003oLi`@Li`30Im7Li`2000M
Li`1Ool0029cW003001cW000009cW003001cW7>L01ecW0800?mcW11cW0@1WdIcW08001ecW05oo`00
8g>L0P000W>L00<007>LLi`07G>L0P00og>L4G>L106OAG>L0P007G>L0Goo0017Li`2003oLi`BLi`3
0Im5Li`2000MLi`1Ool004McW0800?mcW19cW0@1WdAcW08001ecW05oo`008G>L0P000g>L0P007g>L
0P00o`0?4`0?106O@`0?0P007G>L0Goo000PLi`01000LiacW0000W>L00<007>LLi`07W>L0P00og>L
57>L0`6O@g>L0P007G>L0Goo000PLi`01000LiacW0000g>L00<007>LLi`07G>L0P00og>L57>L106O
@W>L0P007G>L0Goo000PLi`01000LiacW0000g>L00<007>LLi`07G>L0P00og>L5G>L106O@G>L0P00
7G>L0Goo000PLi`01000LiacW0000g>L00<007>LLi`07G>L0P00og>L5W>L106O@7>L0P007G>L0Goo
000PLi`20002Li`3000PLi`2003oLi`GLi`30Im0Li`2000MLi`1Ool004McW0800?mcW1McW0@1Wcmc
W08001ecW05oo`00Ag>L0P00og>L67>L106O?W>L0P007G>L0Goo000WLi`00`00LiacW00MLi`2003o
Li`ILi`30IlnLi`2000MLi`1Ool002McW003001cW7>L01ecW0800?mcW1UcW0@1WcecW08001ecW05o
o`007g>L00<007>LLi`01G>L00<007>LLi`07G>L0P00og>L6W>L106O?7>L0P007G>L0Goo000OLi`9
000OLi`2003oLi`KLi`30IllLi`2000MLi`1Ool002McW003001cW7>L01ecW0800?mcW1]cW0@1Wc]c
W08001ecW05oo`009g>L00<007>LLi`07G>L0P00og>L77>L106O>W>L0P007G>L0Goo000WLi`00`00
LiacW00MLi`2003oLi`MLi`40IliLi`2000MLi`1Ool004McW0800?mcW1icW0<1WcUcW08001ecW05o
o`009g>L00<007>LLi`07G>L0P00og>L7W>L106O>7>L0P007G>L0Goo000RLi`00`00LiacW002Li`0
0`00LiacW00MLi`2003oLi`OLi`40IlgLi`2000MLi`1Ool0029cW003001cW7>L009cW003001cW7>L
01ecW0800?mcW21cW0<1WcMcW08001ecW05oo`0087>L00<007>L00001@007g>L0P00og>L87>L106O
=W>L0P007G>L0Goo000WLi`00`00LiacW00MLi`2003oLi`QLi`40IleLi`2000MLi`1Ool002McW003
001cW7>L01ecW0800?mcW29cW0@1WcAcW08001ecW05oo`009g>L00<007>LLi`07G>L0P00og>L8g>L
0`6O=7>L0P007G>L0Goo0017Li`2003oLi`SLi`40IlcLi`2000MLi`1Ool002=cW0@0021cW0800?mc
W2AcW0@1Wc9cW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`07G>L0P00og>L9G>L0`6O
<W>L0P007G>L0Goo000RLi`00`00LiacW002Li`00`00LiacW009Li`30005Li`40008Li`2003oLi`U
Li`40IlaLi`2000MLi`1Ool0029cW003001cW7>L009cW003001cW7>L00QcW005001cW7>LLi`00003
Li`00`00LiacW002Li`00`00LiacW005Li`2003oLi`VLi`40Il`Li`2000MLi`1Ool0029cW003001c
W7>L009cW003001cW7>L00acW005001cW7>LLi`00004Li`00`00LiacW005Li`2003oLi`WLi`30Il`
Li`2000MLi`1Ool0029cW080009cW003001cW7>L00ecW005001cW7>LLi`00004Li`00`00LiacW005
Li`4003o00lU00l40Il_00l2000MLi`1Ool003AcW08000AcW003001cW7>L009cW003001cW7>L00Ec
W0800?mcW2QcW0@1WbicW08001ecW05oo`00=W>L00D007>LLiacW00000AcW003001cW7>L00EcW080
0?mcW2UcW0@1WbecW08001ecW05oo`008g>L10003g>L00D007>LLiacW00000AcW003001cW7>L00Ec
W0800?mcW2YcW0<1WbecW08001ecW05oo`008W>L00<007>L00000W>L00<007>LLi`027>L00D007>L
LiacW00000=cW003001cW7>L009cW003001cW7>L00EcW0800?mcW2YcW0@1WbacW08001ecW05oo`00
8W>L00<007>L00000W>L00<007>LLi`02G>L0`001G>L100027>L0P00og>L:g>L106O:g>L0P007G>L
0Goo000RLi`00`00Li`00002Li`00`00LiacW00MLi`2003oLi`/Li`30Il[Li`2000MLi`1Ool0029c
W003001cW000009cW003001cW7>L01ecW0800?mcW2acW0@1WbYcW08001ecW05oo`008g>L0P000W>L
00<007>LLi`07G>L0P00og>L;G>L106O:G>L0P007G>L0Goo0017Li`2003oLi`^Li`30IlYLi`2000M
Li`1Ool004McW0800?mcW2icW0@1WbQcW08001ecW05oo`00Ag>L0P00og>L;g>L106O9g>L0P007G>L
0Goo0017Li`2003oLi``Li`40IlVLi`2000MLi`1Ool004McW0800?mcW35cW0<1WbIcW08001ecW05o
o`00Ag>L0P00og>L<G>L106O9G>L0P007G>L0Goo0017Li`2003oLi`bLi`40IlTLi`2000MLi`1Ool0
04McW0800?mcW3=cW0<1WbAcW08001ecW05oo`00Ag>L0P00og>L<g>L106O8g>L0P007G>L0Goo0017
Li`2003oLi`dLi`40IlRLi`2000MLi`1Ool004McW0800?mcW3EcW0@1Wb5cW08001ecW05oo`00Ag>L
0P00og>L=W>L0`6O8G>L0P007G>L0Goo0017Li`2003oLi`fLi`40IlPLi`2000MLi`1Ool004McW080
0?mcW3McW0@1WamcW08001ecW05oo`00Ag>L0P00og>L>7>L0`6O7g>L0P007G>L0Goo0017Li`2003o
Li`hLi`40IlNLi`2000MLi`1Ool004McW0800?mcW3UcW0@1WaecW08001ecW05oo`008W>L1P007g>L
0P00og>L>W>L0`6O7G>L0P007G>L0Goo000PLi`20006Li`2000MLi`2003oLi`jLi`40IlLLi`2000M
Li`1Ool001mcW003001cW7>L00QcW003001cW7>L01YcW0800?mcW3]cW0@1Wa]cW08001ecW05oo`00
Ag>L0P00o`0??00?106O6P0?0P007G>L0Goo000RLi`00`00LiacW002Li`00`00LiacW00MLi`2003o
Li`mLi`30IlJLi`2000MLi`1Ool0029cW0H001mcW0800?mcW3ecW0@1WaUcW08001ecW05oo`008W>L
00<007>LLi`00W>L00<007>LLi`07G>L0P00og>L?W>L106O67>L0P007G>L0Goo000RLi`00`00Liac
W00RLi`2003oLi`oLi`30IlHLi`2000MLi`1Ool002=cW0D001mcW0800?mcW3mcW0@1WaMcW08001ec
W05oo`008g>L00D007>LLiacW00001mcW0800?mcW41cW0@1WaIcW08001ecW05oo`008W>L00<007>L
Li`08W>L0P00og>L@G>L0`6O5W>L0P007G>L0Goo000SLi`5000OLi`2003oLia1Li`40IlELi`2000M
Li`1Ool004McW0800?mcW49cW0@1WaAcW08001ecW05oo`008g>L100087>L0P00og>L@g>L106O4g>L
0P007G>L0Goo000RLi`00`00Li`00002Li`00`00LiacW00MLi`2003oLia4Li`30IlCLi`2000MLi`1
Ool0029cW003001cW000009cW003001cW7>L01ecW0800?mcW4AcW0@1Wa9cW08001ecW05oo`008W>L
00<007>L00000W>L00<007>LLi`07G>L0P00og>LAG>L106O4G>L0P007G>L0Goo000RLi`00`00Li`0
0002Li`00`00LiacW00MLi`2003oLia6Li`30IlALi`2000MLi`1Ool002=cW080009cW003001cW7>L
01ecW0800?mcW4IcW0@1Wa1cW08001ecW05oo`00Ag>L0P00og>LAg>L106O3g>L0P007G>L0Goo0017
Li`2003oLia8Li`40Il>Li`2000MLi`1Ool0029cW003001cW7>L029cW0800?mcW4UcW0<1W`icW080
01ecW05oo`0087>L1`0087>L0P00og>LBG>L106O3G>L0P007G>L0Goo000RLi`00`00LiacW002Li`0
0`00LiacW00MLi`2003oLia:Li`40Il<Li`2000MLi`1Ool0029cW003001cW7>L009cW003001cW7>L
01ecW0800?mcW4]cW0<1W`acW08001ecW05oo`008W>L00<007>LLi`00W>L00<007>LLi`07G>L0P00
og>LBg>L106O2g>L0P007G>L0Goo000RLi`01@00LiacW7>L000087>L0P00og>LC7>L106O2W>L0P00
7G>L0Goo0017Li`2003oLia=Li`30Il:Li`2000MLi`1Ool004McW0800?mcW4ecW0@1W`UcW08001ec
W05oo`008g>L10003W>L0`000g>L100027>L0P00og>LCW>L106O27>L0P007G>L0Goo000RLi`00`00
Li`00002Li`00`00LiacW00<Li`01@00LiacW7>L000017>L00<007>LLi`01G>L0P00og>LCg>L106O
1g>L0P007G>L0Goo000RLi`00`00Li`00002Li`00`00LiacW00<Li`01@00LiacW7>L000017>L00<0
07>LLi`01G>L0P00og>LD7>L0`6O1g>L0P007G>L0Goo000RLi`00`00Li`00002Li`00`00LiacW008
Li`60002Li`00`00LiacW002Li`00`00LiacW005Li`4003o00m>00l40Il600l2000MLi`1Ool0029c
W003001cW000009cW003001cW7>L00UcW004001cW7>L0003Li`00`00LiacW002Li`00`00LiacW005
Li`2003oLiaALi`40Il5Li`2000MLi`1Ool002=cW080009cW003001cW7>L00UcW004001cW7>L0003
Li`00`00LiacW002Li`00`00LiacW005Li`2003oLiaBLi`30Il5Li`2000MLi`1Ool003AcW003001c
W00000=cW003001cW7>L009cW003001cW7>L00EcW0800?mcW59cW0<1W`EcW08001ecW05oo`00=7>L
00<007>L00000g>L00<007>LLi`00W>L00<007>LLi`01G>L0P00og>LFW>L0P007G>L0Goo000RLi`0
0`00LiacW002Li`00`00LiacW00;Li`20004Li`40008Li`2003oLiaJLi`2000MLi`1Ool0029cW0H0
01mcW0800?mcW5YcW08001ecW05oo`008g>L00D007>LLiacW00001mcW?l005h001ecW05oo`008W>L
00<007>LLi`00W>L00<007>LLi`07G>Lo`00GP007G>L0Goo000RLi`00`00LiacW002Li`00`00Liac
W03oLibHLi`1Ool0029cW003001cW7>L0?mcW9ecW05oo`00og>L`W>L0Goo003oLic2Li`1Ool002=c
W003001cW7>L00800>mcW0P00:9cW05oo`008W>L00D007>L001cW0000?mcW9]cW05oo`008W>L00<0
07>L00000W>L00<007>LLi`0og>LV7>L0Goo000RLi`00`00Li`00002Li`00`00LiacW03MLi`01000
LiacW000]W>L0Goo000RLi`00`00Li`00002Li`00`00LiacW02JLi`50004Li`3000017>L000007>L
2@0000AcW0000000009cW0<000=cW080009cW0<00004Li`00000Li`70002Li`50005Li`01000Liac
W0001g>L0`0037>L1@00Vg>L0Goo000RLi`200000g>L0000002NLi`01@00LiacW7>L00000W>L00@0
07>LLiacW08000EcW003001cW7>L009cW08000=cW004001cW7>L0005Li`00`00Li`00003Li`20005
Li`00`00LiacW002Li`00`00LiacW009Li`01000LiacW0001g>L00<007>LLi`03G>L00<007>LLi`0
Vg>L0Goo0035Li`01@00LiacW7>L00000W>L00<007>LLi`00W>L00<007>LLi`00g>L00<007>LLi`0
0W>L00<007>LLi`00W>L00@007>LLi`0009cW006001cW7>L001cW00017>L00<007>LLi`00g>L00<0
07>LLi`00W>L00<007>LLi`027>L1P001W>L00<007>LLi`03G>L00<007>LLi`0Vg>L0Goo0035Li`0
1@00LiacW7>L00000g>L1@001G>L00<007>LLi`00W>L00<007>LLi`00W>L00X007>LLi`007>L001c
W000Li`0009cW0D000EcW003001cW7>L009cW0H000IcW004001cW7>L0003Li`6000>Li`00`00Liac
W02KLi`1Ool00<EcW0@000=cW003001cW7>L009cW003001cW7>L00=cW003001cW7>L009cW08000=c
W00<001cW7>L001cW000Li`007>L001cW00017>L00<007>LLi`00g>L00<007>LLi`00W>L00<007>L
Li`00W>L00<007>LLi`017>L00@007>LLi`000AcW004001cW7>L000?Li`00`00LiacW02KLi`1Ool0
0<EcW005001cW7>LLi`00003Li`40006Li`00`00LiacW002Li`00`00Li`000020003Li`01`00Li`0
07>L001cW000009cW0@000IcW003001cW7>L00=cW0@000IcW0H000=cW004001cW7>L000?Li`00`00
LiacW02KLi`1Ool001mcW003001cW7>L00QcW003001cW7>L09QcW005001cW7>LLi`0000=Li`00`00
LiacW002Li`00`00LiacW005Li`20003Li`2000<Li`00`00LiacW00>Li`01000LiacW0001G>L00<0
07>L00003g>L00<007>LLi`0Vg>L0Goo000PLi`20006Li`2002JLi`5000>Li`00`00LiacW002Li`0
0`00LiacW004Li`30003Li`2000<Li`00`00LiacW00?Li`01000LiacW00017>L00<007>L00003G>L
0`00WG>L0Goo000RLi`6002^Li`20003Li`2000ILi`2000ALi`01000LiacW0001G>L0P003g>L00<0
07>LLi`0Vg>L0Goo003oLic2Li`1Ool00?mcW<9cW05oo`00og>L`W>L0Goo003oLic2Li`1Ool00?mc
W<9cW05oo`00og>L`W>L0Goo0000\
\>"],
  ImageRangeCache->{{{0, 449.375}, {277.375, 0}} -> {0.0245117, -2.29012, \
0.0120909, 0.172294}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(UnLoad[balbfiles[\([\)\(1\)\(]\)]]\)], "Input"],

Cell[BoxData[
    \(Load[c57files[\([1]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"we1", "=", 
        RowBox[{"ListPlot", "[", 
          RowBox[{
            StyleBox[\(actbyslc[\([1]\)]\),
              FontColor->RGBColor[1, 0, 0]], ",", \(PlotRange -> All\), ",", 
            StyleBox[\(PlotLabel -> sessionname2\),
              FontColor->RGBColor[1, 0, 0]], ",", \(AxesOrigin -> {0, 0}\), 
            ",", \(Frame -> True\), ",", \(PlotJoined -> True\), 
            ",", \(RotateLabel -> True\), 
            ",", \(GridLines -> {None, Automatic}\), ",", 
            RowBox[{"FrameLabel", "->", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["\"\<Successive 5min intervals\>\"",
                    FontColor->RGBColor[1, 0, 0]], ",", 
                  "\"\<Activity per TimeSlice (meters)\>\""}], 
                StyleBox["}",
                  FontSlant->"Italic"]}]}], 
            ",", \(TextStyle -> {FontSize -> 14}\), 
            ",", \(Background \[Rule] GrayLevel[0.9]\), 
            ",", \(FrameStyle \[Rule] Thickness[0.008]\), 
            ",", \(FrameTicks -> {{1, 2, 3, 4, 5}, {10, 20, 30, 40, 50}, 
                None, None}\), 
            ",", \(PlotStyle -> {Hue[0.9], Thickness[0.01]}\)}], "]"}]}], 
      ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.9 g
MFill
% Scaling calculations
-0.214286 0.238095 -0.404629 0.0204155 [
[.02381 -0.0125 -6.1875 -16.9375 ]
[.02381 -0.0125 6.1875 0 ]
[.2619 -0.0125 -6.1875 -16.9375 ]
[.2619 -0.0125 6.1875 0 ]
[.5 -0.0125 -6.1875 -16.9375 ]
[.5 -0.0125 6.1875 0 ]
[.7381 -0.0125 -6.1875 -16.9375 ]
[.7381 -0.0125 6.1875 0 ]
[.97619 -0.0125 -6.1875 -16.9375 ]
[.97619 -0.0125 6.1875 0 ]
[.5 -0.0125 -106.688 -33.875 ]
[.5 -0.0125 106.688 -16.9375 ]
[-0.0125 .00368 -20.75 -8.46875 ]
[-0.0125 .00368 0 8.46875 ]
[-0.0125 .20783 -20.75 -8.46875 ]
[-0.0125 .20783 0 8.46875 ]
[-0.0125 .41199 -20.75 -8.46875 ]
[-0.0125 .41199 0 8.46875 ]
[-0.0125 .61614 -20.75 -8.46875 ]
[-0.0125 .61614 0 8.46875 ]
[-0.01875 .30902 -37.6875 -131.813 ]
[-0.01875 .30902 -20.75 131.813 ]
[.5 .63053 -52.25 0 ]
[.5 .63053 52.25 16.9375 ]
[ -0.004 -0.004 0 0 ]
[ 1.004 .62203 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .10576 m
1 .10576 L
s
0 .20783 m
1 .20783 L
s
0 .30991 m
1 .30991 L
s
0 .41199 m
1 .41199 L
s
0 .51407 m
1 .51407 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.008 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -167.688 -37.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Successive) show
155.125 16.188 moveto
(5) show
163.500 16.188 moveto
(min) show
197.000 16.188 moveto
(intervals) show
272.375 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .00368 m
.00625 .00368 L
s
gsave
-0.0125 .00368 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .20783 m
.00625 .20783 L
s
gsave
-0.0125 .20783 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .41199 m
.00625 .41199 L
s
gsave
-0.0125 .41199 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .61614 m
.00625 .61614 L
s
gsave
-0.0125 .61614 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.008 w
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -222.031 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
192.813 12.4688 translate
90 rotate
-192.813 -12.4688 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Activity) show
138.375 16.188 moveto
(per) show
171.875 16.188 moveto
(TimeSlice) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
255.625 16.188 moveto
(H) show
264.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
314.250 16.188 moveto
(L) show
322.625 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 .6 r
.01 w
.02381 .60332 m
.2619 .48082 L
.5 .13296 L
.7381 .07582 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{419.75, 259.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S00010a000`40O003h00O=Woo00<007ooOol0
ogooJgoo000eLi`2003oLia]Li`002mcW003001cW7>L00<00003Li`007>L0?mcW6acW000;g>L0`00
0W>L00<007>LLi`0og>LKG>L000_Li`30002Li`00`00LiacW03oLia]Li`0039cW0<00003Li`007>L
0?mcW6acW000=G>L0P00og>LKG>L000fLi`00`00LiacW03oLia[Li`007icW003001cW000008000Ec
W0800003Li`00000009cW0@000AcW0@000AcW0D0009cW0D000=cW0D000=cW0L000=cW08000EcW0D0
00mcW0@000=cW0<00006Li`00000Li`007>L1`0000EcW000000007>L00<000YcW0L00005Li`00000
001cW0030003Li`30004Li`50002Li`50005Li`20005Li`3000017>L000007>L1`0000=cW0000000
0`00FW>L000bLi`40018Li`20003Li`01@00LiacW7>L00000W>L0P000W>L00<007>LLi`00W>L00@0
07>LLi`000AcW004001cW7>L0007Li`00`00LiacW002Li`01000LiacW00017>L00<007>LLi`00g>L
00<007>LLi`017>L0P0017>L00<007>LLi`04G>L00<007>LLi`00W>L00D007>LLiacW000009cW004
001cW7>L0004Li`00`00LiacW003Li`01@00LiacW7>L00003W>L00<007>LLi`00g>L00D007>LLiac
W00000=cW005001cW7>LLi`00002Li`00`00LiacW006Li`00`00LiacW006Li`20004Li`01000Liac
W7>L0P001G>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>LLi`0Eg>L000aLi`00`00LiacW002
Li`00`00LiacW01:Li`01@00LiacW7>L00000g>L00@007>LLi`000McW003001cW7>L00EcW003001c
W7>L00YcW003001cW7>L00EcW003001cW7>L00=cW003001cW7>L00=cW004001cW7>L0003Li`00`00
LiacW00FLi`01@00LiacW7>L00000W>L00@007>LLi`000AcW003001cW7>L00=cW005001cW7>LLi`0
000>Li`00`00LiacW003Li`01@00LiacW7>L00000g>L00<007>LLi`017>L00<007>LLi`01W>L00<0
07>LLi`01G>L00@007>LLi`000=cW003001cW7>L009cW003001cW7>L00=cW003001cW7>L00McW003
001cW7>L05McW000<G>L00<007>LLi`00W>L00<007>LLi`0BW>L00D007>LLiacW00000=cW004001c
W7>L0007Li`00`00LiacW005Li`60003Li`40004Li`40006Li`00`00LiacW003Li`01000LiacW000
0g>L1P004g>L00D007>LLiacW000009cW004001cW7>L0004Li`00`00LiacW003Li`01@00LiacW7>L
00003W>L00<007>LLi`00g>L00D007>LLiacW00000=cW003001cW7>L00AcW0H000=cW003001cW7>L
00EcW004001cW7>L0004Li`50005Li`00`00LiacW003Li`4001JLi`0035cW003001cW7>L009cW003
001cW7>L04IcW0@000AcW005001cW7>LLi`00002Li`01000LiacW7>L0P000W>L00@007>LLiacW080
009cW003001cW7>L009cW004001cW7>L0004Li`01000LiacW00017>L00<007>LLi`00g>L00<007>L
Li`00W>L00<007>LLi`00W>L00@007>LLi`000AcW003001cW7>L015cW004001cW7>LLi`200001G>L
000007>L000017>L00<007>LLi`00g>L0P000W>L00<007>LLi`037>L00<007>LLi`00g>L0P000W>L
00D007>LLiacW00000IcW003001cW7>L009cW004001cW7>LLi`20005Li`00`00LiacW002Li`01000
LiacW00017>L00<007>LLi`00g>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>LLi`0Eg>L000a
Li`00`00LiacW002Li`00`00LiacW015Li`00`00LiacW005Li`20002Li`20003Li`300000g>L001c
W002Li`300000g>L001cW002Li`40004Li`50003Li`50003Li`30003Li`30002Li`30002Li`4000@
Li`40003Li`200001G>L001cW7>L00000g>L0`0017>L0P0000=cW00000003G>L0`0017>L0P0000=c
W00000000g>L1P000g>L10000g>L0P0000EcW000000007>L00<0009cW0<0009cW0@000IcW003001c
W7>L00=cW0D005UcW000<G>L0P000W>L00<007>LLi`0AW>L00@007>LLiacW08005McW003001cW7>L
03McW003001cW7>L02McW003001cW7>L065cW000Og>L0`0000=cW000Li`0=7>L00<007>LLi`07g>L
00<007>LLi`047>L00<007>LLi`05W>L00<007>LLi`02g>L00<007>LLi`09g>L00<007>LLi`0HG>L
003KLi`5001NLi`2001SLi`0035cW003001cW7>L0?mcW71cW000;g>L1`00og>LKW>L000aLi`00`00
LiacW002Li`00`00LiacW03oLia[Li`0035cW003001cW7>L009cW003001cW7>L0?mcW6]cW000<G>L
00<007>LLi`00W>L00<007>LLi`0og>LJg>L000aLi`01@00LiacW7>L0000og>LKW>L003oLibTLi`0
0?mcW:AcW000=W>L00<007>LLi`08G>L1@00?g>L1@00@G>L0`00@g>L0`00@7>L1000<W>L000aLi`0
0`00LiacW002Li`00`00LiacW00SLi`00`00LiacW00oLi`01@00LiacW7>L0000@7>L00D007>LLiac
W00004=cW003001cW7>L03icW003001cW7>L009cW003001cW7>L02mcW000<G>L00<007>LLi`00W>L
00<007>LLi`08g>L00<007>LLi`0@7>L00<007>LLi`0AG>L00<007>LLi`0@G>L00<007>LLi`0@g>L
00<007>LLi`0;g>L000_Li`00`00Li`00005000ULi`00`00LiacW011Li`00`00LiacW014Li`00`00
LiacW00mLi`60014Li`00`00LiacW00_Li`003IcW003001cW7>L02=cW003001cW7>L049cW003001c
W7>L045cW080045cW004001cW7>L0015Li`00`00LiacW00_Li`003IcW003001cW7>L02=cW003001c
W7>L049cW003001cW7>L04=cW003001cW7>L03icW004001cW7>L0011Li`4000bLi`003IcW003001c
W7>L02=cW003001cW7>L04=cW003001cW7>L049cW003001cW7>L03mcW003001cW000045cW003001c
W7>L03=cW000<G>L00<007>LLi`09W>L0`00@G>L00D007>LLiacW000041cW005001cW7>LLi`00011
Li`00`00Li`00011Li`00`00LiacW00cLi`0035cW08002UcW003001cW7>L041cW0<0049cW0<004=c
W080045cW0D0035cW000<G>L00@007>L00000?mcW6mcW000=G>L0P00og>LKG>L000eLi`2003oLia]
Li`0035cW004001cW000003oLia_Li`0035cW08000ecW0D000AcW0@00?mcW5McW000<G>L00<007>L
Li`037>L00D007>LLiacW00000=cW003001cW7>L009cW003001cW7>L0?mcW5AcW000@G>L00<007>L
Li`017>L00<007>LLi`00W>L00<007>LLi`01G>Lo`008`00;7>L000fLi`00`00LiacW009Li`00`00
LiacW003Li`00`00LiacW002Li`00`00LiacW005Lico000S000/Li`0035cW003001cW7>L009cW003
001cW7>L00YcW003001cW7>L009cW003001cW7>L009cW003001cW7>L00EcW08000EcW003001cW7>L
049cW003001cW7>L049cW003001cW7>L049cW003001cW7>L045cW003001cW7>L00=cW08002acW000
<G>L00<007>LLi`00W>L00<007>LLi`02W>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>LLi`0
1G>L0P00og>L6G>L00=l4g>LLi`00g>L0P00;7>L000_Li`00`00Li`00005000=Li`01@00LiacW7>L
000017>L00<007>LLi`01G>L0P00og>L5W>L17`C1G>L0P00;7>L000fLi`00`00LiacW007Li`01@00
LiacW7>L00000g>L00<007>LLi`00W>L00<007>LLi`01G>L0P00og>L4W>L1g`C1W>L0P00;7>L000f
Li`00`00LiacW008Li`30005Li`40008Li`2003oLi`>Li`8O1<9Li`2000/Li`003IcW003001cW7>L
01acW0800?mcW0YcW0Ql4`ecW08002acW000EG>L0P00og>L1g>L1g`C4G>L0P00;7>L000aLi`00`00
LiacW00QLi`2003oLi`3Li`7O1<ELi`2000/Li`002mcW0L001mcW0800?icW0Ql4aQcW08002acW000
<G>L00<007>LLi`00W>L00<007>LLi`077>L0P00nW>L27`C77>L0P00;7>L000aLi`00`00LiacW002
Li`00`00LiacW00LLi`2003fLi`8O1<PLi`2000/Li`0035cW003001cW7>L009cW003001cW7>L01ac
W0800?=cW0Ml4bAcW08002acW000<G>L00D007>LLiacW00001mcW0800>mcW0Ml4bQcW08002acW000
EG>L0P00jg>L27`C:g>L0P00;7>L001ELi`2003WLi`8O1<_Li`2000/Li`0035cW003001cW7>L025c
W0800>AcW0Ml4c=cW08002acW000<G>L0`001G>L00<007>LLi`06G>L0P00h7>L1g`C=g>L0P00;7>L
000aLi`00`00LiacW0020002Li`2000KLi`2003LLi`8O1<jLi`2000/Li`003IcW0800003Li`007>L
01YcW0800=QcW0Ql4cicW08002acW000<G>L00<007>LLi`00P007g>L0P00e7>L27`C@W>L0P00;7>L
000aLi`3000QLi`2003@Li`8O1=6Li`2000/Li`0035cW003001cW7>L025cW0800<acW0Ql4dYcW080
02acW000EG>L0P00b7>L27`CCW>L0P00;7>L001ELi`20033Li`9O1=BLi`2000/Li`005EcW0800;mc
W0Ul4eIcW08002acW000EG>L0P00^g>L27`CFg>L0P00;7>L001ELi`2002fLi`9O1=OLi`2000/Li`0
05EcW0800;9cW0Ul4f=cW08002acW000EG>L0P00[W>L27`CJ7>L0P00;7>L001ELi`2002Y00l9O1=/
00l2000/Li`005EcW0800:EcW0Ul4g1cW08002acW000EG>L0P00XG>L27`CMG>L0P00;7>L001ELi`2
002LLi`9O1=iLi`2000/Li`005EcW08009QcW0Ul4gecW08002acW000EG>L0P00U7>L27`CPW>L0P00
;7>L000aLi`00`00LiacW005Li`00`00LiacW00ILi`2002?Li`9O1>6Li`2000/Li`0035cW0T001]c
W08008mcW0El4hYcW08002acW000<G>L00D007>LLiacW00000=cW003001cW7>L01UcW08008icW09l
4hicW08002acW000<G>L00<007>LLi`00W>L00<007>LLi`077>L0P00SG>L0W`CSg>L0P00;7>L000a
Li`00`00LiacW002Li`00`00LiacW00LLi`2002=Li`00g`CLiacW02>Li`2000/Li`0039cW0@001mc
W08008acW09l4i1cW08002acW000EG>L0P00Rg>L0W`CTG>L0P00;7>L001ELi`2002;Li`00g`CLiac
W02@Li`2000/Li`0039cW0@001mcW08008YcW09l4i9cW08002acW000<G>L00<007>L00000W>L00<0
07>LLi`077>L0P00RG>L0W`CTg>L0P00;7>L000aLi`00`00Li`00002Li`00`00LiacW00LLi`20029
Li`00g`CLiacW02BLi`2000/Li`0035cW003001cW000009cW003001cW7>L01acW08008QcW09l4iAc
W08002acW000<G>L00<007>L00000W>L00<007>LLi`077>L0P00Qg>L0W`CUG>L0P00;7>L000bLi`2
0002Li`00`00LiacW00LLi`20026Li`2O1>FLi`2000/Li`005EcW08008IcW003O1=cW7>L09EcW080
02acW000EG>L0P00QG>L0W`CUg>L0P00;7>L000aLi`00`00LiacW002Li`00`00LiacW00LLi`20024
Li`2O1>HLi`2000/Li`0035cW0H001icW08008AcW003O1=cW7>L09McW08002acW000<W>L00D007>L
LiacW00001icW08008=cW09l4iUcW08002acW000<G>L00<007>LLi`00W>L00<007>LLi`077>L0P00
PW>L0W`CVW>L0P00;7>L000aLi`00`00LiacW002Li`00`00LiacW008Li`30005Li`40008Li`20022
Li`00g`CLiacW02ILi`2000/Li`0035cW003001cW7>L00acW005001cW7>LLi`00003Li`00`00Liac
W002Li`00`00LiacW005Li`20021Li`2O1>KLi`2000/Li`004AcW005001cW7>LLi`00004Li`00`00
LiacW005Li`20020Li`2O1>LLi`2000/Li`004AcW005001cW7>LLi`00004Li`00`00LiacW005Li`3
001o00l00g`C00l03`2K00l2000/Li`0049cW08000AcW003001cW7>L009cW003001cW7>L00EcW080
07mcW09l4iecW08002acW000A7>L00D007>LLiacW00000AcW003001cW7>L00EcW08007icW09l4iic
W08002acW000A7>L00D007>LLiacW00000AcW003001cW7>L00EcW08007icW003O1=cW7>L09ecW080
02acW000@7>L00D007>LLiacW00000=cW003001cW7>L009cW003001cW7>L00EcW08007ecW09l4imc
W08002acW000@G>L0`001G>L100027>L0P00O7>L0W`CX7>L0P00;7>L001ELi`2001lLi`00g`CLiac
W02OLi`2000/Li`005EcW08007]cW09l4j5cW08002acW000EG>L0P00NW>L0W`CXW>L0P00;7>L001E
Li`2001iLi`2O1>SLi`2000/Li`002mcW0<002=cW08007UcW003O1=cW7>L0:9cW08002acW000;g>L
00<007>LLi`017>L00<007>LLi`077>L0P00N7>L0W`CY7>L0P00;7>L000_Li`00`00LiacW004Li`0
0`00LiacW00LLi`2001gLi`2O1>ULi`2000/Li`002mcW0P001icW08007McW003O1=cW7>L0:AcW080
02acW000;g>L00<007>LLi`017>L00<007>LLi`077>L0P00MW>L0W`CYW>L0P00;7>L000_Li`00`00
LiacW004Li`00`00LiacW00LLi`2001eLi`2O1>WLi`2000/Li`002mcW0<002=cW08007EcW003O1=c
W7>L0:IcW08002acW000EG>L0P00M7>L0W`CZ7>L0P00;7>L000fLi`00`00LiacW00LLi`2001cLi`2
O1>YLi`2000/Li`0035cW003001cW7>L009cW003001cW7>L01acW08007=cW003O1=cW7>L0:QcW080
02acW000<G>L00<007>LLi`00W>L00<007>LLi`077>L0P00LW>L0W`CZW>L0P00;7>L000_Li`00`00
Li`00005000NLi`2001aLi`2O1>[Li`2000/Li`003IcW003001cW7>L01acW080075cW003O1=cW7>L
0:YcW08002acW000=W>L00<007>LLi`077>L0P00L7>L0W`C[7>L0P00;7>L000fLi`00`00LiacW00L
Li`2001_Li`2O1>]Li`2000/Li`0035cW003001cW7>L009cW003001cW7>L01acW08006mcW003O1=c
W7>L0:acW08002acW000<G>L1P007W>L0P00KW>L0W`C[W>L0P00;7>L000aLi`00`00LiacW002Li`0
0`00LiacW00LLi`2001]Li`2O1>_Li`2000/Li`0035cW003001cW7>L025cW08006acW09l4k1cW080
02acW000<W>L1@007W>L0P00K7>L00=l4g>LLi`0[g>L0P00;7>L000bLi`01@00LiacW7>L00007W>L
0P00J`0?0W`C/@0?0P00;7>L000aLi`00`00LiacW00QLi`2001ZLi`2O1>bLi`2000/Li`0039cW0D0
01icW08006YcW003O1=cW7>L0;5cW08002acW000EG>L0P00JG>L0W`C/g>L0P00;7>L000bLi`4000O
Li`2001XLi`2O1>dLi`2000/Li`0035cW003001cW000009cW003001cW7>L01acW08006QcW003O1=c
W7>L0;=cW08002acW000<G>L00<007>L00000W>L00<007>LLi`077>L0P00Ig>L0W`C]G>L0P00;7>L
000aLi`00`00Li`00002Li`00`00LiacW00LLi`2001VLi`2O1>fLi`2000/Li`0035cW003001cW000
009cW003001cW7>L01acW08006IcW003O1=cW7>L0;EcW08002acW000<W>L0P000W>L00<007>LLi`0
77>L0P00IG>L0W`C]g>L0P00;7>L001ELi`2001TLi`2O1>hLi`2000/Li`005EcW08006AcW003O1=c
W7>L0;McW08002acW000<7>L0P000g>L0P007W>L0P00Hg>L0W`C^G>L0P00;7>L000_Li`01000Liac
W0000W>L00<007>LLi`07G>L0P00HW>L0W`C^W>L0P00;7>L000_Li`01000LiacW0000g>L00<007>L
Li`077>L0P00HW>L00=l4g>LLi`0^G>L0P00;7>L000_Li`01000LiacW0000g>L00<007>LLi`077>L
0P00HG>L0W`C^g>L0P00;7>L000_Li`01000LiacW0000g>L00<007>LLi`077>L0P00H7>L0W`C_7>L
0P00;7>L000_Li`20002Li`3000OLi`2001PLi`00g`CLiacW02kLi`2000/Li`005EcW08005mcW09l
4kecW08002acW000EG>L0P00GW>L0W`C_W>L0P00;7>L000fLi`00`00LiacW00LLi`2001MLi`2O1>o
Li`2000/Li`003IcW003001cW7>L01acW08005ecW003O1=cW7>L0;icW08002acW000;W>L00<007>L
Li`01G>L00<007>LLi`077>L0P00G7>L0W`C`7>L0P00;7>L000^Li`9000NLi`2001KLi`2O1?1Li`2
000/Li`003IcW003001cW7>L01acW08005]cW003O1=cW7>L0<1cW08002acW000=W>L00<007>LLi`0
77>L0P00FW>L0W`C`W>L0P00;7>L000fLi`00`00LiacW00:Li`30003Li`40008Li`2001ILi`2O1?3
Li`2000/Li`004AcW005001cW7>LLi`00004Li`00`00LiacW005Li`2001ILi`00g`CLiacW032Li`2
000/Li`003IcW003001cW7>L00]cW005001cW7>LLi`00004Li`00`00LiacW005Li`2001HLi`2O1?4
Li`2000/Li`0035cW003001cW7>L009cW003001cW7>L00McW0H0009cW003001cW7>L009cW003001c
W7>L00EcW0<005H03`9l4lD03`8002acW000<G>L00<007>LLi`00W>L00<007>LLi`027>L00@007>L
Li`000=cW003001cW7>L009cW003001cW7>L00EcW08005McW003O1=cW7>L0<AcW08002acW000;g>L
00<007>L00001@002W>L00@007>LLi`000=cW003001cW7>L009cW003001cW7>L00EcW08005IcW09l
4lIcW08002acW000=W>L00<007>LLi`02G>L00<007>L00000g>L00<007>LLi`00W>L00<007>LLi`0
1G>L0P00EG>L0W`Cag>L0P00;7>L000fLi`00`00LiacW009Li`00`00Li`00003Li`00`00LiacW002
Li`00`00LiacW005Li`2001ELi`00g`CLiacW036Li`2000/Li`003IcW003001cW7>L00YcW08000Ac
W0@000QcW08005AcW09l4lQcW08002acW000EG>L0P00Dg>L0W`CbG>L0P00;7>L000bLi`4000OLi`2
001CLi`00g`CLiacW038Li`2000/Li`0035cW003001cW7>L009cW003001cW7>L01acW080059cW09l
4lYcW08002acW000<G>L00<007>LLi`00W>L00<007>LLi`077>L0P00DG>L0W`Cbg>L0P00;7>L000a
Li`00`00LiacW002Li`00`00LiacW00LLi`2001@Li`2O1?<Li`2000/Li`0035cW003001cW7>L009c
W003001cW7>L01acW080051cW003O1=cW7>L0<]cW08002acW000<G>L0P000W>L00<007>LLi`07G>L
0P00Cg>L0W`CcG>L0P00;7>L001ELi`2001>Li`2O1?>Li`2000/Li`005EcW08004icW003O1=cW7>L
0<ecW08002acW000<W>L10007g>L0P00CG>L0W`Ccg>L0P00;7>L000aLi`00`00Li`00002Li`00`00
LiacW00LLi`2001<Li`2O1?@Li`2000/Li`0035cW003001cW000009cW003001cW7>L01acW08004ac
W003O1=cW7>L0<mcW08002acW000<G>L00<007>L00000W>L00<007>LLi`077>L0P00Bg>L0W`CdG>L
0P00;7>L000aLi`00`00Li`00002Li`00`00LiacW00LLi`2001:Li`2O1?BLi`2000/Li`0039cW080
009cW003001cW7>L01acW08004QcW0=l4m=cW08002acW000EG>L0P00AW>L1G`Cdg>L0P00;7>L001E
Li`20014Li`5O1?ELi`2000/Li`005EcW080049cW0El4mMcW08002acW000EG>L0P00@7>L1G`CfG>L
0P00;7>L001ELi`2000nLi`5O1?KLi`2000/Li`005EcW08003acW0El4mecW08002acW000EG>L0P00
>W>L1G`Cgg>L0P00;7>L001ELi`2000hLi`5O1?QLi`2000/Li`005EcW08003H03`El4n<03`8002ac
W000EG>L0P00=7>L1G`CiG>L0P00;7>L001ELi`2000bLi`5O1?WLi`2000/Li`005EcW080031cW0El
4nUcW08002acW000EG>L0P00;W>L1G`Cjg>L0P00;7>L001ELi`2000/Li`5O1?]Li`2000/Li`005Ec
W08002YcW0El4nmcW08002acW000EG>L0P00:7>L1G`ClG>L0P00;7>L001ELi`2000WLi`4O1?cLi`2
000/Li`0035cW0H001icW08002EcW0Al4oEcW08002acW000;g>L0P001W>L0P0077>L0P008g>L1G`C
mW>L0P00;7>L000^Li`00`00LiacW008Li`00`00LiacW00ILi`2000QLi`5O1?hLi`2000/Li`005Ec
W08001mcW0El4oYcW08002acW000<G>L00<007>LLi`00W>L00<007>LLi`077>L0P007G>L1G`Co7>L
0P00;7>L000aLi`6000NLi`2000KLi`5O1?nLi`2000/Li`0035cW003001cW7>L009cW003001cW7>L
01acW08001UcW0El4omcW05cW08002acW000<G>L00<007>LLi`08G>L0P005g>L1G`Cog>L0g>L0P00
;7>L000bLi`5000NLi`2000ELi`5O1?oLi`5Li`2000/Li`0039cW005001cW7>LLi`0000NLi`2000C
Li`5O1?oLi`7Li`2000/Li`0035cW003001cW7>L025cW080015cW0El4omcW0UcW08002acW000<W>L
1@007W>L0P003g>L1G`Cog>L2g>L0P00;7>L001ELi`2000=Li`5O1?oLi`=Li`2000/Li`0039cW0@0
01mcW08000]cW0El4omcW0mcW08002acW000<G>L00<007>L00000W>L00<007>LLi`077>L0P002G>L
1G`Cog>L4G>L0P00;7>L000aLi`00`00Li`00002Li`00`00LiacW00LLi`20007Li`5O1?oLi`CLi`2
000/Li`0035cW003001cW000009cW003001cW7>L01acW08000EcW0El4omcW1EcW08002acW000<G>L
00<007>L00000W>L00<007>LLi`077>L0P0017>L17`Cog>L5g>L0P00;7>L000bLi`20002Li`00`00
LiacW008Li`40004Li`40008Li`20005Li`00g`CLiacW03oLi`GLi`2000/Li`0041cW003001cW7>L
009cW004001cW7>L0004Li`00`00LiacW005Li`2003oLi`OLi`2000/Li`004EcW004001cW7>L0004
Li`00`00LiacW005Li`2003oLi`OLi`2000/Li`0035cW003001cW7>L015cW004001cW7>L0004Li`0
0`00LiacW005Lico000S000/Li`002mcW0L000mcW004001cW7>L0004Li`00`00LiacW005Lico000S
000/Li`0035cW003001cW7>L009cW003001cW7>L00QcW0@000=cW003001cW7>L009cW003001cW7>L
0?mcW5AcW000<G>L00<007>LLi`00W>L00<007>LLi`027>L00<007>LLi`017>L00<007>LLi`00W>L
00<007>LLi`0og>LE7>L000aLi`00`00LiacW002Li`00`00LiacW008Li`00`00LiacW004Li`00`00
LiacW002Li`00`00LiacW03oLiaDLi`0035cW005001cW7>LLi`0000;Li`50003Li`4003oLiaGLi`0
0?mcW0P009acW000og>LY7>L000bLi`4003oLia^Li`0035cW003001cW000009cW003001cW7>L0;Ic
W004001cW7>L002`Li`0035cW003001cW000009cW003001cW7>L07icW0<000AcW0@000IcW004001c
W7>LLi`30003Li`20002Li`3000017>L000007>L1`000W>L1@0017>L00@007>LLi`000EcW0<000ic
W0D000AcW08008mcW000<G>L00<007>L00000W>L00<007>LLi`0OG>L00D007>LLiacW000009cW003
001cW7>L009cW003001cW7>L00=cW003001cW7>L009cW003001cW7>L00=cW003001cW00000=cW080
00EcW003001cW7>L009cW003001cW7>L00QcW004001cW7>L0003Li`01@00LiacW7>L00003g>L00<0
07>LLi`017>L0P00Sg>L000aLi`00`00Li`00002Li`00`00LiacW01lLi`00`00LiacW00:Li`00`00
LiacW003Li`00`00LiacW002Li`01000LiacW0000W>L00<007>L000017>L00<007>LLi`00g>L00<0
07>LLi`00W>L00<007>LLi`01g>L1P001W>L00<007>LLi`03G>L00<007>LLi`0UG>L000bLi`20002
Li`00`00LiacW01lLi`00`00LiacW00:Li`00`00LiacW004Li`02`00LiacW7>L001cW000Li`007>L
00000W>L1@001G>L00<007>LLi`00W>L1P001G>L00@007>LLi`000McW003001cW7>L00ecW003001c
W7>L09EcW000]G>L00<007>LLi`02W>L00<007>LLi`017>L00d007>LLiacW000Li`007>L001cW000
Li`00004Li`00`00LiacW003Li`00`00LiacW002Li`00`00LiacW002Li`00`00LiacW003Li`01000
LiacW0001G>L0P0047>L00<007>LLi`0UG>L002eLi`00`00LiacW006Li`40007Li`02`00LiacW7>L
001cW000Li`007>L00000W>L10001W>L00<007>LLi`00g>L10001G>L1P001W>L00<007>LLi`03G>L
00<007>LLi`0UG>L000aLi`00`00LiacW002Li`00`00LiacW01mLi`00`00LiacW0020003Li`00`00
LiacW009Li`00`00LiacW0020003Li`2000<Li`00`00LiacW00=Li`01000LiacW0001g>L00<007>L
Li`03G>L00<007>LLi`0UG>L000aLi`60020Li`200000g>L001cW002Li`00`00LiacW004Li`00`00
LiacW002Li`00`00Li`000020003Li`2000<Li`00`00LiacW00>Li`01000LiacW0000W>L00D007>L
LiacW00000ecW0<009McW000<W>L00D007>LLiacW00008McW0D0009cW0H001AcW080011cW004001c
W7>L0003Li`3000@Li`00`00LiacW02ELi`0035cW003001cW7>L009cW003001cW7>L0?mcW6]cW000
<G>L00<007>LLi`00W>L00<007>LLi`0og>LJg>L000aLi`00`00LiacW03oLia`Li`00?mcW:AcW000
og>LY7>L000bLi`00`00LiacW002003oLia]Li`0035cW005001cW000Li`0003oLia^Li`0035cW003
001cW000009cW003001cW7>L0?mcW6]cW000<G>L00<007>L00000W>L00<007>LLi`0og>LJg>L000a
Li`00`00Li`00002Li`00`00LiacW03oLia[Li`0035cW0800003Li`000000?mcW6icW000og>LY7>L
003oLibTLi`00?mcW:AcW000og>LY7>L003oLibTLi`002icW003001cW7>L00QcW003001cW7>L0?mc
W6QcW000;g>L0P001W>L0P00og>LJg>L000aLi`6003oLia]Li`00?mcW:AcW000og>LY7>L003oLibT
Li`00001\
\>"],
  ImageRangeCache->{{{0, 418.75}, {258.438, 0}} -> {-0.353752, 13.0147, \
0.0145596, 0.169801}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[we, we1, PlotLabel \[Rule] None]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.9 g
MFill
% Scaling calculations
-0.214286 0.238095 -0.0542079 0.0133179 [
[.02381 -0.0125 -6.1875 -16.9375 ]
[.02381 -0.0125 6.1875 0 ]
[.2619 -0.0125 -6.1875 -16.9375 ]
[.2619 -0.0125 6.1875 0 ]
[.5 -0.0125 -6.1875 -16.9375 ]
[.5 -0.0125 6.1875 0 ]
[.7381 -0.0125 -6.1875 -16.9375 ]
[.7381 -0.0125 6.1875 0 ]
[.97619 -0.0125 -6.1875 -16.9375 ]
[.97619 -0.0125 6.1875 0 ]
[.5 -0.0125 -106.688 -33.875 ]
[.5 -0.0125 106.688 -16.9375 ]
[-0.0125 .07897 -20.75 -8.46875 ]
[-0.0125 .07897 0 8.46875 ]
[-0.0125 .21215 -20.75 -8.46875 ]
[-0.0125 .21215 0 8.46875 ]
[-0.0125 .34533 -20.75 -8.46875 ]
[-0.0125 .34533 0 8.46875 ]
[-0.0125 .47851 -20.75 -8.46875 ]
[-0.0125 .47851 0 8.46875 ]
[-0.0125 .61169 -20.75 -8.46875 ]
[-0.0125 .61169 0 8.46875 ]
[-0.01875 .30902 -37.6875 -131.813 ]
[-0.01875 .30902 -20.75 131.813 ]
[ -0.004 -0.004 0 0 ]
[ 1.004 .62203 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .07897 m
1 .07897 L
s
0 .21215 m
1 .21215 L
s
0 .34533 m
1 .34533 L
s
0 .47851 m
1 .47851 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67.1875 -20.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.008 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -167.688 -37.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Successive) show
155.125 16.188 moveto
(5) show
163.500 16.188 moveto
(min) show
197.000 16.188 moveto
(intervals) show
272.375 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .07897 m
.00625 .07897 L
s
gsave
-0.0125 .07897 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .21215 m
.00625 .21215 L
s
gsave
-0.0125 .21215 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .34533 m
.00625 .34533 L
s
gsave
-0.0125 .34533 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .47851 m
.00625 .47851 L
s
gsave
-0.0125 .47851 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .61169 m
.00625 .61169 L
s
gsave
-0.0125 .61169 -81.75 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.008 w
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -222.031 -12.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
192.813 12.4688 translate
90 rotate
-192.813 -12.4688 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Activity) show
138.375 16.188 moveto
(per) show
171.875 16.188 moveto
(TimeSlice) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
255.625 16.188 moveto
(H) show
264.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
314.250 16.188 moveto
(L) show
322.625 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .4 1 r
.01 w
.02381 .01472 m
.2619 .02363 L
.5 .24711 L
.7381 .21256 L
.97619 .48387 L
s
1 0 .6 r
.02381 .60332 m
.2619 .52341 L
.5 .29649 L
.7381 .25921 L
.97619 .21935 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{571.875, 353.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008k0001HA000`40O003h00Oogooogoo?Goo003o
LicoLi`mLi`00?mcW?mcW3ecW000og>Log>L?G>L003oLicoLi`mLi`00?mcW?mcW3ecW000c7>L00<0
07>L00000P001G>L0P0000=cW00000000W>L100017>L100017>L1@000W>L1@000g>L1@000g>L1`00
0g>L0P001G>L1@003g>L10000W>L0`0000IcW000001cW000Li`700001G>L00000000Li`00`002g>L
1`0000EcW000000007>L00<000=cW0<000AcW0D0009cW0D000EcW08000EcW0<00004Li`00000Li`7
00000g>L00000003002TLi`00<acW08000=cW005001cW7>LLi`00002Li`20002Li`00`00LiacW002
Li`01000LiacW00017>L00@007>LLi`000McW003001cW7>L009cW004001cW7>L0004Li`00`00Liac
W003Li`00`00LiacW004Li`20004Li`00`00LiacW00ALi`00`00LiacW002Li`01000LiacW0000W>L
00@007>LLi`000AcW003001cW7>L00=cW005001cW7>LLi`0000?Li`00`00LiacW003Li`01@00Liac
W7>L00000g>L00D007>LLiacW000009cW003001cW7>L00IcW003001cW7>L00IcW08000AcW004001c
W7>LLi`20005Li`00`00LiacW002Li`00`00LiacW002Li`00`00LiacW02QLi`00=5cW005001cW7>L
Li`00003Li`01000LiacW0001g>L00<007>LLi`01G>L00<007>LLi`02W>L00<007>LLi`01G>L00<0
07>LLi`00g>L00<007>LLi`00g>L00@007>LLi`000=cW003001cW7>L01IcW004001cW7>L0002Li`0
1000LiacW00017>L00<007>LLi`00g>L00D007>LLiacW00000mcW003001cW7>L00=cW005001cW7>L
Li`00003Li`00`00LiacW004Li`00`00LiacW006Li`00`00LiacW005Li`01000LiacW0000g>L00<0
07>LLi`00W>L00<007>LLi`00g>L00<007>LLi`01g>L00<007>LLi`0XG>L003ALi`01@00LiacW7>L
00000g>L00@007>LLi`000McW003001cW7>L00EcW0H000=cW0@000AcW0@000IcW003001cW7>L00=c
W004001cW7>L0003Li`6000CLi`01000LiacW0000W>L00@007>LLi`000AcW003001cW7>L00=cW005
001cW7>LLi`0000?Li`00`00LiacW003Li`01@00LiacW7>L00000g>L00<007>LLi`017>L1P000g>L
00<007>LLi`01G>L00@007>LLi`000AcW0D000EcW003001cW7>L00=cW0@00:AcW000cG>L100017>L
00D007>LLiacW000009cW004001cW7>LLi`20002Li`01000LiacW7>L0P000W>L00<007>LLi`00W>L
00@007>LLi`000AcW004001cW7>L0004Li`00`00LiacW003Li`00`00LiacW002Li`00`00LiacW002
Li`01000LiacW00017>L00<007>LLi`04G>L00<007>LLi`00P0000EcW000001cW00000AcW003001c
W7>L00=cW080009cW003001cW7>L00ecW003001cW7>L00=cW080009cW005001cW7>LLi`00006Li`0
0`00LiacW002Li`01000LiacW7>L0P001G>L00<007>LLi`00W>L00@007>LLi`000AcW003001cW7>L
00=cW003001cW7>L009cW003001cW7>L009cW003001cW7>L0:5cW000c7>L00<007>LLi`01G>L0P00
0W>L0P000g>L0`0000=cW000Li`00W>L0`0000=cW000Li`00W>L100017>L1@000g>L1@000g>L0`00
0g>L0`000W>L0`000W>L100047>L10000W>L0P0000EcW000LiacW00000=cW0<000AcW0800003Li`0
000000icW0<000AcW0800003Li`0000000=cW0H000=cW0@000=cW0800005Li`00000001cW0030002
Li`30002Li`40006Li`00`00LiacW003Li`5002SLi`00<acW004001cW7>LLi`2001GLi`00`00Liac
W00gLi`00`00LiacW00WLi`00`00LiacW02[Li`00<ecW0<00003Li`007>L03AcW003001cW7>L01mc
W003001cW7>L00mcW003001cW7>L01McW003001cW7>L00]cW003001cW7>L02McW003001cW7>L0:]c
W000og>L:W>L1@00GW>L0P00[G>L003oLicoLi`mLi`00?mcW?mcW3ecW000og>Log>L?G>L003oLico
Li`mLi`00?mcW?mcW3ecW000og>Log>L?G>L003oLicoLi`mLi`00?mcW?mcW3ecW000AG>L1@00L7>L
1@00LW>L0`00MW>L0`00LG>L10006G>L0017Li`00`00LiacW01`Li`01@00LiacW7>L0000LG>L00D0
07>LLiacW00007IcW003001cW7>L06mcW003001cW7>L009cW003001cW7>L01IcW000Ag>L00<007>L
Li`0LG>L00<007>LLi`0MW>L00<007>LLi`0M7>L00<007>LLi`0M7>L00<007>LLi`05W>L0017Li`0
0`00LiacW01bLi`00`00LiacW01eLi`00`00LiacW01`Li`6001eLi`00`00LiacW00FLi`004McW003
001cW7>L07=cW003001cW7>L079cW08007AcW004001cW7>L001fLi`00`00LiacW00FLi`004McW003
001cW7>L07=cW003001cW7>L07AcW003001cW7>L075cW004001cW7>L001bLi`4000ILi`004McW003
001cW7>L07AcW003001cW7>L07=cW003001cW7>L079cW003001cW000079cW003001cW7>L01YcW000
AG>L0`00LW>L00D007>LLiacW000075cW005001cW7>LLi`0001dLi`00`00Li`0001bLi`00`00Liac
W00JLi`004McW003001cW7>L075cW0<007=cW0<007IcW080079cW0D001QcW000og>Log>L?G>L003o
LicoLi`mLi`00?mcW?mcW3ecW000og>Log>L?G>L003oLicoLi`mLi`00?mcW?mcW3ecW000og>Log>L
?G>L000jLico003e000=Li`003YcW?l00?D000ecW000>W>Lo`00m@003G>L000jLi`3000:Li`00`00
LiacW01cLi`00`00LiacW01cLi`00`00LiacW01dLi`00`00LiacW01cLi`00`00LiacW008Li`3000=
Li`003YcW0<000YcW003001cW7>L07=cW003001cW7>L07=cW003001cW7>L07AcW003001cW7>L07=c
W003001cW7>L00QcW0<000ecW000>W>L0`00og>Lkg>L0`003G>L000jLi`30008Li`20IooLicULi`3
000=Li`003YcW0<000QcW1X1WomcW<ecW0<000ecW000>W>L0`0027>L<@6Oog>L]W>L0`003G>L000j
Li`30008Lia90IooLibNLi`3000=Li`003YcW0<000YcW5l1WomcW8IcW0<000ecW000>W>L0`008W>L
GP6Oog>LKg>L0`003G>L000jLi`3000iLia:0IooLia/Li`3000=Li`003YcW0<0055cW3<1WomcW6]c
W0<000ecW000>W>L0`00JG>L706Oog>LJW>L0`003G>L000jLi`30020Li`60IooLiaYLi`3000=Li`0
03YcW0<0085cW0H1WomcW6QcW0<000ecW000>W>L0`00PW>L1P6Oog>LIg>L0`003G>L000jLi`30023
Li`60IooLiaVLi`3000=Li`003YcW0<008AcW0H1WomcW6EcW0<000ecW000>W>L0`00QG>L1P6Oog>L
I7>L0`003G>L000jLi`30026Li`60IooLiaSLi`3000=Li`003YcW0<008McW0H1WomcW69cW0<000ec
W000>W>L0`00R7>L1P6Oog>LHG>L0`003G>L000jLi`30029Li`60IooLiaPLi`3000=Li`003YcW0<0
08YcW0H1WomcW5mcW0<000ecW0005g>L00<007>LLi`087>L0`00Rg>L1P6Oog>LGW>L0`003G>L000F
Li`2000RLi`3002<Li`60IooLiaMLi`3000=Li`0011cW003001cW7>L00<00003Li`007>L025cW0<0
08ecW0L1WomcW5]cW0<000ecW00047>L0`000W>L00<007>LLi`08W>L0`00SW>L1`6Oog>LFW>L0`00
3G>L000@Li`30002Li`00`00LiacW00RLi`3002?Li`70IooLiaILi`3000=Li`001=cW0<00003Li`0
07>L025cW0<0095cW0H1WomcW5QcW0<000ecW0005W>L0P008W>L0`00TW>L1P6Oog>LEg>L0`003G>L
000GLi`00`00LiacW00PLi`3002CLi`60IooLiaFLi`3000=Li`003YcW0<009AcW0H1WomcW5EcW0<0
00ecW0004g>L10008g>L0`00UG>L1P6Oog>LE7>L0`003G>L000BLi`00`00LiacW002Li`00`00Liac
W00PLi`3002FLi`60IooLiaCLi`3000=Li`0019cW003001cW7>L009cW003001cW7>L021cW0<009Mc
W0H1WomcW59cW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`02W>L1@000g>L10002W>L0`00
V7>L1P6Oog>LDG>L0`003G>L000BLi`00`00LiacW002Li`00`00LiacW00<Li`00`00LiacW002Li`0
0`00LiacW002Li`00`00LiacW007Li`3002ILi`60IooLia@Li`3000=Li`0019cW080009cW003001c
W7>L00ecW003001cW7>L009cW003001cW7>L009cW003001cW7>L00McW0D009P03`H1Wol03dl03`<0
00ecW0009W>L00<007>LLi`00W>L00<007>LLi`00W>L00<007>LLi`01g>L0`00Vg>L1P6Oog>LCW>L
0`003G>L000VLi`00`00LiacW002Li`00`00LiacW002Li`00`00LiacW007Li`3002LLi`60IooLia=
Li`3000=Li`0019cW003001cW7>L015cW003001cW7>L009cW003001cW7>L009cW003001cW7>L00Mc
W0<009ecW0H1WomcW4acW0<000ecW00047>L1`003g>L00<007>LLi`00W>L00<007>LLi`00W>L00<0
07>LLi`01g>L0`00WW>L1`6Oog>LBW>L0`003G>L000BLi`00`00LiacW002Li`00`00LiacW00:Li`3
0004Li`00`00LiacW002Li`00`00LiacW007Li`3002OLi`70IooLia9Li`3000=Li`0019cW003001c
W7>L009cW003001cW7>L00acW003001cW7>L00=cW0@000YcW0<00:1cW0L1WomcW4QcW0<000ecW000
4W>L00<007>LLi`00W>L00<007>LLi`087>L0`00XW>L1P6Oog>LAg>L0`003G>L000BLi`01@00Liac
W7>L00008g>L0`00Xg>L1P6Oog>LAW>L0`003G>L000jLi`3002TLi`60IooLia5Li`3000=Li`003Yc
W0<00:EcW0H1WomcW4AcW0<000ecW0005g>L00<007>LLi`087>L0`00YW>L1P6Oog>L@g>L0`003G>L
000BLi`00`00LiacW002Li`00`00LiacW00PLi`3002WLi`60IooLia2Li`3000=Li`0019cW003001c
W7>L009cW003001cW7>L021cW0<00:QcW0H1WomcW45cW0<000ecW00047>L00<007>L00001@008W>L
0`00ZG>L1P6Oog>L@7>L0`003G>L000GLi`00`00LiacW00PLi`3002ZLi`60IooLi`oLi`3000=Li`0
01McW003001cW7>L021cW0<00:]cW0H1WomcW3icW0<000ecW0005g>L00<007>LLi`087>L0`00[7>L
1P6Oog>L?G>L0`003G>L000BLi`00`00LiacW00ULi`3002]Li`60IooLi`lLi`3000=Li`0019cW080
02IcW0<00:icW0H1WomcW3]cW0<000ecW0004W>L00@007>L000002AcW0<00:mcW0L1WomcW3UcW0<0
00ecW0005W>L0P008W>L0`00/7>L1`6Oog>L>7>L0`003G>L000FLi`2000RLi`3002aLi`70IooLi`g
Li`3000=Li`0019cW004001cW000000TLi`3002cLi`60IooLi`fLi`3000=Li`0019cW08002IcW0<0
0;AcW0H1WomcW3EcW0<000ecW0004W>L00<007>LLi`09G>L0`00]G>L1P6Oog>L=7>L0`003G>L000j
Li`3002fLi`60IooLi`cLi`3000=Li`001McW003001cW7>L021cW0<00;McW0H1WomcW39cW0<000ec
W0004W>L00<007>LLi`00W>L00<007>LLi`087>L0`00^7>L1P6Oog>L<G>L0`003G>L000BLi`00`00
LiacW002Li`00`00LiacW00PLi`3002iLi`60IooLi``Li`3000=Li`0011cW003001cW00000D0029c
W0<00;YcW0H1WomcW2mcW0<000ecW0005g>L00<007>LLi`087>L0`00^g>L1P6Oog>L;W>L0`003G>L
000GLi`00`00LiacW00PLi`3002lLi`60IooLi`]Li`3000=Li`001McW003001cW7>L021cW0<00;ec
W0H1WomcW2acW0<000ecW000>W>L0`00_W>L1P6Oog>L:g>L0`003G>L000BLi`00`00LiacW00ULi`3
002oLi`70IooLi`YLi`3000=Li`0011cW0L002=cW0<00<1cW0L1WomcW2QcW0<000ecW0004W>L00<0
07>LLi`00W>L00<007>LLi`087>L0`00`G>L1`6Oog>L9g>L0`003G>L000BLi`00`00LiacW002Li`0
0`00LiacW00PLi`30033Li`60IooLi`VLi`3000=Li`0019cW003001cW7>L009cW003001cW7>L021c
W0<00<AcW0H1WomcW2EcW0<000ecW0004W>L00D007>LLiacW00002=cW0<00<EcW0H1WomcW2AcW0<0
00ecW000>W>L0`00aW>L1P6Oog>L8g>L0`003G>L000jLi`30037Li`60IooLi`RLi`3000=Li`0019c
W003001cW7>L02EcW0<00<QcW0H1WomcW25cW0<000ecW0004W>L0`001G>L00<007>LLi`07G>L0`00
bG>L1P6Oog>L87>L0`003G>L000BLi`00`00LiacW0020002Li`2000OLi`3003:Li`60IooLi`OLi`3
000=Li`001McW0800003Li`007>L01icW0<00<]cW0H1WomcW1icW0<000ecW0004W>L00<007>LLi`0
0P008g>L0`00c7>L1P6Oog>L7G>L0`003G>L000BLi`3000ULi`3003=Li`60IooLi`LLi`3000=Li`0
019cW003001cW7>L02EcW0<00<icW0H1WomcW1]cW0<000ecW000>W>L0`00cg>L1P6Oog>L6W>L0`00
3G>L000jLi`3003@Li`70IooLi`HLi`3000=Li`003YcW0<00=5cW0L1WomcW1McW0<000ecW000>W>L
0`00dW>L1`6Oog>L5W>L0`003G>L000jLi`3003DLi`60IooLi`ELi`3000=Li`003YcW0<00=EcW0H1
WomcW1AcW0<000ecW000>W>L0`00eW>L1P6Oog>L4g>L0`003G>L000jLi`3003GLi`60IooLi`BLi`3
000=Li`003YcW0<00=QcW0H1WomcW15cW0<000ecW000>W>L0`00fG>L1P6Oog>L47>L0`003G>L000j
Li`3003JLi`60IooLi`?Li`3000=Li`003YcW0<00=]cW0H1WomcW0icW0<000ecW0004W>L00<007>L
Li`01G>L00<007>LLi`07G>L0`00g7>L1P6Oog>L3G>L0`003G>L000BLi`9000OLi`3003MLi`60Ioo
Li`<Li`3000=Li`0019cW005001cW7>LLi`00003Li`00`00LiacW006Li`50004Li`4000:Li`3003N
Li`60IooLi`;Li`3000=Li`0019cW003001cW7>L009cW003001cW7>L00UcW005001cW7>LLi`00003
Li`00`00LiacW002Li`00`00LiacW007Li`3003OLi`60In8Li`20ImoLi`3000=Li`0019cW003001c
W7>L009cW003001cW7>L00YcW003001cW7>L00AcW003001cW7>L009cW003001cW7>L00McW0<00>1c
W0H1Wh1cW0T1WgmcW0<000ecW0004g>L10003W>L00<007>LLi`00g>L00<007>LLi`00W>L00<007>L
Li`01g>L1@00g`0?1`6OM`0?4@6OOP0?0`003G>L000VLi`00`00LiacW002Li`00`00LiacW002Li`0
0`00LiacW007Li`3003RLi`70Im_Li`I0ImbLi`2O1<9Li`3000=Li`002IcW003001cW7>L009cW003
001cW7>L009cW003001cW7>L00McW0<00>=cW0L1WfMcW241Wf]cW0Ql4`UcW0<000ecW0004g>L1000
47>L00D007>LLiacW00000AcW003001cW7>L00McW0<00>EcW0H1WemcW1d1W`IcW0H1WfAcW0ml4`Qc
W0<000ecW0004W>L00<007>L00000W>L00<007>LLi`02G>L00D007>LLiacW00000=cW003001cW7>L
009cW003001cW7>L00McW0<00>IcW0H1WeMcW1d1W`icW0H1WeecW1El4`QcW0<000ecW0004W>L00<0
07>L00000W>L00<007>LLi`02W>L0`001G>L10002W>L0`00ig>L1P6OCg>L7@6O5W>L1P6OEg>L67`C
2W>L0`003G>L000BLi`00`00Li`00002Li`00`00LiacW00PLi`3003XLi`60Im7Li`M0IlNLi`60Im@
Li`HO1<@Li`3000=Li`0019cW003001cW000009cW003001cW7>L021cW0<00>UcW0H1WcmcW1d1WbIc
W0D1WdYcW1Ql4aIcW0<000ecW0004g>L0P000W>L00<007>LLi`087>L0`00jW>L1P6O=g>L7@6O;W>L
1@6O@g>L67`C77>L0`003G>L000jLi`3003[Li`60Il_Li`M0IlfLi`50IllLi`IO1<QLi`3000=Li`0
03YcW0<00>acW0H1WbMcW1d1WcecW0H1WcEcW1Ul4bMcW0<000ecW0004W>L00<007>LLi`00W>L00<0
07>LLi`087>L0`00kG>L1P6O7g>L7@6OAG>L1P6O;W>L6G`C;G>L0`003G>L000BLi`6000RLi`3003^
Li`60IlGLi`M0Im=Li`60IlWLi`IO1<cLi`3000=Li`001=cW005001cW7>LLi`0000RLi`3003_Li`6
0Il?Li`M0ImELi`60IlPLi`IO1<iLi`3000=Li`0019cW003001cW7>L009cW003001cW7>L021cW0<0
0?1cW0H1W`McW1d1WeecW0H1WaUcW1Ul4cmcW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`0
87>L0`00lG>L8P6OIG>L1@6O4g>L6G`CAG>L0`003G>L000BLi`00`00LiacW00ULi`3003bLi`J0Im]
Li`50Il=Li`HO1=;Li`3000=Li`003YcW0<00?=cW181WgEcW0D1W`IcW1Ql4e5cW0<000ecW000>W>L
0`00m7>L2P6OO7>L1@6O67`CEg>L0`003G>L000jLi`3003fLi`00`6OLiacW020Li`HO1=MLi`3000=
Li`003YcW0<00?mcW7AcW1Ul4f9cW0<000ecW000>W>L0`00og>LKW>L6G`CJ7>L0`003G>L000jLi`3
003oLiaWLi`JO1<40ImZLi`3000=Li`003YcW0<00?mcW65cW1Yl4`EcW0D1WfYcW0<000ecW000>W>L
0`00og>LFW>L6g`C37>L1@6OJG>L0`003G>L000jLi`3003oLiaDLi`KO1<CLi`50ImXLi`3000=Li`0
03YcW0<00?mcW4ecW1]l4aYcW0H1WfMcW0<000ecW000>W>L0`00og>LAW>L77`C8G>L1P6OIW>L0`00
3G>L000jLi`3003oLia0Li`KO1<YLi`60ImULi`3000=Li`0011cW0<002McW0<00?mcW3UcW1al4c1c
W0H1WfAcW0<000ecW00047>L00<007>LLi`017>L00<007>LLi`087>L0`00og>L<W>L77`C>7>L1P6O
Hg>L0`003G>L000@Li`00`00LiacW004Li`00`00LiacW00PLi`3003oLi`/Li`KO1=0Li`50ImSLi`3
000=Li`0011cW0P0029cW0<00?mcW2EcW1al4dMcW0D1Wf9cW0<000ecW00047>L00<007>LLi`017>L
00<007>LLi`087>L0`00og>L7g>L6g`CCg>L1@6OHG>L0`003G>L000@Li`00`00LiacW004Li`00`00
LiacW00PLi`3003oLi`HLi`KO1=FLi`60ImPLi`3000=Li`0011cW0<002McW0<00?mcW15cW1al4eec
W0H1WemcW0<000ecW000>W>L0`00og>L2g>L6g`CIG>L1P6OGW>L0`003G>L000GLi`00`00LiacW00P
Li`3003oLi`4Li`LO1=/Li`60ImMLi`3000=Li`0019cW003001cW7>L009cW003001cW7>L021cW0<0
0?ecW1]l4gAcW0H1WeacW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`087>L0`00mW>L6g`C
O7>L1@6OG7>L0`003G>L000@Li`00`00Li`00005000RLi`3003dLi`GO1>3Li`50ImKLi`3000=Li`0
01McW003001cW7>L021cW0<00?=cW15l4h]cW0D1WeYcW0<000ecW0005g>L00<007>LLi`087>L0`00
lW>L37`CTG>L1P6OFG>L0`003G>L000GLi`00`00LiacW00PLi`3003aLi`6O1>ILi`60ImHLi`3000=
Li`0019cW003001cW7>L009cW003001cW7>L021cW0<00?1cW0Il4i]cW0H1WeMcW0<000ecW0004W>L
1P008W>L0`00kg>L1W`CWG>L1P6OEW>L0`003G>L000BLi`00`00LiacW002Li`00`00LiacW00PLi`3
003^Li`6O1>OLi`60ImELi`3000=Li`0019cW003001cW7>L02EcW0<00>ecW0Il4j5cW0D1WeEcW0<0
00ecW0004g>L1@008W>L0`00k7>L1W`CXg>L1@6OE7>L0`003G>L000CLi`01@00LiacW7>L00008W>L
0`00jg>L1W`CYG>L1@6ODg>L0`003G>L000BLi`00`00LiacW00ULi`3003ZLi`6O1>VLi`60ImBLi`3
000=Li`001=cW0D0029cW0<00>UcW0Il4jQcW0H1We5cW0<000ecW000>W>L0`00j7>L1W`CZW>L1P6O
D7>L0`003G>L000CLi`4000SLi`3003WLi`6O1>/Li`60Im?Li`3000=Li`0019cW003001cW000009c
W003001cW7>L021cW0<00>IcW0Il4jicW0H1WdicW0<000ecW0004W>L00<007>L00000W>L00<007>L
Li`087>L0`00iG>L1W`C/7>L1@6OCW>L0`003G>L000BLi`00`00Li`00002Li`00`00LiacW00PLi`3
003TLi`6O1>bLi`50Im=Li`3000=Li`0019cW003001cW000009cW003001cW7>L021cW0<00>=cW0Il
4kAcW0D1WdacW0<000ecW0004g>L0P000W>L00<007>LLi`087>L0`00hW>L1W`C]G>L1P6OBg>L0`00
3G>L000jLi`3003QLi`6O1>gLi`60Im:Li`3000=Li`003YcW0<00>1cW0Il4kUcW0H1WdUcW0<000ec
W0004G>L0P000g>L0P008W>L0`00gg>L1W`C^g>L1P6OB7>L0`003G>L000@Li`01000LiacW0000W>L
00<007>LLi`08G>L0`00gW>L1W`C_G>L1P6OAg>L0`003G>L000@Li`01000LiacW0000g>L00<007>L
Li`02W>L0`001G>L10002W>L0`00g7>L1g`C_g>L1@6OAg>L0`003G>L000@Li`01000LiacW0000g>L
00<007>LLi`02G>L00D007>LLiacW00000=cW003001cW7>L009cW003001cW7>L00McW0<00=]cW0Ml
4l5cW0D1WdIcW0<000ecW00047>L00@007>LLi`000=cW003001cW7>L00ecW005001cW7>LLi`00004
Li`00`00LiacW007Li`3003JLi`7O1?3Li`50Im5Li`3000=Li`0011cW080009cW0<0011cW005001c
W7>LLi`00004Li`00`00LiacW007Li`5003G00l6O1?500l60Im400l3000=Li`002EcW08000AcW003
001cW7>L009cW003001cW7>L00McW0<00=QcW0Il4lMcW0H1Wd=cW0<000ecW0009g>L00D007>LLiac
W00000AcW003001cW7>L00McW0<00=McW0Il4lUcW0H1Wd9cW0<000ecW0005g>L00<007>LLi`03G>L
00D007>LLiacW00000AcW003001cW7>L00McW0<00=IcW0Il4l]cW0H1Wd5cW0<000ecW0005g>L00<0
07>LLi`02G>L00D007>LLiacW00000=cW003001cW7>L009cW003001cW7>L00McW0<00=EcW0Il4lec
W0D1Wd5cW0<000ecW0003g>L00<007>LLi`01G>L00<007>LLi`02W>L0`001G>L10002W>L0`00e7>L
1W`Ccg>L1@6O@7>L0`003G>L000?Li`9000RLi`3003CLi`6O1?ALi`50IloLi`3000=Li`001McW003
001cW7>L021cW0<00=9cW0Il4m9cW0H1WcicW0<000ecW0005g>L00<007>LLi`087>L0`00dG>L1W`C
e7>L1P6O?G>L0`003G>L000GLi`00`00LiacW00PLi`3003@Li`6O1?FLi`60IllLi`3000=Li`003Yc
W0<00<mcW0Il4mQcW0H1Wc]cW0<000ecW0005g>L00<007>LLi`087>L0`00cW>L1W`CfW>L1P6O>W>L
0`003G>L000BLi`00`00LiacW002Li`00`00LiacW00PLi`3003=Li`6O1?LLi`50IljLi`3000=Li`0
019cW003001cW7>L009cW003001cW7>L021cW0<00<acW0Il4micW0D1WcUcW0<000ecW00047>L00<0
07>L00001@008W>L0`00bg>L1W`Ch7>L1@6O>7>L0`003G>L000GLi`00`00LiacW00PLi`3003:Li`6
O1?QLi`60IlgLi`3000=Li`001McW003001cW7>L021cW0<00<UcW0Il4n=cW0H1WcIcW0<000ecW000
5g>L00<007>LLi`087>L0`00b7>L1W`CiG>L1P6O=G>L0`003G>L000jLi`30037Li`6O1?WLi`60Ild
Li`3000=Li`001=cW0@002=cW0<00<EcW0Ml4nUcW0H1Wc=cW0<000ecW0004W>L00<007>LLi`00W>L
00<007>LLi`087>L0`00a7>L1g`Cjg>L1@6O<g>L0`003G>L000BLi`00`00LiacW002Li`00`00Liac
W00PLi`30033Li`7O1?]Li`50IlbLi`3000=Li`0019cW003001cW7>L009cW003001cW7>L021cW0<0
0<9cW0Il4o1cW0D1Wc5cW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`087>L0`00`G>L1W`C
lG>L1P6O<7>L0`003G>L000BLi`20002Li`00`00LiacW00QLi`30030Li`6O1?cLi`60Il_Li`3000=
Li`003YcW0<00;mcW0Il4oEcW0H1WbicW0<000ecW000>W>L0`00_W>L1W`Cmg>L1P6O;G>L0`003G>L
000CLi`4000SLi`3002mLi`6O1?iLi`60Il/Li`3000=Li`0019cW003001cW000009cW003001cW7>L
021cW0<00;acW0Il4o]cW0D1WbacW0<000ecW0004W>L00<007>L00000W>L00<007>LLi`087>L0`00
^g>L1W`CoG>L1@6O:g>L0`003G>L000BLi`00`00Li`00002Li`00`00LiacW00PLi`3002jLi`6O1?o
Li`50IlZLi`3000=Li`0019cW003001cW000009cW003001cW7>L021cW0<00;UcW0Il4omcW05cW0H1
WbUcW0<000ecW0004g>L0P000W>L00<007>LLi`087>L0`00^7>L1W`Cog>L0g>L1P6O:7>L0`003G>L
000jLi`3002gLi`6O1?oLi`5Li`60IlWLi`3000=Li`003YcW0<00;IcW0Il4omcW0McW0H1WbIcW0<0
00ecW000>W>L0`00]G>L1W`Cog>L2G>L1P6O9G>L0`003G>L000jLi`3002dLi`6O1?oLi`;Li`50IlU
Li`3000=Li`003YcW0<00;=cW0Il4omcW0ecW0D1WbAcW0<000ecW000>W>L0`00/W>L1W`Cog>L3g>L
1@6O8g>L0`003G>L000jLi`3002aLi`6O1?oLi`@Li`60IlRLi`3000=Li`003YcW0<00;1cW0Il4omc
W19cW0H1Wb5cW0<000ecW000>W>L0`00[g>L1W`Cog>L57>L1P6O87>L0`003G>L000jLi`3002]Li`7
O1?oLi`FLi`60IlOLi`3000=Li`003YcW0<00:acW0Ml4omcW1QcW0H1WaicW0<000ecW000>W>L0`00
Zg>L1g`Cog>L6W>L1@6O7W>L0`003G>L000jLi`3002ZLi`6O1?oLi`MLi`50IlMLi`3000=Li`003Yc
W0<00:UcW0Il4omcW1mcW0D1WaacW0<000ecW000>W>L0`00Z7>L1W`Cog>L87>L1P6O6g>L0`003G>L
000jLi`3002WLi`6O1?oLi`RLi`60IlJLi`3000=Li`003YcW0<00:IcW0Il4omcW2AcW0H1WaUcW0<0
00ecW0004W>L1P008W>L0`00YG>L1W`Cog>L9W>L1P6O67>L0`003G>L000@Li`20006Li`2000PLi`3
002TLi`6O1?oLi`XLi`60IlGLi`3000=Li`000mcW003001cW7>L00QcW003001cW7>L01ecW0<00:=c
W0Il4omcW2YcW0D1WaMcW0<000ecW000>W>L0`00XW>L1W`Cog>L;7>L1@6O5W>L0`003G>L000BLi`0
0`00LiacW002Li`00`00LiacW00PLi`3002QLi`6O1?oLi`^Li`50IlELi`3000=Li`0019cW0H0029c
W0<00:1cW0Il4omcW2mcW0H1WaAcW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`087>L0`00
Wg>L1W`Cog>L<G>L1P6O4g>L0`003G>L000BLi`00`00LiacW00ULi`3002NLi`6O1?oLi`cLi`60IlB
Li`3000=Li`001=cW0D0029cW0<009ecW0Il4omcW3EcW0H1Wa5cW0<000ecW0004g>L00D007>LLiac
W000029cW0<009acW0Il4omcW3McW0H1Wa1cW0<000ecW0004W>L00<007>LLi`09G>L0`00Vg>L1W`C
og>L>G>L1@6O47>L0`003G>L000CLi`5000RLi`3002JLi`6O1?oLi`kLi`50Il?Li`3000=Li`003Yc
W0<009UcW0Il4omcW3ecW0D1W`icW0<000ecW0004g>L10003g>L0`000g>L10002W>L0`00V7>L1W`C
og>L?W>L1P6O3G>L0`003G>L000BLi`00`00Li`00002Li`00`00LiacW00=Li`01@00LiacW7>L0000
17>L00<007>LLi`01g>L0`00UW>L1g`Cog>L@7>L1P6O37>L0`003G>L000BLi`00`00Li`00002Li`0
0`00LiacW00=Li`01@00LiacW7>L000017>L00<007>LLi`01g>L0`00UG>L1g`Cog>L@W>L1P6O2g>L
0`003G>L000BLi`00`00Li`00002Li`00`00LiacW009Li`60002Li`00`00LiacW002Li`00`00Liac
W007Li`5002B00l7O1?o00m400l60Il:00l3000=Li`0019cW003001cW000009cW003001cW7>L00Yc
W004001cW7>L0003Li`00`00LiacW002Li`00`00LiacW007Li`3002CLi`6O1?oLia7Li`60Il9Li`3
000=Li`001=cW080009cW003001cW7>L00YcW004001cW7>L0003Li`00`00LiacW002Li`00`00Liac
W007Li`3002BLi`6O1?oLia9Li`50Il9Li`3000=Li`002EcW003001cW00000=cW003001cW7>L009c
W003001cW7>L00McW0<0095cW0Il4omcW4]cW0D1W`QcW0<000ecW0009G>L00<007>L00000g>L00<0
07>LLi`00W>L00<007>LLi`01g>L0`00T7>L1W`Cog>LCG>L0`6O2G>L0`003G>L000BLi`00`00Liac
W00ALi`20004Li`4000:Li`3002?Li`6O1?oLia>Li`20Il:Li`3000=Li`0011cW0L002=cW0<008ic
W0Il4omcW5]cW0<000ecW0004W>L00<007>LLi`00W>L00<007>LLi`087>L0`00SG>L1W`Cog>LG7>L
0`003G>L000BLi`00`00LiacW002Li`00`00LiacW00PLi`3002<Li`6O1?oLiaMLi`3000=Li`0019c
W003001cW7>L009cW003001cW7>L021cW0<008]cW0Il4omcW5icW0<000ecW0004W>L00D007>LLiac
W00002=cW0<008YcW0Il4omcW5mcW0<000ecW000>W>L0`00RG>L1W`Cog>LH7>L0`003G>L000jLi`3
0028Li`6O1?oLiaQLi`3000=Li`001=cW0@002=cW0<008McW0Il4omcW69cW0<000ecW0004W>L00<0
07>L00000W>L00<007>LLi`087>L0`00QW>L1W`Cog>LHg>L0`003G>L000BLi`00`00Li`00002Li`0
0`00LiacW00PLi`30025Li`6O1?oLiaTLi`3000=Li`0019cW003001cW000009cW003001cW7>L021c
W0<008AcW0Il4omcW6EcW0<000ecW0004W>L00<007>L00000W>L00<007>LLi`087>L0`00Pg>L1W`C
og>LIW>L0`003G>L000CLi`20002Li`00`00LiacW00PLi`30022Li`6O1?oLiaWLi`3000=Li`003Yc
W0<0085cW0Il4omcW6QcW0<000ecW000>W>L0`00P7>L1W`Cog>LJG>L0`003G>L000BLi`00`00Liac
W002Li`00`00LiacW00PLi`3001mLi`8O1?oLiaZLi`3000=Li`0019cW0H0029cW0<007YcW0Yl4omc
W6]cW0<000ecW0004g>L00D007>LLiacW000029cW0<007McW0al4omcW6acW0<000ecW0004W>L00<0
07>LLi`00W>L00<007>LLi`087>L0`00M7>L3G`Cog>LKW>L0`003G>L000BLi`00`00LiacW002Li`0
0`00LiacW00PLi`3001aLi`=O1?oLiaaLi`3000=Li`0019cW003001cW7>L02EcW0<006icW0el4omc
W7AcW0<000ecW000>W>L0`00Jg>L3G`Cog>LMg>L0`003G>L000jLi`3001XLi`=O1?oLiajLi`3000=
Li`001=cW003001cW7>L0080029cW0<006EcW0el4omcW7ecW0<000ecW0004W>L00D007>L001cW000
02=cW0<0069cW0el4omcW81cW0<000ecW0004W>L00<007>L00000W>L00<007>LLi`087>L0`00H7>L
37`Cog>LPg>L0`003G>L000BLi`00`00Li`00002Li`00`00LiacW00PLi`3001MLi`<O1?oLib6Li`3
000=Li`0019cW003001cW000009cW003001cW7>L021cW0<005YcW0al4omcW8UcW0<000ecW0004W>L
0P0000=cW00000008g>L0`00Eg>L37`Cog>LS7>L0`003G>L000jLi`3001DLi`=O1?oLib>Li`3000=
Li`003YcW0<0055cW0el4omcW95cW0<000ecW000>W>L0`00CW>L3G`Cog>LU7>L0`003G>L000jLi`3
001;Li`=O1?oLibGLi`3000=Li`000mcW003001cW7>L00QcW003001cW7>L01ecW0<004QcW0el4omc
W9YcW0<000ecW00047>L0P001W>L0P0087>L0`00AG>L3G`Cog>LWG>L0`003G>L000BLi`6000RLi`3
0012Li`=O1?oLibPLi`3000=Li`003YcW0<003mcW0el4omcW:=cW0<000ecW000>W>L0`00?7>L3G`C
og>LYW>L0`003G>L000jLi`3000iLi`=O1?oLibYLi`3000=Li`003YcW0<003IcW0el4omcW:acW0<0
00ecW000>W>L0`00<g>L3G`Cog>L[g>L0`003G>L000jLi`3000`Li`=O1?oLibbLi`3000=Li`003Yc
W0<002ecW0el4omcW;EcW0<000ecW000>W>L0`00:W>L3G`Cog>L^7>L0`003G>L000jLi`3000WLi`=
O1?oLibkLi`3000=Li`003YcW0<002EcW0al4omcW;icW0<000ecW000>W>L0`008W>L37`Cog>L`G>L
0`003G>L000jLi`3000OLi`<O1?oLic4Li`3000=Li`003YcW0<001acW0al4omcW<McW0<000ecW000
>W>L0`006G>L3G`Cog>LbG>L0`003G>L000jLi`3000FLi`=O1?oLic<Li`3000=Li`003YcW0<001=c
W0el4omcW<mcW0<000ecW000>W>L0`0047>L3G`Cog>LdW>L0`003G>L000jLi`3000=Li`=O1?oLicE
Li`3000=Li`003YcW0<000YcW0el4omcW=QcW0<000ecW000>W>L0`0027>L37`Cog>Lfg>L0`003G>L
000jLi`30008Li`9O1?oLicNLi`3000=Li`002AcW0@000AcW0@000YcW0<000UcW0El4omcW>5cW0<0
00ecW0008g>L00<007>LLi`00W>L00@007>LLi`000AcW003001cW7>L00McW0<000UcW09l4omcW>Ac
W0<000ecW000:7>L00@007>LLi`000AcW003001cW7>L00McW0<00?mcW>mcW0<000ecW000:7>L00@0
07>LLi`000AcW003001cW7>L00McW0D00?mcW>ecW0<000ecW000:7>L00@007>LLi`000AcW003001c
W7>L00McW0<00?mcW>mcW0<000ecW00097>L10000g>L00<007>LLi`00W>L00<007>LLi`01g>Lo`00
m@003G>L000TLi`00`00LiacW004Li`00`00LiacW002Li`00`00LiacW007Lico003e000=Li`002Ac
W003001cW7>L00AcW003001cW7>L009cW003001cW7>L00McW?l00?D000ecW00097>L1@000g>L1000
og>Log>L3G>L003oLicoLi`mLi`00?mcW?mcW3ecW000og>Log>L?G>L0000\
\>"],
  ImageRangeCache->{{{0, 570.875}, {352.438, 0}} -> {0.396543, -1.98854, \
0.0084543, 0.151145}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(UnLoad[c57files[\([1]\)]]\)], "Input"],

Cell["\<\
As illustrated, while in Balb there is a gradual build up in Activity, in c57 \
there is a gradual shut down in Activity.\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
The idea of looking at time slices is not limited to numerical computations. \
We can also produce sequences of graphs: each graph represents the activity \
during five minutes without the residue interval.\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Script[{"\<Show[GraphicsArray[Partition[Map[See[PathPlot[{#[[1]],#[[2]]}\
],DisplayFunction->Identity]&,TimeSlice[{1,(300*25*5)},7500]],5]]]\>"}, 
      twofiles]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .18519 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00440917 0.190476 [
[ 0 0 0 0 ]
[ 1 .18519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .18519 L
0 .18519 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00440917 0.200176 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.09259 .43598 m
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09257 .43598 L
.09254 .43598 L
.09249 .43598 L
.09245 .43598 L
.09241 .43594 L
.09239 .43588 L
.0924 .43577 L
.09244 .43564 L
.09254 .43551 L
.09271 .43543 L
.09296 .43543 L
.0933 .43559 L
.09376 .43595 L
.09432 .43654 L
.09498 .43735 L
.09573 .4384 L
.09654 .43965 L
.09737 .44085 L
.09822 .44231 L
.09907 .44396 L
.0999 .44549 L
.10069 .44709 L
.10143 .44886 L
.10207 .45038 L
.10264 .45188 L
.10312 .45334 L
.10352 .45475 L
.10386 .4561 L
.10417 .45736 L
.10449 .45866 L
.10487 .46006 L
.10531 .46159 L
.10582 .46326 L
.10642 .46489 L
.10708 .46656 L
.10777 .46829 L
.10855 .46996 L
.10937 .47148 L
.11022 .47288 L
.11112 .47414 L
.112 .47522 L
.1129 .47619 L
.11377 .47703 L
Mistroke
.11459 .47774 L
.11538 .47834 L
.11615 .4789 L
.11695 .47946 L
.11779 .48005 L
.11873 .48067 L
.11976 .48136 L
.12081 .48206 L
.12194 .48281 L
.12309 .48359 L
.1243 .48439 L
.12554 .48519 L
.12687 .48595 L
.12818 .48664 L
.12958 .48725 L
.13093 .48777 L
.13232 .48822 L
.13371 .48861 L
.13501 .48897 L
.13634 .48931 L
.13775 .48966 L
.13918 .49007 L
.14074 .49054 L
.14235 .4911 L
.14411 .49177 L
.14586 .49255 L
.14764 .49339 L
.14943 .49426 L
.15117 .49514 L
.15278 .49597 L
.15431 .4967 L
.15573 .49731 L
.15695 .49785 L
.15807 .49835 L
.15902 .49879 L
.15977 .49917 L
.16034 .49951 L
.16076 .49988 L
.16108 .50034 L
.16136 .50094 L
.16162 .50169 L
.16191 .50262 L
.16224 .50374 L
.16266 .50502 L
.16317 .5066 L
.16374 .50852 L
.16438 .51076 L
.16505 .51288 L
.16577 .51547 L
.16651 .5178 L
Mistroke
.16721 .52037 L
.1679 .52309 L
.16856 .52535 L
.1692 .52791 L
.16983 .53017 L
.17046 .53263 L
.17108 .53479 L
.17166 .53702 L
.17222 .53923 L
.17277 .54142 L
.17331 .54361 L
.17384 .54596 L
.17436 .54811 L
.17487 .55047 L
.17535 .55272 L
.17578 .555 L
.17614 .55747 L
.17642 .55979 L
.17658 .56226 L
.17665 .56452 L
.17664 .56683 L
.17655 .569 L
.17638 .57095 L
.17614 .57293 L
.17583 .57494 L
.17545 .57685 L
.17499 .57874 L
.17444 .58076 L
.1738 .58279 L
.17309 .58476 L
.17235 .58677 L
.17162 .5887 L
.17097 .59025 L
.17034 .59177 L
.16975 .5932 L
.16924 .59438 L
.16877 .59537 L
.16836 .59616 L
.16803 .59675 L
.16778 .59714 L
.16763 .59735 L
.16759 .59743 L
.16764 .59741 L
.16774 .59735 L
.16785 .59727 L
.16794 .5972 L
.16797 .5971 L
.16795 .59696 L
.16787 .59676 L
.16776 .59648 L
Mistroke
.16766 .59612 L
.16756 .5957 L
.16744 .59525 L
.16724 .59479 L
.16697 .59433 L
.16662 .59385 L
.16617 .59336 L
.16563 .59287 L
.16498 .59239 L
.16418 .59196 L
.16321 .59158 L
.16209 .59127 L
.16086 .59106 L
.1596 .59093 L
.1582 .59088 L
.15657 .59082 L
.15474 .5907 L
.1531 .59049 L
.15128 .59018 L
.14924 .58983 L
.14755 .58947 L
.14589 .58913 L
.14416 .58884 L
.14233 .58861 L
.14046 .58848 L
.13881 .58842 L
.13715 .58843 L
.13542 .58848 L
.13359 .58861 L
.13167 .58883 L
.12995 .5892 L
.1281 .58972 L
.12604 .59038 L
.12385 .59116 L
.12196 .59202 L
.12002 .59293 L
.11794 .59386 L
.11595 .59475 L
.11402 .59561 L
.11193 .59646 L
.11019 .59737 L
.1084 .59837 L
.10657 .59946 L
.1048 .60059 L
.10331 .60171 L
.10195 .60281 L
.10064 .60398 L
.0994 .60524 L
.09824 .6066 L
.09721 .60804 L
Mistroke
.09631 .60947 L
.09549 .61095 L
.09477 .61248 L
.09415 .61407 L
.0936 .61572 L
.09309 .61725 L
.09261 .6191 L
.09211 .62081 L
.09163 .62259 L
.09118 .62443 L
.09078 .62634 L
.09043 .62832 L
.09015 .63032 L
.08998 .63215 L
.08992 .63389 L
.08998 .63559 L
.09015 .63729 L
.0904 .639 L
.09072 .64066 L
.09108 .64229 L
.09146 .64386 L
.09185 .64539 L
.09223 .64688 L
.09259 .64842 L
.0929 .65007 L
.09315 .6519 L
.09334 .65385 L
.09348 .65558 L
.09361 .65762 L
.09376 .65954 L
.09393 .66158 L
.09415 .66375 L
.09441 .66602 L
.09476 .66806 L
.09519 .67023 L
.09572 .67254 L
.09633 .67493 L
.09701 .67718 L
.09773 .67941 L
.09849 .68156 L
.09928 .68382 L
.10007 .68608 L
.10088 .68837 L
.10172 .69068 L
.10258 .69272 L
.10347 .69478 L
.10436 .69686 L
.10522 .69885 L
.10603 .70083 L
.10678 .70282 L
Mistroke
.10746 .70473 L
.10809 .70671 L
.10866 .70883 L
.1092 .71105 L
.10971 .71342 L
.1102 .71586 L
.11065 .71857 L
.11107 .72117 L
.11143 .72393 L
.11174 .72641 L
.11199 .72896 L
.1122 .73115 L
.11236 .73327 L
.11249 .73524 L
.11259 .73691 L
.11265 .73825 L
.11268 .73928 L
.11271 .73998 L
.11271 .74039 L
.11271 .74058 L
.11274 .74062 L
.11281 .74062 L
.11296 .74065 L
.1132 .74079 L
.11351 .74109 L
.1139 .74156 L
.11432 .74223 L
.11477 .74312 L
.11522 .74419 L
.11566 .7453 L
.11609 .74646 L
.1165 .74765 L
.11689 .74883 L
.11725 .74995 L
.11757 .75091 L
.11787 .7517 L
.11814 .75227 L
.11841 .75264 L
.11867 .75282 L
.11892 .75287 L
.11918 .75286 L
.11947 .75286 L
.11981 .75292 L
.12025 .75306 L
.12082 .7533 L
.12154 .75365 L
.12239 .75412 L
.12336 .75473 L
.12445 .75545 L
.12566 .75629 L
Mistroke
.12686 .75723 L
.12814 .75824 L
.12948 .7593 L
.13079 .76044 L
.13222 .76167 L
.1337 .76295 L
.13508 .76433 L
.13649 .76585 L
.13791 .76749 L
.13925 .76919 L
.14066 .77114 L
.14199 .77316 L
.14346 .77546 L
.14507 .77772 L
.14654 .77983 L
.1481 .7821 L
.1498 .78443 L
.15161 .7866 L
.15325 .78871 L
.15482 .79072 L
.15627 .7924 L
.15754 .79388 L
.15867 .79521 L
.15966 .79625 L
.16059 .79715 L
.16138 .79796 L
.16209 .7987 L
.16276 .79941 L
.16342 .80015 L
.16408 .8009 L
.16479 .80175 L
.16554 .8027 L
.16641 .80375 L
.16736 .80482 L
.16842 .80606 L
.16959 .80754 L
.17087 .80897 L
.17229 .8105 L
.17383 .81206 L
.17536 .81356 L
.17698 .81503 L
.17857 .81635 L
.18019 .81765 L
.18185 .81895 L
.1833 .82029 L
.18494 .82159 L
.18664 .82304 L
.18825 .82449 L
.19001 .82606 L
.19169 .82777 L
Mistroke
.19344 .82955 L
.19518 .83108 L
.19669 .83283 L
.19815 .83459 L
.19956 .83627 L
.201 .83803 L
.20246 .83973 L
.20382 .8413 L
.20518 .84276 L
.20647 .84401 L
.20756 .84502 L
.20856 .84588 L
.20944 .8466 L
.21025 .84721 L
.21102 .84775 L
.21175 .84824 L
.21247 .84871 L
.21319 .84918 L
.2139 .84966 L
.21463 .85021 L
.21536 .85083 L
.21607 .8515 L
.21681 .85225 L
.21758 .85305 L
.21837 .85387 L
.21917 .85467 L
.21997 .85544 L
.22069 .85613 L
.22139 .85673 L
.22201 .85723 L
.22256 .8576 L
.22306 .85785 L
.22351 .85798 L
.22394 .85803 L
.22434 .85803 L
.22471 .85804 L
.22504 .85807 L
.22537 .85815 L
.2257 .85835 L
.22609 .8587 L
.22655 .85922 L
.22709 .85992 L
.22768 .8607 L
.2283 .86162 L
.22895 .86265 L
.22964 .86367 L
.23038 .86473 L
.23118 .86581 L
.23205 .86685 L
.23297 .8678 L
Mistroke
.23395 .86863 L
.23504 .86935 L
.23618 .86992 L
.23744 .87034 L
.23887 .87064 L
.24037 .87086 L
.24199 .87102 L
.24378 .87115 L
.24569 .87126 L
.24781 .87141 L
.2497 .87162 L
.25181 .87192 L
.25415 .87235 L
.25616 .87289 L
.25828 .87353 L
.26035 .87423 L
.26249 .87502 L
.26435 .87596 L
.26629 .87704 L
.26818 .87827 L
.2701 .87952 L
.27189 .8809 L
.27366 .88236 L
.27547 .88389 L
.27734 .88549 L
.27917 .8869 L
.28103 .8884 L
.28305 .88988 L
.28484 .89124 L
.28675 .89261 L
.28871 .89399 L
.29075 .89515 L
.29272 .89625 L
.29471 .89729 L
.29683 .89824 L
.29876 .89912 L
.30083 .89996 L
.30289 .90077 L
.30512 .90154 L
.30723 .90229 L
.30949 .90303 L
.31177 .90378 L
.31404 .90453 L
.31641 .90527 L
.31843 .90596 L
.32072 .90665 L
.3228 .90735 L
.325 .90806 L
.3272 .90879 L
.32941 .90957 L
Mistroke
.33157 .91041 L
.33376 .91132 L
.33593 .91221 L
.33814 .91312 L
.34025 .91408 L
.34238 .91514 L
.34457 .91621 L
.34673 .91725 L
.34899 .91826 L
.35127 .9192 L
.35353 .92006 L
.35576 .92089 L
.35788 .92168 L
.36002 .92242 L
.362 .92313 L
.36403 .92382 L
.36606 .9245 L
.36809 .92512 L
.37008 .92568 L
.37218 .92617 L
.37417 .92659 L
.37616 .92694 L
.37815 .92723 L
.38017 .92745 L
.38236 .92761 L
.38436 .92774 L
.38654 .92786 L
.38871 .92802 L
.39095 .92824 L
.39307 .92855 L
.39524 .929 L
.39742 .92963 L
.3995 .93048 L
.40158 .93155 L
.40369 .93282 L
.40564 .93396 L
.40761 .93546 L
.40955 .93668 L
.41139 .93792 L
.41327 .93922 L
.41494 .94043 L
.41664 .94158 L
.41832 .94262 L
.42003 .94348 L
.42177 .94429 L
.42363 .94502 L
.42545 .9457 L
.42743 .94634 L
.42947 .94695 L
.43163 .94748 L
Mistroke
.43393 .94798 L
.43649 .94843 L
.43895 .94882 L
.44174 .94916 L
.44449 .94942 L
.44724 .94962 L
.45012 .94973 L
.45304 .94975 L
.45606 .94969 L
.45876 .94956 L
.4616 .94938 L
.46445 .94918 L
.46705 .94897 L
.46965 .94876 L
.47216 .94853 L
.47467 .94831 L
.47696 .9481 L
.47923 .94792 L
.48141 .94777 L
.48355 .94764 L
.48568 .9475 L
.48779 .94733 L
.48995 .94712 L
.49197 .94689 L
.49408 .94663 L
.49604 .94637 L
.49807 .94611 L
.50007 .94586 L
.50209 .94563 L
.50415 .94542 L
.50635 .94522 L
.50834 .94504 L
.51048 .94487 L
.51262 .94471 L
.5149 .94457 L
.51693 .94446 L
.51908 .94438 L
.52136 .94431 L
.52341 .94424 L
.5256 .94417 L
.52779 .94408 L
.52997 .94396 L
.53209 .9438 L
.53429 .9436 L
.53652 .94339 L
.53881 .94318 L
.54121 .94298 L
.54327 .94279 L
.54551 .9426 L
.54769 .94241 L
Mistroke
.54977 .94223 L
.55172 .94206 L
.55358 .94192 L
.55509 .94181 L
.55646 .94173 L
.55754 .94167 L
.5584 .94161 L
.55899 .94155 L
.55929 .94148 L
.55932 .94139 L
.55914 .94126 L
.55882 .94111 L
.55842 .94094 L
.55802 .94074 L
.55765 .94052 L
.55739 .9403 L
.55724 .94006 L
.55725 .93983 L
.55744 .93959 L
.55783 .93936 L
.55844 .93916 L
.5593 .93897 L
.5604 .93882 L
.56173 .93869 L
.56328 .93857 L
.56505 .93846 L
.56696 .93833 L
.5691 .93818 L
.57134 .938 L
.57361 .93779 L
.57605 .93758 L
.57855 .93735 L
.58124 .93713 L
.58359 .93691 L
.58604 .93669 L
.58859 .93649 L
.5906 .93629 L
.59256 .93612 L
.59439 .93596 L
.59602 .93582 L
.59734 .9357 L
.59836 .93562 L
.59907 .93556 L
.59953 .93554 L
.59979 .93558 L
.59992 .93564 L
.6 .9357 L
.60012 .93573 L
.60034 .93569 L
.6007 .93556 L
Mistroke
.60125 .93534 L
.60199 .935 L
.603 .93455 L
.60416 .93403 L
.60564 .93342 L
.60736 .93278 L
.60934 .93212 L
.61168 .93145 L
.61392 .93078 L
.61653 .93015 L
.6191 .92957 L
.62195 .92907 L
.62473 .92864 L
.62772 .92824 L
.63087 .92786 L
.6338 .92746 L
.63696 .92701 L
.64011 .92649 L
.64312 .92591 L
.64585 .92524 L
.64846 .92455 L
.65082 .92385 L
.6531 .9232 L
.65488 .92256 L
.65669 .92186 L
.65823 .92113 L
.65966 .9204 L
.66097 .91969 L
.66219 .91899 L
.66329 .91835 L
.66448 .91767 L
.66565 .91696 L
.66702 .91619 L
.66854 .91529 L
.67013 .91439 L
.67202 .91342 L
.67412 .91241 L
.67648 .91137 L
.67871 .91034 L
.68114 .90934 L
.68369 .90844 L
.68621 .90761 L
.68886 .90682 L
.69155 .90605 L
.69443 .9053 L
.69706 .90457 L
.69979 .90387 L
.70246 .90317 L
.70493 .90246 L
.7073 .90171 L
Mistroke
.70953 .9009 L
.7117 .90002 L
.71374 .89901 L
.71583 .89798 L
.71777 .89688 L
.71976 .89569 L
.72175 .8944 L
.72368 .89309 L
.72555 .89181 L
.7274 .89047 L
.729 .88915 L
.73055 .88795 L
.73198 .88685 L
.73318 .88588 L
.73425 .88506 L
.73508 .88437 L
.73573 .8838 L
.73617 .88336 L
.73642 .88307 L
.73649 .88291 L
.73646 .88285 L
.73639 .88285 L
.73636 .88287 L
.73643 .88287 L
.73664 .8828 L
.73702 .88263 L
.73759 .8823 L
.73836 .8818 L
.73934 .88115 L
.74054 .88035 L
.74187 .87945 L
.74344 .87841 L
.7451 .87724 L
.74698 .87595 L
.74902 .87458 L
.7512 .87311 L
.75343 .87161 L
.75574 .87015 L
.75809 .86864 L
.76049 .86708 L
.76279 .86558 L
.76513 .86406 L
.76759 .86244 L
.76985 .86081 L
.77224 .85909 L
.77472 .85739 L
.77708 .8557 L
.77952 .85393 L
.78198 .85221 L
.78445 .8505 L
Mistroke
.78698 .84875 L
.78942 .84707 L
.79189 .84548 L
.79444 .84385 L
.7968 .84231 L
.79926 .84074 L
.80188 .83919 L
.80408 .83771 L
.80644 .83617 L
.8087 .83459 L
.81096 .83303 L
.8133 .83142 L
.8156 .82969 L
.81787 .82799 L
.8206 .82614 L
.82285 .82439 L
.82532 .82252 L
.82797 .82063 L
.83092 .81881 L
.83335 .81696 L
.83615 .81519 L
.83912 .81337 L
.84167 .81176 L
.8444 .81012 L
.84709 .80847 L
.84985 .80681 L
.85219 .80516 L
.85457 .80338 L
.85679 .80155 L
.8589 .79958 L
.86074 .79773 L
.86251 .79569 L
.86415 .79361 L
.86566 .79144 L
.86711 .78919 L
.86848 .78684 L
.86977 .78431 L
.87102 .78213 L
.87219 .7798 L
.87331 .77751 L
.87434 .77519 L
.87529 .77322 L
.87617 .77112 L
.87703 .76908 L
.87782 .7672 L
.87866 .76525 L
.87946 .76323 L
.8803 .76117 L
.88119 .75886 L
.88213 .75655 L
Mistroke
.883 .75407 L
.88399 .75136 L
.88488 .74876 L
.88579 .74596 L
.88672 .74315 L
.88752 .74036 L
.88834 .73795 L
.88901 .73573 L
.88958 .73379 L
.89002 .73243 L
.89033 .73142 L
.8905 .73079 L
.89054 .73049 L
.8905 .73051 L
.89042 .73078 L
.89031 .73121 L
.8902 .73169 L
.89011 .73214 L
.89004 .7325 L
.89 .73266 L
.89 .73254 L
.89007 .73205 L
.89022 .7312 L
.89047 .73006 L
.89083 .72865 L
.89131 .72699 L
.89188 .72514 L
.89257 .72308 L
.89337 .72111 L
.89418 .71892 L
.8951 .71666 L
.89601 .71435 L
.89699 .7119 L
.89794 .70928 L
.89894 .70686 L
.89989 .70422 L
.90087 .70154 L
.90183 .6989 L
.90278 .6961 L
.90374 .69348 L
.90459 .69063 L
.90541 .68805 L
.90618 .68529 L
.90692 .68268 L
.90757 .67986 L
.90823 .67747 L
.9088 .67501 L
.90934 .6726 L
.90987 .67025 L
.91041 .66795 L
Mistroke
.91096 .66556 L
.91155 .66334 L
.91214 .66098 L
.91283 .65859 L
.91356 .65613 L
.9144 .65363 L
.91524 .65095 L
.91617 .64838 L
.91711 .64563 L
.91809 .64279 L
.91899 .63995 L
.91991 .63709 L
.9208 .63418 L
.92166 .63116 L
.92255 .62805 L
.92342 .62488 L
.92434 .62156 L
.92526 .61822 L
.92623 .61461 L
.92715 .61137 L
.92807 .60812 L
.92889 .60494 L
.92973 .60215 L
.93041 .59957 L
.93109 .5971 L
.9316 .59527 L
.93202 .59372 L
.93236 .59245 L
.93261 .59151 L
.93277 .59087 L
.93286 .59052 L
.93288 .59041 L
.93286 .59046 L
.93282 .5906 L
.93276 .5908 L
.93271 .59101 L
.93267 .59116 L
.93265 .59123 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
Mistroke
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59125 L
.93265 .59127 L
.93267 .59133 L
.93269 .59142 L
.93271 .59154 L
.93271 .59166 L
.93268 .59177 L
.93265 .59184 L
.9326 .59181 L
.93253 .59164 L
.93246 .59128 L
.93239 .5907 L
.93233 .58988 L
.93228 .58881 L
.93221 .58753 L
.93215 .58593 L
.93207 .58405 L
.93198 .58185 L
.93189 .57941 L
.93182 .57664 L
.93178 .57387 L
.93176 .57082 L
.93178 .56767 L
.93185 .56449 L
.93197 .56116 L
.93213 .55763 L
.93234 .5544 L
Mistroke
.9326 .55068 L
.9329 .54726 L
.93328 .54338 L
.93374 .53986 L
.93425 .53614 L
.93476 .53224 L
.9353 .52861 L
.93583 .52486 L
.93629 .52109 L
.93672 .51712 L
.93709 .51348 L
.93739 .50964 L
.93762 .50579 L
.93779 .50185 L
.93788 .49828 L
.9379 .4946 L
.93783 .49078 L
.93767 .4873 L
.93745 .4837 L
.93717 .48012 L
.93684 .47636 L
.93649 .47309 L
.93612 .46962 L
.93577 .46617 L
.93544 .46262 L
.93512 .45939 L
.93481 .45602 L
.93453 .45262 L
.93428 .44931 L
.93407 .4459 L
.9339 .4425 L
.93378 .43925 L
.93367 .43595 L
.93358 .43238 L
.9335 .42916 L
.9334 .42554 L
.93329 .42198 L
.93317 .41882 L
.93306 .41547 L
.93295 .41236 L
.93285 .40946 L
.93276 .40698 L
.93268 .40467 L
.93261 .40295 L
.93255 .40138 L
.93252 .40028 L
.93249 .39948 L
.93248 .399 L
.9325 .39887 L
.93254 .39902 L
Mistroke
.93258 .39934 L
.93261 .39972 L
.93262 .40008 L
.93259 .40035 L
.93251 .40045 L
.93239 .40036 L
.93223 .40008 L
.93204 .39966 L
.93181 .39917 L
.93158 .39867 L
.93136 .3982 L
.93115 .39777 L
.93093 .39739 L
.93073 .39706 L
.93056 .39678 L
.93041 .39654 L
.93031 .39632 L
.93025 .39612 L
.93023 .39591 L
.93023 .39565 L
.93025 .39533 L
.93027 .39494 L
.93028 .3945 L
.93028 .39404 L
.93026 .39362 L
.93026 .39323 L
.93027 .39291 L
.9303 .39269 L
.93033 .39261 L
.93034 .39269 L
.93034 .39294 L
.93031 .39339 L
.93024 .39399 L
.93015 .39472 L
.93001 .39554 L
.92983 .3964 L
.92962 .39724 L
.9294 .398 L
.9292 .39866 L
.92902 .39922 L
.92887 .3997 L
.92877 .40008 L
.92873 .40036 L
.92876 .40057 L
.92886 .4007 L
.92901 .40078 L
.92921 .4008 L
.92946 .40077 L
.9297 .4007 L
.92993 .40062 L
Mistroke
.93015 .40056 L
.93033 .40053 L
.93046 .40053 L
.93055 .40052 L
.93059 .40047 L
.93058 .40036 L
.93053 .4002 L
.93046 .40004 L
.93041 .39991 L
.93039 .39986 L
.93042 .39992 L
.93051 .40014 L
.93064 .40058 L
.93082 .40126 L
.93103 .40222 L
.93128 .40346 L
.93154 .405 L
.93181 .40662 L
.93209 .40859 L
.93237 .41062 L
.93263 .41285 L
.93287 .41516 L
.93308 .41741 L
.93326 .41975 L
.93339 .42198 L
.93348 .4242 L
.93354 .42626 L
.93359 .42825 L
.93362 .43014 L
.93365 .43175 L
.9337 .43328 L
.93374 .43464 L
.93378 .4358 L
.93382 .43685 L
.93385 .43759 L
.93387 .43826 L
.9339 .43877 L
.93393 .43914 L
.93397 .43941 L
.93399 .43963 L
.93399 .43995 L
.93397 .44049 L
.93393 .44137 L
.93389 .44259 L
.93387 .44417 L
.93388 .44623 L
.9339 .44878 L
.93394 .4513 L
.93397 .45421 L
.934 .45746 L
Mistroke
.93401 .46059 L
.93401 .46402 L
.93401 .46767 L
.93402 .47099 L
.93404 .47451 L
.93406 .47803 L
.9341 .48155 L
.93413 .48519 L
.93415 .48881 L
.93413 .49259 L
.93408 .49658 L
.93398 .50073 L
.93384 .50493 L
.93364 .50929 L
.93341 .51394 L
.93314 .51815 L
.93281 .52249 L
.93243 .52689 L
.93198 .53068 L
.9315 .53455 L
.93096 .53829 L
.93039 .54188 L
.92979 .54495 L
.92917 .54806 L
.92852 .55109 L
.92783 .55405 L
.92709 .55713 L
.92631 .56043 L
.92552 .56386 L
.92469 .56765 L
.9239 .57154 L
.92311 .57561 L
.92236 .57991 L
.92162 .58465 L
.92092 .58927 L
.92025 .59437 L
.9197 .59906 L
.91923 .60419 L
.91884 .6089 L
.91853 .61362 L
.91827 .61839 L
.91804 .62245 L
.91781 .62654 L
.91752 .63062 L
.91716 .63398 L
.9167 .63758 L
.91608 .6409 L
.91527 .64438 L
.91438 .64755 L
.91327 .65092 L
Mistroke
.91202 .65422 L
.91063 .65748 L
.90907 .66103 L
.90768 .6644 L
.90601 .6682 L
.90454 .67198 L
.90294 .67603 L
.90136 .68029 L
.89987 .68452 L
.89847 .68891 L
.89716 .69317 L
.89599 .69749 L
.89495 .70183 L
.89406 .70583 L
.89329 .70979 L
.89259 .71371 L
.89194 .7172 L
.89126 .72068 L
.89054 .7241 L
.88979 .727 L
.88902 .72983 L
.8882 .73243 L
.88727 .73489 L
.88617 .73733 L
.88491 .73962 L
.88339 .7419 L
.8816 .74436 L
.87959 .74694 L
.87735 .74961 L
.87498 .75241 L
.87242 .75539 L
.86996 .7581 L
.86737 .7611 L
.86449 .7644 L
.8619 .76731 L
.85917 .77039 L
.85634 .77354 L
.85354 .77664 L
.85068 .77971 L
.84821 .7823 L
.84569 .78474 L
.84331 .78686 L
.84097 .78876 L
.83883 .79025 L
.83658 .79146 L
.83446 .79234 L
.83231 .7928 L
.83019 .79288 L
.82829 .79265 L
.82645 .79222 L
Mistroke
.82466 .79167 L
.82295 .79115 L
.82127 .79076 L
.81953 .79061 L
.81771 .79075 L
.81595 .79123 L
.81408 .79208 L
.8121 .79331 L
.81011 .79484 L
.80798 .79673 L
.80567 .79902 L
.80342 .80156 L
.80088 .80445 L
.79832 .80735 L
.79554 .81049 L
.79291 .81348 L
.79 .81663 L
.78741 .81959 L
.78479 .82273 L
.78229 .82577 L
.77991 .82897 L
.77782 .83197 L
.77585 .83514 L
.77407 .83817 L
.77244 .84124 L
.77085 .84447 L
.76929 .84733 L
.76768 .85064 L
.76601 .85344 L
.76417 .85631 L
.76214 .85921 L
.76011 .86182 L
.75786 .86427 L
.75529 .86659 L
.75272 .86864 L
.74964 .87066 L
.7467 .87245 L
.74341 .8742 L
.73994 .87596 L
.7363 .87778 L
.73274 .87961 L
.72899 .88157 L
.72534 .88351 L
.72171 .88562 L
.71791 .88783 L
.71384 .89019 L
.71022 .89261 L
.70611 .89524 L
.70216 .89783 L
.69807 .9005 L
Mistroke
.69382 .90302 L
.69001 .90547 L
.6861 .90779 L
.68192 .90995 L
.67845 .91188 L
.6747 .91362 L
.67107 .91507 L
.66725 .91623 L
.66399 .91708 L
.6606 .91764 L
.65749 .91795 L
.65423 .91803 L
.65137 .91795 L
.64839 .91774 L
.6454 .91744 L
.64273 .91709 L
.63991 .91671 L
.637 .91637 L
.63428 .9161 L
.63139 .91597 L
.62865 .91598 L
.62595 .91615 L
.62321 .91645 L
.6208 .91687 L
.6184 .91739 L
.61598 .91801 L
.61381 .91875 L
.61156 .91962 L
.60921 .92065 L
.60711 .9218 L
.60498 .92313 L
.6028 .92462 L
.60072 .92616 L
.59849 .92779 L
.59612 .92943 L
.59396 .93084 L
.59123 .93241 L
.58879 .93372 L
.58608 .93496 L
.58297 .9361 L
.57996 .9371 L
.57669 .93791 L
.57346 .93848 L
.56993 .93881 L
.56664 .9389 L
.56291 .93878 L
.5594 .93847 L
.5554 .93802 L
.55175 .93748 L
.54782 .93691 L
Mistroke
.54381 .93628 L
.54013 .93562 L
.53628 .93488 L
.53284 .93407 L
.52914 .93322 L
.52592 .93229 L
.52295 .93137 L
.51995 .93043 L
.51725 .92944 L
.51479 .9284 L
.51246 .9273 L
.51044 .92623 L
.50857 .92491 L
.50689 .92359 L
.50533 .92216 L
.50387 .9206 L
.50248 .91894 L
.50108 .91713 L
.49972 .9154 L
.49838 .91344 L
.49707 .91158 L
.49575 .90958 L
.4944 .9075 L
.49298 .90532 L
.49147 .90311 L
.48982 .90073 L
.48812 .89854 L
.48631 .89609 L
.48447 .89396 L
.48257 .89175 L
.48077 .88956 L
.47901 .88755 L
.47744 .88566 L
.47605 .88391 L
.47478 .88238 L
.47373 .88097 L
.47287 .87955 L
.4722 .87826 L
.47174 .87693 L
.47148 .87551 L
.47137 .87396 L
.47138 .8723 L
.47145 .87058 L
.47152 .86916 L
.47155 .86753 L
.47152 .86587 L
.47147 .86427 L
.47146 .86246 L
.47152 .86082 L
.47171 .85908 L
Mistroke
.47207 .85745 L
.47261 .85582 L
.47333 .85425 L
.47426 .85281 L
.47535 .85162 L
.47665 .85037 L
.47817 .84913 L
.47986 .84796 L
.4817 .84677 L
.48366 .84555 L
.48569 .84439 L
.48771 .84329 L
.48967 .84228 L
.49155 .84139 L
.49331 .84064 L
.4949 .84003 L
.49633 .83949 L
.4977 .83901 L
.4989 .83858 L
.49999 .8382 L
.50095 .83789 L
.50177 .83765 L
.50247 .83747 L
.50308 .83733 L
.5036 .83726 L
.50409 .83726 L
.50459 .83732 L
.50514 .83742 L
.50578 .83756 L
.50651 .83775 L
.50734 .83798 L
.5083 .83823 L
.50935 .83852 L
.51056 .83885 L
.51188 .83922 L
.51339 .83964 L
.51504 .84016 L
.51686 .84076 L
.51884 .84148 L
.52097 .84229 L
.5232 .84321 L
.52546 .84419 L
.52774 .84529 L
.53002 .84645 L
.53212 .8477 L
.53414 .8491 L
.53596 .85062 L
.53755 .8523 L
.53883 .854 L
.53986 .85584 L
Mistroke
.54055 .85768 L
.54098 .85947 L
.54116 .86129 L
.5411 .86311 L
.54079 .86468 L
.54029 .86619 L
.53962 .86759 L
.53879 .86883 L
.53792 .8698 L
.53696 .87057 L
.5359 .87109 L
.53473 .87136 L
.53343 .87144 L
.53211 .87137 L
.53072 .87115 L
.52903 .87075 L
.52732 .87024 L
.52529 .86961 L
.52293 .86884 L
.52081 .8679 L
.51834 .86678 L
.51547 .86551 L
.51302 .86398 L
.51013 .86219 L
.50722 .86045 L
.50434 .85841 L
.50142 .85622 L
.4985 .85388 L
.49566 .85139 L
.49285 .84871 L
.49031 .84615 L
.48808 .84367 L
.48582 .84103 L
.48375 .83852 L
.48183 .83583 L
.48031 .83339 L
.47893 .83082 L
.47779 .8282 L
.47687 .82547 L
.47617 .82281 L
.47572 .82008 L
.47551 .81728 L
.47553 .81459 L
.47579 .81186 L
.47632 .80925 L
.4771 .80674 L
.47812 .80437 L
.47934 .80213 L
.48077 .79997 L
.48233 .79802 L
Mistroke
.48406 .79611 L
.48596 .79438 L
.48804 .79269 L
.49024 .79119 L
.49261 .78974 L
.49517 .78838 L
.49776 .78714 L
.50053 .7861 L
.50337 .7852 L
.50627 .7845 L
.5094 .784 L
.51245 .78374 L
.51558 .78373 L
.51893 .78399 L
.52198 .78451 L
.52519 .78531 L
.52831 .78632 L
.53151 .78754 L
.53448 .78898 L
.53738 .79054 L
.54043 .79224 L
.54304 .79399 L
.54577 .79592 L
.54844 .79775 L
.55104 .79977 L
.55366 .80157 L
.55601 .80344 L
.55847 .80534 L
.56066 .80732 L
.56296 .80917 L
.56515 .81125 L
.56738 .81314 L
.56961 .8152 L
.57186 .81727 L
.5741 .81947 L
.57642 .82154 L
.57871 .8234 L
.58108 .82529 L
.58353 .8272 L
.58611 .82894 L
.5887 .83052 L
.59146 .83209 L
.59452 .83363 L
.59738 .83503 L
.60058 .8364 L
.60393 .83773 L
.60735 .83909 L
.61121 .84049 L
.61462 .84182 L
.61831 .84332 L
Mistroke
.62167 .84475 L
.62507 .84631 L
.62864 .84798 L
.63217 .8498 L
.63511 .85161 L
.63832 .8536 L
.64117 .85572 L
.64395 .85783 L
.64667 .86027 L
.64931 .86272 L
.65199 .86557 L
.65477 .86843 L
.65742 .87124 L
.66032 .87431 L
.66331 .87739 L
.66662 .88062 L
.66941 .88355 L
.67257 .88659 L
.67584 .88953 L
.67883 .89201 L
.682 .89442 L
.68506 .89662 L
.68816 .89838 L
.69103 .89986 L
.69392 .90095 L
.69672 .90166 L
.69955 .90204 L
.70223 .9021 L
.70472 .90195 L
.7072 .90158 L
.70956 .90107 L
.71177 .90046 L
.71375 .89975 L
.71551 .89901 L
.71694 .89823 L
.71813 .89743 L
.71904 .89666 L
.7197 .89594 L
.72014 .89529 L
.72038 .89469 L
.72047 .89414 L
.72046 .89366 L
.72038 .89325 L
.72026 .89287 L
.72012 .89249 L
.72002 .89211 L
.71998 .89176 L
.71998 .89149 L
.72 .89132 L
.72 .89125 L
Mistroke
.71998 .89126 L
.71996 .89131 L
.71997 .89137 L
.72005 .89139 L
.72023 .89133 L
.72051 .89119 L
.72092 .89098 L
.72143 .89072 L
.72201 .89043 L
.72261 .89013 L
.72318 .88983 L
.72374 .88953 L
.72427 .88925 L
.72473 .88899 L
.72512 .88876 L
.72543 .88858 L
.72564 .88846 L
.72573 .8884 L
.72569 .88838 L
.72555 .88841 L
.72535 .88847 L
.72513 .88853 L
.72494 .88858 L
.7248 .88861 L
.72473 .88862 L
.72473 .88862 L
.72476 .88862 L
.7248 .88861 L
.72483 .88861 L
.72484 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72486 .88861 L
.72487 .8886 L
.72488 .8886 L
.72488 .8886 L
.72486 .88861 L
.72484 .88861 L
.7248 .88861 L
.72477 .88862 L
.72473 .88862 L
.7247 .88862 L
.72467 .88863 L
.72465 .88863 L
Mistroke
.72464 .88863 L
.72464 .88863 L
.72464 .88863 L
.72465 .88863 L
.72466 .88863 L
.72469 .88862 L
.72472 .88862 L
.72477 .88859 L
.72484 .88851 L
.72491 .8884 L
.72498 .8883 L
.72501 .88825 L
.725 .88829 L
.72494 .88843 L
.72484 .8887 L
.72469 .88912 L
.72452 .88968 L
.72432 .89033 L
.72409 .89104 L
.72385 .89178 L
.72361 .8925 L
.72336 .89322 L
.7231 .89396 L
.72284 .89469 L
.7226 .89535 L
.7224 .89587 L
.72227 .89618 L
.72225 .89626 L
.72234 .89613 L
.72254 .89581 L
.72284 .89536 L
.72321 .89481 L
.72364 .89423 L
.72409 .89366 L
.72455 .89312 L
.72503 .8926 L
.7255 .8921 L
.72595 .89165 L
.72636 .89127 L
.72671 .89096 L
.72699 .89075 L
.72717 .89061 L
.72726 .89051 L
.72728 .89045 L
.72729 .89038 L
.72731 .89028 L
.72736 .89012 L
.72744 .88991 L
.72755 .88965 L
.72764 .8894 L
Mistroke
.72768 .88915 L
.72764 .88892 L
.72754 .88871 L
.72737 .88854 L
.72715 .88841 L
.72689 .88833 L
.72664 .88829 L
.72639 .88824 L
.72614 .88818 L
.72588 .88814 L
.72559 .88816 L
.72527 .88826 L
.72493 .88844 L
.72458 .88873 L
.72423 .88916 L
.72389 .88973 L
.72356 .89039 L
.72324 .89111 L
.72294 .89184 L
.72265 .89255 L
.72231 .89323 L
.72191 .89392 L
.72148 .89458 L
.72101 .89516 L
.72049 .89561 L
.71991 .89594 L
.71925 .89617 L
.71854 .89635 L
.71779 .89652 L
.71698 .89671 L
.71615 .89699 L
.71521 .89736 L
.71418 .89784 L
.71308 .89839 L
.71193 .899 L
.7108 .89963 L
.70967 .90032 L
.7085 .90109 L
.70723 .90195 L
.70582 .90289 L
.70424 .90393 L
.70243 .90509 L
.7003 .90642 L
.69782 .90791 L
.69522 .90939 L
.69237 .91103 L
.68919 .91286 L
.68604 .91462 L
.68245 .91651 L
.67927 .91819 L
Mistroke
.67596 .91983 L
.67259 .92135 L
.66937 .92262 L
.66606 .92376 L
.66289 .92473 L
.65974 .92551 L
.65643 .92609 L
.65322 .92651 L
.64974 .92677 L
.64625 .92691 L
.6424 .92694 L
.63848 .9269 L
.63432 .92678 L
.62992 .92663 L
.62548 .92649 L
.62071 .92636 L
.61601 .9262 L
.61112 .92601 L
.60595 .9258 L
.60114 .92558 L
.59569 .92538 L
.59118 .92521 L
.58632 .92505 L
.58164 .92487 L
.57689 .92466 L
.57232 .92437 L
.56784 .92396 L
.56328 .92341 L
.55862 .92269 L
.55461 .92179 L
.55039 .92074 L
.54627 .91965 L
.54203 .9184 L
.53835 .91703 L
.53459 .91546 L
.53066 .91394 L
.52723 .91219 L
.52361 .91029 L
.51968 .9083 L
.5161 .90617 L
.51217 .90378 L
.50807 .90152 L
.50401 .89901 L
.4995 .89638 L
.49564 .89358 L
.49148 .89074 L
.48665 .88768 L
.48267 .88475 L
.47836 .88172 L
.47399 .87859 L
Mistroke
.46979 .87545 L
.46607 .87271 L
.46224 .8698 L
.45863 .86683 L
.45492 .86405 L
.4515 .86118 L
.44794 .85837 L
.44424 .85552 L
.44027 .85266 L
.43675 .85047 L
.43294 .8482 L
.42864 .84598 L
.42496 .84424 L
.42099 .84263 L
.41692 .84122 L
.41276 .84021 L
.40892 .83946 L
.4051 .839 L
.40127 .83879 L
.39756 .83881 L
.39373 .83902 L
.38996 .83936 L
.38589 .83974 L
.38184 .84011 L
.37764 .84042 L
.37316 .84063 L
.36902 .8407 L
.36461 .84058 L
.36031 .84023 L
.35576 .83965 L
.35143 .83882 L
.34699 .83772 L
.34245 .83639 L
.33849 .8348 L
.33435 .83287 L
.33052 .83083 L
.32668 .82845 L
.32289 .82579 L
.31918 .82305 L
.31555 .82011 L
.31199 .8171 L
.30841 .81395 L
.30489 .81103 L
.30161 .80808 L
.29801 .80495 L
.29497 .80234 L
.29181 .79963 L
.2885 .79686 L
.28541 .7944 L
.28202 .79185 L
Mistroke
.27868 .7894 L
.27523 .78699 L
.27148 .78458 L
.26815 .78248 L
.26446 .78034 L
.2607 .77827 L
.25682 .7763 L
.25272 .77436 L
.24907 .7726 L
.245 .77087 L
.24145 .76934 L
.23765 .76785 L
.23416 .76636 L
.23066 .76489 L
.22728 .76335 L
.22406 .76181 L
.22091 .76008 L
.21769 .75815 L
.21486 .7562 L
.21198 .75401 L
.2093 .75155 L
.20681 .74902 L
.20441 .74619 L
.20217 .74327 L
.20007 .74017 L
.1981 .73706 L
.19626 .73378 L
.19446 .73047 L
.19273 .7269 L
.19102 .72343 L
.18933 .7197 L
.18755 .71583 L
.18567 .71217 L
.18366 .70827 L
.18158 .70434 L
.17946 .70013 L
.17735 .69675 L
.17525 .69314 L
.17315 .6893 L
.17117 .68638 L
.16925 .68356 L
.16742 .68096 L
.16564 .67869 L
.16394 .67682 L
.16218 .67525 L
.16038 .67398 L
.15853 .67294 L
.15658 .67203 L
.15465 .67119 L
.15263 .67035 L
Mistroke
.15046 .66948 L
.14815 .66854 L
.14596 .66756 L
.14343 .66645 L
.14102 .66523 L
.13842 .6638 L
.13572 .66215 L
.13303 .66041 L
.13018 .65847 L
.12749 .65647 L
.12469 .65447 L
.12176 .65246 L
.11913 .65062 L
.11636 .64892 L
.1138 .64721 L
.11145 .64578 L
.10918 .64445 L
.10712 .64329 L
.10545 .64233 L
.10409 .6416 L
.10303 .6411 L
.10227 .6408 L
.10177 .64069 L
.1015 .64073 L
.10141 .64087 L
.10142 .64104 L
.10148 .64116 L
.10159 .64119 L
.10173 .64113 L
.10184 .64097 L
.10188 .64071 L
.10178 .64035 L
.10156 .63992 L
.10124 .63945 L
.10086 .63895 L
.1004 .63845 L
.09984 .63796 L
.09916 .63749 L
.09836 .63706 L
.09743 .63668 L
.0964 .6364 L
.09528 .63621 L
.09408 .63613 L
.09282 .63613 L
.09152 .6362 L
.09024 .63632 L
.08903 .63645 L
.08789 .63655 L
.08681 .63662 L
.08583 .63666 L
Mistroke
.08497 .63669 L
.08426 .63671 L
.08369 .63673 L
.08325 .63675 L
.08295 .63676 L
.08279 .63676 L
.08273 .63676 L
.08274 .63676 L
.08278 .63676 L
.08281 .63676 L
.08284 .63676 L
.08288 .63676 L
.08292 .63676 L
.08296 .63676 L
.08298 .63676 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08299 .63675 L
.083 .63671 L
.08304 .63662 L
.08309 .6365 L
.08313 .63639 L
.08315 .63631 L
.08314 .63629 L
.08308 .63638 L
.08296 .63661 L
.08279 .637 L
.08256 .63755 L
.0823 .63825 L
.082 .63909 L
.08168 .64008 L
.08133 .64117 L
.08096 .64238 L
.0806 .64371 L
.08028 .64515 L
.08004 .64663 L
.07988 .64805 L
.07982 .64945 L
.07987 .65077 L
.08002 .65199 L
.08025 .65314 L
.08052 .65423 L
Mistroke
.08081 .65535 L
.08109 .65655 L
.08135 .65786 L
.08159 .65929 L
.0818 .66066 L
.08197 .66211 L
.0821 .6636 L
.08219 .66511 L
.08222 .66656 L
.0822 .66786 L
.08214 .66918 L
.08206 .67058 L
.08197 .67199 L
.0819 .67331 L
.08183 .67456 L
.08177 .67576 L
.0817 .67692 L
.08163 .67795 L
.08158 .67893 L
.08156 .67985 L
.0816 .68077 L
.08168 .68164 L
.08181 .68241 L
.08199 .68306 L
.0822 .68358 L
.08242 .68395 L
.08265 .68418 L
.08289 .68429 L
.08316 .68431 L
.08345 .68429 L
.08376 .68427 L
.08409 .68426 L
.08443 .68429 L
.08476 .68437 L
.08508 .68447 L
.08537 .68456 L
.08564 .68467 L
.08587 .68486 L
.0861 .68515 L
.08632 .68555 L
.08654 .68606 L
.08673 .6867 L
.08688 .68746 L
.08698 .68836 L
.08702 .6894 L
.08701 .69057 L
.08696 .69181 L
.08688 .69305 L
.0868 .69435 L
.08672 .69577 L
Mistroke
.08667 .6973 L
.08662 .69882 L
.08659 .70022 L
.08656 .70134 L
.08654 .70228 L
.08652 .70301 L
.08651 .70353 L
.0865 .70383 L
.0865 .7039 L
.0865 .70374 L
.08651 .7034 L
.08652 .70296 L
.08653 .70241 L
.08655 .70179 L
.08657 .70113 L
.08658 .70048 L
.0866 .69988 L
.08661 .69931 L
.08663 .69879 L
.08666 .69835 L
.0867 .69801 L
.08675 .69778 L
.08679 .69761 L
.08682 .69746 L
.08681 .69729 L
.08676 .69708 L
.08666 .6968 L
.08653 .69646 L
.08637 .69605 L
.08619 .6956 L
.08598 .69509 L
.08573 .69449 L
.08545 .69379 L
.08512 .69299 L
.08476 .69207 L
.08438 .69103 L
.08398 .68988 L
.08359 .68867 L
.08323 .68742 L
.08291 .68607 L
.08265 .68463 L
.08244 .68309 L
.08228 .68143 L
.08217 .67977 L
.08208 .67795 L
.082 .67597 L
.08193 .67415 L
.08187 .67217 L
.08181 .67 L
.08173 .66799 L
Mistroke
.08165 .66581 L
.08156 .66355 L
.08144 .66135 L
.08128 .65907 L
.08108 .65703 L
.08084 .65498 L
.08056 .65302 L
.08025 .6512 L
.07992 .64951 L
.07958 .64779 L
.07925 .64629 L
.07894 .64485 L
.07864 .64349 L
.07837 .64225 L
.07812 .64104 L
.07791 .63985 L
.07776 .63869 L
.07769 .6375 L
.07771 .63625 L
.07784 .63492 L
.07806 .63361 L
.07835 .63225 L
.07868 .63083 L
.079 .62945 L
.07927 .62794 L
.07944 .62655 L
.0795 .62509 L
.07942 .62353 L
.07921 .6219 L
.07889 .62035 L
.07844 .61871 L
.07786 .61711 L
.07718 .61548 L
.07644 .6139 L
.07566 .61235 L
.07485 .61068 L
.07411 .60914 L
.07343 .60751 L
.07283 .60582 L
.07231 .60411 L
.07188 .60231 L
.07154 .60058 L
.07129 .59871 L
.07113 .59675 L
.07105 .59499 L
.07101 .59312 L
.07099 .59112 L
.07096 .58934 L
.07092 .58748 L
.07088 .58559 L
Mistroke
.07083 .58392 L
.07076 .58225 L
.07066 .58066 L
.07052 .57909 L
.07034 .57748 L
.0701 .57597 L
.06982 .57432 L
.0695 .57252 L
.06917 .57075 L
.06883 .56882 L
.06848 .56681 L
.06813 .56462 L
.06778 .56265 L
.06745 .56041 L
.06711 .55823 L
.06677 .55617 L
.06642 .55397 L
.06605 .55189 L
.06572 .54983 L
.06539 .54778 L
.06512 .54609 L
.0649 .54435 L
.06472 .54298 L
.0646 .54175 L
.0645 .54068 L
.06444 .5398 L
.06439 .53911 L
.06437 .53862 L
.06437 .53832 L
.06439 .53817 L
.06442 .53813 L
.06445 .53816 L
.06448 .53824 L
.06449 .53831 L
.06449 .53837 L
.06449 .53842 L
.06449 .53849 L
.06449 .53858 L
.06448 .53867 L
.06448 .53874 L
.06448 .53878 L
.06448 .53875 L
.06448 .53865 L
.06449 .53846 L
.0645 .53817 L
.06451 .5378 L
.06453 .53736 L
.06455 .53688 L
.06456 .53637 L
.06458 .53587 L
Mistroke
.0646 .53538 L
.06462 .53489 L
.06463 .53443 L
.06465 .53406 L
.06466 .53379 L
.06466 .53365 L
.06466 .5336 L
.06466 .5336 L
.06467 .53362 L
.06469 .53362 L
.06471 .53354 L
.06472 .53335 L
.06472 .53302 L
.0647 .53257 L
.06467 .53203 L
.06464 .53141 L
.06461 .53077 L
.06458 .53009 L
.06456 .5294 L
.06456 .52871 L
.06456 .52806 L
.06458 .52749 L
.06459 .52702 L
.06461 .52665 L
.06463 .52638 L
.06466 .52621 L
.06471 .52612 L
.06476 .52609 L
.06482 .52608 L
.06488 .52609 L
.06492 .52612 L
.06496 .52615 L
.06498 .52619 L
.06497 .52623 L
.06495 .52624 L
.06493 .52624 L
.06494 .52623 L
.06497 .5262 L
.06504 .52616 L
.06512 .52614 L
.06516 .52615 L
.06513 .5262 L
.06502 .52629 L
.06481 .52641 L
.0645 .52656 L
.06411 .52673 L
.06367 .52693 L
.06324 .52715 L
.06285 .52735 L
.06252 .52751 L
Mistroke
.06226 .52759 L
.06202 .52755 L
.0618 .52735 L
.06159 .52697 L
.06141 .52636 L
.06136 .52553 L
.0614 .52446 L
.0615 .52317 L
.06165 .52186 L
.06182 .52035 L
.062 .51877 L
.06212 .51732 L
.06218 .51586 L
.06219 .51454 L
.0622 .51325 L
.0622 .51203 L
.06225 .51099 L
.06233 .51005 L
.06244 .50924 L
.06257 .50853 L
.0627 .5079 L
.06281 .50731 L
.0629 .50674 L
.06297 .50622 L
.063 .5057 L
.063 .50521 L
.06298 .50475 L
.06297 .50429 L
.06298 .50382 L
.063 .50335 L
.06301 .50289 L
.06303 .50243 L
.06305 .50197 L
.06306 .50151 L
.06308 .50104 L
.0631 .50054 L
.06312 .49998 L
.06314 .49937 L
.06316 .49874 L
.06318 .49809 L
.06321 .49742 L
.06323 .49674 L
.06325 .49606 L
.06327 .49538 L
.06327 .49473 L
.06328 .49415 L
.06329 .49363 L
.06332 .49315 L
.06337 .49267 L
.06342 .49217 L
Mistroke
.06349 .49165 L
.06356 .49114 L
.06361 .49065 L
.06363 .49015 L
.06363 .4896 L
.06362 .48902 L
.06363 .48836 L
.06367 .4876 L
.06375 .4868 L
.06388 .48598 L
.06403 .48513 L
.06421 .48427 L
.0644 .48339 L
.06461 .48249 L
.06483 .48159 L
.06509 .48064 L
.06539 .47964 L
.06575 .4786 L
.06615 .47759 L
.06659 .4765 L
.06703 .47534 L
.06744 .47415 L
.06782 .4729 L
.06815 .47157 L
.06842 .47018 L
.06867 .46885 L
.06893 .46749 L
.06921 .46614 L
.06951 .46497 L
.06982 .46388 L
.07014 .46295 L
.07044 .46218 L
.07073 .46153 L
.071 .461 L
.07126 .46059 L
.0715 .46029 L
.07175 .4601 L
.07201 .46002 L
.07226 .46002 L
.07248 .46008 L
.07265 .46017 L
.07276 .46027 L
.07283 .46034 L
.07285 .46037 L
.07283 .46038 L
.07279 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07267 .46038 L
.07264 .46038 L
.0726 .46038 L
.07256 .46038 L
Mistroke
.07254 .46038 L
.07255 .46038 L
.07261 .46038 L
.07272 .46038 L
.07288 .46038 L
.07309 .46037 L
.07333 .46037 L
.0736 .46036 L
.07388 .46036 L
.07416 .46036 L
.07444 .46035 L
.07471 .46035 L
.07497 .46034 L
.07519 .46034 L
.07537 .46034 L
.07549 .46033 L
.07556 .46033 L
.07558 .46033 L
.07556 .46033 L
.07552 .46033 L
.07548 .46033 L
.07544 .46034 L
.07543 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07543 .46033 L
.07544 .4603 L
.07549 .46022 L
.07558 .46011 L
.07566 .46001 L
.07569 .45997 L
.07567 .46001 L
.07556 .46017 L
.07535 .46046 L
.07502 .46091 L
.07458 .46151 L
.07405 .46222 L
.07349 .46301 L
.07291 .46381 L
.07235 .46458 L
.07182 .46533 L
.07128 .46604 L
.07075 .46669 L
.07026 .46719 L
.06987 .46748 L
.0696 .4675 L
.06944 .46725 L
.06937 .46677 L
.06941 .46614 L
.06954 .46542 L
.06973 .46465 L
.06993 .4639 L
.07014 .46315 L
.07034 .46243 L
.07053 .46169 L
.07069 .46095 L
.0708 .46026 L
.07087 .45969 L
.07089 .45927 L
.07089 .45902 L
Mistroke
.07086 .4589 L
.0708 .45881 L
.07071 .45874 L
.07061 .45864 L
.07053 .45853 L
.07048 .45839 L
.07048 .45825 L
.07052 .45813 L
.07061 .45803 L
.07075 .45795 L
.07087 .45789 L
.07101 .45775 L
.07112 .45754 L
.07117 .45728 L
.0712 .45695 L
.07122 .45665 L
.07124 .45643 L
.07125 .45631 L
.07127 .45633 L
.07127 .45647 L
.0713 .45668 L
.07133 .45695 L
.07139 .45724 L
.0715 .45755 L
.07168 .45788 L
.07192 .45829 L
.07219 .45876 L
.07244 .4592 L
.07267 .45966 L
.07291 .46002 L
.07319 .46028 L
.07355 .46042 L
.07406 .46041 L
.07469 .46025 L
.0755 .45994 L
.07651 .45951 L
.07775 .459 L
.07912 .45841 L
.08033 .45777 L
.08179 .4571 L
.08309 .45642 L
.08467 .45573 L
.08603 .45503 L
.08755 .45433 L
.08882 .45363 L
.09005 .45292 L
.09109 .45221 L
.09202 .45148 L
.09284 .45069 L
.09353 .44984 L
Mistroke
.09413 .44886 L
.09469 .4477 L
.09523 .44636 L
.09573 .44492 L
.09619 .44341 L
.0966 .44179 L
.09694 .44019 L
.09725 .43858 L
.09753 .43716 L
.0978 .43583 L
.09804 .43456 L
.09826 .43357 L
.09842 .43272 L
.09852 .43201 L
.09852 .43147 L
.09842 .43108 L
.09821 .43081 L
.09791 .43057 L
.09754 .43032 L
.09711 .43 L
.09663 .42961 L
.09615 .42911 L
.09564 .42856 L
.09512 .42791 L
.09459 .42727 L
.09413 .42658 L
.09372 .42591 L
.09336 .42531 L
.09309 .42479 L
.0929 .42436 L
.09279 .42405 L
.09276 .42384 L
.09278 .42375 L
.09282 .42378 L
.09287 .42391 L
.09291 .4241 L
.09294 .42429 L
.09296 .42443 L
.09294 .42448 L
.09291 .4244 L
.09288 .42417 L
.09285 .42375 L
.09285 .4231 L
.09289 .4222 L
.09299 .42104 L
.09314 .41974 L
.09335 .41815 L
.09361 .41631 L
.09391 .41435 L
.09425 .41213 L
Mistroke
.0946 .40988 L
.09494 .40772 L
.09529 .40535 L
.09563 .4032 L
.09595 .40098 L
.09623 .39878 L
.09646 .39666 L
.09661 .39458 L
.0967 .39245 L
.09674 .3904 L
.09677 .38824 L
.09679 .38614 L
.09683 .38406 L
.09694 .38173 L
.09713 .37959 L
.09741 .37728 L
.09777 .37489 L
.09819 .37249 L
.09865 .37001 L
.09909 .36751 L
.09954 .36487 L
.09997 .36205 L
.10039 .35931 L
.10078 .35644 L
.10111 .3537 L
.10133 .35071 L
.10148 .34832 L
.10157 .34577 L
.10161 .34366 L
.10162 .34164 L
.10162 .33994 L
.10164 .33842 L
.10171 .33731 L
.10187 .33626 L
.10199 .33562 L
.10215 .33523 L
.10234 .33507 L
.10255 .33507 L
.10279 .33518 L
.10301 .33531 L
.1032 .33545 L
.10336 .3356 L
.10352 .33575 L
.10368 .33587 L
.10384 .33596 L
.10395 .33606 L
.104 .33613 L
.10397 .33614 L
.10389 .33607 L
.10373 .33589 L
Mistroke
.10349 .33557 L
.10315 .33509 L
.10269 .33446 L
.10214 .33367 L
.10149 .33274 L
.10084 .33177 L
.10009 .33067 L
.09935 .32958 L
.09861 .32852 L
.0979 .32751 L
.09724 .32659 L
.0967 .32579 L
.09625 .32506 L
.09593 .32443 L
.09571 .32388 L
.0956 .3234 L
.09557 .32297 L
.09558 .32255 L
.0956 .32212 L
.09562 .3217 L
.09563 .32131 L
.09564 .32093 L
.09565 .32053 L
.09565 .32006 L
.09567 .31954 L
.09572 .31895 L
.09581 .31832 L
.09598 .3176 L
.09623 .31677 L
.09659 .31581 L
.09706 .3147 L
.09764 .3134 L
.09833 .31201 L
.09914 .31029 L
.10007 .30852 L
.10104 .30658 L
.1021 .30455 L
.10321 .30252 L
.10433 .30041 L
.10553 .29835 L
.10669 .29638 L
.10793 .29436 L
.10919 .29239 L
.1105 .29042 L
.11183 .28849 L
.11315 .2865 L
.11452 .28459 L
.11577 .28267 L
.11708 .28077 L
.11836 .27888 L
Mistroke
.11973 .27694 L
.1212 .27488 L
.12254 .27286 L
.12396 .2707 L
.12546 .26855 L
.12684 .26635 L
.12837 .26408 L
.12975 .26203 L
.13123 .25991 L
.13302 .25762 L
.13453 .25551 L
.13609 .25327 L
.1378 .25093 L
.13962 .24867 L
.1412 .24637 L
.14272 .2443 L
.14422 .24223 L
.14562 .24018 L
.14704 .23826 L
.14852 .23624 L
.14987 .23429 L
.15129 .23242 L
.15279 .23047 L
.15417 .22842 L
.15561 .22635 L
.15691 .22452 L
.15827 .22263 L
.15972 .22077 L
.16107 .21896 L
.16255 .21709 L
.16393 .21527 L
.16535 .21329 L
.1668 .21144 L
.16812 .20948 L
.16942 .20753 L
.17079 .20547 L
.17215 .20331 L
.17363 .20132 L
.1751 .19916 L
.17668 .19695 L
.17816 .19482 L
.17971 .19276 L
.1811 .19072 L
.18236 .18897 L
.18365 .1874 L
.18474 .18577 L
.18575 .18443 L
.18667 .18318 L
.18747 .18205 L
.18821 .18103 L
Mistroke
.18891 .18006 L
.18959 .17916 L
.19028 .17821 L
.19106 .17726 L
.19198 .17624 L
.19302 .17508 L
.19422 .17372 L
.19561 .17236 L
.1971 .17085 L
.1987 .16918 L
.20048 .16737 L
.20235 .16536 L
.20426 .16345 L
.20621 .16127 L
.20818 .15904 L
.21012 .15657 L
.21197 .15436 L
.21373 .1521 L
.21539 .1498 L
.21684 .14795 L
.21817 .14619 L
.21928 .14462 L
.22024 .14341 L
.22101 .14246 L
.22162 .14179 L
.2221 .14136 L
.22244 .14113 L
.22263 .14106 L
.22267 .1411 L
.22256 .14121 L
.22234 .14132 L
.22199 .14143 L
.22155 .1415 L
.22104 .14155 L
.22049 .14157 L
.21993 .14155 L
.21938 .14154 L
.21885 .14152 L
.21831 .1415 L
.2178 .14148 L
.21733 .14147 L
.21696 .14145 L
.2167 .14145 L
.21658 .14145 L
.21657 .14147 L
.21665 .14153 L
.21681 .14162 L
.21705 .14171 L
.21736 .14178 L
.21776 .14183 L
Mistroke
.21828 .14184 L
.21894 .14177 L
.21975 .1416 L
.22073 .14133 L
.22182 .14092 L
.22307 .14036 L
.22451 .13961 L
.22599 .13872 L
.22771 .13765 L
.22945 .13641 L
.23139 .13505 L
.23338 .13358 L
.23539 .13214 L
.23748 .13078 L
.23931 .12949 L
.24115 .12832 L
.24283 .12731 L
.24458 .12638 L
.24604 .1256 L
.2476 .12489 L
.24902 .12424 L
.2505 .12359 L
.25203 .12291 L
.25353 .12217 L
.25521 .12134 L
.25686 .12047 L
.25874 .11944 L
.2609 .11826 L
.26287 .11698 L
.26508 .11564 L
.26754 .11423 L
.26972 .11282 L
.2721 .1114 L
.27447 .1101 L
.27681 .10881 L
.27909 .10752 L
.28136 .10626 L
.28351 .10501 L
.28582 .10369 L
.28798 .10229 L
.29008 .10091 L
.29251 .09949 L
.29461 .09807 L
.29693 .09663 L
.29924 .09527 L
.30146 .094 L
.30371 .09283 L
.30552 .09185 L
.30734 .09105 L
.30874 .09039 L
Mistroke
.30995 .08988 L
.31096 .08954 L
.31173 .08936 L
.31235 .0893 L
.31282 .08931 L
.31317 .08933 L
.31345 .08935 L
.31371 .08932 L
.31403 .0892 L
.31448 .08897 L
.31513 .0886 L
.31594 .08809 L
.31701 .08746 L
.31834 .08669 L
.31981 .08579 L
.32155 .0848 L
.32344 .08378 L
.32548 .08266 L
.32771 .08144 L
.32982 .08024 L
.33219 .07903 L
.3343 .07777 L
.33657 .07658 L
.33878 .07534 L
.34102 .07414 L
.34318 .07303 L
.34534 .0719 L
.3473 .07077 L
.34928 .06969 L
.35124 .06864 L
.35315 .06757 L
.35516 .06649 L
.35713 .0654 L
.3593 .06429 L
.36145 .06323 L
.36373 .06221 L
.36612 .06117 L
.36854 .06009 L
.37111 .05905 L
.37343 .05805 L
.37595 .05705 L
.37834 .05608 L
.38076 .05518 L
.38328 .05435 L
.38551 .05362 L
.38785 .05301 L
.39009 .05251 L
.39231 .05209 L
.39447 .05178 L
.39663 .05159 L
Mistroke
.39868 .05151 L
.40081 .05152 L
.40276 .05156 L
.40474 .05162 L
.40666 .05164 L
.40849 .0516 L
.41025 .05147 L
.4119 .05124 L
.41341 .05091 L
.4148 .05051 L
.41612 .05008 L
.41734 .04967 L
.41854 .04927 L
.41973 .04887 L
.421 .04849 L
.42234 .04816 L
.42387 .04791 L
.42553 .04777 L
.42737 .04772 L
.42943 .04775 L
.43157 .04785 L
.43392 .04799 L
.43617 .04814 L
.43873 .04828 L
.44119 .04839 L
.44383 .04848 L
.44632 .04856 L
.44865 .04864 L
.45088 .04872 L
.4529 .04878 L
.4547 .04884 L
.45621 .04889 L
.45754 .04893 L
.45855 .04896 L
.45936 .04899 L
.45996 .04901 L
.46035 .04902 L
.46055 .04902 L
.46059 .04902 L
.4605 .04902 L
.46035 .04901 L
.46021 .04901 L
.46016 .04901 L
.46029 .04901 L
.46068 .04902 L
.46135 .04904 L
.4623 .04907 L
.46356 .04911 L
.46496 .04916 L
.46675 .04921 L
Mistroke
.46874 .04928 L
.47098 .04935 L
.47343 .04943 L
.476 .04951 L
.47883 .04959 L
.48156 .04968 L
.48428 .04976 L
.48711 .04985 L
.48992 .04993 L
.49289 .05002 L
.49564 .0501 L
.4986 .05019 L
.50164 .05028 L
.50477 .05036 L
.50776 .05045 L
.51098 .05054 L
.51426 .05063 L
.51749 .05073 L
.52078 .05082 L
.52415 .05091 L
.52757 .051 L
.53068 .05109 L
.53396 .05118 L
.53709 .05127 L
.54029 .05135 L
.54338 .05143 L
.54649 .05151 L
.54942 .05159 L
.55231 .05167 L
.55518 .05174 L
.55789 .05181 L
.56067 .05188 L
.56327 .05195 L
.56591 .05202 L
.56846 .05208 L
.57095 .05215 L
.57342 .05221 L
.57574 .05227 L
.57787 .05233 L
.57989 .05238 L
.58165 .05242 L
.58324 .05246 L
.58461 .05247 L
.58572 .05245 L
.58663 .0524 L
.58733 .05235 L
.5878 .05233 L
.58803 .05232 L
.58804 .05237 L
.5879 .05247 L
Mistroke
.58768 .05264 L
.5875 .05291 L
.58742 .05329 L
.58751 .0538 L
.58781 .05443 L
.58838 .05515 L
.58913 .05592 L
.59014 .05677 L
.59143 .05771 L
.59293 .05871 L
.59475 .05973 L
.59667 .06072 L
.59888 .06173 L
.60137 .06274 L
.60383 .06367 L
.6067 .06456 L
.60936 .0654 L
.61237 .06617 L
.61511 .06684 L
.6182 .0674 L
.62089 .06786 L
.6237 .06827 L
.62617 .06861 L
.62853 .06888 L
.63066 .06908 L
.63247 .06921 L
.63394 .06932 L
.63518 .06941 L
.63614 .0695 L
.6369 .06965 L
.6375 .06985 L
.63799 .07015 L
.63845 .07061 L
.63897 .07119 L
.63962 .07183 L
.6404 .07264 L
.64141 .07361 L
.64265 .07475 L
.64413 .07598 L
.64584 .07739 L
.64772 .07888 L
.64975 .08044 L
.6519 .0822 L
.65416 .08383 L
.6565 .0856 L
.65891 .08739 L
.66138 .08929 L
.6639 .09108 L
.66654 .093 L
.66905 .09481 L
Mistroke
.67168 .09668 L
.67426 .09852 L
.67688 .10052 L
.6796 .10238 L
.68223 .10451 L
.68481 .10643 L
.68762 .1085 L
.69008 .11048 L
.69263 .11244 L
.69518 .11446 L
.69745 .11621 L
.69968 .11791 L
.70202 .11969 L
.70395 .12117 L
.70589 .12259 L
.70785 .1239 L
.70979 .12506 L
.71171 .12608 L
.71363 .12693 L
.7156 .12759 L
.71773 .12813 L
.71986 .12857 L
.722 .12891 L
.72439 .12919 L
.72679 .12941 L
.72945 .12956 L
.7322 .12964 L
.73517 .12968 L
.73806 .12967 L
.74109 .12964 L
.74413 .12959 L
.74735 .12953 L
.75022 .12947 L
.75313 .12942 L
.75615 .1294 L
.75887 .12942 L
.76175 .1295 L
.7645 .12966 L
.76735 .12991 L
.76986 .13028 L
.77246 .13078 L
.77499 .13142 L
.77763 .13219 L
.77985 .13306 L
.78221 .13405 L
.78457 .13519 L
.787 .1364 L
.78925 .13772 L
.79161 .13909 L
.79379 .14049 L
Mistroke
.79581 .14197 L
.79777 .14351 L
.79958 .14505 L
.80127 .14667 L
.80281 .1483 L
.80421 .15005 L
.80557 .15183 L
.80686 .15376 L
.80815 .15567 L
.80945 .15769 L
.8108 .15986 L
.81225 .16194 L
.81375 .1642 L
.81531 .16645 L
.81698 .16884 L
.81866 .1712 L
.82044 .17354 L
.82234 .17602 L
.82421 .17849 L
.82616 .18105 L
.82822 .18361 L
.83013 .18629 L
.83215 .18888 L
.83409 .19152 L
.83598 .19407 L
.83781 .19657 L
.83954 .19887 L
.84117 .20104 L
.84267 .20308 L
.84399 .20478 L
.84515 .20629 L
.84616 .20757 L
.84695 .20856 L
.84756 .20934 L
.848 .2099 L
.84829 .21026 L
.84847 .21047 L
.84858 .21058 L
.84862 .21061 L
.84858 .21055 L
.84848 .21043 L
.8483 .21025 L
.84807 .21001 L
.84779 .20971 L
.84747 .20938 L
.84711 .20904 L
.84673 .20868 L
.84632 .20827 L
.84588 .2078 L
.84543 .20727 L
Mistroke
.84495 .2067 L
.84445 .20611 L
.84395 .20555 L
.84347 .20505 L
.84303 .20464 L
.84263 .20431 L
.84229 .20406 L
.84203 .20387 L
.84182 .20378 L
.84168 .20377 L
.84164 .20386 L
.84171 .20408 L
.84193 .20445 L
.84232 .20502 L
.84289 .20583 L
.8436 .20688 L
.84449 .20817 L
.8455 .20955 L
.84666 .21118 L
.84801 .21307 L
.84938 .21497 L
.85092 .21716 L
.8525 .21956 L
.8542 .22219 L
.85581 .22481 L
.85738 .22773 L
.85889 .23033 L
.86034 .23324 L
.86164 .23604 L
.86285 .23912 L
.86386 .24231 L
.86475 .24521 L
.86548 .24855 L
.86602 .25181 L
.86633 .25515 L
.86643 .25837 L
.86636 .26168 L
.86615 .26508 L
.86584 .26842 L
.86547 .27193 L
.86503 .27547 L
.86454 .27887 L
.86402 .28262 L
.86347 .28609 L
.86285 .28947 L
.86218 .29314 L
.86146 .29652 L
.86069 .29981 L
.85986 .30332 L
.85898 .30664 L
Mistroke
.85801 .31 L
.85697 .31341 L
.85581 .31672 L
.85452 .31968 L
.85307 .32275 L
.85148 .3257 L
.84984 .32853 L
.84797 .3313 L
.84589 .33402 L
.84398 .3366 L
.84187 .33908 L
.83981 .34152 L
.83777 .34391 L
.83578 .34634 L
.83414 .34862 L
.8326 .35103 L
.83121 .35344 L
.83014 .35598 L
.82929 .35857 L
.8287 .36129 L
.82839 .36423 L
.82833 .36742 L
.82848 .3707 L
.82881 .37422 L
.82932 .37779 L
.82998 .38171 L
.83079 .38506 L
.83173 .38869 L
.83284 .39207 L
.83407 .3954 L
.83548 .39858 L
.83702 .40146 L
.83876 .40412 L
.84049 .40666 L
.84235 .40901 L
.84428 .41132 L
.84625 .41364 L
.84831 .41602 L
.85038 .41851 L
.85244 .42118 L
.85458 .42418 L
.8568 .42694 L
.85894 .43003 L
.86126 .43336 L
.86335 .43644 L
.86559 .43956 L
.86811 .44302 L
.87024 .44585 L
.87256 .44872 L
.87495 .45158 L
Mistroke
.87755 .45431 L
.87982 .4569 L
.88232 .45935 L
.88494 .46176 L
.8878 .46423 L
.89025 .46653 L
.89298 .46903 L
.8958 .47156 L
.89889 .47422 L
.90177 .477 L
.90484 .47995 L
.90813 .48275 L
.91102 .48553 L
.91408 .48808 L
.917 .49044 L
.91995 .49247 L
.92255 .49419 L
.92485 .49563 L
.92702 .49666 L
.92898 .49737 L
.9307 .49772 L
.93203 .49772 L
.93317 .49734 L
.93409 .49664 L
.93478 .49567 L
.93525 .49446 L
.93556 .49311 L
.93573 .49171 L
.9358 .49026 L
.93581 .48879 L
.93577 .48728 L
.93569 .48568 L
.93559 .484 L
.9355 .48214 L
.9354 .4801 L
.93529 .47784 L
.93517 .47539 L
.93506 .47268 L
.93495 .46997 L
.93485 .46705 L
.93474 .46388 L
.93462 .46067 L
.93451 .45722 L
.93439 .45364 L
.93426 .45013 L
.93414 .44647 L
.93401 .44267 L
.93388 .43902 L
.93378 .43527 L
.93369 .43162 L
Mistroke
.93363 .42803 L
.93357 .42458 L
.93348 .42115 L
.93336 .41848 L
.93317 .41582 L
.93292 .41338 L
.93259 .41163 L
.9322 .41017 L
.93177 .40903 L
.93134 .40827 L
.93095 .40785 L
.93061 .40764 L
.9303 .40748 L
.93004 .40718 L
.92981 .4066 L
.92961 .40554 L
.92942 .40393 L
.92925 .40165 L
.92908 .39908 L
.92891 .39573 L
.92872 .3917 L
.92848 .38771 L
.92817 .3833 L
.92775 .37853 L
.92724 .37405 L
.92665 .36941 L
.92604 .3646 L
.92543 .36045 L
.92483 .35634 L
.92424 .35233 L
.92366 .34867 L
.92311 .34504 L
.92257 .34155 L
.92201 .33807 L
.92142 .3347 L
.92078 .33118 L
.92012 .32816 L
.91939 .32499 L
.91859 .32168 L
.91775 .31881 L
.91683 .31588 L
.91586 .313 L
.9148 .3103 L
.91361 .30756 L
.91232 .30493 L
.91093 .30234 L
.90935 .29959 L
.90768 .2969 L
.90588 .29409 L
.90395 .29122 L
Mistroke
.90183 .28814 L
.8998 .28519 L
.8977 .28209 L
.89528 .27865 L
.89317 .27568 L
.89084 .27231 L
.88847 .26898 L
.88605 .26541 L
.88342 .26195 L
.88108 .25842 L
.87855 .25478 L
.87613 .25101 L
.87346 .24728 L
.87083 .24305 L
.86823 .2393 L
.86565 .23545 L
.8629 .23136 L
.86018 .22724 L
.85754 .22326 L
.85513 .21954 L
.85284 .21601 L
.85072 .21265 L
.84871 .20967 L
.84679 .2068 L
.84499 .20404 L
.84335 .20152 L
.8417 .19915 L
.84004 .19676 L
.83835 .19442 L
.83661 .19195 L
.83491 .18959 L
.83316 .18703 L
.83122 .18435 L
.82909 .18132 L
.82685 .17833 L
.82444 .17502 L
.8218 .17157 L
.81923 .16818 L
.81649 .16466 L
.81414 .16134 L
.81181 .15837 L
.80974 .15555 L
.80787 .15307 L
.80616 .15086 L
.80486 .14913 L
.80376 .14765 L
.80289 .14651 L
.80226 .14567 L
.80186 .1451 L
.80167 .1448 L
Mistroke
.80167 .14472 L
.80181 .14482 L
.80201 .14501 L
.80222 .14523 L
.80238 .14542 L
.80245 .14552 L
.80241 .14547 L
.80226 .1453 L
.80202 .14504 L
.80172 .14476 L
.80136 .14448 L
.80103 .14425 L
.80077 .14407 L
.80053 .14392 L
.80025 .14378 L
.79989 .14361 L
.79945 .1434 L
.79891 .14313 L
.79822 .14275 L
.79734 .14226 L
.79625 .14164 L
.79488 .14095 L
.79321 .14003 L
.79129 .13888 L
.78954 .13757 L
.78728 .13598 L
.78465 .13425 L
.78203 .13239 L
.77926 .13066 L
.77653 .12897 L
.77424 .12758 L
.77209 .12639 L
.77034 .12543 L
.76888 .12472 L
.76783 .12424 L
.76716 .12399 L
.76686 .12396 L
.76686 .12415 L
.76711 .12451 L
.76757 .12499 L
.76817 .12554 L
.76882 .1261 L
.76949 .12665 L
.77013 .12722 L
.77071 .1278 L
.77118 .1284 L
.77153 .12901 L
.77183 .12964 L
.7721 .13028 L
.77238 .13092 L
Mistroke
.77267 .13153 L
.773 .1321 L
.77341 .13259 L
.7739 .13301 L
.7745 .13337 L
.77521 .13368 L
.77603 .13395 L
.77697 .13417 L
.77801 .13435 L
.77914 .13448 L
.78033 .13457 L
.78151 .13465 L
.78269 .13473 L
.78386 .13484 L
.78496 .13499 L
.78598 .1352 L
.78687 .13543 L
.78765 .13566 L
.78827 .1359 L
.78876 .13612 L
.78913 .13633 L
.78939 .1365 L
.78954 .13664 L
.78961 .13674 L
.78962 .13679 L
.78959 .13681 L
.78953 .13679 L
.78946 .13676 L
.78939 .13672 L
.78935 .13669 L
.78933 .13667 L
.78931 .13664 L
.78925 .13657 L
.78915 .13645 L
.78903 .13632 L
.78891 .13621 L
.78882 .13615 L
.78882 .13618 L
.78892 .13634 L
.78918 .13666 L
.7896 .13715 L
.79023 .13782 L
.79106 .13866 L
.79209 .13967 L
.79321 .14079 L
.79452 .1422 L
.79605 .14372 L
.79766 .14546 L
.79947 .14736 L
.80138 .14942 L
Mistroke
.80336 .1515 L
.80538 .15375 L
.80746 .15603 L
.80951 .15845 L
.81168 .16104 L
.81363 .16368 L
.81575 .16637 L
.81783 .1691 L
.81987 .17203 L
.82204 .17481 L
.82411 .17768 L
.82621 .18065 L
.82824 .18345 L
.83037 .18645 L
.83251 .18943 L
.83469 .19251 L
.83679 .19581 L
.83881 .19873 L
.84087 .20191 L
.84295 .20523 L
.84495 .20827 L
.84696 .21142 L
.84905 .21443 L
.85083 .21737 L
.85257 .2201 L
.85419 .22254 L
.85563 .22456 L
.85675 .22627 L
.85778 .22764 L
.85867 .22868 L
.8594 .22952 L
.86006 .23026 L
.86068 .23097 L
.86129 .23173 L
.86193 .23264 L
.8626 .23375 L
.86335 .2352 L
.86422 .23692 L
.8653 .23914 L
.86664 .24182 L
.8682 .24502 L
.87006 .24878 L
.87197 .25283 L
.87408 .25737 L
.8762 .26212 L
.87832 .26737 L
.88022 .27227 L
.88203 .27743 L
.8838 .28322 L
.88519 .28787 L
Mistroke
.88644 .29312 L
.88751 .2982 L
.88836 .30351 L
.88896 .3083 L
.88934 .31341 L
.88953 .31835 L
.88955 .32339 L
.88942 .32848 L
.88915 .33382 L
.88879 .33932 L
.88836 .34484 L
.88786 .35047 L
.88728 .35636 L
.88657 .36217 L
.88573 .3682 L
.88476 .37419 L
.88369 .37993 L
.88256 .38516 L
.88138 .39057 L
.88018 .39576 L
.87898 .40084 L
.87774 .40603 L
.87648 .41082 L
.87515 .41583 L
.87378 .42076 L
.87231 .42577 L
.87074 .43073 L
.86908 .43581 L
.86727 .44083 L
.86543 .44586 L
.86346 .45061 L
.86132 .45553 L
.85904 .45992 L
.85646 .46444 L
.85381 .46865 L
.85069 .47287 L
.84755 .47654 L
.84422 .48004 L
.84078 .48321 L
.83718 .4861 L
.83368 .48858 L
.83021 .4908 L
.82648 .49262 L
.82323 .49417 L
.8196 .49549 L
.81583 .49659 L
.81269 .49752 L
.80932 .49835 L
.80555 .49918 L
.80228 .50014 L
Mistroke
.79841 .50132 L
.79513 .50269 L
.79131 .50439 L
.78775 .50641 L
.78416 .50876 L
.78045 .51142 L
.77688 .51423 L
.77378 .51731 L
.77059 .52045 L
.76771 .52376 L
.76489 .52716 L
.76236 .53045 L
.75978 .53388 L
.75731 .53722 L
.75472 .54069 L
.75195 .54426 L
.74941 .54789 L
.74665 .55163 L
.74371 .55539 L
.74111 .55925 L
.73829 .56327 L
.73602 .56729 L
.73384 .5717 L
.73184 .57586 L
.73035 .58027 L
.72916 .58487 L
.7283 .58921 L
.72778 .59392 L
.72755 .59832 L
.72754 .60301 L
.72768 .60745 L
.72793 .61215 L
.72821 .61731 L
.72849 .62185 L
.72878 .62683 L
.72905 .63168 L
.7293 .63668 L
.7295 .64203 L
.72965 .64673 L
.72973 .65206 L
.72971 .65744 L
.72959 .66233 L
.72934 .66783 L
.72896 .67323 L
.72848 .6791 L
.72789 .68402 L
.72725 .68911 L
.72656 .69434 L
.72583 .69903 L
.72512 .70406 L
Mistroke
.72449 .70908 L
.72398 .71431 L
.72365 .71936 L
.72355 .72457 L
.72367 .72972 L
.72402 .73521 L
.72459 .74008 L
.72533 .74522 L
.72619 .75063 L
.72714 .75558 L
.7281 .761 L
.72904 .76569 L
.72987 .77066 L
.73055 .77546 L
.73102 .78016 L
.73122 .78505 L
.73112 .78949 L
.73068 .79433 L
.7299 .79887 L
.72883 .80353 L
.72746 .80842 L
.72587 .81297 L
.72405 .81786 L
.72202 .82287 L
.71985 .82743 L
.71756 .83227 L
.7152 .83718 L
.71287 .84184 L
.71057 .84652 L
.70835 .85142 L
.7062 .85579 L
.70409 .86048 L
.7021 .86513 L
.70018 .86999 L
.69838 .87442 L
.69668 .87918 L
.6951 .88345 L
.69366 .88771 L
.69227 .89153 L
.69083 .89526 L
.68935 .89855 L
.68769 .90179 L
.68584 .90462 L
.68371 .90736 L
.6812 .90998 L
.67853 .9123 L
.67533 .91454 L
.67195 .91651 L
.66801 .91838 L
.66423 .92011 L
Mistroke
.65991 .92175 L
.65546 .92327 L
.65083 .92462 L
.64611 .9258 L
.64139 .92678 L
.63663 .92758 L
.63159 .9282 L
.62729 .92867 L
.62268 .92905 L
.61814 .9294 L
.6134 .92976 L
.60901 .93018 L
.6045 .93067 L
.59968 .93124 L
.59548 .9319 L
.59096 .93264 L
.58655 .93343 L
.58211 .93426 L
.5776 .93516 L
.5734 .93606 L
.56917 .937 L
.56518 .93793 L
.5613 .93882 L
.55728 .93963 L
.55376 .94035 L
.55015 .94097 L
.54666 .94147 L
.54336 .9419 L
.54007 .94225 L
.5369 .94252 L
.53355 .9427 L
.53018 .9428 L
.5265 .94282 L
.5226 .94276 L
.51838 .94258 L
.51385 .94236 L
.50874 .94211 L
.5045 .94185 L
.49973 .94158 L
.49418 .94136 L
.48972 .94119 L
.4851 .94112 L
.4802 .94118 L
.47545 .94135 L
.4709 .94165 L
.46612 .9421 L
.462 .94269 L
.45776 .94333 L
.45362 .94393 L
.44952 .94448 L
Mistroke
.44551 .94493 L
.44143 .94525 L
.43747 .94543 L
.43373 .94544 L
.4298 .94529 L
.42642 .9449 L
.42291 .94424 L
.41942 .94328 L
.4161 .94219 L
.41264 .94095 L
.40937 .93961 L
.40596 .93831 L
.40238 .937 L
.39897 .93584 L
.39529 .93472 L
.39142 .93354 L
.38788 .93243 L
.38407 .93127 L
.38024 .93005 L
.37653 .92882 L
.37294 .92766 L
.36963 .92648 L
.36659 .92546 L
.36388 .92447 L
.36144 .92355 L
.35937 .92268 L
.35771 .92191 L
.35633 .92123 L
.35527 .92067 L
.35455 .92028 L
.35415 .92003 L
.35403 .9199 L
.35411 .91987 L
.35429 .91989 L
.35448 .91994 L
.3546 .91998 L
.35457 .92 L
.35428 .91996 L
.35365 .91983 L
.35266 .91957 L
.35133 .91918 L
.34963 .91869 L
.34763 .91809 L
.34529 .91741 L
.34263 .91665 L
.33972 .91582 L
.33666 .915 L
.33356 .91411 L
.33037 .91305 L
.32743 .91201 L
Mistroke
.32445 .91086 L
.32155 .90961 L
.31887 .90828 L
.31625 .90698 L
.31372 .9056 L
.31123 .90432 L
.30874 .90302 L
.30616 .90171 L
.30368 .90044 L
.30108 .89918 L
.29839 .89802 L
.29565 .89689 L
.29291 .8958 L
.29021 .8948 L
.28766 .89391 L
.28525 .8931 L
.28303 .89233 L
.28119 .8916 L
.27966 .89093 L
.2785 .89034 L
.27769 .88983 L
.27714 .88936 L
.27678 .88891 L
.27653 .88849 L
.27626 .88809 L
.27589 .8877 L
.27534 .88733 L
.27458 .88696 L
.27355 .88662 L
.27226 .88632 L
.27071 .88604 L
.2691 .88575 L
.26732 .8854 L
.26532 .88497 L
.26303 .88445 L
.26083 .88386 L
.25853 .88323 L
.25614 .88253 L
.25379 .88177 L
.2514 .88089 L
.24895 .87986 L
.24658 .87869 L
.24413 .87737 L
.24153 .8758 L
.23895 .87404 L
.23635 .87215 L
.23373 .87012 L
.23122 .86796 L
.22877 .86591 L
.22639 .86363 L
Mistroke
.22417 .86154 L
.22199 .8593 L
.2199 .85702 L
.2179 .85478 L
.21595 .85257 L
.2141 .85038 L
.21223 .84835 L
.21038 .84639 L
.20851 .84445 L
.20674 .84263 L
.20501 .84071 L
.20343 .83898 L
.2019 .83725 L
.20047 .83553 L
.19916 .83387 L
.19791 .8322 L
.19662 .83063 L
.19535 .82903 L
.19399 .82739 L
.1925 .82584 L
.19086 .82423 L
.18927 .82259 L
.18742 .82089 L
.1855 .81918 L
.18342 .81742 L
.18098 .81555 L
.17877 .81367 L
.17632 .81162 L
.17368 .80944 L
.17093 .80703 L
.16796 .8044 L
.16505 .80157 L
.16208 .79853 L
.15874 .79517 L
.15568 .79178 L
.15223 .78841 L
.14902 .78489 L
.14544 .78099 L
.14242 .77794 L
.13915 .77449 L
.13592 .77087 L
.13322 .76802 L
.13047 .76511 L
.12784 .76221 L
.12544 .75954 L
.12318 .75697 L
.12107 .75447 L
.11906 .75203 L
.11708 .74947 L
.11525 .74705 L
Mistroke
.11345 .74445 L
.11154 .74172 L
.10962 .73886 L
.10761 .73601 L
.10576 .73316 L
.10395 .73033 L
.10225 .7277 L
.10065 .72543 L
.0992 .7232 L
.09794 .72123 L
.09678 .71944 L
.0958 .71802 L
.09492 .71683 L
.09412 .7158 L
.09341 .7149 L
.09278 .71402 L
.0922 .71309 L
.09162 .71204 L
.09103 .71081 L
.09046 .70932 L
.08989 .70763 L
.08935 .70596 L
.08881 .70429 L
.08832 .70236 L
.08785 .70057 L
.08741 .69867 L
.08698 .69682 L
.08655 .69485 L
.08613 .69304 L
.0857 .69117 L
.08527 .68922 L
.08485 .68725 L
.08445 .68551 L
.08401 .68363 L
.08355 .68163 L
.08307 .67967 L
.08262 .67759 L
.08225 .67555 L
.08199 .6735 L
.08185 .67154 L
.08184 .66958 L
.08192 .66784 L
.08208 .66617 L
.08229 .6646 L
.08251 .66316 L
.08271 .66175 L
.08287 .66027 L
.08297 .65872 L
.08301 .65712 L
.08302 .65538 L
Mistroke
.08297 .65351 L
.08287 .65144 L
.08272 .64939 L
.08253 .64713 L
.08225 .64488 L
.082 .64247 L
.08168 .6398 L
.08129 .63727 L
.08084 .63435 L
.08033 .63157 L
.07974 .62859 L
.07906 .62532 L
.07837 .62236 L
.0776 .61948 L
.07679 .61622 L
.07604 .61334 L
.07522 .61013 L
.07454 .60714 L
.07387 .60421 L
.07322 .60126 L
.07262 .59839 L
.07207 .59551 L
.07158 .59287 L
.07113 .58999 L
.07068 .58727 L
.07023 .5842 L
.06979 .58141 L
.06937 .57831 L
.06899 .57523 L
.06857 .57177 L
.06811 .5687 L
.06769 .56529 L
.06727 .56179 L
.06684 .55876 L
.06643 .55552 L
.06607 .55237 L
.06579 .54946 L
.06557 .54656 L
.06542 .54418 L
.06528 .54189 L
.06512 .53988 L
.06494 .53787 L
.06472 .53588 L
.06448 .53404 L
.06423 .53215 L
.06398 .53024 L
.06375 .52857 L
.06355 .52682 L
.06337 .52523 L
.06319 .52366 L
Mistroke
.06301 .52221 L
.06282 .5208 L
.06265 .5195 L
.06252 .51846 L
.06243 .51759 L
.06239 .51692 L
.06238 .51647 L
.06241 .51624 L
.06245 .5162 L
.06249 .51628 L
.06252 .51642 L
.06253 .51658 L
.06252 .5167 L
.06252 .51675 L
.06252 .51668 L
.06253 .51643 L
.06255 .51596 L
.06257 .51528 L
.0626 .51439 L
.06263 .51325 L
.06266 .51185 L
.06268 .51031 L
.0627 .50856 L
.06275 .50662 L
.06284 .50476 L
.06297 .50282 L
.06314 .50084 L
.06333 .49923 L
.06352 .49773 L
.06372 .49634 L
.06392 .49508 L
.06413 .494 L
.06437 .49301 L
.0646 .49207 L
.06484 .49112 L
.06509 .49008 L
.06535 .48895 L
.0656 .48762 L
.06581 .48607 L
.06598 .48454 L
.06613 .48265 L
.06627 .48084 L
.06639 .47888 L
.06652 .47693 L
.06665 .47502 L
.06677 .47338 L
.06689 .4719 L
.06696 .47063 L
.067 .46963 L
.06701 .4688 L
Mistroke
.06699 .46815 L
.06699 .46765 L
.06699 .46728 L
.067 .46703 L
.067 .46688 L
.06701 .46677 L
.06701 .46665 L
.06702 .46647 L
.06703 .46619 L
.06704 .46581 L
.06705 .46533 L
.06706 .46474 L
.06705 .46409 L
.06703 .46341 L
.06701 .46276 L
.06701 .46221 L
.06703 .46177 L
.06708 .46147 L
.06716 .46132 L
.06728 .46129 L
.06744 .46139 L
.06766 .46158 L
.06793 .46185 L
.06827 .46215 L
.06866 .46244 L
.06909 .46265 L
.06955 .46279 L
.07004 .46278 L
.07054 .46258 L
.07102 .46225 L
.07144 .46175 L
.07182 .46114 L
.07214 .46047 L
.07239 .45982 L
.07257 .45927 L
.07267 .45884 L
.07273 .45859 L
.07275 .45848 L
.07275 .45856 L
.07273 .45875 L
.07272 .459 L
.07275 .45932 L
.07286 .45964 L
.07307 .45991 L
.07338 .46009 L
.07379 .46016 L
.07428 .46008 L
.07486 .45984 L
.07553 .45945 L
.07627 .45895 L
Mistroke
.07707 .4584 L
.07781 .45786 L
.07869 .45735 L
.07947 .45689 L
.08026 .4565 L
.08109 .45616 L
.08195 .45589 L
.08279 .45566 L
.08365 .45542 L
.08453 .45511 L
.08544 .45469 L
.08626 .45414 L
.08713 .45343 L
.08802 .45257 L
.08888 .45152 L
.08975 .45033 L
.09059 .44921 L
.09131 .44806 L
.09198 .44685 L
.0926 .44584 L
.09319 .44493 L
.09377 .44416 L
.09433 .44356 L
.09492 .44316 L
.09557 .44293 L
.09631 .44282 L
.09712 .44279 L
.09789 .44278 L
.0988 .44275 L
.09972 .44269 L
.10067 .4426 L
.10166 .44247 L
.1025 .44229 L
.1033 .4421 L
.10404 .44191 L
.10466 .44169 L
.10515 .44143 L
.10552 .44111 L
.10577 .44072 L
.10593 .44024 L
.10603 .43961 L
.10611 .43878 L
.10615 .43771 L
.10618 .43643 L
.10621 .43483 L
.10626 .43283 L
.10634 .43077 L
.10644 .42824 L
.10659 .42558 L
.10676 .42265 L
Mistroke
.10689 .41964 L
.10696 .4161 L
.10696 .41313 L
.10689 .40966 L
.10672 .40636 L
.10644 .40299 L
.10603 .39937 L
.10552 .39624 L
.10491 .39285 L
.10419 .38972 L
.10339 .3866 L
.10257 .38346 L
.1017 .38101 L
.10084 .37848 L
.10012 .37606 L
.09937 .37375 L
.09882 .37136 L
.09836 .36936 L
.09799 .36728 L
.09774 .36497 L
.09758 .36242 L
.0975 .35995 L
.09744 .3576 L
.09737 .35499 L
.09731 .35196 L
.09723 .34906 L
.09712 .34584 L
.09696 .34285 L
.09675 .33985 L
.09655 .3368 L
.09634 .3338 L
.09614 .33123 L
.09594 .32878 L
.09579 .32655 L
.09567 .32471 L
.09559 .32302 L
.09556 .32153 L
.09559 .3203 L
.09567 .31924 L
.09576 .31835 L
.09584 .31768 L
.09591 .31717 L
.09594 .31681 L
.09596 .31658 L
.09596 .31646 L
.09595 .31643 L
.09594 .31646 L
.09594 .31651 L
.09594 .31656 L
.09593 .31661 L
Mistroke
.09593 .31665 L
.09593 .31669 L
.09593 .31672 L
.09593 .31674 L
.09593 .31674 L
.09593 .31675 L
.09591 .31678 L
.09588 .31683 L
.09583 .31691 L
.09579 .31698 L
.09576 .31704 L
.09575 .31706 L
.09579 .31702 L
.0959 .31689 L
.09608 .31664 L
.09631 .31626 L
.09658 .31575 L
.09687 .3151 L
.09719 .31435 L
.09753 .31356 L
.0979 .31274 L
.09827 .31192 L
.09865 .31107 L
.09905 .31021 L
.0994 .3094 L
.09975 .30861 L
.10012 .30786 L
.10047 .30715 L
.10079 .30649 L
.10113 .3059 L
.1015 .30537 L
.1019 .30488 L
.10233 .30444 L
.10274 .30403 L
.10312 .30365 L
.10347 .30329 L
.10378 .30295 L
.10403 .30267 L
.10422 .30248 L
.10435 .30237 L
.10444 .30234 L
.1045 .30238 L
.10451 .30245 L
.1045 .30252 L
.10445 .30258 L
.10441 .30261 L
.10437 .30261 L
.10436 .30261 L
.10435 .30261 L
.10435 .30261 L
Mistroke
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30258 L
.10435 .30253 L
.10436 .30246 L
.10436 .30239 L
.10436 .30235 L
.10436 .30237 L
.10436 .30245 L
.10435 .30264 L
.10434 .30292 L
.10434 .30328 L
.10433 .30369 L
.10432 .30414 L
.10431 .30462 L
.1043 .3051 L
.10429 .30556 L
.10428 .30601 L
.10428 .30643 L
.10427 .3068 L
.10426 .30711 L
.10426 .30735 L
.10426 .30748 L
.10425 .30753 L
.10424 .30751 L
.10421 .30745 L
.10416 .30738 L
.10412 .30733 L
.1041 .30732 L
.10411 .3073 L
.10416 .30726 L
.10425 .30719 L
.10438 .30713 L
.10454 .3071 L
.10474 .30712 L
.10498 .30721 L
.10529 .30743 L
.10567 .30777 L
.10609 .30822 L
.10654 .30873 L
.107 .30924 L
.10742 .30971 L
.10778 .3101 L
.10806 .3104 L
.10823 .3106 L
.1083 .31069 L
.10828 .31065 L
Mistroke
.10818 .31049 L
.10804 .31022 L
.10788 .30987 L
.10769 .30948 L
.10749 .30905 L
.10731 .30859 L
.10717 .30813 L
.10712 .30773 L
.10721 .3074 L
.10748 .30709 L
.10795 .30678 L
.10859 .30645 L
.10935 .3061 L
.11024 .30573 L
.11122 .30531 L
.11216 .30488 L
.11314 .30444 L
.11407 .30402 L
.11493 .30362 L
.11576 .30326 L
.11642 .30295 L
.11699 .3027 L
.11745 .30248 L
.11779 .30231 L
.11801 .30216 L
.11813 .30202 L
.11815 .30187 L
.11811 .30168 L
.11805 .30147 L
.11798 .30122 L
.11792 .30098 L
.11788 .30076 L
.11787 .30057 L
.11787 .30042 L
.11787 .30032 L
.11787 .30026 L
.11787 .30024 L
.11787 .30026 L
.11787 .3003 L
.11785 .30036 L
.11781 .30045 L
.11774 .30054 L
.11766 .30065 L
.11761 .30075 L
.11759 .30083 L
.11764 .30086 L
.11776 .30082 L
.11797 .30066 L
.11825 .30037 L
.1186 .29991 L
Mistroke
.11903 .29925 L
.11953 .29834 L
.12008 .2972 L
.12082 .2958 L
.12156 .29404 L
.12237 .29205 L
.12327 .28978 L
.12424 .28729 L
.12527 .28438 L
.12618 .28173 L
.1272 .27899 L
.12833 .27569 L
.12933 .27294 L
.13039 .26974 L
.13157 .26672 L
.13294 .26365 L
.13446 .26028 L
.13585 .25759 L
.13734 .25462 L
.13901 .25152 L
.14064 .2483 L
.14241 .24563 L
.1443 .24269 L
.14617 .23962 L
.14812 .23695 L
.15009 .23428 L
.15195 .23172 L
.15363 .22922 L
.15525 .22711 L
.15681 .22485 L
.15811 .22297 L
.15949 .22107 L
.16068 .21924 L
.1619 .21743 L
.16316 .21561 L
.16433 .214 L
.16559 .21217 L
.16694 .2104 L
.16819 .20845 L
.16954 .20643 L
.17102 .20429 L
.17248 .20211 L
.17408 .19988 L
.17577 .1977 L
.17731 .19549 L
.17897 .19335 L
.1805 .19121 L
.18203 .18905 L
.18344 .18706 L
.18483 .18506 L
Mistroke
.18599 .18331 L
.1871 .18168 L
.18807 .18019 L
.18897 .17891 L
.18969 .17786 L
.19027 .17698 L
.1907 .17627 L
.19097 .17577 L
.19108 .17548 L
.19108 .17535 L
.19103 .17533 L
.19096 .17535 L
.19092 .17535 L
.19095 .17529 L
.19107 .17513 L
.1913 .17484 L
.19162 .17441 L
.19205 .17386 L
.19259 .17322 L
.19318 .17253 L
.19395 .17169 L
.19474 .17081 L
.19561 .16982 L
.19657 .16871 L
.19758 .16751 L
.19855 .16624 L
.19955 .16501 L
.20053 .16369 L
.2015 .16228 L
.20247 .16087 L
.20339 .15943 L
.20431 .15795 L
.20521 .15648 L
.20603 .15503 L
.20676 .15377 L
.2074 .15264 L
.20793 .15165 L
.20835 .15079 L
.20871 .15011 L
.20899 .14955 L
.20921 .14908 L
.20935 .14875 L
.20944 .14854 L
.20946 .14838 L
.20944 .14829 L
.20939 .14822 L
.20934 .14818 L
.20929 .14815 L
.20926 .14812 L
.20924 .1481 L
Mistroke
.20924 .14808 L
.20924 .14807 L
.20924 .14808 L
.20923 .14812 L
.20922 .14815 L
.20918 .14816 L
.20912 .14818 L
.20905 .1482 L
.20898 .14826 L
.20893 .14834 L
.20891 .14842 L
.20896 .14848 L
.20908 .14848 L
.20931 .1484 L
.20963 .14823 L
.21008 .14798 L
.21066 .14764 L
.21135 .14722 L
.2122 .14669 L
.21321 .14609 L
.21434 .14536 L
.21568 .14449 L
.21712 .14357 L
.21877 .14256 L
.22059 .14144 L
.22251 .14021 L
.22476 .13889 L
.227 .13761 L
.22903 .13621 L
.23144 .13481 L
.23377 .13335 L
.23608 .13193 L
.23838 .13057 L
.2405 .12927 L
.24263 .12811 L
.24432 .1271 L
.246 .12619 L
.24742 .12545 L
.24873 .12483 L
.2498 .1243 L
.25073 .12383 L
.25155 .12339 L
.25229 .12295 L
.25304 .1225 L
.25384 .122 L
.25471 .12144 L
.25574 .12077 L
.25699 .11997 L
.25841 .11902 L
.26009 .11794 L
Mistroke
.26174 .1168 L
.26345 .11562 L
.26537 .11445 L
.26719 .11338 L
.26869 .11243 L
.27017 .11164 L
.27155 .11104 L
.27279 .11063 L
.27374 .1104 L
.27453 .11033 L
.27514 .11042 L
.2756 .11066 L
.27596 .11101 L
.27631 .11147 L
.27669 .112 L
.27715 .11257 L
.27772 .11312 L
.27838 .11359 L
.27902 .11392 L
.27972 .11406 L
.28054 .114 L
.28145 .11377 L
.28231 .11336 L
.28316 .11281 L
.28397 .11211 L
.28468 .1113 L
.28532 .11046 L
.28588 .1096 L
.28636 .10876 L
.28677 .10795 L
.28712 .10721 L
.28744 .10661 L
.2877 .10616 L
.28792 .10585 L
.28809 .1057 L
.2882 .10571 L
.28827 .10588 L
.2883 .10614 L
.2883 .10647 L
.28828 .10685 L
.28824 .10725 L
.2882 .10762 L
.28816 .10795 L
.28815 .10824 L
.28815 .10843 L
.28815 .10861 L
.28815 .10875 L
.28815 .10887 L
.28815 .10893 L
.28815 .10899 L
Mistroke
.28815 .10902 L
.28815 .10901 L
.28815 .10897 L
.28815 .10892 L
.28815 .10885 L
.28815 .10877 L
.28815 .10866 L
.28815 .10855 L
.28815 .10846 L
.28815 .10839 L
.28815 .10835 L
.28815 .10837 L
.28815 .10843 L
.28815 .10853 L
.28815 .10862 L
.28815 .10869 L
.28815 .10877 L
.28815 .10885 L
.28815 .10892 L
.28815 .109 L
.28815 .10906 L
.28815 .1091 L
.28815 .10911 L
.28815 .10909 L
.28815 .10904 L
.28815 .10896 L
.28815 .10887 L
.28815 .10878 L
.28815 .1087 L
.28815 .10862 L
.28815 .10854 L
.28815 .10846 L
.28815 .1084 L
.28816 .10836 L
.28818 .10834 L
.2882 .10835 L
.2882 .10838 L
.28819 .10845 L
.28815 .10852 L
.2881 .10859 L
.28804 .10866 L
.28797 .10872 L
.28791 .10877 L
.28786 .10881 L
.28782 .10887 L
.2878 .10897 L
.28779 .10905 L
.28779 .10913 L
.28779 .10918 L
.28781 .10919 L
Mistroke
.28784 .10919 L
.28789 .10919 L
.28795 .10924 L
.28802 .10932 L
.28809 .10942 L
.28814 .10951 L
.28819 .10955 L
.28821 .10952 L
.2882 .10941 L
.28818 .10918 L
.28816 .10885 L
.28815 .10844 L
.28815 .10801 L
.28815 .10764 L
.28815 .10732 L
.28815 .10705 L
.28815 .10682 L
.28815 .10663 L
.28815 .10648 L
.28815 .10635 L
.28815 .10626 L
.28815 .1062 L
.28815 .10618 L
.28815 .10619 L
.28815 .10621 L
.28815 .10622 L
.28815 .10616 L
.28815 .10603 L
.28815 .10579 L
.28815 .10557 L
.28815 .10532 L
.28815 .10511 L
.28815 .10498 L
.28815 .10492 L
.28815 .10494 L
.28815 .10498 L
.28815 .10503 L
.28815 .10506 L
.28815 .10508 L
.28815 .10511 L
.28815 .10512 L
.28815 .1051 L
.28815 .10501 L
.28815 .10488 L
.28815 .10473 L
.28815 .10461 L
.28815 .10455 L
.28815 .1046 L
.28815 .10474 L
.28815 .105 L
Mistroke
.28815 .10535 L
.28815 .10578 L
.28815 .10624 L
.28815 .1067 L
.28815 .10716 L
.28815 .10761 L
.28815 .10806 L
.28815 .10849 L
.28815 .10888 L
.28815 .10918 L
.28815 .10938 L
.28815 .10949 L
.28815 .10953 L
.28815 .1095 L
.28815 .10943 L
.28815 .10936 L
.28815 .1093 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
Mistroke
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10928 L
.28815 .10929 L
.28815 .1093 L
.28815 .1093 L
.28815 .10929 L
.28815 .10929 L
.28815 .10931 L
.28815 .10934 L
.28815 .10937 L
.28815 .10936 L
.28815 .1093 L
.28815 .10916 L
.28815 .10894 L
.28816 .10862 L
.28818 .10826 L
.28822 .10782 L
.28824 .10737 L
.28823 .10695 L
.28818 .10657 L
.28811 .10619 L
.28801 .10584 L
.2879 .10553 L
.28779 .10528 L
.28769 .10508 L
.28761 .10493 L
.28756 .10483 L
.28753 .1048 L
.28752 .10482 L
.28753 .1049 L
.28754 .10497 L
.28759 .10499 L
.28766 .10496 L
.28776 .10489 L
.28787 .10481 L
.28799 .10473 L
.28809 .10466 L
.28818 .10461 L
.28823 .10458 L
.28825 .10459 L
.28823 .10462 L
Mistroke
.28819 .10464 L
.28818 .10463 L
.2882 .10458 L
.28824 .1045 L
.28827 .10444 L
.28829 .10441 L
.28828 .10443 L
.28822 .10453 L
.28812 .10472 L
.28797 .10499 L
.28776 .10535 L
.28751 .10581 L
.28722 .10633 L
.28692 .10687 L
.28664 .10736 L
.28639 .10778 L
.28618 .10812 L
.28605 .10837 L
.28598 .1085 L
.28601 .10852 L
.2861 .10845 L
.28625 .10833 L
.28645 .10816 L
.28665 .10792 L
.28684 .10766 L
.28702 .10737 L
.2872 .1071 L
.28737 .10685 L
.28757 .10666 L
.28783 .10654 L
.28821 .10635 L
.28878 .10624 L
.28958 .10614 L
.2906 .10596 L
.29192 .10568 L
.29361 .10527 L
.2954 .10472 L
.29765 .10405 L
.30039 .1033 L
.30305 .10245 L
.30628 .10146 L
.30955 .10034 L
.3132 .09909 L
.31706 .09762 L
.32067 .09599 L
.32434 .09424 L
.32849 .09226 L
.33246 .09036 L
.33621 .08831 L
.34031 .08609 L
Mistroke
.34413 .08401 L
.34812 .08166 L
.35185 .07943 L
.35589 .07689 L
.35956 .07448 L
.36298 .07197 L
.36639 .06946 L
.37009 .06693 L
.37287 .06446 L
.37578 .06223 L
.37864 .05997 L
.3809 .05804 L
.38303 .05622 L
.38484 .05455 L
.38626 .0533 L
.38738 .05227 L
.38816 .05149 L
.38866 .05097 L
.38893 .05069 L
.38903 .05061 L
.38906 .05067 L
.38912 .05081 L
.38929 .05095 L
.38959 .05105 L
.39006 .05108 L
.39068 .051 L
.39146 .05078 L
.39228 .05043 L
.3932 .04998 L
.39414 .04951 L
.39506 .04906 L
.3958 .04864 L
.39646 .04833 L
.39705 .04809 L
.39755 .04795 L
.39797 .04791 L
.39832 .04796 L
.39866 .04809 L
.39912 .04826 L
.39981 .04844 L
.40078 .0486 L
.402 .04875 L
.40336 .0489 L
.40496 .04896 L
.40691 .04895 L
.40903 .04888 L
.41122 .0487 L
.41337 .04847 L
.41547 .04821 L
.41747 .04796 L
Mistroke
.41923 .04776 L
.42067 .04763 L
.42192 .04758 L
.42293 .0476 L
.42368 .04764 L
.42425 .0477 L
.42471 .04777 L
.42511 .04782 L
.42548 .04786 L
.42586 .04787 L
.42631 .04789 L
.42687 .04791 L
.42764 .04793 L
.42863 .04796 L
.42982 .048 L
.43124 .04805 L
.43287 .04811 L
.43478 .04817 L
.4367 .04824 L
.43885 .04831 L
.44116 .04839 L
.44343 .04847 L
.44593 .04856 L
.44822 .04866 L
.45061 .04878 L
.45293 .04889 L
.4551 .04897 L
.45707 .04903 L
.45877 .04903 L
.46018 .04899 L
.46133 .04889 L
.46222 .04875 L
.46289 .04857 L
.46336 .04836 L
.46363 .04814 L
.46376 .04791 L
.46376 .04768 L
.46365 .04745 L
.46349 .04723 L
.46329 .04705 L
.4631 .04689 L
.46295 .04679 L
.46285 .04673 L
.46278 .04671 L
.46275 .04672 L
.46272 .04674 L
.46267 .04675 L
.46258 .04674 L
.46247 .04672 L
.46236 .0467 L
Mistroke
.46228 .04671 L
.46227 .04676 L
.46237 .04685 L
.46263 .04699 L
.46309 .04718 L
.46378 .0474 L
.46471 .04765 L
.46591 .04792 L
.46725 .0482 L
.46892 .04848 L
.47082 .04876 L
.47292 .04899 L
.47526 .04918 L
.47771 .04933 L
.48025 .04947 L
.48282 .04961 L
.48534 .04978 L
.48778 .04998 L
.49002 .05025 L
.49217 .05059 L
.49397 .05098 L
.49567 .0514 L
.49721 .05182 L
.49855 .05226 L
.49964 .05271 L
.50049 .05322 L
.50107 .05377 L
.5014 .05434 L
.50149 .05493 L
.50139 .0555 L
.50116 .05604 L
.50083 .05655 L
.50045 .057 L
.50007 .05738 L
.49967 .05773 L
.49926 .05809 L
.49888 .05847 L
.49852 .0588 L
.49821 .05907 L
.49796 .05924 L
.49781 .05933 L
.49774 .05936 L
.49776 .05933 L
.49783 .05927 L
.49792 .05922 L
.498 .05922 L
.49807 .05927 L
.49811 .05933 L
.49812 .05936 L
.49811 .05934 L
Mistroke
.49806 .05925 L
.49797 .05907 L
.49783 .05881 L
.49765 .05846 L
.49745 .05805 L
.49722 .05761 L
.49698 .05714 L
.49673 .05669 L
.49649 .05624 L
.49625 .0558 L
.49604 .05538 L
.49585 .055 L
.4957 .0547 L
.4956 .05449 L
.49554 .05437 L
.49552 .05434 L
.49553 .05436 L
.49557 .05442 L
.49561 .0545 L
.49564 .05455 L
.49565 .05457 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49569 .05458 L
.49574 .05458 L
.49582 .05458 L
.49589 .05459 L
.49597 .05459 L
.49604 .05459 L
.49607 .05461 L
.49603 .05466 L
.49591 .05473 L
.49568 .05478 L
.49532 .0548 L
.49479 .05476 L
.49406 .05465 L
.4931 .05445 L
.4919 .05415 L
.4904 .05377 L
.48853 .05331 L
.48644 .0528 L
.48416 .05227 L
.48152 .05173 L
.47842 .05121 L
.47542 .05067 L
.47193 .05013 L
.4683 .04963 L
.46422 .04921 L
Mistroke
.46053 .04889 L
.45612 .04864 L
.45188 .04847 L
.44747 .04837 L
.443 .04831 L
.43848 .04824 L
.43373 .04813 L
.42915 .04844 L
.42515 .04838 L
.42091 .04834 L
.41726 .04833 L
.41341 .04837 L
.41011 .04844 L
.40712 .04854 L
.40425 .04865 L
.40164 .04881 L
.39923 .04899 L
.39701 .04922 L
.39511 .0495 L
.39328 .04989 L
.39151 .05037 L
.38978 .05096 L
.38811 .05164 L
.38638 .05239 L
.38461 .05315 L
.38293 .05385 L
.38135 .05453 L
.37991 .05516 L
.37863 .05575 L
.37755 .05628 L
.37662 .05675 L
.37583 .05714 L
.37515 .05742 L
.37463 .05756 L
.37424 .05757 L
.37401 .05746 L
.37391 .05727 L
.37392 .05703 L
.37399 .05676 L
.37411 .05649 L
.37423 .05622 L
.37433 .05595 L
.37439 .05571 L
.37445 .0555 L
.37452 .05532 L
.37458 .05516 L
.37459 .05503 L
.37454 .05493 L
.37442 .05487 L
.37424 .05483 L
Mistroke
.37402 .05482 L
.37376 .05482 L
.3735 .05486 L
.37325 .05496 L
.37302 .05511 L
.37279 .05534 L
.37257 .05565 L
.37232 .05605 L
.37205 .05652 L
.37174 .05707 L
.37137 .0577 L
.37092 .05839 L
.37034 .05917 L
.36953 .06001 L
.36842 .06096 L
.36696 .06204 L
.3651 .06327 L
.36291 .06462 L
.36018 .06614 L
.35686 .06787 L
.35362 .06977 L
.34981 .07181 L
.34582 .07401 L
.34163 .07623 L
.33704 .07853 L
.33275 .08091 L
.32831 .08316 L
.32403 .08543 L
.3196 .08754 L
.31563 .08952 L
.31153 .09146 L
.30782 .09321 L
.304 .09492 L
.30043 .09663 L
.29667 .09828 L
.29283 .10013 L
.28899 .10202 L
.28474 .1041 L
.28103 .10628 L
.2771 .1085 L
.27316 .11084 L
.26957 .11305 L
.26599 .11518 L
.26306 .11713 L
.26052 .1187 L
.25807 .12013 L
.25616 .12127 L
.25454 .12226 L
.25324 .12311 L
.25221 .12385 L
Mistroke
.25134 .12454 L
.25047 .12526 L
.2495 .12613 L
.24836 .12723 L
.2471 .12849 L
.24546 .13007 L
.24341 .13184 L
.241 .13382 L
.23822 .1362 L
.23533 .13886 L
.23206 .14184 L
.22871 .14452 L
.22499 .14746 L
.22166 .15048 L
.21792 .15359 L
.2144 .15644 L
.21052 .15958 L
.20696 .16268 L
.20295 .16602 L
.19965 .16929 L
.1962 .17304 L
.19272 .17657 L
.18932 .18001 L
.18588 .18403 L
.18289 .18789 L
.17984 .19161 L
.17678 .19577 L
.17381 .19986 L
.17093 .20401 L
.16814 .2082 L
.16549 .21235 L
.16299 .21646 L
.16073 .22043 L
.15868 .22436 L
.15691 .22815 L
.15533 .2316 L
.15404 .23485 L
.15298 .23761 L
.15216 .24006 L
.15159 .24195 L
.15122 .24338 L
.15105 .24446 L
.15104 .24513 L
.15113 .24549 L
.15126 .24558 L
.15136 .24548 L
.15137 .24531 L
.15122 .24516 L
.15085 .24515 L
.15021 .24542 L
Mistroke
.14926 .24606 L
.14792 .24714 L
.14632 .24858 L
.14422 .25053 L
.14207 .25289 L
.13955 .25579 L
.13643 .25927 L
.13372 .26243 L
.13061 .26601 L
.12735 .2699 L
.12437 .27383 L
.12114 .27814 L
.11816 .28172 L
.11526 .28563 L
.11257 .28928 L
.1099 .29305 L
.10734 .29673 L
.10488 .30003 L
.10254 .30348 L
.10066 .30652 L
.09886 .30951 L
.09739 .3122 L
.0961 .31484 L
.09503 .31722 L
.0942 .31971 L
.09356 .32198 L
.09309 .32434 L
.09272 .32682 L
.09241 .32938 L
.0921 .33224 L
.09176 .33505 L
.0913 .33817 L
.09071 .34167 L
.09003 .34485 L
.08927 .34825 L
.08845 .35196 L
.08763 .35558 L
.08681 .35932 L
.08601 .36316 L
.08527 .36688 L
.0846 .37023 L
.08401 .37377 L
.08353 .37703 L
.08315 .38025 L
.08287 .38323 L
.08266 .38616 L
.08252 .38874 L
.08244 .39114 L
.08239 .39329 L
.08238 .39515 L
Mistroke
.08238 .39681 L
.08241 .39814 L
.08244 .39918 L
.08249 .39994 L
.08256 .40043 L
.08265 .40069 L
.08273 .40077 L
.08281 .40072 L
.08287 .4006 L
.0829 .40046 L
.0829 .40032 L
.08288 .4002 L
.08285 .40013 L
.08283 .40009 L
.08281 .40008 L
.08275 .40007 L
.08267 .40004 L
.08256 .4 L
.08246 .39993 L
.08242 .39985 L
.08247 .39976 L
.08262 .39969 L
.0829 .39968 L
.08332 .39976 L
.08386 .39997 L
.08454 .40036 L
.08534 .40094 L
.0862 .40171 L
.08719 .40265 L
.08831 .40374 L
.08943 .40494 L
.09059 .40615 L
.09173 .40742 L
.09275 .40873 L
.09364 .4099 L
.09436 .41101 L
.09488 .41204 L
.09521 .41297 L
.09535 .4139 L
.09533 .41488 L
.09516 .41597 L
.09486 .41722 L
.09445 .41862 L
.09393 .42026 L
.09333 .42213 L
.09269 .42414 L
.09207 .42592 L
.09149 .42785 L
.09098 .42985 L
.09056 .43151 L
Mistroke
.09024 .43305 L
.08999 .43435 L
.08983 .4353 L
.08974 .43587 L
.0897 .43611 L
.08971 .43612 L
.08978 .43603 L
.08988 .43593 L
.09 .43599 L
.09009 .43634 L
.09013 .43704 L
.09009 .43814 L
.08999 .4396 L
.08983 .44136 L
.0896 .44304 L
.08928 .44508 L
.08883 .44709 L
.0882 .44929 L
.08739 .45162 L
.08638 .45376 L
.08494 .45601 L
.08361 .45798 L
.08199 .46001 L
.0801 .46207 L
.07831 .46409 L
.07678 .46578 L
.0752 .46766 L
.0733 .46943 L
.07188 .47105 L
.07059 .47267 L
.06935 .4743 L
.06831 .47591 L
.06753 .47732 L
.06693 .47865 L
.06652 .47985 L
.06627 .4809 L
.06615 .48179 L
.06612 .48251 L
.06614 .48308 L
.06619 .48357 L
.06625 .48399 L
.0663 .48432 L
.06633 .48458 L
.06636 .48478 L
.06637 .48492 L
.06637 .485 L
.06637 .48502 L
.06637 .48498 L
.06638 .48491 L
.06638 .48486 L
Mistroke
.06638 .48485 L
.06638 .48491 L
.06637 .48497 L
.06637 .48501 L
.06637 .48499 L
.06638 .48489 L
.06639 .48469 L
.0664 .48441 L
.06641 .48405 L
.06642 .48362 L
.06644 .48316 L
.06646 .48269 L
.06647 .48223 L
.06649 .48177 L
.06651 .4813 L
.06652 .48084 L
.06653 .4804 L
.06654 .48002 L
.06652 .47973 L
.0665 .47952 L
.06649 .47939 L
.06649 .47928 L
.06651 .47913 L
.06654 .4789 L
.06659 .47851 L
.06668 .47795 L
.06681 .47721 L
.06698 .47634 L
.0672 .47534 L
.06745 .47424 L
.06773 .47315 L
.06802 .47192 L
.06832 .47058 L
.06863 .4693 L
.0689 .46796 L
.06917 .46662 L
.06941 .46535 L
.06961 .4642 L
.06977 .46318 L
.06988 .46233 L
.06996 .46161 L
.07002 .46099 L
.07005 .46046 L
.07007 .46002 L
.07007 .45966 L
.07005 .4594 L
.07003 .45925 L
.07002 .4592 L
.07001 .45925 L
.06999 .45936 L
Mistroke
.06995 .4595 L
.06991 .45961 L
.06986 .45975 L
.06983 .45991 L
.06984 .46009 L
.06989 .46026 L
.07 .46039 L
.07016 .46044 L
.07037 .46038 L
.07062 .4602 L
.07089 .4599 L
.07119 .45955 L
.07149 .45908 L
.07178 .45857 L
.07207 .45806 L
.07234 .4576 L
.07257 .45713 L
.07276 .45669 L
.0729 .45628 L
.07298 .45593 L
.07301 .45564 L
.073 .45543 L
.07296 .4553 L
.07292 .45526 L
.07288 .4553 L
.07286 .45537 L
.07286 .45545 L
.07288 .45552 L
.07293 .45558 L
.07301 .45562 L
.07308 .45566 L
.07312 .45567 L
.07309 .45566 L
.07299 .45561 L
.07279 .45552 L
.07248 .45538 L
.07206 .4552 L
.07157 .45499 L
.07104 .45476 L
.0705 .45452 L
.06997 .45428 L
.06946 .45403 L
.06895 .4538 L
.06845 .45358 L
.06799 .45339 L
.06763 .45324 L
.06738 .45314 L
.06725 .45308 L
.0672 .45306 L
.06722 .45308 L
Mistroke
.06729 .45311 L
.06738 .45315 L
.06744 .45318 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06745 .45318 L
.06742 .45316 L
.06737 .45312 L
.06733 .45308 L
.0673 .45306 L
.06728 .45308 L
.0673 .45313 L
.06738 .45323 L
.06752 .45337 L
.06773 .45355 L
.06803 .45376 L
.0684 .45399 L
.06883 .45423 L
.0693 .45448 L
.06981 .45472 L
.07033 .45496 L
.07086 .45517 L
.07136 .45536 L
.0718 .45551 L
.07219 .45561 L
.07251 .45567 L
.07276 .45568 L
.07292 .45567 L
.07301 .45563 L
.07304 .45559 L
.07304 .45555 L
.07301 .45554 L
.07296 .45554 L
.07292 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45553 L
.07286 .45551 L
.07286 .45545 L
.07286 .45538 L
.07286 .4553 L
Mistroke
.07287 .45527 L
.07286 .45529 L
.07286 .4554 L
.07285 .45559 L
.07284 .45588 L
.07283 .45624 L
.07282 .45667 L
.0728 .45715 L
.07278 .45765 L
.07277 .45814 L
.07275 .45864 L
.07273 .45912 L
.07272 .45958 L
.07273 .46 L
.07277 .46036 L
.07285 .46065 L
.07292 .46084 L
.07294 .46092 L
.07291 .46086 L
.0728 .46069 L
.0726 .46043 L
.07228 .46009 L
.07186 .4597 L
.07135 .45927 L
.07078 .4588 L
.07018 .45831 L
.06962 .45782 L
.06911 .45734 L
.06861 .45686 L
.06817 .45642 L
.06782 .45603 L
.06763 .45572 L
.06761 .4555 L
.06774 .45538 L
.06797 .45533 L
.06829 .45536 L
.06865 .45542 L
.06902 .4555 L
.06937 .45556 L
.06965 .45558 L
.06988 .45558 L
.07006 .45558 L
.07018 .45558 L
.07026 .45558 L
.07028 .45558 L
.07027 .45558 L
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45555 L
.07013 .45549 L
.07013 .45542 L
.07013 .45535 L
.07013 .45531 L
.07011 .45534 L
.07008 .45544 L
.07003 .45563 L
.06998 .45592 L
.06995 .45629 L
.06995 .45672 L
.06999 .45719 L
.07008 .45769 L
.07023 .45818 L
.07042 .45867 L
.07064 .45915 L
.0709 .4596 L
.07116 .45998 L
.07143 .46029 L
.07171 .46051 L
.07197 .46063 L
.07223 .46066 L
.07245 .46063 L
.07263 .46056 L
.07275 .46047 L
.07283 .46041 L
.07285 .46038 L
.07283 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46037 L
.07267 .46035 L
.07264 .46029 L
.0726 .46022 L
.07257 .46015 L
.07255 .46011 L
.07256 .46014 L
.07262 .46024 L
Mistroke
.07272 .46043 L
.07287 .46071 L
.07306 .46108 L
.07329 .4615 L
.07354 .46197 L
.07381 .46247 L
.07407 .46296 L
.07434 .46345 L
.07459 .46393 L
.07483 .46437 L
.07504 .46476 L
.0752 .46507 L
.07532 .46529 L
.07539 .46541 L
.07541 .46545 L
.07539 .46542 L
.07535 .46535 L
.07531 .46527 L
.07528 .46521 L
.07526 .46518 L
.07526 .46517 L
.07527 .46511 L
.07528 .46499 L
.07529 .46482 L
.0753 .46465 L
.07532 .46451 L
.07535 .46445 L
.07539 .46451 L
.07543 .46474 L
.07546 .46519 L
.07546 .46588 L
.07543 .46686 L
.0753 .4682 L
.07503 .46997 L
.07457 .47183 L
.07404 .47436 L
.07332 .47688 L
.07244 .48 L
.07158 .4831 L
.07051 .48648 L
.06947 .48973 L
.06835 .49292 L
.06723 .49593 L
.06604 .49919 L
.06507 .50172 L
.06417 .50455 L
.06336 .50683 L
.06271 .50908 L
.06225 .51127 L
.06197 .51324 L
Mistroke
.06184 .51493 L
.06184 .51616 L
.06192 .51739 L
.06205 .51849 L
.06219 .51937 L
.0623 .52015 L
.06234 .52082 L
.06231 .52134 L
.06217 .52168 L
.06187 .52187 L
.06143 .52195 L
.06091 .52195 L
.06038 .52192 L
.05985 .5219 L
.05936 .52187 L
.05892 .52179 L
.05854 .52166 L
.05822 .52147 L
.05801 .52118 L
.05792 .52081 L
.05797 .52038 L
.05814 .51989 L
.0584 .51938 L
.05873 .51887 L
.05909 .51836 L
.05944 .51788 L
.05971 .51744 L
.05986 .51708 L
.05993 .5168 L
.05995 .5166 L
.05994 .51646 L
.0599 .51637 L
.05986 .51629 L
.05983 .51619 L
.05981 .51605 L
.05982 .51586 L
.05983 .51562 L
.05983 .51538 L
.05984 .51518 L
.05985 .51502 L
.05985 .51492 L
.05985 .51487 L
.05985 .51489 L
.05985 .51494 L
.05984 .51503 L
.05983 .51514 L
.05979 .5153 L
.05974 .51549 L
.05969 .5157 L
.05966 .51593 L
Mistroke
.05967 .51617 L
.05971 .51645 L
.05979 .51678 L
.05991 .51719 L
.06006 .51773 L
.06022 .51842 L
.0604 .5193 L
.06059 .52038 L
.06081 .52175 L
.06106 .52346 L
.06134 .52547 L
.06166 .52766 L
.06201 .53029 L
.06239 .53314 L
.06279 .53636 L
.06322 .53961 L
.06365 .54321 L
.06413 .54712 L
.06465 .55082 L
.06521 .55518 L
.06581 .55964 L
.06646 .56398 L
.06714 .56933 L
.06779 .57423 L
.06841 .57854 L
.069 .58394 L
.06957 .58873 L
.0701 .59378 L
.07062 .59952 L
.07117 .60414 L
.07173 .60941 L
.07234 .61462 L
.073 .6199 L
.07372 .62453 L
.07445 .62955 L
.07524 .6344 L
.07606 .63915 L
.07686 .64385 L
.07769 .64846 L
.07852 .65316 L
.07932 .65813 L
.08014 .66283 L
.08087 .66719 L
.0816 .67186 L
.08234 .6764 L
.0831 .68098 L
.0838 .6852 L
.08455 .68956 L
.08533 .69362 L
.0861 .69729 L
Mistroke
.08689 .7008 L
.0877 .70422 L
.08846 .70682 L
.08919 .70926 L
.08986 .71149 L
.0904 .71307 L
.09083 .71433 L
.09118 .71529 L
.09143 .71598 L
.0916 .71647 L
.09172 .71681 L
.0918 .71709 L
.09188 .71737 L
.09198 .7177 L
.09212 .7181 L
.09233 .71864 L
.09263 .71931 L
.09302 .72012 L
.09349 .72106 L
.09403 .72208 L
.09462 .72313 L
.09526 .72416 L
.09587 .72511 L
.09644 .72591 L
.09696 .72652 L
.09742 .72703 L
.09784 .72744 L
.0982 .72781 L
.09854 .72816 L
.09888 .72854 L
.09927 .72893 L
.09972 .72933 L
.10026 .72971 L
.1009 .73007 L
.10163 .73047 L
.10239 .73094 L
.10329 .73153 L
.10419 .73224 L
.10515 .73304 L
.10614 .73388 L
.10705 .73472 L
.10795 .73554 L
.10866 .73636 L
.10927 .73719 L
.10975 .73803 L
.11008 .73887 L
.11026 .73974 L
.11032 .74063 L
.11028 .74152 L
.11018 .74236 L
Mistroke
.11004 .74309 L
.10988 .74368 L
.10973 .74417 L
.10963 .74457 L
.1096 .74488 L
.10966 .74513 L
.10983 .74536 L
.11011 .74558 L
.11053 .74583 L
.11108 .74612 L
.11177 .74646 L
.11252 .74688 L
.11339 .74738 L
.1143 .74797 L
.11524 .74865 L
.11623 .74937 L
.11718 .75009 L
.11811 .75075 L
.11899 .75137 L
.11978 .75193 L
.12047 .75238 L
.12107 .75272 L
.12157 .75293 L
.12197 .75302 L
.1223 .75301 L
.1226 .75297 L
.12289 .75293 L
.12316 .75291 L
.12339 .7529 L
.12355 .7529 L
.12362 .75288 L
.12358 .75281 L
.12341 .75266 L
.12313 .75246 L
.12277 .75219 L
.12236 .75187 L
.12189 .75146 L
.12136 .75094 L
.12075 .75031 L
.12009 .74959 L
.11937 .74878 L
.11861 .74791 L
.11782 .747 L
.11704 .74607 L
.11627 .74518 L
.11556 .74425 L
.11492 .74331 L
.11437 .74244 L
.11388 .74158 L
.11339 .74072 L
Mistroke
.11286 .73985 L
.11228 .73899 L
.11165 .73818 L
.11098 .73746 L
.11023 .73681 L
.1094 .73622 L
.10851 .73568 L
.10758 .73517 L
.10668 .73473 L
.10585 .7344 L
.10512 .73415 L
.1044 .73398 L
.10369 .73389 L
.10301 .73382 L
.10241 .73371 L
.10189 .7335 L
.10141 .73315 L
.10096 .73266 L
.10056 .73203 L
.1002 .73128 L
.09983 .73041 L
.09938 .72955 L
.09881 .72863 L
.09818 .72776 L
.09754 .72697 L
.0969 .7264 L
.09632 .72595 L
.0958 .72565 L
.09537 .72552 L
.09504 .72557 L
.09477 .72578 L
.09456 .72614 L
.09438 .7266 L
.09422 .72709 L
.09407 .72758 L
.09396 .72806 L
.09389 .7284 L
.09387 .72866 L
.09389 .72879 L
.09393 .72884 L
.09396 .72883 L
.09396 .72876 L
.09393 .72866 L
.09389 .72856 L
.09387 .72851 L
.09389 .72854 L
.09394 .72864 L
.09404 .72882 L
.0942 .7291 L
.09439 .72947 L
Mistroke
.09462 .72991 L
.09486 .73039 L
.09509 .7309 L
.09532 .7314 L
.09555 .7319 L
.09579 .73239 L
.09605 .73284 L
.09632 .73324 L
.0966 .73355 L
.09688 .73377 L
.09715 .73389 L
.09741 .73392 L
.09767 .73388 L
.09791 .7338 L
.09814 .7337 L
.09839 .73363 L
.09865 .73359 L
.09889 .73357 L
.09911 .73356 L
.09927 .73356 L
.09935 .73355 L
.09938 .73355 L
.09935 .73355 L
.0993 .73353 L
.09924 .73346 L
.0992 .73334 L
.0992 .73323 L
.09929 .73317 L
.09946 .73319 L
.09974 .7333 L
.1001 .73352 L
.10057 .73385 L
.1011 .7343 L
.10173 .73487 L
.10243 .73554 L
.1032 .73633 L
.10399 .73721 L
.10482 .73812 L
.10565 .7391 L
.10642 .74013 L
.10714 .74117 L
.10779 .74216 L
.10836 .74303 L
.10883 .74371 L
.10921 .74426 L
.10949 .74469 L
.10968 .74504 L
.10977 .7453 L
.10977 .74552 L
.10972 .74569 L
Mistroke
.10967 .74583 L
.10964 .74593 L
.10967 .74606 L
.10981 .74624 L
.11006 .74651 L
.11047 .74692 L
.11103 .74748 L
.11176 .7482 L
.11259 .74909 L
.11365 .75019 L
.11495 .75144 L
.1163 .75285 L
.11784 .75446 L
.11954 .75616 L
.12129 .7579 L
.12312 .75972 L
.12475 .76141 L
.12635 .76304 L
.12779 .76451 L
.12915 .76593 L
.1303 .76702 L
.13137 .76793 L
.13225 .76867 L
.133 .76924 L
.13364 .76968 L
.13423 .77003 L
.13485 .77037 L
.13554 .77084 L
.13637 .77156 L
.13743 .77257 L
.13874 .7739 L
.14033 .77559 L
.14183 .77738 L
.14372 .77966 L
.14564 .78188 L
.14771 .78437 L
.14982 .7868 L
.15179 .7892 L
.15384 .79168 L
.15587 .7942 L
.15776 .79624 L
.15951 .79823 L
.16113 .80008 L
.16265 .80176 L
.16416 .80335 L
.16569 .80481 L
.16733 .80635 L
.16914 .80807 L
.1711 .80982 L
.17328 .81185 L
Mistroke
.17566 .81408 L
.1783 .8167 L
.18111 .81919 L
.18404 .82197 L
.18736 .82526 L
.19047 .82804 L
.19386 .83125 L
.19717 .8344 L
.20068 .83791 L
.20389 .84097 L
.20722 .84434 L
.21051 .84756 L
.21365 .85087 L
.21675 .85396 L
.21977 .85712 L
.22277 .86022 L
.22586 .86346 L
.22893 .8663 L
.23214 .86914 L
.23559 .87216 L
.23887 .87451 L
.24248 .87689 L
.24613 .87925 L
.25016 .88132 L
.25362 .88325 L
.25748 .88505 L
.26196 .88669 L
.26574 .88829 L
.27012 .88995 L
.27443 .89158 L
.27904 .8933 L
.28425 .89524 L
.28883 .89723 L
.29397 .89931 L
.29962 .9016 L
.30447 .90374 L
.30991 .90599 L
.31586 .90816 L
.3206 .91026 L
.32586 .91235 L
.33101 .91428 L
.33621 .9162 L
.34064 .91793 L
.34514 .91962 L
.3495 .92123 L
.35375 .92281 L
.35792 .92426 L
.3622 .92578 L
.36642 .92731 L
.37096 .92885 L
Mistroke
.37526 .93046 L
.37989 .93212 L
.3846 .93382 L
.38921 .93554 L
.39402 .93736 L
.39908 .93911 L
.40368 .9408 L
.40838 .94248 L
.41277 .94405 L
.4169 .94548 L
.42065 .94677 L
.4239 .94785 L
.42673 .94871 L
.42913 .94937 L
.43092 .94982 L
.43229 .95007 L
.43324 .95016 L
.43382 .95013 L
.43409 .94999 L
.43413 .94981 L
.43411 .9496 L
.43423 .94941 L
.43462 .94927 L
.43536 .94919 L
.43647 .94919 L
.438 .94926 L
.43987 .94937 L
.44204 .94949 L
.44435 .94961 L
.44674 .9497 L
.44915 .94976 L
.4516 .94978 L
.45368 .94977 L
.45561 .94974 L
.45721 .94969 L
.45849 .94961 L
.4594 .94954 L
.45993 .94947 L
.46015 .94941 L
.46015 .94938 L
.46003 .94937 L
.45986 .94938 L
.45971 .94937 L
.45963 .94932 L
.45964 .94924 L
.45972 .94916 L
.45976 .94912 L
.45974 .94915 L
.45961 .94926 L
.45937 .94948 L
Mistroke
.45901 .94979 L
.45851 .95019 L
.45788 .95067 L
.4571 .9512 L
.45619 .95178 L
.45519 .95238 L
.45412 .95301 L
.45299 .95364 L
.45185 .95424 L
.45074 .95475 L
.44971 .95512 L
.44884 .9553 L
.4481 .95529 L
.44754 .95508 L
.44717 .95472 L
.447 .95424 L
.44697 .9537 L
.44703 .95317 L
.44709 .95267 L
.44707 .9522 L
.44692 .95175 L
.44658 .95131 L
.44601 .95091 L
.44521 .95058 L
.44418 .95036 L
.44296 .95022 L
.4416 .95014 L
.44023 .9501 L
.43874 .95007 L
.43703 .95001 L
.4354 .94985 L
.43369 .94958 L
.43192 .9492 L
.43008 .94871 L
.42818 .94813 L
.42626 .94743 L
.42415 .94667 L
.42174 .94581 L
.41906 .94484 L
.41588 .94372 L
.41241 .94247 L
.40845 .9411 L
.40434 .93959 L
.39974 .93794 L
.3952 .9362 L
.39022 .93436 L
.38528 .93234 L
.37953 .93035 L
.37466 .92823 L
.36923 .92599 L
Mistroke
.36356 .92375 L
.3583 .92147 L
.35257 .91924 L
.34738 .91703 L
.34184 .9149 L
.33623 .91278 L
.33124 .91093 L
.32606 .90908 L
.32102 .90729 L
.31598 .90548 L
.3112 .9037 L
.30643 .90175 L
.30167 .8997 L
.29695 .89752 L
.29216 .89516 L
.28758 .89268 L
.28276 .88992 L
.27763 .88684 L
.27358 .88432 L
.26881 .88147 L
.26389 .87819 L
.25964 .87558 L
.25501 .87282 L
.25027 .87023 L
.24574 .86758 L
.24113 .86525 L
.23688 .86291 L
.23259 .86073 L
.22829 .85841 L
.22421 .85606 L
.22025 .85367 L
.21619 .85099 L
.21252 .84822 L
.2088 .84513 L
.20527 .84189 L
.20175 .83834 L
.1986 .83509 L
.19544 .8316 L
.19219 .8278 L
.18913 .82458 L
.18578 .82111 L
.18261 .81777 L
.17909 .81429 L
.17579 .81122 L
.17225 .80798 L
.16873 .80488 L
.16491 .80156 L
.16166 .7986 L
.15798 .79535 L
.15449 .79191 L
Mistroke
.15101 .78853 L
.14758 .78483 L
.14426 .78112 L
.14102 .77687 L
.13796 .77306 L
.13499 .76866 L
.13204 .7638 L
.12937 .75932 L
.12664 .75421 L
.12393 .74932 L
.12124 .74426 L
.11852 .73854 L
.11591 .73404 L
.11327 .7291 L
.11061 .72409 L
.10788 .71979 L
.1053 .71523 L
.10262 .71151 L
.10014 .70814 L
.0977 .70514 L
.09539 .70263 L
.09338 .70062 L
.09158 .69903 L
.08999 .69781 L
.08873 .69692 L
.08771 .69632 L
.08695 .69594 L
.08644 .69578 L
.08618 .69578 L
.08613 .69593 L
.08626 .69616 L
.08653 .69647 L
.0869 .69681 L
.08731 .69715 L
.08771 .69747 L
.08806 .69776 L
.08838 .69802 L
.08866 .69827 L
.08891 .69849 L
.08912 .69868 L
.08929 .69884 L
.08941 .69895 L
.08948 .69901 L
.0895 .69903 L
.08948 .69901 L
.08944 .69897 L
.0894 .69893 L
.08936 .6989 L
.08934 .69889 L
.08934 .69888 L
Mistroke
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .69901 L
.08934 .69903 L
.08934 .69902 L
.08934 .69896 L
.08934 .69887 L
.08934 .69875 L
.08935 .69862 L
.08935 .69848 L
.08935 .69831 L
.08936 .6981 L
.08937 .69784 L
.08938 .69754 L
.0894 .69718 L
.08945 .69677 L
.0895 .6963 L
.08955 .69577 L
.08957 .69518 L
.08954 .69451 L
.08946 .69373 L
.08932 .69284 L
.08913 .69178 L
.08893 .69055 L
.08873 .68914 L
.08855 .68765 L
.08841 .68603 L
.08836 .68433 L
.08839 .68254 L
.08854 .68072 L
.08882 .67885 L
.08924 .67681 L
.08983 .67479 L
.09061 .6726 L
.09157 .67032 L
.0927 .66789 L
.094 .66559 L
.09539 .66314 L
.09687 .66071 L
.09835 .65814 L
.09985 .65572 L
.10135 .65332 L
.10292 .65087 L
.10455 .64857 L
.10629 .64622 L
.10814 .64409 L
.11002 .64203 L
Mistroke
.112 .6402 L
.11393 .63855 L
.11585 .63717 L
.11779 .63599 L
.1196 .63501 L
.12132 .63419 L
.12314 .63359 L
.12471 .63321 L
.1263 .63306 L
.1279 .63313 L
.1294 .63347 L
.1309 .63402 L
.13233 .63475 L
.13354 .63559 L
.13477 .6365 L
.13598 .63746 L
.13705 .63841 L
.1381 .6394 L
.13897 .64036 L
.13967 .6413 L
.14017 .64221 L
.14048 .64309 L
.14068 .64394 L
.14077 .6447 L
.14079 .64534 L
.14075 .64592 L
.14071 .64642 L
.14068 .64686 L
.14066 .64723 L
.14066 .64752 L
.14069 .64768 L
.14071 .64767 L
.14073 .64747 L
.14073 .6471 L
.14071 .64654 L
.14066 .64584 L
.14055 .645 L
.14041 .64404 L
.14029 .6429 L
.14025 .64153 L
.14033 .63995 L
.14056 .63811 L
.14099 .63608 L
.14165 .63386 L
.14247 .63143 L
.14352 .62908 L
.14469 .62669 L
.14592 .62422 L
.14716 .62178 L
.14842 .61956 L
Mistroke
.14953 .61722 L
.15062 .61497 L
.15169 .61269 L
.15269 .61058 L
.1536 .60845 L
.15446 .6063 L
.15527 .60428 L
.15605 .60216 L
.15679 .59993 L
.15743 .59775 L
.1581 .59537 L
.1587 .59307 L
.15928 .59061 L
.1598 .588 L
.1602 .58548 L
.16047 .58269 L
.1606 .57999 L
.16056 .5771 L
.16039 .57394 L
.16008 .57052 L
.15969 .5677 L
.15926 .56433 L
.15883 .56038 L
.15841 .5571 L
.15801 .55359 L
.15765 .54978 L
.15737 .54588 L
.15718 .54198 L
.15708 .53814 L
.15708 .53418 L
.15717 .53031 L
.15733 .52637 L
.15749 .52226 L
.15758 .51794 L
.15756 .51385 L
.15738 .50937 L
.157 .50497 L
.1564 .50071 L
.15554 .4962 L
.15454 .49209 L
.1533 .48767 L
.1518 .48384 L
.15013 .47988 L
.14832 .47607 L
.14661 .47248 L
.14475 .46904 L
.14283 .46591 L
.14124 .46293 L
.13968 .46003 L
.13839 .45758 L
Mistroke
.13732 .45519 L
.13654 .45288 L
.13603 .45065 L
.13578 .44857 L
.13582 .44657 L
.13614 .44464 L
.13677 .44278 L
.13767 .4409 L
.13882 .43898 L
.1402 .43696 L
.14175 .4348 L
.1435 .43246 L
.14544 .43004 L
.14747 .42747 L
.14964 .42502 L
.15191 .4225 L
.15428 .41997 L
.15675 .41744 L
.1593 .41489 L
.16189 .41248 L
.16463 .40996 L
.16737 .40753 L
.17021 .40497 L
.17308 .40244 L
.17599 .39986 L
.17885 .39733 L
.18159 .39486 L
.18464 .39231 L
.18719 .38979 L
.18998 .38723 L
.19276 .38465 L
.19553 .38202 L
.19837 .37958 L
.2011 .37716 L
.2039 .37485 L
.2068 .37263 L
.20991 .37066 L
.21259 .36872 L
.21542 .36685 L
.21812 .36504 L
.22112 .36319 L
.22418 .36137 L
.22712 .3596 L
.2301 .35787 L
.23289 .3563 L
.23546 .35485 L
.23792 .35359 L
.23984 .35252 L
.24173 .35156 L
.24321 .3507 L
Mistroke
.24437 .34985 L
.24516 .34894 L
.24563 .34806 L
.24584 .34698 L
.24585 .34569 L
.24575 .34422 L
.24557 .34236 L
.24541 .34013 L
.24534 .33739 L
.24543 .33445 L
.2457 .33105 L
.2461 .32715 L
.2466 .32308 L
.24725 .31882 L
.24806 .31408 L
.24894 .3098 L
.2499 .3052 L
.25093 .30054 L
.25194 .29569 L
.25296 .29135 L
.25398 .28671 L
.25497 .28201 L
.25597 .27739 L
.25697 .27285 L
.25798 .26845 L
.25901 .26368 L
.26001 .25959 L
.26099 .25518 L
.26191 .25064 L
.26275 .24636 L
.2635 .24178 L
.26415 .23715 L
.2647 .23289 L
.26517 .2281 L
.26557 .2238 L
.26591 .21977 L
.26623 .21562 L
.26657 .21176 L
.26694 .20781 L
.26742 .20404 L
.26804 .20041 L
.26884 .19715 L
.26985 .19384 L
.27108 .19059 L
.27257 .18731 L
.27421 .18406 L
.27606 .18058 L
.27817 .17686 L
.28039 .17303 L
.28281 .16877 L
Mistroke
.28537 .16446 L
.28811 .15988 L
.29083 .15552 L
.29369 .15085 L
.29662 .14573 L
.29957 .14151 L
.30255 .13694 L
.30553 .13233 L
.30843 .12813 L
.31129 .12388 L
.31428 .1199 L
.31693 .11608 L
.31969 .11232 L
.3221 .10871 L
.32443 .1052 L
.32656 .10175 L
.32849 .09854 L
.33025 .09525 L
.33189 .09236 L
.3335 .08956 L
.33508 .08694 L
.33673 .0845 L
.33851 .08216 L
.34059 .08004 L
.34309 .0779 L
.34581 .0758 L
.34867 .07374 L
.35184 .07173 L
.35523 .06971 L
.35855 .06787 L
.36205 .06607 L
.36531 .06435 L
.36832 .06281 L
.37136 .06135 L
.37408 .06017 L
.37634 .05916 L
.37845 .05838 L
.38044 .05782 L
.38233 .0575 L
.38417 .05737 L
.38595 .0574 L
.38782 .05753 L
.3899 .05761 L
.39201 .05764 L
.39421 .05759 L
.3966 .0574 L
.39915 .05705 L
.40186 .05661 L
.40453 .05612 L
.40721 .05562 L
Mistroke
.40963 .0551 L
.41205 .05455 L
.41441 .05399 L
.41677 .0534 L
.41919 .0528 L
.42173 .05222 L
.42448 .05167 L
.42755 .05117 L
.43043 .05073 L
.43355 .05033 L
.43649 .05001 L
.43968 .04972 L
.44272 .04946 L
.4456 .0492 L
.44831 .04897 L
.45111 .04879 L
.45345 .04868 L
.45577 .04865 L
.45794 .04869 L
.46005 .04878 L
.46204 .04891 L
.46408 .04905 L
.46631 .04917 L
.46852 .04926 L
.47094 .04934 L
.47352 .04942 L
.47625 .04951 L
.47898 .04959 L
.48175 .04968 L
.48427 .04976 L
.48656 .04983 L
.48859 .04989 L
.49033 .04994 L
.49178 .04998 L
.49304 .05002 L
.49409 .05005 L
.49504 .05008 L
.49594 .0501 L
.49688 .05013 L
.49793 .05016 L
.49919 .05019 L
.50061 .05024 L
.50224 .05028 L
.50417 .05034 L
.5064 .0504 L
.50888 .05048 L
.51166 .05055 L
.51448 .05064 L
.51749 .05072 L
.52053 .05081 L
Mistroke
.52369 .05089 L
.5268 .05098 L
.52997 .05105 L
.53306 .05109 L
.53616 .05113 L
.53918 .05117 L
.54206 .05122 L
.54479 .0513 L
.54741 .05143 L
.54995 .05161 L
.55247 .05184 L
.55486 .05213 L
.5572 .05247 L
.55966 .05286 L
.56212 .05329 L
.56459 .05376 L
.56722 .05422 L
.56962 .0547 L
.57203 .05516 L
.57438 .0556 L
.57666 .05604 L
.57891 .05635 L
.58082 .05662 L
.58238 .05681 L
.58367 .05693 L
.58464 .05698 L
.5853 .057 L
.58564 .057 L
.58571 .057 L
.58567 .05699 L
.5857 .05698 L
.5859 .05696 L
.5863 .05696 L
.58693 .05697 L
.58787 .05696 L
.58907 .05694 L
.59048 .05691 L
.59203 .05688 L
.59372 .05689 L
.59545 .05694 L
.59737 .05706 L
.59924 .05725 L
.60101 .05752 L
.6028 .05788 L
.60461 .05833 L
.6064 .05885 L
.60801 .05944 L
.60969 .06006 L
.61135 .06067 L
.61302 .06128 L
Mistroke
.61466 .06186 L
.61627 .06241 L
.61784 .06291 L
.61937 .06335 L
.62088 .06374 L
.62241 .06413 L
.62379 .06451 L
.62517 .06493 L
.62657 .06539 L
.62803 .06594 L
.62956 .06662 L
.6311 .06738 L
.63274 .06826 L
.63466 .06924 L
.63662 .07034 L
.63883 .07151 L
.64122 .07268 L
.64379 .07389 L
.6464 .07509 L
.64901 .07618 L
.65163 .07732 L
.65427 .0783 L
.65704 .07928 L
.65977 .08031 L
.66262 .08139 L
.66562 .08254 L
.66877 .08367 L
.67187 .08486 L
.6751 .08613 L
.67837 .08745 L
.68154 .08868 L
.68472 .08999 L
.68802 .09129 L
.6915 .09283 L
.69469 .09418 L
.69789 .09557 L
.70112 .097 L
.70435 .0984 L
.7075 .09982 L
.7109 .10128 L
.71391 .10259 L
.71715 .10402 L
.72052 .10553 L
.72399 .10699 L
.72745 .10857 L
.73105 .11024 L
.73475 .11185 L
.73838 .11355 L
.74209 .11522 L
.7458 .11686 L
Mistroke
.74937 .11843 L
.75287 .12001 L
.7563 .12154 L
.75968 .12303 L
.76298 .12454 L
.76621 .12602 L
.7695 .12752 L
.77262 .12893 L
.77578 .13037 L
.77892 .13183 L
.78177 .13324 L
.78456 .13465 L
.78711 .13605 L
.78936 .13733 L
.79151 .13856 L
.79323 .13964 L
.79489 .14065 L
.79631 .14163 L
.79755 .14261 L
.79861 .14356 L
.79947 .14456 L
.80019 .14564 L
.8009 .14686 L
.80168 .14827 L
.80259 .14982 L
.80371 .15154 L
.80509 .15358 L
.80671 .15574 L
.80854 .15808 L
.81052 .16059 L
.81267 .16306 L
.81464 .16563 L
.81677 .16817 L
.81899 .17076 L
.82103 .17312 L
.82311 .17553 L
.8251 .17775 L
.82697 .17999 L
.8287 .1821 L
.83029 .18409 L
.83178 .18619 L
.83316 .18822 L
.83448 .19036 L
.83581 .19263 L
.83716 .19482 L
.83858 .19716 L
.84001 .19934 L
.84147 .20153 L
.84293 .20372 L
.84435 .20565 L
Mistroke
.84573 .20761 L
.84701 .20955 L
.84814 .21115 L
.84911 .21269 L
.84994 .21414 L
.85063 .21547 L
.85122 .21668 L
.85174 .21776 L
.85224 .21881 L
.85277 .21993 L
.8534 .2212 L
.85416 .22271 L
.8551 .22441 L
.85628 .22646 L
.85757 .22879 L
.85924 .23135 L
.86116 .23422 L
.86327 .23733 L
.86565 .24059 L
.86822 .24412 L
.87083 .24767 L
.87353 .25144 L
.87595 .25512 L
.87868 .25878 L
.88118 .26198 L
.88394 .26547 L
.88616 .26879 L
.88857 .27207 L
.89103 .27523 L
.89339 .27846 L
.89565 .2816 L
.8978 .28503 L
.90015 .28801 L
.90225 .29118 L
.90444 .29443 L
.90675 .29779 L
.90881 .30098 L
.91061 .30416 L
.91253 .30729 L
.91405 .31008 L
.91569 .31301 L
.91691 .31547 L
.918 .31792 L
.91893 .32013 L
.91969 .32219 L
.92029 .32407 L
.92077 .32586 L
.92116 .32761 L
.9215 .32941 L
.9218 .3312 L
Mistroke
.92214 .33315 L
.92253 .33529 L
.92298 .33733 L
.92347 .33957 L
.92399 .34185 L
.9245 .34424 L
.92497 .34664 L
.9254 .34898 L
.92577 .35141 L
.92606 .35374 L
.92631 .35615 L
.92652 .35826 L
.92674 .36043 L
.92697 .3626 L
.92721 .36474 L
.92747 .36693 L
.92772 .36892 L
.92794 .3709 L
.92812 .37287 L
.92826 .37458 L
.92837 .37625 L
.92845 .37772 L
.92851 .37894 L
.92856 .38009 L
.92859 .38092 L
.92859 .38154 L
.92854 .38194 L
.92842 .38207 L
.92827 .38195 L
.92808 .38161 L
.9279 .38113 L
.92772 .38055 L
.92756 .3799 L
.92743 .37923 L
.92732 .37853 L
.9272 .37779 L
.92707 .37697 L
.9269 .37604 L
.9267 .37495 L
.92648 .37372 L
.92626 .37237 L
.92605 .371 L
.92585 .36955 L
.92566 .36809 L
.92549 .36664 L
.92535 .36533 L
.92522 .36417 L
.92512 .3631 L
.92504 .36224 L
.92498 .36145 L
Mistroke
.92496 .36076 L
.92496 .36018 L
.92497 .35968 L
.92498 .35918 L
.92498 .35857 L
.92496 .35783 L
.92494 .35695 L
.92493 .35587 L
.92491 .35468 L
.92489 .35321 L
.92485 .35144 L
.92478 .3496 L
.9247 .34757 L
.92459 .34559 L
.92446 .34346 L
.92431 .34164 L
.92412 .3398 L
.92389 .33791 L
.92358 .336 L
.92321 .33401 L
.92274 .332 L
.92217 .32977 L
.92148 .32752 L
.92067 .32503 L
.91979 .32253 L
.91881 .32012 L
.91778 .3175 L
.91669 .31503 L
.91561 .31246 L
.9145 .30992 L
.91344 .30774 L
.91238 .30561 L
.9113 .30364 L
.91032 .3018 L
.90938 .30019 L
.90845 .29868 L
.90753 .2972 L
.90665 .29577 L
.90573 .29422 L
.90477 .29258 L
.90373 .2908 L
.90262 .28889 L
.90141 .28683 L
.90014 .28476 L
.8988 .28262 L
.89746 .28057 L
.89607 .27854 L
.89483 .2767 L
.89368 .27507 L
.89262 .27362 L
Mistroke
.89166 .27238 L
.89088 .27137 L
.89023 .27059 L
.88971 .27002 L
.88933 .26966 L
.88908 .26946 L
.88894 .26939 L
.8889 .26941 L
.88893 .26948 L
.889 .26959 L
.88908 .2697 L
.88916 .26978 L
.88922 .26984 L
.88925 .26988 L
.88926 .26991 L
.88926 .26995 L
.88926 .26998 L
.88928 .27002 L
.8893 .27006 L
.88934 .27008 L
.88937 .27005 L
.88939 .26994 L
.88938 .26972 L
.88933 .26939 L
.88923 .26897 L
.88908 .2685 L
.88889 .26805 L
.88867 .26763 L
.88842 .26723 L
.88817 .26687 L
.88792 .26653 L
.88768 .2662 L
.88745 .26587 L
.88725 .26556 L
.88707 .26526 L
.88693 .26501 L
.88684 .26479 L
.88679 .26462 L
.88679 .26449 L
.88683 .26436 L
.88689 .26426 L
.88695 .26421 L
.887 .26422 L
.88704 .26431 L
.88706 .26452 L
.88707 .26488 L
.88706 .26536 L
.88703 .26592 L
.88698 .26649 L
.88693 .26707 L
Mistroke
.88688 .26758 L
.88686 .26801 L
.88686 .2684 L
.88692 .26879 L
.88705 .26923 L
.88726 .26979 L
.88758 .27057 L
.88805 .27161 L
.88866 .27297 L
.88938 .27454 L
.8903 .27652 L
.89136 .27871 L
.89262 .28131 L
.894 .28395 L
.89551 .28685 L
.89712 .2897 L
.89872 .29258 L
.90039 .29533 L
.90186 .29768 L
.90329 .29985 L
.90455 .30169 L
.90569 .3032 L
.90669 .30435 L
.90748 .30519 L
.90811 .30579 L
.9086 .30617 L
.90897 .30641 L
.90927 .30654 L
.90955 .30658 L
.90984 .30657 L
.91014 .30653 L
.91043 .30645 L
.91068 .30636 L
.91091 .30627 L
.91114 .30623 L
.91135 .30625 L
.91149 .30632 L
.91156 .3064 L
.91154 .30646 L
.91141 .3065 L
.91116 .30649 L
.9108 .30645 L
.91033 .3064 L
.90974 .30631 L
.90903 .30614 L
.90822 .30584 L
.90729 .30536 L
.90627 .30463 L
.90514 .30363 L
.9038 .30224 L
Mistroke
.90222 .30037 L
.90052 .298 L
.89837 .29495 L
.89604 .29164 L
.89358 .28799 L
.89088 .28362 L
.88789 .27894 L
.88499 .27399 L
.88185 .26869 L
.87824 .26229 L
.87511 .25714 L
.87168 .25156 L
.86817 .24567 L
.86474 .23983 L
.86097 .23394 L
.85763 .22854 L
.85399 .22315 L
.85031 .21752 L
.84668 .21225 L
.84303 .20645 L
.83937 .20159 L
.83578 .19621 L
.83222 .19097 L
.82869 .18574 L
.82538 .18034 L
.82217 .17552 L
.81926 .1708 L
.81659 .16641 L
.81423 .16208 L
.81219 .1588 L
.81044 .15552 L
.80892 .15273 L
.80764 .15054 L
.80652 .14857 L
.80554 .14694 L
.80464 .14557 L
.80378 .14441 L
.80292 .14344 L
.80198 .14258 L
.8009 .14178 L
.79973 .14105 L
.79832 .14021 L
.79663 .13921 L
.79467 .13807 L
.79237 .13675 L
.78996 .13534 L
.78746 .13391 L
.78473 .1325 L
.78212 .13118 L
.77944 .12993 L
Mistroke
.77704 .12877 L
.7747 .12772 L
.77253 .12677 L
.7706 .1259 L
.76899 .12514 L
.7676 .1245 L
.76653 .124 L
.76574 .12363 L
.76522 .12338 L
.76494 .12322 L
.76486 .12313 L
.76493 .12309 L
.76512 .1231 L
.76541 .12316 L
.76576 .12325 L
.76615 .12339 L
.76656 .12356 L
.76701 .12375 L
.7675 .12397 L
.76806 .12419 L
.76867 .12442 L
.76932 .12464 L
.76998 .12484 L
.77066 .12503 L
.77132 .12523 L
.77195 .12544 L
.77252 .12565 L
.773 .12585 L
.77338 .12603 L
.77368 .12619 L
.77388 .12631 L
.774 .12642 L
.77404 .12649 L
.77401 .12652 L
.77393 .12651 L
.7738 .12646 L
.77363 .12636 L
.77344 .1262 L
.77325 .12598 L
.77311 .12569 L
.77306 .12537 L
.77308 .12504 L
.77314 .12475 L
.77316 .12449 L
.77312 .12426 L
.77298 .12408 L
.77267 .12394 L
.77217 .12382 L
.77139 .12367 L
.77029 .12347 L
Mistroke
.7688 .12317 L
.76689 .12275 L
.76488 .12219 L
.76242 .12146 L
.7595 .12057 L
.75651 .1195 L
.75303 .1183 L
.74987 .117 L
.74627 .11572 L
.74327 .11444 L
.73992 .11319 L
.73713 .11202 L
.73422 .11088 L
.73166 .10984 L
.72912 .10883 L
.72662 .10785 L
.72413 .10692 L
.72138 .10602 L
.71856 .10512 L
.71536 .10424 L
.71156 .10328 L
.70767 .10224 L
.70306 .10108 L
.69787 .09983 L
.69221 .09843 L
.68647 .09688 L
.67983 .09522 L
.67387 .09344 L
.66697 .09165 L
.6607 .08965 L
.65367 .08761 L
.64757 .08531 L
.64127 .08291 L
.63551 .08044 L
.62985 .07771 L
.62463 .07507 L
.61963 .07229 L
.61467 .06959 L
.61027 .06686 L
.60591 .06445 L
.60166 .06184 L
.59764 .05988 L
.5934 .05803 L
.58965 .05634 L
.58576 .05493 L
.58169 .05381 L
.57807 .05292 L
.57426 .05225 L
.57057 .05179 L
.56708 .0515 L
Mistroke
.5635 .05132 L
.56027 .05121 L
.557 .05111 L
.55401 .05098 L
.55107 .05082 L
.5483 .05064 L
.54559 .05044 L
.54297 .05021 L
.5404 .04995 L
.53803 .04972 L
.53572 .04952 L
.53336 .04935 L
.53109 .04924 L
.52879 .04918 L
.52646 .04917 L
.52432 .04921 L
.5222 .04929 L
.5202 .04941 L
.51833 .04957 L
.51662 .04975 L
.51513 .04995 L
.51377 .05014 L
.51256 .05031 L
.51153 .05046 L
.51073 .05059 L
.51016 .05067 L
.50981 .0507 L
.50959 .05067 L
.50948 .05058 L
.50942 .05042 L
.50939 .05022 L
.50936 .04999 L
.5093 .04975 L
.50924 .04951 L
.50924 .04928 L
.50932 .04905 L
.50948 .04883 L
.5097 .04863 L
.50999 .04846 L
.5103 .04831 L
.51064 .04821 L
.51101 .04816 L
.51141 .04816 L
.51186 .0482 L
.51237 .04827 L
.51293 .04835 L
.51355 .04843 L
.51419 .04849 L
.51483 .04854 L
.51546 .04858 L
Mistroke
.51608 .04861 L
.5167 .04864 L
.51727 .04865 L
.5178 .04867 L
.51827 .04867 L
.51864 .04866 L
.5189 .04863 L
.51902 .04858 L
.51897 .04854 L
.5187 .04852 L
.5182 .04851 L
.51747 .04851 L
.51651 .04851 L
.51536 .04851 L
.51406 .04851 L
.51264 .04852 L
.51113 .04855 L
.50956 .04859 L
.50801 .04865 L
.50639 .04875 L
.5047 .04887 L
.50305 .04899 L
.50132 .04912 L
.49948 .04925 L
.49752 .04935 L
.49542 .04945 L
.4931 .04954 L
.49054 .0496 L
.48806 .04966 L
.48518 .04969 L
.48231 .0497 L
.47913 .04968 L
.47584 .04961 L
.4726 .04951 L
.46914 .04937 L
.46582 .04923 L
.46242 .04909 L
.45926 .04898 L
.45598 .04887 L
.45269 .04877 L
.44961 .04867 L
.44637 .04856 L
.44302 .04846 L
.44 .04836 L
.4367 .04825 L
.43339 .04813 L
.42992 .04799 L
.42649 .04782 L
.42298 .04762 L
.41946 .04743 L
Mistroke
.41622 .04726 L
.41326 .04713 L
.41042 .04704 L
.40794 .04701 L
.40542 .04706 L
.40335 .0472 L
.40135 .04744 L
.39936 .04779 L
.39734 .04831 L
.39536 .04902 L
.39311 .04987 L
.39049 .05092 L
.38788 .05219 L
.38481 .05371 L
.38127 .05523 L
.37783 .05696 L
.3743 .05876 L
.37026 .06063 L
.36663 .06235 L
.36336 .06389 L
.35988 .06552 L
.35704 .067 L
.35401 .06845 L
.35167 .06979 L
.34946 .07095 L
.34727 .07203 L
.34497 .07308 L
.34254 .07422 L
.33994 .07552 L
.33757 .0768 L
.33474 .07831 L
.33174 .08 L
.32833 .08182 L
.32526 .08339 L
.32185 .08506 L
.31888 .08644 L
.31588 .0877 L
.31354 .08872 L
.31141 .08959 L
.30971 .09015 L
.30846 .09051 L
.30766 .09068 L
.30721 .09068 L
.30703 .09055 L
.30707 .0903 L
.30729 .09002 L
.30759 .08977 L
.30791 .08956 L
.30821 .08937 L
.30849 .08919 L
Mistroke
.30876 .08903 L
.30905 .0889 L
.30937 .08875 L
.30973 .08857 L
.31013 .08836 L
.31054 .08814 L
.31096 .08792 L
.31137 .0877 L
.31174 .0875 L
.31206 .08733 L
.31235 .08719 L
.31261 .0871 L
.31285 .08705 L
.31309 .08704 L
.31329 .08706 L
.31342 .0871 L
.31346 .08714 L
.31337 .08717 L
.31316 .08717 L
.31284 .08714 L
.31243 .08705 L
.31197 .08692 L
.31152 .08679 L
.31112 .0867 L
.31077 .08666 L
.31043 .08668 L
.31008 .08681 L
.30969 .08706 L
.30926 .08748 L
.30876 .08807 L
.30817 .08882 L
.30745 .08976 L
.30659 .09084 L
.30553 .09201 L
.3042 .09336 L
.3026 .09495 L
.30048 .09664 L
.29796 .09844 L
.2949 .10042 L
.29144 .10236 L
.2876 .10444 L
.28343 .10669 L
.2788 .10889 L
.27437 .11137 L
.26933 .11384 L
.26434 .11654 L
.25926 .11924 L
.25413 .12209 L
.24914 .12484 L
.24414 .12766 L
Mistroke
.23943 .13031 L
.23505 .13297 L
.23116 .13535 L
.22756 .13775 L
.2248 .1396 L
.22236 .14131 L
.22028 .14283 L
.21867 .14402 L
.21746 .14494 L
.21666 .14563 L
.21622 .1461 L
.21606 .14637 L
.21609 .14649 L
.21623 .14653 L
.21643 .1465 L
.21662 .14643 L
.21677 .14635 L
.21687 .14626 L
.21694 .14619 L
.21697 .14613 L
.21698 .1461 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21699 .14609 L
.21702 .1461 L
.21711 .1461 L
.21723 .1461 L
.21735 .14611 L
.2174 .14611 L
.21736 .14611 L
.21719 .1461 L
.21688 .14609 L
.21643 .14608 L
.21584 .14606 L
.21514 .14603 L
.21437 .14599 L
.21353 .14594 L
.21271 .14587 L
.21191 .14578 L
.21116 .14569 L
.2105 .1456 L
.20997 .14554 L
Mistroke
.20961 .14553 L
.20944 .14561 L
.20942 .14579 L
.20953 .14609 L
.20969 .14652 L
.20987 .14709 L
.21001 .14779 L
.21006 .14865 L
.21001 .14966 L
.20985 .15081 L
.20958 .15204 L
.20915 .15344 L
.20852 .15504 L
.20768 .15664 L
.20659 .15845 L
.20526 .16046 L
.20376 .16236 L
.2021 .16433 L
.20033 .16647 L
.19867 .16841 L
.19692 .17045 L
.19517 .17238 L
.19359 .17402 L
.19208 .17558 L
.1907 .17702 L
.18956 .17814 L
.1887 .17906 L
.18814 .17976 L
.18788 .18022 L
.18789 .18047 L
.18812 .18057 L
.18853 .18054 L
.18902 .18042 L
.1895 .18029 L
.1899 .18017 L
.1902 .1801 L
.19038 .18008 L
.19041 .18014 L
.19029 .18027 L
.19002 .18044 L
.18965 .18063 L
.18921 .18085 L
.18873 .18108 L
.18817 .1813 L
.18759 .18153 L
.18697 .18174 L
.18634 .18194 L
.18576 .18212 L
.18526 .18228 L
.18486 .18241 L
Mistroke
.18457 .1825 L
.1844 .18253 L
.18436 .18251 L
.18446 .18244 L
.18475 .18234 L
.18497 .18225 L
.18521 .18215 L
.18555 .18204 L
.18598 .18192 L
.1865 .18175 L
.1871 .18151 L
.1878 .18115 L
.18857 .18064 L
.1894 .17997 L
.19025 .17915 L
.19108 .17819 L
.19187 .17711 L
.19259 .17603 L
.19322 .17486 L
.19382 .17369 L
.19437 .17261 L
.19488 .17156 L
.19536 .17066 L
.19582 .16987 L
.19626 .16925 L
.19666 .16884 L
.19701 .16868 L
.19732 .16876 L
.19757 .16908 L
.19778 .16958 L
.19797 .17019 L
.19817 .17085 L
.19837 .17152 L
.19855 .17219 L
.19871 .17287 L
.19882 .17354 L
.19887 .17422 L
.19889 .17487 L
.1989 .17545 L
.19892 .17592 L
.19896 .17626 L
.19901 .1765 L
.19905 .17667 L
.19907 .17681 L
.19903 .17694 L
.19888 .17709 L
.19859 .17726 L
.19817 .17747 L
.19759 .17772 L
.19687 .178 L
Mistroke
.19602 .17827 L
.19513 .17851 L
.19417 .17878 L
.19316 .17906 L
.19215 .17935 L
.19117 .17966 L
.19032 .17996 L
.18958 .18018 L
.189 .1803 L
.18863 .18033 L
.1884 .18029 L
.18827 .18021 L
.1882 .18013 L
.18814 .18008 L
.18801 .18005 L
.18778 .18003 L
.18746 .18002 L
.18705 .18001 L
.18656 .17999 L
.18603 .17998 L
.18547 .17996 L
.18494 .17994 L
.18445 .17993 L
.18391 .17991 L
.18341 .17989 L
.183 .17985 L
.18273 .17981 L
.1826 .17977 L
.18262 .17976 L
.18278 .17977 L
.18307 .17982 L
.18349 .17989 L
.184 .17998 L
.18461 .18007 L
.18532 .18017 L
.18615 .18031 L
.18701 .1805 L
.1878 .18075 L
.18851 .18109 L
.18905 .18155 L
.18936 .18214 L
.18938 .18288 L
.18907 .1838 L
.18844 .18491 L
.18759 .18612 L
.18635 .18758 L
.18476 .18932 L
.18313 .19119 L
.18122 .19345 L
.17901 .19594 L
Mistroke
.17661 .19857 L
.17415 .20154 L
.17164 .20472 L
.16905 .20802 L
.16652 .21152 L
.16394 .21507 L
.16132 .21894 L
.15859 .22294 L
.15592 .22681 L
.15305 .23103 L
.15017 .23538 L
.14723 .23991 L
.14417 .24424 L
.14086 .24952 L
.13794 .25366 L
.13455 .2592 L
.1313 .26352 L
.12831 .26844 L
.12519 .2731 L
.12203 .27731 L
.11877 .28195 L
.11576 .28637 L
.11299 .29051 L
.11019 .29419 L
.10758 .29767 L
.10515 .30057 L
.10294 .30341 L
.10135 .30563 L
.09978 .30781 L
.09869 .30941 L
.09786 .31078 L
.09727 .31194 L
.09693 .31289 L
.09682 .31364 L
.09688 .31424 L
.09701 .31474 L
.09715 .31525 L
.09726 .31581 L
.09731 .31648 L
.09723 .31734 L
.09699 .31848 L
.09659 .31997 L
.09605 .32165 L
.09542 .32356 L
.09472 .32585 L
.09393 .32858 L
.09308 .33138 L
.09221 .33408 L
.09135 .33741 L
.09053 .34095 L
Mistroke
.08973 .34476 L
.08895 .34834 L
.08819 .35263 L
.08744 .35629 L
.08665 .35991 L
.08582 .36399 L
.08502 .36775 L
.08424 .37154 L
.08353 .3755 L
.08288 .37902 L
.0823 .38251 L
.0818 .38589 L
.08139 .38876 L
.08104 .39142 L
.08076 .39373 L
.08052 .39582 L
.08032 .39735 L
.08015 .39861 L
.08003 .39958 L
.07995 .40026 L
.07992 .40067 L
.07994 .40085 L
.07998 .40086 L
.08003 .40076 L
.08007 .4006 L
.08009 .40042 L
.0801 .40027 L
.0801 .40016 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
Mistroke
.0802 .40006 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.00440917 0.39418 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.08028 .40002 m
.08036 .39998 L
.08039 .39996 L
.08036 .39998 L
.08024 .40003 L
.08002 .40013 L
.07967 .40029 L
.0792 .40051 L
.07864 .40076 L
.07804 .40104 L
.07745 .40131 L
.07692 .40155 L
.07644 .40176 L
.07601 .40191 L
.07565 .40199 L
.0754 .402 L
.07529 .40194 L
.07533 .40181 L
.07549 .40163 L
.07575 .40139 L
.07608 .40112 L
.07644 .40084 L
.0768 .40057 L
.07707 .40035 L
.07724 .40017 L
.07732 .40006 L
.07737 .4 L
.0774 .39998 L
.07742 .39998 L
.07745 .39999 L
.07752 .39999 L
.07764 .39998 L
.07783 .39998 L
.07808 .39999 L
.07838 .40004 L
.07874 .40014 L
.07916 .40028 L
.07964 .40045 L
.08018 .40066 L
.08077 .40089 L
.08136 .40114 L
.08192 .40138 L
.08245 .40161 L
.08294 .40179 L
.08339 .40193 L
.08384 .40205 L
.08429 .40215 L
.08477 .40225 L
.08528 .40234 L
.08581 .40246 L
Mistroke
.08632 .40263 L
.08683 .40285 L
.08734 .40315 L
.08784 .40357 L
.08838 .40412 L
.08897 .40481 L
.08955 .4056 L
.09017 .40651 L
.09079 .40752 L
.0914 .40865 L
.09193 .40991 L
.09236 .41131 L
.09266 .41294 L
.09287 .4148 L
.09297 .41699 L
.093 .41924 L
.09296 .42193 L
.09285 .42466 L
.09263 .42787 L
.09229 .43127 L
.09176 .43401 L
.09107 .4373 L
.09021 .44006 L
.08917 .44335 L
.08794 .44583 L
.08651 .44825 L
.08501 .45045 L
.08387 .45215 L
.08245 .45345 L
.08099 .45445 L
.07985 .45519 L
.07879 .45569 L
.07777 .45601 L
.07684 .45617 L
.07611 .45619 L
.07557 .45609 L
.07518 .45588 L
.07492 .45562 L
.07474 .45531 L
.0746 .45501 L
.07447 .45473 L
.07435 .45447 L
.07416 .45422 L
.07389 .45397 L
.07361 .45373 L
.07337 .45351 L
.07316 .45332 L
.07299 .45316 L
.07287 .45306 L
.0728 .453 L
Mistroke
.07278 .45298 L
.0728 .45299 L
.07284 .45303 L
.07288 .45307 L
.07292 .4531 L
.07293 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07295 .45312 L
.07299 .45312 L
.07308 .45315 L
.07321 .4532 L
.07334 .45328 L
.07338 .45335 L
.0733 .45339 L
.07309 .4534 L
.07271 .45336 L
.0721 .45326 L
.07127 .45307 L
.07027 .45279 L
.06918 .4524 L
.06813 .4519 L
.06726 .45129 L
.06618 .45057 L
.06525 .44976 L
.06429 .44884 L
.06337 .44783 L
.06265 .44673 L
.06219 .4456 L
.06196 .44447 L
.0619 .44329 L
.06197 .4421 L
.06213 .44088 L
.06231 .43961 L
.06244 .4383 L
.06253 .43698 L
.06258 .43559 L
.06262 .4342 L
.06262 .4329 L
.06262 .43164 L
Mistroke
.0626 .4304 L
.06259 .42919 L
.06261 .42804 L
.06267 .4269 L
.0628 .42573 L
.06301 .42459 L
.06332 .42344 L
.0637 .42229 L
.06416 .42116 L
.06468 .42016 L
.06522 .41918 L
.06578 .41824 L
.06633 .41735 L
.06685 .41658 L
.06733 .41587 L
.06777 .41527 L
.06818 .41479 L
.06854 .41446 L
.06886 .41427 L
.06913 .4142 L
.06937 .41423 L
.06959 .4143 L
.0698 .41437 L
.07 .41444 L
.07018 .41448 L
.07039 .41449 L
.07063 .41448 L
.07089 .41451 L
.07118 .41456 L
.0715 .41466 L
.07183 .41481 L
.07215 .41498 L
.07244 .41517 L
.0727 .41533 L
.07292 .41548 L
.07308 .41559 L
.07317 .41575 L
.07319 .4158 L
.07314 .41599 L
.07297 .41617 L
.0727 .41631 L
.07234 .41639 L
.0719 .41642 L
.0714 .41637 L
.07085 .41627 L
.0703 .41611 L
.06981 .41595 L
.06939 .41581 L
.06906 .4157 L
.06882 .41557 L
Mistroke
.06865 .41543 L
.06856 .41525 L
.06854 .41502 L
.06855 .41476 L
.06859 .41447 L
.06864 .41418 L
.0687 .4139 L
.06875 .41365 L
.06877 .41344 L
.06878 .41324 L
.06879 .41303 L
.06879 .4128 L
.0688 .41258 L
.06881 .41239 L
.06881 .41224 L
.06882 .41213 L
.06882 .41207 L
.06882 .41205 L
.06882 .41207 L
.06882 .4121 L
.06882 .41215 L
.06881 .41218 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06882 .41216 L
.06882 .41209 L
.06882 .41199 L
.06883 .41188 L
.06883 .41184 L
.06883 .41187 L
.06882 .41201 L
.06881 .41228 L
.0688 .41269 L
.06878 .41323 L
.06876 .41388 L
.06874 .41459 L
.06872 .41533 L
Mistroke
.06871 .41602 L
.06872 .41665 L
.06874 .41726 L
.06876 .41788 L
.06876 .41846 L
.06873 .41896 L
.06866 .41939 L
.06854 .41976 L
.06837 .42011 L
.06815 .42045 L
.0679 .42079 L
.06762 .42114 L
.06732 .42155 L
.06703 .42202 L
.06674 .42252 L
.06645 .42301 L
.06618 .42347 L
.06596 .42384 L
.06581 .42407 L
.06572 .42417 L
.06569 .42418 L
.06569 .42417 L
.0657 .42416 L
.06567 .42423 L
.0656 .42442 L
.06546 .42479 L
.06525 .42532 L
.06496 .42597 L
.06463 .42669 L
.06427 .42744 L
.06393 .42815 L
.06361 .42885 L
.06332 .42954 L
.0631 .43022 L
.06297 .43083 L
.06294 .43132 L
.06304 .43162 L
.06325 .43175 L
.06355 .43173 L
.0639 .43162 L
.06425 .43148 L
.06457 .43137 L
.06484 .43135 L
.06501 .43144 L
.06508 .43164 L
.06504 .43194 L
.0649 .43233 L
.06469 .43284 L
.0644 .43346 L
.06408 .43418 L
Mistroke
.06374 .43495 L
.06338 .43578 L
.06306 .43666 L
.06278 .43753 L
.06257 .43836 L
.06242 .43911 L
.06232 .43979 L
.06227 .44039 L
.06227 .44088 L
.0623 .44124 L
.06234 .44146 L
.06237 .44155 L
.06237 .4415 L
.06235 .44131 L
.06232 .44099 L
.06229 .44053 L
.06229 .43996 L
.06233 .43929 L
.06241 .43856 L
.06255 .43779 L
.06276 .43698 L
.06303 .43618 L
.06335 .4354 L
.06369 .43465 L
.06402 .43395 L
.06431 .43331 L
.06455 .4327 L
.06474 .43214 L
.06485 .43162 L
.06489 .43111 L
.06484 .43057 L
.06471 .42998 L
.06451 .42933 L
.06427 .42866 L
.064 .42794 L
.0637 .42716 L
.06342 .42628 L
.06319 .42529 L
.06301 .42429 L
.06289 .42324 L
.06281 .42216 L
.06278 .42115 L
.0628 .42014 L
.06289 .41912 L
.06302 .4181 L
.06319 .41711 L
.0634 .41623 L
.06363 .41539 L
.0639 .41466 L
.06419 .41402 L
Mistroke
.06449 .41349 L
.06478 .41303 L
.06507 .41265 L
.06536 .41235 L
.06562 .41214 L
.06585 .41202 L
.06603 .41198 L
.06615 .412 L
.0662 .41203 L
.06619 .41206 L
.06613 .4121 L
.06605 .41214 L
.06596 .41219 L
.06591 .41223 L
.06591 .41226 L
.06597 .41229 L
.06609 .41232 L
.06628 .41235 L
.06654 .41237 L
.06687 .41239 L
.06728 .41239 L
.06775 .41239 L
.06828 .41239 L
.06889 .41237 L
.06958 .41235 L
.07031 .41233 L
.07106 .41229 L
.07184 .41225 L
.07262 .41221 L
.07336 .41217 L
.07405 .41213 L
.07471 .4121 L
.07534 .41206 L
.07594 .41202 L
.07646 .41197 L
.07686 .41191 L
.07712 .41185 L
.0772 .41183 L
.07706 .41189 L
.07667 .41205 L
.07606 .4123 L
.07527 .41266 L
.07441 .4131 L
.07353 .41362 L
.0727 .41421 L
.07191 .41488 L
.07112 .41561 L
.07031 .41641 L
.06955 .41716 L
.06893 .41798 L
Mistroke
.06853 .41883 L
.06833 .41972 L
.06828 .42064 L
.06831 .42161 L
.0684 .4226 L
.06849 .42366 L
.06849 .42482 L
.06839 .42606 L
.06822 .42733 L
.06802 .42854 L
.06777 .42974 L
.06748 .43099 L
.06713 .43227 L
.06674 .43357 L
.06631 .43475 L
.06583 .43591 L
.06534 .43706 L
.06484 .43816 L
.06436 .43918 L
.06391 .44008 L
.06353 .44081 L
.0632 .44149 L
.06292 .44213 L
.06268 .44272 L
.06249 .44323 L
.06234 .44364 L
.06223 .44393 L
.06216 .44408 L
.06214 .44411 L
.06217 .44401 L
.06221 .44381 L
.06227 .44356 L
.06231 .4433 L
.06234 .44306 L
.06235 .44281 L
.06236 .44255 L
.06236 .4423 L
.06237 .44205 L
.06238 .4418 L
.06239 .44158 L
.0624 .44138 L
.0624 .44123 L
.0624 .44112 L
.06241 .44106 L
.06241 .44104 L
.06241 .44106 L
.0624 .44109 L
.0624 .44113 L
.0624 .44117 L
.0624 .44118 L
Mistroke
.0624 .44118 L
.0624 .44116 L
.06241 .4411 L
.06241 .441 L
.06241 .44089 L
.06242 .44083 L
.06241 .44085 L
.06241 .44098 L
.0624 .44123 L
.06238 .44159 L
.06237 .44207 L
.06235 .44266 L
.06233 .44331 L
.06231 .444 L
.06228 .44471 L
.06226 .44536 L
.06222 .44603 L
.06216 .44669 L
.06209 .44737 L
.06202 .44784 L
.06195 .44821 L
.06189 .44839 L
.06188 .44844 L
.06194 .44842 L
.06209 .44837 L
.06236 .44835 L
.06274 .4484 L
.06322 .44855 L
.06381 .44878 L
.06446 .44907 L
.0652 .44944 L
.06603 .4499 L
.06687 .45048 L
.06782 .45116 L
.06868 .45197 L
.06953 .45294 L
.07033 .45409 L
.07101 .45543 L
.07154 .45694 L
.07189 .45842 L
.07209 .45999 L
.07213 .46166 L
.07205 .46341 L
.07188 .46501 L
.07164 .4665 L
.07138 .46798 L
.07109 .46939 L
.07079 .47051 L
.07048 .47147 L
.07017 .47225 L
Mistroke
.0699 .47285 L
.0697 .47325 L
.06958 .47348 L
.06955 .47354 L
.06959 .47345 L
.06965 .47322 L
.06971 .47295 L
.06972 .47255 L
.06968 .47203 L
.06957 .47138 L
.06941 .4706 L
.06924 .4697 L
.06907 .46873 L
.06895 .46767 L
.06887 .46655 L
.06885 .46544 L
.06887 .4643 L
.06889 .4632 L
.06892 .46226 L
.06897 .46141 L
.06904 .46065 L
.06914 .45997 L
.06928 .45939 L
.06945 .45892 L
.06962 .45853 L
.06975 .45824 L
.06985 .45803 L
.06987 .45788 L
.06982 .45774 L
.06973 .45761 L
.06965 .45748 L
.0696 .45733 L
.06959 .45718 L
.06961 .45702 L
.06965 .45688 L
.0697 .45675 L
.06974 .45659 L
.06978 .45656 L
.0698 .45638 L
.06982 .4562 L
.06986 .45604 L
.06992 .45589 L
.06999 .45575 L
.07006 .45562 L
.07012 .45552 L
.07017 .45547 L
.07019 .45547 L
.07018 .4555 L
.07016 .45552 L
.07014 .45554 L
Mistroke
.07014 .45558 L
.07017 .45562 L
.07021 .45566 L
.07025 .4557 L
.07027 .45572 L
.07026 .45571 L
.0702 .45565 L
.07009 .45556 L
.06993 .45542 L
.06973 .45524 L
.06949 .45502 L
.06921 .45477 L
.0689 .4545 L
.06858 .45421 L
.06826 .45392 L
.06793 .45367 L
.06763 .45346 L
.06738 .45332 L
.06721 .45328 L
.06715 .45335 L
.06723 .45351 L
.06748 .45374 L
.06794 .45401 L
.06859 .45427 L
.0694 .4545 L
.07039 .45468 L
.07158 .45477 L
.07299 .4548 L
.07429 .45476 L
.07573 .45465 L
.07732 .45449 L
.07885 .45428 L
.08045 .45402 L
.0818 .45374 L
.08313 .45345 L
.0844 .4532 L
.0855 .453 L
.08644 .45286 L
.08723 .45278 L
.08785 .45275 L
.08831 .45276 L
.08868 .4528 L
.08896 .45283 L
.08917 .45286 L
.08933 .45288 L
.08944 .45288 L
.08949 .45288 L
.08951 .45288 L
.08949 .45287 L
.08945 .45286 L
Mistroke
.08941 .45283 L
.08936 .45279 L
.08933 .45276 L
.08932 .45274 L
.08931 .45274 L
.08931 .45277 L
.08931 .45281 L
.08931 .45287 L
.08931 .45299 L
.0893 .45316 L
.08929 .45343 L
.08928 .45378 L
.08926 .45423 L
.08924 .45476 L
.08922 .45536 L
.0892 .45601 L
.08918 .45668 L
.08918 .45729 L
.0892 .45781 L
.08922 .45824 L
.08925 .45864 L
.08927 .45901 L
.08927 .45937 L
.08921 .45974 L
.08908 .46019 L
.08887 .46073 L
.0886 .46136 L
.08828 .46207 L
.08793 .46286 L
.08756 .46375 L
.0872 .46469 L
.08685 .46573 L
.08652 .46682 L
.08622 .46793 L
.08595 .469 L
.08576 .46991 L
.08561 .47074 L
.08555 .47134 L
.08558 .47179 L
.08573 .47205 L
.08595 .47216 L
.08616 .47216 L
.08634 .47209 L
.08642 .47198 L
.08639 .47187 L
.0862 .47181 L
.0858 .47186 L
.08512 .47208 L
.08415 .47252 L
.08289 .47322 L
Mistroke
.08135 .47425 L
.07978 .47561 L
.07817 .47729 L
.07618 .47938 L
.07385 .48197 L
.07212 .48451 L
.06973 .48788 L
.068 .49106 L
.06613 .4948 L
.06469 .49863 L
.06339 .50265 L
.06233 .50687 L
.06164 .51117 L
.06132 .51536 L
.06125 .5198 L
.06143 .52454 L
.06179 .52926 L
.06231 .53348 L
.06293 .53864 L
.06357 .54278 L
.06426 .54773 L
.06498 .55158 L
.06568 .55554 L
.06639 .55966 L
.06709 .56341 L
.06774 .56716 L
.06833 .5705 L
.06887 .57371 L
.06935 .5767 L
.06973 .5796 L
.07001 .58201 L
.07022 .58457 L
.07038 .5869 L
.07052 .58936 L
.07063 .59187 L
.07073 .5942 L
.07083 .59659 L
.07095 .59897 L
.07109 .60098 L
.07125 .60295 L
.07142 .60471 L
.07158 .60636 L
.07174 .60803 L
.07192 .60951 L
.07209 .61098 L
.07228 .6124 L
.07246 .61377 L
.07265 .61508 L
.07283 .61634 L
.073 .61741 L
Mistroke
.07316 .61859 L
.0733 .6199 L
.07344 .62115 L
.07361 .62249 L
.07383 .62391 L
.07411 .62536 L
.07443 .62676 L
.07477 .62809 L
.07511 .62932 L
.07545 .63055 L
.07579 .63183 L
.07612 .63319 L
.07644 .63467 L
.07675 .6362 L
.07706 .63785 L
.07737 .6396 L
.0777 .64141 L
.07806 .643 L
.07842 .64487 L
.07878 .64656 L
.07914 .6484 L
.07949 .65043 L
.07984 .6526 L
.08019 .65465 L
.08053 .65676 L
.08085 .65893 L
.08113 .66092 L
.08138 .66285 L
.08158 .66468 L
.08175 .66638 L
.08187 .66781 L
.08197 .66911 L
.08204 .67022 L
.08208 .6711 L
.08209 .67172 L
.08206 .6721 L
.08202 .67227 L
.08197 .6723 L
.08194 .67222 L
.08193 .67207 L
.08193 .67189 L
.08193 .67174 L
.08194 .67168 L
.08194 .67167 L
.08194 .67166 L
.08194 .67161 L
.08194 .67151 L
.08194 .67138 L
.08195 .67126 L
.08195 .67116 L
Mistroke
.08194 .67113 L
.0819 .67122 L
.08185 .67149 L
.0818 .67196 L
.08176 .67266 L
.08175 .67358 L
.08178 .67469 L
.08186 .67598 L
.08198 .67725 L
.08215 .67864 L
.08235 .68008 L
.08257 .68152 L
.08281 .68284 L
.08306 .68406 L
.08331 .68507 L
.08356 .68588 L
.08379 .68647 L
.08399 .68682 L
.08413 .68694 L
.08421 .6869 L
.08424 .68677 L
.08424 .68663 L
.08421 .68651 L
.0842 .68645 L
.08421 .6865 L
.08426 .68666 L
.08437 .68695 L
.08453 .68738 L
.08474 .68794 L
.08502 .68864 L
.08539 .68946 L
.08584 .69038 L
.08641 .6914 L
.08709 .69244 L
.08789 .69346 L
.08876 .6944 L
.08972 .69528 L
.09079 .6961 L
.0919 .69687 L
.0932 .69757 L
.09455 .69823 L
.09609 .69887 L
.0977 .69952 L
.09947 .70016 L
.10135 .70074 L
.10325 .70122 L
.10524 .70157 L
.10742 .70186 L
.10953 .70208 L
.11183 .70221 L
Mistroke
.11424 .70222 L
.1166 .70206 L
.11923 .7017 L
.12194 .7011 L
.12469 .70028 L
.12769 .69929 L
.13039 .69814 L
.13289 .6969 L
.13513 .69565 L
.1374 .69444 L
.13951 .69337 L
.14161 .69236 L
.1431 .6915 L
.14432 .69074 L
.14529 .69011 L
.14603 .6896 L
.14654 .6892 L
.14681 .68894 L
.14689 .6888 L
.14685 .68878 L
.14676 .68885 L
.14663 .68896 L
.14648 .68908 L
.14635 .68917 L
.14629 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14626 .68922 L
.14623 .68925 L
.14618 .68931 L
.14614 .6894 L
.1461 .68949 L
.14608 .6896 L
.14609 .68972 L
.14616 .68981 L
.14627 .68984 L
.14645 .68976 L
Mistroke
.1467 .68949 L
.14703 .68897 L
.14741 .68814 L
.14785 .68696 L
.14836 .68543 L
.14894 .68353 L
.14962 .68117 L
.15043 .67852 L
.15132 .67564 L
.15233 .67228 L
.15346 .66894 L
.15461 .66531 L
.15583 .66158 L
.15714 .65801 L
.15835 .65455 L
.15967 .65133 L
.16109 .64843 L
.16241 .64599 L
.16391 .64391 L
.16529 .6423 L
.16678 .64104 L
.16839 .64011 L
.16992 .63945 L
.17155 .63902 L
.1733 .63877 L
.17502 .63865 L
.17683 .63862 L
.1787 .63863 L
.18053 .63861 L
.18231 .63855 L
.184 .6384 L
.18559 .63821 L
.18692 .63801 L
.18824 .63787 L
.18934 .63787 L
.19034 .63803 L
.19124 .63839 L
.19204 .63898 L
.19273 .63982 L
.19341 .64092 L
.19412 .64228 L
.19487 .64386 L
.19579 .64583 L
.19676 .64787 L
.1979 .65025 L
.19929 .65305 L
.2008 .65593 L
.20263 .65921 L
.2045 .66264 L
.20658 .66646 L
Mistroke
.20885 .67029 L
.21148 .67437 L
.21404 .67863 L
.21678 .68321 L
.2192 .68765 L
.22167 .69232 L
.22399 .69708 L
.22609 .70212 L
.22792 .70674 L
.22955 .71161 L
.23091 .71648 L
.23203 .72157 L
.23297 .72626 L
.23371 .73098 L
.23426 .73556 L
.23464 .73957 L
.23485 .74418 L
.23495 .74819 L
.23492 .75242 L
.23479 .75618 L
.23459 .75988 L
.23431 .76357 L
.23393 .76725 L
.2335 .77013 L
.23304 .77313 L
.23259 .77661 L
.23222 .77932 L
.23202 .78214 L
.23205 .78513 L
.23237 .78799 L
.23295 .79089 L
.23376 .79392 L
.23478 .79709 L
.23596 .80055 L
.23713 .80407 L
.23845 .80789 L
.23983 .81201 L
.24114 .81668 L
.24248 .82054 L
.24368 .82501 L
.24477 .82981 L
.24569 .83381 L
.24638 .83825 L
.24682 .8426 L
.24706 .8468 L
.24713 .85062 L
.24707 .8543 L
.24694 .85752 L
.24676 .86048 L
.24653 .8631 L
Mistroke
.24626 .86542 L
.24599 .8675 L
.24576 .86906 L
.24557 .8703 L
.24539 .87121 L
.24519 .87185 L
.24496 .87225 L
.24468 .87247 L
.2443 .87262 L
.24381 .87278 L
.24322 .87302 L
.24254 .87336 L
.2418 .87376 L
.24102 .87421 L
.24024 .87468 L
.23947 .87513 L
.23869 .8755 L
.23795 .87575 L
.23729 .87587 L
.23675 .87586 L
.23637 .87572 L
.23615 .87546 L
.23608 .87511 L
.23614 .87467 L
.23631 .87417 L
.23653 .87365 L
.23677 .87318 L
.23698 .8728 L
.23716 .87251 L
.23729 .87227 L
.23736 .87205 L
.23735 .87181 L
.23724 .87153 L
.23701 .87114 L
.23665 .87063 L
.23614 .86996 L
.23548 .86915 L
.23466 .86824 L
.23372 .86727 L
.23275 .86628 L
.23177 .86528 L
.23083 .86431 L
.22992 .86341 L
.22901 .8626 L
.22816 .86188 L
.22732 .86125 L
.22646 .86076 L
.22556 .86041 L
.22461 .86023 L
.22366 .86024 L
Mistroke
.22275 .86042 L
.2219 .86075 L
.22118 .8612 L
.22054 .86175 L
.21995 .86235 L
.21943 .86296 L
.21901 .86353 L
.21877 .86407 L
.21876 .86457 L
.21898 .86502 L
.21943 .86541 L
.22005 .8657 L
.2208 .86589 L
.2216 .86598 L
.22238 .86598 L
.22306 .86591 L
.22366 .86581 L
.22419 .8657 L
.22465 .86561 L
.22505 .86556 L
.22541 .86553 L
.22571 .86548 L
.22597 .8654 L
.22618 .86528 L
.22633 .86516 L
.22648 .86507 L
.22665 .86504 L
.22692 .86509 L
.2273 .86521 L
.22784 .86544 L
.22852 .86579 L
.22936 .86629 L
.23034 .86695 L
.23146 .86776 L
.23281 .86869 L
.2344 .86981 L
.23623 .87104 L
.23839 .87239 L
.24089 .87402 L
.24383 .87568 L
.24728 .87748 L
.25107 .87952 L
.25533 .8815 L
.26002 .88369 L
.2654 .88612 L
.27061 .88834 L
.27624 .89084 L
.28224 .8933 L
.28794 .89581 L
.29402 .89825 L
Mistroke
.30075 .90081 L
.30611 .90305 L
.31187 .90557 L
.31777 .90791 L
.32352 .91019 L
.32945 .91272 L
.33519 .91483 L
.34075 .91711 L
.34644 .91938 L
.35207 .92166 L
.35806 .92386 L
.36382 .92627 L
.36967 .92833 L
.37557 .93056 L
.38175 .9329 L
.38769 .93497 L
.39373 .93719 L
.39971 .93909 L
.40537 .94097 L
.41149 .94276 L
.41694 .94429 L
.42264 .94567 L
.42841 .94688 L
.43399 .94784 L
.43946 .94864 L
.44487 .94921 L
.45036 .94958 L
.45551 .94973 L
.46076 .94967 L
.46594 .94944 L
.47158 .94907 L
.47659 .94861 L
.48222 .94808 L
.4879 .94751 L
.49442 .94693 L
.50008 .94636 L
.50651 .9458 L
.51319 .94524 L
.52054 .94467 L
.52694 .94412 L
.53398 .94357 L
.54157 .94302 L
.54767 .94245 L
.55444 .94186 L
.56146 .94126 L
.56711 .94064 L
.57293 .94001 L
.57836 .93937 L
.58337 .93874 L
.58809 .9381 L
Mistroke
.59237 .93749 L
.59644 .9369 L
.60012 .93633 L
.60361 .93578 L
.60695 .93526 L
.6102 .9348 L
.61329 .93442 L
.61637 .93411 L
.61949 .93384 L
.62268 .93359 L
.62606 .93333 L
.6296 .93301 L
.63335 .93257 L
.63733 .93198 L
.64171 .93124 L
.64579 .93037 L
.65003 .92938 L
.65442 .92829 L
.65843 .92717 L
.66259 .92597 L
.66646 .92472 L
.66989 .92341 L
.67327 .92204 L
.67631 .92074 L
.67919 .9194 L
.68189 .91805 L
.68448 .91667 L
.68701 .91532 L
.68961 .91388 L
.69226 .91242 L
.69494 .91088 L
.69774 .90923 L
.70071 .90745 L
.7036 .90573 L
.70652 .90391 L
.70951 .90212 L
.71235 .90027 L
.71525 .89842 L
.71815 .89662 L
.72099 .89474 L
.72381 .89284 L
.72664 .89091 L
.72956 .88885 L
.73261 .88671 L
.73589 .88439 L
.73936 .8822 L
.74311 .87973 L
.74705 .87734 L
.75111 .87479 L
.75523 .87224 L
Mistroke
.7594 .86985 L
.76336 .86737 L
.76713 .86503 L
.77076 .86278 L
.77367 .86077 L
.77634 .85888 L
.77867 .85722 L
.78061 .85575 L
.78219 .8544 L
.78353 .8531 L
.78471 .85194 L
.78593 .85075 L
.78734 .84946 L
.78903 .848 L
.79101 .84645 L
.79348 .84468 L
.79606 .84262 L
.79919 .8404 L
.80291 .83798 L
.80663 .83526 L
.8109 .83246 L
.81544 .82944 L
.82035 .82585 L
.82495 .8229 L
.82982 .81985 L
.83442 .81658 L
.83908 .81315 L
.84335 .81007 L
.84761 .80669 L
.85164 .80361 L
.85494 .80041 L
.85863 .79724 L
.86206 .79392 L
.86502 .79055 L
.86774 .78694 L
.87025 .78328 L
.87248 .77955 L
.87453 .7756 L
.87642 .77163 L
.8782 .76751 L
.8799 .76323 L
.88159 .75878 L
.8832 .75444 L
.88476 .74996 L
.88629 .74539 L
.88767 .74108 L
.88901 .73689 L
.89019 .73275 L
.89123 .72926 L
.89209 .72594 L
Mistroke
.89278 .72306 L
.89331 .72055 L
.89371 .71859 L
.89401 .71699 L
.89422 .71582 L
.8944 .71501 L
.89456 .7145 L
.89472 .71425 L
.89488 .71417 L
.89506 .71419 L
.89524 .71421 L
.89543 .71425 L
.89562 .71435 L
.89581 .71448 L
.89596 .71465 L
.89605 .71488 L
.89607 .71521 L
.89603 .71563 L
.89596 .71609 L
.89584 .71657 L
.89569 .71708 L
.89548 .71769 L
.89523 .71838 L
.89495 .71915 L
.89466 .72 L
.89438 .7209 L
.89406 .7219 L
.8937 .72303 L
.89326 .72429 L
.89272 .72573 L
.89207 .72728 L
.89131 .72911 L
.89041 .73128 L
.88938 .73361 L
.88825 .73633 L
.88706 .7393 L
.886 .74173 L
.88484 .74459 L
.88384 .74679 L
.8829 .74891 L
.88205 .75098 L
.88133 .75289 L
.88074 .75448 L
.88029 .7559 L
.87999 .75715 L
.87983 .75821 L
.87979 .75907 L
.87982 .75974 L
.87989 .76027 L
.87996 .7607 L
Mistroke
.88001 .76106 L
.88005 .76136 L
.88009 .76161 L
.88012 .76181 L
.88014 .76194 L
.88014 .76198 L
.88014 .76193 L
.88014 .76181 L
.88013 .76164 L
.88013 .76146 L
.88013 .76131 L
.88013 .76124 L
.88013 .76126 L
.88013 .76131 L
.88013 .76135 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88016 .76134 L
.88021 .76128 L
.88028 .76119 L
.88035 .76107 L
.88042 .76094 L
.88047 .7608 L
.88049 .76071 L
.88046 .76071 L
.88034 .76082 L
.88012 .76112 L
.87974 .76166 L
.87914 .76259 L
.87829 .76395 L
.87723 .76567 L
Mistroke
.87595 .76779 L
.87442 .7704 L
.87277 .77303 L
.87091 .77617 L
.86918 .77919 L
.86742 .78234 L
.86567 .78546 L
.86414 .78807 L
.86265 .79084 L
.86149 .79292 L
.86052 .79473 L
.85976 .79621 L
.85923 .79728 L
.85891 .79794 L
.85878 .79823 L
.85879 .79827 L
.85887 .79817 L
.85898 .79798 L
.8591 .79776 L
.8592 .79756 L
.85927 .79744 L
.8593 .79738 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79736 L
.85932 .79733 L
.85935 .79725 L
.85938 .79714 L
.85941 .79704 L
.85944 .79701 L
.85945 .79708 L
.85943 .79727 L
.85934 .7976 L
.8592 .7981 L
.85901 .7987 L
.85877 .79939 L
.8585 .80008 L
.85821 .80071 L
.85793 .80119 L
.85766 .80154 L
.85741 .80172 L
.85719 .80172 L
.857 .80151 L
.85686 .80103 L
.85676 .80031 L
.85672 .79941 L
.85673 .79837 L
.85679 .79726 L
Mistroke
.85687 .79612 L
.85697 .7951 L
.85706 .79423 L
.85713 .79356 L
.85717 .7931 L
.85719 .79281 L
.85718 .79267 L
.85716 .79269 L
.85714 .79282 L
.85713 .79301 L
.85713 .79321 L
.85713 .79337 L
.85713 .79344 L
.85713 .79337 L
.85713 .79315 L
.85713 .79281 L
.85712 .79231 L
.85711 .79159 L
.85711 .79062 L
.85709 .78947 L
.85708 .78811 L
.85706 .78662 L
.85704 .78497 L
.85703 .78328 L
.85701 .78161 L
.85699 .77996 L
.85697 .7785 L
.85696 .77721 L
.85694 .7761 L
.85694 .77533 L
.85693 .77481 L
.85693 .77453 L
.85693 .77451 L
.85693 .77471 L
.85694 .77513 L
.85695 .77573 L
.85695 .77634 L
.85696 .77697 L
.85697 .77758 L
.85698 .77816 L
.85698 .77864 L
.85698 .77901 L
.85699 .77927 L
.85699 .77945 L
.85699 .77957 L
.85699 .77961 L
.85699 .77958 L
.85699 .77952 L
.85699 .77944 L
.85699 .77938 L
Mistroke
.85699 .77935 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77935 L
.85699 .77937 L
.85699 .77943 L
.85699 .7795 L
.85699 .77957 L
.85701 .77964 L
.85705 .77969 L
.85711 .77971 L
.85717 .77967 L
.85723 .77954 L
.85728 .77928 L
.8573 .77886 L
.85726 .77827 L
Mistroke
.85714 .77747 L
.85693 .77651 L
.8566 .77536 L
.85615 .77399 L
.85551 .77238 L
.85468 .77065 L
.85359 .76869 L
.85238 .7665 L
.85097 .76434 L
.84939 .76202 L
.84793 .75978 L
.84649 .75757 L
.84502 .75544 L
.84371 .75354 L
.84244 .75174 L
.84149 .75031 L
.84064 .74914 L
.84003 .74828 L
.83956 .74765 L
.83921 .74724 L
.83901 .74702 L
.83894 .7469 L
.83892 .74677 L
.83888 .74648 L
.83879 .74592 L
.83865 .74498 L
.83846 .74359 L
.83818 .74171 L
.83786 .7397 L
.83752 .73722 L
.83723 .73402 L
.83704 .73051 L
.83698 .7272 L
.8371 .72314 L
.83744 .71891 L
.83805 .7139 L
.8389 .7097 L
.84005 .70502 L
.84148 .70025 L
.84315 .69568 L
.84505 .69094 L
.84714 .68684 L
.84957 .68261 L
.85178 .67836 L
.85421 .67464 L
.85716 .6709 L
.85956 .66767 L
.86225 .66441 L
.86499 .66152 L
.86803 .65874 L
Mistroke
.87102 .65631 L
.87359 .65391 L
.87666 .65165 L
.87968 .64944 L
.88266 .64733 L
.88608 .64532 L
.88908 .64348 L
.89235 .64175 L
.89542 .64018 L
.89864 .6388 L
.90147 .63759 L
.90422 .63653 L
.90693 .6356 L
.90926 .63473 L
.9113 .6339 L
.91316 .63309 L
.91476 .63227 L
.9161 .63148 L
.91715 .63066 L
.91796 .62984 L
.91855 .62903 L
.91895 .62825 L
.9192 .62752 L
.91934 .62689 L
.91939 .62636 L
.9194 .62597 L
.91938 .62572 L
.91935 .62556 L
.91932 .62548 L
.91933 .62543 L
.91939 .62536 L
.91951 .62524 L
.91972 .62502 L
.92007 .62467 L
.92053 .62416 L
.92103 .62352 L
.92153 .62281 L
.92199 .62214 L
.92237 .62153 L
.92261 .62103 L
.92269 .62069 L
.92263 .62054 L
.92245 .62057 L
.9222 .62078 L
.9219 .62114 L
.92158 .62162 L
.92122 .62223 L
.92079 .6229 L
.92032 .62359 L
.91985 .62426 L
Mistroke
.91945 .62483 L
.91918 .62528 L
.91902 .6256 L
.91896 .62578 L
.91896 .62584 L
.91901 .62584 L
.91904 .62582 L
.91902 .62583 L
.91896 .62591 L
.91889 .62605 L
.91886 .6262 L
.91889 .62626 L
.91902 .62618 L
.91925 .62591 L
.91961 .62537 L
.9201 .62452 L
.92076 .6233 L
.92155 .62171 L
.92253 .61963 L
.92369 .61695 L
.92502 .614 L
.92652 .61039 L
.92813 .60609 L
.92983 .60166 L
.93151 .59662 L
.93317 .59092 L
.93479 .58523 L
.93621 .57984 L
.93754 .57387 L
.93869 .56775 L
.93964 .56267 L
.94041 .55752 L
.94095 .55294 L
.94129 .54869 L
.94144 .54571 L
.94142 .54315 L
.94126 .54115 L
.94102 .53985 L
.94073 .53908 L
.94043 .5388 L
.94015 .53893 L
.93989 .53937 L
.93967 .54 L
.93949 .5407 L
.93937 .54139 L
.93929 .54196 L
.93925 .54231 L
.93923 .54247 L
.93925 .5425 L
.93928 .54244 L
Mistroke
.93931 .54234 L
.93933 .54226 L
.93934 .54223 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93934 .54224 L
.93933 .5423 L
.93931 .54241 L
.93929 .54256 L
.93926 .54272 L
.93925 .54282 L
.93926 .54281 L
.9393 .54263 L
.93937 .54226 L
.93947 .54169 L
.9396 .54092 L
.93975 .53994 L
.93991 .53876 L
.94008 .53748 L
.94025 .53608 L
.94041 .53451 L
.94056 .53296 L
.9407 .53137 L
.94081 .52987 L
.9409 .52848 L
.94095 .52727 L
.94098 .5263 L
.94098 .52559 L
.94098 .52514 L
.94097 .52494 L
.94097 .5249 L
.94096 .52496 L
.94094 .52506 L
.9409 .52515 L
.94083 .52518 L
.94071 .52507 L
.94056 .52477 L
.94039 .52419 L
.94019 .52316 L
.93996 .52158 L
.9397 .51955 L
.93939 .51692 L
.93903 .51374 L
Mistroke
.93864 .50982 L
.93821 .50572 L
.93777 .50089 L
.93732 .49554 L
.93688 .49007 L
.93648 .48428 L
.9361 .47766 L
.93574 .4713 L
.93536 .46534 L
.93497 .45875 L
.93456 .4519 L
.93415 .44515 L
.93375 .43869 L
.93335 .43194 L
.93294 .42535 L
.93252 .41872 L
.93209 .4125 L
.93163 .40571 L
.93115 .39978 L
.93061 .39381 L
.93004 .38805 L
.92944 .3824 L
.92884 .37715 L
.92827 .37203 L
.92773 .36724 L
.92722 .36281 L
.92673 .35882 L
.92628 .35507 L
.92583 .35177 L
.92539 .34877 L
.92494 .34599 L
.92448 .34329 L
.92403 .341 L
.92357 .33877 L
.9231 .33656 L
.92264 .33442 L
.92213 .33224 L
.92159 .32999 L
.921 .32797 L
.9204 .32573 L
.91977 .32343 L
.91911 .32123 L
.91845 .31906 L
.91786 .3171 L
.91732 .31544 L
.91683 .31411 L
.9164 .31313 L
.91605 .31252 L
.91575 .3122 L
.91551 .31214 L
Mistroke
.91533 .31229 L
.91522 .31261 L
.91518 .31302 L
.91521 .31353 L
.91529 .31409 L
.9154 .31466 L
.91551 .31515 L
.9156 .3155 L
.91564 .31565 L
.9156 .31556 L
.91546 .31517 L
.91517 .31445 L
.91472 .3134 L
.91407 .31204 L
.9133 .31045 L
.91232 .30853 L
.91109 .30631 L
.90992 .30408 L
.90864 .30166 L
.90705 .29911 L
.90579 .29671 L
.90441 .29429 L
.90292 .29209 L
.90179 .29017 L
.90073 .28852 L
.89979 .28719 L
.89905 .2862 L
.89848 .28546 L
.89806 .28494 L
.89779 .28461 L
.89764 .28442 L
.89757 .28435 L
.89758 .28439 L
.89767 .28455 L
.89783 .28483 L
.89806 .2852 L
.89834 .28565 L
.89866 .28614 L
.89903 .28662 L
.8994 .28707 L
.89978 .28748 L
.90016 .28785 L
.90056 .28819 L
.90096 .28848 L
.90136 .28874 L
.90174 .28898 L
.90209 .28921 L
.90242 .28947 L
.90273 .2898 L
.90303 .29021 L
Mistroke
.90331 .29071 L
.90359 .29128 L
.90387 .29194 L
.90413 .29264 L
.90437 .29334 L
.90458 .29399 L
.90475 .29457 L
.90488 .29506 L
.90494 .29542 L
.90494 .29564 L
.90488 .29575 L
.90477 .29574 L
.90465 .29565 L
.90454 .29554 L
.90447 .29547 L
.90445 .29549 L
.90449 .29563 L
.9046 .29593 L
.9048 .29644 L
.9051 .2972 L
.90552 .29823 L
.90607 .29954 L
.90675 .30115 L
.90756 .303 L
.90846 .30503 L
.90947 .30717 L
.91058 .30942 L
.91169 .31146 L
.91283 .31353 L
.91395 .31531 L
.91501 .31705 L
.91602 .31845 L
.91691 .31962 L
.9177 .32051 L
.91839 .3211 L
.91894 .32143 L
.91938 .32158 L
.91969 .32165 L
.91989 .32169 L
.91998 .32174 L
.91999 .32186 L
.91993 .32207 L
.91982 .32234 L
.91969 .3226 L
.91954 .3228 L
.91941 .32289 L
.91929 .32287 L
.9192 .32273 L
.91914 .32248 L
.9191 .32213 L
Mistroke
.91907 .32162 L
.91905 .32098 L
.91904 .32023 L
.91906 .31939 L
.9191 .31854 L
.91916 .31771 L
.91924 .31695 L
.91933 .3163 L
.91941 .3158 L
.91947 .31544 L
.91952 .31517 L
.91955 .315 L
.91958 .31494 L
.91966 .31497 L
.91978 .31507 L
.9199 .3152 L
.91995 .31529 L
.91991 .31528 L
.91974 .31514 L
.9194 .31484 L
.91887 .31433 L
.91813 .31358 L
.91715 .31255 L
.91596 .31119 L
.91482 .30968 L
.91318 .30781 L
.91165 .30554 L
.90992 .30318 L
.90788 .3004 L
.90567 .29725 L
.9033 .29387 L
.90086 .29023 L
.89826 .28627 L
.89549 .28206 L
.89237 .27748 L
.88946 .27241 L
.88635 .26808 L
.88291 .26268 L
.87955 .25771 L
.87595 .25211 L
.87228 .24657 L
.86884 .24162 L
.86533 .23627 L
.86166 .2307 L
.85838 .22574 L
.85503 .22025 L
.852 .21583 L
.84905 .21111 L
.84628 .20672 L
.84395 .20323 L
Mistroke
.84176 .19979 L
.83987 .1967 L
.83822 .19406 L
.83702 .19206 L
.8361 .19049 L
.83542 .18936 L
.83497 .1886 L
.83471 .18817 L
.83458 .18796 L
.83452 .18785 L
.83444 .18775 L
.83431 .18756 L
.8341 .18728 L
.83381 .18691 L
.8334 .18645 L
.83282 .18588 L
.83208 .18519 L
.83118 .18437 L
.83004 .18335 L
.82874 .18225 L
.82712 .18088 L
.82515 .1792 L
.82293 .17721 L
.82094 .17503 L
.81864 .17269 L
.81594 .16986 L
.81371 .16709 L
.81105 .1642 L
.80854 .1611 L
.80616 .15829 L
.8038 .1551 L
.80203 .15257 L
.80049 .15041 L
.79921 .14848 L
.79827 .14683 L
.79768 .14561 L
.79737 .14487 L
.79727 .14451 L
.79731 .14443 L
.79744 .14451 L
.79761 .1447 L
.7978 .14495 L
.79794 .1452 L
.79801 .14534 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
Mistroke
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14539 L
.79802 .14544 L
.79803 .14552 L
.79807 .1456 L
.79815 .14568 L
.79826 .14573 L
.79837 .14571 L
.79846 .14559 L
.79851 .14535 L
.79846 .14496 L
.79829 .14444 L
.79795 .14378 L
.79743 .143 L
.79671 .14218 L
.7958 .14125 L
.7947 .14025 L
.7935 .13921 L
.79213 .13818 L
.79059 .13713 L
.78892 .13606 L
.78722 .13502 L
.78539 .13402 L
.78365 .13308 L
.78187 .13221 L
.78012 .13142 L
.77845 .13064 L
.77679 .12985 L
.77523 .12903 L
.77364 .12817 L
.77206 .12728 L
.77039 .12636 L
.76864 .12542 L
.76691 .12446 L
.76498 .12348 L
.76288 .12249 L
Mistroke
.76054 .12138 L
.75804 .12021 L
.75508 .11889 L
.75221 .11744 L
.74887 .11592 L
.74534 .11429 L
.74161 .11256 L
.7379 .11084 L
.734 .10914 L
.73053 .1075 L
.72698 .10591 L
.72393 .10449 L
.72097 .10315 L
.71862 .10194 L
.71652 .10093 L
.71501 .10015 L
.71388 .09956 L
.71307 .09913 L
.71256 .09883 L
.71229 .09862 L
.71219 .09848 L
.71217 .09837 L
.7122 .09829 L
.71226 .09821 L
.7123 .09813 L
.71231 .09805 L
.71228 .09799 L
.71223 .09795 L
.71218 .09795 L
.71216 .09804 L
.7122 .09822 L
.71232 .09851 L
.71252 .09888 L
.7128 .0993 L
.71311 .09976 L
.71343 .10024 L
.71375 .10075 L
.7141 .10125 L
.7145 .10178 L
.71501 .10234 L
.7157 .10294 L
.71658 .10361 L
.71772 .10436 L
.71913 .10519 L
.72082 .10611 L
.72259 .10699 L
.72465 .10795 L
.72646 .10894 L
.72866 .10995 L
.73106 .11094 L
Mistroke
.7332 .11189 L
.7355 .11274 L
.73773 .11344 L
.73978 .114 L
.74162 .11441 L
.74324 .11466 L
.74457 .11478 L
.74571 .1148 L
.74672 .11473 L
.74763 .11462 L
.74845 .11449 L
.74917 .11439 L
.74975 .11432 L
.75019 .11432 L
.75049 .1144 L
.75065 .11456 L
.75073 .11482 L
.7508 .11517 L
.75093 .11563 L
.7512 .11624 L
.75165 .11701 L
.75228 .11793 L
.75314 .11905 L
.75415 .12033 L
.75537 .12173 L
.75684 .12322 L
.7584 .12487 L
.76006 .12656 L
.76193 .12834 L
.76366 .13013 L
.76547 .13201 L
.76714 .13378 L
.76866 .13556 L
.76992 .13723 L
.77092 .13878 L
.77164 .14005 L
.77217 .14129 L
.77258 .1423 L
.77294 .14324 L
.77333 .14413 L
.7738 .145 L
.77441 .1459 L
.77518 .14687 L
.77613 .14795 L
.7773 .1492 L
.77861 .15063 L
.78013 .15208 L
.78193 .1539 L
.78394 .15589 L
.78619 .15818 L
Mistroke
.78862 .16069 L
.79122 .16326 L
.79383 .16588 L
.79656 .16852 L
.79925 .17124 L
.80201 .17387 L
.80479 .17656 L
.80769 .17926 L
.8106 .18206 L
.81364 .18475 L
.81656 .18764 L
.81945 .1901 L
.82231 .19268 L
.82495 .19489 L
.8274 .19718 L
.82963 .19906 L
.83152 .20074 L
.83318 .20223 L
.83449 .2034 L
.83543 .20438 L
.83596 .20521 L
.83607 .2059 L
.83578 .20652 L
.83514 .20714 L
.83422 .20788 L
.83304 .20878 L
.83164 .20995 L
.83004 .2114 L
.82823 .21312 L
.82622 .21493 L
.82399 .21712 L
.82159 .21936 L
.81882 .22187 L
.81586 .22452 L
.8126 .22723 L
.8092 .23008 L
.80549 .23309 L
.80194 .23612 L
.79797 .23954 L
.7944 .24273 L
.79037 .24628 L
.78677 .24994 L
.78318 .25352 L
.77941 .25751 L
.77578 .26099 L
.77239 .2645 L
.76889 .26794 L
.76539 .27135 L
.7618 .27454 L
.75795 .27727 L
Mistroke
.75424 .27988 L
.75015 .28225 L
.74595 .28431 L
.74138 .28614 L
.73685 .28767 L
.73173 .28883 L
.72745 .2897 L
.72258 .29027 L
.71801 .29052 L
.71389 .29046 L
.70982 .29008 L
.70591 .28939 L
.7022 .28835 L
.69887 .287 L
.69581 .28531 L
.69307 .28329 L
.6907 .28097 L
.68863 .27836 L
.68691 .27519 L
.68549 .27216 L
.68436 .26858 L
.68355 .2644 L
.68298 .26021 L
.68268 .25587 L
.68264 .25118 L
.68284 .24612 L
.68327 .24108 L
.68395 .2354 L
.68484 .23009 L
.68593 .22449 L
.68722 .21855 L
.68873 .21307 L
.69045 .20747 L
.6924 .20202 L
.69461 .19638 L
.6971 .19102 L
.69989 .18597 L
.70288 .18106 L
.70614 .17639 L
.70961 .17212 L
.71323 .16834 L
.71692 .16451 L
.7207 .16099 L
.72449 .15796 L
.72814 .15499 L
.73164 .1524 L
.73496 .14999 L
.73791 .14772 L
.74058 .1458 L
.74288 .14399 L
Mistroke
.74483 .14227 L
.74628 .14077 L
.74733 .1393 L
.74798 .13807 L
.74824 .13691 L
.74816 .13581 L
.74778 .13476 L
.74719 .13368 L
.74647 .13255 L
.74566 .13131 L
.7447 .13001 L
.74361 .12845 L
.74233 .12662 L
.74079 .12472 L
.73888 .12233 L
.73657 .12006 L
.73376 .11748 L
.73068 .11479 L
.72713 .11225 L
.72312 .10953 L
.71958 .10709 L
.71539 .10462 L
.71125 .10217 L
.70727 .10005 L
.70286 .09796 L
.69881 .09606 L
.69519 .09426 L
.69167 .09271 L
.68835 .09125 L
.68534 .08989 L
.68233 .08865 L
.67937 .08742 L
.67621 .08617 L
.67292 .08489 L
.66919 .0835 L
.66547 .082 L
.66143 .08054 L
.65696 .07893 L
.65281 .07729 L
.6482 .07554 L
.64351 .07375 L
.63932 .07184 L
.63489 .06998 L
.63057 .06814 L
.62648 .0664 L
.62252 .06483 L
.61908 .06334 L
.61582 .06198 L
.61293 .06071 L
.6102 .05953 L
Mistroke
.60766 .05845 L
.60519 .05744 L
.60282 .05653 L
.60052 .05573 L
.59842 .05504 L
.59639 .05445 L
.59444 .05392 L
.59246 .05347 L
.5905 .05307 L
.58845 .05275 L
.58624 .0525 L
.58413 .05232 L
.58185 .05219 L
.57939 .05212 L
.57673 .05211 L
.57409 .05214 L
.57125 .05217 L
.56823 .05217 L
.5651 .0521 L
.562 .05198 L
.55888 .05179 L
.55615 .05156 L
.55328 .05128 L
.55097 .05099 L
.54886 .05069 L
.54699 .05043 L
.5454 .05021 L
.54409 .05003 L
.5429 .04991 L
.54172 .04984 L
.54038 .04983 L
.5388 .04986 L
.53687 .04994 L
.53474 .05005 L
.53208 .05019 L
.52876 .05034 L
.52522 .05048 L
.52118 .05059 L
.5166 .05064 L
.51217 .05062 L
.50733 .05054 L
.50221 .05041 L
.49721 .05025 L
.49226 .05007 L
.4872 .04988 L
.48216 .04969 L
.47693 .04953 L
.47232 .04937 L
.46714 .04923 L
.46278 .04908 L
Mistroke
.45803 .04893 L
.45344 .04878 L
.44874 .04863 L
.44398 .04848 L
.43965 .04833 L
.43509 .04818 L
.43106 .04804 L
.42697 .04791 L
.4236 .04779 L
.42027 .04768 L
.41757 .04758 L
.41511 .04749 L
.41294 .04742 L
.41121 .04735 L
.40975 .04728 L
.40852 .04718 L
.40753 .04707 L
.40674 .04697 L
.40607 .04689 L
.40544 .04683 L
.40475 .04683 L
.40393 .04689 L
.4029 .04702 L
.40163 .04722 L
.40008 .04752 L
.39823 .04794 L
.39611 .04851 L
.39375 .04924 L
.39117 .05012 L
.38839 .05117 L
.38577 .05241 L
.38264 .05376 L
.37971 .05521 L
.37649 .05681 L
.37305 .05841 L
.36942 .06011 L
.36564 .06206 L
.36187 .06383 L
.35766 .06577 L
.3536 .06789 L
.34912 .07022 L
.34471 .07246 L
.33983 .0749 L
.33522 .07734 L
.32999 .08009 L
.32526 .08249 L
.3203 .08527 L
.31512 .08798 L
.31028 .09087 L
.30478 .09401 L
Mistroke
.30016 .09664 L
.29512 .09955 L
.29006 .1023 L
.28566 .10505 L
.2811 .1077 L
.27657 .11022 L
.27273 .11247 L
.26875 .11454 L
.26509 .11658 L
.26194 .1183 L
.25882 .11999 L
.25576 .12163 L
.25295 .12307 L
.25018 .12451 L
.24739 .126 L
.24482 .12747 L
.24192 .12908 L
.23887 .13074 L
.2361 .13228 L
.23324 .13383 L
.23015 .13552 L
.22705 .13726 L
.2242 .13909 L
.22161 .14074 L
.21916 .14239 L
.21697 .14398 L
.21509 .14541 L
.21347 .14676 L
.21209 .14795 L
.21093 .14895 L
.21 .14974 L
.20917 .15034 L
.20847 .15077 L
.20787 .151 L
.20735 .15107 L
.20691 .15098 L
.20658 .15072 L
.20635 .15033 L
.2062 .14981 L
.20611 .1492 L
.2061 .14853 L
.20615 .14785 L
.20624 .14724 L
.20639 .14677 L
.20658 .14641 L
.20684 .14616 L
.20716 .14601 L
.20754 .14593 L
.20798 .14589 L
.20847 .14582 L
Mistroke
.20898 .14572 L
.20954 .14559 L
.21012 .14543 L
.21072 .14527 L
.21133 .14506 L
.21195 .14479 L
.21254 .14445 L
.21314 .14415 L
.21371 .14382 L
.21428 .1435 L
.21488 .14319 L
.21552 .14292 L
.21619 .14272 L
.21693 .14257 L
.21771 .14242 L
.21847 .14224 L
.21919 .14203 L
.21985 .14175 L
.22043 .14142 L
.22093 .14103 L
.22135 .1406 L
.2217 .14011 L
.22196 .1396 L
.22215 .13908 L
.22226 .13855 L
.22232 .138 L
.22234 .13742 L
.22233 .13684 L
.22232 .1363 L
.22233 .13582 L
.22236 .13543 L
.22241 .13511 L
.22242 .13489 L
.22237 .13476 L
.22224 .13469 L
.22204 .13469 L
.22175 .13474 L
.22141 .13485 L
.22104 .13502 L
.22067 .13523 L
.22034 .13545 L
.22007 .13565 L
.21991 .13584 L
.21972 .13605 L
.21946 .13628 L
.21918 .13655 L
.21889 .13686 L
.21862 .13719 L
.21836 .13752 L
.21812 .13786 L
Mistroke
.2179 .1382 L
.21768 .13855 L
.21742 .1389 L
.21712 .13928 L
.21671 .13971 L
.21624 .14021 L
.21567 .14083 L
.21504 .14159 L
.21445 .14252 L
.21383 .14362 L
.21321 .14489 L
.21245 .14637 L
.21157 .14806 L
.21053 .15 L
.20931 .15196 L
.20781 .15433 L
.20612 .15679 L
.2042 .15967 L
.2023 .16238 L
.20021 .16534 L
.19806 .16834 L
.19569 .17148 L
.19344 .17444 L
.19119 .17753 L
.18879 .18046 L
.18645 .18351 L
.18415 .1866 L
.182 .18946 L
.1797 .19253 L
.17735 .19568 L
.17507 .19878 L
.17272 .20194 L
.17025 .20524 L
.16786 .20856 L
.16521 .21217 L
.16246 .2159 L
.15963 .21986 L
.15649 .22406 L
.15345 .22851 L
.1502 .23283 L
.14677 .23756 L
.1439 .2416 L
.14081 .2461 L
.13805 .25008 L
.1352 .25434 L
.13274 .25777 L
.13018 .26145 L
.12807 .26469 L
.12599 .26803 L
.12392 .27136 L
Mistroke
.12205 .27417 L
.12014 .2771 L
.11817 .28024 L
.11624 .28342 L
.1144 .28626 L
.11244 .28934 L
.11036 .29269 L
.1084 .29563 L
.10646 .29875 L
.10432 .30214 L
.1026 .30507 L
.10094 .30841 L
.09933 .31154 L
.09778 .31504 L
.09633 .31887 L
.09509 .32214 L
.09392 .32592 L
.09281 .33029 L
.09179 .33397 L
.09085 .3385 L
.08994 .34296 L
.08902 .34716 L
.08808 .35234 L
.08717 .35696 L
.08628 .36192 L
.08543 .36662 L
.08463 .37162 L
.08386 .37586 L
.08312 .38042 L
.08244 .38416 L
.08185 .38783 L
.08135 .39112 L
.08092 .39372 L
.08056 .39609 L
.08027 .39778 L
.08007 .39911 L
.07994 .40006 L
.0799 .40068 L
.07995 .40105 L
.08009 .40124 L
.08032 .4013 L
.0806 .40131 L
.08091 .40132 L
.08123 .40138 L
.08152 .4015 L
.08181 .40168 L
.08207 .40189 L
.08232 .4021 L
.08253 .40229 L
.08271 .40244 L
Mistroke
.08283 .40255 L
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08287 .40258 L
.08283 .40256 L
.08281 .40253 L
.08279 .40252 L
.08277 .4025 L
.08275 .40247 L
.08272 .40244 L
.08269 .4024 L
.08266 .40236 L
.08263 .40233 L
.08261 .40231 L
.0826 .40229 L
.08259 .40228 L
.08259 .40228 L
.08259 .40227 L
.08259 .40228 L
.08261 .4023 L
.08263 .40232 L
.08265 .40236 L
.08268 .40239 L
.08272 .40243 L
.08275 .40247 L
.08277 .4025 L
.08278 .40251 L
.08279 .40252 L
.08278 .40251 L
.08277 .4025 L
.08276 .40249 L
.08276 .40248 L
.08274 .40248 L
.08271 .40248 L
.08266 .40248 L
.08262 .40248 L
.0826 .40248 L
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08316 .40248 L
.0834 .40248 L
.0837 .40248 L
.08405 .40247 L
.08445 .40247 L
.08485 .40247 L
.08518 .40247 L
.08541 .40246 L
Mistroke
.08548 .40246 L
.08535 .40247 L
.08498 .40247 L
.08441 .40247 L
.08372 .40248 L
.08297 .40248 L
.08222 .40249 L
.08152 .40249 L
.08088 .4025 L
.08028 .4025 L
.07973 .40251 L
.07927 .40251 L
.07895 .40248 L
.07892 .40242 L
.07915 .40233 L
.07961 .40224 L
.08026 .40215 L
.08109 .4021 L
.08201 .40214 L
.08299 .4023 L
.08401 .40258 L
.08502 .403 L
.08608 .40355 L
.08716 .40423 L
.08824 .40503 L
.08935 .40585 L
.0904 .40672 L
.0914 .40763 L
.09231 .40859 L
.09309 .4095 L
.09375 .41044 L
.09425 .41139 L
.09458 .41236 L
.09472 .41347 L
.09471 .41472 L
.09455 .41616 L
.09427 .41784 L
.09389 .4196 L
.09342 .42177 L
.09289 .42391 L
.09231 .42634 L
.09173 .42861 L
.09118 .43091 L
.09068 .43344 L
.09024 .4354 L
.0899 .4372 L
.08967 .43886 L
.08954 .44028 L
.08949 .44139 L
.08951 .44216 L
Mistroke
.08959 .44267 L
.0897 .443 L
.08982 .4432 L
.08989 .44329 L
.08989 .44331 L
.08978 .44329 L
.08957 .44325 L
.08925 .44318 L
.08884 .44304 L
.08836 .44284 L
.08783 .44259 L
.08728 .44231 L
.08674 .44203 L
.0862 .44175 L
.0857 .44148 L
.08525 .44124 L
.08489 .44101 L
.08462 .44084 L
.08442 .44074 L
.08427 .44073 L
.08413 .4408 L
.08395 .44093 L
.08371 .44109 L
.08338 .44126 L
.08295 .4414 L
.08244 .44151 L
.08187 .44158 L
.08132 .44162 L
.08078 .44165 L
.08025 .44165 L
.07974 .44163 L
.07929 .44158 L
.07895 .4415 L
.07877 .4414 L
.07873 .44128 L
.07877 .44115 L
.07887 .44103 L
.07897 .44092 L
.07902 .44083 L
.07896 .44078 L
.07876 .44077 L
.07839 .44079 L
.07787 .44084 L
.07719 .44091 L
.0763 .44103 L
.07529 .44118 L
.07418 .44138 L
.07297 .44161 L
.07169 .44187 L
.0704 .44213 L
Mistroke
.06921 .4424 L
.06818 .44267 L
.06723 .44292 L
.06638 .44316 L
.06568 .44336 L
.06516 .44352 L
.06484 .44363 L
.06468 .4437 L
.06463 .44372 L
.06466 .4437 L
.06476 .44366 L
.06491 .44363 L
.06501 .44363 L
.06505 .44365 L
.06505 .44369 L
.06505 .4437 L
.06505 .44369 L
.06506 .44364 L
.06506 .44354 L
.06506 .4434 L
.06507 .44322 L
.06508 .443 L
.06509 .44276 L
.06509 .44251 L
.0651 .44226 L
.06511 .44201 L
.06512 .44177 L
.06513 .44154 L
.06513 .44135 L
.06514 .44119 L
.06514 .44108 L
.06514 .44102 L
.06514 .441 L
.06514 .44102 L
.06514 .44106 L
.06514 .4411 L
.06514 .44113 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06515 .44115 L
.06518 .44115 L
.06522 .44115 L
.06527 .44115 L
.06529 .44115 L
Mistroke
.06528 .44115 L
.06523 .44115 L
.06513 .44115 L
.06497 .44115 L
.06476 .44116 L
.06451 .44116 L
.06425 .44116 L
.06397 .44117 L
.06366 .44117 L
.06341 .44118 L
.06314 .44118 L
.06288 .44118 L
.06264 .44118 L
.06246 .44117 L
.06234 .44114 L
.06227 .4411 L
.06225 .44107 L
.06226 .44105 L
.0623 .44106 L
.06235 .44111 L
.06239 .44121 L
.0624 .44135 L
.06239 .44153 L
.06238 .44175 L
.06237 .44199 L
.06235 .44226 L
.06231 .44254 L
.06225 .44283 L
.0622 .44311 L
.06217 .44335 L
.06218 .44353 L
.06224 .44364 L
.06235 .44365 L
.06251 .44356 L
.06273 .44339 L
.06298 .44316 L
.06325 .44288 L
.06355 .44259 L
.06384 .4423 L
.06415 .44205 L
.06446 .44185 L
.06477 .4417 L
.06503 .44158 L
.06523 .44146 L
.06534 .44134 L
.06536 .44119 L
.06528 .44103 L
.06511 .44083 L
.06487 .4406 L
.06459 .44032 L
Mistroke
.0643 .43998 L
.06401 .43956 L
.06374 .43904 L
.06347 .43842 L
.06322 .43769 L
.063 .43685 L
.06281 .43589 L
.06267 .43483 L
.06258 .43368 L
.06255 .43253 L
.06257 .4313 L
.06263 .42998 L
.06271 .42861 L
.06281 .4272 L
.06289 .42568 L
.06296 .42415 L
.06301 .42261 L
.06306 .42118 L
.0631 .41986 L
.06314 .41863 L
.06318 .41753 L
.06321 .4166 L
.06323 .41585 L
.06325 .41529 L
.06326 .41492 L
.06326 .41478 L
.06326 .41485 L
.06325 .41511 L
.06324 .4155 L
.06321 .41596 L
.06316 .41641 L
.0631 .41683 L
.06305 .41718 L
.06302 .41742 L
.06303 .41754 L
.06309 .41753 L
.06321 .41737 L
.06338 .41708 L
.0636 .41667 L
.06386 .41613 L
.06415 .41551 L
.06445 .41485 L
.06475 .41422 L
.06505 .41367 L
.06534 .41323 L
.0656 .41288 L
.06583 .41261 L
.06602 .41241 L
.06615 .41226 L
.06622 .41216 L
Mistroke
.06624 .41211 L
.06623 .41208 L
.06619 .41207 L
.06614 .41209 L
.0661 .41213 L
.06608 .41217 L
.06608 .4122 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.0661 .4122 L
.06613 .41217 L
.06618 .41212 L
.06622 .41208 L
.06624 .41204 L
.0662 .41201 L
.06611 .41202 L
.06595 .41208 L
.06574 .41224 L
.06549 .41252 L
.06523 .41292 L
.06497 .41341 L
.06476 .41395 L
.06462 .41453 L
.06456 .415 L
.06457 .41547 L
.06466 .41587 L
.06486 .41617 L
.06512 .41638 L
.06546 .41648 L
.06587 .4165 L
.06634 .41638 L
.06685 .41621 L
Mistroke
.06733 .41594 L
.0678 .41562 L
.06824 .41529 L
.06865 .415 L
.06902 .41478 L
.06939 .4146 L
.06977 .41448 L
.07019 .41445 L
.07063 .41445 L
.07113 .41446 L
.07167 .41443 L
.07228 .41436 L
.07293 .41425 L
.07358 .41409 L
.07422 .41391 L
.07482 .4137 L
.07535 .41348 L
.0758 .41324 L
.07617 .41302 L
.07648 .41282 L
.07673 .41263 L
.07692 .41246 L
.07706 .41233 L
.07713 .41223 L
.07717 .41215 L
.07718 .41207 L
.0772 .41196 L
.07725 .41183 L
.07729 .41172 L
.0773 .41167 L
.07727 .41173 L
.07717 .41189 L
.07699 .41216 L
.0767 .41253 L
.07632 .41301 L
.07588 .41356 L
.07537 .41419 L
.07482 .41489 L
.07421 .41568 L
.0736 .4165 L
.07297 .41734 L
.07233 .41819 L
.07172 .41903 L
.07114 .41983 L
.0706 .42055 L
.0701 .42121 L
.0696 .42187 L
.06908 .42259 L
.06852 .42345 L
.0679 .42446 L
Mistroke
.06721 .42569 L
.06644 .42717 L
.06566 .42883 L
.06496 .43034 L
.06431 .43197 L
.06372 .43361 L
.06319 .4351 L
.06275 .43665 L
.06244 .43791 L
.06227 .43904 L
.06225 .43999 L
.06237 .44073 L
.0626 .44125 L
.06294 .44155 L
.06336 .44168 L
.0638 .44173 L
.06424 .44177 L
.06468 .4418 L
.06513 .44186 L
.0656 .44198 L
.06606 .44218 L
.0665 .44243 L
.06691 .44268 L
.06733 .44292 L
.06775 .44314 L
.06818 .44332 L
.06864 .44347 L
.06912 .44358 L
.06961 .44363 L
.07012 .44364 L
.07062 .44362 L
.07109 .44358 L
.07155 .44353 L
.07197 .44349 L
.07236 .44347 L
.07269 .44346 L
.07297 .44346 L
.07317 .44346 L
.07331 .44345 L
.07338 .44345 L
.07341 .44345 L
.0734 .44345 L
.07341 .44345 L
.07349 .44345 L
.07358 .44345 L
.0736 .44345 L
.07356 .44345 L
.07343 .44345 L
.07316 .44346 L
.0727 .44346 L
Mistroke
.07204 .44347 L
.07125 .44348 L
.07042 .44349 L
.06962 .4435 L
.06888 .44351 L
.06817 .44353 L
.06744 .44354 L
.06667 .44355 L
.06592 .44355 L
.06534 .44353 L
.06501 .44348 L
.06487 .44341 L
.06486 .44334 L
.06491 .4433 L
.06501 .44332 L
.06509 .44341 L
.06503 .44356 L
.06482 .44379 L
.06453 .44408 L
.06418 .44444 L
.06382 .44488 L
.06349 .44541 L
.06324 .44602 L
.06305 .44671 L
.06295 .44744 L
.06295 .44818 L
.06307 .44892 L
.06331 .44958 L
.06371 .45016 L
.06421 .45065 L
.06485 .4511 L
.06559 .45155 L
.06633 .45206 L
.06706 .45268 L
.06771 .45346 L
.06823 .45444 L
.06858 .45564 L
.06876 .457 L
.06877 .45865 L
.06863 .46059 L
.06832 .46295 L
.06788 .46565 L
.06731 .46889 L
.06663 .47223 L
.06586 .47629 L
.06504 .48061 L
.06425 .48486 L
.06349 .49008 L
.06283 .49483 L
.06232 .50016 L
Mistroke
.06196 .50545 L
.06175 .51073 L
.06168 .51612 L
.06174 .52191 L
.06196 .52714 L
.06233 .533 L
.06286 .53799 L
.0635 .54323 L
.06424 .54849 L
.06503 .55361 L
.06578 .55879 L
.06653 .56349 L
.06724 .56893 L
.06789 .5735 L
.06853 .57868 L
.06913 .58337 L
.0698 .58832 L
.07057 .59326 L
.07143 .59806 L
.07238 .60276 L
.07346 .60706 L
.07446 .61123 L
.07553 .6151 L
.07668 .61856 L
.07773 .62172 L
.07895 .62466 L
.07993 .62711 L
.08087 .62941 L
.08172 .63157 L
.08242 .63362 L
.08295 .63554 L
.08326 .63752 L
.08337 .63958 L
.08332 .64175 L
.08319 .64402 L
.08302 .6461 L
.0828 .64835 L
.08259 .65085 L
.08241 .65355 L
.08228 .65613 L
.08217 .65886 L
.0821 .66138 L
.08208 .66389 L
.08212 .66628 L
.08222 .66833 L
.08237 .67026 L
.08256 .6721 L
.08278 .67381 L
.08302 .67541 L
.08326 .67689 L
Mistroke
.0835 .67826 L
.08372 .6796 L
.0839 .68092 L
.08404 .68226 L
.08414 .68361 L
.0842 .68499 L
.08424 .68649 L
.08428 .68809 L
.08433 .68974 L
.0844 .69134 L
.08452 .69278 L
.08469 .69412 L
.08491 .69536 L
.08516 .69648 L
.08541 .69742 L
.08567 .69817 L
.08593 .69873 L
.08617 .69912 L
.08638 .69935 L
.08655 .69943 L
.08668 .69939 L
.08675 .69928 L
.08677 .69918 L
.08676 .69907 L
.08672 .69892 L
.08666 .69873 L
.0866 .69856 L
.08655 .69848 L
.0865 .69853 L
.08648 .69873 L
.08648 .69911 L
.08653 .69969 L
.08662 .70045 L
.08676 .70134 L
.08694 .70231 L
.08715 .70333 L
.08739 .70432 L
.08765 .70528 L
.0879 .70625 L
.08816 .70718 L
.08841 .70797 L
.08865 .70856 L
.08885 .70889 L
.08901 .70902 L
.0891 .70903 L
.08912 .70901 L
.0891 .70901 L
.08906 .70912 L
.08902 .70942 L
.08902 .70992 L
Mistroke
.08907 .71058 L
.08918 .71128 L
.08933 .71197 L
.08951 .71261 L
.08972 .71325 L
.08997 .71393 L
.09025 .71467 L
.09057 .71543 L
.09093 .71619 L
.09131 .71694 L
.0917 .71766 L
.09206 .71831 L
.09237 .71888 L
.09264 .7194 L
.09285 .71991 L
.09304 .72051 L
.09321 .72125 L
.0934 .72211 L
.09365 .72304 L
.09403 .72401 L
.09456 .72501 L
.09524 .72607 L
.09609 .72724 L
.09704 .72847 L
.09822 .72988 L
.09946 .73142 L
.10091 .73307 L
.10233 .73481 L
.10401 .73651 L
.10542 .73809 L
.10698 .73942 L
.10841 .74057 L
.10961 .74146 L
.11061 .74207 L
.11136 .74244 L
.11185 .74262 L
.11214 .74256 L
.1123 .74228 L
.11238 .74173 L
.11242 .74093 L
.11246 .73989 L
.11252 .73865 L
.11257 .73726 L
.11259 .73572 L
.11256 .73402 L
.11247 .73224 L
.11233 .73026 L
.11212 .72813 L
.11184 .72603 L
.11146 .72376 L
Mistroke
.11094 .72137 L
.11023 .71893 L
.10934 .71653 L
.10838 .71401 L
.10738 .71159 L
.1064 .70904 L
.10557 .70647 L
.1049 .70384 L
.10452 .70096 L
.10441 .69796 L
.10456 .6945 L
.10498 .69102 L
.10568 .68699 L
.10659 .68293 L
.10789 .67839 L
.1093 .67358 L
.11095 .66833 L
.11286 .66292 L
.1148 .65829 L
.1168 .653 L
.11876 .64848 L
.12036 .64354 L
.122 .63899 L
.12343 .63498 L
.12477 .63111 L
.12591 .62754 L
.1269 .6244 L
.12761 .62118 L
.12807 .61809 L
.12823 .61482 L
.12811 .6116 L
.12773 .60794 L
.12711 .60417 L
.12628 .60001 L
.1253 .59556 L
.1241 .59129 L
.12274 .58652 L
.12118 .58147 L
.11947 .57637 L
.11763 .57131 L
.11568 .5663 L
.11365 .56113 L
.11161 .55656 L
.10961 .55184 L
.10755 .54742 L
.10555 .54308 L
.10373 .53897 L
.10183 .53484 L
.10001 .53076 L
.09815 .52689 L
Mistroke
.09645 .523 L
.09479 .51933 L
.09319 .51581 L
.09166 .51236 L
.09019 .50937 L
.08892 .50651 L
.08763 .50401 L
.08631 .50183 L
.085 .49991 L
.08381 .49842 L
.08266 .49726 L
.08153 .49646 L
.08043 .49601 L
.07943 .49579 L
.0786 .49571 L
.0779 .4957 L
.07724 .49573 L
.07652 .49579 L
.07576 .49592 L
.07495 .49613 L
.07408 .49646 L
.07312 .49692 L
.07206 .49752 L
.07094 .49829 L
.06985 .49925 L
.06886 .50043 L
.06803 .50184 L
.06708 .50343 L
.06587 .50544 L
.06485 .50743 L
.06393 .50966 L
.06317 .51209 L
.06262 .51461 L
.06226 .5167 L
.06207 .51893 L
.06199 .52089 L
.06202 .52273 L
.06207 .52442 L
.06209 .52578 L
.06209 .52696 L
.06209 .52792 L
.06209 .52858 L
.06207 .52896 L
.06205 .52907 L
.06203 .52898 L
.062 .52877 L
.06198 .52854 L
.06196 .52835 L
.06195 .52827 L
.06197 .52837 L
Mistroke
.06201 .52872 L
.06207 .5294 L
.06217 .53055 L
.06233 .53224 L
.06257 .53438 L
.06291 .53716 L
.06336 .54024 L
.0639 .54404 L
.06453 .5487 L
.06526 .55253 L
.06601 .55706 L
.06679 .5624 L
.06757 .56663 L
.06825 .57218 L
.06889 .57664 L
.06941 .5807 L
.06985 .58495 L
.07023 .58889 L
.07053 .5923 L
.07075 .59532 L
.07091 .59805 L
.07102 .60019 L
.0711 .60216 L
.07118 .6038 L
.07129 .60535 L
.07146 .60673 L
.07169 .60803 L
.072 .60928 L
.07236 .61048 L
.07273 .61167 L
.07311 .61291 L
.07348 .61425 L
.07382 .61577 L
.07414 .61741 L
.07446 .61927 L
.07479 .62156 L
.07514 .62391 L
.07553 .62665 L
.07593 .62976 L
.07635 .63259 L
.07676 .63582 L
.07716 .63919 L
.07755 .64248 L
.07796 .64578 L
.07838 .64921 L
.07881 .65205 L
.07926 .65494 L
.07971 .65769 L
.08012 .65994 L
.08049 .66192 L
Mistroke
.08081 .66354 L
.08109 .66473 L
.08133 .66563 L
.08156 .66629 L
.08175 .66672 L
.08191 .66698 L
.08205 .6671 L
.08215 .66713 L
.08221 .6671 L
.08223 .66703 L
.08221 .66694 L
.08218 .66686 L
.08213 .66677 L
.0821 .66671 L
.08208 .66668 L
.08208 .66667 L
.08209 .66667 L
.08213 .66667 L
.08221 .66666 L
.0823 .66666 L
.08234 .66666 L
.08232 .66666 L
.08221 .66667 L
.08198 .66668 L
.08162 .66666 L
.08116 .66662 L
.08064 .66655 L
.08015 .66648 L
.07971 .66641 L
.07931 .66636 L
.07905 .66636 L
.07878 .66645 L
.07858 .66665 L
.07847 .66699 L
.07851 .6675 L
.07876 .66821 L
.07918 .6691 L
.07981 .67015 L
.08055 .67139 L
.08144 .67282 L
.08245 .67438 L
.08354 .67616 L
.0846 .67797 L
.08576 .67998 L
.08693 .68215 L
.08818 .68443 L
.08943 .68679 L
.09074 .68938 L
.09201 .69192 L
.0933 .69473 L
Mistroke
.09451 .6977 L
.0957 .70082 L
.09675 .70414 L
.09772 .70714 L
.09859 .7104 L
.09933 .71352 L
.09999 .7164 L
.10056 .7192 L
.10103 .72148 L
.10141 .72363 L
.10172 .72525 L
.10197 .7266 L
.10216 .72767 L
.10229 .72845 L
.10237 .72893 L
.10238 .72916 L
.10236 .72921 L
.10231 .72912 L
.10226 .72895 L
.10224 .72873 L
.10227 .7285 L
.10234 .72831 L
.10242 .72819 L
.10246 .72814 L
.10243 .72817 L
.10231 .72828 L
.1021 .72849 L
.10177 .72879 L
.10135 .72919 L
.10086 .72965 L
.10031 .73017 L
.09974 .73071 L
.09919 .73125 L
.09864 .73178 L
.0981 .73231 L
.09758 .73279 L
.09712 .73322 L
.09676 .73355 L
.09651 .73379 L
.09636 .73393 L
.09632 .73397 L
.09635 .73393 L
.09643 .73386 L
.09652 .73377 L
.09658 .7337 L
.09662 .73367 L
.09662 .73366 L
.09662 .73366 L
.0966 .73365 L
.09657 .73362 L
Mistroke
.09652 .73358 L
.09647 .73354 L
.09642 .73353 L
.09639 .73354 L
.09641 .7336 L
.09649 .73369 L
.09665 .73383 L
.09687 .73401 L
.09717 .73422 L
.09753 .73445 L
.09796 .73467 L
.09844 .73485 L
.099 .73501 L
.09962 .73516 L
.10031 .73533 L
.10101 .73553 L
.10176 .73577 L
.10253 .73606 L
.10332 .73639 L
.10408 .73676 L
.10484 .73716 L
.10558 .73758 L
.10628 .73803 L
.10695 .73848 L
.10759 .73895 L
.10819 .73942 L
.10871 .73986 L
.10916 .74025 L
.10953 .74056 L
.1098 .74077 L
.11 .74089 L
.11015 .74092 L
.11032 .74088 L
.11046 .7408 L
.11051 .74072 L
.11045 .74066 L
.11028 .74064 L
.10998 .74065 L
.10953 .74067 L
.1089 .74069 L
.10814 .74073 L
.10734 .74079 L
.10659 .74088 L
.10589 .74099 L
.1052 .7411 L
.10447 .74116 L
.10368 .74117 L
.1029 .74109 L
.10221 .74092 L
.10165 .74064 L
Mistroke
.1012 .74028 L
.10081 .73985 L
.10051 .73937 L
.10032 .73886 L
.10021 .73835 L
.10003 .73784 L
.09986 .73735 L
.09976 .73688 L
.09974 .73648 L
.09979 .73615 L
.09992 .73592 L
.10012 .73578 L
.10041 .73573 L
.10078 .73575 L
.1012 .7358 L
.10166 .73587 L
.10212 .73591 L
.10256 .73593 L
.10296 .73592 L
.10332 .7359 L
.10363 .73589 L
.1039 .73588 L
.10413 .73587 L
.10434 .73586 L
.10453 .73587 L
.10472 .7359 L
.10489 .73596 L
.10501 .73604 L
.10508 .73613 L
.10508 .73619 L
.105 .73617 L
.10483 .73606 L
.10459 .73582 L
.10427 .73546 L
.10388 .73497 L
.10343 .73437 L
.10292 .73369 L
.10242 .733 L
.10188 .73225 L
.10134 .73149 L
.10088 .73077 L
.1005 .73009 L
.10019 .72947 L
.09991 .72897 L
.09967 .72864 L
.09946 .72846 L
.09926 .72841 L
.09904 .72843 L
.09878 .72848 L
.09845 .72849 L
Mistroke
.09804 .72844 L
.09754 .72829 L
.09692 .72801 L
.09626 .72764 L
.09551 .7272 L
.09467 .72671 L
.09376 .72622 L
.0928 .72576 L
.09183 .72536 L
.09098 .72502 L
.09009 .72484 L
.08928 .72479 L
.08852 .72491 L
.08784 .7252 L
.08725 .72567 L
.08679 .72622 L
.08646 .72684 L
.08627 .72739 L
.08618 .72789 L
.08619 .72826 L
.08628 .72847 L
.08643 .72851 L
.08663 .72836 L
.08684 .72805 L
.08709 .72762 L
.08735 .72711 L
.08761 .72656 L
.08782 .72597 L
.08799 .72539 L
.08808 .72486 L
.08812 .72442 L
.08812 .72406 L
.08812 .72377 L
.08816 .72356 L
.08828 .72344 L
.08851 .72343 L
.08885 .72352 L
.08929 .7237 L
.08984 .72395 L
.09048 .72426 L
.0912 .72465 L
.09197 .72515 L
.09267 .72571 L
.09342 .72628 L
.09425 .72681 L
.09497 .7273 L
.09563 .7277 L
.0962 .72798 L
.09662 .72808 L
.09691 .72799 L
Mistroke
.09706 .72769 L
.09711 .7272 L
.09707 .72656 L
.09701 .72583 L
.09694 .72502 L
.09689 .72418 L
.09684 .72336 L
.0968 .72262 L
.09677 .722 L
.09676 .7215 L
.09678 .72115 L
.09684 .72096 L
.09695 .72093 L
.09711 .72103 L
.09731 .72123 L
.09754 .72148 L
.0978 .72177 L
.09808 .72206 L
.09835 .72236 L
.09862 .72264 L
.09888 .7229 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72358 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
Mistroke
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09959 .72354 L
.09962 .72357 L
.09966 .72361 L
.0997 .72364 L
.09972 .72366 L
.09971 .72365 L
.09965 .7236 L
.09954 .7235 L
.09939 .72336 L
.09919 .72318 L
.09895 .72296 L
.09869 .72273 L
.09841 .72248 L
.09814 .72223 L
.09787 .72198 L
.0976 .72174 L
.09736 .72151 L
.09714 .72132 L
Mistroke
.09697 .72117 L
.09685 .72106 L
.09678 .72099 L
.09675 .72096 L
.09673 .72095 L
.09673 .72095 L
.09674 .72095 L
.09675 .72096 L
.09678 .72099 L
.09684 .72105 L
.09694 .72114 L
.0971 .72129 L
.0973 .72147 L
.09754 .72168 L
.0978 .72192 L
.09807 .72217 L
.09835 .72242 L
.09862 .72267 L
.09888 .72291 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72359 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
Mistroke
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72354 L
.09957 .72357 L
.09957 .72361 L
.09957 .72365 L
.09957 .72367 L
.09957 .72366 L
.09956 .72361 L
.09955 .72352 L
.09951 .72341 L
.09945 .72329 L
.09935 .72316 L
.09924 .72302 L
.09916 .72287 L
.09913 .72268 L
.09921 .72242 L
.09942 .72206 L
.09978 .7216 L
.10033 .72102 L
.10109 .72031 L
.10208 .71944 L
.10315 .71843 L
.1045 .7173 L
.10595 .71598 L
.10744 .71444 L
.10917 .71268 L
.11089 .71069 L
.11268 .70857 L
.11445 .70606 L
.11608 .70341 L
.11763 .70034 L
.11892 .69722 L
.12003 .69369 L
.12085 .69 L
.12133 .686 L
.12151 .68135 L
.12136 .67725 L
.12082 .67256 L
.11996 .66711 L
.11862 .66279 L
.11706 .65778 L
.1152 .65274 L
.11312 .64716 L
.11076 .64228 L
.10841 .63704 L
Mistroke
.10615 .63173 L
.10416 .62568 L
.10193 .62077 L
.09975 .61534 L
.0979 .60939 L
.09609 .60368 L
.09446 .59759 L
.0932 .59137 L
.0921 .58515 L
.09113 .5788 L
.09031 .57245 L
.08959 .56602 L
.08894 .55962 L
.08836 .55329 L
.08789 .54684 L
.08755 .54074 L
.08734 .53448 L
.08726 .52835 L
.08725 .52225 L
.0873 .5162 L
.08737 .51024 L
.08743 .5045 L
.08748 .49893 L
.08749 .49346 L
.08749 .4882 L
.08752 .48305 L
.08763 .47795 L
.08785 .47317 L
.0882 .46841 L
.08866 .46378 L
.08929 .45924 L
.09008 .45485 L
.09107 .45048 L
.09222 .44624 L
.09362 .44212 L
.09519 .4381 L
.09698 .43428 L
.09895 .43057 L
.10096 .42707 L
.10312 .4237 L
.10521 .42061 L
.10724 .41778 L
.10923 .4153 L
.11098 .41313 L
.11262 .41133 L
.11399 .4099 L
.11518 .40886 L
.11616 .40813 L
.11691 .40767 L
.11746 .40739 L
Mistroke
.1178 .40721 L
.11796 .40706 L
.11801 .40689 L
.11801 .40663 L
.11803 .40623 L
.11813 .40566 L
.11839 .40492 L
.11882 .40399 L
.11945 .4029 L
.12026 .4016 L
.12128 .40018 L
.12248 .39868 L
.12379 .39719 L
.12523 .39573 L
.12674 .39434 L
.12832 .39303 L
.12997 .39181 L
.13157 .39066 L
.1332 .38956 L
.13479 .38851 L
.13638 .38747 L
.13795 .38643 L
.13959 .3854 L
.14121 .38437 L
.14288 .3833 L
.14468 .38219 L
.1465 .38105 L
.14831 .38003 L
.15018 .37925 L
.15197 .37851 L
.1538 .37758 L
.15549 .37642 L
.15718 .37496 L
.15884 .37298 L
.16029 .37038 L
.16167 .36711 L
.16294 .36334 L
.16408 .35943 L
.16505 .35594 L
.16583 .3523 L
.16648 .34908 L
.16701 .34591 L
.16745 .3427 L
.1678 .33971 L
.16807 .33735 L
.16825 .33581 L
.16836 .335 L
.16841 .33472 L
.16842 .33487 L
.16839 .33539 L
Mistroke
.16834 .33603 L
.1683 .33647 L
.16823 .33663 L
.16811 .33653 L
.16791 .33623 L
.16763 .33577 L
.16728 .33512 L
.16688 .33428 L
.16643 .3332 L
.16594 .33192 L
.16541 .33041 L
.16482 .32867 L
.16423 .32672 L
.16364 .32453 L
.16306 .32212 L
.16254 .3196 L
.16212 .31703 L
.16183 .31453 L
.16166 .31218 L
.16155 .30993 L
.16143 .30758 L
.16125 .30509 L
.16098 .30238 L
.16059 .29963 L
.16007 .29671 L
.15945 .29366 L
.15876 .2906 L
.15806 .28768 L
.15737 .285 L
.15671 .28268 L
.15604 .28055 L
.15533 .27847 L
.1546 .27646 L
.15391 .27461 L
.1533 .27301 L
.1528 .27169 L
.15241 .27065 L
.15209 .26991 L
.1518 .26945 L
.15151 .2692 L
.15126 .269 L
.15101 .26858 L
.15079 .2679 L
.15067 .26704 L
.15073 .26606 L
.15101 .26499 L
.15147 .26392 L
.15206 .2629 L
.15273 .26196 L
.15346 .26105 L
Mistroke
.15425 .26013 L
.15505 .25912 L
.15593 .25793 L
.15683 .25652 L
.15774 .25492 L
.15862 .25319 L
.1594 .25137 L
.16009 .24943 L
.16078 .24733 L
.16149 .24492 L
.16233 .24207 L
.16331 .23884 L
.16458 .23487 L
.16621 .23017 L
.16807 .22521 L
.17017 .21969 L
.17227 .2141 L
.17399 .20954 L
.1757 .20494 L
.17719 .20107 L
.17856 .19753 L
.17996 .19405 L
.1813 .19081 L
.18239 .18821 L
.18312 .18646 L
.18357 .18537 L
.18384 .18471 L
.184 .18437 L
.18405 .18438 L
.18411 .18452 L
.18435 .18438 L
.1848 .18396 L
.18537 .18347 L
.18601 .18303 L
.18666 .18264 L
.1873 .18224 L
.18787 .1818 L
.1884 .18132 L
.18887 .18076 L
.18929 .18012 L
.18968 .17937 L
.19007 .17849 L
.19049 .17745 L
.19098 .17623 L
.19158 .17488 L
.1923 .17338 L
.19315 .17176 L
.19409 .17003 L
.1952 .16823 L
.19641 .16637 L
Mistroke
.19775 .16453 L
.19917 .16272 L
.20064 .16099 L
.20211 .15931 L
.20355 .15768 L
.20488 .15606 L
.20618 .15446 L
.20742 .15287 L
.20859 .15132 L
.20966 .14987 L
.21074 .1485 L
.21181 .1472 L
.21292 .14598 L
.21403 .14479 L
.2152 .14365 L
.21639 .14257 L
.21765 .14156 L
.21889 .14064 L
.22015 .13979 L
.22141 .13899 L
.22263 .13821 L
.22385 .13743 L
.22511 .13666 L
.22642 .13589 L
.22769 .13515 L
.22898 .13443 L
.23025 .13373 L
.2315 .13307 L
.23271 .13248 L
.23389 .13195 L
.23495 .1315 L
.23591 .13111 L
.23667 .13077 L
.23725 .1305 L
.2376 .13031 L
.23768 .13021 L
.23749 .1302 L
.23706 .13024 L
.23641 .13029 L
.23558 .13036 L
.23461 .13043 L
.23362 .13049 L
.23253 .13054 L
.23151 .13063 L
.23052 .13077 L
.22961 .13096 L
.22881 .13121 L
.22815 .13151 L
.22765 .13186 L
.22732 .13224 L
Mistroke
.22712 .13256 L
.22708 .13296 L
.22715 .13338 L
.22729 .13371 L
.22744 .13404 L
.22752 .13432 L
.2275 .13457 L
.22734 .13479 L
.22704 .13497 L
.22661 .13513 L
.22608 .13528 L
.22552 .13544 L
.225 .13561 L
.22454 .1358 L
.22414 .13601 L
.22382 .13622 L
.22354 .13644 L
.22331 .13664 L
.22315 .13682 L
.22311 .13697 L
.22322 .13708 L
.22349 .13712 L
.22387 .1371 L
.2243 .13703 L
.22472 .13694 L
.22505 .13688 L
.2252 .13688 L
.22514 .13696 L
.22489 .13714 L
.22451 .1374 L
.22405 .13773 L
.22355 .13813 L
.22302 .13857 L
.22249 .13903 L
.22196 .13949 L
.22144 .13997 L
.22095 .14046 L
.22051 .14093 L
.22012 .14133 L
.21977 .14165 L
.21949 .14184 L
.21927 .1419 L
.21911 .14181 L
.21901 .14159 L
.21895 .14127 L
.21891 .14088 L
.21885 .14046 L
.21877 .14004 L
.21869 .1396 L
.21864 .13915 L
Mistroke
.21863 .13864 L
.21867 .13815 L
.21878 .13763 L
.21893 .13715 L
.21914 .13677 L
.2194 .13652 L
.21971 .13639 L
.2201 .13636 L
.22057 .13638 L
.22117 .13639 L
.22191 .13635 L
.22283 .13622 L
.22396 .13598 L
.22535 .13561 L
.22707 .13508 L
.229 .13437 L
.23122 .13354 L
.23377 .13247 L
.23664 .13125 L
.23988 .12975 L
.24326 .12802 L
.24694 .12618 L
.25073 .12416 L
.25488 .122 L
.25882 .11993 L
.26351 .11767 L
.26754 .11538 L
.27185 .1131 L
.27722 .11055 L
.2814 .10795 L
.28616 .10518 L
.2912 .10223 L
.29644 .09911 L
.30036 .09679 L
.30443 .09434 L
.30855 .09177 L
.31161 .08999 L
.31467 .0884 L
.31729 .08696 L
.31913 .08604 L
.32059 .08541 L
.32158 .08507 L
.32213 .085 L
.32229 .08518 L
.32215 .08557 L
.32183 .08606 L
.32146 .08657 L
.32109 .08702 L
.32077 .08736 L
.32053 .08756 L
Mistroke
.3204 .08765 L
.32037 .08767 L
.32041 .08761 L
.32045 .08754 L
.32048 .08748 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.32048 .08747 L
.32045 .08753 L
.32041 .0876 L
.32035 .08766 L
.32029 .0877 L
.32024 .08768 L
.32021 .08762 L
.32024 .08749 L
.32035 .0873 L
.32056 .08704 L
.32086 .08668 L
.32126 .08623 L
.32177 .0857 L
.32237 .0851 L
.32309 .08443 L
.32391 .08372 L
.3248 .08298 L
.32582 .08223 L
.3269 .08148 L
.32811 .08077 L
.32942 .08009 L
.33083 .07941 L
.33236 .07871 L
.33394 .07797 L
.33567 .07717 L
.33756 .07628 L
.33962 .0753 L
.34178 .07426 L
.3441 .07328 L
.34629 .07232 L
.34846 .0714 L
.3506 .07045 L
.35266 .06961 L
.35454 .06876 L
.35634 .06789 L
.35814 .0671 L
.35967 .06631 L
.36116 .0655 L
Mistroke
.36266 .06465 L
.3642 .06375 L
.36581 .06279 L
.3674 .06189 L
.36905 .06083 L
.37085 .05964 L
.37271 .0585 L
.37463 .05727 L
.37656 .05605 L
.37844 .05492 L
.38023 .05389 L
.38188 .05303 L
.38335 .05234 L
.38458 .05178 L
.38563 .05137 L
.38649 .05109 L
.38718 .05091 L
.38771 .05083 L
.3881 .05084 L
.38836 .05092 L
.38853 .05103 L
.38864 .05113 L
.38873 .05118 L
.38881 .05115 L
.3889 .051 L
.38897 .05074 L
.38902 .0504 L
.38904 .05 L
.38902 .04955 L
.38898 .04907 L
.38893 .04857 L
.38885 .04813 L
.38872 .04771 L
.38856 .04731 L
.38842 .04696 L
.38831 .04668 L
.38829 .04652 L
.38837 .04645 L
.38862 .04645 L
.38905 .0465 L
.38972 .04659 L
.39067 .04669 L
.39193 .04679 L
.3935 .04687 L
.3951 .04695 L
.39706 .04701 L
.39916 .04708 L
.40141 .04714 L
.40371 .04719 L
.40599 .04724 L
Mistroke
.40801 .04729 L
.40987 .04733 L
.41158 .04736 L
.41289 .0474 L
.41399 .04744 L
.41482 .04748 L
.41539 .04751 L
.41574 .04752 L
.41591 .04753 L
.41593 .04753 L
.41585 .04753 L
.41571 .04752 L
.41554 .04751 L
.41538 .04751 L
.41524 .0475 L
.41514 .0475 L
.41506 .0475 L
.415 .04749 L
.41498 .04749 L
.41503 .0475 L
.41515 .0475 L
.41538 .04751 L
.41574 .04753 L
.41625 .04756 L
.41695 .04759 L
.41789 .04762 L
.41911 .04765 L
.42057 .0477 L
.42229 .04776 L
.42427 .04783 L
.42647 .04791 L
.42878 .04798 L
.43114 .04802 L
.43355 .04803 L
.43582 .04801 L
.43799 .04794 L
.44009 .04783 L
.44177 .0477 L
.44327 .04754 L
.44453 .04737 L
.44551 .0472 L
.44626 .04702 L
.44678 .04684 L
.4471 .04668 L
.44721 .04652 L
.44713 .04639 L
.4469 .04629 L
.44653 .04621 L
.44607 .04617 L
.44552 .04616 L
Mistroke
.44493 .04617 L
.44431 .04618 L
.44369 .04618 L
.44306 .04614 L
.44243 .04609 L
.44175 .04603 L
.44098 .04599 L
.44016 .04597 L
.43929 .04598 L
.4384 .04603 L
.43746 .0461 L
.43641 .04618 L
.43525 .04627 L
.43384 .04639 L
.43218 .04655 L
.43025 .04677 L
.4282 .04705 L
.4258 .0474 L
.42338 .04781 L
.42096 .04828 L
.41861 .04882 L
.41683 .0494 L
.41484 .04995 L
.4131 .0504 L
.41158 .05077 L
.41016 .05106 L
.40886 .05124 L
.40773 .05128 L
.40676 .05116 L
.40592 .0509 L
.40515 .05051 L
.40444 .05005 L
.40377 .04952 L
.40307 .04897 L
.40226 .04841 L
.40134 .04788 L
.40036 .04744 L
.39944 .04709 L
.39863 .04684 L
.39799 .04671 L
.39746 .04667 L
.39705 .04671 L
.39674 .04679 L
.39648 .04687 L
.39625 .04691 L
.39604 .04688 L
.39583 .04677 L
.39562 .0466 L
.39542 .04638 L
.39522 .04613 L
Mistroke
.39501 .04588 L
.39479 .04565 L
.3946 .04546 L
.39446 .04531 L
.39441 .04522 L
.39446 .04518 L
.3946 .0452 L
.39483 .04529 L
.39513 .04543 L
.39548 .04562 L
.39588 .04586 L
.39632 .04611 L
.39676 .04638 L
.39719 .04662 L
.39761 .04681 L
.398 .04695 L
.39842 .04702 L
.39893 .04706 L
.39959 .04707 L
.40045 .04706 L
.40162 .04707 L
.40313 .04709 L
.40504 .04715 L
.40732 .04722 L
.40994 .04732 L
.41304 .04743 L
.41624 .04754 L
.41985 .04767 L
.42367 .0478 L
.42728 .04794 L
.43123 .04809 L
.43529 .04823 L
.43901 .04837 L
.44279 .04851 L
.44652 .04863 L
.45004 .04874 L
.45354 .0488 L
.45665 .04882 L
.45961 .0488 L
.46237 .04876 L
.46498 .04871 L
.46737 .04866 L
.46959 .04864 L
.47172 .04863 L
.47374 .04865 L
.4758 .04871 L
.47787 .04878 L
.48005 .04889 L
.4822 .049 L
.4844 .04916 L
Mistroke
.48693 .04934 L
.48964 .04955 L
.49275 .04976 L
.49587 .04998 L
.49969 .05018 L
.50337 .05036 L
.50746 .05052 L
.51184 .05065 L
.51678 .05075 L
.52065 .05085 L
.52544 .05095 L
.53047 .05107 L
.53474 .0512 L
.53956 .05133 L
.54435 .05147 L
.54937 .05159 L
.55367 .05172 L
.55829 .05183 L
.56268 .05194 L
.56643 .05204 L
.5703 .05212 L
.57393 .0522 L
.57722 .05225 L
.5803 .05228 L
.58298 .0523 L
.58546 .05234 L
.58766 .05242 L
.58963 .05255 L
.59146 .05275 L
.59315 .05306 L
.59469 .05341 L
.59604 .05381 L
.59731 .05427 L
.59846 .05471 L
.59949 .05518 L
.60041 .05561 L
.60122 .05605 L
.60195 .05646 L
.60259 .05681 L
.60312 .05706 L
.60355 .05721 L
.60389 .05728 L
.60416 .05732 L
.60439 .05736 L
.60461 .05743 L
.60485 .05755 L
.60511 .05776 L
.60542 .05806 L
.60578 .05845 L
.60619 .05889 L
Mistroke
.60664 .05935 L
.60712 .05982 L
.60762 .06028 L
.60814 .06075 L
.60868 .06122 L
.60917 .06165 L
.60957 .06201 L
.60985 .06225 L
.61001 .06235 L
.61001 .06231 L
.60986 .06214 L
.60957 .06187 L
.60916 .06154 L
.60864 .06115 L
.60802 .06071 L
.6073 .0602 L
.60652 .05958 L
.60569 .05889 L
.60481 .05811 L
.60394 .05728 L
.6031 .05648 L
.60232 .05576 L
.6016 .05519 L
.60096 .05477 L
.60033 .05448 L
.59968 .0543 L
.59897 .05422 L
.59817 .05427 L
.59727 .05444 L
.59633 .05472 L
.59536 .05505 L
.59434 .05539 L
.59329 .05573 L
.59223 .05603 L
.59112 .05621 L
.58998 .05624 L
.58888 .05608 L
.58782 .05577 L
.58683 .05536 L
.58595 .05491 L
.5852 .05449 L
.58455 .05406 L
.584 .05367 L
.58354 .05328 L
.58316 .0529 L
.58287 .05253 L
.58267 .05221 L
.58257 .05196 L
.58258 .05176 L
.58271 .05162 L
Mistroke
.58297 .05154 L
.58333 .05153 L
.5838 .05158 L
.58438 .05169 L
.5851 .05189 L
.58595 .05217 L
.58699 .05258 L
.5882 .05307 L
.58952 .05363 L
.59097 .05424 L
.59244 .05486 L
.59393 .05545 L
.59532 .05601 L
.59665 .05651 L
.5978 .05693 L
.59881 .05723 L
.59968 .05742 L
.60039 .05752 L
.60095 .05756 L
.60137 .05754 L
.60164 .05748 L
.60177 .05741 L
.60179 .05735 L
.60176 .05731 L
.60171 .0573 L
.60165 .0573 L
.6016 .05731 L
.60154 .05732 L
.60147 .05734 L
.60136 .05735 L
.60121 .05737 L
.60101 .05738 L
.60077 .05739 L
.60051 .05739 L
.60025 .05739 L
.60003 .05739 L
.59986 .05741 L
.59975 .05746 L
.59971 .05752 L
.59973 .05756 L
.59981 .05757 L
.59991 .05753 L
.60004 .05742 L
.60016 .05722 L
.60028 .05691 L
.60035 .0565 L
.60037 .05602 L
.60031 .05552 L
.60018 .055 L
.59999 .05451 L
Mistroke
.59978 .05408 L
.59958 .05376 L
.59939 .05359 L
.59924 .05358 L
.59916 .05378 L
.59921 .05417 L
.59939 .05476 L
.59974 .05547 L
.60028 .05626 L
.60101 .05711 L
.60195 .058 L
.60306 .05887 L
.60441 .05964 L
.60602 .06039 L
.60781 .06116 L
.60984 .06196 L
.61227 .06279 L
.61476 .06366 L
.61774 .06457 L
.62085 .0656 L
.62398 .06675 L
.62746 .06787 L
.63093 .06908 L
.63458 .07046 L
.63794 .07175 L
.64133 .0731 L
.64489 .07447 L
.64807 .07581 L
.65123 .0772 L
.65471 .07867 L
.65797 .08019 L
.66132 .0819 L
.66486 .08384 L
.66855 .08565 L
.67189 .08774 L
.6756 .08997 L
.67942 .09201 L
.68281 .09425 L
.68664 .0961 L
.68973 .09786 L
.69297 .09953 L
.69578 .10085 L
.69823 .10193 L
.70026 .10269 L
.70184 .10314 L
.70295 .10333 L
.7037 .10333 L
.70415 .10324 L
.70441 .10312 L
.70458 .10303 L
Mistroke
.70476 .10306 L
.70508 .10324 L
.70563 .10358 L
.70648 .10411 L
.70768 .10486 L
.70927 .1058 L
.71112 .10691 L
.71355 .10823 L
.71618 .10974 L
.71939 .11133 L
.72299 .11307 L
.72658 .11487 L
.73087 .11672 L
.73517 .11851 L
.74025 .12034 L
.74452 .12212 L
.7493 .12373 L
.75397 .12532 L
.75891 .12686 L
.76317 .12827 L
.76745 .12956 L
.77178 .13076 L
.77525 .13187 L
.77879 .13284 L
.78187 .13371 L
.78461 .13447 L
.78682 .13512 L
.78865 .13566 L
.79012 .1361 L
.79128 .13645 L
.79219 .13669 L
.79285 .13685 L
.79334 .13694 L
.79368 .13697 L
.79389 .13695 L
.79398 .13692 L
.79399 .13688 L
.79395 .13684 L
.79388 .1368 L
.7938 .13677 L
.79374 .13675 L
.79369 .13675 L
.79365 .13675 L
.79362 .13672 L
.7936 .13667 L
.79359 .1366 L
.79356 .13654 L
.79351 .1365 L
.79345 .1365 L
.7934 .13654 L
Mistroke
.79337 .13664 L
.79337 .13682 L
.79343 .13711 L
.79355 .13748 L
.79373 .13795 L
.794 .13847 L
.79433 .13904 L
.79476 .13966 L
.79528 .14036 L
.79592 .14113 L
.7967 .14199 L
.79759 .14297 L
.7986 .144 L
.79969 .14514 L
.80083 .14641 L
.80201 .14781 L
.80324 .14935 L
.8045 .15084 L
.80583 .15256 L
.80722 .15442 L
.80864 .15629 L
.81012 .15825 L
.81163 .1603 L
.81318 .16226 L
.81467 .1643 L
.81609 .1662 L
.81746 .16799 L
.81869 .16961 L
.81982 .17107 L
.82082 .17228 L
.82165 .17329 L
.82231 .17405 L
.82274 .17456 L
.82297 .1748 L
.82299 .17481 L
.82283 .17463 L
.82251 .17422 L
.8221 .17364 L
.82166 .17291 L
.82123 .17211 L
.82084 .17132 L
.82051 .1706 L
.82027 .17 L
.82013 .16955 L
.8201 .16927 L
.82017 .16919 L
.8203 .16925 L
.82046 .16945 L
.82063 .16968 L
.82079 .16998 L
Mistroke
.82096 .17038 L
.82113 .17088 L
.82128 .17151 L
.82143 .17228 L
.8216 .17326 L
.82183 .17452 L
.82216 .1761 L
.82262 .1779 L
.82326 .18021 L
.8241 .18283 L
.82522 .18591 L
.82657 .18935 L
.82824 .19328 L
.83018 .19755 L
.83245 .20226 L
.83484 .20694 L
.83766 .21169 L
.84038 .2166 L
.84345 .22121 L
.84667 .22621 L
.8501 .23069 L
.853 .23476 L
.8569 .23906 L
.85997 .24327 L
.86355 .24674 L
.86687 .25034 L
.87045 .25356 L
.87365 .25661 L
.87644 .25935 L
.87937 .26195 L
.88227 .26421 L
.88437 .26613 L
.88632 .2678 L
.8882 .26915 L
.88958 .27023 L
.89073 .27115 L
.89161 .2719 L
.89226 .27262 L
.89276 .27348 L
.89322 .27459 L
.89372 .27604 L
.89434 .27791 L
.8951 .28007 L
.89611 .28299 L
.89728 .28639 L
.89874 .28972 L
.90035 .2938 L
.90234 .2984 L
.90431 .30313 L
.90667 .30863 L
Mistroke
.9088 .31329 L
.91127 .31828 L
.91349 .32326 L
.91586 .32834 L
.91794 .33305 L
.91996 .33769 L
.92192 .34231 L
.92349 .34624 L
.92496 .35042 L
.92621 .35383 L
.92725 .3572 L
.92808 .36037 L
.92871 .36312 L
.92916 .36592 L
.92948 .36826 L
.92969 .37057 L
.92982 .37285 L
.9299 .37493 L
.92993 .37701 L
.92994 .37906 L
.92995 .38103 L
.92995 .38262 L
.92996 .38415 L
.92998 .3856 L
.93002 .38693 L
.93005 .38795 L
.93009 .38865 L
.93013 .38896 L
.93017 .38893 L
.93019 .38869 L
.93018 .38831 L
.93015 .38786 L
.93008 .38736 L
.92997 .38691 L
.92983 .38656 L
.92966 .38632 L
.92948 .38622 L
.92932 .38628 L
.92918 .3865 L
.92909 .38681 L
.92901 .38717 L
.92894 .38757 L
.92888 .38799 L
.92883 .38836 L
.92881 .38863 L
.92882 .38882 L
.92886 .38891 L
.92893 .38893 L
.92902 .3889 L
.92911 .38889 L
Mistroke
.92922 .38891 L
.92933 .38903 L
.92944 .38927 L
.92956 .38961 L
.92973 .39007 L
.92993 .39064 L
.93017 .39135 L
.93045 .39225 L
.93074 .39338 L
.93106 .39473 L
.93137 .39632 L
.93167 .3982 L
.93194 .40029 L
.93217 .40268 L
.93238 .40532 L
.93258 .40789 L
.93275 .41062 L
.93291 .41338 L
.93303 .41604 L
.93313 .41863 L
.93322 .42095 L
.93329 .42308 L
.93336 .42492 L
.93343 .42636 L
.93349 .42743 L
.93353 .42812 L
.93354 .42846 L
.93354 .42853 L
.93352 .42844 L
.93351 .42825 L
.93349 .42798 L
.93348 .42765 L
.93347 .4273 L
.93346 .42691 L
.93344 .42652 L
.93343 .42615 L
.93342 .42581 L
.93341 .42548 L
.93339 .42513 L
.93338 .42475 L
.93338 .42433 L
.93339 .42386 L
.9334 .42332 L
.93341 .4227 L
.9334 .42201 L
.93337 .42125 L
.9333 .42047 L
.93319 .41971 L
.93304 .41901 L
.93286 .41837 L
Mistroke
.93265 .4178 L
.93241 .41729 L
.93214 .41684 L
.93189 .41647 L
.93165 .4162 L
.93145 .41607 L
.93131 .41611 L
.93124 .41632 L
.93124 .41671 L
.93132 .41721 L
.93148 .41774 L
.93172 .41822 L
.932 .41863 L
.93231 .419 L
.93263 .41936 L
.93291 .41973 L
.93315 .42013 L
.9333 .42065 L
.93336 .42137 L
.93331 .42236 L
.93312 .42372 L
.93279 .4255 L
.93231 .42775 L
.93171 .43026 L
.93101 .43336 L
.93026 .43711 L
.92947 .4414 L
.92869 .44632 L
.92796 .4522 L
.92729 .45747 L
.9267 .46403 L
.92622 .4706 L
.92587 .47698 L
.92566 .48386 L
.9256 .4909 L
.92569 .49808 L
.92588 .50524 L
.92615 .51241 L
.92645 .52002 L
.92672 .52735 L
.92693 .53472 L
.92702 .54223 L
.927 .55007 L
.92688 .55747 L
.92665 .56587 L
.92633 .57269 L
.92595 .57991 L
.9255 .5867 L
.92503 .59307 L
.92452 .59988 L
Mistroke
.924 .60585 L
.92346 .6108 L
.92291 .61603 L
.92232 .62065 L
.92166 .62522 L
.92088 .62991 L
.91995 .63419 L
.91879 .63879 L
.91739 .64364 L
.91565 .64902 L
.91364 .65475 L
.91135 .66109 L
.90883 .66807 L
.90591 .67549 L
.90306 .683 L
.90016 .69136 L
.89724 .69845 L
.8944 .70638 L
.89169 .71412 L
.88926 .72195 L
.88708 .72921 L
.88512 .7364 L
.88335 .74296 L
.88187 .74861 L
.88054 .75441 L
.87936 .75988 L
.87834 .76459 L
.87749 .76906 L
.87678 .77278 L
.87611 .77618 L
.87539 .77901 L
.87448 .78163 L
.87328 .78412 L
.87182 .78626 L
.87002 .78828 L
.86786 .79019 L
.8653 .79198 L
.86254 .79367 L
.85923 .79531 L
.85605 .79682 L
.85213 .79848 L
.84774 .80028 L
.84341 .80214 L
.83837 .80417 L
.83309 .8063 L
.82762 .8086 L
.82195 .81104 L
.81623 .81342 L
.81027 .81592 L
.80413 .81841 L
Mistroke
.79793 .82102 L
.79149 .82364 L
.78492 .82631 L
.77824 .82895 L
.77154 .83144 L
.76479 .83367 L
.75769 .83555 L
.75183 .83696 L
.74544 .83786 L
.73894 .83819 L
.73304 .83794 L
.72703 .83709 L
.72123 .83566 L
.7154 .83371 L
.70989 .8312 L
.70422 .82838 L
.69846 .82516 L
.69268 .82166 L
.68645 .81804 L
.68067 .81428 L
.67461 .81051 L
.66812 .80682 L
.66212 .80337 L
.65582 .80017 L
.64971 .79737 L
.64326 .79502 L
.63704 .79325 L
.63069 .79202 L
.62459 .79139 L
.6183 .79129 L
.6122 .79169 L
.60579 .79249 L
.59946 .79362 L
.593 .79485 L
.58698 .79618 L
.58015 .79745 L
.57433 .79844 L
.56799 .79913 L
.5617 .79935 L
.55522 .799 L
.54893 .79793 L
.54228 .79612 L
.53625 .79358 L
.52963 .79034 L
.52332 .78655 L
.517 .7823 L
.51064 .77763 L
.50378 .77245 L
.49773 .76741 L
.49131 .76201 L
Mistroke
.48447 .75584 L
.47881 .75062 L
.47282 .7447 L
.46702 .7389 L
.46153 .7328 L
.45651 .72713 L
.452 .72217 L
.44795 .71731 L
.4443 .71296 L
.44127 .70905 L
.43872 .70529 L
.43682 .70256 L
.43542 .70016 L
.43459 .69811 L
.43434 .6965 L
.43457 .69522 L
.43523 .69424 L
.43624 .69358 L
.43756 .69311 L
.43908 .69266 L
.44084 .69221 L
.4429 .69175 L
.44508 .69119 L
.44749 .69042 L
.45012 .68952 L
.45298 .68864 L
.45616 .68787 L
.45937 .68727 L
.46299 .68685 L
.46698 .68663 L
.47126 .68654 L
.47603 .68655 L
.48107 .68665 L
.48631 .68687 L
.49225 .68722 L
.49802 .68773 L
.50404 .68847 L
.51025 .68943 L
.51704 .69068 L
.52358 .69221 L
.53026 .69398 L
.53644 .69602 L
.54304 .69818 L
.54953 .70066 L
.5559 .70346 L
.56182 .70665 L
.56788 .71006 L
.57382 .71373 L
.5799 .71812 L
.58597 .72216 L
Mistroke
.59213 .72675 L
.59795 .73165 L
.60438 .73715 L
.60969 .74203 L
.61519 .74762 L
.62101 .75369 L
.62569 .75967 L
.63073 .76596 L
.63522 .77254 L
.63959 .77951 L
.64362 .78589 L
.64747 .79273 L
.65121 .79958 L
.65505 .80624 L
.65882 .81256 L
.66274 .819 L
.66702 .82453 L
.67156 .82954 L
.67634 .83461 L
.68141 .8391 L
.68637 .84318 L
.69163 .84669 L
.69666 .84986 L
.70188 .8525 L
.7064 .85507 L
.71127 .85724 L
.7158 .85923 L
.72014 .86092 L
.72447 .86253 L
.72802 .86394 L
.73139 .86519 L
.7344 .86629 L
.73693 .86735 L
.73904 .86836 L
.74067 .86929 L
.74175 .8702 L
.74235 .87109 L
.7425 .87196 L
.74228 .87281 L
.74176 .87363 L
.74101 .87442 L
.74013 .87512 L
.73926 .87581 L
.7384 .87647 L
.7376 .8771 L
.73692 .87764 L
.73641 .87809 L
.7361 .87841 L
.73599 .8786 L
.73608 .87867 L
Mistroke
.73637 .87864 L
.73686 .87853 L
.73751 .87839 L
.73829 .87827 L
.73918 .87816 L
.74017 .87802 L
.74128 .8778 L
.74257 .87748 L
.74399 .87703 L
.74562 .87643 L
.74743 .87569 L
.74934 .8748 L
.75152 .87373 L
.75382 .87246 L
.75634 .87101 L
.75911 .86935 L
.76188 .86747 L
.76493 .86542 L
.76792 .86326 L
.77116 .86097 L
.77444 .85857 L
.77779 .85622 L
.78114 .85379 L
.78425 .85147 L
.78729 .84909 L
.79002 .84704 L
.79249 .84507 L
.79474 .84327 L
.79672 .84168 L
.79836 .84033 L
.79974 .83926 L
.80082 .83842 L
.80166 .83779 L
.8023 .83731 L
.80279 .83693 L
.80316 .83662 L
.80343 .83641 L
.80359 .8363 L
.80364 .83635 L
.80356 .83656 L
.80338 .83694 L
.80311 .83744 L
.80276 .83805 L
.80234 .83874 L
.80188 .83947 L
.80139 .84023 L
.80091 .84097 L
.80044 .8417 L
.8 .84242 L
.7996 .8431 L
Mistroke
.79924 .84371 L
.79896 .84419 L
.79878 .84454 L
.79869 .84475 L
.79868 .84484 L
.79871 .84484 L
.79876 .84475 L
.79879 .84462 L
.79878 .84449 L
.79874 .84438 L
.79865 .84427 L
.79855 .84416 L
.79845 .84404 L
.79837 .84389 L
.79832 .84369 L
.79832 .84342 L
.79837 .84307 L
.79846 .84264 L
.79861 .84213 L
.79882 .84158 L
.79907 .841 L
.79936 .84041 L
.79967 .83983 L
.80001 .83928 L
.80038 .83872 L
.80075 .83819 L
.80107 .83772 L
.80128 .83732 L
.80136 .83706 L
.8013 .83696 L
.80107 .83705 L
.80068 .83733 L
.80013 .83776 L
.79947 .83829 L
.79875 .83889 L
.79802 .8395 L
.79735 .84007 L
.79673 .84061 L
.79617 .84112 L
.79568 .8416 L
.79531 .84201 L
.79508 .84233 L
.795 .84255 L
.79507 .84266 L
.79525 .84268 L
.79553 .84262 L
.79585 .84252 L
.79617 .84242 L
.79643 .84233 L
.79661 .84229 L
Mistroke
.79671 .84227 L
.79677 .84227 L
.79679 .84226 L
.79677 .84226 L
.79674 .84227 L
.7967 .84227 L
.79667 .84227 L
.79666 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84232 L
.79665 .84241 L
.79665 .84256 L
.79665 .84273 L
.79664 .84293 L
.7966 .84309 L
.79653 .84318 L
.79643 .84314 L
.7963 .84292 L
.79614 .84244 L
.796 .84162 L
Mistroke
.79592 .84036 L
.79595 .8386 L
.79614 .83652 L
.79654 .83384 L
.79722 .83067 L
.79821 .82679 L
.79954 .82286 L
.80128 .81852 L
.80346 .81343 L
.80592 .80898 L
.80883 .80414 L
.81216 .79908 L
.81579 .79486 L
.81961 .79049 L
.82365 .78642 L
.82776 .78283 L
.83201 .77959 L
.83597 .77698 L
.84012 .77475 L
.8434 .77313 L
.84718 .77192 L
.85089 .77115 L
.85381 .77079 L
.85638 .77074 L
.859 .77094 L
.86082 .77132 L
.86276 .77177 L
.86414 .77224 L
.86531 .77267 L
.86631 .77299 L
.86717 .77312 L
.86798 .77303 L
.86882 .77267 L
.86975 .77201 L
.87083 .77109 L
.87195 .76985 L
.87318 .76825 L
.87454 .7663 L
.87606 .76396 L
.87782 .76137 L
.8798 .75833 L
.8816 .75499 L
.88346 .75121 L
.88527 .74728 L
.88702 .74321 L
.88864 .73858 L
.89016 .73441 L
.89158 .72976 L
.89294 .72541 L
.8943 .72138 L
Mistroke
.89555 .71719 L
.89687 .71317 L
.89814 .70951 L
.89944 .70585 L
.90072 .70253 L
.90196 .69928 L
.90318 .696 L
.90433 .69294 L
.90546 .68977 L
.90659 .68641 L
.90769 .68335 L
.90882 .67999 L
.90994 .67649 L
.91112 .67273 L
.91231 .66904 L
.91359 .66499 L
.91486 .66049 L
.91619 .65614 L
.91759 .65136 L
.91906 .64631 L
.92061 .64069 L
.92222 .63562 L
.92389 .62943 L
.92561 .62392 L
.9274 .61781 L
.9291 .61218 L
.93084 .60592 L
.93257 .59971 L
.9343 .59394 L
.93592 .58776 L
.93744 .58219 L
.93884 .57639 L
.94005 .57094 L
.94108 .56573 L
.9419 .56054 L
.94251 .55534 L
.9429 .55109 L
.94312 .54665 L
.94314 .54274 L
.94303 .53933 L
.94281 .53628 L
.94251 .53384 L
.94218 .53186 L
.94183 .53038 L
.94149 .52938 L
.94118 .52886 L
.94093 .52876 L
.94075 .52901 L
.94065 .52954 L
.94061 .53026 L
Mistroke
.94063 .5311 L
.94067 .53199 L
.94073 .53287 L
.94079 .53369 L
.94084 .53439 L
.9409 .53495 L
.94095 .53539 L
.94102 .53569 L
.94108 .53587 L
.94114 .53591 L
.94119 .53586 L
.94125 .53573 L
.9413 .5356 L
.94134 .53551 L
.94134 .53547 L
.94129 .53546 L
.9412 .53545 L
.94106 .53547 L
.94086 .53552 L
.9406 .53562 L
.94034 .53579 L
.94012 .53602 L
.93996 .53632 L
.93985 .53667 L
.93979 .53707 L
.93976 .53752 L
.93975 .53799 L
.93975 .53847 L
.93984 .53892 L
.94001 .53932 L
.94023 .53962 L
.94049 .53979 L
.94076 .53982 L
.94102 .53971 L
.94125 .53947 L
.9414 .53912 L
.94144 .53868 L
.94142 .53817 L
.94137 .5376 L
.94133 .537 L
.94131 .53643 L
.94129 .53592 L
.94128 .53552 L
.94126 .53527 L
.94122 .53521 L
.94114 .53536 L
.94103 .5357 L
.94089 .5362 L
.94073 .5368 L
.94055 .53745 L
Mistroke
.94036 .53813 L
.94017 .53878 L
.93998 .5394 L
.9398 .54002 L
.93963 .54066 L
.93949 .54136 L
.93938 .54213 L
.93932 .543 L
.9393 .54397 L
.93932 .54505 L
.93939 .5462 L
.9395 .54747 L
.93964 .54883 L
.93976 .55026 L
.93984 .55166 L
.93986 .55312 L
.93982 .55442 L
.93969 .55559 L
.93947 .55658 L
.93916 .55736 L
.93877 .55791 L
.93833 .55823 L
.93788 .55836 L
.93745 .55835 L
.93704 .55825 L
.93665 .5581 L
.93629 .55795 L
.93603 .55787 L
.9359 .55783 L
.93594 .55783 L
.93614 .55782 L
.9365 .5578 L
.93697 .55778 L
.93752 .55775 L
.93813 .55773 L
.93878 .55769 L
.93939 .55764 L
.93999 .55757 L
.94057 .55751 L
.94106 .55747 L
.94147 .55749 L
.94176 .55755 L
.94192 .55766 L
.94192 .55779 L
.94178 .55794 L
.9415 .55809 L
.94113 .55822 L
.9407 .55832 L
.94023 .5584 L
.93977 .55844 L
Mistroke
.93935 .55849 L
.93893 .55855 L
.93855 .55858 L
.93821 .55856 L
.93793 .55845 L
.93773 .55824 L
.93762 .55795 L
.93757 .55761 L
.93758 .55727 L
.93762 .55697 L
.93768 .55676 L
.93773 .55667 L
.93775 .55667 L
.93775 .55673 L
.93775 .55678 L
.93775 .55678 L
.93775 .55673 L
.93775 .55664 L
.93775 .55653 L
.93774 .55637 L
.93774 .55617 L
.93773 .55591 L
.93772 .5556 L
.93771 .55525 L
.9377 .55482 L
.93769 .55438 L
.93768 .55407 L
.93767 .55396 L
.93768 .554 L
.93768 .55416 L
.93769 .55437 L
.9377 .55455 L
.93771 .55451 L
.9377 .55406 L
.93766 .553 L
.9376 .55114 L
.93751 .54831 L
.93739 .54446 L
.93724 .53968 L
.93706 .5345 L
.93684 .52793 L
.9366 .52046 L
.93633 .51204 L
.93604 .50285 L
.93576 .49468 L
.93547 .48446 L
.93519 .47542 L
.93491 .46566 L
.93462 .45666 L
.93431 .44723 L
Mistroke
.93396 .43886 L
.93357 .43062 L
.93314 .42164 L
.93265 .41419 L
.9321 .40623 L
.93149 .39751 L
.93083 .39047 L
.9301 .38281 L
.92929 .3751 L
.92842 .36831 L
.92751 .3615 L
.92656 .35484 L
.92559 .34923 L
.92467 .34386 L
.92378 .3392 L
.92297 .33524 L
.92224 .3321 L
.9216 .32965 L
.92104 .32789 L
.92058 .32674 L
.92021 .32605 L
.91993 .32575 L
.91974 .32575 L
.91964 .32593 L
.9196 .32624 L
.91962 .3266 L
.91966 .32697 L
.91971 .3273 L
.91977 .32757 L
.91981 .32778 L
.91984 .32793 L
.91986 .32804 L
.91987 .32809 L
.9199 .32808 L
.91996 .32799 L
.92004 .32776 L
.92011 .32735 L
.92015 .32672 L
.92013 .32583 L
.92001 .3247 L
.91977 .32328 L
.91939 .32163 L
.91886 .31973 L
.91822 .31768 L
.91747 .31551 L
.91663 .3133 L
.91583 .31117 L
.91494 .30913 L
.9141 .30732 L
.91327 .30572 L
Mistroke
.91249 .30439 L
.91184 .30333 L
.91132 .30254 L
.91096 .302 L
.91074 .30169 L
.91065 .30154 L
.91064 .30151 L
.91069 .30158 L
.91075 .30168 L
.91077 .30181 L
.91076 .30191 L
.91073 .30198 L
.91068 .30197 L
.91056 .30183 L
.91034 .30152 L
.91001 .30103 L
.90956 .30033 L
.90897 .29944 L
.90825 .29837 L
.9074 .29714 L
.90647 .2958 L
.90543 .29434 L
.9043 .29278 L
.90308 .29106 L
.90171 .28913 L
.90033 .28706 L
.89874 .28469 L
.89692 .28201 L
.89491 .27904 L
.89275 .27576 L
.89038 .27217 L
.88778 .26834 L
.88495 .26367 L
.88194 .25929 L
.87858 .25362 L
.87505 .24876 L
.87113 .24264 L
.8672 .23666 L
.86309 .23101 L
.85893 .22484 L
.85487 .21889 L
.85053 .21235 L
.84659 .20676 L
.8426 .20156 L
.83859 .19587 L
.83462 .19022 L
.83077 .18475 L
.82688 .1789 L
.82343 .1742 L
.82009 .16933 L
Mistroke
.81694 .16451 L
.8142 .16068 L
.81168 .15713 L
.80952 .15362 L
.80773 .15114 L
.80627 .14896 L
.80518 .14726 L
.8044 .14594 L
.80391 .14504 L
.80367 .14455 L
.80364 .14439 L
.80372 .14444 L
.80388 .14462 L
.80406 .14487 L
.80421 .14511 L
.80431 .14531 L
.80438 .14544 L
.80444 .14553 L
.80449 .1456 L
.80452 .14567 L
.80454 .14571 L
.80453 .14568 L
.80448 .14559 L
.80439 .14542 L
.80426 .14517 L
.8041 .14485 L
.80392 .14448 L
.80373 .14408 L
.80353 .14365 L
.80334 .14321 L
.80312 .14276 L
.80289 .14231 L
.80263 .14185 L
.80237 .14143 L
.8021 .14105 L
.80183 .14076 L
.80159 .14055 L
.80136 .14046 L
.80115 .14047 L
.80096 .14056 L
.80078 .14066 L
.80059 .14071 L
.80041 .14069 L
.80024 .14058 L
.8001 .14042 L
.8 .14024 L
.79994 .14005 L
.79993 .13989 L
.79994 .13977 L
.79997 .13968 L
Mistroke
.80001 .13964 L
.80003 .13961 L
.80005 .1396 L
.80005 .1396 L
.80005 .13963 L
.80007 .13973 L
.8001 .13993 L
.80014 .14021 L
.80018 .14057 L
.80023 .14096 L
.80028 .14136 L
.80032 .14171 L
.80034 .14197 L
.80034 .14211 L
.80028 .14214 L
.80014 .14207 L
.79988 .14192 L
.7995 .14172 L
.79897 .14146 L
.79826 .14109 L
.79737 .1406 L
.79626 .14 L
.79497 .13928 L
.79345 .13846 L
.79166 .13751 L
.78965 .13644 L
.78737 .13524 L
.78483 .13393 L
.78185 .1325 L
.77876 .13101 L
.77533 .12939 L
.77168 .12763 L
.76804 .1259 L
.76414 .1241 L
.76038 .12227 L
.75681 .12056 L
.75322 .11886 L
.74967 .11723 L
.74639 .11577 L
.74358 .11439 L
.74094 .11314 L
.73861 .11201 L
.7365 .11098 L
.7347 .11003 L
.73298 .10916 L
.73137 .10829 L
.72971 .10742 L
.72793 .10653 L
.72606 .10564 L
.724 .10474 L
Mistroke
.72162 .10379 L
.71903 .1028 L
.71604 .10175 L
.71244 .10063 L
.70879 .09941 L
.70454 .09804 L
.69987 .09651 L
.69442 .0948 L
.68892 .09288 L
.68389 .09086 L
.67765 .08875 L
.67192 .08637 L
.66534 .08382 L
.65857 .08115 L
.6519 .07826 L
.64545 .0754 L
.63852 .07242 L
.63146 .06952 L
.62425 .06662 L
.61722 .06408 L
.61034 .06147 L
.60335 .05936 L
.5964 .05737 L
.58949 .05558 L
.58251 .05414 L
.57591 .05296 L
.56994 .05205 L
.56331 .05141 L
.558 .05101 L
.55228 .0508 L
.54709 .05072 L
.54198 .05072 L
.53676 .05073 L
.53176 .05072 L
.52623 .05069 L
.52132 .05063 L
.51572 .05054 L
.51017 .05042 L
.50418 .05029 L
.49799 .05014 L
.49199 .04999 L
.48567 .04981 L
.47903 .04962 L
.47246 .04941 L
.46609 .04919 L
.45952 .04897 L
.45299 .04876 L
.44633 .04854 L
.44017 .04833 L
.43396 .04813 L
Mistroke
.4282 .04793 L
.42278 .04773 L
.41788 .04754 L
.41307 .04738 L
.40938 .04725 L
.40602 .04714 L
.40317 .04707 L
.40104 .04703 L
.39942 .04701 L
.3983 .047 L
.39764 .04701 L
.39736 .04703 L
.39735 .04704 L
.39751 .04706 L
.39776 .04707 L
.39803 .04708 L
.39824 .04708 L
.39838 .04707 L
.39847 .04705 L
.39852 .04702 L
.39853 .04697 L
.39853 .0469 L
.39853 .04682 L
.39853 .04675 L
.39853 .04673 L
.39853 .04676 L
.39853 .04685 L
.39853 .04696 L
.39853 .04709 L
.39853 .04724 L
.39853 .04742 L
.39853 .04763 L
.39853 .0479 L
.39853 .04822 L
.39853 .04857 L
.39853 .04894 L
.39853 .04931 L
.39853 .04971 L
.39853 .05007 L
.39853 .05036 L
.39854 .05064 L
.39859 .05088 L
.39868 .05107 L
.39883 .05124 L
.39899 .05137 L
.39912 .05147 L
.39918 .05151 L
.39909 .05148 L
.39885 .05141 L
.39841 .05132 L
Mistroke
.39776 .05126 L
.39689 .05126 L
.3958 .05135 L
.39451 .0515 L
.39312 .05169 L
.39153 .05191 L
.38974 .05219 L
.38788 .05252 L
.38587 .05295 L
.38379 .05349 L
.38166 .05417 L
.37957 .05498 L
.37755 .05592 L
.37555 .05697 L
.37357 .05808 L
.3717 .05915 L
.36978 .06022 L
.36793 .06125 L
.36616 .06223 L
.36457 .06316 L
.3632 .06394 L
.36202 .06458 L
.36102 .06507 L
.36012 .06541 L
.35933 .0656 L
.35853 .0657 L
.35772 .06574 L
.35681 .06586 L
.3557 .06616 L
.35431 .06672 L
.35259 .0676 L
.35064 .06878 L
.34834 .07036 L
.34562 .0722 L
.34236 .0745 L
.33915 .07703 L
.33508 .07998 L
.33094 .08288 L
.32627 .08607 L
.32063 .08954 L
.31593 .09267 L
.30952 .09605 L
.30402 .0994 L
.29782 .10254 L
.29148 .10578 L
.28447 .10916 L
.27746 .11218 L
.27065 .11542 L
.26375 .11863 L
.25632 .12165 L
Mistroke
.2501 .12467 L
.24393 .12771 L
.23817 .13063 L
.2319 .13366 L
.22751 .13643 L
.22283 .1394 L
.21822 .14248 L
.21476 .14542 L
.21126 .14871 L
.20781 .15234 L
.20502 .15556 L
.2021 .15921 L
.19908 .16347 L
.19645 .16724 L
.19345 .17174 L
.19055 .17595 L
.18743 .18059 L
.18418 .18532 L
.18088 .19012 L
.17788 .19445 L
.17494 .19857 L
.1722 .20243 L
.16944 .20656 L
.16714 .20978 L
.16489 .21298 L
.16261 .21646 L
.16055 .21946 L
.15842 .22268 L
.15624 .22593 L
.15387 .22955 L
.15118 .23361 L
.14859 .23729 L
.1457 .24123 L
.14247 .24583 L
.13916 .25038 L
.13551 .25538 L
.13146 .26135 L
.12791 .26613 L
.12401 .27157 L
.1201 .2771 L
.11622 .28305 L
.11278 .28799 L
.10927 .29394 L
.10635 .2988 L
.10353 .30431 L
.10099 .30968 L
.0986 .31515 L
.09643 .32054 L
.09457 .3262 L
.09284 .33117 L
Mistroke
.09126 .33665 L
.08989 .34251 L
.08864 .34742 L
.08753 .35333 L
.08658 .35807 L
.08568 .36339 L
.08484 .36834 L
.08403 .37315 L
.08325 .378 L
.08252 .38185 L
.08188 .38581 L
.08136 .38916 L
.08094 .3922 L
.08062 .39467 L
.08039 .39677 L
.08021 .39834 L
.08009 .3995 L
.08 .4003 L
.07994 .40078 L
.07992 .401 L
.07993 .401 L
.07998 .40088 L
.08003 .40071 L
.08007 .40052 L
.0801 .40034 L
.0801 .40022 L
.0801 .40014 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08005 .40006 L
.08001 .40002 L
.07997 .39999 L
.07993 .39997 L
.07991 .39998 L
.07992 .40002 L
.07996 .40009 L
.08003 .40017 L
.08016 .40027 L
Mistroke
.08038 .40039 L
.08072 .40056 L
.08118 .40079 L
.08177 .4011 L
.08249 .4015 L
.08332 .402 L
.08424 .4026 L
.08518 .4033 L
.08613 .40408 L
.08703 .40492 L
.08773 .40573 L
.08844 .40656 L
.08911 .40735 L
.08973 .40815 L
.09029 .40886 L
.09075 .40961 L
.0911 .41039 L
.09132 .41122 L
.09143 .4121 L
.09145 .41304 L
.09139 .41408 L
.09129 .41518 L
.09118 .41641 L
.09109 .41769 L
.09103 .41886 L
.09094 .42014 L
.09082 .42131 L
.09068 .42249 L
.09053 .42365 L
.09038 .42472 L
.09025 .42567 L
.09014 .4265 L
.09007 .42724 L
.09003 .42789 L
.09004 .42846 L
.09006 .42896 L
.09007 .42942 L
.09006 .4299 L
.09005 .43036 L
.09003 .43079 L
.09002 .43114 L
.09001 .43142 L
.09 .43161 L
.09 .43172 L
.09002 .43175 L
.09011 .43169 L
.09025 .43158 L
.09038 .43145 L
.09046 .43134 L
.09047 .43127 L
Mistroke
.0904 .43122 L
.09022 .43118 L
.08989 .43114 L
.08931 .43108 L
.08848 .43103 L
.08743 .43098 L
.08619 .43096 L
.08487 .43098 L
.08356 .43104 L
.08205 .43118 L
.08018 .43142 L
.07839 .43177 L
.07658 .43223 L
.07454 .43281 L
.07259 .43351 L
.07097 .43431 L
.06951 .4352 L
.06805 .43617 L
.06664 .43717 L
.06543 .43816 L
.06453 .43907 L
.06378 .43987 L
.06317 .44056 L
.06271 .4411 L
.06238 .44149 L
.06217 .44173 L
.06207 .44185 L
.06205 .44186 L
.06207 .4418 L
.06213 .44169 L
.06222 .44157 L
.06232 .44145 L
.06237 .4414 L
.06239 .44142 L
.06239 .44153 L
.06238 .4417 L
.06238 .44191 L
.06237 .44216 L
.06236 .44244 L
.06235 .4427 L
.06234 .4429 L
.06234 .44305 L
.06234 .44317 L
.06233 .44329 L
.06233 .44341 L
.06232 .44356 L
.06229 .44374 L
.06223 .44394 L
.06214 .44419 L
.06204 .4445 L
Mistroke
.06196 .4449 L
.06192 .44538 L
.06196 .44592 L
.06211 .4465 L
.06239 .44715 L
.0628 .44788 L
.06334 .44868 L
.06407 .44953 L
.06481 .45036 L
.06545 .45119 L
.06625 .45205 L
.067 .45296 L
.06786 .45398 L
.06854 .45517 L
.06915 .45661 L
.06966 .45817 L
.06999 .45997 L
.07012 .46204 L
.07006 .46442 L
.06981 .46709 L
.06939 .46965 L
.06884 .47248 L
.0682 .47564 L
.06757 .47869 L
.06691 .48182 L
.06625 .48469 L
.0656 .48748 L
.065 .48988 L
.06448 .49204 L
.06403 .49363 L
.06368 .49482 L
.06344 .49563 L
.06328 .49607 L
.06317 .49622 L
.0631 .49619 L
.06305 .49617 L
.063 .49636 L
.06293 .49684 L
.06281 .49768 L
.06266 .49875 L
.06249 .5004 L
.06234 .50266 L
.06223 .505 L
.06217 .50781 L
.06217 .51081 L
.06222 .51369 L
.06237 .51694 L
.06258 .51945 L
.06284 .52175 L
.06312 .52387 L
Mistroke
.0634 .5257 L
.06365 .52708 L
.06386 .52799 L
.06402 .52858 L
.06412 .52905 L
.06414 .52959 L
.06409 .53035 L
.06405 .53141 L
.06407 .53285 L
.06416 .53492 L
.06428 .53774 L
.06449 .54084 L
.06484 .54461 L
.06536 .54892 L
.06595 .55356 L
.0666 .5589 L
.06728 .56407 L
.06792 .56982 L
.06864 .57589 L
.06924 .58138 L
.06978 .58766 L
.07025 .59209 L
.07068 .59754 L
.07104 .60171 L
.07136 .60545 L
.07164 .60915 L
.07189 .61239 L
.07216 .6149 L
.07245 .61702 L
.07276 .61874 L
.07311 .62009 L
.07349 .62112 L
.07386 .62189 L
.07418 .62241 L
.07446 .62287 L
.07469 .6232 L
.07486 .62345 L
.07498 .62362 L
.07507 .62377 L
.07512 .62393 L
.07514 .62418 L
.07517 .62462 L
.07522 .62532 L
.07531 .62629 L
.07545 .6276 L
.07568 .62933 L
.07599 .6315 L
.0764 .63377 L
.07683 .63643 L
.07732 .63981 L
Mistroke
.07788 .64303 L
.07847 .6468 L
.07903 .65065 L
.07958 .65488 L
.0801 .65852 L
.08056 .66223 L
.08093 .66604 L
.08122 .66915 L
.08141 .67225 L
.08153 .67521 L
.08159 .67772 L
.08162 .67997 L
.08165 .68181 L
.08169 .6832 L
.08177 .68421 L
.08189 .68485 L
.08205 .68519 L
.08224 .68531 L
.08247 .68531 L
.08274 .68522 L
.08302 .68507 L
.0833 .68486 L
.08357 .68465 L
.08383 .68446 L
.08406 .68429 L
.08424 .68416 L
.08437 .68407 L
.08444 .68401 L
.08446 .68398 L
.08445 .68399 L
.08441 .68402 L
.08436 .68405 L
.08432 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.0843 .68406 L
.08429 .68402 L
.08426 .68394 L
.08422 .68382 L
Mistroke
.08419 .68372 L
.08417 .68366 L
.08418 .6837 L
.08423 .68386 L
.08433 .68415 L
.08448 .68459 L
.08467 .68515 L
.0849 .68581 L
.08514 .68653 L
.0854 .6873 L
.08566 .68805 L
.08592 .68879 L
.08617 .68951 L
.08639 .69018 L
.08656 .69073 L
.08669 .69114 L
.08676 .69141 L
.0868 .69155 L
.08683 .69163 L
.08687 .69169 L
.08694 .69177 L
.08705 .69193 L
.08721 .69221 L
.08743 .69261 L
.08768 .69309 L
.08795 .69361 L
.08821 .69411 L
.08848 .69462 L
.08874 .69511 L
.08897 .69556 L
.08918 .69596 L
.08935 .69628 L
.08947 .6965 L
.08953 .69662 L
.08956 .69666 L
.08954 .69663 L
.0895 .69656 L
.08946 .69648 L
.08942 .69641 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69637 L
.08941 .69634 L
.08941 .69625 L
.08941 .69613 L
.0894 .69602 L
.08937 .69595 L
Mistroke
.08933 .69594 L
.08929 .696 L
.08926 .69618 L
.08927 .69648 L
.08931 .69693 L
.0894 .69756 L
.08954 .69841 L
.08971 .69948 L
.08992 .70073 L
.09015 .7021 L
.09037 .70361 L
.09057 .70521 L
.09075 .70685 L
.09093 .70839 L
.0911 .70987 L
.09126 .71132 L
.09143 .7128 L
.09159 .71412 L
.09177 .71542 L
.09199 .71672 L
.09226 .71805 L
.0926 .71942 L
.09302 .72081 L
.09352 .72208 L
.09414 .72345 L
.09485 .72491 L
.0956 .72643 L
.09633 .72789 L
.09702 .72927 L
.09763 .73049 L
.09813 .73143 L
.09848 .73209 L
.0987 .73249 L
.09879 .73262 L
.09875 .73252 L
.09861 .73223 L
.09841 .73182 L
.09816 .73134 L
.09788 .73081 L
.09759 .73025 L
.0973 .7297 L
.09703 .7292 L
.09682 .72881 L
.09668 .72857 L
.09661 .72845 L
.09659 .72842 L
.0966 .72845 L
.09664 .72854 L
.09668 .72865 L
.09672 .72871 L
Mistroke
.09674 .7287 L
.09674 .72861 L
.09675 .72846 L
.09675 .72825 L
.09676 .72797 L
.09677 .72761 L
.09677 .72726 L
.09678 .72688 L
.09679 .72648 L
.0968 .72609 L
.09681 .72569 L
.09681 .72532 L
.09682 .72494 L
.09682 .72465 L
.09683 .72437 L
.09684 .72413 L
.09684 .72393 L
.09684 .72382 L
.09685 .72375 L
.09685 .72373 L
.09685 .72374 L
.09685 .72375 L
.09685 .72374 L
.09685 .72374 L
.09685 .72374 L
.09685 .72376 L
.09685 .72378 L
.09685 .72379 L
.09685 .7238 L
.09684 .72382 L
.09685 .72382 L
.09685 .72378 L
.09685 .72371 L
.09685 .7236 L
.09686 .72349 L
.09686 .72341 L
.09687 .72342 L
.09689 .72355 L
.0969 .7238 L
.0969 .72415 L
.09687 .72455 L
.09683 .72497 L
.09677 .72535 L
.09671 .72564 L
.09664 .72585 L
.09658 .72597 L
.09654 .72602 L
.09651 .726 L
.09649 .72591 L
.09649 .72575 L
Mistroke
.09649 .72548 L
.0965 .72513 L
.09653 .72473 L
.09657 .7243 L
.09662 .72391 L
.09668 .7236 L
.09675 .72341 L
.09681 .72335 L
.09686 .72338 L
.0969 .72345 L
.09691 .72353 L
.09691 .72359 L
.09689 .72362 L
.09687 .72363 L
.09686 .72363 L
.09686 .72363 L
.09686 .72365 L
.09686 .72368 L
.09685 .72372 L
.09685 .72375 L
.09685 .72377 L
.09683 .72376 L
.09679 .72371 L
.09673 .72361 L
.09667 .72347 L
.09661 .72328 L
.09657 .72307 L
.09658 .72285 L
.09669 .72264 L
.09691 .72245 L
.09725 .72225 L
.09772 .72203 L
.0983 .72178 L
.09902 .72151 L
.09974 .72121 L
.10056 .72088 L
.10133 .72051 L
.10206 .7201 L
.10279 .71964 L
.10336 .71909 L
.10382 .71842 L
.10414 .71758 L
.10437 .71654 L
.10455 .71529 L
.10467 .71383 L
.10479 .71225 L
.10496 .71053 L
.10522 .70865 L
.10556 .70675 L
.10606 .70479 L
Mistroke
.10677 .70278 L
.10765 .70068 L
.10888 .69858 L
.11008 .69656 L
.11146 .69447 L
.11295 .6924 L
.11447 .69037 L
.11619 .6883 L
.1178 .68631 L
.1194 .68429 L
.12117 .68234 L
.12294 .68041 L
.1247 .67865 L
.12654 .67695 L
.12815 .6753 L
.12986 .67386 L
.13128 .67251 L
.13268 .67136 L
.13377 .67034 L
.13473 .66947 L
.13555 .66873 L
.13615 .6681 L
.1365 .66753 L
.1366 .66696 L
.13647 .6663 L
.13614 .66545 L
.13564 .66434 L
.13502 .66292 L
.13436 .66122 L
.13366 .65922 L
.13295 .65686 L
.13224 .65446 L
.13157 .65179 L
.13093 .6488 L
.13034 .6459 L
.12985 .64287 L
.12946 .63945 L
.12919 .6363 L
.12904 .6327 L
.12901 .62916 L
.12905 .62542 L
.12906 .62169 L
.12912 .61786 L
.12916 .61391 L
.12919 .60962 L
.12921 .60582 L
.12923 .60141 L
.12931 .59695 L
.12953 .59259 L
.12993 .5879 L
Mistroke
.1305 .58328 L
.13124 .57878 L
.13212 .57435 L
.13303 .57052 L
.13408 .5669 L
.13525 .56354 L
.13642 .56053 L
.13766 .55782 L
.1389 .55508 L
.13997 .55271 L
.141 .55032 L
.14194 .5478 L
.14277 .54512 L
.14341 .54227 L
.14389 .53961 L
.14429 .53676 L
.14465 .53343 L
.14498 .53033 L
.14527 .52708 L
.14555 .52347 L
.14586 .51998 L
.14616 .51632 L
.14641 .51256 L
.14661 .50927 L
.14674 .50583 L
.14683 .50252 L
.14691 .4992 L
.14702 .49568 L
.14722 .49232 L
.14751 .48888 L
.14797 .48523 L
.14858 .48159 L
.14935 .47796 L
.15024 .47436 L
.15127 .47102 L
.15242 .46775 L
.15363 .46471 L
.15493 .46185 L
.1562 .45931 L
.15752 .45695 L
.15876 .45486 L
.15999 .45287 L
.16121 .45093 L
.16237 .44899 L
.16356 .44707 L
.16469 .44505 L
.16582 .44299 L
.16693 .44084 L
.16794 .43864 L
.16892 .43635 L
Mistroke
.16983 .4342 L
.17068 .432 L
.17151 .42973 L
.17227 .42761 L
.17303 .42543 L
.1738 .42324 L
.17462 .42103 L
.17549 .41888 L
.17641 .41667 L
.17732 .4145 L
.17833 .41225 L
.17934 .40996 L
.18043 .40754 L
.18149 .40484 L
.18262 .402 L
.1838 .39883 L
.18497 .3954 L
.18625 .39171 L
.18753 .38782 L
.18889 .38368 L
.1903 .37978 L
.19177 .37563 L
.19315 .37177 L
.1946 .36777 L
.19622 .36399 L
.19779 .36062 L
.19953 .3571 L
.20124 .35412 L
.20309 .35115 L
.20495 .34849 L
.20692 .34589 L
.20885 .34356 L
.21087 .34121 L
.21271 .33895 L
.2147 .33671 L
.21675 .33431 L
.21882 .3319 L
.22095 .32934 L
.22311 .32664 L
.22534 .32376 L
.22731 .32093 L
.22927 .31783 L
.23116 .31454 L
.23299 .31097 L
.23473 .30731 L
.23648 .3034 L
.23826 .29924 L
.24002 .29483 L
.24177 .29041 L
.24351 .28582 L
Mistroke
.24521 .28164 L
.24697 .27736 L
.24867 .27328 L
.25043 .26923 L
.25215 .26599 L
.25398 .26279 L
.25592 .25978 L
.25797 .25716 L
.26031 .25462 L
.26279 .25229 L
.26539 .24993 L
.26836 .24761 L
.27143 .24514 L
.27481 .24257 L
.27835 .23981 L
.28202 .23708 L
.28577 .23396 L
.28984 .2308 L
.29384 .22742 L
.29732 .22405 L
.30134 .22052 L
.30498 .21695 L
.3085 .21347 L
.31205 .20989 L
.3156 .2063 L
.31908 .20238 L
.3221 .19879 L
.32538 .19488 L
.32832 .19092 L
.33146 .18686 L
.33411 .18282 L
.33686 .17879 L
.3394 .17471 L
.34202 .17053 L
.34437 .1662 L
.34681 .16172 L
.34921 .15727 L
.35174 .15338 L
.35431 .14872 L
.35706 .14426 L
.36002 .14003 L
.36286 .1352 L
.36646 .13147 L
.36958 .12714 L
.37281 .1232 L
.37633 .11991 L
.37964 .11642 L
.38331 .11295 L
.38625 .1104 L
.38947 .10797 L
Mistroke
.39272 .10572 L
.39559 .10362 L
.39824 .10167 L
.4012 .0997 L
.40365 .09786 L
.40614 .09598 L
.40866 .09406 L
.41069 .09236 L
.41271 .09056 L
.4147 .08866 L
.4163 .08685 L
.41787 .08484 L
.41919 .08302 L
.42034 .08113 L
.42123 .07917 L
.42185 .07735 L
.42228 .07564 L
.42254 .07393 L
.42268 .0723 L
.42273 .07079 L
.42274 .06934 L
.42272 .06801 L
.42269 .0668 L
.42267 .06576 L
.42263 .06493 L
.42259 .06429 L
.42255 .06383 L
.42252 .06354 L
.42251 .06337 L
.4225 .06329 L
.42251 .06327 L
.42252 .06333 L
.42255 .06344 L
.42259 .06359 L
.42262 .06373 L
.42264 .06382 L
.42263 .06381 L
.42258 .06371 L
.42248 .06351 L
.42234 .06321 L
.42216 .06284 L
.42194 .06243 L
.42171 .06203 L
.42146 .06166 L
.42122 .06137 L
.42097 .06115 L
.42073 .06102 L
.42051 .06096 L
.42031 .06099 L
.42016 .06113 L
Mistroke
.42005 .06134 L
.41999 .06163 L
.41997 .062 L
.41999 .06242 L
.42002 .06284 L
.42007 .0632 L
.4201 .06348 L
.42011 .06364 L
.42011 .06372 L
.42011 .06374 L
.42011 .06371 L
.42011 .06367 L
.42011 .06362 L
.42011 .06357 L
.42011 .06355 L
.42011 .06356 L
.42011 .06358 L
.42011 .06359 L
.42011 .06359 L
.42011 .06357 L
.42011 .06353 L
.42011 .06348 L
.42011 .06341 L
.42011 .06334 L
.42011 .06327 L
.42011 .0632 L
.42011 .06314 L
.42011 .06307 L
.42011 .06302 L
.42011 .06298 L
.42011 .06296 L
.42011 .06295 L
.42012 .06298 L
.42013 .06304 L
.42016 .06311 L
.4202 .0632 L
.42023 .06327 L
.42025 .06335 L
.42024 .06343 L
.42019 .06351 L
.42009 .06357 L
.41993 .06358 L
.41972 .06354 L
.41946 .06339 L
.41919 .06312 L
.41892 .06273 L
.41869 .06233 L
.41849 .06189 L
.41835 .06148 L
.41826 .06113 L
Mistroke
.41825 .06089 L
.41831 .06074 L
.41844 .06068 L
.41863 .06073 L
.41886 .06086 L
.41912 .06107 L
.4194 .06133 L
.41967 .06168 L
.41989 .0621 L
.42006 .06256 L
.42017 .063 L
.42024 .06338 L
.42026 .06363 L
.42024 .06377 L
.42021 .0638 L
.42016 .06377 L
.42013 .0637 L
.42012 .06363 L
.42011 .06357 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
Mistroke
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42012 .06353 L
.42014 .06351 L
.42019 .06347 L
.42027 .0634 L
.42034 .06333 L
.42037 .0633 L
.42035 .06334 L
.42025 .06348 L
.42006 .06372 L
.41978 .06403 L
.41942 .06438 L
.41899 .06473 L
.41852 .06503 L
.41803 .06527 L
.41755 .06543 L
.41707 .06552 L
.4166 .06555 L
.41615 .06552 L
.41576 .06542 L
.41545 .06527 L
.41523 .06503 L
.41512 .06473 L
.41511 .06442 L
.41518 .06411 L
.41528 .06384 L
.41539 .06361 L
.41547 .06345 L
.41548 .06334 L
.41542 .06322 L
.4153 .06303 L
.4151 .06273 L
.41484 .06232 L
.41451 .06178 L
.41412 .06116 L
.41369 .06051 L
.41323 .05984 L
.41276 .05915 L
.41229 .05849 L
.41185 .05787 L
.41145 .05733 L
.4111 .05689 L
.41082 .05656 L
Mistroke
.41061 .05634 L
.41047 .05622 L
.41039 .05617 L
.41037 .05616 L
.41038 .05616 L
.41041 .05617 L
.41045 .05619 L
.41049 .05624 L
.41052 .05633 L
.41054 .05645 L
.41054 .05662 L
.41052 .05683 L
.41048 .05707 L
.41042 .05733 L
.41035 .05761 L
.4103 .05786 L
.4103 .05807 L
.41036 .0582 L
.4105 .05822 L
.41074 .05812 L
.41106 .05788 L
.41145 .0575 L
.4119 .057 L
.41238 .05641 L
.41287 .05574 L
.41337 .05505 L
.41385 .05437 L
.41431 .05375 L
.41473 .05319 L
.41507 .05272 L
.41534 .05233 L
.41551 .05205 L
.41559 .05187 L
.41559 .05178 L
.41554 .05177 L
.41547 .0518 L
.4154 .05187 L
.41535 .05194 L
.41533 .05201 L
.41533 .05203 L
.41533 .05204 L
.41534 .05201 L
.41535 .05196 L
.41536 .05189 L
.41536 .05182 L
.41535 .05179 L
.41532 .05181 L
.41529 .05191 L
.41525 .05209 L
.41521 .05236 L
Mistroke
.41518 .0527 L
.41515 .0531 L
.41513 .05355 L
.41512 .05401 L
.41512 .05447 L
.41512 .05493 L
.41513 .05538 L
.41515 .0558 L
.41517 .05617 L
.4152 .05647 L
.41524 .05668 L
.41528 .05679 L
.41532 .05683 L
.41534 .05683 L
.41536 .05681 L
.41537 .05681 L
.41536 .05682 L
.41534 .05682 L
.41533 .0568 L
.41533 .0567 L
.41533 .05652 L
.41533 .05625 L
.41533 .0559 L
.41533 .0555 L
.41533 .05504 L
.41531 .05456 L
.41528 .0541 L
.41524 .05365 L
.41518 .05321 L
.41511 .05279 L
.41504 .05243 L
.41501 .05215 L
.41506 .05197 L
.41522 .05189 L
.41551 .05188 L
.41592 .05192 L
.41646 .052 L
.4171 .05209 L
.41778 .05217 L
.41853 .05221 L
.41929 .05222 L
.42002 .05223 L
.42071 .05226 L
.42133 .05232 L
.42187 .0524 L
.42227 .05247 L
.42257 .05249 L
.42275 .05247 L
.42284 .05238 L
.42286 .05222 L
Mistroke
.42286 .05198 L
.42288 .05164 L
.42295 .05124 L
.42307 .0508 L
.42326 .05035 L
.4235 .04989 L
.42376 .04944 L
.42402 .04897 L
.42427 .0485 L
.4245 .04808 L
.42469 .04773 L
.42484 .04749 L
.42493 .0474 L
.42496 .04746 L
.42492 .04766 L
.42483 .04798 L
.42469 .04838 L
.42457 .04883 L
.4245 .0493 L
.42453 .04977 L
.42469 .05024 L
.42499 .05071 L
.42546 .05118 L
.4261 .05163 L
.4269 .05205 L
.4278 .0524 L
.42885 .05265 L
.42995 .05281 L
.43112 .05286 L
.43231 .05286 L
.43341 .05284 L
.43443 .05283 L
.4353 .05284 L
.43597 .05288 L
.43644 .05295 L
.43669 .05303 L
.43676 .0531 L
.43672 .05319 L
.43661 .05326 L
.43644 .0533 L
.43622 .0533 L
.43593 .05327 L
.43554 .05323 L
.43502 .05313 L
.43435 .05297 L
.43355 .05271 L
.43263 .05237 L
.43159 .05194 L
.4305 .05146 L
.42953 .05093 L
Mistroke
.4285 .05043 L
.42746 .04994 L
.42642 .04946 L
.42531 .04908 L
.42429 .0487 L
.42333 .04835 L
.42246 .04806 L
.42172 .04784 L
.42105 .04769 L
.4204 .04759 L
.41969 .04753 L
.41887 .04749 L
.41791 .04746 L
.41673 .04742 L
.41534 .04736 L
.41374 .04727 L
.41196 .04715 L
.41029 .04703 L
.40838 .04693 L
.40631 .04689 L
.40447 .04693 L
.40254 .04706 L
.40044 .04731 L
.39825 .0477 L
.39605 .04821 L
.39377 .04883 L
.39165 .04954 L
.38952 .05034 L
.38752 .05126 L
.38544 .05228 L
.38336 .05333 L
.38132 .05435 L
.37922 .05536 L
.37725 .05635 L
.37546 .05728 L
.37371 .05819 L
.37202 .05907 L
.37049 .05991 L
.36914 .06071 L
.36792 .06149 L
.36688 .06224 L
.36602 .06292 L
.36531 .06352 L
.36472 .06402 L
.36419 .06443 L
.36366 .06479 L
.36306 .06513 L
.36233 .06549 L
.36144 .06587 L
.36033 .06632 L
Mistroke
.35892 .06689 L
.35716 .06762 L
.3553 .0685 L
.35319 .06957 L
.35063 .07085 L
.34785 .07215 L
.34451 .07382 L
.34161 .0754 L
.33791 .07713 L
.33458 .07892 L
.33054 .08081 L
.32739 .08254 L
.32316 .08444 L
.31997 .0861 L
.31602 .08783 L
.31246 .08959 L
.30855 .09147 L
.30493 .09326 L
.30099 .09529 L
.29735 .0973 L
.29283 .09962 L
.28948 .10173 L
.2848 .1042 L
.28071 .10669 L
.27598 .10935 L
.2725 .11162 L
.26762 .11416 L
.26316 .11675 L
.25975 .11901 L
.25521 .12149 L
.25157 .12373 L
.24708 .12601 L
.24349 .12829 L
.24018 .13028 L
.23631 .13228 L
.23352 .134 L
.23042 .1356 L
.22745 .13708 L
.22507 .13834 L
.22312 .13933 L
.22142 .14016 L
.21989 .14082 L
.2186 .14132 L
.21764 .14165 L
.21698 .14185 L
.21661 .14192 L
.21643 .14191 L
.2164 .14186 L
.21649 .1418 L
.21666 .14175 L
Mistroke
.21679 .14168 L
.21686 .14159 L
.2169 .14145 L
.21695 .14126 L
.21698 .14103 L
.217 .14079 L
.217 .14056 L
.217 .14038 L
.21701 .14026 L
.21701 .14018 L
.21701 .14015 L
.21701 .14015 L
.21701 .14017 L
.21702 .14018 L
.21705 .14024 L
.21709 .14034 L
.21713 .1405 L
.21716 .14071 L
.21716 .14095 L
.21714 .14117 L
.21712 .14137 L
.21708 .14156 L
.21698 .14176 L
.2168 .14206 L
.2165 .14252 L
.21608 .14317 L
.2155 .14406 L
.21478 .14509 L
.21393 .1463 L
.213 .14768 L
.21203 .14916 L
.21106 .15061 L
.21016 .1517 L
.20934 .15312 L
.20856 .1542 L
.20784 .1552 L
.20723 .1561 L
.20676 .15683 L
.20644 .15735 L
.20627 .15766 L
.20621 .1578 L
.20624 .15782 L
.20635 .15773 L
.20647 .1576 L
.20657 .15748 L
.2066 .15741 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.00440917 0.588183 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.20661 .15736 m
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15737 L
.20661 .15738 L
.20661 .15738 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .15729 L
.20661 .15726 L
.20661 .15723 L
.20661 .15721 L
.20661 .15719 L
.20661 .15719 L
.20661 .15718 L
.20661 .15718 L
.20661 .15719 L
.20661 .1572 L
.20661 .15722 L
.20661 .15725 L
.20661 .15728 L
.20661 .15731 L
.20661 .15734 L
Mistroke
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
.20661 .15739 L
.2066 .1574 L
.2066 .15741 L
.2066 .15741 L
.20661 .15739 L
.20661 .15737 L
.20661 .15733 L
.20661 .15729 L
.20661 .15725 L
.20661 .15721 L
.20661 .15718 L
.20661 .15716 L
.20661 .15715 L
.20661 .15715 L
.20661 .15717 L
.20661 .15719 L
.20661 .15724 L
.20661 .15727 L
.20661 .15729 L
.20661 .15728 L
.20661 .15724 L
.20661 .15717 L
.20661 .15708 L
.20661 .15698 L
.20661 .15688 L
.20661 .15678 L
.20661 .15668 L
.20661 .15661 L
.20661 .15657 L
.20661 .15655 L
.20661 .15655 L
.20661 .15658 L
.20661 .15664 L
.20661 .15675 L
.20661 .1569 L
.20661 .15702 L
.20661 .15716 L
.20661 .15728 L
.20661 .15735 L
.20661 .15742 L
.20661 .15745 L
.20661 .15743 L
.20661 .15738 L
.20661 .15733 L
.20661 .15727 L
.20661 .1572 L
.20661 .15712 L
Mistroke
.20661 .15705 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .15731 L
.20661 .15738 L
.20661 .15743 L
.20661 .15745 L
.20661 .15744 L
.20661 .1574 L
.20661 .15735 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15726 L
.20661 .15727 L
.20661 .15729 L
.20661 .1573 L
.20661 .15731 L
.20661 .15732 L
.20661 .15735 L
.20661 .15736 L
.20661 .15735 L
.20661 .1573 L
.20661 .15722 L
.20661 .15712 L
.20661 .15701 L
.20661 .1569 L
.20661 .15682 L
.20661 .15676 L
.20661 .15673 L
.20661 .15672 L
.20661 .15674 L
.20661 .15678 L
.20661 .15681 L
.20661 .15688 L
.20661 .15696 L
.20661 .15704 L
.20661 .15714 L
Mistroke
.20661 .15723 L
.20661 .1573 L
.20661 .15737 L
.20661 .15742 L
.20661 .15746 L
.20661 .15747 L
.20661 .15747 L
.20661 .15745 L
.20661 .15741 L
.20661 .15737 L
.20661 .15731 L
.20661 .15724 L
.20661 .15716 L
.20661 .15709 L
.20661 .15704 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .1573 L
.20661 .15736 L
.20661 .15741 L
.20661 .15743 L
.20661 .15743 L
.20661 .1574 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
.20661 .15738 L
Mistroke
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15727 L
.20661 .15732 L
.20661 .15737 L
.20661 .1574 L
.20661 .15741 L
.20661 .15738 L
.20661 .15734 L
.20661 .15731 L
.20661 .15727 L
.20661 .15723 L
.20661 .15715 L
.20661 .157 L
.20661 .15678 L
.20661 .15649 L
.20661 .15622 L
.20661 .15602 L
.20661 .15585 L
.20661 .15572 L
.20661 .15561 L
.20662 .15552 L
.20662 .15537 L
.20662 .15527 L
.20662 .15512 L
.20662 .15493 L
.20662 .15471 L
.20662 .15449 L
.20662 .15425 L
.20662 .15407 L
.20662 .15388 L
.20662 .15367 L
.20663 .15341 L
.20663 .1531 L
.20663 .1528 L
.20663 .15258 L
.20663 .15249 L
.20663 .15255 L
.20663 .15273 L
Mistroke
.20663 .15298 L
.20663 .15323 L
.20663 .15344 L
.20663 .15358 L
.20662 .15367 L
.20662 .15371 L
.20662 .15371 L
.20662 .15365 L
.20663 .15357 L
.20663 .15346 L
.20663 .15336 L
.20663 .15326 L
.20663 .15317 L
.20663 .15312 L
.20663 .15313 L
.20663 .1532 L
.20663 .1533 L
.20663 .15343 L
.20663 .15358 L
.20662 .15376 L
.20662 .1539 L
.20662 .15399 L
.20662 .15407 L
.20662 .15413 L
.20662 .15418 L
.20662 .15423 L
.20662 .15431 L
.20662 .15443 L
.20662 .15461 L
.20662 .15483 L
.20662 .15509 L
.20662 .15538 L
.20661 .15567 L
.20661 .15588 L
.20661 .15599 L
.20661 .15596 L
.20661 .15583 L
.20661 .15561 L
.20662 .1553 L
.20662 .15493 L
.20662 .15455 L
.20662 .15414 L
.20662 .15374 L
.20663 .15336 L
.20663 .15303 L
.20663 .15277 L
.20663 .15261 L
.20663 .15254 L
.20663 .15252 L
.20663 .15254 L
Mistroke
.20663 .15258 L
.20663 .15264 L
.20663 .15269 L
.20663 .15272 L
.20663 .15272 L
.20663 .1527 L
.20663 .15267 L
.20663 .15263 L
.20663 .15262 L
.20663 .15265 L
.20663 .1527 L
.20663 .15277 L
.20663 .15285 L
.20663 .15295 L
.20663 .15303 L
.20663 .1531 L
.20663 .15316 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .15361 L
.20662 .15372 L
.20662 .15381 L
.20662 .15388 L
.20662 .15393 L
.20662 .15403 L
.20662 .15417 L
.20662 .15437 L
.20662 .1546 L
.20662 .15484 L
.20662 .15507 L
.20662 .15526 L
.20662 .15534 L
.20662 .15532 L
.20662 .15522 L
.20662 .15501 L
.20662 .15476 L
.20662 .15449 L
.20662 .15425 L
.20662 .15401 L
.20662 .1538 L
.20663 .1536 L
.20663 .15343 L
.20663 .15333 L
.20663 .15329 L
.20663 .15331 L
.20663 .15337 L
.20663 .15344 L
.20663 .15352 L
.20663 .1536 L
Mistroke
.20663 .15362 L
.20663 .15361 L
.20663 .15352 L
.20663 .15338 L
.20663 .1532 L
.20663 .15301 L
.20663 .15284 L
.20663 .1527 L
.20663 .15262 L
.20663 .1526 L
.20663 .15264 L
.20663 .15271 L
.20663 .15277 L
.20663 .15278 L
.20663 .15275 L
.20663 .15273 L
.20663 .15277 L
.20663 .15286 L
.20663 .15298 L
.20663 .15314 L
.20663 .1533 L
.20663 .15346 L
.20663 .15359 L
.20662 .15367 L
.20662 .15372 L
.20662 .15372 L
.20662 .15368 L
.20663 .15361 L
.20663 .15359 L
.20663 .15355 L
.20663 .15349 L
.20663 .1534 L
.20663 .1533 L
.20663 .1532 L
.20663 .15311 L
.20663 .15305 L
.20663 .15301 L
.20663 .15302 L
.20663 .15309 L
.20663 .15318 L
.20663 .15326 L
.20663 .15328 L
.20663 .15327 L
.20663 .15323 L
.20663 .15317 L
.20663 .15308 L
.20663 .15298 L
.20663 .15288 L
.20663 .15282 L
.20663 .15279 L
Mistroke
.20663 .15279 L
.20663 .15281 L
.20663 .15282 L
.20663 .15283 L
.20663 .15287 L
.20663 .15294 L
.20663 .15303 L
.20663 .15313 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .1536 L
.20662 .15367 L
.20662 .1537 L
.20662 .1537 L
.20662 .15368 L
.20662 .15363 L
.20663 .15355 L
.20663 .15343 L
.20663 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .1529 L
.20663 .15277 L
.20663 .15267 L
.20663 .15264 L
.20663 .15267 L
.20663 .15275 L
.20663 .15289 L
.20663 .1531 L
.20663 .15341 L
.20662 .15381 L
.20662 .15422 L
.20662 .15464 L
.20662 .155 L
.20662 .15527 L
.20662 .15545 L
.20662 .15555 L
.20662 .15555 L
.20662 .15544 L
.20662 .15523 L
.20662 .15495 L
.20662 .15465 L
.20662 .15428 L
.20662 .15389 L
.20663 .1535 L
.20663 .15316 L
.20663 .1529 L
.20663 .15273 L
.20663 .15263 L
Mistroke
.20663 .15257 L
.20663 .15259 L
.20663 .15268 L
.20663 .15282 L
.20663 .15295 L
.20663 .15306 L
.20663 .15315 L
.20663 .15324 L
.20663 .15332 L
.20663 .15339 L
.20663 .15344 L
.20663 .15348 L
.20663 .1535 L
.20663 .15352 L
.20663 .15352 L
.20663 .15348 L
.20663 .15341 L
.20663 .15329 L
.20663 .15319 L
.20663 .15306 L
.20663 .15294 L
.20663 .15286 L
.20663 .15283 L
.20663 .15285 L
.20663 .1529 L
.20663 .15297 L
.20663 .15303 L
.20663 .15307 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15302 L
.20663 .15305 L
.20663 .15306 L
.20663 .15308 L
.20663 .1531 L
.20663 .15312 L
.20663 .15312 L
.20663 .15311 L
.20663 .1531 L
.20663 .15309 L
.20663 .15308 L
.20663 .15307 L
.20663 .15306 L
.20663 .15307 L
.20663 .15308 L
.20663 .15311 L
.20663 .15314 L
.20663 .15319 L
Mistroke
.20662 .15326 L
.20662 .15334 L
.20662 .15341 L
.20662 .15351 L
.20662 .15361 L
.20662 .15367 L
.20662 .1537 L
.20662 .15369 L
.20662 .15363 L
.20662 .15354 L
.20662 .15343 L
.20662 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .15291 L
.20663 .15282 L
.20663 .15275 L
.20663 .15271 L
.20663 .15271 L
.20663 .15271 L
.20663 .1527 L
.20663 .15269 L
.20663 .15268 L
.20663 .15269 L
.20663 .15271 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
Mistroke
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15269 L
.20663 .15265 L
.20663 .1526 L
.20663 .15255 L
.20663 .15252 L
.20663 .15254 L
.20663 .15261 L
.20663 .15274 L
.20663 .15295 L
.20663 .15321 L
.20663 .15355 L
.20662 .15395 L
.20662 .1544 L
.20662 .15485 L
.20662 .15526 L
.20661 .15562 L
.20661 .15587 L
.20661 .15606 L
.20661 .15617 L
.20661 .15621 L
.20661 .15617 L
.20661 .15604 L
.20661 .15582 L
.20662 .15556 L
.20662 .15527 L
.20662 .15497 L
.20662 .15467 L
.20662 .15442 L
.20662 .15416 L
.20662 .15396 L
.20662 .15384 L
.20662 .15375 L
.20662 .15367 L
.20663 .15362 L
.20663 .15356 L
.20663 .15351 L
.20663 .15343 L
.20663 .15337 L
.20663 .15337 L
.20663 .15345 L
.20663 .15356 L
.20662 .15368 L
.20662 .1538 L
.20662 .15386 L
.20662 .15385 L
Mistroke
.20662 .15378 L
.20662 .15367 L
.20663 .15354 L
.20663 .15341 L
.20663 .15334 L
.20663 .15337 L
.20663 .15348 L
.20662 .1537 L
.20662 .15398 L
.20662 .1543 L
.20662 .15462 L
.20662 .15488 L
.20662 .15509 L
.20662 .15526 L
.20662 .15537 L
.20662 .15541 L
.20662 .15538 L
.20662 .15522 L
.20662 .15496 L
.20662 .15461 L
.20662 .15418 L
.20662 .15369 L
.20663 .1532 L
.20663 .15276 L
.20663 .15243 L
.20663 .15228 L
.20663 .15231 L
.20663 .15249 L
.20663 .15278 L
.20663 .15311 L
.20663 .15345 L
.20662 .15375 L
.20662 .15397 L
.20662 .15412 L
.20662 .15422 L
.20662 .15428 L
.20662 .15432 L
.20662 .15432 L
.20662 .15427 L
.20662 .15414 L
.20662 .15395 L
.20662 .15372 L
.20663 .15347 L
.20663 .1532 L
.20663 .15295 L
.20663 .15279 L
.20663 .15272 L
.20663 .15277 L
.20663 .1529 L
.20663 .15305 L
Mistroke
.20663 .15317 L
.20663 .15327 L
.20663 .15334 L
.20663 .15341 L
.20663 .15345 L
.20663 .15346 L
.20663 .15344 L
.20663 .15341 L
.20663 .1534 L
.20663 .1534 L
.20663 .15345 L
.20663 .15356 L
.20662 .15374 L
.20662 .15396 L
.20662 .15421 L
.20662 .15443 L
.20662 .1546 L
.20662 .15471 L
.20662 .15479 L
.20662 .15487 L
.20662 .15492 L
.20662 .15489 L
.20662 .15481 L
.20662 .15466 L
.20662 .15442 L
.20662 .15411 L
.20662 .15379 L
.20663 .15351 L
.20663 .15329 L
.20663 .15321 L
.20663 .15326 L
.20663 .15341 L
.20663 .15359 L
.20662 .15378 L
.20662 .15394 L
.20662 .15408 L
.20662 .15416 L
.20662 .15419 L
.20662 .15418 L
.20662 .15418 L
.20662 .15416 L
.20662 .15411 L
.20662 .15407 L
.20662 .15399 L
.20662 .1539 L
.20662 .15381 L
.20662 .15376 L
.20662 .15373 L
.20662 .15373 L
.20662 .15372 L
Mistroke
.20662 .15373 L
.20662 .15369 L
.20662 .15361 L
.20662 .15346 L
.20662 .15334 L
.20663 .15321 L
.20663 .15309 L
.20663 .153 L
.20663 .15301 L
.20663 .15313 L
.20663 .15337 L
.20662 .15368 L
.20662 .15406 L
.20662 .15445 L
.20662 .15482 L
.2066 .15509 L
.20657 .15526 L
.20653 .15534 L
.20649 .15531 L
.20648 .15519 L
.20649 .15499 L
.20655 .15472 L
.20665 .15436 L
.2068 .15395 L
.207 .15354 L
.20723 .15316 L
.20749 .15287 L
.20776 .15268 L
.20802 .15258 L
.20828 .15255 L
.20853 .15258 L
.20875 .15266 L
.20893 .15278 L
.20905 .1529 L
.20914 .15299 L
.20921 .15303 L
.20927 .15299 L
.20935 .15287 L
.20947 .15269 L
.20961 .15247 L
.20976 .15224 L
.20994 .15201 L
.21013 .15176 L
.21033 .15149 L
.21052 .15119 L
.21071 .15088 L
.2109 .15054 L
.21109 .1502 L
.21127 .14984 L
.21142 .14952 L
Mistroke
.21152 .14925 L
.21157 .14907 L
.21159 .14891 L
.21161 .14878 L
.21162 .14867 L
.21167 .14856 L
.21173 .14842 L
.2118 .14828 L
.21185 .14816 L
.21188 .14809 L
.21189 .14808 L
.21187 .14812 L
.21184 .14818 L
.21182 .14823 L
.21182 .14824 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
Mistroke
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14824 L
.21182 .14823 L
.21183 .1482 L
.21184 .14818 L
.21184 .14817 L
.21183 .14819 L
.21182 .14824 L
.21179 .14831 L
.21176 .14839 L
.21173 .14847 L
.21171 .14855 L
.21168 .14861 L
.21167 .14866 L
.21166 .14869 L
.21167 .14869 L
.2117 .14868 L
.21174 .14868 L
.21178 .14866 L
.21181 .14863 L
.21182 .14858 L
.21178 .14852 L
.21168 .14845 L
.21154 .14839 L
.21136 .14833 L
.21118 .14829 L
.21102 .14827 L
.21088 .14828 L
.21077 .1483 L
.2107 .14833 L
.21068 .14834 L
.21069 .14833 L
.21073 .14832 L
.21079 .1483 L
.21091 .14828 L
.21108 .14826 L
.21128 .14824 L
.21149 .14822 L
.2117 .14821 L
.21187 .1482 L
.212 .14821 L
.21207 .14822 L
.21207 .14824 L
.21202 .14826 L
.21193 .14828 L
.2118 .14831 L
.21164 .14833 L
Mistroke
.21144 .14835 L
.2112 .14836 L
.21095 .14836 L
.21067 .14836 L
.21039 .14835 L
.21011 .14833 L
.20985 .14828 L
.20963 .14823 L
.20944 .14819 L
.20929 .14817 L
.2092 .14818 L
.20916 .14822 L
.20917 .1483 L
.20921 .14841 L
.20925 .14854 L
.20929 .14867 L
.20932 .14878 L
.20933 .14886 L
.20934 .1489 L
.20933 .14889 L
.20933 .14887 L
.20932 .14888 L
.2093 .1489 L
.20927 .14893 L
.20925 .14893 L
.20923 .14892 L
.20922 .1489 L
.20921 .14889 L
.20921 .14891 L
.20922 .14899 L
.20922 .1491 L
.20923 .1493 L
.20923 .14954 L
.20923 .1498 L
.20923 .15007 L
.20922 .15033 L
.20922 .15056 L
.20922 .1508 L
.20922 .15101 L
.20922 .15123 L
.20922 .15151 L
.20922 .15176 L
.20922 .15205 L
.20922 .1523 L
.20922 .1525 L
.20922 .15259 L
.20922 .15262 L
.20922 .15259 L
.20922 .15254 L
.20922 .15241 L
Mistroke
.20922 .15237 L
.20922 .15234 L
.20922 .15233 L
.20922 .15232 L
.20922 .15232 L
.20922 .15232 L
.20922 .15233 L
.20922 .15236 L
.20922 .15243 L
.20922 .15252 L
.20921 .15262 L
.20921 .15272 L
.20921 .1528 L
.20921 .15286 L
.20921 .15289 L
.20921 .15289 L
.20921 .15286 L
.20921 .15282 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.2092 .1528 L
.20917 .1528 L
.20913 .1528 L
.20909 .1528 L
.20907 .1528 L
.20908 .1528 L
.20915 .1528 L
Mistroke
.20928 .15281 L
.20946 .15281 L
.20969 .15283 L
.20993 .15286 L
.21016 .15287 L
.21038 .15288 L
.21056 .15288 L
.21071 .15288 L
.21081 .15285 L
.21086 .15281 L
.21087 .15276 L
.21081 .15269 L
.21071 .15262 L
.21056 .15253 L
.21037 .15244 L
.21015 .15235 L
.20994 .15227 L
.20976 .15219 L
.20963 .15211 L
.20954 .15205 L
.2095 .152 L
.2095 .15199 L
.20954 .15202 L
.20961 .15207 L
.2097 .15212 L
.20979 .15218 L
.20988 .15223 L
.20996 .15229 L
.21002 .15232 L
.21006 .15237 L
.21007 .15243 L
.21004 .15248 L
.21001 .15252 L
.20996 .15257 L
.2099 .15262 L
.20981 .15265 L
.20971 .15267 L
.20959 .15269 L
.20947 .15271 L
.20935 .15272 L
.20925 .15274 L
.20917 .15276 L
.20912 .15279 L
.20911 .15281 L
.20913 .15283 L
.20917 .15284 L
.2092 .15283 L
.20921 .15282 L
.20921 .15281 L
.20921 .1528 L
Mistroke
.20921 .15281 L
.20921 .15281 L
.20921 .15283 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
.20921 .15279 L
.20921 .15276 L
.20921 .15274 L
.20921 .15272 L
.20921 .1527 L
.20921 .15267 L
.20921 .15265 L
.20921 .15262 L
.20922 .15258 L
.20922 .15253 L
.20922 .15248 L
.20922 .15242 L
.20922 .15237 L
.20922 .15233 L
.20922 .15231 L
.20922 .15231 L
.20922 .15231 L
.20922 .15233 L
.20922 .15236 L
.20922 .1524 L
.20922 .15241 L
.20922 .15246 L
.20922 .15252 L
.20921 .1526 L
.20921 .15267 L
.20921 .15274 L
.20921 .15279 L
.20921 .15282 L
.20921 .15284 L
.20921 .15284 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
.20921 .15281 L
.20921 .15281 L
.2092 .15282 L
.20919 .15284 L
.20918 .15286 L
.20916 .15289 L
.20914 .15292 L
.20913 .15295 L
.20913 .15296 L
.20915 .15292 L
.2092 .15283 L
Mistroke
.2093 .15266 L
.20944 .15241 L
.20962 .15209 L
.20984 .15171 L
.21008 .15128 L
.21033 .15085 L
.21059 .15039 L
.21084 .14996 L
.21108 .14953 L
.21131 .14913 L
.21153 .14876 L
.21171 .14844 L
.21185 .14819 L
.21193 .14805 L
.21196 .148 L
.21194 .14803 L
.21187 .14813 L
.21179 .14827 L
.21169 .14843 L
.21161 .14857 L
.21154 .14866 L
.2115 .14871 L
.21148 .14873 L
.21147 .14875 L
.21147 .14876 L
.21147 .14878 L
.21149 .14879 L
.21152 .14877 L
.21157 .14873 L
.21163 .14866 L
.21169 .14859 L
.21176 .14851 L
.21183 .14843 L
.2119 .14837 L
.21196 .14834 L
.21199 .14834 L
.21199 .14836 L
.21196 .14837 L
.21189 .14836 L
.21179 .14832 L
.21163 .14828 L
.21142 .14824 L
.21117 .14821 L
.21091 .14817 L
.21066 .14814 L
.21042 .14813 L
.21019 .14814 L
.20998 .14814 L
.20979 .14813 L
.20963 .14813 L
Mistroke
.20951 .14817 L
.20941 .14826 L
.20933 .14837 L
.20929 .1485 L
.20928 .14863 L
.2093 .14877 L
.20934 .1489 L
.20939 .14901 L
.20943 .14911 L
.20949 .14917 L
.20959 .14919 L
.20976 .14914 L
.20998 .14906 L
.21023 .14894 L
.21048 .14882 L
.21071 .14875 L
.21092 .14874 L
.21104 .14883 L
.2111 .14898 L
.21109 .1492 L
.21103 .14946 L
.21094 .14973 L
.21083 .15001 L
.21071 .15027 L
.21059 .15048 L
.21051 .1506 L
.21046 .15065 L
.21046 .15064 L
.21051 .15053 L
.21062 .15036 L
.21079 .15008 L
.21101 .14971 L
.21122 .14935 L
.21144 .14897 L
.21163 .14865 L
.21176 .1484 L
.21184 .14826 L
.21188 .14817 L
.21191 .14809 L
.21194 .14802 L
.21198 .14796 L
.212 .14795 L
.21198 .14799 L
.21192 .1481 L
.2118 .14827 L
.21164 .1485 L
.21144 .14878 L
.21121 .14912 L
.21095 .1495 L
.21068 .14992 L
Mistroke
.21042 .15036 L
.21015 .1508 L
.20989 .15123 L
.20965 .15168 L
.20943 .15199 L
.20927 .15231 L
.20915 .15256 L
.20908 .15273 L
.20906 .15283 L
.20908 .15288 L
.20912 .15288 L
.20916 .15288 L
.20919 .15287 L
.20921 .15287 L
.20921 .15287 L
.20921 .15285 L
.20921 .15283 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20922 .1528 L
.20924 .15276 L
.20931 .15266 L
.20943 .1525 L
.20959 .15229 L
.20976 .15206 L
.20992 .15185 L
.21002 .15173 L
.21 .15176 L
.20981 .15201 L
.20938 .15256 L
.20864 .15351 L
.20756 .1549 L
.20605 .15679 L
.20427 .15908 L
.20215 .16199 L
.19947 .16541 L
.19663 .16937 L
.19315 .1739 L
.18919 .17905 L
.18555 .18453 L
.18134 .19029 L
.1764 .19694 L
.17219 .2029 L
.16753 .20955 L
.16222 .21655 L
.15685 .22399 L
.15265 .2305 L
.14734 .23765 L
.14164 .24496 L
.13711 .25201 L
.1316 .25897 L
.12676 .26561 L
.12232 .27264 L
.1176 .27931 L
.11307 .28561 L
.10937 .29218 L
Mistroke
.1054 .29847 L
.10246 .30458 L
.09955 .31089 L
.09698 .3167 L
.09469 .32311 L
.09276 .32863 L
.09107 .33454 L
.08958 .34106 L
.08823 .34645 L
.087 .35286 L
.08597 .35839 L
.08498 .36423 L
.08409 .36991 L
.08326 .37516 L
.0825 .37981 L
.08183 .38449 L
.08126 .38811 L
.08078 .39161 L
.0804 .39465 L
.08013 .39699 L
.07996 .39885 L
.07988 .40015 L
.07986 .40095 L
.07988 .40133 L
.07992 .4014 L
.07997 .40124 L
.08002 .40095 L
.08007 .40065 L
.08009 .4004 L
.0801 .40024 L
.0801 .40015 L
.08009 .4001 L
.08006 .40006 L
.08001 .40002 L
.07997 .39999 L
.07995 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08072 .40066 L
.08098 .40089 L
.08126 .40114 L
.08151 .40139 L
.08175 .40164 L
.08198 .40188 L
.08218 .4021 L
.08236 .40229 L
.08252 .40244 L
Mistroke
.08265 .40255 L
.08279 .40261 L
.08296 .40263 L
.08316 .40261 L
.08342 .40257 L
.08376 .40251 L
.08418 .40245 L
.08468 .40242 L
.08524 .40242 L
.0858 .40244 L
.08631 .40247 L
.08676 .40252 L
.08712 .40257 L
.08741 .40259 L
.08759 .40257 L
.08768 .40253 L
.08768 .40248 L
.08764 .40243 L
.08759 .4024 L
.08755 .40244 L
.08754 .40254 L
.08757 .40273 L
.08764 .40304 L
.0878 .40348 L
.08806 .40406 L
.08843 .40477 L
.08888 .40555 L
.08939 .40641 L
.08994 .40733 L
.0905 .40827 L
.09107 .40921 L
.09159 .41011 L
.09207 .41102 L
.09247 .41195 L
.09284 .41296 L
.09314 .41412 L
.09334 .41551 L
.09343 .41723 L
.09338 .41926 L
.09316 .42179 L
.0927 .42463 L
.09194 .42808 L
.09088 .4318 L
.08951 .43566 L
.08777 .44023 L
.0859 .44459 L
.0838 .44949 L
.08139 .45394 L
.0791 .45884 L
.07656 .46389 L
Mistroke
.07447 .46857 L
.07216 .47334 L
.07007 .47801 L
.06833 .48294 L
.06657 .48814 L
.06499 .49395 L
.06393 .49916 L
.06314 .50458 L
.06265 .50957 L
.06243 .51553 L
.06245 .52162 L
.0627 .52878 L
.06317 .53423 L
.06375 .54112 L
.06449 .5471 L
.06535 .55307 L
.06619 .55885 L
.06711 .56474 L
.06789 .57046 L
.06863 .57518 L
.06932 .58008 L
.06986 .58459 L
.07029 .5886 L
.07059 .59251 L
.07075 .59552 L
.0708 .59838 L
.07076 .60081 L
.07066 .60287 L
.07055 .60454 L
.07046 .60583 L
.07042 .60688 L
.07044 .60767 L
.07052 .60823 L
.07066 .60854 L
.07086 .60865 L
.0711 .60856 L
.07133 .60836 L
.07157 .60808 L
.07178 .60776 L
.07197 .60749 L
.07213 .60733 L
.07225 .60733 L
.07235 .60751 L
.07239 .60793 L
.07242 .60863 L
.07248 .60971 L
.0726 .61118 L
.07276 .61322 L
.07302 .61591 L
.07342 .61895 L
Mistroke
.07394 .62277 L
.07454 .62717 L
.07526 .63181 L
.0761 .6381 L
.07697 .64326 L
.07802 .6495 L
.07902 .65708 L
.08023 .66349 L
.08135 .67051 L
.0826 .67721 L
.08396 .68377 L
.08513 .69112 L
.08632 .6966 L
.08754 .70276 L
.08867 .70748 L
.08981 .71239 L
.09075 .71582 L
.09165 .71874 L
.09249 .72127 L
.09314 .72308 L
.09366 .72419 L
.09405 .72479 L
.09429 .72501 L
.0944 .72499 L
.09444 .7248 L
.09442 .72451 L
.09437 .72419 L
.09431 .72395 L
.09425 .72383 L
.0942 .72378 L
.09416 .72375 L
.09415 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09416 .72375 L
.09419 .72378 L
.09423 .72382 L
.09427 .72386 L
.09429 .72388 L
.09427 .72386 L
.09422 .72381 L
.09411 .72371 L
.09396 .72357 L
.09375 .72339 L
.09352 .72318 L
.09326 .72294 L
.09298 .72269 L
.09271 .72244 L
Mistroke
.09244 .72219 L
.09218 .72195 L
.09193 .72173 L
.09172 .72153 L
.09154 .72138 L
.09142 .72127 L
.09136 .72121 L
.09133 .72119 L
.09134 .72119 L
.09135 .7212 L
.09135 .7212 L
.09134 .7212 L
.09134 .72119 L
.09135 .72121 L
.09141 .72126 L
.09152 .72136 L
.09167 .7215 L
.09187 .72168 L
.09211 .72189 L
.09237 .72213 L
.09264 .72238 L
.09291 .72263 L
.09318 .72288 L
.09345 .72312 L
.09369 .72335 L
.09391 .72354 L
.09408 .72369 L
.0942 .7238 L
.09427 .72386 L
.09429 .72388 L
.09428 .72386 L
.09424 .72383 L
.09419 .72379 L
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .72291 L
.09417 .72264 L
.09417 .72238 L
.09418 .72212 L
.09419 .72187 L
.09419 .72164 L
.0942 .72143 L
.0942 .72127 L
.09421 .72117 L
.09422 .72113 L
.09425 .72117 L
.09429 .72126 L
.09433 .72137 L
.09435 .72145 L
.09433 .72146 L
.09428 .72137 L
.09417 .72118 L
.09402 .72089 L
.09382 .72052 L
.09359 .72008 L
.09334 .7196 L
.09307 .71909 L
.09281 .71858 L
.09254 .71808 L
.09229 .71759 L
.09205 .71713 L
.09183 .71674 L
.09167 .71642 L
.09155 .7162 L
.09149 .71607 L
Mistroke
.09148 .71605 L
.09153 .7161 L
.0916 .71618 L
.09168 .71626 L
.09174 .71631 L
.09174 .71633 L
.09169 .71634 L
.09159 .71635 L
.09143 .71635 L
.09122 .71634 L
.09098 .71629 L
.09072 .71619 L
.09045 .71604 L
.09018 .71581 L
.08991 .71553 L
.08966 .71518 L
.08943 .71479 L
.08923 .71437 L
.08906 .71395 L
.08894 .71351 L
.08882 .71305 L
.08876 .71266 L
.08875 .71226 L
.08878 .71192 L
.08884 .71163 L
.08893 .71141 L
.08905 .71128 L
.0892 .71123 L
.08941 .71123 L
.08965 .71125 L
.08991 .71128 L
.09018 .7113 L
.09046 .71131 L
.09074 .71132 L
.09101 .71133 L
.09126 .71132 L
.09149 .71131 L
.09167 .71131 L
.09179 .7113 L
.09186 .7113 L
.09189 .7113 L
.09187 .7113 L
.09183 .7113 L
.09179 .7113 L
.09175 .71128 L
.09174 .71122 L
.09174 .71115 L
.09174 .71109 L
.09174 .71106 L
.09174 .71109 L
Mistroke
.09174 .71119 L
.09173 .71135 L
.09173 .71158 L
.09172 .71189 L
.09171 .71227 L
.0917 .71269 L
.09169 .71316 L
.09168 .71364 L
.09167 .71412 L
.09165 .7146 L
.09164 .71509 L
.09163 .71548 L
.09162 .71584 L
.09162 .71612 L
.09161 .71631 L
.09161 .71641 L
.09161 .71645 L
.09161 .71644 L
.09161 .71641 L
.09161 .71639 L
.09161 .71638 L
.09161 .71637 L
.09161 .71636 L
.09161 .71634 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09159 .71632 L
.09156 .71632 L
.09152 .71632 L
.09148 .71632 L
.09146 .71633 L
.09148 .71632 L
.09153 .71632 L
.09164 .71632 L
.0918 .71631 L
.09201 .7163 L
.09225 .71629 L
.09251 .71628 L
.09279 .71627 L
.09307 .71626 L
.09334 .71625 L
.09361 .71624 L
.09386 .71623 L
.09408 .71622 L
.09426 .71622 L
.09439 .71621 L
.09445 .71621 L
.09448 .71621 L
Mistroke
.09446 .71621 L
.09442 .71621 L
.09438 .71621 L
.09434 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71622 L
.09433 .71624 L
.09433 .7163 L
.09433 .71638 L
.09433 .71645 L
.09432 .71649 L
.09432 .71647 L
.09431 .71636 L
.09431 .71616 L
.09431 .71587 L
.09431 .71549 L
.09432 .71504 L
.09432 .71455 L
.09433 .71404 L
.09435 .71352 L
.09436 .71301 L
.09437 .71251 L
.09439 .71205 L
.0944 .71164 L
.09442 .71131 L
.09443 .71108 L
.09445 .71095 L
.09445 .71091 L
.09446 .71094 L
.09446 .71101 L
.09446 .7111 L
Mistroke
.09446 .71116 L
.09445 .71119 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .71122 L
.09445 .71125 L
.09445 .71129 L
.09445 .71139 L
.09444 .71155 L
.09444 .71174 L
.09444 .71189 L
.09445 .71196 L
.09449 .71189 L
.09454 .71161 L
.09461 .71107 L
.09471 .71023 L
.09481 .70907 L
.09487 .70765 L
.09488 .70583 L
.09481 .70363 L
.09461 .7014 L
.09428 .69879 L
.0938 .69605 L
.09313 .6929 L
.0924 .6895 L
.09143 .68631 L
.09027 .68267 L
.08915 .6794 L
.08808 .6759 L
.08678 .67248 L
Mistroke
.08533 .66906 L
.08415 .66578 L
.08302 .66249 L
.08188 .65914 L
.0809 .65608 L
.08007 .65299 L
.07935 .6504 L
.07878 .64789 L
.07837 .64574 L
.07806 .64383 L
.07784 .64222 L
.07768 .64081 L
.07755 .6396 L
.07746 .63859 L
.07737 .6377 L
.07726 .63687 L
.07714 .63604 L
.07698 .63514 L
.07679 .63411 L
.07656 .63296 L
.07629 .63153 L
.07596 .62992 L
.07558 .62798 L
.07516 .62579 L
.07473 .62329 L
.0743 .6203 L
.07391 .61752 L
.07354 .61426 L
.07317 .61075 L
.0728 .60742 L
.0724 .60366 L
.07196 .59946 L
.07148 .59576 L
.07094 .59148 L
.07034 .58685 L
.06969 .5826 L
.06899 .57774 L
.06837 .57286 L
.06761 .56804 L
.0669 .5623 L
.06615 .55718 L
.06542 .55156 L
.06478 .54522 L
.06418 .53976 L
.06365 .53381 L
.06325 .52769 L
.06297 .52169 L
.06283 .515 L
.06282 .51005 L
.06293 .50465 L
Mistroke
.06315 .49897 L
.06346 .49488 L
.06383 .49085 L
.06424 .48718 L
.06467 .48415 L
.06509 .48161 L
.06548 .47983 L
.06583 .47845 L
.06614 .47746 L
.06639 .47686 L
.06658 .47658 L
.06672 .47653 L
.06679 .47664 L
.06681 .47682 L
.06679 .47705 L
.06675 .47734 L
.06669 .47763 L
.06664 .47788 L
.06661 .47805 L
.06659 .47808 L
.06657 .47794 L
.06654 .4776 L
.06652 .477 L
.06653 .4761 L
.06659 .47488 L
.0667 .47334 L
.06686 .47179 L
.06709 .46985 L
.06737 .46793 L
.06768 .46574 L
.06802 .46386 L
.06837 .46198 L
.0687 .46019 L
.06904 .45862 L
.06935 .45739 L
.06963 .45644 L
.06987 .45579 L
.07006 .45542 L
.07019 .45525 L
.07026 .45523 L
.07028 .45529 L
.07026 .45538 L
.07022 .45547 L
.07017 .45554 L
.07014 .45559 L
.07012 .45563 L
.07012 .45562 L
.07012 .45559 L
.07012 .45557 L
.07012 .45555 L
Mistroke
.07013 .45554 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .4556 L
.07015 .45562 L
.07019 .45566 L
.07024 .4557 L
.07026 .45572 L
.07026 .45571 L
.07022 .45565 L
.07013 .45556 L
.06998 .45542 L
.06979 .45524 L
.06955 .45503 L
.06927 .4548 L
.06896 .45455 L
.06862 .4543 L
.06835 .45405 L
.06806 .45381 L
.06782 .45359 L
.06764 .4534 L
.06756 .45325 L
.06759 .45314 L
.06773 .45307 L
.06795 .45305 L
Mistroke
.06822 .45306 L
.06854 .45309 L
.06887 .45313 L
.06919 .45316 L
.06949 .45317 L
.06975 .45317 L
.06997 .45316 L
.07015 .45316 L
.07027 .45316 L
.07034 .45316 L
.07036 .45316 L
.07035 .45316 L
.07031 .45316 L
.07026 .45316 L
.07022 .45316 L
.0702 .45316 L
.07019 .45314 L
.07016 .45312 L
.07011 .45308 L
.07008 .45304 L
.07005 .45302 L
.07007 .45303 L
.07012 .45309 L
.07023 .45318 L
.07039 .45332 L
.07059 .4535 L
.07082 .45371 L
.07108 .45395 L
.07136 .4542 L
.07161 .45445 L
.07182 .45471 L
.07199 .45498 L
.07214 .45524 L
.07227 .45547 L
.07238 .45564 L
.07248 .45575 L
.07264 .45579 L
.07289 .45577 L
.07329 .45571 L
.07387 .45561 L
.07465 .45547 L
.07566 .45526 L
.07673 .45495 L
.07802 .45453 L
.07947 .45398 L
.08094 .45332 L
.08248 .45253 L
.08401 .45162 L
.08525 .45056 L
.08643 .44939 L
Mistroke
.0875 .44803 L
.08837 .44641 L
.08909 .44468 L
.08966 .44266 L
.09011 .44044 L
.09049 .43786 L
.09082 .43519 L
.09112 .43212 L
.09138 .42863 L
.09158 .42492 L
.09173 .42065 L
.09186 .4159 L
.09196 .41074 L
.09205 .40427 L
.09211 .39871 L
.09214 .39212 L
.09214 .38592 L
.09211 .37943 L
.09207 .37271 L
.09203 .36532 L
.09201 .35947 L
.09201 .35327 L
.09208 .34684 L
.09222 .34156 L
.0924 .33704 L
.09261 .33254 L
.0928 .32899 L
.09294 .32592 L
.09303 .32365 L
.09306 .32181 L
.09307 .3205 L
.09306 .31957 L
.09306 .319 L
.09309 .3187 L
.09317 .31859 L
.09328 .31862 L
.09343 .31874 L
.0936 .3189 L
.09379 .31905 L
.09402 .31911 L
.09429 .319 L
.09463 .31865 L
.09504 .31801 L
.09556 .31711 L
.09618 .31597 L
.09691 .3146 L
.09776 .31302 L
.09861 .31146 L
.09957 .30972 L
.10059 .30807 L
Mistroke
.10154 .30646 L
.10257 .30496 L
.10352 .30364 L
.10445 .30253 L
.10531 .30153 L
.10604 .30068 L
.10665 .29998 L
.10711 .29944 L
.1074 .29907 L
.10754 .29881 L
.10753 .29865 L
.10741 .29857 L
.10721 .29857 L
.10694 .29862 L
.10664 .29867 L
.10633 .29868 L
.10605 .29877 L
.10583 .29884 L
.10563 .29899 L
.1054 .29918 L
.10512 .2994 L
.1048 .29965 L
.10442 .29993 L
.10399 .30024 L
.10349 .30058 L
.10296 .30095 L
.10242 .3014 L
.1019 .30193 L
.10138 .30253 L
.10091 .30318 L
.10047 .30383 L
.09996 .30446 L
.09951 .30506 L
.09913 .30565 L
.09884 .30623 L
.09861 .30679 L
.09841 .30733 L
.09826 .30783 L
.09816 .3083 L
.09808 .30875 L
.09798 .30917 L
.09783 .30959 L
.09769 .30998 L
.09759 .3104 L
.09755 .31086 L
.09758 .31134 L
.09768 .3118 L
.09786 .31219 L
.09812 .31248 L
.09845 .31265 L
Mistroke
.09882 .31267 L
.09921 .31254 L
.09962 .31227 L
.10001 .31187 L
.1004 .31135 L
.10081 .3107 L
.10124 .30989 L
.10173 .30895 L
.10228 .30785 L
.10289 .30657 L
.10354 .30511 L
.10425 .3036 L
.10505 .3019 L
.10596 .30006 L
.10698 .29798 L
.1082 .29589 L
.10954 .29349 L
.11109 .29097 L
.11277 .2884 L
.11464 .28535 L
.11655 .28247 L
.11857 .27936 L
.12082 .27579 L
.12289 .2727 L
.12516 .26921 L
.12742 .26581 L
.12974 .26228 L
.13199 .25877 L
.13442 .25534 L
.13662 .25179 L
.139 .24852 L
.14137 .24507 L
.14386 .24159 L
.14638 .23803 L
.14922 .23419 L
.15175 .23068 L
.1546 .22686 L
.15743 .22294 L
.16031 .21895 L
.16324 .21509 L
.16618 .21102 L
.16929 .2066 L
.17202 .20282 L
.17486 .19872 L
.17765 .19465 L
.1805 .1904 L
.18301 .18681 L
.18557 .18306 L
.1882 .17913 L
.19056 .17588 L
Mistroke
.193 .17244 L
.1954 .16922 L
.19773 .16604 L
.19997 .16311 L
.20209 .16031 L
.20421 .15763 L
.20615 .15494 L
.20819 .15248 L
.21027 .14995 L
.2125 .14752 L
.21476 .14517 L
.2171 .14274 L
.21968 .14076 L
.22224 .13879 L
.22495 .13706 L
.22719 .13547 L
.22965 .13395 L
.23179 .13274 L
.23386 .13164 L
.23581 .13065 L
.23733 .12978 L
.23861 .12903 L
.2396 .12841 L
.24028 .12792 L
.24068 .12755 L
.24088 .1272 L
.24093 .12688 L
.2409 .12658 L
.24081 .1263 L
.24064 .12606 L
.24041 .12589 L
.24013 .12579 L
.23981 .12576 L
.23944 .12576 L
.23903 .12576 L
.23856 .12574 L
.23805 .12571 L
.23748 .12567 L
.23692 .12568 L
.23627 .12575 L
.2356 .12592 L
.23495 .12617 L
.23437 .1265 L
.23389 .1269 L
.23354 .12735 L
.23333 .12782 L
.23324 .1283 L
.23325 .12879 L
.23332 .12929 L
.23343 .12976 L
Mistroke
.23355 .13015 L
.23366 .13046 L
.2338 .13067 L
.23396 .13078 L
.23412 .13079 L
.23426 .13071 L
.23438 .13056 L
.23449 .13036 L
.23457 .13015 L
.23471 .12992 L
.235 .12964 L
.23551 .12931 L
.23629 .12889 L
.23738 .12833 L
.23888 .12768 L
.24082 .12686 L
.24334 .12586 L
.24603 .12466 L
.24923 .12321 L
.25309 .12148 L
.25738 .11963 L
.26188 .11735 L
.26599 .11494 L
.27098 .11216 L
.27629 .1092 L
.28207 .10599 L
.28771 .10266 L
.29413 .09921 L
.29937 .09607 L
.30541 .09274 L
.31122 .08987 L
.31649 .08691 L
.32228 .08389 L
.32653 .08165 L
.33108 .07956 L
.33472 .07769 L
.33806 .07612 L
.34063 .07484 L
.34275 .0739 L
.34426 .07318 L
.34523 .07267 L
.34578 .07231 L
.34603 .07209 L
.34603 .07198 L
.34589 .07195 L
.34571 .07197 L
.34554 .072 L
.34539 .07207 L
.34528 .07215 L
.34521 .07223 L
Mistroke
.34517 .07228 L
.34514 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
Mistroke
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34515 .07229 L
.3452 .07225 L
.34528 .07219 L
.34534 .07215 L
.34536 .07214 L
.34533 .07219 L
.34523 .07229 L
.34506 .07245 L
.34479 .07264 L
.34444 .07287 L
.34402 .07312 L
.34356 .07333 L
.34311 .07348 L
.34268 .07358 L
.34229 .07365 L
.34192 .07372 L
.34159 .07382 L
.34131 .07392 L
.34109 .07406 L
.34093 .07419 L
.34083 .07432 L
.34078 .07449 L
.34078 .07465 L
.34079 .07484 L
.34081 .07503 L
.34079 .07532 L
.34071 .07567 L
.3406 .07603 L
.34049 .07635 L
.34037 .0766 L
.34027 .07677 L
.34018 .07688 L
.34012 .07691 L
.3401 .0769 L
.34013 .07685 L
.34016 .07678 L
.34019 .07674 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
Mistroke
.34021 .07671 L
.34021 .07671 L
.3402 .07673 L
.34017 .07678 L
.34013 .07685 L
.34009 .07692 L
.34007 .07695 L
.34008 .07694 L
.34011 .07685 L
.34018 .07669 L
.34028 .07645 L
.3404 .07615 L
.34053 .07582 L
.34064 .07548 L
.34076 .07512 L
.34089 .07473 L
.34105 .07432 L
.34128 .07386 L
.34168 .07335 L
.34231 .07278 L
.3433 .07213 L
.34476 .07137 L
.3467 .07051 L
.34921 .06953 L
.35209 .06852 L
.35513 .06736 L
.35847 .06608 L
.3625 .06466 L
.36589 .06313 L
.36968 .06155 L
.37326 .05993 L
.37618 .05855 L
.3797 .05719 L
.38225 .05603 L
.38459 .05493 L
.38657 .05396 L
.38807 .05313 L
.38918 .05242 L
.39021 .05175 L
.39116 .05112 L
.39212 .05053 L
.39312 .04996 L
.39415 .04943 L
.39511 .04892 L
.39614 .0485 L
.39711 .04812 L
.39804 .04778 L
.39895 .04748 L
.39981 .04722 L
.40063 .04702 L
Mistroke
.40144 .04688 L
.40229 .04682 L
.40321 .04683 L
.40429 .0469 L
.40559 .04702 L
.4072 .04715 L
.40917 .04727 L
.41148 .04737 L
.41412 .04746 L
.417 .04757 L
.42017 .04767 L
.42342 .04779 L
.42641 .0479 L
.4298 .048 L
.43255 .04811 L
.43538 .04821 L
.43812 .04829 L
.44034 .04837 L
.44227 .04843 L
.44376 .04848 L
.44489 .04852 L
.4457 .04854 L
.44627 .04856 L
.4467 .04857 L
.44718 .04858 L
.4478 .0486 L
.44867 .04863 L
.44991 .04868 L
.45167 .04875 L
.45388 .04883 L
.4567 .04893 L
.45967 .04904 L
.46352 .04917 L
.46735 .0493 L
.47187 .04941 L
.47664 .04951 L
.48071 .04958 L
.4854 .04964 L
.49028 .04969 L
.49498 .04974 L
.49948 .0498 L
.50369 .04986 L
.50798 .04994 L
.51165 .05003 L
.51555 .05014 L
.51943 .05026 L
.52319 .05039 L
.5273 .05055 L
.53113 .05073 L
.53502 .05093 L
Mistroke
.53911 .05113 L
.54306 .05132 L
.54722 .05151 L
.55176 .05167 L
.55575 .05181 L
.56022 .05192 L
.56448 .05197 L
.56869 .05199 L
.57252 .05201 L
.5762 .05206 L
.57977 .05217 L
.58278 .05233 L
.58546 .05257 L
.58791 .05289 L
.58996 .05328 L
.59161 .05371 L
.59297 .05418 L
.59403 .05466 L
.59489 .05512 L
.5956 .05558 L
.59622 .05602 L
.59676 .05644 L
.59729 .05682 L
.59785 .05712 L
.59843 .05733 L
.59903 .05746 L
.59965 .05751 L
.60028 .0575 L
.60088 .05746 L
.60144 .0574 L
.60194 .05735 L
.60238 .05734 L
.60274 .05734 L
.60304 .05735 L
.60327 .05736 L
.60346 .05736 L
.6036 .05736 L
.60369 .05737 L
.60375 .05737 L
.60378 .05737 L
.60378 .05737 L
.60376 .05737 L
.60373 .05737 L
.60369 .05737 L
.60366 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
Mistroke
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05736 L
.60364 .05735 L
.60364 .05731 L
.60362 .05726 L
.60358 .05721 L
.60352 .05717 L
.60345 .05717 L
.6034 .05722 L
.6034 .05734 L
.60346 .05752 L
.6036 .05778 L
.60382 .05812 L
.6041 .05851 L
.60445 .05894 L
.60483 .05939 L
.60525 .05982 L
.60569 .06028 L
.60619 .06067 L
.6067 .06108 L
.60723 .06143 L
.60775 .06172 L
.60825 .06191 L
.6087 .06202 L
.60909 .06206 L
.60941 .06206 L
.60965 .06202 L
.60984 .06198 L
.61 .06195 L
.61014 .06194 L
.61028 .06193 L
.6104 .06192 L
.6105 .06192 L
.61055 .06193 L
.61057 .06193 L
.61055 .06193 L
.61052 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61045 .06193 L
Mistroke
.6105 .06195 L
.61057 .062 L
.61064 .06207 L
.61068 .06213 L
.61066 .06216 L
.61057 .06214 L
.6104 .06204 L
.61014 .06186 L
.60979 .0616 L
.60939 .06126 L
.60895 .06086 L
.60851 .06041 L
.60808 .05996 L
.60773 .0595 L
.60733 .05906 L
.60693 .05862 L
.60653 .0582 L
.60613 .05783 L
.60575 .05753 L
.60536 .05732 L
.60498 .0572 L
.6046 .05715 L
.60423 .05716 L
.60385 .05721 L
.60345 .05728 L
.603 .05732 L
.60255 .05733 L
.60213 .05733 L
.60176 .05732 L
.60147 .05731 L
.60127 .05731 L
.60115 .05731 L
.60112 .05731 L
.60115 .05731 L
.60121 .05733 L
.60129 .05736 L
.60136 .05739 L
.60141 .05739 L
.60146 .05736 L
.60149 .05731 L
.60152 .05724 L
.60156 .05718 L
.60159 .05715 L
.60162 .05716 L
.6016 .05716 L
.60154 .05712 L
.60138 .057 L
.60108 .05682 L
.60062 .05656 L
.59997 .05626 L
Mistroke
.59915 .05591 L
.59816 .05554 L
.597 .05515 L
.59567 .05476 L
.59435 .0544 L
.59289 .05401 L
.59129 .05362 L
.58953 .05324 L
.58798 .05287 L
.58644 .05256 L
.58494 .05238 L
.58353 .05231 L
.58229 .05231 L
.5813 .05234 L
.58047 .05238 L
.5798 .05238 L
.57927 .05232 L
.57886 .0522 L
.57856 .05203 L
.57837 .05182 L
.57828 .0516 L
.57827 .05137 L
.57833 .05114 L
.57843 .05091 L
.57854 .0507 L
.57862 .05049 L
.57865 .05032 L
.57866 .05017 L
.57866 .05006 L
.57866 .04997 L
.57866 .04991 L
.57866 .04985 L
.57866 .04981 L
.57866 .0498 L
.5787 .04984 L
.57877 .04996 L
.57889 .05017 L
.57899 .0505 L
.57907 .05094 L
.57909 .05148 L
.57904 .0521 L
.57889 .05271 L
.57862 .05341 L
.57821 .05415 L
.57762 .05482 L
.5768 .05546 L
.57575 .05602 L
.57452 .05646 L
.57314 .05671 L
.57154 .05676 L
Mistroke
.56973 .05659 L
.56796 .05624 L
.56612 .05578 L
.56431 .05526 L
.56275 .05473 L
.56134 .05419 L
.56024 .0537 L
.55938 .05321 L
.5588 .05273 L
.55853 .05226 L
.55859 .05182 L
.55893 .05144 L
.55947 .05113 L
.56018 .05087 L
.56097 .05066 L
.56179 .05049 L
.56262 .05032 L
.56332 .05015 L
.56392 .04997 L
.56445 .04982 L
.56491 .04974 L
.56531 .04974 L
.56568 .04983 L
.56608 .04999 L
.56659 .05021 L
.56731 .05047 L
.5683 .05076 L
.56954 .05105 L
.57109 .05131 L
.57298 .05154 L
.57488 .05175 L
.57702 .05196 L
.57935 .05216 L
.58149 .05239 L
.58369 .05264 L
.58596 .05295 L
.58783 .0533 L
.58965 .05372 L
.59117 .0541 L
.59244 .05455 L
.59339 .05505 L
.59405 .05552 L
.5944 .05601 L
.59457 .05645 L
.59464 .05682 L
.59466 .05706 L
.5947 .05713 L
.5948 .05704 L
.59496 .05681 L
.59519 .05646 L
Mistroke
.59548 .05602 L
.59581 .05554 L
.59617 .05505 L
.59658 .0546 L
.59702 .05417 L
.59746 .05375 L
.59788 .05334 L
.59826 .05296 L
.5986 .05262 L
.5989 .05233 L
.59916 .05209 L
.59939 .05189 L
.59954 .05171 L
.5996 .05155 L
.59956 .05139 L
.59942 .0512 L
.59915 .051 L
.59876 .05084 L
.59827 .05072 L
.5977 .05063 L
.59707 .05059 L
.5964 .05057 L
.59571 .05058 L
.59504 .0506 L
.59437 .05062 L
.59373 .05064 L
.59316 .05063 L
.59269 .05061 L
.59235 .05059 L
.59213 .05056 L
.59202 .05051 L
.59201 .05046 L
.59207 .0504 L
.5922 .05035 L
.59238 .05032 L
.59258 .05031 L
.59279 .05032 L
.59299 .0504 L
.59312 .05057 L
.59312 .0508 L
.59294 .05106 L
.59255 .05135 L
.59189 .05166 L
.59089 .05195 L
.58951 .05223 L
.5877 .05245 L
.58573 .05263 L
.58326 .0528 L
.58039 .0529 L
.57723 .05295 L
Mistroke
.57359 .05295 L
.57016 .05285 L
.56615 .05264 L
.56236 .05235 L
.55815 .05198 L
.5545 .05157 L
.55052 .05116 L
.54691 .05076 L
.54341 .05038 L
.53995 .05004 L
.53668 .04973 L
.53344 .04944 L
.53008 .04917 L
.52713 .0489 L
.52408 .04866 L
.5212 .04848 L
.51837 .04836 L
.5157 .04831 L
.51368 .04831 L
.51172 .04834 L
.50996 .04839 L
.50863 .04843 L
.50752 .04846 L
.50666 .04847 L
.50608 .04847 L
.50577 .04847 L
.50572 .04847 L
.50585 .04847 L
.50611 .04846 L
.50642 .04844 L
.50671 .04841 L
.50695 .04836 L
.50713 .0483 L
.50725 .04825 L
.50737 .0482 L
.50754 .04815 L
.50778 .04812 L
.50814 .04809 L
.50866 .0481 L
.5094 .04812 L
.51037 .04817 L
.51157 .04825 L
.51303 .04838 L
.51472 .04857 L
.5167 .04879 L
.51877 .04905 L
.5211 .04933 L
.5235 .04963 L
.52608 .04993 L
.52862 .05023 L
Mistroke
.53111 .05053 L
.53375 .0508 L
.53634 .05106 L
.53886 .05127 L
.54129 .05143 L
.5435 .05155 L
.54556 .05162 L
.54743 .05165 L
.54913 .05168 L
.5507 .0517 L
.55213 .05174 L
.5534 .05178 L
.55451 .0518 L
.55542 .05178 L
.55612 .05172 L
.5566 .05164 L
.55689 .05154 L
.55706 .05143 L
.55718 .05131 L
.5573 .05119 L
.55753 .05107 L
.55804 .05099 L
.55893 .05097 L
.56016 .05102 L
.56165 .05116 L
.56352 .0514 L
.5658 .05177 L
.56796 .05225 L
.57024 .0528 L
.57282 .05339 L
.57527 .05397 L
.57816 .05449 L
.58076 .05497 L
.58305 .05546 L
.58536 .05594 L
.58772 .0564 L
.59009 .05686 L
.59246 .05732 L
.59473 .05778 L
.59697 .05824 L
.59938 .05871 L
.60188 .05921 L
.60447 .05974 L
.60732 .06034 L
.6099 .06104 L
.61261 .06183 L
.61526 .06268 L
.61786 .06354 L
.6204 .06441 L
.62291 .06531 L
Mistroke
.62521 .06621 L
.62756 .06709 L
.62997 .06792 L
.63239 .06877 L
.63483 .06963 L
.63722 .07053 L
.63966 .07141 L
.64208 .07224 L
.64438 .07307 L
.64655 .07391 L
.64862 .07475 L
.65057 .07555 L
.65241 .07634 L
.65418 .07711 L
.65586 .07785 L
.65746 .0785 L
.65898 .07908 L
.66039 .07959 L
.6617 .08005 L
.66288 .08044 L
.66392 .08073 L
.66482 .08092 L
.66555 .08102 L
.66614 .08107 L
.6666 .08111 L
.66693 .08111 L
.66713 .08107 L
.66719 .081 L
.66712 .08093 L
.66694 .08082 L
.66666 .08063 L
.66632 .08034 L
.66593 .07998 L
.6655 .07956 L
.66505 .07912 L
.66462 .07865 L
.66422 .07821 L
.66386 .07777 L
.66351 .07733 L
.66315 .07692 L
.66276 .07656 L
.66234 .07627 L
.66189 .07607 L
.66142 .07596 L
.66091 .07591 L
.66041 .07593 L
.65994 .076 L
.65951 .07608 L
.65909 .07616 L
.65864 .07623 L
Mistroke
.6581 .07629 L
.65746 .07634 L
.65669 .07636 L
.65575 .07634 L
.65465 .07625 L
.65333 .07606 L
.65175 .07574 L
.64984 .07528 L
.64791 .07465 L
.64552 .07389 L
.6426 .07295 L
.63968 .07184 L
.63626 .07062 L
.63239 .06933 L
.62861 .06785 L
.62447 .06626 L
.62023 .06473 L
.61567 .06309 L
.61115 .06151 L
.60591 .05989 L
.60129 .05853 L
.59599 .05725 L
.59046 .05606 L
.58517 .05499 L
.57966 .05414 L
.57452 .05339 L
.56959 .05273 L
.56492 .05218 L
.56054 .05172 L
.55694 .05134 L
.55352 .05102 L
.55086 .05076 L
.54865 .05054 L
.54692 .05034 L
.54566 .05016 L
.54478 .04998 L
.54421 .04978 L
.54388 .04957 L
.54372 .04939 L
.54366 .04924 L
.54366 .04914 L
.54369 .04908 L
.54375 .04907 L
.54387 .04909 L
.54407 .04915 L
.54435 .04922 L
.54472 .04928 L
.54516 .04932 L
.54567 .04938 L
.54625 .04941 L
Mistroke
.54689 .04944 L
.54756 .04947 L
.54824 .04949 L
.5489 .04951 L
.54952 .04952 L
.55007 .04952 L
.55055 .04952 L
.55092 .0495 L
.5512 .04948 L
.55137 .04946 L
.55146 .04943 L
.55147 .04941 L
.55144 .0494 L
.55138 .04939 L
.55132 .0494 L
.55127 .0494 L
.55126 .0494 L
.55131 .04938 L
.55142 .04934 L
.55152 .04931 L
.55159 .0493 L
.55159 .04931 L
.55151 .04935 L
.55137 .04944 L
.55115 .04956 L
.55085 .04972 L
.55045 .04991 L
.54994 .05012 L
.54931 .05033 L
.54849 .05054 L
.54752 .05075 L
.54632 .05094 L
.54485 .05111 L
.54306 .05124 L
.54089 .05132 L
.53856 .05136 L
.53573 .05134 L
.53245 .05127 L
.52881 .05115 L
.52432 .051 L
.51981 .05084 L
.51555 .05067 L
.51007 .05051 L
.50511 .05035 L
.49911 .05019 L
.49432 .05003 L
.48859 .04987 L
.48397 .04972 L
.47877 .04958 L
.47483 .04944 L
Mistroke
.47085 .04933 L
.46728 .04923 L
.46452 .04914 L
.46224 .04907 L
.46048 .04901 L
.45918 .04897 L
.45828 .04895 L
.45771 .04893 L
.45742 .04892 L
.45733 .04892 L
.45736 .04892 L
.45747 .04892 L
.45762 .04893 L
.45778 .04893 L
.45792 .04894 L
.45801 .04894 L
.45807 .04894 L
.4581 .04894 L
.45811 .04894 L
.45811 .04894 L
.45811 .04894 L
.45814 .04896 L
.45819 .04899 L
.45827 .04903 L
.45834 .04906 L
.45837 .04908 L
.45835 .04907 L
.45825 .04901 L
.45806 .04892 L
.45778 .04878 L
.45742 .04859 L
.457 .04838 L
.45654 .04814 L
.45605 .04789 L
.45556 .04764 L
.45506 .04739 L
.45458 .04714 L
.45411 .04689 L
.45369 .04666 L
.45336 .04647 L
.45313 .04634 L
.45302 .04629 L
.45304 .04632 L
.45323 .04642 L
.4536 .04657 L
.4541 .04673 L
.45463 .04691 L
.45512 .0471 L
.45552 .04732 L
.45569 .0476 L
Mistroke
.45556 .04793 L
.45508 .04831 L
.45422 .04872 L
.45288 .04915 L
.45104 .0496 L
.44872 .05008 L
.44649 .05058 L
.44334 .05106 L
.4402 .05149 L
.43615 .05187 L
.43164 .05221 L
.4277 .0525 L
.42311 .05274 L
.41854 .05293 L
.41411 .05314 L
.40946 .05335 L
.40604 .05354 L
.40226 .05372 L
.39852 .05389 L
.39559 .05406 L
.39274 .05427 L
.38995 .05445 L
.38765 .05466 L
.38569 .05486 L
.38408 .05504 L
.38279 .0552 L
.38178 .05537 L
.38106 .05554 L
.38047 .05567 L
.38001 .05574 L
.37968 .05572 L
.37949 .05563 L
.37951 .05549 L
.37976 .05529 L
.38022 .05502 L
.38084 .05469 L
.38162 .05431 L
.38253 .0539 L
.38349 .05346 L
.38448 .05304 L
.38543 .05262 L
.38636 .05222 L
.38726 .05187 L
.3881 .05159 L
.38884 .05138 L
.38945 .05122 L
.38991 .0511 L
.39025 .051 L
.39048 .05086 L
.39063 .05068 L
Mistroke
.39072 .05042 L
.39077 .05008 L
.3908 .04966 L
.3908 .0492 L
.39079 .04874 L
.39076 .04832 L
.39074 .04791 L
.39072 .04752 L
.39073 .04718 L
.39078 .04691 L
.39086 .04669 L
.39095 .0465 L
.39104 .04633 L
.39111 .04618 L
.39115 .04605 L
.39119 .04593 L
.39122 .0458 L
.39128 .04569 L
.39139 .04561 L
.3916 .04556 L
.3919 .04554 L
.39227 .04557 L
.39271 .04564 L
.39317 .04574 L
.39365 .04588 L
.39413 .04607 L
.39458 .04627 L
.39499 .04648 L
.39536 .04665 L
.3957 .04675 L
.39599 .04677 L
.39622 .04675 L
.39639 .04671 L
.3965 .0467 L
.39659 .04675 L
.39668 .04691 L
.39677 .04716 L
.3969 .04751 L
.39705 .04792 L
.39724 .04838 L
.39744 .04885 L
.39765 .04932 L
.39784 .04978 L
.398 .05023 L
.39815 .05066 L
.39826 .05103 L
.39835 .05133 L
.39841 .05154 L
.39846 .05166 L
.39851 .0517 L
Mistroke
.39857 .05168 L
.39864 .05161 L
.39869 .05154 L
.39873 .05149 L
.39873 .05146 L
.39872 .05147 L
.39869 .05148 L
.39863 .05148 L
.39851 .05147 L
.39831 .05144 L
.39804 .05141 L
.39771 .05138 L
.39732 .05134 L
.39689 .0513 L
.39642 .05126 L
.39594 .05123 L
.39547 .05121 L
.39503 .05119 L
.39462 .05117 L
.39427 .05116 L
.39398 .05115 L
.39377 .05116 L
.39363 .05117 L
.39356 .05119 L
.39354 .05122 L
.39355 .05125 L
.39358 .05127 L
.39362 .05129 L
.39367 .0513 L
.3937 .0513 L
.39373 .0513 L
.39376 .05131 L
.3938 .05133 L
.39384 .05133 L
.39386 .05132 L
.39384 .05129 L
.39379 .05124 L
.3937 .05119 L
.39357 .05112 L
.39342 .05103 L
.39328 .0509 L
.39318 .05075 L
.39312 .05061 L
.39307 .05049 L
.393 .05041 L
.39283 .05026 L
.39256 .05035 L
.39212 .05059 L
.39147 .05099 L
.39053 .05159 L
Mistroke
.38918 .05241 L
.38742 .05347 L
.38552 .05463 L
.38291 .056 L
.37999 .05752 L
.37688 .05924 L
.37307 .06099 L
.36871 .06304 L
.36484 .06489 L
.35997 .06684 L
.35616 .06871 L
.35131 .07051 L
.34774 .07213 L
.34392 .0737 L
.34041 .0751 L
.33711 .07643 L
.33451 .07759 L
.33209 .07869 L
.32997 .07971 L
.32832 .08061 L
.32697 .08135 L
.32588 .08186 L
.32503 .08221 L
.32436 .0824 L
.32383 .08242 L
.32341 .08231 L
.32307 .08206 L
.32282 .08172 L
.32266 .08131 L
.32261 .08086 L
.32267 .0804 L
.32285 .0799 L
.32314 .0794 L
.32354 .07896 L
.32408 .07861 L
.32474 .07832 L
.32548 .07809 L
.32632 .0779 L
.32719 .07775 L
.32809 .07762 L
.32902 .0775 L
.32996 .07737 L
.33089 .07724 L
.3318 .07712 L
.33267 .07701 L
.33349 .0769 L
.33424 .0768 L
.33495 .07669 L
.33565 .07656 L
.33637 .07639 L
Mistroke
.33711 .07617 L
.33795 .07588 L
.33886 .07551 L
.33991 .07504 L
.34118 .07447 L
.34264 .07381 L
.34436 .07301 L
.34629 .07208 L
.34851 .071 L
.35102 .06977 L
.35377 .06843 L
.35677 .06692 L
.35996 .06534 L
.36323 .0636 L
.3667 .06181 L
.37003 .06022 L
.37322 .0587 L
.37631 .05713 L
.37898 .05563 L
.38162 .05421 L
.3836 .05317 L
.38533 .05231 L
.38677 .05163 L
.38785 .05112 L
.38862 .05077 L
.38912 .05059 L
.3894 .05052 L
.38953 .05051 L
.38958 .05054 L
.38959 .0506 L
.38959 .05068 L
.38964 .05077 L
.38978 .05082 L
.38999 .05084 L
.39021 .05086 L
.39045 .0509 L
.39069 .05095 L
.39091 .05101 L
.39111 .05108 L
.39126 .05114 L
.39137 .05119 L
.39143 .05123 L
.39145 .05125 L
.39143 .05125 L
.3914 .05122 L
.39136 .0512 L
.39133 .0512 L
.39134 .05122 L
.39139 .05127 L
.39147 .05134 L
Mistroke
.39154 .05141 L
.39158 .05145 L
.39155 .05142 L
.39145 .05131 L
.39125 .05108 L
.39097 .05072 L
.3906 .05029 L
.39017 .04983 L
.3897 .0494 L
.3892 .04903 L
.3887 .04874 L
.3882 .04853 L
.38774 .04841 L
.38736 .04837 L
.38708 .04842 L
.38688 .04856 L
.38673 .04875 L
.38659 .04901 L
.38642 .04934 L
.38618 .04974 L
.38582 .0502 L
.38533 .05065 L
.38471 .05105 L
.38407 .05139 L
.38348 .05171 L
.38294 .05202 L
.38244 .05232 L
.38192 .05261 L
.38144 .05292 L
.38099 .05327 L
.38057 .0537 L
.38012 .05421 L
.37965 .05482 L
.37894 .05553 L
.37803 .05635 L
.37686 .05729 L
.37557 .05827 L
.37385 .05931 L
.37169 .06038 L
.36937 .06141 L
.36661 .0626 L
.36407 .06377 L
.36143 .06496 L
.35886 .0661 L
.3567 .06713 L
.35468 .06806 L
.35285 .06888 L
.35129 .06962 L
.35 .07028 L
.34884 .07089 L
Mistroke
.34777 .07151 L
.34676 .07215 L
.34579 .07283 L
.34482 .0735 L
.34385 .07415 L
.34292 .0747 L
.34196 .07517 L
.34094 .07556 L
.33985 .07589 L
.33871 .0762 L
.33756 .07649 L
.33645 .0768 L
.33542 .07714 L
.33449 .07751 L
.33363 .07793 L
.33275 .0784 L
.3319 .07895 L
.33089 .07961 L
.32968 .08041 L
.32825 .08132 L
.32655 .08235 L
.32452 .0835 L
.32235 .08478 L
.31976 .08616 L
.31671 .0877 L
.31367 .08939 L
.31013 .09126 L
.30624 .09323 L
.30226 .09539 L
.29798 .09762 L
.2932 .10001 L
.28911 .10238 L
.28435 .10489 L
.28016 .10728 L
.27547 .10976 L
.27155 .11202 L
.26725 .11427 L
.26357 .11638 L
.25976 .11829 L
.25667 .12 L
.25373 .12152 L
.25128 .12279 L
.24915 .12388 L
.24758 .12474 L
.24642 .12537 L
.24563 .12581 L
.2452 .12606 L
.24504 .12617 L
.24505 .12618 L
.24512 .12617 L
Mistroke
.24512 .12623 L
.24495 .12639 L
.24454 .12673 L
.24384 .12729 L
.24278 .12811 L
.24133 .1292 L
.2397 .13045 L
.2377 .13195 L
.23561 .13358 L
.23326 .13533 L
.23104 .13708 L
.22877 .13885 L
.22664 .14048 L
.22474 .14196 L
.22303 .14327 L
.2217 .14432 L
.22064 .14516 L
.21988 .14578 L
.21939 .14621 L
.21911 .14648 L
.21899 .14662 L
.21898 .14666 L
.21905 .14661 L
.21916 .14651 L
.21931 .14639 L
.21943 .14628 L
.21951 .14622 L
.21954 .14618 L
.21956 .14618 L
.21959 .14616 L
.21968 .14614 L
.2198 .14611 L
.21991 .14607 L
.21997 .14606 L
.21993 .14607 L
.21976 .14611 L
.21946 .1462 L
.21901 .14632 L
.21842 .14648 L
.21773 .14666 L
.21697 .14686 L
.21618 .14708 L
.21539 .14729 L
.21462 .14748 L
.21386 .14763 L
.21314 .14775 L
.21251 .14784 L
.21203 .14789 L
.21174 .14792 L
.21166 .14792 L
Mistroke
.21172 .14795 L
.21186 .14807 L
.21201 .14831 L
.21212 .1487 L
.21211 .1493 L
.21197 .15011 L
.2117 .15108 L
.21128 .15223 L
.21067 .1536 L
.20982 .15524 L
.20866 .15713 L
.20709 .15946 L
.20528 .16179 L
.20307 .16448 L
.20047 .16763 L
.19734 .17119 L
.1937 .1755 L
.19058 .17945 L
.18644 .18399 L
.18248 .18887 L
.17816 .19409 L
.17349 .19975 L
.16875 .20581 L
.1643 .21178 L
.15929 .21807 L
.15437 .22538 L
.14938 .23225 L
.14455 .23907 L
.13959 .24641 L
.13436 .2535 L
.12941 .26183 L
.12444 .26912 L
.11964 .2767 L
.1147 .28536 L
.11043 .29366 L
.10633 .30046 L
.1025 .30864 L
.099 .31634 L
.09589 .3248 L
.09309 .33198 L
.0907 .33932 L
.08862 .34696 L
.08684 .35337 L
.08527 .36012 L
.08394 .36655 L
.08277 .37272 L
.08174 .37832 L
.0809 .38311 L
.0802 .38789 L
.07965 .39127 L
Mistroke
.07925 .39454 L
.07899 .39697 L
.07884 .39887 L
.07879 .40022 L
.07882 .40103 L
.07894 .40139 L
.07914 .40146 L
.07939 .40132 L
.07964 .40105 L
.07987 .40072 L
.08006 .4004 L
.08018 .40021 L
.08024 .40014 L
.08024 .40011 L
.08021 .40011 L
.08016 .40011 L
.08013 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08012 .40009 L
.08016 .40006 L
.08021 .40002 L
.08025 .39998 L
.08027 .39997 L
.08025 .39998 L
.08018 .40003 L
.08006 .40013 L
.07988 .40027 L
.07965 .40046 L
.07939 .40067 L
.07911 .40091 L
.07882 .40115 L
.07854 .40138 L
.0783 .40159 L
.07807 .40178 L
.07785 .40195 L
.07765 .40211 L
.07747 .40228 L
Mistroke
.07733 .40242 L
.07723 .40256 L
.07714 .40271 L
.07704 .4029 L
.07688 .40317 L
.07663 .40356 L
.07627 .40406 L
.0758 .40466 L
.07524 .4053 L
.07463 .40601 L
.07395 .40668 L
.07321 .40745 L
.0724 .40826 L
.07153 .40914 L
.07065 .41007 L
.06972 .4111 L
.06878 .41226 L
.06785 .41357 L
.06694 .41507 L
.06609 .41676 L
.06534 .41844 L
.06467 .42035 L
.06409 .42237 L
.06359 .42439 L
.06318 .42647 L
.06285 .42847 L
.06259 .43029 L
.06242 .43197 L
.06235 .43342 L
.06235 .43455 L
.0624 .43539 L
.06247 .43596 L
.06253 .4363 L
.06255 .43649 L
.06255 .43659 L
.06253 .43664 L
.0625 .43672 L
.06245 .43687 L
.0624 .43714 L
.06237 .43753 L
.06236 .43804 L
.06238 .43866 L
.06244 .43933 L
.06253 .44004 L
.06267 .44076 L
.06287 .44145 L
.06313 .44209 L
.06345 .44264 L
.06382 .44309 L
.06422 .44343 L
Mistroke
.06465 .44365 L
.0651 .44377 L
.06556 .4438 L
.06604 .44378 L
.06651 .44373 L
.06696 .44368 L
.06739 .44363 L
.06778 .44358 L
.06817 .44354 L
.06855 .44352 L
.06894 .44351 L
.06934 .44351 L
.06975 .4435 L
.07019 .4435 L
.07066 .44349 L
.07117 .44348 L
.07167 .44348 L
.07212 .44347 L
.07248 .44348 L
.07273 .44351 L
.07284 .44355 L
.07279 .44359 L
.07257 .44361 L
.07221 .4436 L
.0717 .44355 L
.07109 .44346 L
.07033 .44333 L
.06965 .44315 L
.06884 .44291 L
.06804 .4426 L
.0673 .44225 L
.06667 .44189 L
.06615 .44159 L
.06571 .44137 L
.06533 .44125 L
.06498 .44127 L
.06463 .44144 L
.06428 .44178 L
.06392 .44228 L
.06354 .44296 L
.06321 .4438 L
.06299 .44476 L
.06292 .44579 L
.06302 .4469 L
.06332 .44806 L
.06383 .44925 L
.06456 .45046 L
.06544 .45161 L
.06653 .45275 L
.06771 .45393 L
Mistroke
.06892 .45514 L
.0702 .45643 L
.07147 .45783 L
.07268 .4593 L
.07372 .46088 L
.07463 .46253 L
.0754 .46408 L
.07602 .46553 L
.07653 .46682 L
.07697 .46798 L
.07732 .46896 L
.07762 .4699 L
.07782 .47078 L
.07791 .47158 L
.07785 .47236 L
.07762 .47318 L
.07721 .4741 L
.07658 .47514 L
.07576 .47637 L
.07474 .47782 L
.07369 .47946 L
.07239 .4813 L
.07128 .48303 L
.07015 .48502 L
.06898 .48707 L
.0679 .48882 L
.06704 .49016 L
.06636 .49124 L
.06587 .49208 L
.06557 .4927 L
.06543 .49305 L
.06542 .49323 L
.06552 .49332 L
.06566 .49337 L
.06579 .49348 L
.06586 .49368 L
.06587 .49403 L
.06579 .49463 L
.06562 .4955 L
.06538 .49665 L
.06509 .49803 L
.06475 .49965 L
.06438 .50139 L
.06401 .50317 L
.06365 .505 L
.06333 .50675 L
.06305 .50828 L
.06282 .5097 L
.06265 .51095 L
.06254 .512 L
Mistroke
.06249 .5128 L
.06248 .51342 L
.06251 .51391 L
.06254 .51423 L
.06258 .5144 L
.06259 .51447 L
.0626 .51448 L
.0626 .51442 L
.06261 .51434 L
.06263 .51422 L
.06269 .5141 L
.06277 .51399 L
.06285 .51395 L
.06288 .51397 L
.06286 .51402 L
.06275 .51411 L
.06255 .51422 L
.06223 .51435 L
.06181 .51448 L
.06131 .5146 L
.06076 .5147 L
.06021 .51477 L
.05967 .51482 L
.05916 .51484 L
.05864 .51485 L
.05813 .51484 L
.05766 .5148 L
.05729 .51472 L
.05704 .51462 L
.05691 .5145 L
.05686 .51438 L
.05689 .51429 L
.05696 .51425 L
.05705 .51426 L
.05711 .51432 L
.05713 .51438 L
.05713 .51439 L
.05713 .51433 L
.05712 .51416 L
.0571 .51388 L
.05707 .51353 L
.05705 .51312 L
.05704 .5127 L
.05707 .51228 L
.05714 .51185 L
.05726 .51139 L
.05743 .51088 L
.05765 .51033 L
.05789 .50977 L
.05813 .50924 L
Mistroke
.05838 .50876 L
.05862 .50834 L
.05887 .50795 L
.05915 .50751 L
.05948 .50696 L
.05986 .50629 L
.06029 .50543 L
.06077 .50437 L
.06129 .50312 L
.06185 .50174 L
.06241 .50033 L
.06291 .4991 L
.06345 .49795 L
.06403 .49667 L
.06455 .49562 L
.06506 .4946 L
.06552 .49361 L
.06589 .4927 L
.06616 .49195 L
.06633 .49138 L
.06641 .49096 L
.06641 .49069 L
.06637 .49052 L
.06631 .49041 L
.06626 .49029 L
.06622 .49015 L
.0662 .48997 L
.06621 .48979 L
.06621 .48964 L
.06622 .48954 L
.06622 .48948 L
.06622 .48947 L
.06622 .48948 L
.06622 .48952 L
.06622 .48956 L
.06621 .48959 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
Mistroke
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48962 L
.06622 .48964 L
.06624 .4897 L
.06626 .48978 L
.06626 .48986 L
.06624 .48992 L
.06621 .48994 L
.06616 .48991 L
.0661 .48978 L
.06605 .48954 L
.06601 .48919 L
.06598 .4887 L
.06597 .48808 L
.06598 .48732 L
.066 .48649 L
.06603 .4856 L
.06606 .48467 L
.06611 .4837 L
.06618 .48268 L
.06626 .48166 L
.06635 .48058 L
.06645 .47947 L
.06654 .47833 L
.06661 .47719 L
Mistroke
.06664 .47604 L
.06666 .47489 L
.06669 .47376 L
.06674 .47282 L
.06683 .47174 L
.06698 .4708 L
.06716 .46985 L
.06733 .46889 L
.06748 .46796 L
.06761 .4671 L
.06774 .46631 L
.06788 .46556 L
.06803 .46481 L
.0682 .46405 L
.0684 .46325 L
.0686 .46239 L
.0688 .46147 L
.06899 .46049 L
.06915 .45951 L
.06927 .4586 L
.0694 .4578 L
.06952 .4571 L
.06967 .45652 L
.06982 .45606 L
.06999 .45572 L
.07013 .45549 L
.07022 .45536 L
.07026 .45532 L
.07025 .45534 L
.07021 .45541 L
.07016 .4555 L
.07013 .45558 L
.07011 .45563 L
.07011 .45562 L
.07011 .45558 L
.07011 .45556 L
.07011 .45559 L
.07011 .45566 L
.0701 .45575 L
.0701 .45588 L
.07009 .45603 L
.07009 .4562 L
.07008 .45636 L
.07008 .45651 L
.07007 .45664 L
.07007 .45673 L
.07006 .4568 L
.07006 .45683 L
.07006 .45684 L
.07006 .45678 L
Mistroke
.07007 .45668 L
.07008 .45649 L
.07009 .45633 L
.0701 .45612 L
.0701 .45592 L
.07011 .45575 L
.07012 .45562 L
.07012 .45555 L
.07012 .45553 L
.07012 .45552 L
.07012 .45553 L
.07013 .45553 L
.07013 .45553 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07014 .4556 L
.07019 .45562 L
.07027 .45566 L
.07035 .4557 L
.07038 .45571 L
.07036 .4557 L
.07026 .45565 L
.07006 .45556 L
.06976 .45542 L
.06936 .45525 L
.06887 .45504 L
.06834 .45481 L
.06781 .4546 L
.06732 .45441 L
.06686 .45424 L
.06638 .45409 L
.06588 .45393 L
.06541 .45377 L
.06498 .4536 L
.06463 .4534 L
.06433 .45316 L
.06407 .45286 L
.06386 .45247 L
.06368 .45196 L
.06351 .45132 L
Mistroke
.06332 .45054 L
.06309 .4496 L
.06285 .44846 L
.06264 .44711 L
.06248 .44558 L
.06236 .44393 L
.0623 .44205 L
.0623 .44009 L
.06235 .43801 L
.06244 .43593 L
.06255 .43373 L
.06266 .43172 L
.06277 .42955 L
.06285 .42768 L
.06292 .42568 L
.06298 .42384 L
.06303 .42203 L
.06308 .4206 L
.06312 .41927 L
.06316 .41809 L
.06319 .41711 L
.0632 .41637 L
.06318 .41576 L
.06315 .41529 L
.06312 .41493 L
.0631 .41468 L
.06309 .41451 L
.06312 .41443 L
.0632 .41441 L
.06334 .41444 L
.06354 .4145 L
.06381 .41455 L
.06415 .41458 L
.06455 .41453 L
.06498 .41442 L
.06546 .41425 L
.06599 .41405 L
.06655 .41382 L
.06718 .41358 L
.06776 .41333 L
.06837 .4131 L
.06899 .41287 L
.06962 .41265 L
.07024 .41246 L
.07076 .41231 L
.07126 .41219 L
.07176 .41211 L
.07226 .41207 L
.07276 .41205 L
.07322 .41206 L
Mistroke
.07368 .41208 L
.07414 .4121 L
.07459 .41213 L
.07501 .41214 L
.07538 .41214 L
.07571 .41213 L
.07599 .41213 L
.07624 .41213 L
.07647 .41213 L
.07667 .41213 L
.07685 .41212 L
.07699 .41212 L
.07709 .41212 L
.07714 .41212 L
.07715 .41212 L
.07714 .41212 L
.07709 .41212 L
.07705 .41212 L
.07702 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41213 L
Mistroke
.07701 .41215 L
.07701 .4122 L
.07702 .41227 L
.07702 .41234 L
.07701 .41237 L
.077 .41235 L
.07699 .41225 L
.07698 .41206 L
.07697 .41178 L
.07696 .41142 L
.07696 .41099 L
.07697 .41052 L
.07698 .41003 L
.077 .40955 L
.07701 .40908 L
.07702 .40861 L
.07704 .40816 L
.07706 .40776 L
.07708 .40745 L
.07711 .40725 L
.07713 .40719 L
.07715 .40722 L
.07716 .40732 L
.07716 .40743 L
.07717 .40751 L
.07716 .40752 L
.07715 .40742 L
.07712 .40722 L
.07709 .40692 L
.07706 .40649 L
.07706 .40594 L
.07709 .40526 L
.07717 .40449 L
.0773 .40364 L
.07749 .40269 L
.07773 .40165 L
.07801 .40063 L
.0783 .39961 L
.07861 .39865 L
.07891 .39779 L
.0792 .39708 L
.07948 .39647 L
.07975 .39596 L
.07999 .39556 L
.08018 .39527 L
.08031 .39509 L
.08038 .39501 L
.08041 .395 L
.08039 .39505 L
.08035 .39512 L
Mistroke
.0803 .39521 L
.08027 .39528 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08027 .39529 L
.0803 .39524 L
.08034 .39517 L
.08038 .3951 L
.0804 .39507 L
.08039 .39509 L
.08033 .39519 L
.08022 .39537 L
.08005 .39565 L
.07983 .39602 L
.07957 .39645 L
.07929 .39692 L
.079 .39742 L
.07871 .3979 L
.07843 .39836 L
.07815 .39883 L
.07788 .39928 L
.07764 .39968 L
.07745 .4 L
.07732 .40022 L
.07725 .40034 L
.07722 .40038 L
.07724 .40035 L
.07728 .40027 L
.07733 .40017 L
.07736 .40008 L
.07738 .40002 L
.07738 .39999 L
.07738 .4 L
Mistroke
.07738 .40005 L
.07738 .40015 L
.07737 .40029 L
.07737 .40047 L
.07736 .40068 L
.07735 .40092 L
.07735 .40117 L
.07734 .40142 L
.07733 .40166 L
.07732 .4019 L
.07732 .40213 L
.07731 .40232 L
.07731 .40247 L
.0773 .40258 L
.0773 .40264 L
.0773 .40266 L
.0773 .40265 L
.0773 .40261 L
.0773 .40257 L
.0773 .40254 L
.07731 .40253 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
Mistroke
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07726 .40252 L
.07721 .40252 L
.07717 .40252 L
.07716 .40252 L
.07717 .40252 L
.07723 .40252 L
.07734 .40252 L
.0775 .40252 L
.0777 .40252 L
.07795 .40252 L
.07821 .40252 L
.07849 .40251 L
.07877 .40251 L
.07905 .40251 L
.07932 .40251 L
.07957 .40251 L
.0798 .4025 L
.07997 .4025 L
.08009 .4025 L
.08015 .4025 L
.08014 .4025 L
.08008 .4025 L
.08 .4025 L
.07994 .4025 L
.07991 .40251 L
.07995 .40252 L
.08005 .40255 L
.08021 .40258 L
.08041 .40262 L
.08065 .40263 L
Mistroke
.08091 .40262 L
.08119 .40257 L
.08147 .40247 L
.08174 .40233 L
.082 .40215 L
.08225 .40194 L
.08248 .4017 L
.08268 .40147 L
.08285 .40126 L
.08297 .40109 L
.08304 .40092 L
.08306 .40074 L
.08302 .40053 L
.08293 .40029 L
.08281 .40004 L
.08266 .39976 L
.08246 .39945 L
.08224 .39912 L
.08199 .39875 L
.08172 .39832 L
.08146 .3978 L
.08119 .39722 L
.08093 .39655 L
.0807 .39582 L
.0805 .39506 L
.08034 .3943 L
.08024 .39357 L
.08019 .39292 L
.08018 .39238 L
.08021 .39191 L
.08026 .3915 L
.08032 .39114 L
.08036 .39082 L
.08039 .39056 L
.0804 .39038 L
.0804 .39029 L
.0804 .39027 L
.0804 .3903 L
.0804 .39037 L
.0804 .39045 L
.0804 .3905 L
.08039 .39052 L
.08039 .39053 L
.08039 .39053 L
.08039 .39054 L
.08039 .39057 L
.08039 .3906 L
.08039 .39064 L
.08037 .39065 L
.08034 .39062 L
Mistroke
.0803 .39054 L
.08027 .39044 L
.08025 .39031 L
.08027 .39019 L
.08033 .39007 L
.08044 .38994 L
.08061 .38981 L
.08082 .38967 L
.08106 .38951 L
.08134 .38935 L
.08162 .38917 L
.08191 .389 L
.08219 .38884 L
.08246 .38871 L
.08272 .38862 L
.08294 .38854 L
.08312 .38847 L
.08324 .3884 L
.08332 .38833 L
.08334 .38824 L
.08333 .38815 L
.08329 .38808 L
.08325 .38803 L
.08321 .38802 L
.0832 .38804 L
.08319 .38808 L
.08319 .38811 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
Mistroke
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08317 .38812 L
.08314 .38812 L
.08309 .38812 L
.08305 .38812 L
.08303 .38814 L
.08303 .38819 L
.08305 .38827 L
.08312 .38834 L
.08324 .38837 L
.08343 .38834 L
.08369 .38824 L
.08403 .38806 L
.08443 .38778 L
.08488 .38741 L
.08536 .38698 L
.08588 .38651 L
.0864 .38602 L
.08692 .38554 L
.08739 .38507 L
.0878 .3846 L
.08816 .38416 L
.08845 .38376 L
.08866 .38344 L
.08881 .38322 L
.0889 .3831 L
.08894 .38306 L
.08894 .38308 L
.08892 .38315 L
.08888 .38323 L
.08883 .38329 L
.08879 .38331 L
.08878 .38332 L
.08877 .38332 L
Mistroke
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08879 .38334 L
.08883 .3834 L
.08891 .38347 L
.08899 .38354 L
.08902 .38357 L
.08899 .38354 L
.0889 .38343 L
.0887 .38324 L
.08839 .38295 L
.08798 .38258 L
.08749 .38215 L
.08696 .38164 L
.08642 .38109 L
.08589 .38053 L
.08537 .38 L
.08484 .37951 L
.08432 .37908 L
.08385 .37877 L
.08349 .37864 L
.08329 .37871 L
.08326 .37896 L
.08336 .37935 L
.08357 .37984 L
.08385 .38039 L
.08418 .38096 L
.08451 .3815 L
.08481 .382 L
.08509 .38246 L
Mistroke
.08536 .38286 L
.08561 .38319 L
.08583 .3834 L
.08602 .38345 L
.08619 .38338 L
.0863 .38327 L
.08636 .38315 L
.08635 .38307 L
.0863 .38308 L
.08621 .38324 L
.08606 .38357 L
.08586 .38406 L
.08557 .3847 L
.08521 .38549 L
.08478 .38639 L
.08427 .38734 L
.08383 .38831 L
.0833 .38938 L
.08274 .3906 L
.08218 .39192 L
.08167 .39319 L
.08122 .39435 L
.08083 .39545 L
.08051 .39646 L
.08026 .39735 L
.0801 .39808 L
.07999 .3987 L
.07995 .39923 L
.07995 .39966 L
.07997 .39998 L
.08001 .4002 L
.08005 .40033 L
.0801 .40037 L
.08015 .40034 L
.08024 .40026 L
.08032 .40016 L
.08035 .40006 L
.08033 .40001 L
.08023 .40004 L
.08004 .40013 L
.07972 .40027 L
.07929 .40046 L
.07878 .40068 L
.07823 .40091 L
.07768 .40117 L
.07715 .40142 L
.07665 .40167 L
.07614 .40192 L
.07562 .40215 L
.07514 .40234 L
Mistroke
.07475 .40246 L
.0745 .4025 L
.07438 .40248 L
.07435 .40243 L
.07441 .40235 L
.07453 .40229 L
.07468 .40232 L
.07478 .40247 L
.07481 .40274 L
.07477 .40315 L
.07465 .40369 L
.07443 .40435 L
.07411 .4051 L
.07369 .40579 L
.07318 .40658 L
.07257 .40746 L
.07187 .40854 L
.07115 .40949 L
.07038 .41045 L
.06953 .41141 L
.06861 .41243 L
.06765 .4135 L
.06674 .41464 L
.06592 .41587 L
.06527 .41685 L
.06468 .41819 L
.06416 .41972 L
.06369 .42145 L
.06327 .42325 L
.06293 .42515 L
.0627 .42711 L
.06255 .42889 L
.06248 .43051 L
.06247 .43199 L
.06251 .43331 L
.06256 .43439 L
.06257 .43528 L
.06257 .43597 L
.06256 .43646 L
.06255 .43675 L
.06254 .43686 L
.06254 .43685 L
.06255 .43677 L
.06255 .43662 L
.06256 .43645 L
.06257 .43627 L
.06257 .43611 L
.06257 .43601 L
.06258 .436 L
.06257 .43609 L
Mistroke
.06257 .43631 L
.06255 .43666 L
.06254 .43713 L
.06252 .43771 L
.0625 .43837 L
.06247 .4391 L
.06245 .43983 L
.06242 .44058 L
.0624 .44131 L
.06237 .44198 L
.06233 .44258 L
.06227 .44308 L
.06218 .44344 L
.0621 .44368 L
.06205 .44379 L
.06207 .44379 L
.06217 .44372 L
.06236 .44361 L
.06267 .44351 L
.06307 .44343 L
.06354 .44337 L
.06403 .44332 L
.06453 .44326 L
.06504 .44322 L
.06554 .44324 L
.06608 .44335 L
.06665 .44354 L
.06722 .4438 L
.06775 .4441 L
.06822 .4444 L
.06862 .44467 L
.06896 .44489 L
.06923 .44506 L
.06943 .44516 L
.06962 .44521 L
.06983 .44522 L
.07006 .44518 L
.07028 .4451 L
.07045 .44494 L
.07057 .44471 L
.07065 .44439 L
.07072 .44404 L
.0708 .44369 L
.07084 .44343 L
.07084 .44327 L
.07079 .44324 L
.07068 .44334 L
.07047 .44352 L
.07015 .44371 L
.06973 .44388 L
Mistroke
.06923 .44399 L
.06869 .44407 L
.06813 .44412 L
.0676 .44414 L
.06709 .44415 L
.06657 .44415 L
.06606 .44413 L
.06559 .44408 L
.06522 .444 L
.06497 .4439 L
.06483 .44378 L
.06479 .44367 L
.06481 .44357 L
.06488 .4435 L
.06498 .44346 L
.06505 .44344 L
.06511 .44342 L
.06516 .44338 L
.0652 .44333 L
.06522 .44329 L
.06521 .44331 L
.06514 .44341 L
.065 .44357 L
.06478 .44379 L
.0645 .44408 L
.06416 .44443 L
.06381 .44487 L
.06349 .44538 L
.06325 .44594 L
.06308 .44652 L
.063 .44712 L
.06304 .44774 L
.0632 .44837 L
.06348 .44902 L
.06386 .44972 L
.06429 .45054 L
.0648 .45146 L
.06538 .45256 L
.06592 .4539 L
.06644 .45554 L
.06689 .45756 L
.06722 .45963 L
.0674 .46225 L
.0674 .46521 L
.06722 .46831 L
.06688 .47219 L
.06641 .47558 L
.06585 .4797 L
.06526 .48367 L
.06463 .4883 L
Mistroke
.06406 .4924 L
.06349 .49625 L
.06298 .50087 L
.06252 .50516 L
.06218 .5092 L
.06194 .5128 L
.06181 .51712 L
.06185 .52118 L
.06205 .52593 L
.06241 .52992 L
.0629 .53437 L
.06349 .53905 L
.06412 .5441 L
.06487 .54914 L
.06549 .55431 L
.06614 .5595 L
.06679 .56502 L
.06742 .57047 L
.06798 .5767 L
.06853 .58214 L
.06907 .58705 L
.06957 .59235 L
.07005 .59749 L
.07055 .60249 L
.07105 .607 L
.07156 .6111 L
.07205 .61497 L
.07254 .61833 L
.07301 .62138 L
.07345 .62381 L
.07384 .62598 L
.07419 .62758 L
.0745 .6288 L
.07475 .62965 L
.07495 .63018 L
.0751 .63043 L
.07518 .63046 L
.07521 .63036 L
.07521 .63019 L
.07518 .63 L
.07514 .62982 L
.0751 .62968 L
.07506 .62961 L
.07505 .62957 L
.07504 .62953 L
.07503 .62945 L
.075 .62934 L
.07496 .62923 L
.07493 .62916 L
.0749 .62917 L
Mistroke
.07491 .62926 L
.07496 .62944 L
.07505 .62973 L
.07518 .63014 L
.07533 .63068 L
.07551 .63138 L
.07571 .63227 L
.07594 .63335 L
.07621 .63454 L
.07651 .63588 L
.07685 .63732 L
.07722 .63883 L
.07759 .64037 L
.07797 .64182 L
.0783 .64324 L
.07858 .64464 L
.0788 .64604 L
.07898 .64733 L
.07916 .64859 L
.07934 .64981 L
.07955 .65105 L
.07977 .65232 L
.08001 .65365 L
.08024 .65508 L
.08046 .65671 L
.08065 .65861 L
.08083 .66074 L
.08097 .66307 L
.08111 .66566 L
.08123 .6684 L
.08134 .67069 L
.08143 .67352 L
.0815 .67591 L
.08159 .67836 L
.08171 .68087 L
.08186 .68314 L
.08207 .68532 L
.08233 .6873 L
.08266 .68922 L
.08308 .69108 L
.08356 .69303 L
.08413 .69508 L
.08475 .69715 L
.08537 .69938 L
.08596 .70171 L
.08652 .70408 L
.08705 .70619 L
.08751 .70828 L
.08791 .71034 L
.08826 .71233 L
Mistroke
.08856 .71402 L
.08884 .7155 L
.08912 .71671 L
.08941 .7176 L
.0897 .71816 L
.08999 .71846 L
.09026 .71852 L
.09051 .71842 L
.09073 .71822 L
.09095 .718 L
.09113 .71773 L
.09131 .71743 L
.09146 .71708 L
.09156 .7167 L
.09162 .71633 L
.09164 .71604 L
.09163 .71591 L
.09162 .71598 L
.09161 .71625 L
.09159 .7167 L
.09157 .71726 L
.09155 .71787 L
.09154 .7185 L
.09156 .71913 L
.09164 .71977 L
.09176 .72041 L
.09192 .72106 L
.09212 .72169 L
.09234 .72227 L
.09257 .72276 L
.09279 .72313 L
.09299 .72337 L
.0932 .72351 L
.09341 .72357 L
.09363 .72358 L
.09387 .72359 L
.09411 .72362 L
.09437 .72369 L
.09464 .72377 L
.09491 .72381 L
.09517 .72381 L
.09543 .72378 L
.09566 .72373 L
.09591 .72368 L
.09617 .72362 L
.09642 .72355 L
.09664 .72346 L
.09679 .72337 L
.09686 .7233 L
.09685 .72327 L
Mistroke
.09679 .7233 L
.09669 .72341 L
.09659 .72361 L
.09652 .72392 L
.09654 .72436 L
.0967 .72497 L
.09703 .72576 L
.09752 .72672 L
.09818 .72785 L
.09904 .72915 L
.1 .73057 L
.10112 .73202 L
.10232 .73349 L
.10359 .73492 L
.10478 .73622 L
.10606 .73742 L
.1071 .73842 L
.10805 .73927 L
.10888 .73995 L
.10955 .74045 L
.11002 .74076 L
.11031 .74089 L
.11043 .74088 L
.11044 .74081 L
.11037 .74073 L
.11022 .74071 L
.11002 .74076 L
.10983 .74092 L
.10969 .74119 L
.10962 .74155 L
.10962 .74197 L
.10971 .74243 L
.10991 .74296 L
.11023 .74356 L
.11069 .74424 L
.11128 .74501 L
.112 .74585 L
.11279 .74676 L
.11375 .74771 L
.11478 .74872 L
.11597 .74978 L
.11719 .75088 L
.11853 .75207 L
.11991 .75343 L
.12138 .75501 L
.12288 .75677 L
.12453 .75879 L
.12624 .76101 L
.12813 .76343 L
.13024 .76602 L
Mistroke
.13259 .76889 L
.13509 .77167 L
.1377 .77464 L
.14047 .77759 L
.1432 .78061 L
.14602 .78364 L
.14862 .78651 L
.15094 .7892 L
.15337 .79174 L
.15567 .79403 L
.15794 .79616 L
.15987 .79807 L
.16172 .79991 L
.16352 .80164 L
.16531 .80344 L
.16722 .80526 L
.16927 .80732 L
.17155 .80957 L
.17412 .81218 L
.17705 .81511 L
.18036 .81861 L
.18411 .82195 L
.1881 .82616 L
.19251 .83069 L
.19691 .83464 L
.20157 .83936 L
.20643 .84405 L
.21076 .84842 L
.21512 .85315 L
.21906 .85666 L
.22296 .86047 L
.2262 .86342 L
.22915 .86649 L
.23171 .86872 L
.23405 .87064 L
.23611 .87225 L
.23807 .87357 L
.24006 .87475 L
.24208 .87591 L
.24426 .87698 L
.24674 .87822 L
.24957 .87962 L
.25233 .88113 L
.25564 .88283 L
.2592 .88468 L
.26292 .88658 L
.26672 .88841 L
.27032 .89019 L
.27387 .89179 L
.27741 .89335 L
Mistroke
.28086 .89484 L
.28407 .8962 L
.28723 .89751 L
.29027 .89874 L
.29321 .89992 L
.29613 .90105 L
.29903 .90216 L
.30198 .90316 L
.30495 .90428 L
.30798 .90534 L
.3112 .90648 L
.3145 .90771 L
.31803 .90903 L
.32171 .91035 L
.32531 .91175 L
.32916 .91311 L
.33307 .91451 L
.33693 .91594 L
.34091 .91734 L
.34487 .91884 L
.34856 .92039 L
.35247 .92208 L
.35637 .92369 L
.3601 .92532 L
.36387 .92694 L
.36769 .92844 L
.37162 .93 L
.37593 .9316 L
.38022 .93331 L
.38505 .93499 L
.39053 .93682 L
.39557 .9386 L
.40137 .94044 L
.4074 .9422 L
.41419 .94388 L
.41935 .94531 L
.42507 .94664 L
.43115 .94775 L
.43555 .94866 L
.44008 .94941 L
.44395 .94998 L
.44739 .95035 L
.45003 .95054 L
.45212 .95056 L
.45367 .95042 L
.45483 .95017 L
.45562 .94987 L
.4561 .94963 L
.45635 .94951 L
.45642 .94953 L
Mistroke
.45639 .9497 L
.45628 .94999 L
.45606 .95037 L
.45576 .95082 L
.45537 .95132 L
.45495 .95185 L
.45455 .95237 L
.45413 .9529 L
.45369 .95341 L
.45322 .95389 L
.45274 .95432 L
.45232 .95467 L
.45198 .95491 L
.45171 .95506 L
.45145 .95511 L
.45111 .95511 L
.45067 .95507 L
.45008 .95504 L
.44928 .95504 L
.44831 .95508 L
.44721 .95516 L
.44609 .95525 L
.44503 .95533 L
.44407 .9554 L
.44327 .95546 L
.44265 .95551 L
.44219 .95555 L
.44192 .95556 L
.44184 .95557 L
.44201 .95555 L
.44236 .95552 L
.4428 .95549 L
.44324 .95545 L
.44361 .95542 L
.44386 .95541 L
.44393 .9554 L
.44376 .95542 L
.44335 .95545 L
.44275 .9555 L
.44206 .95555 L
.44137 .9556 L
.44074 .95565 L
.44019 .95569 L
.43972 .95573 L
.43936 .95575 L
.43913 .95577 L
.43905 .95577 L
.43912 .95576 L
.43933 .95575 L
.43962 .95572 L
Mistroke
.43998 .95572 L
.44035 .95573 L
.44073 .95578 L
.44107 .95582 L
.44136 .95581 L
.44164 .95572 L
.44194 .95554 L
.44227 .95528 L
.44264 .95499 L
.44303 .95467 L
.44345 .95437 L
.44394 .95411 L
.4445 .95393 L
.44515 .95385 L
.44584 .95384 L
.44655 .95386 L
.44724 .95388 L
.4479 .95386 L
.44851 .95386 L
.4491 .95385 L
.44968 .95381 L
.45028 .95369 L
.4509 .9535 L
.45156 .95322 L
.45223 .95285 L
.45291 .95239 L
.45356 .95184 L
.45416 .95123 L
.45472 .95065 L
.45523 .95018 L
.45569 .94984 L
.4561 .94963 L
.45645 .94951 L
.45671 .94948 L
.45689 .94948 L
.45698 .9495 L
.45699 .94948 L
.45693 .94941 L
.45683 .94926 L
.45673 .94906 L
.45665 .94883 L
.4566 .94858 L
.45658 .94833 L
.45658 .94808 L
.45662 .94786 L
.4567 .94769 L
.45681 .94756 L
.45692 .94747 L
.45701 .9474 L
.45706 .94731 L
Mistroke
.45706 .9472 L
.45698 .94707 L
.45681 .9469 L
.45651 .94667 L
.45607 .94638 L
.45548 .946 L
.45476 .94552 L
.45396 .94496 L
.45306 .94432 L
.45206 .94363 L
.45094 .9429 L
.44969 .94217 L
.44836 .94147 L
.44697 .94085 L
.44553 .94034 L
.44414 .93993 L
.44282 .93961 L
.44165 .93939 L
.44067 .93926 L
.43994 .93919 L
.43944 .93917 L
.43916 .93916 L
.43912 .93914 L
.43928 .93907 L
.43967 .93889 L
.44024 .93852 L
.441 .93785 L
.44198 .9368 L
.44314 .93533 L
.44449 .93342 L
.44592 .93114 L
.44741 .92828 L
.44894 .92513 L
.45048 .92145 L
.45209 .91751 L
.45379 .9127 L
.45549 .90855 L
.45724 .9038 L
.45902 .8986 L
.46074 .89424 L
.46247 .88942 L
.46419 .88464 L
.46595 .88004 L
.46767 .87599 L
.46952 .87202 L
.47157 .86813 L
.47393 .86497 L
.47662 .8618 L
.47961 .85914 L
.48308 .85677 L
Mistroke
.48702 .85478 L
.49131 .85321 L
.4962 .85213 L
.50144 .8515 L
.50708 .85134 L
.51333 .85167 L
.51966 .85252 L
.52668 .85392 L
.53358 .85596 L
.54058 .85844 L
.54784 .86158 L
.55527 .86522 L
.56238 .86959 L
.57016 .87413 L
.57733 .87872 L
.58387 .88412 L
.59051 .889 L
.5967 .89467 L
.60211 .89923 L
.60672 .9041 L
.61097 .90842 L
.61427 .9123 L
.61704 .91551 L
.6196 .91861 L
.62169 .92093 L
.62363 .92282 L
.62557 .92429 L
.6277 .92539 L
.63016 .92615 L
.63297 .92661 L
.63559 .92683 L
.63907 .92682 L
.64326 .9266 L
.6476 .92615 L
.65284 .92547 L
.6585 .92447 L
.66495 .92307 L
.67054 .92121 L
.67702 .91903 L
.68356 .91636 L
.68939 .91327 L
.69572 .90996 L
.7021 .90631 L
.709 .90213 L
.71483 .89849 L
.72144 .8944 L
.72769 .89028 L
.73419 .88601 L
.74094 .88189 L
.74729 .87774 L
Mistroke
.75383 .87362 L
.76015 .86956 L
.76689 .86542 L
.77275 .86166 L
.77884 .85772 L
.78484 .85386 L
.79054 .84978 L
.79612 .84608 L
.80132 .84253 L
.80628 .83875 L
.81128 .83521 L
.81606 .8317 L
.82074 .82826 L
.82548 .82479 L
.82966 .82163 L
.83384 .81858 L
.83779 .81572 L
.84156 .81289 L
.84496 .81029 L
.84805 .80787 L
.85059 .80574 L
.85277 .80385 L
.85451 .80222 L
.85584 .80082 L
.85685 .79966 L
.85756 .79881 L
.85797 .79822 L
.85814 .79789 L
.85813 .79782 L
.85798 .79798 L
.85778 .7983 L
.85759 .79871 L
.85743 .79918 L
.85727 .79969 L
.85708 .80025 L
.85682 .80085 L
.85647 .80146 L
.85599 .80207 L
.85539 .80261 L
.8547 .80308 L
.85393 .80347 L
.85313 .80378 L
.85233 .80402 L
.85158 .80419 L
.85087 .80435 L
.85021 .80451 L
.84963 .8047 L
.84914 .80491 L
.84875 .80512 L
.84846 .80528 L
Mistroke
.84828 .80537 L
.8482 .80539 L
.84822 .80537 L
.84832 .80533 L
.84848 .80527 L
.84864 .80523 L
.84881 .8052 L
.84898 .80518 L
.84917 .80516 L
.84938 .80514 L
.84962 .80514 L
.84987 .80514 L
.85013 .80515 L
.85038 .80516 L
.85059 .80516 L
.85075 .80513 L
.85084 .80508 L
.85085 .80498 L
.85078 .80485 L
.85063 .8047 L
.85043 .80451 L
.85018 .8043 L
.84994 .80405 L
.84971 .80375 L
.8495 .80342 L
.84931 .80311 L
.84912 .80286 L
.84893 .80273 L
.84873 .80278 L
.84849 .80303 L
.84824 .80348 L
.848 .80407 L
.84779 .80475 L
.84761 .80545 L
.8475 .8061 L
.84745 .80666 L
.84749 .80711 L
.84763 .80746 L
.84789 .8077 L
.84827 .8078 L
.84872 .80776 L
.84921 .80758 L
.84974 .80721 L
.85028 .80671 L
.85081 .8061 L
.8513 .80545 L
.85172 .80482 L
.85205 .80429 L
.85229 .80388 L
.85243 .80359 L
Mistroke
.85251 .80338 L
.85253 .8032 L
.85252 .80305 L
.8525 .80291 L
.85251 .80278 L
.85255 .80269 L
.8526 .80266 L
.85267 .8027 L
.85272 .80282 L
.85272 .80302 L
.85266 .80323 L
.85255 .80342 L
.85238 .80353 L
.85222 .80349 L
.85213 .80318 L
.85221 .80251 L
.85254 .80136 L
.85319 .79966 L
.85418 .79731 L
.85556 .7942 L
.85729 .79048 L
.85937 .78607 L
.86191 .78084 L
.86495 .77471 L
.86798 .76819 L
.87142 .76048 L
.87503 .75221 L
.87859 .7442 L
.88251 .73439 L
.88611 .72508 L
.88983 .71345 L
.89355 .7041 L
.89722 .69315 L
.90074 .68201 L
.90463 .66944 L
.90793 .65961 L
.91164 .64856 L
.91538 .63604 L
.91876 .62661 L
.92233 .61608 L
.92576 .60546 L
.92883 .59656 L
.93171 .58726 L
.93421 .57821 L
.93631 .56942 L
.93796 .56071 L
.93918 .55191 L
.93998 .54355 L
.94041 .53455 L
.94055 .52575 L
Mistroke
.94042 .51653 L
.94005 .50665 L
.9395 .49796 L
.93884 .48853 L
.9381 .47827 L
.93732 .46937 L
.93656 .45947 L
.93584 .45035 L
.93516 .44083 L
.93452 .43126 L
.93389 .42141 L
.93322 .41263 L
.93248 .40332 L
.93165 .39397 L
.93075 .38527 L
.92976 .37683 L
.92874 .36834 L
.92772 .36054 L
.92675 .35343 L
.9258 .3468 L
.92487 .34035 L
.92393 .33538 L
.92297 .33061 L
.92198 .32634 L
.921 .32278 L
.91998 .31956 L
.91889 .31681 L
.9177 .31436 L
.91638 .31207 L
.91504 .3099 L
.91337 .30757 L
.91144 .30489 L
.90932 .30187 L
.90674 .29828 L
.90391 .29408 L
.90054 .28929 L
.89704 .28364 L
.89301 .27788 L
.88898 .27142 L
.8844 .26455 L
.87997 .25749 L
.87504 .24962 L
.86986 .24224 L
.86523 .23502 L
.86015 .22753 L
.8548 .21989 L
.84961 .21253 L
.84534 .20588 L
.84049 .19901 L
.83574 .19237 L
Mistroke
.83074 .18577 L
.82631 .1797 L
.82243 .17413 L
.81841 .16875 L
.81458 .16374 L
.81133 .15938 L
.80832 .1553 L
.80588 .15206 L
.80391 .14936 L
.80232 .14718 L
.8012 .14559 L
.80046 .14455 L
.80011 .14403 L
.80013 .14393 L
.80041 .14411 L
.80081 .14445 L
.80127 .14486 L
.80172 .14526 L
.80208 .14553 L
.80228 .14562 L
.80234 .14556 L
.80227 .14539 L
.80211 .14513 L
.80187 .14481 L
.8016 .14442 L
.80132 .144 L
.80104 .14355 L
.80078 .1431 L
.80055 .14265 L
.80034 .14221 L
.80015 .14179 L
.8 .14139 L
.79989 .14105 L
.79983 .14079 L
.79981 .14065 L
.79982 .14064 L
.79985 .14076 L
.79991 .141 L
.79998 .14133 L
.80006 .14171 L
.80014 .14211 L
.80026 .14254 L
.80042 .14299 L
.80061 .14343 L
.80083 .14388 L
.80106 .14432 L
.80129 .14472 L
.80152 .14506 L
.80174 .14534 L
.80194 .14554 L
Mistroke
.80211 .14565 L
.80225 .14568 L
.80238 .14565 L
.80249 .1456 L
.80259 .14556 L
.80269 .14558 L
.80278 .14567 L
.80285 .1458 L
.80286 .14591 L
.80278 .14595 L
.80256 .14588 L
.80217 .14569 L
.80155 .14534 L
.80068 .14479 L
.79954 .14405 L
.79823 .14312 L
.79658 .142 L
.79473 .14077 L
.79258 .13939 L
.79046 .13797 L
.78815 .13651 L
.78588 .1351 L
.78364 .13379 L
.78155 .13262 L
.77978 .13165 L
.77818 .13088 L
.77683 .13032 L
.77579 .12995 L
.77497 .12974 L
.77436 .12965 L
.77396 .12963 L
.77375 .12966 L
.77367 .12973 L
.77371 .12982 L
.77381 .12991 L
.77392 .12997 L
.77403 .13 L
.77411 .13001 L
.77417 .13001 L
.7742 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
Mistroke
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77422 .13001 L
.77429 .13002 L
.77445 .13004 L
.77471 .1301 L
.77501 .13017 L
.7753 .13026 L
.77552 .13036 L
.77559 .13048 L
.77542 .13057 L
.77492 .13058 L
.77397 .13049 L
.77248 .13024 L
.77038 .12978 L
.76759 .12907 L
.76449 .12803 L
Mistroke
.76041 .12664 L
.75581 .12491 L
.75047 .12267 L
.74446 .12018 L
.73737 .11738 L
.73072 .1146 L
.72306 .11118 L
.71443 .10723 L
.70685 .1039 L
.69831 .09998 L
.68984 .09598 L
.6808 .0916 L
.67286 .08809 L
.66456 .08408 L
.6564 .0803 L
.64749 .0764 L
.64064 .07299 L
.6327 .06963 L
.6257 .0664 L
.61854 .06357 L
.61174 .061 L
.60529 .05879 L
.5986 .0567 L
.59212 .05518 L
.58546 .0539 L
.57819 .05288 L
.57136 .05208 L
.5638 .05151 L
.55617 .05112 L
.54803 .05086 L
.53969 .05071 L
.53203 .05061 L
.52379 .05055 L
.51485 .05048 L
.50786 .05036 L
.49983 .05018 L
.49181 .04996 L
.48451 .04974 L
.477 .04952 L
.47011 .04928 L
.46366 .04903 L
.45727 .04875 L
.45125 .04846 L
.44539 .04817 L
.43946 .04791 L
.4341 .04767 L
.42867 .04748 L
.4234 .04738 L
.41819 .04743 L
.41316 .04765 L
Mistroke
.40818 .0481 L
.40298 .04881 L
.39806 .04981 L
.39287 .05115 L
.38722 .05284 L
.38244 .05484 L
.37721 .05718 L
.37182 .05981 L
.3661 .06273 L
.36034 .06585 L
.35509 .06918 L
.34925 .07265 L
.3432 .07622 L
.33715 .07992 L
.33068 .08345 L
.32449 .08713 L
.3181 .09059 L
.31187 .09391 L
.30544 .09719 L
.29902 .10036 L
.29225 .10337 L
.2863 .10629 L
.28017 .10904 L
.27435 .11169 L
.26857 .11426 L
.26347 .11682 L
.25842 .11935 L
.25354 .1219 L
.24896 .12443 L
.24451 .12701 L
.24003 .12968 L
.23603 .13224 L
.23217 .13477 L
.22831 .13734 L
.22462 .13995 L
.22143 .14235 L
.21823 .14484 L
.215 .14746 L
.21184 .15015 L
.20887 .15297 L
.20584 .15601 L
.2027 .15938 L
.19965 .16307 L
.19632 .16734 L
.19289 .17189 L
.18915 .17707 L
.18506 .18281 L
.18086 .18882 L
.17624 .19529 L
.17134 .20263 L
Mistroke
.16648 .20905 L
.16138 .21634 L
.1562 .22369 L
.15094 .23155 L
.14568 .23864 L
.14048 .24609 L
.13513 .25399 L
.12988 .26114 L
.12473 .2689 L
.11956 .27631 L
.11468 .28475 L
.1102 .29237 L
.10586 .30065 L
.10258 .30912 L
.09849 .31847 L
.09556 .3272 L
.09265 .33667 L
.09001 .34555 L
.08786 .35357 L
.08593 .36135 L
.08439 .36907 L
.08317 .37626 L
.08223 .38251 L
.08152 .38716 L
.081 .392 L
.08061 .39523 L
.08033 .39793 L
.08009 .39991 L
.0799 .4011 L
.07977 .40165 L
.07971 .40178 L
.07971 .40164 L
.0798 .40131 L
.07996 .40088 L
.08018 .40053 L
.08044 .40032 L
.08072 .40018 L
.081 .40011 L
.08129 .4001 L
.08157 .4001 L
.08186 .40009 L
.08213 .40009 L
.08239 .40009 L
.0826 .40009 L
.08276 .40007 L
.08285 .40004 L
.08288 .4 L
.08286 .39997 L
.08282 .39995 L
.08279 .39996 L
Mistroke
.0828 .40001 L
.08287 .40011 L
.08301 .40025 L
.0832 .40043 L
.08343 .40063 L
.08366 .40083 L
.08386 .40099 L
.08405 .40111 L
.08425 .40121 L
.08447 .40132 L
.08474 .40144 L
.08509 .40156 L
.08552 .40175 L
.08603 .40204 L
.08659 .40249 L
.08718 .40315 L
.08779 .40411 L
.08841 .40544 L
.089 .40714 L
.08959 .40939 L
.09018 .41195 L
.09071 .41509 L
.09105 .41887 L
.09117 .4226 L
.09103 .42662 L
.09061 .43112 L
.08988 .43581 L
.08881 .44065 L
.0874 .4454 L
.08586 .44996 L
.08418 .4545 L
.08239 .45821 L
.08058 .46191 L
.0789 .46529 L
.07745 .4678 L
.07611 .46986 L
.07483 .47141 L
.07367 .47244 L
.07278 .47297 L
.07222 .47307 L
.07193 .47281 L
.0718 .47226 L
.07175 .47148 L
.07175 .47055 L
.07179 .46955 L
.07177 .4685 L
.07158 .46749 L
.07131 .46654 L
.07105 .46562 L
.07079 .4647 L
Mistroke
.07055 .46379 L
.07032 .46289 L
.07013 .46197 L
.06999 .46105 L
.0699 .46017 L
.06985 .45937 L
.06986 .45868 L
.06989 .45812 L
.06995 .45769 L
.07 .45735 L
.07005 .45708 L
.07007 .45688 L
.07008 .45672 L
.07008 .45662 L
.07008 .45661 L
.07008 .4567 L
.07007 .45689 L
.07006 .45719 L
.07005 .45755 L
.07004 .45792 L
.07003 .45824 L
.07002 .45845 L
.07002 .45859 L
.07002 .45868 L
.07002 .45867 L
.07002 .45863 L
.07001 .45855 L
.06998 .45843 L
.06994 .4582 L
.06991 .45789 L
.0699 .45751 L
.06993 .45706 L
.07 .45662 L
.07013 .45623 L
.0703 .45591 L
.07051 .45566 L
.07076 .45549 L
.07104 .45538 L
.07132 .45535 L
.0716 .45537 L
.07189 .45541 L
.07216 .45546 L
.07241 .45551 L
.07263 .45554 L
.0728 .45554 L
.07293 .45554 L
.073 .45554 L
.07302 .45554 L
.073 .45554 L
.07296 .45554 L
Mistroke
.07291 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07295 .45554 L
.07305 .45556 L
.07315 .45561 L
.07321 .45571 L
.0732 .45582 L
.07311 .45594 L
.07291 .45603 L
.07257 .45603 L
.07208 .45593 L
.07144 .45567 L
.07068 .45527 L
.06981 .4547 L
.06887 .45399 L
.06794 .45314 L
.06697 .45217 L
.06597 .45101 L
.06503 .4497 L
.06422 .4482 L
.06362 .4465 L
.06323 .44471 L
.06303 .44277 L
.06296 .44076 L
.06297 .43864 L
.06304 .43656 L
.06315 .43438 L
.06327 .43221 L
.06342 .42994 L
.06361 .42776 L
.06384 .42555 L
.06407 .42346 L
.06429 .42153 L
.06448 .41983 L
Mistroke
.06464 .41835 L
.06478 .41713 L
.06491 .41617 L
.06505 .41543 L
.06519 .41488 L
.06536 .4145 L
.06554 .41426 L
.06573 .41415 L
.0659 .41415 L
.06603 .41423 L
.06613 .41437 L
.06621 .41451 L
.06629 .41464 L
.06643 .41472 L
.06664 .41474 L
.06695 .41469 L
.06736 .41459 L
.06785 .41444 L
.06841 .41426 L
.06903 .41404 L
.06969 .41379 L
.07039 .41354 L
.07107 .41328 L
.07178 .41302 L
.0725 .41278 L
.07318 .41255 L
.07383 .41235 L
.07446 .41219 L
.07504 .41208 L
.07556 .41201 L
.07598 .41199 L
.07632 .412 L
.07659 .41203 L
.07678 .41207 L
.07692 .4121 L
.07703 .41212 L
.07711 .41212 L
.07716 .41212 L
.07717 .41212 L
.07715 .41212 L
.07711 .41212 L
.07706 .41212 L
.07703 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41213 L
.07702 .41215 L
.07705 .41221 L
Mistroke
.0771 .41228 L
.07713 .41235 L
.07715 .41239 L
.07714 .41237 L
.07707 .41227 L
.07693 .41208 L
.07673 .41181 L
.07649 .41146 L
.07624 .41107 L
.076 .41067 L
.07578 .41026 L
.07561 .40985 L
.07546 .40941 L
.07537 .40893 L
.07533 .4084 L
.07538 .40784 L
.07552 .40725 L
.07576 .40661 L
.0761 .40593 L
.07653 .40524 L
.07703 .40453 L
.07756 .40386 L
.07807 .40317 L
.07855 .40247 L
.07894 .40181 L
.07927 .40124 L
.07953 .40077 L
.07973 .40036 L
.07987 .39999 L
.07998 .39969 L
.08007 .39943 L
.08014 .39922 L
.08022 .39904 L
.08031 .39885 L
.08044 .39862 L
.0806 .39835 L
.08081 .39803 L
.08107 .39767 L
.08137 .39726 L
.08166 .39681 L
.08196 .39633 L
.08224 .39591 L
.0825 .39563 L
.08273 .39546 L
.08291 .39543 L
.08303 .39554 L
.08309 .39576 L
.08311 .39607 L
.08308 .39644 L
.08303 .39684 L
Mistroke
.08297 .39727 L
.0829 .39774 L
.08283 .39825 L
.08275 .39877 L
.08266 .39927 L
.08258 .39967 L
.08253 .39997 L
.08253 .40016 L
.08263 .40025 L
.08284 .40025 L
.08318 .4002 L
.08364 .40014 L
.08422 .4001 L
.08491 .40013 L
.0856 .40024 L
.08638 .40041 L
.08718 .40062 L
.08795 .40085 L
.08874 .40109 L
.08941 .40133 L
.09 .40158 L
.09049 .40182 L
.09086 .40204 L
.0911 .40223 L
.09122 .40238 L
.09124 .40249 L
.0912 .40255 L
.09113 .40257 L
.09106 .40255 L
.09099 .40252 L
.09095 .40248 L
.09093 .40244 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09098 .40243 L
.09106 .40242 L
.09114 .40242 L
.09119 .40242 L
.09117 .40242 L
.09108 .40243 L
.09089 .40243 L
.09058 .40243 L
.09016 .40243 L
.08966 .40244 L
Mistroke
.08912 .40244 L
.08857 .40244 L
.08801 .40245 L
.08755 .40245 L
.08702 .40246 L
.0865 .40246 L
.08602 .40246 L
.08565 .40246 L
.0854 .40247 L
.08526 .40247 L
.08521 .40247 L
.08522 .40247 L
.0853 .40247 L
.08539 .40246 L
.08546 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08549 .40246 L
.0855 .40244 L
.08554 .40239 L
.08558 .40231 L
.08562 .40225 L
.08564 .40223 L
.08562 .40231 L
.08556 .40248 L
.08542 .40272 L
.08521 .40301 L
.08494 .40332 L
.08464 .40361 L
.08432 .40385 L
.08401 .40402 L
.08374 .40414 L
.08351 .40419 L
.08335 .4042 L
.08327 .40416 L
.08332 .40404 L
.0835 .4038 L
.08382 .40344 L
.08428 .403 L
.08486 .40254 L
.08557 .40214 L
.08638 .4019 L
.08723 .40188 L
.08809 .40214 L
.08895 .40269 L
.08978 .40353 L
.09054 .40465 L
.09124 .40604 L
.09184 .40754 L
Mistroke
.0923 .40936 L
.09265 .41129 L
.09287 .41345 L
.09295 .41575 L
.09291 .41793 L
.0928 .42018 L
.09267 .42234 L
.09247 .42441 L
.09217 .42656 L
.09182 .42847 L
.0914 .43048 L
.09089 .43266 L
.09023 .43493 L
.08943 .43741 L
.08844 .44019 L
.08722 .44278 L
.08573 .44583 L
.08431 .44877 L
.0827 .45207 L
.08104 .45561 L
.07897 .45893 L
.07673 .46311 L
.07483 .4667 L
.0726 .47099 L
.07072 .47537 L
.06874 .48062 L
.06737 .48396 L
.06576 .49041 L
.0645 .4956 L
.06383 .50078 L
.06307 .50586 L
.06264 .50994 L
.06234 .51454 L
.06213 .52102 L
.06218 .52561 L
.06239 .52938 L
.06266 .53295 L
.06287 .53651 L
.0631 .53904 L
.06338 .54159 L
.06369 .5436 L
.064 .54469 L
.06427 .54545 L
.06453 .54596 L
.06477 .54624 L
.06504 .54636 L
.06529 .54637 L
.06553 .54634 L
.06573 .54628 L
.06596 .54618 L
Mistroke
.06624 .54607 L
.0665 .54597 L
.06672 .54588 L
.0669 .54583 L
.06702 .54581 L
.06708 .54581 L
.06711 .54581 L
.06709 .54581 L
.06705 .54581 L
.06701 .54581 L
.06698 .54581 L
.06697 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54579 L
.06697 .54574 L
.06697 .54566 L
.06698 .54559 L
.06698 .54556 L
.06698 .54558 L
.06697 .54568 L
.06695 .54587 L
.06693 .54616 L
.06691 .54654 L
.06688 .54698 L
.06686 .54747 L
.06684 .54797 L
.06682 .54846 L
.0668 .54894 L
.06679 .54941 L
.06677 .54987 L
.06676 .55028 L
.06675 .55061 L
.06675 .55083 L
.06675 .55095 L
.06676 .55099 L
.06678 .55097 L
.06679 .5509 L
.0668 .55081 L
.06681 .55075 L
.0668 .55073 L
.0668 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
Mistroke
.06679 .55072 L
.06678 .55069 L
.06675 .55063 L
.0667 .55055 L
.06664 .55041 L
.06657 .55025 L
.06651 .55008 L
.06647 .54997 L
.06645 .54996 L
.06647 .55009 L
.06656 .55041 L
.06679 .55102 L
.06715 .55196 L
.06769 .55334 L
.06846 .55496 L
.06941 .55748 L
.07098 .56085 L
.0726 .56355 L
.07454 .5676 L
.07722 .57134 L
.07961 .57551 L
.08211 .58064 L
.08391 .5839 L
.08706 .58924 L
.08872 .59244 L
.09155 .59752 L
.09357 .60143 L
.09518 .6052 L
.09687 .60816 L
.09799 .61182 L
.09891 .61569 L
.09969 .61823 L
.10016 .62203 L
.1003 .62475 L
.1003 .62859 L
.10018 .63112 L
.09994 .63475 L
.09962 .63867 L
.09925 .64173 L
.09891 .64565 L
.09848 .64862 L
.09795 .65293 L
.09733 .65569 L
.09668 .65935 L
.09596 .66281 L
.09509 .66664 L
.09406 .66944 L
.09314 .67305 L
.0921 .67601 L
.09096 .67848 L
Mistroke
.09001 .68199 L
.08919 .68438 L
.0885 .68698 L
.08791 .68982 L
.08742 .69212 L
.08711 .69403 L
.08698 .69596 L
.08701 .69812 L
.08719 .70027 L
.08749 .70192 L
.08783 .7036 L
.08822 .7054 L
.08867 .7072 L
.0891 .7088 L
.08951 .71009 L
.08998 .7115 L
.0904 .71314 L
.09086 .71439 L
.09123 .71559 L
.09164 .71676 L
.09205 .71782 L
.09247 .71874 L
.09288 .71944 L
.09324 .72004 L
.09356 .72053 L
.09383 .7209 L
.09405 .72117 L
.09423 .72136 L
.09432 .72148 L
.09436 .72152 L
.09436 .72151 L
.09434 .72146 L
.0943 .72138 L
.09426 .7213 L
.09422 .72125 L
.09421 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.00440917 0.782187 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.0942 .72123 m
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72122 L
.0942 .7212 L
.0942 .72116 L
.0942 .72112 L
.09421 .7211 L
.09421 .7211 L
.0942 .72113 L
.0942 .72122 L
.0942 .72135 L
.0942 .72154 L
.09419 .72176 L
.09418 .722 L
.09418 .72225 L
.09417 .72253 L
Mistroke
.09417 .72275 L
.09416 .723 L
.09416 .72325 L
.09415 .72347 L
.09415 .72365 L
.09414 .72377 L
.09414 .72385 L
.09414 .72388 L
.09414 .72387 L
.09414 .72384 L
.09414 .72379 L
.09414 .72376 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09416 .72378 L
.09422 .72382 L
.0943 .72385 L
.09433 .72387 L
.09431 .72385 L
.09424 .7238 L
.09407 .72371 L
.09378 .72358 L
.09334 .7234 L
.0928 .7232 L
.09224 .72297 L
.09174 .72274 L
.09128 .7225 L
.09081 .72226 L
.09034 .72203 L
.08984 .72182 L
.08935 .72163 L
.08896 .72149 L
.08872 .72138 L
Mistroke
.08861 .72132 L
.08857 .72131 L
.08859 .72132 L
.08866 .72136 L
.08874 .72139 L
.08877 .72142 L
.08877 .72144 L
.08876 .72144 L
.08873 .72144 L
.08869 .72145 L
.08865 .72145 L
.08863 .72145 L
.08864 .72145 L
.0887 .72144 L
.0888 .72144 L
.08896 .72143 L
.08917 .72143 L
.08941 .72142 L
.08968 .72141 L
.08996 .72139 L
.09023 .72138 L
.09049 .72137 L
.09075 .72136 L
.091 .72135 L
.09123 .72134 L
.09141 .72134 L
.09154 .72133 L
.09161 .72133 L
.09163 .72133 L
.09162 .72133 L
.09158 .72133 L
.09153 .72133 L
.0915 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
Mistroke
.09149 .72133 L
.09148 .72133 L
.09147 .72132 L
.09145 .72129 L
.09141 .72125 L
.09137 .72122 L
.09135 .7212 L
.09136 .72121 L
.09142 .72126 L
.09152 .72136 L
.09167 .7215 L
.09188 .72168 L
.09211 .7219 L
.09238 .72213 L
.09265 .72238 L
.09291 .72263 L
.09317 .72288 L
.09343 .72312 L
.09367 .72334 L
.09389 .72353 L
.09407 .72369 L
.09419 .7238 L
.09426 .72386 L
.09428 .72388 L
.09427 .72386 L
.09423 .72383 L
.09419 .72379 L
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .7229 L
.09417 .72264 L
.09417 .72238 L
.09418 .72212 L
Mistroke
.0942 .72188 L
.09423 .7217 L
.09428 .72158 L
.09432 .72149 L
.09434 .72141 L
.09433 .72133 L
.09427 .72122 L
.09417 .72105 L
.09402 .7208 L
.09382 .72046 L
.09359 .72005 L
.09333 .71959 L
.09307 .71909 L
.09281 .71859 L
.09256 .71812 L
.09231 .71764 L
.09207 .71718 L
.09185 .71677 L
.09168 .71645 L
.09156 .71622 L
.09149 .7161 L
.09147 .71606 L
.09148 .71608 L
.09152 .71615 L
.09156 .71623 L
.09159 .71629 L
.09161 .71631 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09162 .71634 L
.09163 .71636 L
.09166 .71641 L
.09169 .71647 L
.09172 .71652 L
.09172 .71654 L
.09167 .71648 L
.09157 .7163 L
.09136 .71611 L
.0911 .71584 L
.09087 .71552 L
.09044 .71522 L
.09025 .71484 L
.0901 .7144 L
.09003 .71397 L
.08997 .71358 L
.08996 .71317 L
.09002 .71265 L
.09013 .71217 L
.09026 .71179 L
.09043 .71147 L
.09064 .71131 L
.09096 .71122 L
.09128 .71119 L
.09155 .71121 L
.09171 .71124 L
.09182 .71128 L
.0919 .71129 L
.09193 .71124 L
.09192 .71117 L
.09186 .71114 L
.09175 .71115 L
.09156 .71122 L
.0913 .71139 L
.09102 .71168 L
.09077 .7121 L
.09057 .71259 L
.09044 .71314 L
.09039 .71359 L
.09037 .71403 L
.09035 .71447 L
.09034 .71488 L
.09036 .71537 L
.09043 .71583 L
.09058 .71619 L
.09079 .71639 L
Mistroke
.09104 .71648 L
.09132 .71651 L
.09155 .71649 L
.09168 .71641 L
.09172 .71633 L
.09173 .71632 L
.09171 .71632 L
.09168 .71632 L
.09164 .71632 L
.09162 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09161 .71637 L
.0916 .71644 L
.0916 .71651 L
.0916 .71654 L
.0916 .71652 L
.09161 .71643 L
.09161 .71626 L
.09162 .71597 L
.09163 .71558 L
.09164 .71512 L
.09165 .71462 L
.09166 .71411 L
.09168 .71364 L
.09169 .71319 L
Mistroke
.0917 .71273 L
.09171 .71226 L
.09172 .71182 L
.09173 .71147 L
.09174 .71124 L
.09174 .71112 L
.09174 .71108 L
.09174 .71109 L
.09174 .71116 L
.09174 .71124 L
.09174 .71129 L
.09173 .7113 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09174 .71131 L
.09174 .71132 L
.09177 .71134 L
.09181 .71138 L
.09184 .71142 L
.09186 .71143 L
.09185 .71143 L
.0918 .71138 L
.0917 .71129 L
.09155 .71116 L
.09134 .71099 L
.0911 .71079 L
.09083 .71056 L
.09056 .71034 L
.09031 .71016 L
.09006 .70999 L
.08981 .70978 L
.08956 .70952 L
.08934 .70921 L
.08916 .70888 L
.08905 .70849 L
.08899 .70804 L
.08898 .70754 L
.08901 .70704 L
.08905 .70654 L
.08911 .7061 L
.08915 .70573 L
.08917 .70538 L
.08918 .70499 L
.08919 .70458 L
.0892 .70423 L
.08921 .70393 L
.08922 .70365 L
Mistroke
.08923 .70332 L
.08923 .70293 L
.08924 .70254 L
.08925 .70215 L
.08927 .7017 L
.08928 .70121 L
.08929 .70074 L
.08931 .70026 L
.08932 .69979 L
.08933 .69936 L
.08934 .69903 L
.08934 .69881 L
.08935 .6987 L
.08935 .69866 L
.08935 .69868 L
.08934 .69875 L
.08934 .69882 L
.08934 .69887 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .699 L
.08934 .69902 L
.08934 .69901 L
.08934 .69895 L
.08934 .69885 L
.08934 .69871 L
.08935 .69852 L
.08935 .69829 L
.08936 .69805 L
.08937 .69779 L
.08938 .69754 L
.08938 .69728 L
.08939 .69704 L
.08939 .6968 L
.0894 .6966 L
.0894 .69644 L
.08941 .69632 L
Mistroke
.08941 .69626 L
.08941 .69624 L
.08941 .69625 L
.08941 .69629 L
.08941 .69634 L
.08941 .69638 L
.08944 .69643 L
.08948 .6965 L
.08951 .69657 L
.08953 .6966 L
.08952 .69658 L
.08947 .69649 L
.08937 .69632 L
.08922 .69604 L
.08902 .69566 L
.08879 .6952 L
.08853 .69472 L
.08827 .69422 L
.08802 .69375 L
.08777 .6933 L
.08753 .69283 L
.08729 .69237 L
.08709 .69197 L
.08695 .69171 L
.08687 .69156 L
.08683 .69149 L
.08681 .69146 L
.08678 .69141 L
.08673 .69131 L
.08662 .69112 L
.08645 .69079 L
.08622 .69034 L
.08596 .68984 L
.08569 .68933 L
.08544 .68886 L
.0852 .68841 L
.08496 .68796 L
.08471 .6875 L
.08449 .68707 L
.08432 .68673 L
.0842 .68651 L
.08413 .68639 L
.08411 .68635 L
.08412 .68636 L
.08416 .68643 L
.0842 .68651 L
.08423 .68655 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
Mistroke
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08427 .68656 L
.08431 .68648 L
.08435 .68633 L
.08437 .68628 L
.08436 .68633 L
.0843 .68646 L
.0842 .68676 L
.08403 .68732 L
.08379 .68819 L
.08351 .68933 L
.08321 .69045 L
.08291 .69151 L
.08262 .69244 L
.08235 .69332 L
.08207 .69419 L
.08179 .69507 L
.08152 .69599 L
.08131 .69661 L
.08116 .69672 L
.08106 .6965 L
.08103 .69612 L
.08107 .69559 L
.08117 .69486 L
.08133 .69414 L
.08152 .69341 L
.08176 .69262 L
.08204 .69179 L
.08234 .69095 L
.08264 .69013 L
.08291 .68935 L
.08318 .68865 L
.08345 .68801 L
.08372 .68742 L
.08397 .68686 L
.08416 .68631 L
.0843 .68579 L
.08438 .68533 L
.08441 .68497 L
.0844 .68467 L
.08437 .68447 L
.08433 .68435 L
.08431 .68429 L
.0843 .68425 L
.0843 .68423 L
.0843 .6842 L
Mistroke
.0843 .68415 L
.0843 .684 L
.08431 .68374 L
.08432 .68338 L
.08433 .6829 L
.08435 .68227 L
.08437 .68151 L
.0844 .68079 L
.08443 .68004 L
.08449 .67924 L
.08455 .67836 L
.08461 .6774 L
.08465 .67658 L
.08467 .67581 L
.08464 .67504 L
.08458 .67425 L
.08446 .67344 L
.08428 .6726 L
.08404 .67184 L
.08378 .67091 L
.08353 .66984 L
.08331 .66874 L
.08312 .66774 L
.08291 .66659 L
.08268 .66515 L
.08244 .6637 L
.08222 .6624 L
.08201 .66085 L
.08177 .65914 L
.08158 .65777 L
.08138 .65618 L
.08122 .65435 L
.0811 .65291 L
.08099 .65132 L
.08083 .65 L
.08064 .64848 L
.08043 .64693 L
.08024 .64573 L
.08004 .64454 L
.07984 .64335 L
.07962 .64241 L
.07939 .64148 L
.07917 .6406 L
.07898 .6398 L
.07881 .63909 L
.07862 .63845 L
.07838 .6378 L
.07812 .63712 L
.07786 .63636 L
.07761 .63547 L
Mistroke
.07735 .63445 L
.07709 .63346 L
.07683 .63244 L
.07661 .63125 L
.07641 .62992 L
.07625 .62883 L
.07607 .62736 L
.07586 .6262 L
.07565 .62497 L
.07547 .62365 L
.07534 .62241 L
.07527 .62143 L
.07524 .62052 L
.07525 .61968 L
.07529 .61899 L
.07537 .61848 L
.07545 .6181 L
.07553 .61791 L
.07557 .61778 L
.07558 .61768 L
.07556 .61756 L
.0755 .61738 L
.07539 .61709 L
.07521 .61668 L
.07497 .61614 L
.07467 .61549 L
.0743 .61471 L
.07389 .61382 L
.07345 .61274 L
.07301 .61144 L
.07258 .60989 L
.07218 .60825 L
.07183 .60637 L
.07151 .60438 L
.07121 .60217 L
.07095 .60003 L
.0707 .59769 L
.07048 .59541 L
.07026 .59302 L
.07006 .59048 L
.06986 .58811 L
.06967 .58559 L
.06952 .58317 L
.06937 .58098 L
.06921 .57885 L
.06904 .57697 L
.06888 .57536 L
.06876 .57396 L
.06868 .57282 L
.06865 .57191 L
Mistroke
.06866 .57118 L
.06869 .57062 L
.06875 .57024 L
.0688 .57001 L
.06884 .56992 L
.06885 .56991 L
.06885 .56997 L
.06885 .57006 L
.06884 .57017 L
.06884 .57027 L
.06884 .57037 L
.06883 .57044 L
.06883 .57049 L
.06883 .57054 L
.06883 .57059 L
.06884 .57064 L
.06887 .57066 L
.06892 .57063 L
.06896 .57049 L
.06899 .57023 L
.069 .56984 L
.06896 .56931 L
.0689 .56865 L
.0688 .56786 L
.06867 .56693 L
.06851 .56583 L
.0683 .56458 L
.06806 .56317 L
.06777 .56149 L
.06745 .55983 L
.06712 .558 L
.06677 .55602 L
.06642 .55406 L
.06606 .55203 L
.06571 .54987 L
.06537 .54756 L
.06505 .54495 L
.06472 .54249 L
.06441 .53963 L
.06411 .53659 L
.06381 .5336 L
.06353 .53017 L
.06327 .52723 L
.06305 .52383 L
.06285 .52108 L
.06271 .51837 L
.06261 .51546 L
.06258 .51252 L
.06262 .50992 L
.06274 .50739 L
Mistroke
.06295 .5052 L
.06324 .50311 L
.06358 .5011 L
.06395 .49906 L
.0643 .49715 L
.06463 .49497 L
.06495 .49284 L
.06529 .49046 L
.06564 .48803 L
.06601 .48555 L
.06638 .48293 L
.06674 .48035 L
.06707 .47772 L
.06738 .47506 L
.06769 .47265 L
.068 .47025 L
.06833 .46811 L
.06868 .46629 L
.06908 .46466 L
.06953 .46326 L
.07001 .46219 L
.07048 .46135 L
.07092 .46069 L
.07132 .46021 L
.07168 .45984 L
.07202 .45955 L
.07235 .45929 L
.07269 .45903 L
.07305 .45875 L
.07344 .45843 L
.07378 .45807 L
.07411 .45767 L
.0744 .45724 L
.07464 .45683 L
.07482 .45643 L
.075 .4561 L
.07517 .45583 L
.07532 .45565 L
.07544 .45554 L
.0755 .45549 L
.0755 .45547 L
.07548 .45548 L
.07545 .45551 L
.07543 .45555 L
.07544 .45562 L
.07553 .4557 L
.07573 .45576 L
.07605 .45579 L
.07649 .45579 L
.07703 .45574 L
Mistroke
.07766 .45566 L
.07827 .45552 L
.07905 .45533 L
.07976 .4551 L
.08049 .45485 L
.08123 .45458 L
.08193 .45432 L
.08252 .45407 L
.083 .45382 L
.08338 .45358 L
.08367 .45335 L
.08385 .45316 L
.08396 .453 L
.08402 .45289 L
.08404 .45283 L
.08403 .45281 L
.08401 .45283 L
.08396 .45287 L
.08392 .45291 L
.0839 .45292 L
.08392 .45287 L
.08396 .4528 L
.08401 .45272 L
.08403 .45267 L
.08401 .45267 L
.08394 .45275 L
.08382 .45293 L
.08365 .45324 L
.08342 .45369 L
.08314 .45423 L
.08283 .4548 L
.08251 .45536 L
.0822 .45594 L
.08189 .45647 L
.08159 .457 L
.08128 .45754 L
.08087 .45804 L
.08067 .45848 L
.08054 .45887 L
.08048 .45913 L
.08047 .45935 L
.08052 .45947 L
.0806 .45951 L
.0807 .45956 L
.08078 .45964 L
.08084 .45977 L
.08088 .45993 L
.0809 .46008 L
.08091 .46022 L
.08091 .46032 L
Mistroke
.08091 .46039 L
.0809 .46039 L
.08089 .46036 L
.08088 .46031 L
.08088 .46027 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08089 .46025 L
.0809 .46027 L
.08093 .46032 L
.08097 .46039 L
.08101 .46046 L
.08103 .46048 L
.08102 .46042 L
.08096 .46028 L
.08086 .46007 L
.0807 .45985 L
.08047 .45962 L
.08019 .45939 L
.07987 .45917 L
.07953 .45895 L
.07918 .45872 L
.0789 .45848 L
.07864 .45824 L
.07843 .45803 L
.07832 .45784 L
.07834 .45764 L
.07853 .45742 L
.07891 .45717 L
.07948 .45679 L
.0802 .4562 L
.08107 .45532 L
.08207 .45414 L
.08311 .45267 L
.08418 .45088 L
Mistroke
.08526 .44879 L
.08624 .4468 L
.0872 .44452 L
.08798 .44247 L
.08866 .44033 L
.08923 .43816 L
.0897 .4359 L
.09007 .43398 L
.09034 .43211 L
.09051 .43029 L
.09062 .42853 L
.09068 .42679 L
.09072 .42489 L
.09075 .42281 L
.09079 .42033 L
.09086 .41779 L
.09095 .41494 L
.09104 .4119 L
.09112 .40855 L
.09118 .4054 L
.09122 .40222 L
.09125 .39912 L
.09127 .39658 L
.0913 .39412 L
.09134 .39209 L
.0914 .39051 L
.09146 .3893 L
.09151 .38848 L
.09153 .38795 L
.09148 .38762 L
.09133 .38741 L
.09108 .3872 L
.09075 .38687 L
.09034 .38632 L
.08987 .38545 L
.08937 .38437 L
.08884 .38303 L
.08832 .38141 L
.08782 .37969 L
.08737 .37784 L
.08697 .37603 L
.08664 .37426 L
.0864 .37263 L
.08626 .37104 L
.0862 .36986 L
.08618 .36885 L
.08622 .3679 L
.08627 .36727 L
.08635 .36672 L
.08644 .36634 L
Mistroke
.0865 .36616 L
.08654 .36613 L
.08654 .36618 L
.08654 .3663 L
.08653 .36644 L
.08653 .36655 L
.08653 .36661 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08652 .36664 L
.08651 .36667 L
.08647 .3667 L
.08643 .36674 L
.08639 .36676 L
.08637 .36675 L
.08638 .36669 L
.08644 .3666 L
.08656 .36646 L
.08672 .36628 L
.08693 .36606 L
.08718 .36583 L
.08745 .36558 L
.08774 .36533 L
.08803 .36509 L
.08832 .36488 L
.08858 .36472 L
.0888 .36463 L
.08898 .3646 L
.08911 .3646 L
.08922 .36463 L
.0893 .36463 L
.08938 .36456 L
.08947 .36436 L
.0896 .36402 L
.08977 .36349 L
.08999 .36274 L
.09025 .36177 L
Mistroke
.09053 .36062 L
.0908 .35918 L
.09109 .35737 L
.09138 .35537 L
.09168 .35296 L
.09198 .35023 L
.09229 .34736 L
.0926 .34402 L
.09293 .34079 L
.0933 .33742 L
.09371 .33395 L
.09418 .33059 L
.09471 .3271 L
.09532 .3237 L
.09602 .32074 L
.0968 .31775 L
.09763 .31487 L
.09849 .31238 L
.09939 .31006 L
.1003 .30813 L
.1012 .30644 L
.10208 .305 L
.10293 .30383 L
.1037 .30282 L
.10442 .30198 L
.10508 .30129 L
.10565 .30072 L
.10613 .30031 L
.10653 .30004 L
.10684 .29988 L
.10708 .29984 L
.10724 .29987 L
.10732 .29996 L
.10734 .30006 L
.10732 .30015 L
.10727 .30022 L
.10721 .30025 L
.10716 .30027 L
.10712 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
Mistroke
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.10708 .30027 L
.10705 .30027 L
.10701 .30027 L
.10697 .30027 L
.10694 .30027 L
.10696 .30027 L
.10702 .30027 L
.10713 .30027 L
.10729 .30027 L
.10749 .30028 L
.10773 .30028 L
.10799 .30028 L
.10827 .30028 L
Mistroke
.10855 .30029 L
.10883 .30029 L
.1091 .30029 L
.10935 .30029 L
.10957 .3003 L
.10974 .3003 L
.10986 .3003 L
.10993 .3003 L
.10995 .3003 L
.10994 .3003 L
.1099 .3003 L
.10985 .3003 L
.10981 .3003 L
.1098 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .30033 L
Mistroke
.10979 .30039 L
.10979 .30046 L
.10979 .30054 L
.10976 .3006 L
.10971 .30063 L
.10964 .30059 L
.10956 .30047 L
.10949 .30023 L
.10945 .29986 L
.10945 .29939 L
.10954 .29881 L
.10973 .29815 L
.11006 .29745 L
.11053 .29669 L
.11116 .29586 L
.11193 .29497 L
.11277 .29404 L
.11375 .29311 L
.11476 .29212 L
.11585 .29108 L
.11699 .28995 L
.11825 .28869 L
.11955 .28721 L
.12111 .28547 L
.12275 .28342 L
.12469 .28088 L
.12704 .27799 L
.12951 .27426 L
.13208 .27057 L
.13546 .2664 L
.13861 .26126 L
.14241 .25636 L
.14653 .25012 L
.15015 .24498 L
.15445 .23871 L
.15871 .23196 L
.16333 .22448 L
.16726 .21816 L
.17143 .21047 L
.17565 .20346 L
.17961 .19648 L
.1839 .19002 L
.18761 .18368 L
.19152 .17658 L
.19579 .1714 L
.1991 .16549 L
.20302 .16086 L
.20631 .15589 L
.20933 .1523 L
.21238 .14891 L
Mistroke
.21506 .14595 L
.21742 .14337 L
.21943 .14149 L
.22112 .13993 L
.2224 .13881 L
.22337 .138 L
.2241 .13743 L
.22461 .13705 L
.22494 .13682 L
.22514 .13667 L
.22522 .13659 L
.22522 .13659 L
.22515 .13665 L
.22505 .13676 L
.22494 .13689 L
.22487 .13699 L
.22487 .13705 L
.22493 .13705 L
.22502 .137 L
.22509 .13693 L
.22508 .13687 L
.22497 .13683 L
.22473 .13685 L
.22436 .13694 L
.22385 .13711 L
.22323 .13736 L
.22252 .13769 L
.22176 .13808 L
.22102 .1385 L
.22025 .13896 L
.21946 .13941 L
.21875 .13986 L
.21809 .1403 L
.21753 .14071 L
.2171 .14107 L
.21682 .14136 L
.21667 .14156 L
.21663 .14168 L
.21668 .14172 L
.21678 .14169 L
.21687 .14162 L
.21693 .14155 L
.21696 .14149 L
.21695 .14146 L
.21691 .14145 L
.21687 .14145 L
.21685 .14145 L
.21686 .14145 L
.21692 .14145 L
.21702 .14146 L
Mistroke
.21718 .14146 L
.21737 .14147 L
.2176 .14148 L
.21785 .14149 L
.21812 .14149 L
.21838 .14151 L
.21863 .14154 L
.21884 .14161 L
.219 .14169 L
.21911 .14176 L
.21917 .14182 L
.21919 .14185 L
.2192 .14184 L
.21927 .14176 L
.21941 .14158 L
.21967 .1413 L
.22011 .14088 L
.2208 .14033 L
.22176 .13961 L
.22294 .13876 L
.22439 .13776 L
.22608 .13662 L
.22793 .13534 L
.23 .13402 L
.23199 .13266 L
.23405 .13141 L
.23591 .13023 L
.23763 .12917 L
.23913 .1283 L
.24025 .12764 L
.2411 .12718 L
.24166 .1269 L
.24193 .12678 L
.24196 .1268 L
.24178 .12693 L
.24149 .12674 L
.24117 .12688 L
.2409 .12702 L
.24073 .12716 L
.24074 .12726 L
.24099 .1273 L
.24151 .12725 L
.24226 .12702 L
.24321 .12668 L
.24433 .12622 L
.24561 .12565 L
.24713 .125 L
.24863 .12427 L
.2503 .12345 L
.25212 .12251 L
Mistroke
.25409 .12148 L
.2562 .12035 L
.25852 .11902 L
.26114 .11746 L
.26397 .11584 L
.26713 .11394 L
.27049 .1119 L
.27458 .10976 L
.27827 .10738 L
.28277 .105 L
.28723 .10242 L
.29205 .09969 L
.29758 .09688 L
.30239 .09378 L
.30736 .09138 L
.31205 .08861 L
.31672 .08593 L
.32146 .08324 L
.3258 .08116 L
.32932 .07904 L
.33345 .077 L
.3368 .07501 L
.34004 .07333 L
.34318 .07162 L
.34642 .06986 L
.34992 .06829 L
.35277 .06662 L
.35628 .06493 L
.35938 .06309 L
.36271 .06143 L
.36604 .05948 L
.36943 .05769 L
.37282 .05587 L
.37611 .054 L
.37883 .05249 L
.38147 .05105 L
.38369 .04973 L
.38548 .04865 L
.38693 .0478 L
.38797 .04712 L
.38869 .04666 L
.38913 .04638 L
.38935 .04624 L
.38943 .04619 L
.3894 .0462 L
.38932 .04625 L
.38922 .04632 L
.38913 .04639 L
.38904 .04647 L
.38899 .04653 L
Mistroke
.38894 .04655 L
.38889 .04656 L
.38884 .04655 L
.38879 .04655 L
.38872 .04655 L
.38867 .04655 L
.38863 .04655 L
.38864 .04655 L
.38871 .04655 L
.38885 .04655 L
.38909 .04656 L
.38942 .04657 L
.38986 .04659 L
.39041 .04661 L
.39104 .04663 L
.39178 .04666 L
.39258 .04669 L
.39343 .04672 L
.39429 .04675 L
.39513 .04678 L
.39592 .04681 L
.39663 .04684 L
.39723 .04686 L
.39772 .04688 L
.3981 .04689 L
.39838 .0469 L
.39857 .04691 L
.39868 .04691 L
.39874 .04692 L
.39875 .04692 L
.39873 .04691 L
.39868 .04691 L
.39863 .04691 L
.39858 .04691 L
.39855 .04691 L
.39854 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
Mistroke
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39851 .0469 L
.39846 .04688 L
.39839 .04682 L
.3983 .04674 L
.39821 .04667 L
.39813 .04663 L
.3981 .04663 L
.39817 .04668 L
.3984 .04681 L
.39886 .04702 L
.39938 .04736 L
.40006 .04782 L
.40092 .0484 L
.4018 .04909 L
.40278 .04986 L
.40385 .05069 L
.40489 .05156 L
.40608 .05245 L
.40698 .05332 L
.40783 .05411 L
.40867 .05477 L
.40947 .05533 L
.41022 .05577 L
.41089 .0561 L
.41156 .05631 L
.41234 .05644 L
.41335 .05654 L
.41469 .05663 L
.41623 .05678 L
.41827 .05704 L
.42031 .05743 L
.42298 .05798 L
.42593 .05868 L
.42914 .05954 L
.43211 .06051 L
Mistroke
.43532 .06158 L
.43892 .06266 L
.44172 .06375 L
.44473 .06487 L
.44795 .06601 L
.45056 .06695 L
.4532 .06783 L
.45563 .06846 L
.45785 .06896 L
.46 .06926 L
.46178 .06937 L
.46344 .0693 L
.46504 .06905 L
.46642 .06867 L
.46791 .06816 L
.46925 .06753 L
.47066 .06681 L
.47206 .06598 L
.47361 .06502 L
.47515 .06397 L
.47688 .06287 L
.47852 .06181 L
.48021 .06071 L
.48207 .0596 L
.4838 .05854 L
.48561 .05751 L
.48732 .05656 L
.4888 .05574 L
.49019 .05502 L
.4912 .05445 L
.49205 .05404 L
.49273 .05378 L
.49322 .05365 L
.49354 .05363 L
.49376 .05364 L
.49392 .05368 L
.49407 .05376 L
.49421 .05387 L
.49434 .05399 L
.49447 .05414 L
.49463 .05434 L
.49482 .05459 L
.49503 .05491 L
.4952 .05527 L
.49535 .05565 L
.49548 .05606 L
.4956 .05647 L
.49571 .05682 L
.49582 .05715 L
.49594 .05747 L
Mistroke
.49608 .05781 L
.49625 .05816 L
.49645 .05854 L
.49668 .05894 L
.49691 .0594 L
.49716 .05999 L
.49739 .06072 L
.49762 .06165 L
.49781 .06282 L
.49797 .06407 L
.49807 .06559 L
.49812 .06756 L
.49812 .06946 L
.49808 .07166 L
.49802 .07416 L
.49796 .07633 L
.49786 .0788 L
.49782 .08097 L
.4978 .08316 L
.49779 .08525 L
.49779 .08689 L
.49778 .08861 L
.49779 .08992 L
.49781 .09107 L
.49783 .092 L
.49786 .09268 L
.4979 .0931 L
.49794 .09333 L
.49797 .0934 L
.498 .09337 L
.49802 .09326 L
.49802 .0931 L
.49801 .09295 L
.498 .09286 L
.49799 .09282 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
Mistroke
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49798 .09281 L
.49797 .09277 L
.49794 .09269 L
.4979 .09257 L
.49785 .09243 L
.49779 .0923 L
.49773 .09221 L
.4977 .09217 L
.49769 .09224 L
.49775 .09243 L
.49788 .09283 L
.49813 .0935 L
.4985 .09449 L
.49901 .09585 L
.49966 .09755 L
.50048 .09964 L
.50149 .10233 L
.50265 .10516 L
.50401 .10838 L
.50553 .11208 L
.50718 .11538 L
.50894 .11891 L
.51077 .12261 L
.51262 .12552 L
.51449 .1286 L
.51634 .13127 L
.51827 .13379 L
.52009 .13572 L
.52206 .13747 L
.52412 .13902 L
.52629 .14037 L
.52863 .14159 L
.53118 .14264 L
.53395 .14372 L
.53707 .14475 L
.54032 .1457 L
.54399 .14663 L
.54861 .14741 L
.5526 .14803 L
Mistroke
.55748 .14846 L
.56286 .14863 L
.56901 .14855 L
.57443 .14819 L
.58115 .14756 L
.58794 .14669 L
.59459 .14559 L
.60107 .1443 L
.60908 .14286 L
.61609 .14131 L
.6217 .1398 L
.6289 .13821 L
.6347 .13659 L
.64076 .13493 L
.64627 .1331 L
.65133 .13113 L
.65578 .12915 L
.65949 .12693 L
.66312 .12462 L
.66633 .1222 L
.6692 .11962 L
.67186 .11685 L
.67403 .11448 L
.67606 .11189 L
.67794 .10927 L
.67961 .10695 L
.68122 .10466 L
.68275 .1027 L
.6842 .10094 L
.68565 .09955 L
.68703 .09845 L
.68843 .09765 L
.68985 .09711 L
.69128 .09681 L
.69278 .09668 L
.69438 .09668 L
.69605 .0968 L
.69786 .09702 L
.69968 .09733 L
.70153 .09771 L
.70351 .09812 L
.70555 .09858 L
.70767 .09903 L
.70987 .0995 L
.71212 .10001 L
.7144 .1006 L
.71675 .10127 L
.71917 .10204 L
.72154 .10291 L
.72405 .10388 L
Mistroke
.72643 .10492 L
.72894 .106 L
.73141 .10714 L
.73388 .10833 L
.73638 .10954 L
.73883 .11073 L
.74134 .11192 L
.74401 .11316 L
.74669 .11446 L
.74964 .11587 L
.75276 .11736 L
.75634 .11894 L
.75964 .12063 L
.76334 .12237 L
.76717 .12417 L
.77136 .12603 L
.7749 .12778 L
.77866 .12945 L
.78251 .1311 L
.78545 .13253 L
.78854 .13382 L
.79115 .13493 L
.79335 .13583 L
.79515 .13651 L
.79648 .13698 L
.79739 .13724 L
.798 .13734 L
.79834 .13732 L
.79848 .13721 L
.79847 .13709 L
.79839 .13698 L
.79829 .13692 L
.79819 .13687 L
.79809 .13684 L
.798 .13683 L
.79794 .13682 L
.79789 .13682 L
.79788 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
Mistroke
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79788 .1368 L
.79789 .13678 L
.79791 .13677 L
.79794 .13677 L
.79796 .13677 L
.79795 .13676 L
.79791 .13674 L
.79783 .13674 L
.79774 .13676 L
.79763 .13684 L
.79753 .13697 L
.79744 .13715 L
.79737 .13737 L
.79732 .13764 L
.79729 .13794 L
.79729 .1383 L
.7973 .13871 L
.79732 .13914 L
.79736 .13962 L
.79741 .14013 L
.79746 .14068 L
.79751 .14129 L
.79758 .14196 L
.79768 .14272 L
.7978 .14354 L
.79794 .14442 L
.7981 .14539 L
.7983 .14644 L
.79856 .14758 L
.7989 .14886 L
.79934 .15025 L
.79984 .15176 L
.80047 .15344 L
.80118 .15514 L
.80201 .15697 L
.80299 .15896 L
.8041 .161 L
Mistroke
.80538 .16321 L
.80683 .16559 L
.8085 .16809 L
.8104 .17076 L
.81246 .17351 L
.81472 .17642 L
.81729 .1794 L
.81982 .18248 L
.82278 .18539 L
.8255 .18828 L
.82846 .1911 L
.83121 .19361 L
.83417 .19605 L
.83683 .19831 L
.83899 .20027 L
.84105 .2021 L
.8429 .20373 L
.84445 .20519 L
.84567 .20651 L
.8466 .20769 L
.84725 .20869 L
.84767 .20961 L
.84786 .21049 L
.84781 .21138 L
.84751 .21231 L
.84702 .21328 L
.84638 .21438 L
.84549 .21571 L
.84437 .21732 L
.84303 .21929 L
.84163 .22147 L
.83999 .22419 L
.83827 .22736 L
.83653 .23097 L
.83472 .23521 L
.83298 .23974 L
.83133 .24484 L
.82983 .25024 L
.82862 .25598 L
.82771 .26221 L
.82716 .26827 L
.82697 .27465 L
.82717 .28154 L
.82773 .28781 L
.82863 .29457 L
.82988 .30121 L
.83144 .30814 L
.83337 .31538 L
.83564 .32231 L
.83813 .32983 L
Mistroke
.84083 .33789 L
.84352 .34594 L
.84634 .35452 L
.84921 .36291 L
.85164 .37212 L
.85391 .38034 L
.85576 .3893 L
.85713 .39812 L
.8579 .40674 L
.85804 .41507 L
.85763 .42349 L
.85655 .4315 L
.85475 .43868 L
.85243 .44588 L
.8495 .45269 L
.84598 .4593 L
.84243 .46555 L
.83859 .47168 L
.83469 .47778 L
.83098 .48385 L
.82762 .49003 L
.82468 .49601 L
.82209 .50244 L
.82015 .50839 L
.81859 .51481 L
.81745 .52179 L
.81684 .52849 L
.81657 .53562 L
.81666 .5433 L
.81699 .55118 L
.8175 .55967 L
.81805 .56895 L
.81858 .5779 L
.819 .58809 L
.81924 .59707 L
.81921 .60717 L
.81885 .61829 L
.81818 .6285 L
.81718 .63865 L
.81588 .64891 L
.81429 .65941 L
.81252 .66983 L
.81049 .6797 L
.80828 .68976 L
.80591 .70079 L
.80333 .71006 L
.8006 .72056 L
.79778 .73074 L
.79511 .74172 L
.79251 .7514 L
Mistroke
.79011 .76204 L
.78792 .77205 L
.7862 .782 L
.785 .79119 L
.78439 .79977 L
.78445 .8079 L
.78514 .8143 L
.7864 .82015 L
.78816 .82503 L
.79036 .82871 L
.79291 .83143 L
.79559 .83325 L
.79831 .83423 L
.80094 .8345 L
.80327 .8342 L
.80532 .83352 L
.80696 .8326 L
.80812 .83165 L
.80881 .83085 L
.80902 .83034 L
.80876 .83016 L
.80806 .83039 L
.80691 .83108 L
.80523 .83222 L
.80311 .83381 L
.80043 .83583 L
.79716 .83816 L
.79328 .84086 L
.78867 .84382 L
.78346 .84698 L
.7778 .85022 L
.77115 .85348 L
.76435 .85656 L
.75677 .85948 L
.74857 .86215 L
.73981 .86456 L
.73174 .86673 L
.72288 .8687 L
.71405 .87055 L
.7055 .8724 L
.69717 .87446 L
.68882 .87683 L
.6807 .87963 L
.67336 .88296 L
.66562 .88658 L
.65879 .8909 L
.65202 .89534 L
.64596 .9001 L
.64 .90524 L
.63519 .91002 L
Mistroke
.63026 .91478 L
.6259 .91913 L
.62128 .92344 L
.61715 .92706 L
.6128 .9302 L
.60836 .93268 L
.60371 .93451 L
.59865 .93579 L
.59278 .93663 L
.58728 .93713 L
.58053 .93743 L
.57287 .93763 L
.56463 .93781 L
.5554 .938 L
.54568 .93816 L
.53603 .93829 L
.52567 .9384 L
.51518 .9385 L
.50449 .93863 L
.49468 .93882 L
.4842 .93905 L
.47468 .9393 L
.46513 .93955 L
.45615 .93974 L
.44756 .93982 L
.43923 .93972 L
.43163 .93938 L
.42425 .93878 L
.41699 .9379 L
.40979 .93675 L
.40229 .93536 L
.39543 .93377 L
.38823 .9319 L
.38054 .92975 L
.37328 .92731 L
.36563 .92462 L
.35756 .92164 L
.34997 .91861 L
.34207 .91539 L
.33402 .91204 L
.32566 .90863 L
.31766 .90509 L
.30947 .90151 L
.30132 .89784 L
.29295 .89409 L
.28534 .89031 L
.27738 .88658 L
.27009 .88296 L
.26319 .87959 L
.25689 .87653 L
Mistroke
.25073 .8738 L
.24607 .87156 L
.2418 .86973 L
.23812 .86833 L
.23545 .86735 L
.23345 .86673 L
.23209 .86641 L
.23134 .8663 L
.23103 .86629 L
.23091 .8663 L
.23082 .86624 L
.23056 .86597 L
.23003 .86542 L
.2291 .8645 L
.22766 .86315 L
.2257 .86132 L
.22312 .85892 L
.21986 .85591 L
.21591 .85232 L
.21135 .84826 L
.20637 .8436 L
.20067 .83846 L
.19482 .83289 L
.18839 .82667 L
.18191 .82021 L
.17516 .81344 L
.16796 .80609 L
.16078 .79879 L
.1539 .79142 L
.14668 .78387 L
.13947 .77618 L
.13243 .76925 L
.12595 .76211 L
.11976 .75518 L
.1142 .74927 L
.10929 .74351 L
.10489 .73835 L
.10111 .73375 L
.09785 .72961 L
.09541 .7263 L
.09351 .7235 L
.09211 .7212 L
.09112 .71927 L
.09045 .7176 L
.08999 .71602 L
.08965 .7144 L
.08932 .71264 L
.08898 .71069 L
.08861 .70829 L
.08815 .70537 L
Mistroke
.08753 .70183 L
.08672 .69761 L
.08577 .69266 L
.08473 .68698 L
.08359 .68072 L
.08239 .67392 L
.08115 .66704 L
.0799 .66011 L
.07874 .65284 L
.07759 .64487 L
.07646 .63743 L
.07535 .63062 L
.07423 .62282 L
.07309 .61506 L
.072 .60843 L
.07091 .60063 L
.06986 .59389 L
.06883 .58673 L
.06785 .57889 L
.06695 .57226 L
.06608 .56497 L
.0652 .55765 L
.06435 .54987 L
.06355 .54291 L
.06287 .53562 L
.06237 .52747 L
.06209 .52111 L
.06207 .51428 L
.06233 .50747 L
.06281 .50076 L
.06346 .49464 L
.06428 .48877 L
.06515 .48351 L
.06603 .47872 L
.06688 .47442 L
.06769 .47048 L
.06841 .46707 L
.06904 .46428 L
.06956 .46189 L
.06995 .45998 L
.07021 .4585 L
.07032 .45746 L
.07034 .4568 L
.07032 .45643 L
.07027 .45618 L
.07022 .456 L
.07017 .45586 L
.07014 .45572 L
.07012 .45556 L
.07013 .45541 L
Mistroke
.07013 .45531 L
.07013 .45529 L
.07013 .45533 L
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .45557 L
.07014 .45555 L
.07018 .45549 L
.07022 .45541 L
.07027 .45533 L
.07029 .4553 L
.07027 .45532 L
.07021 .45543 L
.07009 .45563 L
.06992 .45593 L
.0697 .45633 L
.06944 .45682 L
.06915 .45738 L
.06885 .45797 L
.06855 .45851 L
.06824 .459 L
.06794 .45938 L
Mistroke
.06764 .45965 L
.06738 .45975 L
.06716 .4597 L
.06703 .45949 L
.06698 .45914 L
.06704 .45867 L
.06719 .45813 L
.06741 .45755 L
.06768 .45697 L
.06797 .45645 L
.06827 .45602 L
.06857 .4557 L
.06887 .45547 L
.06916 .45534 L
.06943 .4553 L
.06968 .45533 L
.0699 .4554 L
.07007 .45548 L
.0702 .45554 L
.07026 .45557 L
.07029 .45558 L
.07027 .45558 L
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.0701 .45558 L
.07007 .45558 L
.07003 .45558 L
.06999 .45558 L
.06996 .45558 L
.06998 .45558 L
.07004 .45558 L
.07015 .45558 L
.07031 .45558 L
.07052 .45557 L
.07076 .45557 L
.07103 .45557 L
.07131 .45556 L
.0716 .45556 L
.07188 .45555 L
.07214 .45555 L
.07236 .45555 L
.07253 .45554 L
.07267 .45554 L
.07276 .45554 L
.07282 .45554 L
.07284 .45556 L
.07283 .45558 L
.07283 .45562 L
.0729 .45566 L
.07307 .45568 L
.07338 .45566 L
.07384 .4556 L
.07444 .4555 L
.07518 .45538 L
.07604 .45524 L
.07701 .4551 L
.07807 .45495 L
.07915 .45479 L
.08036 .4546 L
.08151 .45435 L
.08267 .45403 L
.08382 .45364 L
.08492 .45316 L
.0859 .45256 L
.08678 .45181 L
Mistroke
.0875 .45088 L
.08808 .44976 L
.08856 .44842 L
.08896 .44682 L
.08933 .44494 L
.08971 .44272 L
.0901 .44017 L
.0905 .4372 L
.09085 .4339 L
.09111 .43003 L
.09126 .42579 L
.09128 .42085 L
.09119 .41553 L
.091 .40961 L
.09076 .40307 L
.09048 .39732 L
.09017 .39109 L
.08984 .38457 L
.0895 .37907 L
.08919 .37334 L
.08889 .36833 L
.08864 .36447 L
.08845 .36094 L
.08864 .3589 L
.08858 .35672 L
.08865 .3552 L
.08881 .35444 L
.08899 .35407 L
.08918 .35366 L
.0894 .35312 L
.08961 .35241 L
.08977 .35143 L
.08991 .34997 L
.09008 .34806 L
.0903 .34579 L
.09058 .34329 L
.09091 .34045 L
.0913 .33743 L
.09172 .33433 L
.09216 .33153 L
.09263 .32878 L
.0931 .32613 L
.09359 .32365 L
.09411 .32151 L
.09469 .31942 L
.09531 .31752 L
.096 .31565 L
.09677 .31378 L
.09762 .31209 L
.09846 .31039 L
Mistroke
.09938 .30876 L
.1003 .30733 L
.10111 .3059 L
.10194 .30467 L
.10261 .3035 L
.10322 .30244 L
.10375 .30153 L
.10418 .30083 L
.10448 .30034 L
.10466 .30004 L
.10472 .2999 L
.10471 .29987 L
.10465 .29991 L
.10457 .29999 L
.10449 .30006 L
.10443 .30011 L
.10441 .30016 L
.1044 .3002 L
.1044 .30023 L
.1044 .30024 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30024 L
.10439 .30023 L
.10435 .3002 L
.10431 .30016 L
.10427 .30013 L
.10425 .30011 L
.10427 .30012 L
.10433 .30017 L
.10443 .30027 L
.10459 .30041 L
.10479 .30059 L
.10502 .3008 L
.10528 .30104 L
.10556 .30129 L
.10583 .30153 L
.1061 .30178 L
.10636 .30202 L
Mistroke
.10661 .30225 L
.10682 .30244 L
.10699 .30259 L
.10711 .3027 L
.10718 .30276 L
.1072 .30278 L
.10719 .30276 L
.10715 .30273 L
.1071 .30268 L
.10707 .30265 L
.10705 .30264 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30264 L
.10706 .30265 L
.10707 .30266 L
.10707 .30269 L
.10707 .30272 L
.10706 .30274 L
.10702 .30278 L
.10696 .30282 L
.10687 .30287 L
.10676 .30291 L
.10665 .30291 L
.10657 .30282 L
.10655 .3026 L
.10663 .30223 L
.10686 .30167 L
.10719 .3009 L
.1077 .29995 L
.10837 .2988 L
.1092 .29747 L
.11007 .29606 L
.11111 .29447 L
.11215 .29278 L
.11331 .29102 L
.11432 .2893 L
.11532 .28757 L
.11628 .28593 L
.11704 .28446 L
.11766 .28312 L
.11814 .28195 L
.11851 .281 L
.11874 .28022 L
.11883 .27964 L
Mistroke
.11879 .27924 L
.11864 .27902 L
.11837 .27898 L
.11801 .27911 L
.11756 .27936 L
.11703 .27972 L
.11648 .28017 L
.11591 .28069 L
.11537 .28129 L
.11485 .28195 L
.11432 .28264 L
.11381 .28336 L
.11333 .28409 L
.11296 .28482 L
.1127 .28551 L
.11255 .28613 L
.11249 .28666 L
.11251 .28712 L
.11259 .2875 L
.11269 .2878 L
.11279 .28801 L
.11285 .28816 L
.11289 .28826 L
.11291 .28833 L
.1129 .2884 L
.11284 .28853 L
.11273 .28874 L
.11255 .28907 L
.11232 .28955 L
.11203 .29012 L
.11168 .29078 L
.11128 .29157 L
.11081 .2925 L
.11025 .29366 L
.10956 .29511 L
.10869 .29703 L
.10774 .2991 L
.10663 .30164 L
.10529 .30495 L
.10393 .3083 L
.10224 .31317 L
.10061 .3184 L
.0988 .32331 L
.09649 .33056 L
.09457 .33652 L
.09243 .34444 L
.09024 .35237 L
.08801 .35862 L
.08611 .36586 L
.08436 .37259 L
Mistroke
.08278 .37957 L
.08163 .38423 L
.08068 .38928 L
.07991 .39332 L
.07941 .39619 L
.07907 .39853 L
.07892 .40027 L
.07895 .40124 L
.07909 .40163 L
.07931 .40165 L
.07957 .40147 L
.0798 .40115 L
.07999 .40077 L
.08011 .40045 L
.08018 .40026 L
.0802 .40014 L
.08019 .40009 L
.08017 .40006 L
.08019 .40002 L
.08023 .39998 L
.08026 .39997 L
.08024 .39998 L
.08019 .40003 L
.08008 .40013 L
.07991 .40027 L
.07967 .40046 L
.0794 .40067 L
.0791 .40091 L
.07882 .40116 L
.07852 .40141 L
.07826 .40167 L
.078 .40191 L
.07775 .40213 L
.07749 .40233 L
.07729 .40248 L
.07716 .40259 L
.07711 .40265 L
.07711 .40267 L
.07715 .40265 L
.07722 .40261 L
.07729 .40257 L
.07734 .40254 L
.07734 .40252 L
.07733 .40252 L
.07731 .40252 L
.0773 .40252 L
.07728 .40252 L
.07725 .40252 L
.0772 .40252 L
.07715 .40252 L
Mistroke
.0771 .40252 L
.07708 .40252 L
.07711 .40252 L
.07721 .40252 L
.07739 .40252 L
.07765 .40252 L
.078 .40252 L
.07843 .40251 L
.07892 .40251 L
.07941 .40251 L
.07995 .4025 L
.08049 .4025 L
.08104 .4025 L
.08152 .40249 L
.08196 .40249 L
.08234 .40249 L
.08263 .40248 L
.08283 .40248 L
.08295 .40248 L
.08299 .40248 L
.08297 .40248 L
.08292 .40248 L
.08287 .40248 L
.08282 .40248 L
.08278 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40249 L
.08278 .4025 L
.08281 .40253 L
.08285 .40257 L
.08289 .4026 L
Mistroke
.08291 .40262 L
.08289 .40261 L
.08284 .40256 L
.08273 .40246 L
.08257 .40232 L
.08237 .40214 L
.08214 .40193 L
.08188 .4017 L
.0816 .40145 L
.08133 .4012 L
.08106 .40095 L
.08079 .40071 L
.08055 .40049 L
.08033 .4003 L
.08016 .40015 L
.08004 .40004 L
.07997 .39998 L
.07995 .39996 L
.07997 .39998 L
.08001 .40002 L
.08005 .40006 L
.08009 .40009 L
.0801 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08011 .40009 L
Mistroke
.08012 .40006 L
.08016 .40002 L
.08021 .39998 L
.08024 .39997 L
.08024 .39998 L
.08021 .40003 L
.08012 .40013 L
.07998 .40027 L
.07977 .40046 L
.07952 .40067 L
.07925 .40091 L
.07897 .40116 L
.07867 .40141 L
.0784 .40167 L
.07816 .40191 L
.07788 .40213 L
.07762 .40233 L
.07741 .40248 L
.07727 .40259 L
.07718 .40265 L
.07714 .40267 L
.07712 .40265 L
.07711 .40261 L
.07713 .40257 L
.07716 .40254 L
.07718 .40253 L
.07723 .40252 L
.07733 .40252 L
.07749 .40252 L
.0777 .40252 L
.07794 .40252 L
.07821 .40252 L
.07849 .40253 L
.07877 .40256 L
.07905 .40259 L
.07932 .40263 L
.07957 .40264 L
.07979 .40263 L
.07997 .40258 L
.0801 .40248 L
.08017 .40234 L
.0802 .40216 L
.08019 .40194 L
.08016 .40171 L
.08012 .40146 L
.08009 .40121 L
.08008 .40096 L
.08009 .40072 L
.08009 .4005 L
.0801 .4003 L
Mistroke
.0801 .40015 L
.08011 .40004 L
.08011 .39998 L
.08011 .39996 L
.08011 .39998 L
.08011 .40001 L
.08011 .40006 L
.08011 .40009 L
.08011 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08006 .40006 L
.08002 .40002 L
.07998 .39999 L
.07996 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08073 .40066 L
.08099 .40089 L
.08126 .40114 L
.08153 .40139 L
.08181 .40164 L
.08207 .40188 L
.08232 .4021 L
Mistroke
.08253 .40229 L
.0827 .40244 L
.08282 .40255 L
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08286 .40257 L
.08281 .40253 L
.08276 .4025 L
.08271 .40249 L
.08267 .40248 L
.08263 .40248 L
.08261 .40248 L
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08315 .40248 L
.0834 .40248 L
.08366 .40248 L
.08395 .40247 L
.08422 .40247 L
.0845 .40247 L
.08478 .40247 L
.08503 .40247 L
.08525 .40247 L
.08543 .40246 L
.08555 .40246 L
.08562 .40246 L
.08564 .40246 L
.08562 .40246 L
.08558 .40246 L
.08554 .40246 L
.0855 .40246 L
.08549 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
Mistroke
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40247 L
.08548 .40248 L
.08548 .40251 L
.08548 .40255 L
.08548 .40258 L
.08548 .4026 L
.08548 .40259 L
.08548 .40254 L
.08548 .40244 L
.08549 .4023 L
.08549 .40212 L
.0855 .40191 L
.08551 .40167 L
.08551 .40142 L
.08552 .40117 L
Mistroke
.08553 .40092 L
.08554 .40068 L
.08554 .40046 L
.08555 .40027 L
.08555 .40011 L
.08556 .40001 L
.08556 .39994 L
.08556 .39993 L
.08556 .39994 L
.08556 .39998 L
.08556 .40002 L
.08556 .40005 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08555 .40007 L
.08554 .40007 L
.08551 .4001 L
.08547 .40016 L
.08542 .40023 L
.0854 .4003 L
.08542 .40034 L
.08548 .40031 L
.08559 .40021 L
.08573 .40002 L
.08592 .39973 L
.08613 .39937 L
.08636 .39894 L
.08658 .39847 L
Mistroke
.0868 .39798 L
.08703 .39748 L
.08728 .39699 L
.08756 .39651 L
.08787 .39606 L
.08816 .39567 L
.08847 .39536 L
.08878 .39514 L
.08908 .39502 L
.08937 .39495 L
.08966 .39493 L
.08994 .39492 L
.09021 .39493 L
.09048 .39495 L
.09073 .395 L
.09094 .39511 L
.09109 .3953 L
.09117 .39558 L
.09119 .39594 L
.09118 .39637 L
.09115 .39684 L
.09109 .39733 L
.09102 .39783 L
.09097 .39832 L
.09094 .3988 L
.09093 .39924 L
.09093 .39963 L
.09094 .39993 L
.09095 .40014 L
.09097 .40023 L
.09099 .40023 L
.091 .40016 L
.09101 .40007 L
.09102 .4 L
.09101 .39998 L
.09099 .40002 L
.09095 .40009 L
.0909 .40019 L
.09085 .40031 L
.09083 .40046 L
.09082 .40067 L
.09083 .40096 L
.09089 .40138 L
.091 .40193 L
.09116 .40261 L
.0914 .40341 L
.0917 .40431 L
.09207 .40527 L
.09249 .40621 L
.09297 .40711 L
Mistroke
.09349 .40789 L
.09405 .40859 L
.09461 .4092 L
.0951 .40977 L
.09552 .4103 L
.09583 .4108 L
.09602 .41134 L
.09606 .41196 L
.09596 .41275 L
.09573 .41388 L
.09538 .41551 L
.09487 .41762 L
.09424 .41977 L
.09332 .4226 L
.09235 .42586 L
.09119 .42985 L
.0898 .43395 L
.08815 .43882 L
.08616 .44319 L
.08438 .44803 L
.08216 .4534 L
.08027 .45821 L
.07848 .46222 L
.07624 .46665 L
.07429 .47079 L
.07202 .47506 L
.07019 .47851 L
.06863 .482 L
.06718 .48497 L
.0659 .48769 L
.06487 .49005 L
.06419 .49183 L
.06369 .49343 L
.06337 .49463 L
.06316 .49555 L
.06305 .4962 L
.06302 .49663 L
.06302 .49689 L
.06302 .49703 L
.06304 .49711 L
.06307 .49716 L
.06311 .49725 L
.06315 .49746 L
.06317 .49789 L
.06314 .49863 L
.06307 .49974 L
.06298 .5012 L
.06287 .503 L
.06275 .50518 L
.06264 .50768 L
Mistroke
.06256 .51045 L
.0625 .51357 L
.06249 .51656 L
.06252 .51988 L
.06262 .5236 L
.06282 .52705 L
.06313 .53102 L
.06353 .53525 L
.06405 .53957 L
.06466 .54467 L
.06534 .54936 L
.06604 .55429 L
.06675 .55978 L
.06746 .56491 L
.06812 .57054 L
.06879 .57622 L
.0694 .5812 L
.07 .58664 L
.07058 .592 L
.07114 .59702 L
.07166 .60173 L
.07213 .60609 L
.07251 .61016 L
.07288 .61386 L
.07324 .6174 L
.07363 .6204 L
.07404 .62311 L
.0745 .62574 L
.07499 .62825 L
.0755 .63049 L
.076 .63291 L
.07647 .63522 L
.0769 .63774 L
.07733 .64061 L
.07777 .64391 L
.07825 .64706 L
.07875 .65074 L
.0793 .6549 L
.07992 .65957 L
.0806 .6645 L
.08131 .66977 L
.08205 .675 L
.08283 .68011 L
.08365 .68519 L
.08442 .69023 L
.08524 .69433 L
.08601 .69797 L
.08675 .70123 L
.08745 .70387 L
.08803 .7059 L
Mistroke
.08851 .70749 L
.08888 .70862 L
.08914 .70934 L
.08929 .70973 L
.08935 .70987 L
.08935 .70982 L
.0893 .70966 L
.08924 .70947 L
.08918 .70929 L
.08913 .70912 L
.0891 .70898 L
.08908 .70892 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08906 .7089 L
.08903 .70891 L
.08898 .70891 L
.08894 .70891 L
.0889 .70891 L
.08887 .70891 L
.08886 .70891 L
.08889 .70891 L
.089 .70891 L
.0892 .7089 L
.08952 .70889 L
.08995 .70887 L
.09049 .70885 L
.09112 .70883 L
.09183 .7088 L
.0926 .70877 L
.09339 .70874 L
.09413 .70871 L
.0949 .70868 L
.09555 .70865 L
.09614 .70863 L
.09662 .70861 L
.09698 .7086 L
.09721 .70859 L
.09733 .70858 L
.09737 .70858 L
.09736 .70858 L
.09733 .70859 L
.09732 .70859 L
Mistroke
.09736 .70858 L
.09749 .70858 L
.09772 .70857 L
.09805 .70856 L
.09844 .70854 L
.09888 .70853 L
.09936 .70851 L
.09987 .70848 L
.10037 .70845 L
.10083 .7084 L
.10125 .70834 L
.10161 .70829 L
.10193 .70826 L
.10222 .70826 L
.10248 .70831 L
.10271 .70842 L
.10293 .70859 L
.10313 .70881 L
.10333 .70906 L
.10353 .70932 L
.10374 .70956 L
.10399 .70976 L
.10429 .70991 L
.10465 .71 L
.10506 .71002 L
.10549 .70999 L
.1059 .70988 L
.1063 .70972 L
.10666 .70951 L
.10697 .70926 L
.10724 .70898 L
.10748 .7087 L
.10769 .70844 L
.10788 .70824 L
.10803 .70811 L
.10815 .70803 L
.10821 .70801 L
.10823 .70803 L
.10821 .70807 L
.10817 .70811 L
.10813 .70815 L
.10809 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
Mistroke
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10805 .7082 L
.10802 .70827 L
.10797 .70836 L
.10792 .70846 L
.10786 .70858 L
.1078 .70866 L
.10777 .70868 L
.10779 .70859 L
.10787 .70839 L
.10802 .70806 L
.1083 .70757 L
.10873 .70691 L
.10934 .70606 L
.1101 .705 L
.11102 .70367 L
.11214 .70205 L
.11344 .70012 L
.11472 .69787 L
.11605 .69539 L
.11749 .69252 L
.11885 .68945 L
.12045 .68586 L
.12175 .68213 L
.12303 .67772 L
.12433 .67331 L
.12563 .66839 L
.12695 .66321 L
.12816 .65756 L
.12944 .65168 L
.13074 .6459 L
.13197 .63981 L
.13327 .63271 L
.13451 .62663 L
Mistroke
.13577 .61996 L
.13698 .61372 L
.13813 .60762 L
.13916 .60051 L
.14001 .59536 L
.14073 .58968 L
.1413 .58417 L
.14174 .57947 L
.14206 .57492 L
.14227 .57067 L
.1424 .56696 L
.14249 .56351 L
.14253 .56035 L
.14255 .55803 L
.14256 .55587 L
.14259 .55409 L
.14262 .55254 L
.14267 .55124 L
.14273 .5502 L
.1428 .5493 L
.14287 .5485 L
.14295 .54771 L
.14302 .54689 L
.14308 .546 L
.14313 .54506 L
.14315 .54387 L
.14312 .54242 L
.14301 .54071 L
.14282 .53878 L
.1425 .53654 L
.14204 .53393 L
.14148 .53126 L
.14081 .52812 L
.14006 .52521 L
.13925 .52186 L
.13846 .51863 L
.13766 .51517 L
.13694 .51189 L
.13629 .50855 L
.1357 .50522 L
.13521 .50213 L
.1348 .49914 L
.13446 .49632 L
.13422 .49355 L
.13402 .4911 L
.13384 .48866 L
.13367 .48628 L
.13348 .48406 L
.13327 .48183 L
.13302 .47971 L
Mistroke
.13274 .47762 L
.13241 .47562 L
.13201 .47359 L
.13153 .47174 L
.13096 .46979 L
.13033 .46803 L
.1296 .46625 L
.12871 .46459 L
.12767 .46296 L
.12648 .46138 L
.12531 .45998 L
.1239 .45857 L
.12216 .45718 L
.12057 .45586 L
.1188 .45453 L
.11694 .4532 L
.11492 .45185 L
.11275 .4505 L
.1107 .44925 L
.10888 .4481 L
.10711 .44705 L
.10523 .44613 L
.10348 .44533 L
.10178 .44465 L
.10029 .44405 L
.09909 .44357 L
.09811 .44323 L
.09723 .44302 L
.09641 .44293 L
.09566 .44294 L
.09502 .44299 L
.09439 .44304 L
.09372 .44307 L
.09302 .44307 L
.09234 .443 L
.09171 .44286 L
.09117 .44265 L
.09051 .44243 L
.08973 .44219 L
.08895 .44195 L
.08828 .4417 L
.08772 .44147 L
.08727 .44125 L
.08696 .44106 L
.08676 .44091 L
.08668 .4408 L
.08668 .44073 L
.08671 .44068 L
.08674 .44066 L
.08675 .44066 L
Mistroke
.08678 .44068 L
.08683 .44072 L
.0869 .44079 L
.08701 .4409 L
.08716 .44107 L
.08735 .44129 L
.08757 .44154 L
.0878 .4418 L
.08803 .44205 L
.08826 .44227 L
.08851 .44249 L
.08877 .4427 L
.08904 .44286 L
.08931 .44295 L
.08956 .44293 L
.08978 .44279 L
.08998 .44248 L
.09021 .44199 L
.09048 .44132 L
.09083 .44049 L
.0913 .43947 L
.09194 .43827 L
.09277 .43698 L
.09386 .43547 L
.09517 .43365 L
.09676 .4318 L
.09866 .42965 L
.10056 .42734 L
.1028 .42485 L
.1052 .4222 L
.10773 .41923 L
.11044 .41658 L
.11318 .41377 L
.11583 .41092 L
.11844 .40795 L
.12089 .40481 L
.12312 .40191 L
.12533 .39891 L
.12743 .396 L
.12949 .393 L
.13134 .39023 L
.13332 .38731 L
.13525 .38437 L
.13735 .38123 L
.13963 .37829 L
.14178 .3751 L
.14392 .37189 L
.14611 .3684 L
.14847 .36518 L
.15082 .36172 L
Mistroke
.15309 .35807 L
.15519 .35471 L
.15705 .35083 L
.15865 .34726 L
.15997 .34336 L
.16093 .3396 L
.16161 .33578 L
.16198 .33169 L
.16211 .32777 L
.16213 .32372 L
.16208 .3194 L
.162 .31499 L
.16191 .31056 L
.16184 .30602 L
.1618 .3016 L
.16181 .29707 L
.16191 .29214 L
.16208 .2879 L
.16231 .28362 L
.16254 .27997 L
.16275 .27593 L
.16289 .27255 L
.16293 .2691 L
.1628 .26634 L
.1625 .26365 L
.16203 .26146 L
.16139 .25933 L
.16059 .25753 L
.15967 .25579 L
.1587 .25419 L
.15767 .25266 L
.15661 .25121 L
.1556 .24999 L
.15463 .24885 L
.15369 .24782 L
.1528 .24692 L
.15206 .24616 L
.15147 .24551 L
.15104 .24495 L
.1508 .24449 L
.15072 .24414 L
.15075 .24392 L
.15081 .24385 L
.15086 .2439 L
.15083 .24408 L
.15069 .24435 L
.15042 .2447 L
.15005 .24511 L
.14959 .24555 L
.14906 .24601 L
Mistroke
.14851 .24648 L
.14796 .24695 L
.14743 .24742 L
.1469 .24787 L
.1464 .2483 L
.14596 .24867 L
.1456 .24897 L
.14536 .24918 L
.14522 .24929 L
.14518 .24933 L
.14521 .24933 L
.14527 .24931 L
.14533 .24931 L
.14535 .24932 L
.14534 .24935 L
.14532 .24935 L
.14533 .24928 L
.14539 .24913 L
.1455 .24888 L
.14566 .24853 L
.14586 .24809 L
.14609 .2476 L
.14632 .24706 L
.14656 .24647 L
.14681 .24584 L
.14707 .24516 L
.14737 .24445 L
.14768 .24369 L
.14802 .24291 L
.14836 .2421 L
.14869 .24125 L
.14901 .24039 L
.14931 .23952 L
.14958 .2387 L
.14982 .23788 L
.15004 .23705 L
.15023 .23624 L
.15039 .23552 L
.15051 .23496 L
.15058 .23445 L
.15062 .23395 L
.15067 .23349 L
.15076 .233 L
.15094 .23247 L
.15126 .23183 L
.15174 .23098 L
.15241 .22996 L
.15332 .22866 L
.15434 .22707 L
.15562 .22528 L
Mistroke
.15705 .22345 L
.15865 .22123 L
.16043 .2187 L
.16234 .21598 L
.16414 .21314 L
.16617 .21035 L
.16805 .20748 L
.16991 .20458 L
.17191 .20182 L
.17382 .19914 L
.17545 .19637 L
.17709 .19399 L
.17882 .19161 L
.18039 .18927 L
.18193 .18726 L
.18336 .18525 L
.1847 .18347 L
.18592 .18174 L
.18712 .18013 L
.18827 .17847 L
.1895 .17686 L
.19069 .17524 L
.19198 .17351 L
.19337 .17185 L
.19466 .17009 L
.19601 .16834 L
.19743 .1665 L
.19878 .16485 L
.20018 .16302 L
.20157 .16149 L
.2028 .15994 L
.20401 .15843 L
.20517 .15704 L
.20618 .15571 L
.20708 .15452 L
.20786 .15343 L
.20852 .1524 L
.20913 .15143 L
.20972 .15053 L
.21029 .14974 L
.21085 .14898 L
.2114 .14827 L
.21194 .14763 L
.21245 .14711 L
.21291 .14667 L
.21331 .14633 L
.21365 .14608 L
.21394 .14591 L
.21416 .14581 L
.21433 .14578 L
Mistroke
.21446 .1458 L
.21453 .14584 L
.21456 .14589 L
.21456 .14593 L
.21454 .14596 L
.2145 .14599 L
.21446 .14601 L
.21442 .14601 L
.21441 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.21441 .14601 L
.21442 .14598 L
.21445 .14591 L
.21449 .14581 L
.21453 .14571 L
.21455 .14567 L
.21454 .1457 L
.21448 .14584 L
Mistroke
.21438 .1461 L
.21422 .14651 L
.21402 .14704 L
.21379 .14766 L
.21354 .14834 L
.21327 .14905 L
.213 .14977 L
.21272 .15048 L
.21245 .1512 L
.21218 .15189 L
.21193 .1525 L
.21172 .15295 L
.21158 .15321 L
.21153 .15324 L
.21156 .15307 L
.21166 .15275 L
.21181 .15231 L
.212 .15178 L
.21221 .1512 L
.21242 .15057 L
.21267 .14991 L
.21294 .14918 L
.21326 .1484 L
.21361 .1476 L
.21402 .14679 L
.21448 .14599 L
.215 .14519 L
.21558 .14439 L
.21622 .1436 L
.21695 .14284 L
.21778 .14208 L
.2187 .14129 L
.21973 .14047 L
.2209 .13963 L
.22213 .13882 L
.22349 .138 L
.22486 .13717 L
.22634 .13633 L
.22779 .1355 L
.22913 .13469 L
.23048 .13392 L
.23173 .13323 L
.23288 .13265 L
.23392 .13217 L
.23481 .13173 L
.23562 .13132 L
.23631 .13094 L
.23696 .13056 L
.23755 .13022 L
.2381 .1299 L
Mistroke
.23862 .12959 L
.23917 .12926 L
.23974 .12887 L
.2404 .12842 L
.24119 .12789 L
.24209 .12722 L
.24313 .12643 L
.24432 .12554 L
.24562 .12459 L
.2471 .12365 L
.24863 .12263 L
.25038 .12161 L
.25209 .12061 L
.25403 .11957 L
.25609 .11844 L
.25825 .11726 L
.26071 .11609 L
.26283 .11489 L
.26552 .11372 L
.26772 .11257 L
.26998 .11143 L
.27239 .11036 L
.2748 .10933 L
.27729 .10825 L
.27963 .10706 L
.28204 .10591 L
.28447 .10467 L
.28693 .1033 L
.2894 .10188 L
.29191 .10028 L
.2945 .09884 L
.29719 .0973 L
.29988 .09567 L
.30268 .09402 L
.3052 .09254 L
.30809 .09105 L
.31069 .0894 L
.31355 .08786 L
.31622 .0863 L
.31894 .08478 L
.32161 .08349 L
.32419 .08217 L
.32693 .0809 L
.32907 .07977 L
.33157 .07863 L
.33347 .07757 L
.33544 .0765 L
.33735 .07546 L
.33931 .07449 L
.34092 .07363 L
Mistroke
.34254 .07281 L
.34426 .07198 L
.34602 .07111 L
.34784 .07017 L
.34996 .06919 L
.35213 .06808 L
.35475 .06682 L
.35702 .06547 L
.35974 .06397 L
.36273 .0625 L
.36556 .06094 L
.36859 .05933 L
.37159 .05786 L
.3746 .05642 L
.3772 .05513 L
.37968 .05396 L
.38193 .05298 L
.38378 .05221 L
.38538 .0516 L
.3867 .05117 L
.38768 .0509 L
.38844 .05076 L
.38897 .05075 L
.38929 .05079 L
.38944 .05087 L
.38946 .05097 L
.3894 .05104 L
.38929 .05105 L
.38916 .05095 L
.38905 .05072 L
.38897 .0504 L
.38892 .05 L
.3889 .04954 L
.38889 .04902 L
.38889 .04844 L
.38889 .04797 L
.38889 .0475 L
.38889 .04709 L
.38889 .04679 L
.38889 .04666 L
.38888 .04675 L
.38885 .04706 L
.38881 .04754 L
.38877 .0481 L
.38875 .04866 L
.38876 .04916 L
.38881 .0496 L
.38889 .04995 L
.38898 .05015 L
.38909 .05019 L
Mistroke
.38922 .05009 L
.38937 .04985 L
.38958 .0495 L
.38986 .04908 L
.39022 .04862 L
.39068 .04811 L
.39125 .04759 L
.39192 .04714 L
.39268 .04683 L
.39351 .04665 L
.39433 .04656 L
.39517 .04654 L
.39599 .04659 L
.39678 .04668 L
.39752 .04678 L
.39824 .04687 L
.39899 .04692 L
.39972 .04695 L
.40047 .04698 L
.40124 .04701 L
.40204 .04704 L
.4029 .04707 L
.40384 .0471 L
.40495 .04714 L
.4062 .04719 L
.40771 .04724 L
.40931 .0473 L
.41118 .04736 L
.41318 .04743 L
.41537 .04751 L
.4178 .04759 L
.42019 .04768 L
.42275 .04777 L
.42543 .04786 L
.4281 .04797 L
.43084 .04808 L
.43367 .0482 L
.43629 .04831 L
.439 .0484 L
.44163 .04847 L
.4443 .04853 L
.4465 .04857 L
.44866 .04857 L
.4507 .04852 L
.45264 .04843 L
.45451 .04832 L
.4563 .04821 L
.45811 .04811 L
.45985 .04801 L
.46167 .04793 L
Mistroke
.46351 .04786 L
.46538 .04783 L
.46734 .04784 L
.46924 .0479 L
.4712 .04799 L
.47314 .04812 L
.47504 .04828 L
.47702 .04847 L
.47891 .04867 L
.48087 .04888 L
.48274 .04906 L
.48455 .04925 L
.48626 .04942 L
.48783 .04958 L
.48914 .04973 L
.49029 .04984 L
.49143 .04995 L
.49241 .05004 L
.49339 .0501 L
.49438 .05012 L
.49541 .05007 L
.49651 .04996 L
.49774 .0498 L
.49915 .0496 L
.50076 .0494 L
.50243 .04921 L
.50413 .04904 L
.50633 .0489 L
.50843 .04881 L
.51093 .04877 L
.51357 .0488 L
.51626 .04889 L
.51873 .04904 L
.5211 .04926 L
.52332 .04952 L
.52523 .0498 L
.52696 .05009 L
.52845 .0504 L
.52972 .05064 L
.53078 .05085 L
.53162 .05101 L
.53224 .05112 L
.53267 .05118 L
.53293 .0512 L
.53307 .05121 L
.53312 .0512 L
.53313 .05119 L
.53309 .05118 L
.53304 .05117 L
.53297 .05117 L
Mistroke
.5329 .05115 L
.53284 .05115 L
.53281 .05114 L
.5328 .05115 L
.53283 .05116 L
.5329 .05119 L
.533 .05122 L
.5331 .05126 L
.53316 .05128 L
.53313 .05126 L
.533 .05121 L
.53274 .05112 L
.53235 .05098 L
.53185 .05079 L
.53126 .05058 L
.53065 .05034 L
.53003 .0501 L
.52938 .04985 L
.52872 .04961 L
.52801 .04936 L
.52725 .04914 L
.52649 .04893 L
.52575 .04877 L
.52507 .04865 L
.52445 .04858 L
.52393 .04854 L
.5235 .04853 L
.52319 .04853 L
.52293 .04853 L
.52264 .04851 L
.5223 .0485 L
.52191 .0485 L
.52149 .04854 L
.52102 .04861 L
.5205 .04873 L
.51994 .04888 L
.51934 .04906 L
.51873 .04927 L
.5181 .04948 L
.51748 .04969 L
.51687 .04991 L
.51627 .05013 L
.51571 .05034 L
.51521 .05054 L
.51478 .05071 L
.51441 .05081 L
.51409 .05085 L
.5138 .05081 L
.51352 .0507 L
.51324 .05053 L
Mistroke
.5129 .05031 L
.51242 .05006 L
.5118 .04978 L
.51101 .04948 L
.51001 .04919 L
.50889 .04892 L
.50761 .04867 L
.50611 .04847 L
.50435 .04833 L
.50232 .04826 L
.50038 .04827 L
.49794 .04836 L
.49549 .04849 L
.4926 .04864 L
.48962 .04877 L
.48671 .04887 L
.48339 .04891 L
.48038 .04889 L
.47734 .0488 L
.47425 .04867 L
.47176 .04848 L
.46936 .04826 L
.46721 .04801 L
.46538 .04773 L
.4638 .04745 L
.46256 .0472 L
.46163 .04698 L
.46094 .04683 L
.46046 .04672 L
.46014 .04666 L
.45995 .04664 L
.45986 .04664 L
.45986 .04667 L
.45993 .0467 L
.46006 .04674 L
.46024 .04676 L
.46045 .04676 L
.46068 .04677 L
.46095 .04678 L
.46127 .04679 L
.46166 .0468 L
.46213 .04682 L
.4627 .04682 L
.46338 .04682 L
.46419 .04681 L
.46514 .04681 L
.46624 .04682 L
.46747 .04688 L
.46889 .04697 L
.47046 .04711 L
Mistroke
.47221 .0473 L
.47417 .04753 L
.47623 .0478 L
.4785 .0481 L
.48083 .04844 L
.48323 .04878 L
.48559 .04912 L
.48788 .04942 L
.48995 .04969 L
.49187 .04988 L
.49339 .04997 L
.49467 .04995 L
.49568 .04982 L
.49636 .04962 L
.49674 .04937 L
.49683 .04912 L
.4967 .0489 L
.49644 .04872 L
.49614 .0486 L
.4959 .04855 L
.4958 .04857 L
.49595 .04865 L
.49639 .04879 L
.49716 .04899 L
.49822 .04923 L
.49964 .0495 L
.50135 .0498 L
.50342 .05008 L
.50597 .05033 L
.50852 .05052 L
.51152 .05067 L
.51479 .05078 L
.51853 .05086 L
.52186 .05093 L
.52556 .051 L
.52955 .05107 L
.53321 .05116 L
.53708 .05126 L
.54116 .05137 L
.54513 .05147 L
.5487 .05157 L
.5523 .05167 L
.55606 .05177 L
.56029 .05186 L
.56352 .05195 L
.56696 .05204 L
.57049 .05213 L
.57383 .05221 L
.57678 .05228 L
.57969 .05233 L
Mistroke
.58249 .05235 L
.58463 .05238 L
.58689 .05243 L
.58874 .05253 L
.59023 .05265 L
.59155 .05278 L
.59263 .05289 L
.59341 .05299 L
.59392 .05308 L
.59419 .05319 L
.59429 .05334 L
.59431 .05356 L
.59431 .05382 L
.59437 .05413 L
.59452 .05447 L
.59477 .05483 L
.59513 .05519 L
.59557 .05554 L
.59608 .05582 L
.59667 .05612 L
.59728 .0564 L
.59802 .05667 L
.5989 .05693 L
.59977 .05717 L
.60071 .05737 L
.60169 .05751 L
.60267 .05757 L
.60356 .05756 L
.6044 .05751 L
.60514 .05746 L
.6058 .05743 L
.60639 .05741 L
.60692 .05738 L
.60738 .05734 L
.60778 .0573 L
.60809 .05728 L
.6083 .05729 L
.60838 .05735 L
.60834 .05746 L
.60821 .05764 L
.60802 .0579 L
.6078 .05822 L
.60758 .05859 L
.60739 .059 L
.60724 .05943 L
.60714 .05985 L
.60707 .0603 L
.60703 .06069 L
.60702 .06107 L
.60706 .06141 L
Mistroke
.60714 .06168 L
.60729 .06187 L
.6075 .06198 L
.60777 .06202 L
.60808 .06202 L
.6084 .062 L
.60871 .06197 L
.609 .06194 L
.60927 .06193 L
.6095 .06192 L
.60971 .06191 L
.60991 .06191 L
.61009 .06191 L
.61025 .06192 L
.61039 .06192 L
.61049 .06192 L
.61055 .06193 L
.61056 .06193 L
.61055 .06193 L
.61051 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
Mistroke
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61045 .06193 L
.61047 .06195 L
.61051 .06196 L
.61054 .06196 L
.61056 .06197 L
.61055 .06199 L
.6105 .06202 L
.61041 .06203 L
.61027 .06199 L
.6101 .06187 L
.6099 .06166 L
.60968 .0614 L
.60944 .06111 L
.60921 .0608 L
.60898 .06058 L
.60875 .0604 L
.60854 .06027 L
.60836 .06021 L
.60821 .0602 L
.60811 .06023 L
.60805 .06032 L
.60804 .06043 L
.60808 .06061 L
.60816 .06085 L
.60827 .06112 L
.60836 .0614 L
.60841 .06166 L
.60839 .06186 L
Mistroke
.60829 .06201 L
.60811 .06208 L
.60785 .06206 L
.6075 .06199 L
.6071 .06192 L
.60665 .06187 L
.60617 .06187 L
.60569 .0619 L
.60522 .06193 L
.60478 .0619 L
.60437 .06183 L
.60404 .06173 L
.60379 .0616 L
.60365 .06146 L
.6036 .06132 L
.60363 .0612 L
.60371 .06111 L
.60381 .06106 L
.60391 .06103 L
.60397 .06103 L
.604 .06104 L
.604 .06104 L
.60398 .06108 L
.60395 .06117 L
.60391 .06131 L
.60388 .06149 L
.60385 .06171 L
.60382 .0619 L
.60378 .06204 L
.60373 .06209 L
.60365 .06202 L
.60354 .06183 L
.60339 .06152 L
.6032 .06115 L
.60299 .06073 L
.60278 .06028 L
.6026 .05983 L
.60245 .05937 L
.60235 .05893 L
.6023 .05849 L
.60229 .05808 L
.60233 .05772 L
.60241 .05744 L
.60254 .05724 L
.60271 .05713 L
.60292 .05711 L
.60315 .05716 L
.60337 .05728 L
.60355 .05742 L
.60368 .05754 L
Mistroke
.60376 .0576 L
.60377 .05758 L
.60376 .05749 L
.60372 .05732 L
.60369 .05705 L
.60366 .05672 L
.60364 .05632 L
.60364 .05589 L
.60364 .05543 L
.60364 .05495 L
.60363 .05445 L
.60363 .05396 L
.60363 .05349 L
.60363 .0531 L
.60363 .05284 L
.60363 .05273 L
.60363 .05279 L
.60363 .05302 L
.60363 .05337 L
.60363 .05382 L
.60363 .05432 L
.60364 .05483 L
.60364 .05531 L
.60364 .05577 L
.60364 .0562 L
.60364 .05661 L
.60364 .05697 L
.60364 .05726 L
.60364 .05746 L
.60364 .05758 L
.60364 .05761 L
.60364 .05759 L
.60364 .05753 L
.60364 .05745 L
.60364 .0574 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
Mistroke
.60364 .05737 L
.60366 .05737 L
.60371 .05737 L
.6038 .05737 L
.6039 .05737 L
.60395 .05737 L
.60393 .05737 L
.60382 .05737 L
.6036 .05736 L
.60324 .05735 L
.60274 .05734 L
.60214 .05733 L
.6015 .05731 L
.60089 .0573 L
.60034 .05728 L
.59979 .05727 L
.59917 .05725 L
.59848 .05723 L
.59778 .05722 L
.5971 .0572 L
.59648 .05719 L
.59591 .05718 L
.59538 .05717 L
.59492 .05716 L
.59454 .05715 L
.59423 .05714 L
.59385 .05713 L
.59342 .05714 L
.59303 .05718 L
.59271 .05724 L
.59248 .0573 L
.59232 .05733 L
.59222 .05731 L
.59215 .05722 L
.59209 .05704 L
.59202 .05675 L
.59193 .05636 L
.59177 .05595 L
.59156 .05558 L
.59132 .05525 L
.59109 .05495 L
.59085 .05468 L
.59062 .05444 L
.59041 .05421 L
.59023 .05397 L
.59008 .05372 L
.58996 .05347 L
.58988 .05328 L
.58983 .0532 L
.58981 .05323 L
Mistroke
.58983 .05336 L
.58988 .05353 L
.58997 .05371 L
.5901 .05392 L
.59026 .05418 L
.59045 .05449 L
.59066 .05483 L
.59086 .05514 L
.59104 .05546 L
.59118 .05578 L
.59128 .05601 L
.59132 .05605 L
.59131 .05588 L
.59125 .05561 L
.59118 .05531 L
.59109 .05503 L
.591 .05472 L
.59088 .05442 L
.59076 .05418 L
.59064 .05401 L
.59055 .05393 L
.59049 .05391 L
.59047 .05393 L
.59046 .05397 L
.59048 .05401 L
.59049 .05405 L
.59051 .05405 L
.5905 .05396 L
.59045 .05378 L
.59038 .0535 L
.59028 .05326 L
.59017 .05303 L
.59008 .05291 L
.59001 .05293 L
.58996 .05309 L
.58995 .05337 L
.58997 .0537 L
.59 .054 L
.59002 .05423 L
.59003 .05437 L
.59004 .05446 L
.59004 .05448 L
.59004 .05446 L
.59004 .05437 L
.59004 .05423 L
.59004 .054 L
.59003 .05371 L
.59003 .05339 L
.59003 .05307 L
.59003 .05279 L
Mistroke
.59003 .05259 L
.59003 .05247 L
.59003 .05243 L
.59003 .05245 L
.59003 .05249 L
.59003 .05256 L
.59003 .0526 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59002 .05261 L
.59001 .0526 L
.59 .05258 L
.59 .05255 L
.59 .05252 L
.59 .05249 L
.59 .05248 L
.59001 .05253 L
.59005 .05267 L
.59013 .05289 L
.59023 .05317 L
.59035 .05348 L
.59047 .05379 L
.59058 .05407 L
.59067 .05425 L
.59074 .05438 L
.59077 .05445 L
.59078 .05446 L
.59076 .05443 L
.59073 .05434 L
.59068 .05421 L
.59059 .05398 L
.59049 .0537 L
.59038 .0534 L
.59027 .05309 L
.59016 .05283 L
.59007 .05262 L
.59 .0525 L
.58995 .05245 L
.58994 .05248 L
.58996 .05256 L
.58999 .05263 L
.59002 .05269 L
.59003 .05271 L
.59003 .05272 L
.59003 .05272 L
.59003 .05271 L
.59003 .05271 L
.59003 .0527 L
Mistroke
.59003 .05268 L
.59003 .05267 L
.59003 .05265 L
.59003 .05263 L
.59003 .05262 L
.59003 .05261 L
.59003 .05261 L
.59003 .05262 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59004 .05262 L
.59005 .0526 L
.59008 .05255 L
.59011 .05248 L
.59015 .05242 L
.59016 .05239 L
.59015 .05241 L
.5901 .05251 L
.59001 .05269 L
.58986 .05295 L
.58966 .05329 L
.58943 .05371 L
.58919 .0542 L
.58894 .05473 L
.58871 .05523 L
.5885 .05571 L
.58833 .05612 L
.58821 .05644 L
.58816 .05663 L
.58818 .05666 L
.58827 .05651 L
.58842 .05619 L
.58863 .05574 L
.58888 .05522 L
.58917 .05471 L
.58945 .05424 L
.58969 .05381 L
Mistroke
.58987 .05345 L
.58996 .05319 L
.58999 .05302 L
.58996 .05294 L
.58988 .05292 L
.58979 .05294 L
.58969 .053 L
.5896 .05307 L
.58954 .05315 L
.5895 .05319 L
.58948 .05321 L
.58948 .05314 L
.58949 .05302 L
.58953 .05286 L
.58959 .05269 L
.58968 .05257 L
.58978 .05252 L
.58989 .05257 L
.58998 .05274 L
.59006 .05305 L
.59011 .0534 L
.59012 .05382 L
.59011 .05427 L
.59007 .05472 L
.59005 .05514 L
.59004 .05557 L
.59004 .05599 L
.59004 .05637 L
.59004 .05669 L
.59004 .05696 L
.59004 .05715 L
.59004 .05726 L
.59004 .05729 L
.59004 .05726 L
.59004 .05719 L
.59004 .05712 L
.59004 .05707 L
.59004 .05704 L
.59005 .05704 L
.59011 .05704 L
.59022 .05704 L
.59034 .05703 L
.59044 .05702 L
.59048 .057 L
.59043 .05699 L
.59027 .05701 L
.58992 .05704 L
.58938 .05708 L
.58861 .05713 L
.58763 .05718 L
Mistroke
.58646 .05721 L
.5852 .05723 L
.58413 .05724 L
.58291 .05722 L
.58146 .0572 L
.58035 .05716 L
.57926 .05714 L
.57827 .0571 L
.57759 .05705 L
.57714 .05698 L
.57689 .05691 L
.57683 .05684 L
.57694 .05678 L
.57718 .05673 L
.57747 .05669 L
.57778 .05668 L
.57809 .05669 L
.57836 .05672 L
.57856 .05675 L
.5787 .05676 L
.57878 .05677 L
.5788 .05677 L
.57879 .05677 L
.57875 .05676 L
.57872 .05676 L
.57868 .05676 L
.57867 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57867 .05676 L
.57868 .05674 L
.57871 .0567 L
.57874 .05664 L
.57878 .05658 L
.57879 .05656 L
.57878 .05663 L
.57873 .05677 L
.57864 .05698 L
Mistroke
.57851 .05723 L
.57833 .0575 L
.57813 .05775 L
.57791 .05799 L
.57767 .0582 L
.57744 .05836 L
.5772 .05846 L
.57697 .05849 L
.57676 .05842 L
.57658 .05827 L
.57643 .05797 L
.57634 .05754 L
.57631 .05698 L
.57633 .05635 L
.57638 .05567 L
.57643 .05499 L
.57645 .05434 L
.57643 .05374 L
.57636 .0532 L
.57622 .05271 L
.57605 .05225 L
.57585 .05181 L
.57562 .05141 L
.57539 .05106 L
.57515 .05079 L
.57491 .05058 L
.57469 .05041 L
.57447 .05028 L
.57429 .05015 L
.57414 .05004 L
.57404 .04995 L
.57398 .04987 L
.57396 .0498 L
.57398 .04971 L
.57401 .04965 L
.57405 .04963 L
.57408 .04968 L
.57409 .0498 L
.5741 .05001 L
.5741 .05032 L
.5741 .05074 L
.5741 .05126 L
.5741 .05188 L
.5741 .0526 L
.57413 .0534 L
.5742 .05422 L
.57431 .05509 L
.57441 .05603 L
.57445 .05698 L
.57442 .0579 L
Mistroke
.57428 .0587 L
.57402 .05934 L
.57362 .05988 L
.5731 .0603 L
.57248 .06063 L
.57181 .06087 L
.57111 .06105 L
.57043 .06116 L
.56977 .06121 L
.56911 .06121 L
.56847 .06115 L
.5679 .06108 L
.56745 .06102 L
.56717 .06102 L
.56703 .06106 L
.56701 .06113 L
.56706 .06118 L
.56714 .0612 L
.56721 .06116 L
.5672 .06103 L
.5671 .06079 L
.56693 .06043 L
.56673 .05994 L
.5665 .05934 L
.56626 .05863 L
.56602 .05791 L
.56578 .05713 L
.56553 .05628 L
.56529 .05537 L
.56507 .05443 L
.56489 .05359 L
.56477 .05279 L
.56472 .05206 L
.56476 .05145 L
.56486 .05099 L
.56503 .05071 L
.56524 .05061 L
.56548 .05066 L
.56572 .05086 L
.56596 .0512 L
.56619 .05164 L
.56643 .05217 L
.56666 .05277 L
.56688 .0534 L
.56706 .05403 L
.56721 .05462 L
.56731 .0552 L
.56737 .05573 L
.56739 .05616 L
.56737 .05646 L
Mistroke
.56734 .05665 L
.56734 .05674 L
.5674 .05676 L
.5675 .05673 L
.56759 .05667 L
.56765 .0566 L
.56765 .05653 L
.56756 .05649 L
.56732 .05648 L
.56692 .05647 L
.56635 .05646 L
.56562 .05644 L
.56475 .05642 L
.56376 .0564 L
.56276 .05637 L
.56171 .05635 L
.56065 .05632 L
.55962 .05629 L
.55869 .05627 L
.55793 .05625 L
.55725 .05623 L
.55664 .05621 L
.55609 .0562 L
.55559 .05619 L
.5551 .05617 L
.55458 .05616 L
.55404 .05615 L
.55347 .05613 L
.5529 .05612 L
.5523 .0561 L
.55167 .05609 L
.55093 .05607 L
.55011 .05605 L
.54927 .05603 L
.54845 .05601 L
.5477 .05599 L
.54703 .05597 L
.54647 .05596 L
.54602 .05595 L
.54564 .05594 L
.54529 .05592 L
.54496 .05589 L
.54466 .05584 L
.54444 .05576 L
.54429 .05569 L
.54423 .05566 L
.54423 .05568 L
.54429 .05578 L
.54436 .05595 L
.54439 .05622 L
Mistroke
.54432 .05655 L
.54412 .05694 L
.54377 .05737 L
.54328 .05781 L
.54265 .05824 L
.54191 .05867 L
.54107 .05908 L
.54019 .05947 L
.53934 .05981 L
.53856 .06005 L
.53786 .0602 L
.53718 .06026 L
.53655 .06027 L
.53602 .06024 L
.53558 .06021 L
.53522 .06022 L
.5349 .06029 L
.53454 .06042 L
.53408 .06061 L
.53349 .06081 L
.53274 .06102 L
.53182 .06123 L
.53069 .06143 L
.52938 .06162 L
.52794 .0618 L
.52647 .06194 L
.52502 .06204 L
.52348 .0621 L
.52183 .06212 L
.52039 .0621 L
.51899 .06205 L
.51766 .06198 L
.51645 .06192 L
.5154 .06186 L
.51455 .06182 L
.51381 .0618 L
.51319 .06178 L
.51267 .06177 L
.51224 .06176 L
.51191 .06175 L
.5117 .06174 L
.5116 .06174 L
.51158 .06174 L
.51163 .06174 L
.51174 .06174 L
.51185 .06175 L
.51192 .06175 L
.51195 .06175 L
.51195 .06175 L
.51195 .06175 L
Mistroke
.51196 .06175 L
.51198 .06173 L
.51204 .06168 L
.51214 .06162 L
.51224 .06155 L
.51234 .06151 L
.51242 .06152 L
.51246 .06161 L
.51237 .06178 L
.5121 .06203 L
.51166 .06234 L
.51104 .0627 L
.51021 .06313 L
.50915 .06362 L
.50801 .06414 L
.50673 .06461 L
.5054 .06503 L
.50395 .06539 L
.50235 .0657 L
.50075 .06583 L
.49925 .06583 L
.49771 .06567 L
.49608 .06535 L
.49437 .06487 L
.49264 .06426 L
.4911 .06354 L
.48932 .06278 L
.48738 .06194 L
.48558 .06102 L
.48368 .05999 L
.4816 .05893 L
.47962 .0578 L
.47747 .05662 L
.47546 .05553 L
.47378 .05449 L
.47223 .05349 L
.47086 .05253 L
.46976 .05166 L
.4689 .05091 L
.46822 .05027 L
.46774 .04975 L
.46745 .04935 L
.46732 .04905 L
.46734 .04885 L
.46747 .04873 L
.46767 .04871 L
.4679 .04876 L
.46809 .04888 L
.46816 .04906 L
.46804 .04932 L
Mistroke
.46768 .04965 L
.46703 .05007 L
.46603 .05059 L
.46462 .0512 L
.46302 .05188 L
.46081 .05259 L
.45839 .05333 L
.45524 .05408 L
.45194 .05482 L
.44819 .05549 L
.44495 .05607 L
.44049 .05657 L
.43687 .05695 L
.43217 .0572 L
.42873 .05729 L
.42451 .05723 L
.42126 .05702 L
.41756 .05669 L
.41487 .05629 L
.41208 .05583 L
.40948 .05531 L
.40748 .05474 L
.40562 .05412 L
.40408 .05349 L
.40271 .0528 L
.40152 .05207 L
.40048 .05131 L
.39957 .05055 L
.39887 .04984 L
.39819 .04919 L
.39758 .04866 L
.39704 .04819 L
.3966 .04778 L
.39626 .04742 L
.39607 .04711 L
.39606 .04686 L
.39624 .04669 L
.39661 .04661 L
.39715 .04661 L
.39779 .04666 L
.39851 .04676 L
.39925 .04686 L
.39999 .04695 L
.40071 .04702 L
.4014 .04709 L
.40202 .04715 L
.40254 .04718 L
.40294 .04718 L
.40321 .04715 L
.40334 .04706 L
Mistroke
.40333 .04692 L
.40321 .04675 L
.40301 .04654 L
.40275 .04631 L
.40245 .04606 L
.40215 .04582 L
.40185 .04557 L
.40158 .04533 L
.40133 .04511 L
.40112 .0449 L
.40094 .04472 L
.4008 .04458 L
.40072 .04446 L
.40071 .04437 L
.40077 .04433 L
.4009 .04435 L
.40106 .04443 L
.40126 .04456 L
.40147 .04478 L
.40166 .04511 L
.40178 .04558 L
.40182 .04619 L
.40176 .0469 L
.4016 .04774 L
.40132 .0487 L
.40096 .0497 L
.40049 .05068 L
.39995 .05168 L
.39935 .05265 L
.39874 .05357 L
.39813 .05431 L
.39752 .05493 L
.39694 .05541 L
.39644 .05574 L
.39605 .05595 L
.39582 .05608 L
.39573 .05617 L
.39576 .05623 L
.3959 .05628 L
.39611 .05632 L
.39636 .05636 L
.39664 .05641 L
.39691 .05646 L
.39717 .05652 L
.39742 .05656 L
.39767 .05658 L
.39792 .05657 L
.39814 .05653 L
.39833 .05645 L
.39849 .05635 L
Mistroke
.3986 .05625 L
.39866 .05615 L
.39867 .05608 L
.39864 .05607 L
.39857 .05612 L
.39848 .05624 L
.39837 .05643 L
.39828 .05668 L
.39822 .05695 L
.39823 .0572 L
.39832 .05743 L
.39852 .05765 L
.39883 .05784 L
.39924 .05801 L
.39976 .05815 L
.40036 .05825 L
.40101 .05832 L
.40175 .05837 L
.40253 .05841 L
.40338 .05844 L
.40418 .05847 L
.40495 .0585 L
.40566 .05851 L
.40628 .05852 L
.40679 .05849 L
.40719 .05841 L
.40751 .05828 L
.40778 .05811 L
.40802 .05791 L
.40827 .0577 L
.40853 .05748 L
.4088 .05725 L
.40908 .05699 L
.40934 .0567 L
.40957 .0564 L
.40979 .05612 L
.40999 .05588 L
.41017 .05564 L
.41035 .05546 L
.41048 .05525 L
.41056 .05502 L
.41058 .05475 L
.41055 .05446 L
.41048 .05413 L
.41042 .05377 L
.4104 .05343 L
.41044 .05314 L
.41056 .05294 L
.41076 .05275 L
.41101 .0526 L
Mistroke
.41131 .05247 L
.41166 .05233 L
.41206 .05214 L
.41255 .05189 L
.41313 .05156 L
.41382 .0512 L
.41458 .05082 L
.41542 .05044 L
.4163 .05006 L
.4172 .04966 L
.41804 .04924 L
.41887 .04882 L
.41961 .04842 L
.42033 .04808 L
.42094 .04781 L
.4215 .04762 L
.42198 .04753 L
.42236 .0475 L
.42263 .04754 L
.42277 .04761 L
.42279 .04768 L
.42272 .04773 L
.42261 .04776 L
.42251 .04776 L
.42245 .04775 L
.42245 .04775 L
.42253 .04776 L
.42267 .04776 L
.42286 .04776 L
.42311 .04776 L
.42338 .04776 L
.42367 .04776 L
.42393 .04776 L
.42417 .04773 L
.42436 .0477 L
.42449 .04768 L
.42454 .04769 L
.42451 .04776 L
.42441 .0479 L
.42423 .04812 L
.424 .0484 L
.42374 .04878 L
.42345 .04915 L
.42317 .04959 L
.42291 .05001 L
.42271 .05041 L
.42255 .05079 L
.42244 .05112 L
.42238 .05137 L
.42236 .05155 L
Mistroke
.42237 .05163 L
.42241 .05165 L
.42245 .05162 L
.42248 .05161 L
.4225 .05151 L
.4225 .05146 L
.4225 .05145 L
.4225 .0515 L
.4225 .05162 L
.4225 .05172 L
.4225 .05178 L
.4225 .05183 L
.42248 .05183 L
.42246 .05174 L
.42242 .05154 L
.42238 .05125 L
.42236 .05088 L
.42238 .05043 L
.42243 .04995 L
.42254 .04946 L
.42271 .04895 L
.42293 .04844 L
.42318 .04799 L
.42344 .04766 L
.42367 .04748 L
.42387 .04746 L
.42402 .04761 L
.42412 .0479 L
.42416 .0483 L
.42414 .04877 L
.42406 .04926 L
.42392 .04976 L
.42373 .05022 L
.4235 .05068 L
.42325 .05111 L
.42299 .05153 L
.42275 .05189 L
.42257 .05218 L
.42244 .05238 L
.42238 .0525 L
.42236 .05253 L
.42238 .05251 L
.42241 .05244 L
.42247 .05239 L
.42252 .05239 L
.42258 .05243 L
.42262 .0525 L
.42264 .05253 L
.42263 .05251 L
.42258 .05241 L
Mistroke
.42248 .05223 L
.42235 .05196 L
.42218 .05162 L
.422 .0512 L
.42181 .05074 L
.42159 .05027 L
.42136 .04981 L
.4211 .04935 L
.4208 .04888 L
.42048 .04845 L
.42015 .04807 L
.41981 .04777 L
.41949 .04756 L
.41919 .04743 L
.41892 .04738 L
.41868 .0474 L
.41847 .04746 L
.41827 .04753 L
.41808 .04759 L
.41791 .04761 L
.41776 .0476 L
.41766 .0476 L
.4176 .04759 L
.41758 .04759 L
.4176 .04758 L
.41765 .04758 L
.41772 .04757 L
.41778 .04757 L
.41783 .04757 L
.41785 .04757 L
.41783 .04758 L
.41775 .0476 L
.41762 .04762 L
.41744 .04765 L
.41725 .04768 L
.41705 .0477 L
.41688 .04772 L
.41674 .04774 L
.41663 .04775 L
.41657 .04776 L
.41654 .04776 L
.41656 .04775 L
.41661 .04774 L
.41669 .04773 L
.41683 .04771 L
.417 .04768 L
.4172 .04765 L
.4174 .04762 L
.41759 .04759 L
.41774 .04758 L
Mistroke
.41783 .04757 L
.41786 .04757 L
.41783 .04757 L
.41776 .04758 L
.41769 .04759 L
.41762 .0476 L
.41759 .04763 L
.4176 .04766 L
.41765 .0477 L
.41775 .04772 L
.41789 .04771 L
.41807 .04767 L
.41828 .04759 L
.41851 .04746 L
.41876 .0473 L
.41901 .0471 L
.41926 .04689 L
.4195 .04666 L
.41972 .04644 L
.41991 .04621 L
.42006 .04599 L
.42017 .04578 L
.42023 .0456 L
.42025 .04546 L
.42024 .04535 L
.4202 .0453 L
.42016 .04528 L
.42013 .04529 L
.42011 .04532 L
.42011 .04536 L
.42011 .04539 L
.4201 .04539 L
.42007 .04537 L
.42003 .04533 L
.41999 .04529 L
.41996 .04527 L
.41994 .04528 L
.41994 .04533 L
.41997 .04543 L
.42002 .04556 L
.42012 .04574 L
.42027 .04594 L
.42049 .04617 L
.42082 .04642 L
.42128 .04667 L
.42189 .04692 L
.42266 .04718 L
.42361 .04742 L
.42468 .04764 L
.42593 .04783 L
Mistroke
.42736 .04798 L
.42876 .04808 L
.43028 .04815 L
.43184 .04819 L
.43341 .04821 L
.43495 .04823 L
.43632 .04825 L
.43762 .04828 L
.43874 .04831 L
.4397 .04834 L
.44044 .04837 L
.44101 .04839 L
.44141 .0484 L
.44167 .04841 L
.44181 .04841 L
.44188 .04841 L
.44187 .04841 L
.44183 .04841 L
.44176 .04841 L
.44168 .04841 L
.44161 .0484 L
.44156 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44152 .0484 L
.44149 .0484 L
.44146 .0484 L
.44142 .0484 L
.4414 .0484 L
.44142 .0484 L
.44147 .0484 L
.44157 .0484 L
.44172 .04838 L
.44193 .04834 L
.44219 .04828 L
.44246 .04822 L
.44272 .0482 L
.44295 .04823 L
Mistroke
.44315 .04833 L
.4433 .04851 L
.44338 .04878 L
.44339 .04912 L
.44333 .04953 L
.4432 .04996 L
.44302 .05042 L
.44279 .05087 L
.44253 .05132 L
.44225 .05175 L
.44199 .05216 L
.44176 .05253 L
.44159 .05282 L
.44148 .05302 L
.44142 .05313 L
.4414 .05317 L
.44142 .05314 L
.44145 .05308 L
.44149 .05301 L
.44152 .05295 L
.44154 .05292 L
.44154 .05292 L
.44156 .05292 L
.44161 .05292 L
.44169 .05293 L
.44175 .05293 L
.44179 .05293 L
.44177 .05293 L
.44168 .05293 L
.4415 .05292 L
.44123 .05291 L
.44089 .05289 L
.44047 .05287 L
.44 .05285 L
.43952 .05283 L
.43909 .05282 L
.43874 .0528 L
.43839 .05279 L
.43799 .05277 L
.43756 .05276 L
.43713 .05274 L
.4367 .05271 L
.43626 .05265 L
.43576 .05257 L
.4352 .05249 L
.43458 .05244 L
.4339 .05244 L
.43312 .05251 L
.43229 .05266 L
.43138 .05289 L
Mistroke
.43042 .05319 L
.42947 .05357 L
.42858 .05399 L
.42776 .05444 L
.42704 .05487 L
.42637 .0553 L
.42573 .05573 L
.42512 .05613 L
.4245 .05648 L
.42387 .05674 L
.42329 .05691 L
.4228 .05697 L
.42237 .05695 L
.42193 .0569 L
.42147 .05683 L
.42095 .05678 L
.42034 .05679 L
.41964 .05688 L
.41887 .05702 L
.41807 .05719 L
.4173 .05739 L
.41661 .05758 L
.41606 .05775 L
.41557 .05789 L
.41503 .05803 L
.41442 .05818 L
.41383 .05836 L
.41334 .05855 L
.41296 .05876 L
.41265 .05899 L
.41234 .05927 L
.41201 .0596 L
.41164 .06001 L
.41114 .0605 L
.41044 .06108 L
.40957 .06175 L
.40852 .06252 L
.40732 .06335 L
.406 .06422 L
.40462 .06509 L
.40334 .06589 L
.40209 .06664 L
.40089 .06732 L
.39977 .06789 L
.39878 .06836 L
.39797 .06873 L
.39729 .06902 L
.39674 .06925 L
.39631 .06944 L
.39598 .0696 L
Mistroke
.39574 .06975 L
.39555 .06992 L
.39538 .07016 L
.39523 .0705 L
.39511 .07094 L
.39503 .07142 L
.39497 .07187 L
.3949 .07222 L
.39483 .07254 L
.39476 .07276 L
.39469 .07293 L
.39465 .07304 L
.39459 .07307 L
.39451 .07306 L
.39438 .07302 L
.39418 .07295 L
.39388 .07289 L
.39346 .0728 L
.39292 .07269 L
.39229 .0726 L
.39158 .07261 L
.39082 .07272 L
.39007 .07293 L
.38929 .07324 L
.38854 .07364 L
.38778 .07409 L
.38698 .07456 L
.38611 .07501 L
.38515 .07542 L
.38409 .07579 L
.38298 .07613 L
.38175 .07648 L
.38035 .07684 L
.37877 .07719 L
.37715 .07752 L
.37552 .0778 L
.37373 .07802 L
.37184 .07821 L
.3701 .07836 L
.36855 .07848 L
.3671 .07859 L
.36578 .0787 L
.36468 .07885 L
.36378 .07903 L
.36306 .07923 L
.36252 .07943 L
.36217 .0796 L
.362 .07973 L
.36199 .0798 L
.36211 .07981 L
Mistroke
.36229 .07976 L
.36247 .07968 L
.36257 .0796 L
.36256 .07954 L
.36239 .07954 L
.36199 .07964 L
.36137 .07986 L
.36054 .08019 L
.35953 .08063 L
.35833 .08118 L
.35707 .08185 L
.3555 .08257 L
.35388 .08337 L
.352 .08422 L
.34982 .08512 L
.34771 .08602 L
.34536 .08684 L
.34289 .08761 L
.34089 .0883 L
.33869 .08891 L
.3367 .08943 L
.3348 .08989 L
.33285 .09029 L
.33137 .09062 L
.33007 .09089 L
.32897 .09111 L
.32811 .09122 L
.3275 .09128 L
.32716 .09129 L
.32702 .09128 L
.32706 .09119 L
.32718 .09109 L
.32735 .09099 L
.32755 .09083 L
.32773 .09067 L
.32784 .09048 L
.3279 .0903 L
.32793 .09014 L
.32794 .09001 L
.32795 .08993 L
.32794 .08989 L
.32792 .08989 L
.32791 .08992 L
.32791 .08996 L
.32791 .08999 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
Mistroke
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32793 .08998 L
.32796 .08993 L
.328 .08986 L
.32803 .0898 L
.32805 .08977 L
.32804 .08979 L
.32799 .08988 L
.32789 .09006 L
.32774 .09032 L
.32755 .09066 L
.32733 .09106 L
.32709 .0915 L
.32684 .09197 L
.32658 .09242 L
.32632 .09285 L
.32607 .09326 L
.32584 .09362 L
.32563 .09393 L
.32544 .0942 L
.32529 .09443 L
.32519 .09462 L
.32516 .09482 L
.32518 .09504 L
.32527 .0953 L
.32541 .0956 L
.32559 .09592 L
.32577 .09629 L
.32597 .09668 L
.32618 .0971 L
.32641 .09755 L
.32668 .098 L
.327 .09845 L
.32735 .0989 L
.32772 .09937 L
.32808 .09985 L
.32841 .10039 L
.32869 .10102 L
.32887 .10176 L
.32893 .10264 L
.32887 .10373 L
.3287 .10505 L
.32844 .10664 L
.32812 .10833 L
Mistroke
.3277 .11009 L
.32719 .11212 L
.32659 .1142 L
.32591 .11638 L
.32518 .11877 L
.3244 .12075 L
.32364 .12307 L
.32292 .12491 L
.32228 .12675 L
.32176 .12851 L
.32138 .12999 L
.3211 .13114 L
.32094 .13208 L
.32088 .13281 L
.32092 .13333 L
.32103 .13366 L
.32121 .13384 L
.32144 .13389 L
.3217 .13388 L
.32199 .1338 L
.32231 .13368 L
.32264 .13352 L
.32295 .13336 L
.32323 .13322 L
.32343 .13311 L
.32355 .13302 L
.32357 .13299 L
.32349 .13305 L
.32329 .13322 L
.32295 .13357 L
.32248 .13413 L
.32183 .13492 L
.32098 .13598 L
.31995 .1372 L
.31871 .13874 L
.31717 .14062 L
.31527 .14254 L
.31323 .14455 L
.31076 .14689 L
.30817 .14898 L
.30513 .1514 L
.30205 .15322 L
.29833 .15493 L
.29525 .1565 L
.29171 .15773 L
.28803 .15861 L
.28482 .15915 L
.2812 .15936 L
.2785 .15926 L
.27586 .15888 L
Mistroke
.27334 .15828 L
.27121 .15748 L
.26954 .15663 L
.26817 .15572 L
.26717 .15481 L
.2665 .15393 L
.26606 .15313 L
.26581 .15239 L
.26564 .15181 L
.26553 .15128 L
.26543 .15078 L
.26532 .15025 L
.26519 .14966 L
.26501 .14898 L
.26472 .14819 L
.26432 .14732 L
.2638 .14636 L
.26312 .14534 L
.26223 .14433 L
.26112 .14327 L
.25977 .14217 L
.25846 .14108 L
.25685 .14014 L
.25489 .1393 L
.25315 .13859 L
.25127 .13799 L
.24911 .13754 L
.24693 .13722 L
.24471 .13703 L
.24229 .13694 L
.24009 .13699 L
.23794 .13716 L
.23562 .13747 L
.2333 .13791 L
.23132 .13846 L
.2292 .13912 L
.22698 .13989 L
.22495 .14067 L
.22308 .14151 L
.22115 .14238 L
.21925 .14325 L
.21757 .14403 L
.21594 .14475 L
.21443 .14538 L
.21312 .14591 L
.21213 .14628 L
.21131 .14648 L
.21067 .1465 L
.21019 .14637 L
.2099 .1461 L
Mistroke
.20979 .14574 L
.20984 .14532 L
.21004 .14486 L
.21037 .14441 L
.21081 .14399 L
.21132 .1436 L
.21186 .14321 L
.21235 .14279 L
.21274 .14234 L
.21305 .14186 L
.2133 .14138 L
.21352 .14088 L
.21373 .1404 L
.21394 .13992 L
.21418 .13945 L
.21444 .139 L
.21474 .13858 L
.21504 .13816 L
.21534 .13775 L
.2156 .13742 L
.21581 .13721 L
.21598 .13717 L
.21611 .1373 L
.2162 .13757 L
.21624 .13799 L
.21621 .13845 L
.21612 .13898 L
.21596 .13951 L
.21576 .14001 L
.21551 .14046 L
.21523 .14082 L
.21495 .14112 L
.21469 .14134 L
.21449 .14148 L
.21436 .14156 L
.21429 .14158 L
.21427 .14155 L
.21431 .14148 L
.21437 .14138 L
.21446 .14126 L
.21453 .14117 L
.21457 .14112 L
.21456 .14114 L
.2145 .14122 L
.21437 .14138 L
.2142 .14161 L
.21398 .14191 L
.21378 .14223 L
.21365 .14252 L
.21358 .14279 L
Mistroke
.21353 .14308 L
.21349 .14343 L
.21344 .14385 L
.21337 .14436 L
.2132 .14501 L
.21285 .1459 L
.21228 .14716 L
.21149 .1488 L
.21046 .15076 L
.20918 .15298 L
.20794 .15495 L
.20631 .15732 L
.20438 .16008 L
.20247 .16252 L
.20039 .16522 L
.19816 .16791 L
.19642 .16993 L
.19478 .1717 L
.19327 .1735 L
.19207 .17476 L
.19118 .17578 L
.19064 .17627 L
.19035 .17638 L
.19023 .17631 L
.19023 .17615 L
.19035 .17594 L
.19054 .17572 L
.19077 .17555 L
.191 .17548 L
.19126 .17547 L
.19154 .17546 L
.19184 .17542 L
.19217 .17536 L
.19247 .1753 L
.19277 .17528 L
.19302 .17531 L
.1932 .17541 L
.19331 .1756 L
.19332 .17587 L
.19324 .17622 L
.19307 .17663 L
.19283 .17708 L
.19254 .17755 L
.19222 .17802 L
.1919 .17849 L
.1916 .17894 L
.19134 .17937 L
.19113 .17974 L
.19096 .18003 L
.19083 .18024 L
Mistroke
.19077 .18036 L
.19075 .18039 L
.19076 .18037 L
.1908 .1803 L
.19085 .18022 L
.19088 .18016 L
.1909 .18014 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.19092 .1801 L
.19095 .18003 L
.19099 .17993 L
.19103 .17983 L
.19105 .17978 L
.19104 .17982 L
.19098 .17996 L
.19087 .18022 L
.19072 .18062 L
.19052 .18115 L
.19028 .18177 L
.19002 .18245 L
.18975 .18315 L
.18947 .18383 L
.18921 .1845 L
.18895 .18516 L
.18873 .18581 L
.18852 .18639 L
.18834 .18685 L
.18819 .18716 L
Mistroke
.18807 .18733 L
.188 .18739 L
.18795 .18736 L
.18794 .18726 L
.18793 .18714 L
.18793 .18706 L
.18792 .18703 L
.18791 .18705 L
.1879 .1871 L
.18787 .18717 L
.18784 .18724 L
.18784 .18728 L
.18787 .18725 L
.18793 .18716 L
.18805 .18698 L
.18821 .18671 L
.1884 .18637 L
.1886 .18596 L
.18881 .18551 L
.18902 .18503 L
.18926 .18457 L
.18954 .1841 L
.18987 .18365 L
.19025 .18324 L
.19068 .18289 L
.19114 .18262 L
.19159 .18243 L
.19199 .18231 L
.19232 .18224 L
.19256 .18222 L
.19271 .18223 L
.19278 .18223 L
.19279 .18222 L
.19273 .18219 L
.19262 .18215 L
.19245 .18212 L
.19224 .1821 L
.19199 .18209 L
.19171 .18209 L
.19143 .1821 L
.19116 .18213 L
.19096 .18218 L
.19083 .18224 L
.19076 .18232 L
.19074 .18239 L
.19075 .18245 L
.19079 .1825 L
.19083 .18252 L
.19087 .18252 L
.19088 .1825 L
Mistroke
.19089 .18247 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18245 L
.19089 .18243 L
.19089 .18238 L
.19089 .1823 L
.19089 .18224 L
.19089 .1822 L
.19089 .18223 L
.19089 .18233 L
.19089 .18251 L
.19088 .18279 L
.19088 .18314 L
.19088 .18356 L
.19087 .18401 L
.19087 .1845 L
.19088 .185 L
.19091 .1855 L
.19095 .186 L
.19098 .18648 L
.191 .18689 L
.19099 .18718 L
.19093 .18731 L
.19082 .18728 L
.19067 .18711 L
.19048 .18684 L
.19025 .18653 L
.19 .18623 L
Mistroke
.18973 .186 L
.18946 .18583 L
.18919 .18543 L
.18893 .18538 L
.18869 .18538 L
.18848 .18543 L
.18831 .18552 L
.18819 .18569 L
.18812 .18592 L
.1881 .1862 L
.18811 .18649 L
.18815 .18677 L
.18818 .187 L
.18818 .18716 L
.18815 .18724 L
.18812 .18724 L
.1881 .18719 L
.18811 .18712 L
.18817 .18707 L
.18827 .18704 L
.18843 .18704 L
.18863 .18705 L
.18888 .18707 L
.18917 .1871 L
.18948 .18713 L
.18978 .18715 L
.19005 .18716 L
.1903 .18714 L
.19049 .18709 L
.19059 .187 L
.19061 .18689 L
.19053 .18677 L
.19037 .18666 L
.19017 .18655 L
.18994 .18643 L
.18972 .18631 L
.18955 .18619 L
.18945 .18607 L
.18945 .18598 L
.18957 .18591 L
.18976 .18594 L
.18998 .1861 L
.19018 .18642 L
.19036 .18693 L
.19048 .18762 L
.19052 .18846 L
.19044 .18945 L
.19021 .19056 L
.18977 .19187 L
.18912 .19339 L
Mistroke
.18823 .19516 L
.18717 .19704 L
.18572 .19937 L
.18411 .20178 L
.18211 .20461 L
.1796 .20791 L
.17711 .2111 L
.17373 .21479 L
.17033 .21891 L
.16687 .22334 L
.16265 .22807 L
.15804 .23289 L
.15336 .2385 L
.14944 .24326 L
.14467 .24861 L
.13941 .25445 L
.13551 .25909 L
.13108 .2641 L
.12672 .26913 L
.12289 .27397 L
.11911 .27871 L
.11515 .28399 L
.11226 .28828 L
.10904 .29319 L
.10626 .29793 L
.10343 .30276 L
.10115 .30742 L
.09914 .31238 L
.09716 .31645 L
.09571 .32053 L
.09446 .32448 L
.09347 .3275 L
.09278 .33023 L
.09239 .3325 L
.09225 .33407 L
.09228 .33504 L
.0924 .33552 L
.09258 .33563 L
.09274 .33554 L
.09282 .33544 L
.09277 .33553 L
.09258 .336 L
.09223 .33697 L
.09174 .33852 L
.09113 .34086 L
.09044 .34354 L
.08964 .34724 L
.08877 .3512 L
.08787 .35572 L
.08698 .36039 L
Mistroke
.0861 .36552 L
.08529 .37077 L
.08457 .37648 L
.08397 .38068 L
.08347 .38524 L
.08311 .38927 L
.08286 .39277 L
.08271 .39541 L
.08264 .3976 L
.08262 .39928 L
.08264 .40038 L
.08269 .40098 L
.08273 .40124 L
.08277 .40124 L
.0828 .40108 L
.08281 .40082 L
.08282 .40054 L
.08283 .40028 L
.08283 .40013 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08284 .40008 L
.08286 .40007 L
.08292 .40004 L
.08301 .4 L
.08309 .39996 L
.08313 .39995 L
.0831 .39996 L
.08298 .40001 L
.08277 .40011 L
.08244 .40025 L
.08202 .40044 L
.08153 .40065 L
.08099 .40089 L
.08042 .40115 L
.07986 .4014 L
.0793 .40166 L
.07875 .4019 L
.07822 .40212 L
.07781 .40229 L
.07756 .40238 L
.07745 .40241 L
.07744 .40238 L
.07748 .40231 L
.07749 .40224 L
.0774 .40225 L
Mistroke
.07714 .40238 L
.07665 .40265 L
.07593 .40309 L
.07501 .40369 L
.07398 .40439 L
.07288 .40516 L
.07186 .40594 L
.07083 .4068 L
.06979 .40772 L
.06872 .40871 L
.06783 .4097 L
.06707 .41073 L
.06649 .4118 L
.06607 .41292 L
.06577 .41404 L
.06557 .41517 L
.06542 .4163 L
.06529 .41734 L
.06509 .41841 L
.06484 .41949 L
.06457 .42055 L
.06429 .42156 L
.06399 .42246 L
.06369 .42323 L
.06342 .42383 L
.06318 .42427 L
.063 .42453 L
.06287 .42465 L
.0628 .42467 L
.06281 .42459 L
.06283 .42453 L
.06287 .42444 L
.06291 .42432 L
.06295 .42418 L
.06296 .42407 L
.06297 .42399 L
.06297 .42394 L
.06297 .42395 L
.06297 .42406 L
.06296 .42431 L
.06295 .42468 L
.06293 .4252 L
.0629 .42589 L
.06287 .4267 L
.06284 .42774 L
.0628 .42889 L
.06277 .42997 L
.06272 .43114 L
.06268 .4326 L
.06264 .43378 L
Mistroke
.06259 .43491 L
.06255 .43603 L
.06252 .4371 L
.06249 .43807 L
.06246 .43887 L
.06244 .4395 L
.06243 .43998 L
.06242 .44025 L
.06242 .4405 L
.06241 .44072 L
.06241 .44091 L
.0624 .44104 L
.06239 .44118 L
.06236 .44141 L
.06227 .44171 L
.06217 .44207 L
.06209 .44254 L
.06205 .44322 L
.06204 .44413 L
.06212 .44511 L
.06231 .44615 L
.06263 .44734 L
.06311 .44878 L
.06378 .45048 L
.06455 .45229 L
.06524 .4538 L
.06586 .45564 L
.06633 .4578 L
.06684 .45945 L
.06748 .4613 L
.06784 .46338 L
.06808 .46513 L
.0682 .46666 L
.06822 .46818 L
.06815 .4696 L
.06801 .47064 L
.06776 .47149 L
.06748 .47212 L
.06724 .47256 L
.06704 .47285 L
.06687 .473 L
.06673 .47303 L
.06666 .47298 L
.06667 .47289 L
.06671 .4728 L
.06675 .47271 L
.06679 .47264 L
.0668 .4726 L
.06681 .47259 L
.06681 .47259 L
Mistroke
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06682 .47259 L
.06684 .47259 L
.06687 .4726 L
.06688 .47263 L
.06685 .47268 L
.0668 .47274 L
.06674 .47279 L
.06667 .47279 L
.0666 .47273 L
.06654 .47259 L
.0665 .47237 L
.0665 .47203 L
.0665 .47154 L
.06652 .47114 L
.06653 .47066 L
.06655 .47018 L
.06655 .46974 L
.06658 .46927 L
.06664 .46881 L
.06672 .46839 L
.06681 .46804 L
.06689 .4678 L
.06695 .46765 L
.067 .46759 L
.06701 .46758 L
.06698 .46765 L
.06692 .46775 L
.06686 .46783 L
.06683 .46785 L
.06684 .46779 L
.0669 .46764 L
Mistroke
.06702 .46741 L
.0672 .46707 L
.06742 .46663 L
.06769 .46612 L
.06798 .46552 L
.06828 .46485 L
.06858 .46414 L
.06886 .46344 L
.06915 .46278 L
.06942 .46219 L
.06967 .46165 L
.06987 .46116 L
.07 .46077 L
.07008 .46047 L
.07011 .46028 L
.07009 .46018 L
.07006 .46016 L
.07001 .46018 L
.06998 .46024 L
.06996 .46033 L
.06996 .46039 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06992 .46042 L
.06988 .46042 L
.06984 .46042 L
.06982 .46042 L
.06983 .46042 L
.06989 .46042 L
.06999 .46042 L
.07015 .46042 L
.07036 .46042 L
.07061 .46041 L
.07087 .46041 L
.07115 .4604 L
.07142 .4604 L
.07168 .46039 L
.07195 .46039 L
.0722 .46039 L
.07243 .46038 L
.07262 .46038 L
.07274 .46038 L
.07281 .46038 L
.07283 .46038 L
.07282 .46038 L
.07278 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07269 .4605 L
.07269 .46032 L
.0727 .46004 L
.07272 .45967 L
.07273 .45923 L
.07275 .45876 L
.07276 .45826 L
.07278 .45778 L
.0728 .45732 L
.07281 .45685 L
.07283 .4564 L
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07286 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
.07286 .45553 L
Mistroke
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07287 .45552 L
Mistroke
.0729 .45547 L
.07295 .45539 L
.07299 .45532 L
.073 .45529 L
.07298 .45532 L
.07292 .45541 L
.0728 .4556 L
.07262 .45588 L
.07236 .45626 L
.07202 .4567 L
.07167 .45718 L
.07134 .45768 L
.07107 .45816 L
.07084 .45863 L
.07064 .4591 L
.07051 .45955 L
.07048 .45996 L
.07054 .46028 L
.07069 .4605 L
.07091 .46062 L
.07118 .46065 L
.07146 .46063 L
.07179 .46055 L
.07212 .46047 L
.0724 .46041 L
.0726 .46038 L
.07273 .46038 L
.0728 .46038 L
.07283 .46038 L
.07282 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07268 .4605 L
.07269 .46032 L
.0727 .46004 L
.07271 .45967 L
.07272 .45923 L
.07274 .45876 L
.07275 .45826 L
.07277 .45778 L
.07279 .45732 L
.0728 .45685 L
.07282 .4564 L
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07287 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
.07286 .45553 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07287 .45554 L
.07289 .45554 L
.07293 .45554 L
.07297 .45554 L
.07299 .45554 L
.07298 .45554 L
.07293 .45554 L
.07282 .45554 L
.07266 .45554 L
.07245 .45554 L
.07221 .45555 L
.07194 .45555 L
.07166 .45555 L
.07139 .45556 L
.07113 .45556 L
.07087 .45557 L
Mistroke
.07061 .45557 L
.07038 .45557 L
.07019 .45558 L
.07007 .45558 L
.07 .45558 L
.06998 .45558 L
.06999 .45558 L
.07003 .45558 L
.07008 .45558 L
.07011 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .45558 L
.07009 .45558 L
.07005 .45558 L
.07 .45558 L
.06998 .45558 L
.06998 .45558 L
.07002 .45558 L
.07009 .45558 L
.07021 .45558 L
.07037 .45558 L
.07057 .45557 L
.07083 .45557 L
.07114 .45556 L
.0715 .45556 L
.07189 .45555 L
.07231 .45555 L
.07276 .45554 L
.07323 .45553 L
.07369 .45553 L
.07412 .45552 L
.07448 .45551 L
.07479 .45551 L
.07505 .45551 L
.07527 .4555 L
.07545 .4555 L
.07559 .4555 L
.07568 .4555 L
.07572 .4555 L
.07574 .45549 L
.07572 .4555 L
.07568 .4555 L
.07563 .4555 L
.0756 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45549 L
.07558 .45549 L
.07558 .45549 L
.07557 .4555 L
.07557 .4555 L
.07556 .45551 L
Mistroke
.07556 .45551 L
.07555 .45549 L
.07555 .45545 L
.07555 .45541 L
.07555 .45539 L
.07555 .4554 L
.07554 .45543 L
.07554 .45546 L
.07554 .45553 L
.07554 .45562 L
.07554 .45577 L
.07554 .45599 L
.07554 .4563 L
.07553 .45674 L
.07553 .45715 L
.07552 .45756 L
.07551 .45798 L
.07549 .45842 L
.07548 .45887 L
.07547 .4592 L
.07546 .45957 L
.07545 .45986 L
.07545 .46009 L
.07544 .46025 L
.07543 .46037 L
.07543 .46045 L
.07542 .46049 L
.07542 .4605 L
.07542 .46046 L
.07542 .46041 L
.07542 .46037 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.00440917 0.97619 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.07542 .46034 m
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46033 L
.07542 .46031 L
.07544 .46024 L
.07553 .46014 L
.07557 .46009 L
.07555 .46012 L
.07549 .46021 L
.07535 .46039 L
.07506 .46069 L
.07456 .46113 L
.0739 .46165 L
.07336 .46219 L
.07288 .4627 L
Mistroke
.07243 .46317 L
.07196 .46361 L
.07144 .46405 L
.07093 .46451 L
.07041 .46497 L
.06999 .46535 L
.06977 .46556 L
.06968 .46564 L
.06965 .46562 L
.06967 .46554 L
.06975 .46541 L
.06979 .46526 L
.06977 .46519 L
.06972 .46519 L
.06969 .46522 L
.06969 .46524 L
.06973 .46526 L
.06982 .46527 L
.06998 .46526 L
.07019 .46526 L
.07045 .46526 L
.07072 .46525 L
.07099 .46525 L
.07125 .46524 L
.07149 .46524 L
.07174 .46523 L
.072 .46523 L
.07224 .46523 L
.07244 .46522 L
.07256 .46522 L
.07262 .46522 L
.07265 .46522 L
.07264 .46522 L
.0726 .46522 L
.07256 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07252 .46522 L
.0725 .46522 L
.07246 .46522 L
.07242 .46523 L
.07241 .46523 L
.07242 .46523 L
.07246 .46522 L
.07256 .46522 L
.07271 .46522 L
.07293 .46522 L
.07318 .46521 L
.07346 .46521 L
.07373 .4652 L
.07399 .4652 L
.07423 .46519 L
.07448 .46519 L
.07474 .46519 L
.07498 .46518 L
.07517 .46518 L
.07529 .46518 L
.07536 .46518 L
.07538 .46518 L
.07537 .46518 L
Mistroke
.07534 .46518 L
.07529 .46518 L
.07527 .46518 L
.07526 .46518 L
.07526 .4652 L
.07528 .46525 L
.07532 .46532 L
.07536 .46539 L
.07537 .46542 L
.07536 .4654 L
.07532 .4653 L
.07523 .46512 L
.07508 .46484 L
.07488 .46447 L
.07464 .46404 L
.07439 .46357 L
.07413 .46308 L
.07388 .4626 L
.07365 .46213 L
.07341 .46166 L
.07317 .46121 L
.07294 .46083 L
.07277 .46057 L
.07266 .46043 L
.07263 .46038 L
.07265 .46037 L
.07268 .46038 L
.07271 .46035 L
.07273 .46023 L
.07272 .46 L
.07264 .45965 L
.07251 .45921 L
.07231 .45871 L
.07207 .45816 L
.07178 .45761 L
.07155 .45709 L
.07134 .45661 L
.07111 .45618 L
.07087 .45582 L
.07066 .45555 L
.07041 .45544 L
.07021 .45549 L
.07008 .45568 L
.07002 .45596 L
.06999 .45631 L
.06999 .45677 L
.07002 .45719 L
.07005 .45759 L
.07005 .45799 L
.07004 .4584 L
Mistroke
.07004 .45876 L
.07003 .45913 L
.07002 .45953 L
.07001 .45981 L
.07 .46 L
.07 .46017 L
.06998 .46029 L
.06995 .46039 L
.06991 .46046 L
.06986 .4605 L
.06984 .46051 L
.06985 .4605 L
.06989 .46047 L
.06999 .46046 L
.07014 .46044 L
.07036 .46043 L
.07061 .46042 L
.07089 .46041 L
.07116 .4604 L
.07142 .4604 L
.07166 .46039 L
.07191 .46039 L
.07217 .46039 L
.07241 .46038 L
.0726 .46038 L
.07272 .46038 L
.07279 .46038 L
.07281 .46038 L
.0728 .46038 L
.07276 .46038 L
.07274 .46038 L
.07276 .46038 L
.07279 .46038 L
.0728 .46041 L
.07279 .46046 L
.07274 .46053 L
.07264 .46059 L
.07247 .46061 L
.07226 .46056 L
.07201 .46042 L
.07173 .46019 L
.07143 .45981 L
.07115 .45946 L
.07089 .45903 L
.07064 .45857 L
.0704 .4581 L
.07018 .45766 L
.07004 .45719 L
.07003 .45672 L
.07014 .45629 L
Mistroke
.07035 .45592 L
.07061 .45563 L
.0709 .45542 L
.07121 .45531 L
.07152 .4553 L
.07179 .45534 L
.07205 .45541 L
.07231 .45548 L
.07255 .45552 L
.07275 .45554 L
.07288 .45554 L
.07295 .45554 L
.07298 .45554 L
.07297 .45554 L
.07294 .45554 L
.0729 .45554 L
.07287 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07292 .45554 L
.07296 .45554 L
.07298 .45553 L
.07296 .45553 L
.07292 .45553 L
.07282 .45551 L
.07266 .45548 L
.07245 .45543 L
.07219 .45538 L
.07192 .45536 L
.07164 .45538 L
.07137 .45549 L
.07112 .4557 L
.07086 .45598 L
.07059 .45634 L
.07035 .45664 L
.07015 .45704 L
.07001 .45747 L
.06994 .45792 L
.06992 .45829 L
.06992 .45859 L
.06995 .45884 L
.06999 .45905 L
.07001 .45915 L
.07002 .45915 L
.07002 .45905 L
.07003 .45882 L
.07003 .45846 L
Mistroke
.07004 .45806 L
.07005 .45762 L
.07006 .45714 L
.07007 .45676 L
.07008 .45648 L
.07008 .45615 L
.0701 .45583 L
.07011 .45556 L
.07012 .45537 L
.07012 .4553 L
.07012 .45535 L
.07012 .45551 L
.07011 .45578 L
.0701 .45613 L
.07009 .45655 L
.07007 .45709 L
.07005 .45756 L
.07003 .45807 L
.07002 .45852 L
.07 .45898 L
.06999 .45944 L
.06998 .45985 L
.06997 .46019 L
.06996 .46042 L
.06995 .46056 L
.06995 .46063 L
.06995 .46063 L
.06995 .46059 L
.06995 .46053 L
.06995 .46048 L
.06996 .46044 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06998 .46042 L
.06998 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06998 .46042 L
.06998 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06995 .46042 L
Mistroke
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46043 L
.06995 .46044 L
.06995 .46045 L
.06995 .46046 L
.06996 .46046 L
.06996 .46045 L
.06996 .46044 L
.06997 .46042 L
.06997 .46038 L
.06998 .46033 L
.06999 .46026 L
.06999 .4602 L
.07 .46013 L
.07001 .46007 L
.07001 .46004 L
.07002 .46003 L
.07002 .46002 L
.07002 .46002 L
.07002 .46004 L
.07001 .46007 L
.07 .4601 L
Mistroke
.06999 .46016 L
.06998 .46022 L
.06998 .46029 L
.06997 .46036 L
.06997 .4604 L
.06997 .46043 L
.06997 .46044 L
.06997 .46045 L
.06997 .46046 L
.06997 .46046 L
.06997 .46045 L
.06997 .46042 L
.06997 .46044 L
.06997 .46043 L
.06997 .46037 L
.06997 .46026 L
.06998 .46012 L
.06998 .45997 L
.06999 .45984 L
.06999 .45972 L
.06999 .45962 L
.07 .4595 L
.07 .45938 L
.07001 .45925 L
.07002 .45917 L
.07002 .45915 L
.07002 .4592 L
.07001 .45931 L
.07001 .45943 L
.07 .45955 L
.07 .45962 L
.07 .45959 L
.07 .45947 L
.07001 .45926 L
.07002 .45893 L
.07003 .45851 L
.07004 .45803 L
.07006 .45758 L
.07007 .45713 L
.07008 .45669 L
.0701 .45625 L
.07011 .45586 L
.07012 .45556 L
.07013 .45539 L
.07013 .45539 L
.07012 .45553 L
.07011 .45575 L
.0701 .45601 L
.07009 .45623 L
.07009 .45638 L
Mistroke
.07008 .45648 L
.07008 .45656 L
.07007 .45664 L
.07007 .45672 L
.07006 .45678 L
.07006 .4568 L
.07006 .45677 L
.07007 .45668 L
.07007 .45653 L
.07008 .45633 L
.07009 .45611 L
.0701 .45594 L
.0701 .45586 L
.0701 .45583 L
.0701 .45586 L
.0701 .45591 L
.0701 .45596 L
.07009 .45602 L
.07009 .45611 L
.07009 .4562 L
.07009 .45627 L
.07008 .45634 L
.07008 .45643 L
.07008 .45654 L
.07007 .45667 L
.07007 .45682 L
.07006 .45699 L
.07006 .45723 L
.07005 .45752 L
.07004 .45782 L
.07004 .4581 L
.07003 .45835 L
.07002 .4586 L
.07002 .4589 L
.07001 .4592 L
.07 .45945 L
.07 .45962 L
.07 .45972 L
.07 .45978 L
.07 .45978 L
.07 .45972 L
.07 .45961 L
.07001 .45947 L
.07001 .45937 L
.07001 .45934 L
.07001 .45941 L
.07 .45952 L
.07 .45964 L
.06999 .45979 L
.06998 .45993 L
Mistroke
.06998 .46007 L
.06997 .46019 L
.06996 .46029 L
.06996 .46038 L
.06996 .46046 L
.06995 .46051 L
.06995 .46053 L
.06996 .46049 L
.06996 .46042 L
.06996 .46036 L
.06997 .46035 L
.06997 .46036 L
.06997 .46036 L
.06997 .46032 L
.06997 .46026 L
.06998 .46019 L
.06998 .46012 L
.06998 .46006 L
.06999 .46002 L
.06999 .45997 L
.06999 .45988 L
.06999 .45975 L
.07 .45959 L
.07 .45942 L
.07001 .45927 L
.07001 .45912 L
.07002 .459 L
.07002 .45892 L
.07002 .4589 L
.07002 .45892 L
.07002 .45899 L
.07002 .45908 L
.07001 .45917 L
.07001 .45928 L
.07 .4594 L
.07 .45954 L
.06999 .45973 L
.06998 .4599 L
.06998 .46011 L
.06997 .46028 L
.06996 .46039 L
.06996 .46045 L
.06996 .46045 L
.06996 .46043 L
.06996 .4604 L
.06996 .46038 L
.06996 .46036 L
.06997 .46034 L
.06997 .46031 L
.06997 .46028 L
Mistroke
.06997 .46027 L
.06997 .4603 L
.06997 .46033 L
.06997 .46035 L
.06997 .46033 L
.06997 .4603 L
.06997 .46026 L
.06997 .4602 L
.06998 .46013 L
.06998 .46007 L
.06998 .46002 L
.06999 .45998 L
.06999 .45995 L
.06999 .45993 L
.06999 .45992 L
.06999 .45991 L
.06999 .45994 L
.06999 .45998 L
.06998 .46005 L
.06998 .46014 L
.06997 .46024 L
.06996 .46034 L
.06996 .46042 L
.06995 .46048 L
.06995 .46051 L
.06995 .46051 L
.06995 .46047 L
.06996 .46044 L
.06996 .46043 L
.06996 .46044 L
.06996 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46041 L
.06996 .46039 L
.06996 .46035 L
.06997 .46032 L
.06997 .4603 L
.06997 .46028 L
.06997 .46027 L
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46026 L
.06997 .46025 L
.06997 .46025 L
.06997 .46025 L
.06997 .46026 L
.06997 .46026 L
Mistroke
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46027 L
.06997 .46027 L
.06997 .46029 L
.06997 .46032 L
.06996 .46035 L
.06996 .46038 L
.06996 .46041 L
.06996 .46044 L
.06995 .46047 L
.06995 .46048 L
.06995 .46047 L
.06996 .46045 L
.06996 .46042 L
.06996 .46038 L
.06996 .46035 L
.06997 .46032 L
.06997 .46029 L
.06997 .46027 L
.06997 .46025 L
.06997 .46024 L
.06997 .46024 L
.06997 .46024 L
.06997 .46025 L
.06997 .46026 L
.06997 .46028 L
.06997 .46031 L
.06996 .46034 L
.06996 .46038 L
.06996 .46041 L
.06996 .46043 L
.06996 .46045 L
.06995 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46044 L
.06995 .46047 L
.06995 .4605 L
.06995 .46051 L
.06995 .46048 L
.06996 .46043 L
.06996 .46035 L
.06997 .46026 L
.06997 .46016 L
.06998 .46007 L
.06998 .46 L
.06999 .45995 L
Mistroke
.06999 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45989 L
.06997 .45995 L
.06997 .46004 L
.06997 .46012 L
.06997 .46019 L
.06996 .46024 L
.06996 .46027 L
.06996 .46026 L
.06996 .46022 L
.06997 .46015 L
.06997 .46007 L
.06997 .45998 L
.06998 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45988 L
.06998 .4599 L
.06997 .45995 L
.06997 .46003 L
.06997 .46012 L
.06996 .46023 L
.06996 .46033 L
.06996 .46042 L
.06996 .46048 L
.06995 .46052 L
.06995 .46054 L
.06995 .46056 L
.06995 .4606 L
.06995 .46066 L
.06995 .46069 L
.06995 .46067 L
.06995 .46056 L
.06996 .46037 L
.06997 .46008 L
.06998 .45971 L
.07 .45928 L
.07001 .4588 L
.07003 .45826 L
.07005 .45771 L
.07007 .45714 L
.07009 .45658 L
.0701 .4561 L
.07012 .45572 L
.07012 .45551 L
.07013 .45549 L
.07012 .45566 L
.07011 .45597 L
Mistroke
.07009 .4564 L
.07008 .45691 L
.07006 .45746 L
.07004 .458 L
.07002 .45853 L
.07 .45904 L
.06999 .45951 L
.06997 .45991 L
.06996 .46025 L
.06996 .46044 L
.06995 .46052 L
.06996 .46048 L
.06996 .46031 L
.06997 .46005 L
.06998 .45974 L
.06999 .45942 L
.07 .45914 L
.07001 .45889 L
.07002 .45871 L
.07002 .45857 L
.07002 .45849 L
.07002 .45848 L
.07002 .45855 L
.07002 .45868 L
.07001 .45895 L
.07 .45923 L
.06999 .45955 L
.06998 .45983 L
.06997 .46003 L
.06997 .46015 L
.06997 .46018 L
.06997 .46011 L
.06997 .46001 L
.06998 .45991 L
.06998 .45984 L
.06998 .4598 L
.06998 .45979 L
.06998 .45978 L
.06998 .45974 L
.06998 .45964 L
.06999 .4595 L
.07 .45932 L
.07 .45907 L
.07001 .45875 L
.07003 .45838 L
.07004 .45804 L
.07005 .45774 L
.07006 .45742 L
.07007 .45708 L
.07008 .45674 L
Mistroke
.07009 .45646 L
.0701 .4563 L
.0701 .45624 L
.0701 .45629 L
.07009 .45642 L
.07009 .45658 L
.07008 .45678 L
.07007 .45699 L
.07007 .45719 L
.07006 .45734 L
.07006 .45745 L
.07005 .45759 L
.07005 .45773 L
.07004 .4579 L
.07004 .45809 L
.07003 .45832 L
.07002 .45859 L
.07001 .45888 L
.07 .4592 L
.06999 .45948 L
.06998 .45969 L
.06998 .45985 L
.06997 .45991 L
.06997 .45993 L
.06998 .45991 L
.06998 .45983 L
.06998 .45972 L
.06999 .45956 L
.06999 .45935 L
.07 .45909 L
.07001 .45881 L
.07002 .4585 L
.07004 .45814 L
.07005 .45773 L
.07006 .45728 L
.07008 .45687 L
.07009 .45656 L
.0701 .45629 L
.0701 .45612 L
.07011 .45608 L
.0701 .45614 L
.0701 .45626 L
.07009 .45641 L
.07009 .45657 L
.07008 .45671 L
.07008 .45685 L
.07008 .45697 L
.07007 .45707 L
.07007 .45707 L
.07007 .45698 L
Mistroke
.07008 .45685 L
.07009 .45665 L
.07009 .45643 L
.0701 .4562 L
.07011 .45598 L
.07012 .45579 L
.07012 .45568 L
.07012 .4557 L
.07011 .45587 L
.0701 .45618 L
.07009 .45656 L
.07007 .45699 L
.07006 .45736 L
.07005 .45766 L
.07004 .45787 L
.07004 .45798 L
.07004 .45797 L
.07004 .4579 L
.07005 .45777 L
.07005 .45758 L
.07006 .45735 L
.07007 .45707 L
.07008 .45677 L
.07009 .4565 L
.0701 .45624 L
.07011 .45602 L
.07011 .45581 L
.07012 .45564 L
.07012 .45554 L
.07012 .45554 L
.07012 .45565 L
.07011 .45581 L
.07011 .45598 L
.0701 .45615 L
.0701 .45631 L
.07009 .45647 L
.07009 .45663 L
.07008 .45678 L
.07008 .45691 L
.07007 .45703 L
.07007 .45712 L
.07007 .45717 L
.07007 .45721 L
.07007 .4572 L
.07007 .45715 L
.07007 .45706 L
.07008 .45696 L
.07008 .4568 L
.07009 .45661 L
.07009 .45648 L
Mistroke
.0701 .45637 L
.0701 .45633 L
.0701 .45632 L
.0701 .45636 L
.0701 .45634 L
.0701 .45629 L
.0701 .45622 L
.0701 .45618 L
.0701 .45614 L
.0701 .4561 L
.07011 .45602 L
.07011 .45594 L
.07011 .45588 L
.07011 .45586 L
.07011 .45591 L
.07011 .45601 L
.0701 .45616 L
.0701 .45634 L
.07009 .45652 L
.07008 .45672 L
.07008 .4569 L
.07007 .45703 L
.07007 .45712 L
.07007 .45717 L
.07007 .45716 L
.07007 .45711 L
.07007 .457 L
.07008 .45683 L
.07009 .45657 L
.0701 .45634 L
.07011 .45607 L
.07011 .45583 L
.07012 .45567 L
.07012 .45561 L
.07012 .45566 L
.07011 .45581 L
.07011 .45601 L
.0701 .45621 L
.07009 .4564 L
.07009 .45656 L
.07008 .4567 L
.07008 .45682 L
.07008 .45689 L
.07008 .4569 L
.07008 .45689 L
.07008 .45681 L
.07008 .45668 L
.07009 .45648 L
.0701 .4563 L
.07011 .45608 L
Mistroke
.07011 .45588 L
.07012 .45572 L
.07012 .45562 L
.07012 .45557 L
.07012 .45555 L
.07012 .45554 L
.07012 .45552 L
.07012 .4555 L
.07013 .4555 L
.07012 .45551 L
.07012 .45555 L
.07012 .45558 L
.07012 .45561 L
.07012 .45563 L
.07012 .45566 L
.07012 .45569 L
.07012 .45574 L
.07012 .45579 L
.07011 .45582 L
.07011 .45583 L
.07011 .45581 L
.07011 .45581 L
.07011 .45585 L
.07011 .45594 L
.07011 .45607 L
.0701 .45622 L
.0701 .45638 L
.07009 .45652 L
.07009 .45664 L
.07008 .45672 L
.07008 .45677 L
.07008 .45677 L
.07008 .45675 L
.07008 .45669 L
.07009 .45663 L
.07009 .45653 L
.07009 .4564 L
.0701 .45624 L
.07011 .45605 L
.07011 .45585 L
.07012 .45567 L
.07012 .45552 L
.07013 .45543 L
.07013 .4554 L
.07013 .45544 L
.07013 .45549 L
.07012 .45552 L
.07013 .4555 L
.07013 .45546 L
.07013 .45544 L
Mistroke
.07013 .45547 L
.07012 .45556 L
.07012 .4557 L
.07011 .45587 L
.07011 .45604 L
.0701 .45621 L
.0701 .45636 L
.07009 .45648 L
.07009 .45658 L
.07009 .45665 L
.07008 .4567 L
.07008 .45673 L
.07008 .45672 L
.07009 .45663 L
.07009 .4565 L
.0701 .45635 L
.0701 .4562 L
.07011 .45605 L
.07011 .45596 L
.07011 .4559 L
.07011 .45589 L
.07011 .45592 L
.07011 .45594 L
.07011 .45592 L
.07011 .45587 L
.07011 .45585 L
.07011 .45591 L
.07011 .45606 L
.0701 .45626 L
.07009 .45649 L
.07008 .45672 L
.07008 .45693 L
.07007 .45707 L
.07007 .45715 L
.07007 .45717 L
.07007 .45716 L
.07007 .45715 L
.07007 .45713 L
.07007 .45711 L
.07008 .45697 L
.07008 .45675 L
.07009 .45647 L
.0701 .45615 L
.07011 .45584 L
.07012 .45558 L
.07013 .45539 L
.07013 .45531 L
.07013 .45531 L
.07013 .45537 L
.07013 .45544 L
Mistroke
.07012 .45552 L
.07012 .45559 L
.07012 .45568 L
.07012 .45578 L
.07011 .45593 L
.0701 .45616 L
.07009 .45646 L
.07008 .45675 L
.07006 .45707 L
.07005 .45736 L
.07005 .45758 L
.07004 .45774 L
.07004 .45783 L
.07004 .45782 L
.07004 .45773 L
.07005 .45759 L
.07006 .4574 L
.07006 .45719 L
.07007 .45691 L
.07008 .4566 L
.0701 .45628 L
.07011 .45596 L
.07012 .45568 L
.07013 .45545 L
.07013 .4553 L
.07014 .45521 L
.07014 .45523 L
.07013 .45536 L
.07012 .45559 L
.07011 .45588 L
.0701 .4562 L
.07009 .45654 L
.07007 .45687 L
.07006 .45716 L
.07005 .45741 L
.07005 .45757 L
.07004 .45767 L
.07004 .4577 L
.07004 .45766 L
.07005 .45757 L
.07006 .45737 L
.07007 .45714 L
.07008 .45683 L
.07009 .45648 L
.0701 .45614 L
.07011 .45584 L
.07012 .4556 L
.07013 .45545 L
.07013 .45538 L
.07013 .45537 L
Mistroke
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45559 L
.07012 .45561 L
.07012 .45563 L
.07011 .45569 L
.07011 .45575 L
.0701 .45583 L
.0701 .45594 L
.07009 .45603 L
.07009 .4561 L
.07008 .45617 L
.07008 .45624 L
.07007 .45634 L
.07007 .45647 L
.07007 .45663 L
.07006 .45684 L
.07006 .45712 L
.07005 .45745 L
.07003 .45779 L
.07003 .45812 L
.07003 .45839 L
.07003 .45856 L
.07003 .45866 L
.07004 .45869 L
.07004 .45869 L
.07004 .45861 L
.07004 .45846 L
.07004 .45821 L
.07004 .45789 L
.07006 .45751 L
.07007 .45711 L
.07008 .45671 L
.0701 .4563 L
.07011 .45602 L
.07011 .45579 L
.07012 .45564 L
.07012 .45555 L
.07012 .45551 L
.07012 .45552 L
.07012 .45554 L
.07012 .45556 L
.07012 .45555 L
.07012 .45554 L
.07013 .45554 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07013 .45553 L
.07013 .45549 L
.07013 .45548 L
.07013 .4555 L
.07012 .45557 L
.07012 .45565 L
.07011 .45574 L
.07011 .45582 L
.07011 .45589 L
.0701 .45597 L
.0701 .45607 L
.07009 .45618 L
.07008 .4563 L
.07008 .45642 L
.07007 .45651 L
.07007 .45658 L
.07007 .4566 L
.07007 .45655 L
.07007 .45645 L
.07008 .45629 L
.07009 .45615 L
.07009 .45604 L
.0701 .45594 L
.0701 .45589 L
.0701 .4559 L
.0701 .456 L
.07009 .45617 L
.07009 .45639 L
.07008 .45663 L
.07007 .45688 L
.07006 .45712 L
.07006 .45732 L
.07005 .4575 L
.07004 .4576 L
.07004 .4576 L
.07005 .45752 L
.07005 .45738 L
.07006 .4572 L
Mistroke
.07007 .45693 L
.07008 .45663 L
.07009 .45631 L
.07011 .45601 L
.07011 .45576 L
.07012 .45558 L
.07013 .45546 L
.07013 .45539 L
.07013 .45538 L
.07013 .45543 L
.07013 .4555 L
.07012 .45555 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07012 .45555 L
.07012 .45553 L
.07013 .45553 L
.07012 .45552 L
.07012 .45551 L
.07012 .4555 L
.07012 .45551 L
.07012 .45554 L
.07012 .45561 L
.07011 .45574 L
.0701 .45594 L
.07009 .45622 L
.07008 .45654 L
.07007 .45683 L
.07006 .45716 L
.07005 .45751 L
.07004 .45784 L
.07003 .45814 L
.07003 .4584 L
.07002 .45859 L
.07002 .45877 L
.07002 .45892 L
.07002 .45904 L
.07002 .45911 L
.07002 .45916 L
.07001 .45922 L
.07001 .45929 L
.07001 .45937 L
.07001 .45943 L
.07 .45945 L
.07 .45944 L
.07001 .45933 L
.07001 .45915 L
.07002 .45896 L
Mistroke
.07002 .45875 L
.07003 .45851 L
.07003 .45827 L
.07004 .45804 L
.07004 .45781 L
.07005 .45756 L
.07006 .45731 L
.07006 .45708 L
.07007 .45688 L
.07007 .4567 L
.07007 .45653 L
.07008 .45642 L
.07008 .45634 L
.07008 .4563 L
.07008 .45633 L
.07008 .45639 L
.07008 .45626 L
.07008 .45648 L
.07007 .45677 L
.07006 .45715 L
.07005 .45762 L
.07004 .45817 L
.07002 .45875 L
.07001 .45929 L
.07 .45974 L
.06999 .46007 L
.06998 .4603 L
.06998 .46036 L
.06998 .46027 L
.06999 .45999 L
.07 .45959 L
.07002 .45913 L
.07003 .45864 L
.07004 .45819 L
.07005 .45776 L
.07005 .45737 L
.07006 .457 L
.07006 .45663 L
.07007 .45636 L
.07008 .45613 L
.07008 .45596 L
.07009 .45584 L
.07009 .45578 L
.07009 .45578 L
.07009 .4558 L
.07009 .4558 L
.07009 .45579 L
.07009 .45578 L
.07009 .45577 L
.07009 .45576 L
Mistroke
.07009 .45576 L
.07009 .45576 L
.07009 .45575 L
.07009 .45576 L
.07009 .45578 L
.07009 .45579 L
.07009 .45578 L
.0701 .45575 L
.0701 .45571 L
.07011 .45566 L
.07012 .45562 L
.07012 .45558 L
.07013 .45555 L
.07013 .45554 L
.07013 .45554 L
.07013 .45556 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45557 L
.07013 .45555 L
.07013 .45554 L
.07013 .45553 L
.07013 .45555 L
.07012 .45558 L
.07012 .45562 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45562 L
.07012 .45557 L
.07013 .45552 L
.07013 .45549 L
.07013 .45549 L
.07013 .45552 L
.07012 .45557 L
.07012 .45561 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45563 L
.07012 .45558 L
.07013 .45555 L
.07013 .45553 L
.07013 .45553 L
Mistroke
.07013 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .4556 L
.07009 .45563 L
.07005 .45567 L
.07001 .4557 L
.06999 .45572 L
.07 .45571 L
.07006 .45565 L
.07016 .45556 L
.07032 .45541 L
.07054 .45522 L
.07079 .45501 L
.07107 .45476 L
.07136 .45451 L
.07163 .45425 L
.07189 .454 L
.07215 .45375 L
.07242 .45352 L
.07266 .45333 L
.07285 .45317 L
.07298 .45306 L
.07305 .45299 L
.07307 .45297 L
.07306 .45299 L
.07303 .45303 L
.07298 .45307 L
.07295 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07293 .4531 L
.0729 .45308 L
.07286 .45304 L
.07283 .453 L
.07281 .45298 L
.07282 .453 L
.07287 .45305 L
.07297 .45314 L
.07312 .45328 L
.07333 .45346 L
.07357 .45368 L
.07383 .45391 L
.0741 .45416 L
.07436 .4544 L
.0746 .45465 L
.07485 .45489 L
.0751 .45511 L
.07533 .4553 L
.07551 .45545 L
.07563 .45556 L
.0757 .45562 L
.07572 .45564 L
.07571 .45562 L
.07567 .45559 L
.07563 .45555 L
.0756 .45552 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45547 L
.07562 .45541 L
.07567 .45534 L
.07571 .45527 L
.07571 .45523 L
.07569 .45526 L
.07563 .45536 L
.0755 .45555 L
.0753 .45584 L
.07504 .45621 L
.07476 .45665 L
.07447 .45713 L
.07419 .45763 L
.07391 .45812 L
.07367 .45861 L
.07339 .45909 L
.07312 .45955 L
.07288 .45995 L
.07271 .46027 L
.07262 .46049 L
.07257 .46061 L
.07256 .46065 L
.07258 .46062 L
.07263 .46055 L
.07267 .46047 L
.07269 .46041 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46044 L
.07269 .4605 L
.07268 .46057 L
.07269 .46058 L
.07272 .46052 L
.07276 .46037 L
Mistroke
.07281 .46017 L
.07283 .45993 L
.07283 .45967 L
.07279 .45943 L
.07269 .45925 L
.07254 .45912 L
.07233 .45904 L
.07208 .45902 L
.0718 .45902 L
.07153 .45905 L
.07127 .45908 L
.07102 .4592 L
.07076 .45939 L
.07049 .45966 L
.07024 .45998 L
.07005 .46031 L
.06991 .4606 L
.06984 .4608 L
.06981 .46086 L
.06983 .46076 L
.06987 .46051 L
.06993 .46017 L
.06997 .45976 L
.06999 .4593 L
.07001 .45882 L
.07003 .45832 L
.07005 .45782 L
.07006 .45733 L
.07008 .45686 L
.0701 .45641 L
.07011 .45601 L
.07012 .45569 L
.07013 .45547 L
.07013 .45535 L
.07013 .45531 L
.07013 .45533 L
.07013 .45539 L
.07013 .45546 L
.07013 .4555 L
.07012 .45549 L
.07012 .45545 L
.07012 .45542 L
.07012 .45544 L
.07012 .45551 L
.07011 .45567 L
.0701 .4559 L
.07009 .45624 L
.07008 .45668 L
.07006 .45711 L
.07005 .4576 L
Mistroke
.07003 .4581 L
.07002 .45855 L
.07001 .45901 L
.07 .45946 L
.06999 .45987 L
.06998 .4602 L
.06998 .46041 L
.06998 .46048 L
.06998 .46036 L
.06999 .46012 L
.07 .45971 L
.07001 .45917 L
.07003 .45866 L
.07004 .45816 L
.07005 .45774 L
.07006 .45745 L
.07006 .45723 L
.07006 .45709 L
.07006 .45702 L
.07006 .45699 L
.07006 .45701 L
.07006 .45706 L
.07005 .4571 L
.07005 .45716 L
.07005 .4572 L
.07005 .45724 L
.07005 .45727 L
.07006 .45714 L
.07007 .45697 L
.07008 .45668 L
.07009 .45636 L
.0701 .45605 L
.07011 .45579 L
.07012 .45559 L
.07013 .45547 L
.07013 .45543 L
.07013 .45542 L
.07013 .45545 L
.07013 .4555 L
.07012 .45554 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .4556 L
.07013 .45562 L
.07017 .45566 L
.07026 .4557 L
.07029 .45571 L
.07027 .4557 L
.0702 .45565 L
.07005 .45556 L
Mistroke
.06976 .45542 L
.0693 .45524 L
.06872 .45503 L
.06817 .4548 L
.0677 .45456 L
.06725 .45432 L
.06679 .45407 L
.06631 .45384 L
.06582 .45362 L
.06532 .45342 L
.06492 .45325 L
.0647 .45308 L
.06461 .45292 L
.06458 .4528 L
.0646 .45277 L
.06467 .45284 L
.06473 .45302 L
.06474 .45332 L
.06472 .45375 L
.0647 .45431 L
.06468 .45497 L
.06465 .45568 L
.06463 .45642 L
.0646 .45713 L
.06457 .45782 L
.06455 .45851 L
.06453 .45919 L
.06451 .45981 L
.06449 .4603 L
.06448 .46063 L
.06447 .46081 L
.06447 .46087 L
.06447 .46084 L
.06445 .46075 L
.06442 .46063 L
.06438 .46055 L
.06436 .46052 L
.06437 .46051 L
.06441 .46051 L
.06449 .46051 L
.06463 .46051 L
.06482 .4605 L
.06506 .4605 L
.06533 .46049 L
.0656 .46049 L
.06584 .46049 L
.06605 .46048 L
.06629 .46048 L
.06656 .46048 L
.06684 .46049 L
Mistroke
.06711 .46051 L
.06738 .46054 L
.06766 .46059 L
.06796 .46064 L
.06823 .46066 L
.06848 .46061 L
.06871 .46049 L
.06893 .46028 L
.06918 .45999 L
.06944 .45964 L
.06967 .45925 L
.06988 .45891 L
.07004 .45862 L
.07014 .45844 L
.07019 .45828 L
.07019 .45815 L
.07016 .45801 L
.0701 .45787 L
.07007 .45772 L
.07005 .45759 L
.07004 .45749 L
.07005 .45735 L
.07007 .45728 L
.07009 .4572 L
.07009 .45712 L
.07008 .45692 L
.07008 .45663 L
.07009 .4563 L
.0701 .45597 L
.07012 .4557 L
.07012 .45551 L
.07013 .45541 L
.07013 .45538 L
.07013 .4554 L
.07013 .45545 L
.07013 .45551 L
.07012 .45556 L
.07011 .45558 L
.07007 .4556 L
.07003 .45563 L
.06999 .45567 L
.06997 .4557 L
.06998 .45572 L
.07004 .45571 L
.07015 .45565 L
.07032 .45555 L
.07053 .45541 L
.07078 .45522 L
.07106 .455 L
.07135 .45476 L
Mistroke
.07163 .45451 L
.07192 .45425 L
.07219 .454 L
.07246 .45375 L
.07269 .45352 L
.07287 .45332 L
.073 .45317 L
.07307 .45306 L
.0731 .45299 L
.07308 .45297 L
.07304 .45299 L
.07299 .45303 L
.07296 .45307 L
.07294 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07296 .45309 L
.07299 .45301 L
.07304 .4529 L
.07308 .4528 L
.0731 .45276 L
.07308 .4528 L
.07302 .45296 L
.0729 .45325 L
.07273 .45369 L
.0725 .45426 L
.07224 .45493 L
.07194 .4557 L
.07163 .45652 L
.07133 .45732 L
.07103 .45807 L
.07073 .45879 L
.07046 .45945 L
.07022 .45998 L
.07003 .46029 L
.0699 .46033 L
.06984 .46012 L
.06983 .45974 L
.06986 .45923 L
.06992 .45864 L
.06999 .45802 L
Mistroke
.07004 .45743 L
.07008 .4569 L
.0701 .45643 L
.07011 .45602 L
.07012 .45568 L
.07013 .4554 L
.07014 .4552 L
.07014 .45509 L
.07014 .45508 L
.07014 .45517 L
.07013 .45535 L
.07012 .45561 L
.07011 .45592 L
.0701 .45629 L
.07008 .45674 L
.07006 .45725 L
.07005 .45775 L
.07003 .45822 L
.07002 .45869 L
.07 .45916 L
.06999 .4596 L
.06999 .45997 L
.06998 .46024 L
.06998 .46042 L
.06998 .46052 L
.06998 .46056 L
.06998 .46052 L
.06999 .46045 L
.06999 .46036 L
.06999 .46029 L
.06999 .46027 L
.06998 .46029 L
.06998 .46032 L
.06997 .46036 L
.06996 .46039 L
.06996 .46042 L
.06995 .46044 L
.06995 .46046 L
.06995 .46045 L
.06995 .46044 L
.06996 .46043 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46044 L
Mistroke
.06995 .46048 L
.06995 .46054 L
.06995 .46061 L
.06995 .46064 L
.06995 .46059 L
.06996 .46047 L
.06997 .46027 L
.06998 .46004 L
.06999 .4598 L
.07 .45957 L
.07 .45935 L
.07001 .45915 L
.07002 .45891 L
.07003 .45871 L
.07003 .45854 L
.07004 .45842 L
.07004 .45837 L
.07004 .45837 L
.07004 .4584 L
.07004 .45845 L
.07003 .45854 L
.07002 .45865 L
.07 .45876 L
.06997 .45885 L
.06995 .45885 L
.06996 .45876 L
.07 .45859 L
.07006 .45839 L
.07014 .45819 L
.07023 .45799 L
.07032 .45776 L
.0704 .45751 L
.07046 .45721 L
.0705 .45693 L
.07052 .45664 L
.07054 .45639 L
.07054 .45619 L
.07054 .45597 L
.07052 .45581 L
.07048 .45562 L
.07041 .45545 L
.07032 .45534 L
.07024 .45534 L
.07015 .45545 L
.07008 .45564 L
.07003 .45592 L
.07001 .45621 L
.07002 .45657 L
.07004 .45698 L
.07004 .45743 L
Mistroke
.07004 .4579 L
.07002 .4584 L
.07001 .45895 L
.06999 .45941 L
.06998 .45988 L
.06997 .46026 L
.06996 .4605 L
.06996 .46059 L
.06997 .4605 L
.06997 .46028 L
.06998 .45998 L
.06999 .45967 L
.07 .45937 L
.07001 .45913 L
.07002 .45889 L
.07002 .45868 L
.07003 .45845 L
.07004 .45823 L
.07005 .45805 L
.07005 .45794 L
.07005 .45793 L
.07005 .45803 L
.07004 .4582 L
.07003 .45845 L
.07003 .45877 L
.07002 .45906 L
.07001 .45931 L
.07001 .45944 L
.07 .45958 L
.06999 .45974 L
.06999 .45993 L
.06998 .46013 L
.06997 .46032 L
.06996 .46045 L
.06995 .46054 L
.06995 .46057 L
.06995 .46057 L
.06995 .46053 L
.06995 .46047 L
.06996 .46044 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06997 .46042 L
.07001 .46042 L
.07005 .46042 L
.07009 .46042 L
.07011 .46042 L
.07009 .46042 L
.07003 .46043 L
.06992 .46044 L
.06976 .46044 L
.06956 .46044 L
Mistroke
.06932 .46046 L
.06905 .46051 L
.06877 .46057 L
.06849 .46062 L
.06821 .46064 L
.06795 .46059 L
.0677 .46045 L
.06748 .46022 L
.06731 .45987 L
.0672 .45953 L
.06714 .4591 L
.06714 .45863 L
.06717 .45816 L
.06722 .45771 L
.06728 .45723 L
.06733 .45677 L
.06736 .45635 L
.06737 .45599 L
.06738 .4557 L
.06739 .45549 L
.06739 .45537 L
.0674 .45535 L
.0674 .45539 L
.06739 .45546 L
.06739 .45554 L
.06739 .45559 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45564 L
.06739 .45567 L
.06738 .45571 L
.06738 .45574 L
.06738 .45576 L
.06738 .45575 L
.06738 .45569 L
.06739 .4556 L
.06739 .45545 L
Mistroke
.0674 .45527 L
.06741 .45506 L
.06741 .45482 L
.06742 .45457 L
.06743 .45432 L
.06744 .45407 L
.06745 .45382 L
.06746 .4536 L
.06746 .4534 L
.06747 .45325 L
.06747 .45314 L
.06747 .45308 L
.06746 .45306 L
.06743 .45307 L
.06738 .45311 L
.06734 .45315 L
.06732 .45318 L
.06733 .4532 L
.06739 .4532 L
.06749 .4532 L
.06765 .4532 L
.06785 .4532 L
.06809 .45319 L
.06834 .45319 L
.06858 .45318 L
.06881 .45318 L
.06905 .45318 L
.0693 .45317 L
.06955 .45317 L
.0698 .45317 L
.07006 .45316 L
.07033 .45316 L
.07062 .45315 L
.07094 .45315 L
.07129 .45314 L
.07167 .45314 L
.07205 .45313 L
.07247 .45313 L
.07294 .45312 L
.07343 .45311 L
.07394 .45311 L
.07441 .4531 L
.0749 .45309 L
.0754 .45308 L
.07591 .45308 L
.07642 .45307 L
.07694 .45306 L
.07747 .45305 L
.07795 .45303 L
.07843 .45299 L
Mistroke
.07889 .45295 L
.07935 .45291 L
.07978 .45288 L
.0802 .45289 L
.08062 .45293 L
.08101 .45302 L
.08137 .45316 L
.08169 .45334 L
.08198 .45355 L
.08224 .45378 L
.08249 .45403 L
.08271 .45428 L
.08293 .45453 L
.08315 .45476 L
.08337 .45498 L
.08357 .45518 L
.08373 .45533 L
.08384 .45544 L
.08391 .4555 L
.08392 .45551 L
.08391 .4555 L
.08387 .45546 L
.08382 .45542 L
.08379 .45539 L
.08378 .45538 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08377 .45537 L
.08376 .45537 L
.08373 .45537 L
.08369 .45538 L
.08365 .45537 L
.08363 .45535 L
.08363 .45529 L
.08367 .45522 L
.08374 .45514 L
.08386 .4551 L
.08402 .45511 L
.08423 .45518 L
.0845 .4553 L
.0848 .4555 L
.08516 .45579 L
.08554 .45619 L
.08598 .45668 L
.08647 .45729 L
Mistroke
.087 .45798 L
.08755 .45875 L
.08809 .45959 L
.08862 .46045 L
.08913 .4613 L
.0896 .46211 L
.09004 .46283 L
.09043 .46345 L
.09078 .46397 L
.09109 .46439 L
.09135 .4647 L
.09154 .46493 L
.09167 .46508 L
.09174 .46517 L
.09178 .46519 L
.09178 .46516 L
.09176 .46509 L
.09172 .46501 L
.09168 .46494 L
.09164 .46491 L
.09163 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.0916 .46489 L
.09157 .46486 L
Mistroke
.09153 .46482 L
.09147 .46479 L
.09142 .46477 L
.09139 .46479 L
.09141 .46484 L
.09147 .46494 L
.09158 .46508 L
.09174 .46526 L
.09196 .46547 L
.09226 .46572 L
.09265 .46599 L
.09313 .46627 L
.0937 .46655 L
.09439 .4668 L
.09521 .467 L
.09611 .46713 L
.09716 .46717 L
.09841 .46713 L
.0998 .46701 L
.10145 .46684 L
.10341 .46663 L
.10548 .46638 L
.10816 .46608 L
.11073 .46574 L
.1142 .46535 L
.11727 .46494 L
.12073 .4645 L
.1251 .46402 L
.12833 .46353 L
.13221 .46303 L
.13615 .46252 L
.14013 .46195 L
.14321 .4613 L
.14651 .46052 L
.14994 .45957 L
.15249 .45845 L
.1551 .45716 L
.15743 .45573 L
.15957 .45413 L
.16164 .45226 L
.16362 .4502 L
.16521 .4479 L
.16697 .44522 L
.16867 .44246 L
.17047 .43935 L
.17237 .43607 L
.1742 .4326 L
.17612 .42921 L
.17783 .42564 L
.1794 .42195 L
Mistroke
.18081 .41841 L
.18192 .41448 L
.18285 .41076 L
.18349 .40691 L
.18391 .40286 L
.18412 .39929 L
.18415 .3957 L
.18403 .39223 L
.18384 .38917 L
.18358 .38615 L
.1833 .38329 L
.1831 .38089 L
.18299 .37857 L
.18297 .37657 L
.18311 .37479 L
.18344 .37327 L
.18393 .37207 L
.18452 .37098 L
.18517 .36999 L
.18585 .36904 L
.18653 .36809 L
.18719 .36708 L
.18782 .36595 L
.18842 .36473 L
.18902 .36336 L
.18963 .36181 L
.19026 .36008 L
.19087 .35801 L
.19148 .35562 L
.19207 .35283 L
.19265 .34951 L
.19316 .34602 L
.19364 .34222 L
.19404 .33798 L
.19433 .33392 L
.1945 .3297 L
.19458 .32479 L
.19462 .32083 L
.19462 .31634 L
.19466 .31184 L
.19481 .30729 L
.19513 .30283 L
.19566 .29792 L
.19644 .29325 L
.19749 .28777 L
.1988 .28252 L
.20012 .27687 L
.20171 .27062 L
.20339 .2642 L
.20533 .25781 L
Mistroke
.20738 .25006 L
.20949 .24279 L
.21145 .23677 L
.21347 .22969 L
.21542 .22267 L
.2172 .21518 L
.21882 .2089 L
.22029 .2024 L
.22155 .19601 L
.22266 .19006 L
.22356 .18415 L
.22425 .17884 L
.22475 .17353 L
.22501 .16895 L
.22506 .1644 L
.2249 .16066 L
.22457 .15735 L
.22408 .15454 L
.22347 .15229 L
.22283 .15059 L
.22217 .14933 L
.2215 .14846 L
.22093 .14794 L
.22042 .14768 L
.22001 .14758 L
.21972 .14758 L
.21956 .14766 L
.21947 .14781 L
.21944 .14801 L
.21944 .14825 L
.21943 .1485 L
.21938 .14871 L
.21926 .14887 L
.21906 .14898 L
.21881 .14908 L
.21853 .14917 L
.21827 .14925 L
.21805 .14931 L
.21788 .14935 L
.21776 .14939 L
.2177 .14937 L
.2177 .14927 L
.21774 .1491 L
.21782 .14883 L
.21795 .14847 L
.21816 .14799 L
.21843 .1474 L
.21877 .14671 L
.21916 .14593 L
.2196 .14508 L
Mistroke
.22007 .14417 L
.2206 .14321 L
.22119 .14222 L
.22182 .14122 L
.22242 .14027 L
.22311 .13942 L
.22379 .13868 L
.2245 .13807 L
.2252 .13758 L
.22584 .13723 L
.22637 .137 L
.2268 .1369 L
.22712 .13691 L
.22733 .13697 L
.22745 .13705 L
.22748 .13712 L
.22745 .13714 L
.22738 .13711 L
.22731 .137 L
.22724 .13683 L
.22721 .13662 L
.22721 .1364 L
.22726 .13616 L
.22737 .13592 L
.22752 .13571 L
.22771 .13554 L
.22795 .13541 L
.22823 .1353 L
.22857 .1352 L
.22897 .13508 L
.22943 .13494 L
.22994 .13476 L
.23048 .13452 L
.23103 .13422 L
.23156 .13387 L
.23206 .13346 L
.23254 .13302 L
.23299 .13258 L
.23343 .13217 L
.23386 .13179 L
.23431 .13145 L
.2348 .13113 L
.23533 .13082 L
.23591 .13053 L
.23654 .13025 L
.23719 .12997 L
.23793 .12967 L
.23872 .12935 L
.2395 .12901 L
.2403 .12862 L
Mistroke
.24113 .12821 L
.24191 .12779 L
.24267 .12739 L
.24342 .12705 L
.24408 .12674 L
.24471 .12653 L
.2453 .12642 L
.24589 .12638 L
.24651 .12635 L
.24716 .12628 L
.24794 .12613 L
.2489 .12583 L
.25002 .12532 L
.25139 .12458 L
.25295 .1236 L
.2548 .12237 L
.25694 .12089 L
.25925 .11953 L
.26175 .11771 L
.26444 .11607 L
.26722 .1142 L
.27018 .11228 L
.27347 .11033 L
.27653 .10845 L
.27972 .10649 L
.28286 .10476 L
.28607 .10303 L
.28887 .10141 L
.29158 .09985 L
.294 .09863 L
.29613 .09744 L
.29808 .09635 L
.29972 .09552 L
.30095 .09481 L
.30198 .09425 L
.30277 .09382 L
.3033 .09353 L
.30359 .09337 L
.30369 .09334 L
.30362 .0934 L
.30344 .09354 L
.30322 .0937 L
.30302 .09382 L
.30292 .09387 L
.30295 .09383 L
.30314 .09368 L
.30349 .09344 L
.30395 .09315 L
.30451 .0928 L
.30516 .09242 L
Mistroke
.30588 .09199 L
.30659 .09152 L
.30737 .09104 L
.30826 .09053 L
.30907 .08999 L
.30988 .08947 L
.31062 .08898 L
.31125 .08856 L
.31175 .0882 L
.31211 .08793 L
.3124 .08772 L
.31262 .08755 L
.31282 .08742 L
.31303 .0873 L
.31327 .0872 L
.31353 .08712 L
.3138 .08708 L
.31406 .08707 L
.3143 .0871 L
.31451 .08714 L
.31472 .08719 L
.31494 .08723 L
.31515 .08725 L
.31535 .08726 L
.3155 .08726 L
.31561 .08727 L
.31568 .08727 L
.31569 .08727 L
.31567 .08727 L
.31562 .08727 L
.31555 .08727 L
.31548 .08726 L
.31543 .08726 L
.31541 .08726 L
.31542 .08726 L
.31547 .08726 L
.31557 .08727 L
.31572 .08727 L
.31591 .08728 L
.31613 .08729 L
.31637 .0873 L
.31663 .08731 L
.31689 .08732 L
.31715 .08732 L
.3174 .08733 L
.31765 .08734 L
.31787 .08735 L
.31809 .08736 L
.3183 .08737 L
.31845 .08738 L
Mistroke
.31849 .08738 L
.31842 .08738 L
.31822 .08737 L
.31786 .08736 L
.31733 .08734 L
.31662 .08731 L
.31579 .08729 L
.31495 .08726 L
.31416 .08723 L
.3135 .0872 L
.31291 .08717 L
.31235 .08715 L
.31185 .08716 L
.31153 .08721 L
.31148 .08729 L
.31176 .08736 L
.31229 .08743 L
.31306 .08747 L
.31401 .08746 L
.31503 .08737 L
.31613 .08716 L
.31719 .08684 L
.31818 .0864 L
.31915 .08584 L
.32008 .08516 L
.32112 .08443 L
.32218 .08363 L
.32337 .08275 L
.32469 .08181 L
.32602 .08085 L
.32758 .08001 L
.32908 .07923 L
.33062 .07855 L
.33227 .07798 L
.33369 .07756 L
.33517 .07724 L
.33656 .07701 L
.33768 .07681 L
.33867 .07662 L
.33948 .0764 L
.34007 .07613 L
.34042 .07581 L
.34058 .07539 L
.34065 .07499 L
.3407 .07451 L
.34077 .07406 L
.34085 .07357 L
.34097 .0732 L
.34114 .07283 L
.34134 .07257 L
Mistroke
.3415 .07246 L
.34161 .07251 L
.34167 .07271 L
.34168 .07304 L
.34164 .07345 L
.34154 .07394 L
.34141 .07445 L
.34122 .07497 L
.34099 .07547 L
.34075 .07592 L
.34051 .0763 L
.34031 .07659 L
.34016 .0768 L
.34009 .07692 L
.34007 .07696 L
.34008 .07694 L
.34012 .07688 L
.34016 .0768 L
.34019 .07674 L
.34019 .07671 L
.34014 .07671 L
.34007 .0767 L
.33998 .0767 L
.33991 .0767 L
.33988 .07669 L
.33995 .0767 L
.34012 .0767 L
.34041 .07671 L
.34083 .07673 L
.34137 .07675 L
.34202 .07677 L
.34273 .0768 L
.34339 .07682 L
.34411 .07685 L
.34488 .07688 L
.34556 .07691 L
.3462 .07693 L
.34679 .07695 L
.34726 .07697 L
.34759 .07698 L
.34777 .07699 L
.34782 .077 L
.34778 .07703 L
.3477 .07706 L
.34765 .07707 L
.34765 .07706 L
.34771 .07704 L
.34784 .07702 L
.348 .077 L
.34815 .07697 L
Mistroke
.34828 .0769 L
.34837 .07677 L
.34843 .07657 L
.34846 .07631 L
.34846 .07598 L
.34844 .07566 L
.3484 .07534 L
.34832 .07498 L
.3482 .07462 L
.34805 .07427 L
.34789 .07392 L
.34773 .07355 L
.34759 .07318 L
.34749 .07283 L
.34745 .07259 L
.34745 .07245 L
.34748 .07239 L
.34752 .07244 L
.34755 .07265 L
.34756 .073 L
.34757 .07343 L
.34757 .07389 L
.34757 .07436 L
.34757 .07481 L
.34757 .07525 L
.34757 .07572 L
.34757 .07618 L
.34757 .07657 L
.34757 .07687 L
.34757 .07707 L
.34757 .07719 L
.34757 .07723 L
.34757 .07721 L
.34757 .07714 L
.34757 .07707 L
.34757 .07701 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
Mistroke
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34756 .07698 L
.34754 .077 L
.34747 .07705 L
.34739 .07713 L
.3473 .0772 L
.34722 .07726 L
.34717 .07729 L
.34716 .07728 L
.34723 .0772 L
.34741 .07704 L
.34773 .07678 L
.34822 .07641 L
.34892 .0759 L
.34985 .07523 L
.35091 .0744 L
.35216 .07344 L
.35369 .07231 L
.35539 .07099 L
.35749 .06957 L
.35949 .06802 L
Mistroke
.3618 .06636 L
.36423 .06462 L
.36676 .06289 L
.36952 .06116 L
.37189 .05939 L
.37439 .05779 L
.37699 .0562 L
.37913 .05478 L
.38119 .0535 L
.3831 .0525 L
.38465 .05169 L
.38613 .05108 L
.3874 .05067 L
.3884 .05043 L
.38918 .05033 L
.38972 .05029 L
.39007 .05036 L
.39028 .0505 L
.3904 .05068 L
.39051 .05086 L
.39065 .05097 L
.39087 .05096 L
.39115 .05084 L
.39149 .05064 L
.39191 .05034 L
.3924 .05003 L
.39296 .04967 L
.39357 .04925 L
.39432 .04886 L
.39519 .04853 L
.39627 .04819 L
.39736 .04789 L
.39861 .04763 L
.4 .04728 L
.40149 .04712 L
.40282 .04699 L
.40424 .04693 L
.40557 .04695 L
.40687 .04703 L
.40805 .04714 L
.4092 .04724 L
.41022 .04731 L
.41119 .04736 L
.412 .04739 L
.41269 .04741 L
.41327 .04743 L
.41372 .04745 L
.41407 .04746 L
.41436 .04747 L
.41458 .04748 L
Mistroke
.41476 .04749 L
.41493 .04749 L
.41508 .0475 L
.41521 .0475 L
.41532 .04751 L
.41539 .04751 L
.41541 .04751 L
.41538 .04751 L
.41531 .04751 L
.41522 .0475 L
.41514 .0475 L
.41509 .0475 L
.41513 .0475 L
.41525 .0475 L
.41548 .04751 L
.4158 .04752 L
.4162 .04754 L
.41668 .04756 L
.4172 .04758 L
.41777 .0476 L
.4184 .04762 L
.41908 .04764 L
.41986 .04767 L
.42063 .0477 L
.4215 .04773 L
.42244 .04776 L
.42348 .04779 L
.42459 .04783 L
.42569 .04787 L
.4269 .04791 L
.42824 .04795 L
.42965 .048 L
.43118 .04805 L
.43284 .04811 L
.43452 .04817 L
.43631 .04823 L
.43816 .04829 L
.44002 .04835 L
.44186 .04841 L
.44368 .04847 L
.44549 .04853 L
.44727 .04859 L
.44898 .04865 L
.45064 .0487 L
.45222 .04875 L
.45362 .0488 L
.45487 .04884 L
.45599 .04888 L
.45692 .04892 L
.45774 .04895 L
Mistroke
.45849 .04898 L
.4592 .049 L
.45992 .04901 L
.46069 .04901 L
.46156 .04901 L
.46257 .04902 L
.46372 .04903 L
.4649 .04904 L
.46625 .04908 L
.46772 .04912 L
.46936 .04917 L
.4711 .04923 L
.4729 .04927 L
.47461 .04931 L
.47637 .04936 L
.47813 .04941 L
.47985 .04946 L
.48143 .04951 L
.48301 .04957 L
.4845 .04963 L
.48599 .04968 L
.4873 .04974 L
.48852 .04977 L
.48966 .0498 L
.49064 .04983 L
.49151 .04987 L
.4922 .04991 L
.49275 .04995 L
.49318 .04999 L
.49348 .05002 L
.49365 .05005 L
.4937 .05006 L
.49364 .05006 L
.49353 .05005 L
.4934 .05004 L
.4933 .05003 L
.49326 .05002 L
.49327 .05002 L
.49335 .05003 L
.49348 .05003 L
.49366 .05004 L
.49387 .05004 L
.4941 .05005 L
.49434 .05006 L
.49458 .05006 L
.49482 .05007 L
.49506 .05008 L
.49527 .05008 L
.49546 .05009 L
.49561 .05009 L
Mistroke
.49572 .0501 L
.49578 .0501 L
.4958 .0501 L
.49578 .0501 L
.49575 .0501 L
.49571 .0501 L
.49567 .0501 L
.49564 .05009 L
.49559 .05009 L
.49552 .05009 L
.49544 .05009 L
.49533 .05009 L
.49522 .05008 L
.49516 .05008 L
.49517 .05008 L
.49529 .05008 L
.49557 .05009 L
.49602 .0501 L
.49669 .05012 L
.49772 .05015 L
.4989 .05019 L
.50033 .05023 L
.50208 .05028 L
.5039 .05033 L
.50591 .05039 L
.50803 .05046 L
.51009 .05052 L
.51212 .05058 L
.51414 .05064 L
.51575 .05069 L
.51747 .05073 L
.51868 .05077 L
.51969 .0508 L
.5205 .05082 L
.5211 .05083 L
.52148 .05084 L
.52167 .05084 L
.52173 .05084 L
.5217 .05084 L
.52161 .05084 L
.52149 .05083 L
.52136 .05083 L
.52128 .05083 L
.52124 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
Mistroke
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52122 .05083 L
.52119 .05082 L
.52115 .05082 L
.5211 .05082 L
.52105 .05082 L
.521 .05082 L
.52095 .05082 L
.52091 .05082 L
.52092 .05082 L
.52103 .05082 L
.52125 .05083 L
.5216 .05084 L
.52214 .05085 L
.52289 .05087 L
.52385 .0509 L
.52509 .05093 L
.52642 .05097 L
.52815 .05102 L
.53 .05106 L
.53171 .05112 L
.53383 .05117 L
.53605 .05124 L
.53834 .0513 L
.54065 .05136 L
.54293 .05142 L
.54511 .05148 L
.54712 .05154 L
.54894 .05159 L
.55074 .05163 L
.55206 .05167 L
.55336 .0517 L
.55431 .05172 L
.55508 .05174 L
Mistroke
.55566 .05176 L
.55604 .05177 L
.55624 .05177 L
.55631 .05177 L
.55628 .05177 L
.55619 .05177 L
.55606 .05176 L
.55594 .05176 L
.55585 .05176 L
.55582 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.55577 .05176 L
.5557 .05175 L
.5556 .05175 L
.55549 .05175 L
.55542 .05174 L
.5554 .05174 L
.55546 .05175 L
.55562 .05175 L
.55588 .05176 L
.55628 .05177 L
.55684 .05178 L
.55758 .0518 L
.55852 .05182 L
.55949 .05185 L
.5608 .05188 L
.56208 .05191 L
.56371 .05195 L
.56539 .052 L
.56745 .05205 L
.56931 .0521 L
.57143 .05216 L
.57361 .0522 L
.57595 .05223 L
.57797 .05223 L
.58023 .05223 L
Mistroke
.5825 .05226 L
.58432 .05235 L
.58633 .05251 L
.58821 .05272 L
.58981 .05297 L
.59131 .05322 L
.59258 .05344 L
.5937 .05362 L
.59463 .05377 L
.59531 .05392 L
.59586 .05403 L
.59627 .05412 L
.59659 .05423 L
.59683 .05433 L
.597 .05439 L
.59709 .05439 L
.59713 .05432 L
.59711 .0542 L
.59706 .05403 L
.59698 .05386 L
.59691 .05368 L
.59686 .05351 L
.59684 .05349 L
.59684 .0534 L
.59684 .05334 L
.59684 .05323 L
.59684 .05314 L
.59684 .05311 L
.59684 .0532 L
.59684 .05341 L
.59684 .05374 L
.59686 .05419 L
.59688 .05471 L
.59692 .05523 L
.59696 .05575 L
.59697 .05626 L
.59696 .05669 L
.59691 .05698 L
.59682 .05709 L
.59669 .05702 L
.59652 .05676 L
.59632 .05633 L
.59609 .05579 L
.59586 .05519 L
.59562 .05463 L
.59538 .05413 L
.59514 .05373 L
.5949 .05346 L
.59468 .05334 L
.59451 .05339 L
Mistroke
.59439 .05358 L
.59434 .0539 L
.59437 .05433 L
.59448 .05482 L
.59465 .05533 L
.59486 .05586 L
.59509 .05635 L
.59533 .05675 L
.59556 .05705 L
.5958 .05727 L
.59604 .05739 L
.59627 .05744 L
.59649 .05744 L
.5967 .05743 L
.59688 .05743 L
.59702 .05744 L
.59709 .05745 L
.5971 .05742 L
.59703 .05733 L
.59691 .05715 L
.59674 .05689 L
.59654 .05655 L
.59632 .05615 L
.59609 .05572 L
.59586 .05526 L
.59562 .0548 L
.59539 .05436 L
.59516 .05391 L
.59495 .0535 L
.59476 .05314 L
.59461 .05284 L
.5945 .05264 L
.59441 .05253 L
.59436 .05249 L
.59434 .05251 L
.59436 .05258 L
.59441 .05265 L
.59449 .05271 L
.59459 .05274 L
.59473 .05274 L
.5949 .05275 L
.5951 .05275 L
.59532 .05276 L
.59556 .05277 L
.59579 .05277 L
.59603 .05278 L
.59626 .05278 L
.59647 .05279 L
.59665 .05279 L
.59679 .05279 L
Mistroke
.5969 .05279 L
.59695 .05278 L
.59697 .05278 L
.59695 .05277 L
.5969 .05276 L
.59686 .05274 L
.59683 .05272 L
.59683 .05272 L
.59685 .05275 L
.59687 .0528 L
.5969 .05287 L
.59693 .05298 L
.59697 .05315 L
.59702 .05342 L
.59708 .0537 L
.59712 .05405 L
.59714 .05439 L
.59713 .05468 L
.59707 .05485 L
.59697 .05494 L
.59682 .05496 L
.59662 .05494 L
.59639 .05492 L
.59613 .05491 L
.59587 .05492 L
.59561 .05496 L
.59536 .055 L
.59513 .05507 L
.59492 .05516 L
.59475 .05529 L
.59462 .05545 L
.59452 .05569 L
.59446 .05598 L
.59444 .05631 L
.59446 .05665 L
.59449 .05698 L
.59453 .05722 L
.59456 .05735 L
.59458 .05739 L
.59458 .05735 L
.59458 .05729 L
.59458 .05722 L
.59458 .05717 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59456 .05715 L
Mistroke
.59454 .05715 L
.5945 .05715 L
.59447 .05715 L
.59445 .05715 L
.59446 .05715 L
.59451 .05715 L
.5946 .05715 L
.59473 .05715 L
.59489 .05716 L
.59507 .05716 L
.59525 .05716 L
.59541 .05717 L
.59556 .05717 L
.59572 .05715 L
.59591 .05711 L
.59611 .05704 L
.59635 .05698 L
.59661 .05696 L
.59693 .05699 L
.59732 .05708 L
.59782 .05727 L
.59846 .05753 L
.59924 .05788 L
.60026 .05828 L
.60145 .05871 L
.6029 .05915 L
.60454 .05961 L
.60649 .06008 L
.60828 .06056 L
.61033 .06102 L
.61259 .06145 L
.61459 .06186 L
.61673 .06224 L
.61885 .06262 L
.62095 .063 L
.62304 .06342 L
.62499 .06387 L
.62686 .06438 L
.62851 .06497 L
.63008 .06559 L
.63141 .06619 L
.63258 .06674 L
.63369 .06724 L
.63474 .06772 L
.63562 .0682 L
.63649 .06866 L
.63735 .06909 L
.63823 .06951 L
.63914 .06991 L
.64006 .07032 L
Mistroke
.64091 .07073 L
.64178 .07115 L
.64273 .07156 L
.64368 .072 L
.64477 .07249 L
.64587 .07301 L
.64711 .07355 L
.64838 .07407 L
.64983 .07457 L
.65131 .07506 L
.65295 .07555 L
.65457 .07608 L
.65629 .07667 L
.65818 .07733 L
.66005 .07808 L
.66194 .07888 L
.66371 .0797 L
.66553 .08052 L
.66696 .08132 L
.66848 .0821 L
.66979 .08283 L
.67107 .08348 L
.6723 .08407 L
.67345 .08458 L
.67464 .08503 L
.6759 .08542 L
.677 .08576 L
.67818 .08612 L
.67949 .08652 L
.68082 .08698 L
.6824 .0875 L
.68411 .0881 L
.68582 .0888 L
.68767 .08963 L
.68948 .09047 L
.69128 .09133 L
.69311 .0922 L
.69476 .09308 L
.69645 .09396 L
.69814 .09475 L
.69979 .09553 L
.70145 .0963 L
.7031 .09703 L
.70473 .09773 L
.7063 .09843 L
.70792 .09917 L
.70954 .09998 L
.71124 .1009 L
.71306 .10182 L
.71505 .10279 L
Mistroke
.71726 .10388 L
.71979 .10512 L
.7224 .10633 L
.72539 .10761 L
.72872 .10915 L
.73213 .11047 L
.73573 .11188 L
.73945 .11338 L
.74362 .11491 L
.74688 .11622 L
.75035 .11748 L
.7539 .11866 L
.75648 .11977 L
.75907 .12079 L
.76147 .1216 L
.76322 .1223 L
.76465 .12289 L
.76564 .12333 L
.76619 .12362 L
.76635 .12377 L
.76623 .12381 L
.76591 .12377 L
.76549 .1237 L
.76503 .12361 L
.76461 .12353 L
.76423 .12345 L
.76391 .12341 L
.76364 .1234 L
.76342 .1234 L
.76323 .1234 L
.76309 .12339 L
.763 .12339 L
.76297 .12339 L
.76301 .12339 L
.76308 .12339 L
.76318 .12338 L
.76328 .12336 L
.76337 .12333 L
.76341 .1233 L
.7634 .12328 L
.76337 .12329 L
.76335 .12335 L
.76334 .12346 L
.76334 .12362 L
.76335 .12381 L
.76335 .12402 L
.76335 .12422 L
.76335 .12439 L
.76335 .12452 L
.76336 .1246 L
Mistroke
.76336 .12462 L
.76336 .12461 L
.76336 .12458 L
.76335 .12454 L
.76335 .12448 L
.76335 .1244 L
.76335 .12429 L
.76335 .12417 L
.76335 .12405 L
.76335 .12394 L
.76335 .12386 L
.76335 .12381 L
.76335 .1238 L
.76335 .12381 L
.76335 .12384 L
.76335 .12384 L
.76335 .12381 L
.76334 .12374 L
.76334 .12364 L
.76334 .12354 L
.76334 .12344 L
.76334 .12337 L
.76334 .12333 L
.76334 .12331 L
.76334 .12333 L
.76334 .12336 L
.76334 .12339 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .12339 L
.76332 .12338 L
.7633 .12338 L
.76326 .12338 L
.76323 .12339 L
.76322 .12341 L
.76323 .12343 L
.76328 .12346 L
.76336 .12348 L
.76349 .12351 L
.76365 .12353 L
.76385 .12355 L
.76406 .12356 L
.76428 .12356 L
.7645 .12357 L
.76473 .12356 L
.76494 .12356 L
.76514 .12354 L
Mistroke
.76532 .12352 L
.76546 .1235 L
.76555 .12347 L
.76561 .12345 L
.76562 .12343 L
.76561 .12342 L
.76558 .12341 L
.76554 .12342 L
.76551 .12343 L
.7655 .12344 L
.7655 .12344 L
.7655 .12343 L
.76548 .12342 L
.76546 .1234 L
.76542 .12336 L
.76539 .12333 L
.76536 .12331 L
.76535 .12332 L
.76536 .12337 L
.76542 .12345 L
.76552 .12357 L
.76568 .12373 L
.76589 .1239 L
.76614 .12406 L
.76643 .12422 L
.76676 .12438 L
.76712 .12458 L
.76751 .12481 L
.76793 .12506 L
.76841 .12535 L
.76893 .12567 L
.7695 .12604 L
.77015 .12648 L
.77087 .12699 L
.77164 .12757 L
.77255 .12821 L
.77362 .1289 L
.77485 .1297 L
.7763 .1306 L
.77776 .13158 L
.77947 .13257 L
.78125 .13353 L
.78318 .13455 L
.78518 .13559 L
.78736 .13662 L
.78911 .13767 L
.79112 .13873 L
.79289 .13971 L
.79436 .14064 L
.79582 .14152 L
Mistroke
.79714 .14234 L
.79831 .14309 L
.79924 .14374 L
.80004 .14435 L
.80073 .14491 L
.80132 .1454 L
.80182 .14582 L
.80222 .14616 L
.80262 .14645 L
.80302 .14671 L
.80339 .14693 L
.80372 .14713 L
.80398 .14729 L
.80419 .14742 L
.80435 .14752 L
.80444 .14756 L
.80446 .14752 L
.80444 .14741 L
.80437 .14723 L
.8043 .147 L
.80424 .14675 L
.80418 .14649 L
.80415 .14624 L
.80415 .14601 L
.80421 .14583 L
.80429 .1457 L
.80439 .14563 L
.80447 .14558 L
.80451 .14555 L
.80448 .14551 L
.80437 .14544 L
.80415 .1453 L
.80384 .14509 L
.80346 .14479 L
.80302 .14442 L
.80255 .14401 L
.8021 .14356 L
.80168 .14313 L
.80126 .14272 L
.80085 .1423 L
.80049 .1419 L
.80021 .14157 L
.80003 .14133 L
.79996 .1412 L
.79996 .14116 L
.79999 .14115 L
.80004 .14114 L
.80007 .14111 L
.80003 .141 L
.79993 .1408 L
Mistroke
.79976 .1405 L
.79957 .14012 L
.79935 .13969 L
.79912 .13925 L
.79888 .13881 L
.79864 .13839 L
.79842 .13797 L
.79825 .13757 L
.79817 .13722 L
.79814 .13693 L
.79809 .13674 L
.79802 .13663 L
.79791 .13659 L
.79773 .13661 L
.79741 .13666 L
.79696 .13673 L
.79639 .13677 L
.79578 .1368 L
.79519 .13681 L
.79462 .13684 L
.79407 .13686 L
.79349 .13686 L
.79287 .13684 L
.79225 .13679 L
.79171 .13669 L
.79127 .13656 L
.79091 .13639 L
.79061 .1362 L
.79036 .13598 L
.79019 .13576 L
.79005 .13552 L
.78987 .13527 L
.78967 .13504 L
.78952 .13483 L
.78946 .13468 L
.7895 .13458 L
.78965 .13453 L
.78988 .13453 L
.79019 .13456 L
.79055 .1346 L
.79096 .13466 L
.79139 .13469 L
.79182 .13471 L
.79225 .1347 L
.79265 .13469 L
.79304 .13473 L
.79343 .13484 L
.79382 .13504 L
.7942 .13535 L
.79459 .13578 L
Mistroke
.79498 .13633 L
.7954 .13701 L
.79585 .1378 L
.79636 .1387 L
.79695 .13968 L
.79763 .14081 L
.79843 .1422 L
.79935 .14355 L
.80033 .145 L
.80142 .14656 L
.80251 .1481 L
.80368 .14969 L
.80491 .15124 L
.80592 .15244 L
.80705 .15368 L
.80815 .15478 L
.80906 .1557 L
.80996 .15658 L
.8108 .15739 L
.81154 .15806 L
.81217 .15857 L
.81267 .15896 L
.8131 .15929 L
.81346 .1596 L
.81376 .15993 L
.81403 .16035 L
.81429 .16085 L
.81456 .16146 L
.81482 .16219 L
.81508 .16297 L
.81533 .16374 L
.81557 .16446 L
.8158 .16509 L
.81603 .16565 L
.81624 .16611 L
.81643 .16649 L
.81659 .16678 L
.81674 .16698 L
.81692 .16712 L
.81711 .1672 L
.81733 .16722 L
.81755 .1672 L
.81777 .16714 L
.81798 .16707 L
.81819 .16702 L
.81838 .16699 L
.81857 .16699 L
.81875 .16699 L
.81894 .167 L
.81914 .167 L
Mistroke
.81934 .167 L
.81951 .16701 L
.81964 .16701 L
.81973 .16701 L
.81979 .16701 L
.8198 .16701 L
.81979 .16701 L
.81976 .16701 L
.81972 .16701 L
.81969 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16699 L
.81968 .16697 L
.81968 .16693 L
.81967 .16687 L
.81965 .1668 L
.81959 .16674 L
.81952 .16671 L
.81945 .16671 L
.81941 .16679 L
.81941 .16698 L
.81947 .1673 L
.81962 .16774 L
.81987 .16832 L
.82023 .16901 L
.82069 .16982 L
.82125 .17073 L
.8219 .17168 L
.82258 .17269 L
.82332 .1738 L
.82414 .17504 L
.82502 .17624 L
Mistroke
.82587 .17751 L
.82672 .17882 L
.8275 .18009 L
.8282 .18136 L
.82881 .18259 L
.82932 .18365 L
.82973 .18468 L
.83006 .18566 L
.83032 .18649 L
.83052 .18725 L
.83065 .1879 L
.83072 .18841 L
.83074 .18873 L
.83074 .18885 L
.83072 .18877 L
.83071 .18854 L
.83072 .18817 L
.83076 .18769 L
.83086 .18722 L
.83103 .18669 L
.83124 .18617 L
.8315 .1857 L
.8318 .18524 L
.83214 .18483 L
.83252 .18449 L
.83292 .18424 L
.83335 .18413 L
.83379 .18417 L
.83424 .1844 L
.8347 .18484 L
.83516 .18549 L
.83561 .18635 L
.83608 .18734 L
.83657 .18851 L
.8371 .18988 L
.8377 .19149 L
.83839 .19317 L
.83917 .19506 L
.84006 .19723 L
.84103 .19938 L
.84209 .20169 L
.84324 .2042 L
.84432 .20638 L
.84543 .20867 L
.84659 .21093 L
.84766 .21289 L
.84884 .21488 L
.85008 .2169 L
.85121 .21865 L
.85241 .22043 L
Mistroke
.85371 .2223 L
.85497 .22415 L
.8564 .22615 L
.85776 .22838 L
.85924 .23068 L
.86104 .23312 L
.86267 .23574 L
.8646 .23878 L
.86666 .2423 L
.86881 .24543 L
.87105 .24904 L
.87329 .25267 L
.87559 .25644 L
.87799 .25996 L
.88026 .26345 L
.88264 .26688 L
.88524 .27044 L
.88751 .27346 L
.88997 .27667 L
.89239 .27969 L
.89473 .2827 L
.89685 .28542 L
.89898 .28811 L
.90112 .29068 L
.90279 .29319 L
.90451 .29547 L
.90626 .29774 L
.90765 .29982 L
.90902 .30175 L
.9103 .30365 L
.91134 .30534 L
.91236 .30691 L
.91325 .30834 L
.91404 .30956 L
.91477 .31065 L
.91548 .31158 L
.91616 .31233 L
.91677 .31289 L
.91733 .31336 L
.91782 .31377 L
.91823 .31415 L
.91857 .31452 L
.91885 .31493 L
.91908 .3154 L
.91928 .31594 L
.91945 .31653 L
.91957 .31714 L
.91965 .31773 L
.91969 .31829 L
.91969 .31886 L
Mistroke
.91969 .31945 L
.91967 .32003 L
.91966 .32054 L
.91964 .32096 L
.91964 .32127 L
.91965 .32145 L
.91965 .32152 L
.91965 .32152 L
.91965 .32145 L
.91965 .32138 L
.91965 .32132 L
.91965 .3213 L
.91965 .32129 L
.91965 .32129 L
.91965 .32128 L
.91965 .32127 L
.91964 .32125 L
.91964 .32123 L
.91964 .32119 L
.91964 .32116 L
.91963 .32113 L
.91963 .32111 L
.91963 .32109 L
.91963 .32109 L
.91963 .3211 L
.91963 .32111 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91964 .32112 L
.91965 .32115 L
.91967 .3212 L
.91971 .32126 L
.91974 .32133 L
.91976 .32138 L
.91975 .32138 L
.91971 .32133 L
.91964 .32122 L
.91954 .32104 L
.91941 .32078 L
.91926 .32042 L
.91907 .31997 L
.91886 .31943 L
.91861 .31881 L
.91834 .3181 L
.91804 .31732 L
.91772 .31646 L
Mistroke
.91736 .31554 L
.91697 .31456 L
.91654 .31351 L
.91609 .31242 L
.91559 .31133 L
.91504 .31017 L
.9144 .30889 L
.91369 .30755 L
.91286 .30608 L
.9119 .30442 L
.9109 .30272 L
.9098 .30091 L
.90871 .29908 L
.90756 .29713 L
.90648 .29542 L
.90535 .29351 L
.90425 .29178 L
.90313 .28998 L
.90197 .28805 L
.90095 .28643 L
.89993 .2848 L
.89892 .28316 L
.89796 .28157 L
.89708 .28014 L
.8964 .27906 L
.89573 .27796 L
.89511 .27691 L
.89459 .27606 L
.89413 .27529 L
.89373 .27462 L
.89342 .2741 L
.89321 .27375 L
.89311 .27357 L
.89311 .27357 L
.89321 .27372 L
.89338 .27399 L
.8936 .27433 L
.89385 .27471 L
.89411 .27511 L
.89438 .27557 L
.89465 .27605 L
.89497 .27662 L
.89535 .27731 L
.8958 .27813 L
.89638 .27913 L
.89702 .28026 L
.89776 .2816 L
.89863 .28321 L
.89967 .28489 L
.90092 .28695 L
Mistroke
.90215 .28905 L
.90351 .29145 L
.90508 .29408 L
.90665 .29691 L
.90838 .29954 L
.91022 .30212 L
.91189 .3048 L
.91345 .30681 L
.91483 .30875 L
.91617 .31079 L
.91713 .31235 L
.91794 .31374 L
.91856 .31493 L
.919 .31594 L
.91929 .3168 L
.91946 .31756 L
.91952 .31823 L
.91952 .31881 L
.91947 .31939 L
.91941 .32008 L
.91933 .32088 L
.91928 .3217 L
.91931 .32248 L
.9194 .32319 L
.91951 .32376 L
.91962 .32425 L
.91971 .32464 L
.91978 .32495 L
.91983 .3252 L
.91985 .3254 L
.91984 .32554 L
.91981 .32562 L
.91979 .32564 L
.91978 .32561 L
.91978 .32555 L
.91978 .32547 L
.91978 .32542 L
.91978 .3254 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91978 .3254 L
.91977 .32542 L
.91976 .32547 L
.91974 .32554 L
.91971 .3256 L
.91968 .32563 L
.91967 .32561 L
.91967 .32552 L
Mistroke
.91971 .32535 L
.91979 .32509 L
.9199 .32477 L
.92004 .32439 L
.92021 .32397 L
.92039 .32353 L
.92059 .32309 L
.92079 .32266 L
.92098 .32224 L
.92117 .32184 L
.92135 .32149 L
.92151 .32121 L
.92163 .32102 L
.92172 .32091 L
.92177 .32087 L
.92178 .3209 L
.92177 .32096 L
.92174 .32103 L
.92171 .32109 L
.92169 .32111 L
.92169 .32114 L
.92171 .32119 L
.92175 .32125 L
.92178 .32132 L
.92179 .32135 L
.92178 .32133 L
.92174 .32124 L
.92165 .32108 L
.92153 .32083 L
.92137 .32051 L
.92119 .32015 L
.921 .31976 L
.92081 .31936 L
.92062 .31895 L
.92041 .31853 L
.92017 .31809 L
.91992 .31764 L
.91966 .3172 L
.91939 .31678 L
.91913 .31639 L
.91888 .31603 L
.91864 .31571 L
.91843 .31542 L
.91825 .31521 L
.91807 .31507 L
.91789 .31501 L
.91771 .31503 L
.91756 .31518 L
.91744 .31548 L
.91737 .31591 L
Mistroke
.91734 .31646 L
.91734 .31705 L
.91738 .31771 L
.91743 .31842 L
.91749 .31907 L
.91754 .3197 L
.91757 .32025 L
.91758 .32072 L
.91759 .32107 L
.9176 .3213 L
.9176 .32142 L
.9176 .32144 L
.9176 .32139 L
.9176 .32131 L
.91759 .32123 L
.91759 .32116 L
.91759 .32113 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91758 .32112 L
.91755 .32112 L
.91752 .32112 L
.91749 .32112 L
.91748 .32112 L
.91749 .32112 L
.91753 .32112 L
.91761 .32112 L
.91773 .32112 L
.91789 .32112 L
.91807 .32112 L
.91827 .32112 L
.91848 .32112 L
.91869 .32112 L
.9189 .32112 L
.91911 .32112 L
.9193 .32112 L
.91946 .32112 L
.91959 .32112 L
.91968 .32112 L
.91974 .32112 L
.91975 .32112 L
.91974 .32112 L
.91971 .32112 L
.91967 .32112 L
.91965 .32112 L
Mistroke
.91964 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32113 L
.91964 .32114 L
.91964 .32113 L
.91963 .32113 L
.91963 .32111 L
.91963 .3211 L
.91963 .32109 L
.91963 .32108 L
.91962 .32108 L
.91962 .32106 L
.91962 .32105 L
.91962 .32103 L
.91962 .32101 L
.91961 .32098 L
.91961 .32094 L
.91961 .32091 L
.91961 .32087 L
.9196 .32085 L
.9196 .32083 L
.9196 .32083 L
.9196 .32083 L
.91961 .32084 L
.91961 .32075 L
.91961 .32078 L
.91961 .3208 L
.91961 .32083 L
.91962 .32089 L
.91962 .32095 L
.91962 .32101 L
.91963 .32107 L
.91963 .32111 L
.91963 .32114 L
.91963 .32115 L
.91964 .32115 L
.91964 .32115 L
.91963 .32114 L
.91963 .32113 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91965 .32112 L
.91972 .32112 L
Mistroke
.91982 .32112 L
.9199 .32111 L
.91994 .32109 L
.91994 .32104 L
.91985 .32098 L
.91965 .32091 L
.91932 .32088 L
.91886 .3209 L
.91826 .32099 L
.91752 .32115 L
.91668 .32137 L
.91589 .32166 L
.9151 .322 L
.9142 .32241 L
.91315 .32287 L
.91192 .32336 L
.91089 .32387 L
.90985 .32438 L
.90879 .32487 L
.90778 .32535 L
.9069 .3258 L
.9062 .32625 L
.90564 .32667 L
.90514 .32709 L
.90472 .32749 L
.90439 .32789 L
.90417 .3283 L
.90412 .32873 L
.90422 .32918 L
.90446 .32962 L
.9048 .33007 L
.90524 .33055 L
.90579 .33106 L
.90637 .33164 L
.90693 .33232 L
.90753 .3331 L
.90825 .33401 L
.90911 .335 L
.91006 .33611 L
.91119 .33736 L
.91251 .33877 L
.91369 .34023 L
.91511 .34175 L
.91651 .3434 L
.91811 .3451 L
.91941 .34681 L
.92075 .34844 L
.92202 .35008 L
.92321 .35166 L
.92418 .35318 L
Mistroke
.92506 .35477 L
.9258 .35633 L
.9264 .35791 L
.92689 .35962 L
.9273 .36139 L
.92767 .36309 L
.92798 .36485 L
.92826 .36657 L
.92851 .3681 L
.92872 .3694 L
.92891 .37055 L
.9291 .37164 L
.92928 .37268 L
.92944 .37362 L
.92957 .37445 L
.92968 .37524 L
.92975 .37601 L
.92979 .37682 L
.9298 .37765 L
.92979 .37843 L
.92979 .37908 L
.9298 .37994 L
.92982 .38098 L
.92986 .38203 L
.92989 .38299 L
.92992 .38379 L
.92994 .38446 L
.92996 .38499 L
.92998 .38538 L
.92999 .38564 L
.92999 .3858 L
.92999 .38588 L
.92999 .38592 L
.92999 .38592 L
.92999 .38586 L
.92999 .38573 L
.92998 .38554 L
.92998 .38531 L
.93 .38502 L
.93002 .38466 L
.93003 .38424 L
.93003 .38374 L
.93 .38317 L
.92994 .38253 L
.92983 .3818 L
.92968 .381 L
.9295 .38015 L
.9293 .37927 L
.9291 .37838 L
.9289 .37746 L
Mistroke
.92871 .3765 L
.92853 .37548 L
.92835 .37433 L
.92817 .37294 L
.92798 .37144 L
.92776 .36963 L
.92749 .36738 L
.9272 .36502 L
.92683 .36218 L
.92639 .35912 L
.92585 .35555 L
.92525 .35173 L
.92454 .34784 L
.9237 .34328 L
.9228 .33947 L
.92174 .33444 L
.92075 .33061 L
.91967 .32647 L
.91851 .32184 L
.91736 .3183 L
.9161 .31452 L
.91489 .31102 L
.91359 .30772 L
.91223 .30463 L
.91088 .30188 L
.90948 .2993 L
.90812 .29691 L
.90675 .29477 L
.90548 .29277 L
.90424 .29093 L
.90314 .28929 L
.90212 .28777 L
.90121 .28645 L
.90044 .2853 L
.89978 .28432 L
.89925 .28348 L
.89882 .2828 L
.89851 .28224 L
.89827 .28174 L
.8981 .28129 L
.89797 .28088 L
.89786 .28049 L
.89777 .28014 L
.89771 .2798 L
.89766 .2795 L
.89763 .27922 L
.89761 .27898 L
.8976 .27876 L
.89762 .2786 L
.89765 .27851 L
Mistroke
.89771 .27851 L
.8978 .27862 L
.89792 .27886 L
.89809 .27924 L
.89829 .27971 L
.89851 .28024 L
.89873 .28084 L
.89894 .28151 L
.89914 .28223 L
.89934 .28295 L
.89954 .2837 L
.89974 .28445 L
.89995 .28521 L
.90017 .28593 L
.9004 .28659 L
.90062 .28715 L
.90082 .28759 L
.90099 .28798 L
.90113 .28831 L
.90124 .28857 L
.90133 .28876 L
.90139 .28885 L
.90141 .28884 L
.90139 .28873 L
.90134 .28852 L
.90126 .2882 L
.90113 .28782 L
.90096 .28738 L
.90075 .2869 L
.90053 .28644 L
.90031 .28593 L
.90008 .28536 L
.89982 .28471 L
.89949 .28396 L
.89906 .28308 L
.8985 .28211 L
.89776 .28101 L
.89683 .27975 L
.89575 .27837 L
.8945 .27682 L
.89319 .2752 L
.89177 .27347 L
.89031 .27163 L
.88897 .26979 L
.88762 .26794 L
.8863 .26613 L
.88508 .26446 L
.88402 .26291 L
.8831 .26148 L
.88234 .26027 L
Mistroke
.88174 .25924 L
.88131 .25839 L
.88099 .25774 L
.88077 .25725 L
.88062 .25692 L
.88052 .25673 L
.88046 .25666 L
.88045 .25668 L
.88048 .25678 L
.88056 .25691 L
.88073 .25709 L
.88096 .25737 L
.8812 .25768 L
.88138 .25798 L
.88146 .2582 L
.8814 .25827 L
.88112 .25812 L
.88051 .25759 L
.87951 .25653 L
.87803 .25487 L
.876 .25248 L
.87396 .24985 L
.87107 .24612 L
.86864 .24263 L
.86549 .23873 L
.8614 .23302 L
.85828 .22876 L
.85438 .22314 L
.85004 .21641 L
.84644 .21082 L
.84266 .20541 L
.83875 .19938 L
.83545 .19407 L
.8322 .18857 L
.829 .18382 L
.82588 .17872 L
.8232 .17438 L
.82083 .17074 L
.8184 .16697 L
.81629 .16356 L
.81434 .16045 L
.81268 .1578 L
.81132 .15556 L
.81018 .15366 L
.80925 .15208 L
.80843 .15072 L
.80771 .14955 L
.80704 .14854 L
.8063 .14758 L
.80543 .14663 L
Mistroke
.80444 .14568 L
.80332 .14472 L
.80201 .14373 L
.80048 .14272 L
.79908 .14177 L
.79746 .14082 L
.79573 .1399 L
.79427 .13903 L
.79253 .13827 L
.79122 .13759 L
.78992 .13702 L
.78893 .1366 L
.78802 .13632 L
.78733 .13618 L
.78691 .13617 L
.78674 .13626 L
.78674 .13641 L
.78682 .13655 L
.78693 .13665 L
.78704 .13669 L
.7871 .13664 L
.78706 .13652 L
.7869 .13635 L
.78669 .13615 L
.78645 .13592 L
.78619 .13569 L
.78593 .13547 L
.78567 .13524 L
.78542 .13502 L
.78521 .13482 L
.78504 .13464 L
.78494 .13451 L
.78493 .13441 L
.78501 .13436 L
.7852 .13434 L
.7855 .13436 L
.78588 .13439 L
.78632 .13441 L
.78681 .13441 L
.78735 .1344 L
.78792 .13439 L
.78851 .13442 L
.78913 .13447 L
.78976 .13457 L
.79036 .13471 L
.79094 .13488 L
.79147 .13508 L
.79194 .13529 L
.79236 .13552 L
.79271 .13575 L
Mistroke
.79301 .13598 L
.79325 .1362 L
.79343 .1364 L
.79356 .13657 L
.79365 .13671 L
.79371 .13681 L
.79374 .13686 L
.79375 .13685 L
.79376 .13679 L
.79376 .13669 L
.79375 .13659 L
.79373 .13653 L
.79367 .13654 L
.79359 .13662 L
.79348 .13679 L
.79334 .13704 L
.7932 .13736 L
.79306 .13774 L
.79295 .13816 L
.79286 .1386 L
.79281 .13903 L
.79278 .13947 L
.79279 .13989 L
.79282 .14029 L
.7929 .14064 L
.79304 .14092 L
.79323 .14112 L
.79344 .14123 L
.79362 .14126 L
.79375 .14124 L
.79379 .14118 L
.79371 .1411 L
.7935 .14105 L
.79319 .14104 L
.79281 .14108 L
.79239 .14114 L
.79195 .1412 L
.79151 .14122 L
.79105 .1412 L
.79059 .14112 L
.79013 .14097 L
.78969 .14076 L
.78928 .14047 L
.78893 .14013 L
.78864 .13975 L
.7884 .13932 L
.78818 .13885 L
.78796 .13832 L
.78772 .13774 L
.78741 .13712 L
Mistroke
.78702 .13646 L
.78656 .13578 L
.78604 .13512 L
.78545 .13447 L
.78475 .13382 L
.78392 .13314 L
.78291 .1324 L
.78171 .13161 L
.78025 .1307 L
.77847 .12967 L
.7764 .12848 L
.77397 .12721 L
.77115 .12583 L
.76768 .12428 L
.76407 .12261 L
.75958 .12071 L
.7548 .1187 L
.74951 .1164 L
.74362 .11405 L
.73715 .11128 L
.73093 .10867 L
.72399 .10568 L
.71705 .10286 L
.70917 .09961 L
.7023 .0968 L
.69552 .09367 L
.68732 .09044 L
.68096 .08756 L
.6741 .08445 L
.66711 .08138 L
.66024 .07829 L
.65273 .0755 L
.6462 .07257 L
.64025 .07016 L
.63411 .0677 L
.62828 .06547 L
.62255 .06338 L
.61714 .06132 L
.61266 .05968 L
.60831 .05817 L
.60462 .05684 L
.60137 .05571 L
.59883 .05479 L
.59669 .05411 L
.59505 .05359 L
.59379 .0532 L
.59274 .05292 L
.59183 .05271 L
.59103 .05255 L
.59022 .05243 L
Mistroke
.5894 .05236 L
.58858 .05233 L
.58776 .05235 L
.58694 .0524 L
.58614 .05245 L
.58537 .05249 L
.58468 .05249 L
.58408 .05248 L
.5836 .05247 L
.58325 .05246 L
.583 .05245 L
.58287 .05245 L
.58282 .05245 L
.58286 .05245 L
.58297 .05245 L
.58308 .05245 L
.58317 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58322 .05245 L
.58324 .05243 L
.58329 .05238 L
.58337 .05231 L
.58344 .05225 L
.58347 .05222 L
.58345 .05224 L
.58336 .05233 L
.5832 .05251 L
.58298 .05276 L
.58272 .05309 L
.58243 .05347 L
.58209 .0539 L
.58167 .05435 L
.58117 .05479 L
.58059 .05522 L
.57992 .05565 L
.57915 .05604 L
.5783 .05637 L
.57736 .05664 L
.57637 .05681 L
.57533 .0569 L
.57432 .05691 L
.57331 .05686 L
Mistroke
.57232 .05677 L
.57137 .05669 L
.57047 .05662 L
.56964 .05657 L
.5689 .05653 L
.56825 .0565 L
.56769 .05646 L
.56721 .05641 L
.56682 .05637 L
.56647 .05632 L
.56616 .05624 L
.56588 .05614 L
.56563 .05605 L
.56543 .05599 L
.56526 .05596 L
.56516 .05597 L
.56513 .05602 L
.56517 .05611 L
.56527 .05627 L
.56542 .05652 L
.56557 .05688 L
.56564 .05739 L
.56551 .05821 L
.56507 .05924 L
.56429 .06057 L
.56311 .06225 L
.56148 .06437 L
.55939 .06689 L
.5572 .06916 L
.55449 .07191 L
.55136 .07509 L
.54782 .07787 L
.54409 .08098 L
.5396 .08407 L
.53547 .08673 L
.5307 .08911 L
.52571 .09099 L
.52036 .09224 L
.51502 .09283 L
.50942 .09272 L
.50355 .09195 L
.49712 .09057 L
.49127 .08874 L
.48518 .08642 L
.47849 .0837 L
.47286 .08073 L
.46672 .07746 L
.46108 .07398 L
.45559 .07048 L
.45049 .06693 L
Mistroke
.44561 .06354 L
.44091 .06029 L
.43672 .05736 L
.43261 .05468 L
.42878 .05236 L
.42503 .05038 L
.42141 .04884 L
.41767 .04776 L
.41366 .04716 L
.40996 .04704 L
.40578 .0474 L
.40102 .04823 L
.39678 .0495 L
.39138 .05114 L
.38624 .05314 L
.38034 .05545 L
.3731 .0582 L
.36713 .06115 L
.36001 .06448 L
.35232 .06808 L
.34391 .07211 L
.33632 .07613 L
.32791 .08056 L
.31957 .08515 L
.31018 .08993 L
.30263 .09473 L
.29425 .09969 L
.28472 .10474 L
.27755 .1096 L
.26937 .11462 L
.2606 .1199 L
.25363 .1245 L
.24614 .12936 L
.23891 .13423 L
.23188 .13922 L
.22468 .14424 L
.2185 .14942 L
.21183 .15473 L
.20577 .16046 L
.19995 .1663 L
.19407 .17269 L
.18821 .17886 L
.18246 .18574 L
.17712 .19224 L
.17167 .19993 L
.16677 .20644 L
.16182 .21272 L
.1571 .21973 L
.15235 .22781 L
.14775 .23462 L
Mistroke
.14353 .24122 L
.13918 .24868 L
.13496 .25661 L
.13064 .26548 L
.12696 .27285 L
.12307 .28154 L
.11906 .2914 L
.11542 .29965 L
.11162 .30942 L
.10795 .31882 L
.10436 .32944 L
.10077 .33757 L
.09749 .34657 L
.09436 .3556 L
.09157 .36293 L
.08905 .37013 L
.08678 .3768 L
.0849 .38209 L
.08327 .38694 L
.08195 .39075 L
.08096 .39387 L
.08026 .39633 L
.07982 .39815 L
.0796 .39947 L
.07953 .40037 L
.07956 .40092 L
.07965 .40118 L
.07977 .40123 L
.07988 .40112 L
.07997 .40092 L
.08003 .40068 L
.08007 .40044 L
.0801 .40026 L
.0801 .40015 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
.08019 .40006 L
.08026 .40002 L
.08031 .39998 L
.08031 .39996 L
Mistroke
.08026 .39998 L
.08014 .40003 L
.07995 .40013 L
.07971 .40027 L
.07943 .40046 L
.07912 .40067 L
.0788 .40091 L
.07848 .40116 L
.07817 .40141 L
.07788 .40167 L
.07761 .40191 L
.07737 .40213 L
.07719 .40233 L
.07706 .40248 L
.07701 .40259 L
.07701 .40265 L
.07707 .40267 L
.07716 .40265 L
.07725 .40261 L
.07732 .40257 L
.07735 .40254 L
.07735 .40252 L
.07732 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07725 .40252 L
.07719 .40252 L
.07711 .40252 L
.07703 .40252 L
.07697 .40252 L
.07697 .40252 L
.07703 .40249 L
.07718 .40243 L
Mistroke
.07744 .40235 L
.07782 .40228 L
.07832 .40224 L
.07896 .40225 L
.0797 .40232 L
.0806 .40245 L
.08163 .40265 L
.0828 .40293 L
.08409 .40331 L
.08546 .4038 L
.08688 .40439 L
.08827 .40508 L
.08963 .40585 L
.09089 .40668 L
.09204 .40755 L
.09305 .40842 L
.09394 .40927 L
.09468 .41002 L
.0953 .41065 L
.09578 .41113 L
.09613 .41146 L
.09635 .41166 L
.09645 .41176 L
.09646 .41182 L
.09641 .41184 L
.09633 .41182 L
.09625 .41173 L
.09617 .41157 L
.09612 .41135 L
.09611 .41108 L
.09611 .41077 L
.09612 .41045 L
.09613 .41011 L
.09614 .40975 L
.09615 .4094 L
.09616 .40906 L
.09617 .40871 L
.09618 .40837 L
.09619 .40802 L
.0962 .40769 L
.09621 .40737 L
.09622 .40711 L
.09623 .40695 L
.09623 .40689 L
.09623 .40692 L
.09623 .407 L
.09622 .40708 L
.09622 .40713 L
.09622 .40714 L
.09622 .4071 L
Mistroke
.09622 .40705 L
.09622 .40704 L
.09622 .40707 L
.09622 .40712 L
.09619 .40719 L
.09611 .40726 L
.09596 .40735 L
.09576 .40745 L
.09555 .40757 L
.09535 .40771 L
.0952 .40787 L
.09514 .40806 L
.09527 .40832 L
.09567 .40866 L
.09644 .40912 L
.09764 .40972 L
.09936 .41041 L
.10157 .41125 L
.10437 .41222 L
.10771 .41335 L
.11175 .41463 L
.11628 .41611 L
.12195 .41772 L
.12707 .41945 L
.13317 .42124 L
.13965 .42295 L
.14675 .42453 L
.15294 .42593 L
.15933 .42707 L
.16666 .42797 L
.172 .42853 L
.17784 .42869 L
.18351 .42841 L
.18899 .42763 L
.19321 .42633 L
.19753 .42438 L
.20135 .42164 L
.20497 .4185 L
.20836 .41436 L
.21156 .40987 L
.21462 .40436 L
.2179 .39853 L
.22112 .39142 L
.22422 .38537 L
.22749 .37824 L
.23095 .37018 L
.23435 .36308 L
.23798 .35474 L
.2413 .34834 L
.24479 .34084 L
Mistroke
.24813 .3341 L
.2514 .32806 L
.25469 .32212 L
.25776 .31701 L
.26086 .31229 L
.26409 .30806 L
.26712 .30433 L
.27042 .30083 L
.27393 .29773 L
.27759 .29488 L
.28167 .29227 L
.28571 .28984 L
.29009 .28783 L
.29441 .28595 L
.29901 .28431 L
.30375 .28291 L
.30869 .28178 L
.31365 .28096 L
.31852 .28052 L
.32321 .28048 L
.32791 .28082 L
.33208 .28151 L
.33596 .28249 L
.33957 .28367 L
.34244 .285 L
.34497 .28637 L
.34705 .28764 L
.34869 .28893 L
.34989 .29003 L
.35073 .29104 L
.35123 .29193 L
.35148 .29265 L
.35155 .29317 L
.35151 .29348 L
.35142 .29361 L
.35135 .29361 L
.35134 .29351 L
.35141 .29337 L
.35154 .29323 L
.35174 .29311 L
.35201 .29299 L
.3523 .29288 L
.35259 .29276 L
.35286 .29266 L
.35308 .29263 L
.35322 .29271 L
.35328 .29292 L
.35325 .29326 L
.35313 .29376 L
.35294 .29443 L
Mistroke
.35269 .29526 L
.3524 .29624 L
.35211 .29735 L
.35183 .29859 L
.35158 .30001 L
.35137 .30164 L
.3512 .30335 L
.35109 .30519 L
.35104 .30715 L
.35104 .30914 L
.35107 .31119 L
.35116 .31336 L
.35128 .31552 L
.35139 .31782 L
.35143 .32021 L
.35134 .3226 L
.35109 .32518 L
.35063 .32773 L
.34995 .33042 L
.34904 .333 L
.34794 .3357 L
.3467 .33819 L
.34537 .34073 L
.34403 .34328 L
.34286 .34567 L
.34184 .34797 L
.34099 .3504 L
.34041 .35302 L
.34021 .35551 L
.34047 .35822 L
.34121 .36102 L
.34245 .36406 L
.34409 .36716 L
.34613 .37069 L
.34841 .37411 L
.35096 .37765 L
.35368 .38158 L
.35638 .38561 L
.35913 .38986 L
.36189 .39454 L
.36458 .39871 L
.36723 .40323 L
.36982 .40779 L
.37237 .41242 L
.37485 .41717 L
.3773 .42184 L
.37976 .4265 L
.38222 .43114 L
.38478 .43564 L
.38731 .44006 L
Mistroke
.38987 .44426 L
.39244 .44835 L
.39496 .45197 L
.3975 .45538 L
.4001 .45861 L
.40273 .4614 L
.40545 .46408 L
.40828 .46659 L
.41127 .46904 L
.41428 .47142 L
.4175 .47389 L
.42089 .47648 L
.42445 .47927 L
.4283 .48234 L
.43255 .48584 L
.43724 .48972 L
.44217 .49379 L
.44757 .49834 L
.45341 .50319 L
.45958 .50816 L
.46625 .51325 L
.47295 .51834 L
.48037 .52398 L
.48813 .5292 L
.4953 .53408 L
.50365 .53947 L
.51202 .54477 L
.5212 .55013 L
.5302 .55542 L
.53866 .5607 L
.54728 .56588 L
.5562 .57163 L
.5652 .57691 L
.57378 .58299 L
.58234 .58861 L
.59134 .5952 L
.59973 .60149 L
.60765 .60776 L
.61602 .6145 L
.6232 .62084 L
.63051 .62749 L
.6381 .63459 L
.64436 .64098 L
.6509 .64775 L
.65718 .65464 L
.66333 .66205 L
.66904 .66893 L
.67461 .67627 L
.67997 .68402 L
.68496 .69108 L
Mistroke
.68984 .69869 L
.69453 .70608 L
.69918 .71391 L
.70357 .72104 L
.70801 .72826 L
.71255 .7355 L
.71718 .7429 L
.72196 .74882 L
.72712 .75516 L
.73219 .76111 L
.73821 .76695 L
.7439 .77192 L
.74962 .77648 L
.75593 .78068 L
.76257 .78446 L
.7695 .78791 L
.77645 .79105 L
.78354 .79387 L
.79074 .7963 L
.79808 .79839 L
.80532 .80006 L
.8133 .80125 L
.81962 .80194 L
.82635 .80222 L
.83324 .80213 L
.83864 .80175 L
.84412 .80111 L
.84899 .80027 L
.85343 .79931 L
.85679 .79825 L
.85959 .79713 L
.86171 .79598 L
.8632 .79491 L
.86412 .79394 L
.86452 .79317 L
.86457 .79266 L
.86442 .79242 L
.86415 .79241 L
.86388 .79254 L
.86365 .79272 L
.86354 .79286 L
.86361 .79286 L
.86389 .79261 L
.86439 .79204 L
.86512 .79112 L
.86606 .78985 L
.86719 .78827 L
.8685 .78632 L
.86995 .78418 L
.87144 .78175 L
Mistroke
.87296 .77919 L
.87443 .7766 L
.87579 .7741 L
.87702 .77161 L
.87804 .76951 L
.87887 .76759 L
.87948 .76588 L
.87989 .76437 L
.88014 .76306 L
.88026 .76183 L
.88032 .7606 L
.88038 .75924 L
.88049 .75768 L
.88073 .75597 L
.88115 .75393 L
.88175 .75152 L
.8826 .74868 L
.88368 .74539 L
.88496 .74159 L
.88645 .73761 L
.8881 .73324 L
.88989 .72864 L
.89178 .72385 L
.89375 .71892 L
.8957 .71398 L
.89768 .70903 L
.89959 .70389 L
.90147 .69918 L
.9033 .69382 L
.90503 .68934 L
.9067 .6845 L
.90827 .67989 L
.90977 .67532 L
.9112 .67099 L
.91258 .66656 L
.91395 .66204 L
.91533 .65747 L
.91676 .65259 L
.91825 .6472 L
.91978 .64205 L
.92136 .6365 L
.923 .63039 L
.92465 .62496 L
.92626 .61904 L
.92787 .61297 L
.92941 .60745 L
.93091 .60183 L
.93241 .59633 L
.93369 .59129 L
.93495 .58664 L
Mistroke
.93609 .58229 L
.93713 .57844 L
.93803 .57506 L
.93883 .5721 L
.93951 .56955 L
.94008 .56747 L
.9406 .56572 L
.94105 .56426 L
.94145 .5631 L
.94177 .56223 L
.94202 .56161 L
.94217 .56125 L
.9422 .56114 L
.94211 .56124 L
.9419 .56149 L
.94159 .56183 L
.94119 .56222 L
.94075 .56261 L
.9403 .56296 L
.93986 .56325 L
.93944 .56351 L
.93904 .56376 L
.93867 .56398 L
.93835 .56419 L
.93808 .56437 L
.9379 .56451 L
.9378 .56461 L
.93777 .56464 L
.93779 .56461 L
.93784 .56453 L
.93791 .56441 L
.93794 .56428 L
.93794 .56418 L
.93791 .5641 L
.93787 .56403 L
.93785 .56392 L
.93785 .56379 L
.93786 .56362 L
.93791 .56338 L
.93798 .56301 L
.93811 .56248 L
.93828 .56173 L
.93849 .56074 L
.93875 .55945 L
.93903 .55784 L
.93933 .5558 L
.93964 .55338 L
.93994 .55049 L
.94021 .54718 L
.94045 .54358 L
Mistroke
.94066 .53953 L
.94081 .53539 L
.9409 .53096 L
.94092 .52635 L
.94086 .52155 L
.94073 .51648 L
.94053 .51177 L
.94028 .50675 L
.93998 .5016 L
.93962 .49659 L
.93921 .49148 L
.93875 .48594 L
.93825 .48017 L
.93772 .4751 L
.93717 .46962 L
.9366 .46352 L
.93606 .45825 L
.93556 .45232 L
.9351 .44676 L
.93468 .44078 L
.93428 .43444 L
.93389 .42888 L
.93348 .42354 L
.93305 .41759 L
.93257 .41146 L
.93202 .40464 L
.93143 .39846 L
.93078 .39186 L
.93012 .38511 L
.9294 .37801 L
.92866 .37188 L
.92792 .3657 L
.92719 .35954 L
.92649 .35435 L
.92583 .34942 L
.92525 .345 L
.92474 .34152 L
.92431 .33861 L
.92396 .33642 L
.92369 .33486 L
.92349 .33384 L
.92334 .33326 L
.92321 .333 L
.92305 .33287 L
.92285 .33271 L
.92256 .33242 L
.92215 .33189 L
.92158 .33107 L
.92085 .32991 L
.91996 .32838 L
Mistroke
.91904 .32661 L
.91795 .32454 L
.91689 .32227 L
.91569 .31981 L
.91458 .31718 L
.91345 .31447 L
.91236 .31176 L
.91135 .30914 L
.91053 .30677 L
.9098 .30465 L
.90918 .30286 L
.90864 .30137 L
.90819 .30006 L
.9077 .29886 L
.90712 .29764 L
.90638 .29631 L
.90545 .29475 L
.90428 .29285 L
.90295 .29068 L
.90132 .28809 L
.89945 .28499 L
.89731 .28167 L
.89493 .2779 L
.89237 .27402 L
.88956 .26968 L
.88679 .26516 L
.88379 .2604 L
.88062 .25577 L
.87759 .25106 L
.87436 .24629 L
.87108 .24176 L
.86817 .23741 L
.86492 .2329 L
.86176 .22838 L
.85834 .22365 L
.85506 .21898 L
.85189 .21424 L
.84853 .2093 L
.8449 .20392 L
.84173 .19927 L
.83822 .19419 L
.83446 .18881 L
.83124 .184 L
.82765 .17894 L
.8239 .17381 L
.82085 .16939 L
.81767 .16498 L
.8147 .16104 L
.81206 .15755 L
.80967 .15445 L
Mistroke
.8077 .15191 L
.80592 .14973 L
.80462 .14809 L
.80354 .14678 L
.80272 .1458 L
.80214 .14514 L
.8018 .14475 L
.80167 .14461 L
.80171 .14467 L
.80186 .14484 L
.80206 .14503 L
.80224 .14521 L
.80236 .14535 L
.80236 .14542 L
.80224 .14539 L
.80199 .14528 L
.80166 .1451 L
.80127 .14486 L
.80085 .14456 L
.80041 .14422 L
.79996 .14385 L
.79952 .14348 L
.79909 .14311 L
.79869 .14276 L
.79834 .14245 L
.79806 .14216 L
.79786 .14192 L
.79775 .14172 L
.79771 .14156 L
.79773 .14145 L
.7978 .14136 L
.79787 .14131 L
.79792 .14129 L
.79795 .14131 L
.79795 .14135 L
.79795 .14141 L
.79795 .14144 L
.79795 .14138 L
.79795 .14124 L
.79795 .14102 L
.79795 .14072 L
.79797 .14034 L
.798 .1399 L
.79802 .13943 L
.79803 .13896 L
.79802 .13855 L
.79796 .13822 L
.79787 .138 L
.79775 .13793 L
.79759 .13797 L
Mistroke
.7974 .13811 L
.79719 .13831 L
.79697 .13854 L
.79675 .13878 L
.79654 .13899 L
.79636 .13916 L
.79623 .13926 L
.79614 .13924 L
.79605 .1391 L
.79595 .13886 L
.79585 .13853 L
.79575 .13815 L
.79562 .13775 L
.79546 .13737 L
.79524 .13707 L
.79494 .13688 L
.79454 .1368 L
.79399 .13677 L
.79342 .13675 L
.79266 .13668 L
.79173 .13654 L
.79061 .13628 L
.7893 .13589 L
.78781 .13536 L
.78635 .13475 L
.78474 .13399 L
.78298 .13313 L
.78142 .13221 L
.77987 .13133 L
.77825 .13043 L
.77697 .12953 L
.77575 .12866 L
.77456 .12788 L
.77356 .12721 L
.77266 .12665 L
.77187 .12617 L
.77113 .12575 L
.77036 .12539 L
.7695 .12505 L
.76853 .12471 L
.76754 .12434 L
.76644 .1239 L
.76507 .12339 L
.76336 .12279 L
.76152 .12209 L
.75972 .12127 L
.75769 .12042 L
.75561 .11952 L
.75343 .11859 L
.75168 .11764 L
Mistroke
.74967 .11671 L
.74811 .11587 L
.7466 .11507 L
.74518 .11434 L
.74396 .11371 L
.74301 .11321 L
.74226 .11282 L
.74173 .11254 L
.74137 .11233 L
.74117 .11217 L
.7411 .11206 L
.74113 .11197 L
.74121 .11191 L
.74128 .11188 L
.74136 .11191 L
.74144 .11204 L
.7415 .11227 L
.74154 .11261 L
.74155 .11304 L
.74155 .11357 L
.74156 .11417 L
.74155 .11475 L
.74153 .1154 L
.74149 .11607 L
.74143 .11667 L
.74136 .11726 L
.74131 .11781 L
.7413 .11828 L
.74135 .11864 L
.74147 .11889 L
.74168 .11901 L
.74201 .11902 L
.74244 .11895 L
.74297 .11882 L
.74359 .11869 L
.74433 .1186 L
.7452 .11858 L
.74624 .11864 L
.74736 .11878 L
.74864 .11899 L
.75003 .11926 L
.75154 .11961 L
.75313 .12005 L
.7549 .12059 L
.75665 .12123 L
.75858 .12193 L
.76042 .12272 L
.76246 .1236 L
.76457 .12453 L
.76663 .12542 L
Mistroke
.76868 .1263 L
.77056 .12712 L
.7723 .12785 L
.77376 .12846 L
.77508 .12899 L
.77623 .12944 L
.77713 .12981 L
.77787 .13009 L
.77847 .13028 L
.77894 .13036 L
.77928 .13037 L
.77953 .13033 L
.7797 .13026 L
.77983 .13019 L
.77993 .13014 L
.78006 .13012 L
.7802 .13011 L
.78035 .13012 L
.7805 .13012 L
.78063 .13012 L
.78072 .13012 L
.78077 .13012 L
.78077 .1301 L
.78072 .13005 L
.78065 .12999 L
.78058 .12992 L
.78053 .12989 L
.7805 .12991 L
.78051 .13 L
.78057 .13016 L
.78069 .13042 L
.78087 .13075 L
.78111 .13114 L
.78142 .13156 L
.78177 .13201 L
.78216 .13244 L
.78258 .13287 L
.78301 .1333 L
.78343 .1337 L
.78383 .13406 L
.7842 .13435 L
.78451 .13455 L
.78477 .13466 L
.78496 .1347 L
.78508 .13468 L
.78515 .13462 L
.78517 .13455 L
.78515 .1345 L
.78513 .13447 L
.78509 .13447 L
Mistroke
.78506 .13447 L
.78503 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78499 .13447 L
.78495 .13445 L
.78488 .13443 L
.78481 .13439 L
.78474 .13436 L
.78469 .13434 L
.7847 .13435 L
.78479 .1344 L
.78498 .13449 L
.78528 .13462 L
.78571 .13479 L
.78626 .13499 L
.78694 .13521 L
.78769 .13544 L
.78857 .13568 L
.78952 .13592 L
.79053 .13615 L
.79153 .13636 L
.79248 .13655 L
.79332 .1367 L
.79403 .13681 L
.79458 .13688 L
.79495 .1369 L
.79516 .13689 L
.79521 .13686 L
.79514 .13682 L
.79497 .13679 L
.79474 .13677 L
.79448 .13677 L
.79421 .13677 L
.79398 .13679 L
.7938 .13683 L
.79371 .13686 L
.79371 .13687 L
.7938 .13686 L
.79397 .13682 L
.79419 .13674 L
.79444 .13662 L
.7947 .13646 L
.79495 .13627 L
.79517 .13607 L
.79537 .13585 L
Mistroke
.79554 .13563 L
.79568 .13541 L
.79577 .1352 L
.79582 .135 L
.79585 .13483 L
.7959 .1347 L
.79597 .1346 L
.79602 .13455 L
.79604 .13453 L
.79599 .13455 L
.79586 .13457 L
.79562 .13461 L
.79525 .13463 L
.79476 .13463 L
.79418 .13463 L
.79355 .13461 L
.7929 .1346 L
.79227 .13459 L
.79166 .13458 L
.79104 .13457 L
.79044 .13456 L
.7899 .13455 L
.78947 .13454 L
.78918 .13454 L
.78905 .13453 L
.78904 .13453 L
.78914 .13454 L
.78928 .13454 L
.7894 .13454 L
.78945 .13454 L
.78937 .13454 L
.78916 .13454 L
.78887 .13453 L
.78849 .13453 L
.78809 .13452 L
.78768 .13451 L
.78731 .13451 L
.78699 .1345 L
.78676 .13438 L
.78657 .13438 L
.78642 .13437 L
.78638 .13436 L
.78647 .13435 L
.78678 .13434 L
.78726 .13435 L
.78795 .13438 L
.7887 .13443 L
.78958 .13448 L
.79055 .13453 L
.79154 .13459 L
Mistroke
.79234 .13468 L
.79311 .13481 L
.79388 .13504 L
.79473 .13538 L
.79544 .13587 L
.79617 .1365 L
.79693 .13731 L
.79773 .13829 L
.79857 .13944 L
.79947 .14064 L
.80035 .14206 L
.80145 .14367 L
.80274 .14537 L
.80395 .14728 L
.80541 .14943 L
.80683 .15151 L
.80845 .15383 L
.8102 .15602 L
.81182 .15825 L
.81331 .16051 L
.81477 .16256 L
.81619 .16471 L
.81753 .16674 L
.81861 .16858 L
.81963 .17035 L
.82054 .17189 L
.82131 .17317 L
.82189 .17417 L
.82239 .17489 L
.82278 .17534 L
.82308 .17558 L
.8233 .17564 L
.82347 .17555 L
.82362 .17535 L
.82372 .17503 L
.82379 .17461 L
.82385 .17414 L
.8239 .17369 L
.82399 .17333 L
.82412 .1731 L
.82434 .17303 L
.82463 .17311 L
.825 .17337 L
.82542 .17375 L
.82589 .17416 L
.8264 .17473 L
.82694 .17538 L
.82749 .17615 L
.82803 .1769 L
.82855 .17779 L
Mistroke
.82901 .1787 L
.8294 .17956 L
.82973 .1804 L
.83001 .1812 L
.83026 .18194 L
.83048 .18263 L
.8307 .18331 L
.83093 .184 L
.83116 .18469 L
.8314 .18537 L
.83161 .18602 L
.8318 .18659 L
.83194 .18704 L
.83204 .18741 L
.8321 .18768 L
.83209 .18785 L
.83204 .18789 L
.83194 .18778 L
.83182 .18751 L
.83169 .1871 L
.83156 .18668 L
.83145 .18622 L
.83137 .1858 L
.83134 .18541 L
.83138 .18513 L
.83149 .185 L
.83165 .18498 L
.83185 .18504 L
.83207 .18522 L
.83229 .18558 L
.83247 .18609 L
.83262 .18677 L
.83273 .18762 L
.8328 .18865 L
.83287 .18986 L
.83294 .19125 L
.83303 .19279 L
.83316 .19438 L
.83334 .19589 L
.83358 .19738 L
.83389 .19902 L
.83424 .20084 L
.83462 .20285 L
.83502 .2046 L
.83542 .20634 L
.83581 .20798 L
.83617 .2095 L
.83652 .21099 L
.83686 .21244 L
.8372 .21376 L
Mistroke
.83752 .21506 L
.83782 .21643 L
.83809 .21784 L
.83832 .21922 L
.8385 .22061 L
.83863 .22206 L
.8387 .22344 L
.83873 .22476 L
.83873 .22602 L
.83871 .22718 L
.83868 .2282 L
.83862 .22906 L
.83853 .22982 L
.83842 .23045 L
.83829 .23094 L
.83816 .23129 L
.83804 .23149 L
.83796 .23158 L
.83792 .23159 L
.83792 .23153 L
.83795 .23144 L
.83798 .23133 L
.83801 .23124 L
.83802 .23121 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .23122 L
.83802 .23125 L
.83802 .2313 L
.83802 .23133 L
.83802 .23132 L
.83802 .23125 L
.83802 .23115 L
.83801 .23102 L
.838 .23087 L
.83799 .23073 L
.83796 .2306 L
.83792 .23051 L
.83788 .23045 L
.83787 .23041 L
.83788 .23041 L
.83792 .23041 L
Mistroke
.83801 .23042 L
.83814 .23047 L
.8383 .23056 L
.83849 .23068 L
.83871 .23084 L
.83893 .23099 L
.83915 .23114 L
.83937 .23125 L
.83959 .23133 L
.83979 .23135 L
.83996 .23132 L
.84009 .23127 L
.84018 .23123 L
.84024 .23122 L
.84025 .23121 L
.84024 .23121 L
.84021 .23121 L
.84017 .23121 L
.84015 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84014 .23118 L
.84017 .23112 L
.8402 .23102 L
.84023 .23093 L
.84024 .23089 L
.84023 .23092 L
.84019 .23105 L
.84011 .23129 L
.84 .23166 L
.83985 .23215 L
.83967 .23273 L
.83948 .23336 L
.83928 .23401 L
.83908 .23465 L
.83888 .23527 L
.83868 .23588 L
.8385 .23648 L
.83834 .23702 L
.83821 .23744 L
.83813 .23773 L
.83808 .2379 L
.83806 .23795 L
.83807 .23792 L
.8381 .23783 L
Mistroke
.83813 .23773 L
.83816 .23765 L
.83817 .23762 L
.83817 .23762 L
.83817 .23762 L
.83817 .23761 L
.83817 .2376 L
.83817 .23756 L
.83817 .2375 L
.83817 .23746 L
.83817 .23745 L
.83817 .2375 L
.83818 .23761 L
.83818 .23778 L
.83819 .23799 L
.83819 .23822 L
.8382 .23844 L
.83821 .23863 L
.83821 .23877 L
.83822 .23886 L
.83822 .2389 L
.8382 .23892 L
.83818 .23891 L
.83814 .23884 L
.83811 .23876 L
.83809 .2386 L
.83809 .23837 L
.83813 .2381 L
.83822 .23785 L
.83836 .23764 L
.83856 .23751 L
.83878 .23746 L
.83901 .2375 L
.83922 .23761 L
.8394 .23773 L
.83954 .23782 L
.83963 .2379 L
.83967 .23795 L
.83965 .23797 L
.83958 .23798 L
.83946 .23798 L
.83929 .23798 L
.83909 .23796 L
.83886 .23793 L
.83863 .23788 L
.83841 .23782 L
.83824 .23774 L
.83813 .23767 L
.83807 .23762 L
.83805 .23757 L
Mistroke
.83806 .23755 L
.83809 .23753 L
.83813 .2375 L
.83815 .23745 L
.83817 .2374 L
.83818 .23735 L
.83821 .23733 L
.83824 .23736 L
.83827 .23748 L
.8383 .23771 L
.83829 .23806 L
.83826 .23853 L
.83819 .23913 L
.83808 .23982 L
.83794 .24056 L
.83777 .24135 L
.83758 .24218 L
.83738 .24301 L
.83719 .2438 L
.83699 .2445 L
.83679 .24511 L
.83661 .24562 L
.83644 .246 L
.83631 .24627 L
.83622 .24641 L
.83617 .24646 L
.83615 .24645 L
.83616 .2464 L
.83619 .24634 L
.83623 .24626 L
.83625 .2462 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
Mistroke
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24616 L
.8363 .24615 L
.83636 .24613 L
.83643 .24609 L
.83648 .24606 L
.83651 .24602 L
.83651 .24598 L
.83646 .24596 L
.8363 .24599 L
.83601 .24608 L
.83564 .24626 L
.83519 .24653 L
.83465 .24691 L
.83405 .24737 L
.83348 .24791 L
.8329 .2485 L
.83231 .24913 L
.83173 .24976 L
.83115 .25038 L
.83072 .25095 L
.83036 .25147 L
.83008 .25193 L
.82988 .25231 L
.82978 .25258 L
.82976 .25275 L
.8298 .25283 L
Mistroke
.82986 .25284 L
.82992 .25281 L
.82998 .25274 L
.83004 .25267 L
.83009 .25261 L
.8301 .25258 L
.83008 .25258 L
.83007 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83007 .25258 L
.8301 .25258 L
.83019 .25258 L
.83028 .25258 L
.83032 .25258 L
.8303 .25258 L
.8302 .25258 L
.82998 .25258 L
.82963 .25258 L
.82912 .25258 L
.82852 .25258 L
.82787 .25257 L
.82724 .25257 L
.82665 .25257 L
.82609 .25257 L
.82551 .25256 L
.82491 .25254 L
.82434 .25252 L
.82388 .25249 L
.82358 .25246 L
.82339 .25242 L
Mistroke
.8233 .25241 L
.82329 .25244 L
.82337 .25252 L
.8235 .25267 L
.82363 .2529 L
.82376 .25319 L
.82394 .25354 L
.82416 .25396 L
.82436 .25435 L
.82459 .25474 L
.82482 .25508 L
.82505 .25541 L
.82528 .25576 L
.8255 .25616 L
.82569 .25658 L
.82585 .25702 L
.82597 .25746 L
.82605 .25789 L
.82608 .25828 L
.82608 .25861 L
.82606 .25887 L
.82602 .25909 L
.826 .25926 L
.82599 .25944 L
.82599 .25962 L
.826 .25979 L
.82599 .25985 L
.82599 .25981 L
.82598 .25967 L
.82598 .25948 L
.82597 .25928 L
.82596 .25908 L
.82596 .25893 L
.82596 .25886 L
.82596 .25888 L
.82596 .25896 L
.82596 .25903 L
.82597 .25908 L
.82597 .2591 L
.82597 .25911 L
.82597 .25911 L
.82596 .25911 L
.82593 .25911 L
.82589 .25908 L
.82586 .25902 L
.82584 .25893 L
.82583 .25885 L
.82585 .25877 L
.82589 .25872 L
.82597 .25873 L
Mistroke
.82609 .25882 L
.82626 .25901 L
.82649 .25931 L
.82678 .25974 L
.82711 .26027 L
.82748 .26093 L
.8279 .26167 L
.82836 .2625 L
.82886 .26344 L
.8294 .26447 L
.82996 .26557 L
.83058 .26667 L
.83129 .26782 L
.83203 .26898 L
.83291 .27011 L
.83394 .27124 L
.83504 .27234 L
.83633 .27342 L
.83779 .27454 L
.83936 .27571 L
.8411 .27684 L
.84301 .27794 L
.84525 .27904 L
.84722 .28009 L
.84981 .28106 L
.85195 .28196 L
.85416 .28274 L
.85655 .28343 L
.85899 .28402 L
.86134 .28449 L
.86374 .2848 L
.86612 .28496 L
.86847 .28499 L
.871 .2849 L
.87311 .28467 L
.87534 .28443 L
.87769 .2842 L
.87941 .28401 L
.88125 .28387 L
.88294 .2838 L
.88422 .28378 L
.88534 .28379 L
.88634 .28381 L
.88716 .28389 L
.88779 .284 L
.88822 .28416 L
.8885 .28435 L
.88869 .28454 L
.88881 .28472 L
.88889 .28486 L
Mistroke
.88895 .28494 L
.88905 .28497 L
.88921 .28493 L
.8894 .28488 L
.88955 .28483 L
.88968 .28481 L
.88976 .28481 L
.88981 .28481 L
.88983 .28481 L
.88981 .28481 L
.88978 .28481 L
.88975 .28481 L
.88972 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28483 L
.88971 .28487 L
.88971 .28493 L
.88971 .28496 L
.88971 .28495 L
.88971 .28487 L
.8897 .28474 L
.8897 .28458 L
.88969 .2844 L
.88968 .28422 L
.88968 .28406 L
.88967 .28393 L
.88967 .28385 L
.88967 .2838 L
.88967 .28378 L
.88967 .28379 L
.88967 .28381 L
.88967 .28386 L
.88966 .28393 L
.88964 .28403 L
.88961 .28415 L
.88957 .28431 L
.88954 .2845 L
.88953 .28473 L
.88956 .28498 L
.88964 .28525 L
.88978 .28554 L
.88999 .28586 L
.89027 .28624 L
.8906 .28667 L
.89099 .28711 L
.89139 .28755 L
.89181 .28798 L
Mistroke
.89224 .28838 L
.89266 .28872 L
.89304 .289 L
.89339 .28919 L
.89368 .2893 L
.8939 .28934 L
.89406 .28933 L
.89416 .28932 L
.89421 .28932 L
.89421 .28932 L
.89417 .28933 L
.89409 .2893 L
.89399 .28921 L
.89388 .28903 L
.89376 .28878 L
.89366 .28845 L
.89357 .28807 L
.8935 .28763 L
.89347 .28713 L
.89346 .28662 L
.89347 .28612 L
.89345 .28566 L
.8934 .28527 L
.89333 .28498 L
.89323 .28482 L
.89312 .28479 L
.89301 .28486 L
.89293 .28502 L
.89288 .28529 L
.89289 .28567 L
.893 .28619 L
.8932 .28682 L
.89351 .28761 L
.89399 .28859 L
.89461 .28983 L
.89549 .2914 L
.89658 .29331 L
.89785 .29538 L
.89931 .29757 L
.90078 .29992 L
.90237 .30257 L
.9038 .30511 L
.90526 .30783 L
.90653 .31029 L
.90778 .31271 L
.90885 .31489 L
.9099 .31699 L
.91084 .31871 L
.91177 .3203 L
.91269 .32175 L
Mistroke
.91357 .32309 L
.91436 .3244 L
.91515 .32558 L
.91594 .32681 L
.91672 .32805 L
.91745 .32926 L
.91817 .33042 L
.91877 .33156 L
.91928 .33264 L
.91968 .33361 L
.91995 .33436 L
.92011 .33494 L
.92017 .3354 L
.92019 .33582 L
.92023 .33624 L
.92031 .33674 L
.92047 .33737 L
.92071 .33818 L
.92103 .33911 L
.92143 .34018 L
.92188 .34129 L
.92232 .34232 L
.92279 .34364 L
.92323 .34483 L
.92366 .34604 L
.92405 .34724 L
.92439 .34838 L
.92465 .34938 L
.92482 .35023 L
.92492 .3509 L
.92494 .35142 L
.92492 .3518 L
.92487 .35212 L
.92482 .3524 L
.92479 .35267 L
.92478 .35295 L
.92479 .35319 L
.9248 .35338 L
.9248 .35352 L
.92481 .35361 L
.92481 .35364 L
.92481 .35361 L
.9248 .35351 L
.9248 .35337 L
.92479 .35317 L
.92478 .35291 L
.92477 .35258 L
.92476 .35217 L
.92474 .3517 L
.92472 .35118 L
Mistroke
.92471 .35067 L
.92469 .35019 L
.92468 .34978 L
.92466 .34946 L
.92466 .34927 L
.92466 .34923 L
.92466 .34934 L
.92467 .34962 L
.9247 .34996 L
.92474 .35029 L
.92479 .35064 L
.92486 .35098 L
.92491 .35131 L
.92496 .35169 L
.92499 .35213 L
.92497 .35274 L
.92489 .35365 L
.92473 .35491 L
.92447 .35657 L
.92411 .35868 L
.92364 .36101 L
.9231 .36301 L
.92248 .36518 L
.92181 .36802 L
.92112 .37017 L
.92042 .37235 L
.91977 .37505 L
.91919 .37683 L
.91865 .37831 L
.91818 .37943 L
.91779 .3802 L
.91749 .38056 L
.91728 .38056 L
.91716 .38038 L
.9171 .38012 L
.91711 .37982 L
.9172 .37953 L
.91735 .37927 L
.91756 .379 L
.91781 .37872 L
.91811 .37841 L
.91846 .37805 L
.91884 .37764 L
.91922 .37721 L
.91962 .37676 L
.92003 .37631 L
.9204 .37587 L
.92075 .37547 L
.92106 .37512 L
.92131 .37484 L
Mistroke
.92149 .37464 L
.92159 .37453 L
.92164 .37449 L
.92163 .37452 L
.92158 .37459 L
.9215 .37466 L
.92143 .37472 L
.92137 .37474 L
.92134 .37475 L
.92135 .37475 L
.92139 .37475 L
.92147 .37475 L
.92159 .37475 L
.92175 .37475 L
.92193 .37474 L
.92213 .37474 L
.92234 .37474 L
.92255 .37474 L
.92276 .37473 L
.92296 .37473 L
.92315 .37473 L
.92332 .37473 L
.92345 .37473 L
.92354 .37473 L
.92359 .37473 L
.92361 .37472 L
.92361 .3747 L
.92361 .37465 L
.92364 .37458 L
.92367 .37452 L
.9237 .37448 L
.92371 .37449 L
.92368 .37457 L
.9236 .37472 L
.92347 .37491 L
.92327 .37514 L
.923 .3754 L
.92265 .3757 L
.92218 .37607 L
.92157 .37656 L
.9209 .37718 L
.92013 .37796 L
.91925 .37888 L
.91827 .37993 L
.91724 .38107 L
.91626 .38227 L
.91541 .38342 L
.91464 .38454 L
.9139 .38562 L
.91319 .38667 L
Mistroke
.91261 .38759 L
.91215 .38843 L
.91181 .38915 L
.9116 .38971 L
.91148 .39009 L
.91142 .39033 L
.91144 .39044 L
.91148 .39046 L
.91151 .39044 L
.91156 .39043 L
.91163 .39045 L
.91174 .39049 L
.91188 .39056 L
.91204 .39067 L
.91223 .39077 L
.91244 .39084 L
.91265 .39087 L
.91286 .39082 L
.91307 .39067 L
.91326 .39041 L
.91344 .39005 L
.91359 .38961 L
.91371 .3891 L
.91378 .38857 L
.91382 .38803 L
.91382 .38753 L
.91379 .38707 L
.91374 .38665 L
.91369 .38629 L
.91366 .38597 L
.91364 .38571 L
.91363 .38551 L
.91362 .3854 L
.91362 .38537 L
.91362 .3854 L
.91362 .38546 L
.91363 .38554 L
.91363 .3856 L
.91363 .38565 L
.91362 .38571 L
.91359 .38578 L
.91356 .38586 L
.91352 .38595 L
.91348 .38602 L
.91346 .38606 L
.91345 .38604 L
.91349 .38593 L
.91358 .38572 L
.91374 .38536 L
.91398 .38484 L
Mistroke
.9143 .38414 L
.91474 .38322 L
.91522 .38204 L
.91576 .38053 L
.91634 .37862 L
.91691 .37624 L
.91745 .37346 L
.91793 .37027 L
.91829 .36664 L
.91856 .36278 L
.91873 .35828 L
.91883 .35461 L
.91887 .35105 L
.91887 .34684 L
.91884 .34372 L
.9188 .34062 L
.91877 .33759 L
.91876 .33522 L
.91879 .33318 L
.91888 .3316 L
.919 .33046 L
.91915 .32968 L
.91933 .32919 L
.91952 .32892 L
.9197 .32878 L
.91984 .32864 L
.91993 .32844 L
.91997 .32815 L
.91998 .32784 L
.91995 .32754 L
.91991 .32726 L
.91987 .327 L
.91984 .3268 L
.91982 .32665 L
.91981 .32654 L
.91981 .32646 L
.91981 .32637 L
.9198 .32625 L
.9198 .32611 L
.91981 .32592 L
.91983 .32567 L
.91985 .32535 L
.91988 .32496 L
.91992 .3245 L
.91995 .32397 L
.91997 .32337 L
.91994 .32267 L
.91985 .32183 L
.91965 .3208 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{783, 144.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<?0000T1000`40O003h00Oogooogooogoo4Woo
003oOoooOoooOolBOol00?mooomooomooa9oo`00ogooogooogoo4Woo003oOoooOoooOolBOol00?mo
oomooomooa9oo`00Dgoo3000Rgoo3000Rgoo3000Rgoo3000Rgoo3000E7oo001=Ool6000<Ool7001n
Ool6000<Ool7001nOol6000<Ool6001nOol7000<Ool6001nOol7000<Ool6001>Ool004Qoo`D001Uo
o`D007Aoo`D001Uoo`@007Eoo`D001Qoo`D007Eoo`@001Uoo`D007Aoo`D001Uoo`D004Uoo`00AGoo
0`0017oo0P0000=oo`00Ool00goo00<007ooOol017oo00<007ooOol03Goo0`00KWoo0`0000=oo`00
000020005goo0`00Kgoo0`0000=oo`0000000P001Goo00<007ooOol017oo0P003goo0`00KWoo1000
00=oo`000000100000Aoo`00001oo`8000=oo`03001oogoo008000eoo`<006ioo`<000Aoo`<001ao
o`<004Ioo`00@goo0P000goo7P0027oo0`00J7oo0`000goo80001Goo1000J7oo0`000goo7`001Woo
0`00J7oo0`000goo8@001Goo0`00J7oo0`0017oo4@0000=oo`0000000`0000=oo`0000001@001Woo
0`00@goo0010Ool30004Ool7000:Ool20008Ool70008Ool2001TOol20005Ool20003Ool3000EOol6
0007Ool2001TOol20005Ool3000GOol80007Ool2001TOol20004Ool30002Ool90002Ool400000goo
0000000=0007Ool2001TOol20005Ool30006Ool2000@Ool300000goo000000020007Ool20011Ool0
03eoo`<000Eoo`@001ioo`D000Moo`<005ioo`<000Aoo`<000Ioo`8001Uoo`@000Moo`<005ioo`<0
00Aoo`<0021oo`D000Ioo`<005ioo`<000Eoo`8000Aoo`<000=oo`H00003Ool0000000@000Uoo`80
00Yoo`<005ioo`<000Eoo`<000Yoo`03001oogoo00aoo`8000Ioo`@000Ioo`<003ioo`00>goo0P00
1Woo1@008Goo1@0027oo0P00FWoo0P001Goo100027oo00<007ooOol06Woo0`0027oo00<007ooOol0
FGoo0P001Goo10009Goo1@001Goo0P00FWoo0P001Woo0P0017oo0`0027oo00<007ooOol00Woo00<0
07ooOol06Woo0P00FWoo0P001Goo1@0037oo0P002goo0P002Woo0`001goo0P00?7oo000iOol20006
Ool5000UOol60007Ool2001FOol20006Ool3000:Ool00`00Oomoo`0LOol40006Ool2001GOol20005
Ool4000YOol40006Ool2001GOol00`00Oomoo`04Ool20002Ool5000?Ool00`00Oomoo`0LOol2001F
Ool20006Ool4000?Ool20009Ool2000=Ool30007Ool2000jOol003Qoo`03001oogoo00=oo`L002Qo
o`H000Moo`03001oogoo059oo`03001oogoo00Aoo`<000]oo`03001oogoo021oo`<000Ioo`03001o
ogoo05=oo`03001oogoo00Aoo`8002ioo`8000Qoo`03001oogoo05=oo`03001oogoo00=oo`800003
Ool00000008001=oo`03001oogoo01ioo`03001oogoo059oo`03001oogoo00Aoo`<001Aoo`@000=o
o`80019oo`<000Ioo`03001oogoo03Moo`00=goo00<007ooOol00goo1P00;7oo1P001Woo00<007oo
Ool0Cgoo0P001Goo0`002goo0P0097oo1P000goo0P00DGoo0P001Goo0`00<Goo0`001Woo0P00DGoo
0P0017oo0`0000=oo`0000005Woo00<007ooOol05goo0`001Goo0P00DGoo00<007ooOol00goo0`00
6Woo10005Goo0`001Goo00<007ooOol0=Woo000fOol00`00Oomoo`02Ool500000goo001oo`0^Ool7
0004Ool00`00Oomoo`1=Ool00`00Oomoo`03Ool4000;Ool2000WOol60003Ool00`00Oomoo`1=Ool0
0`00Oomoo`03Ool3000fOol20006Ool00`00Oomoo`1=Ool00`00Oomoo`02Ool30004Ool00`00Oomo
o`0DOol2000GOol200000goo000000020004Ool00`00Oomoo`1=Ool00`00Oomoo`02Ool3000gOol3
0004Ool00`00Oomoo`0eOol003Aoo`8000=oo`@000=oo`80031oo`8000=oo`<000=oo`8004aoo`03
001oogoo009oo`@000aoo`8002Yoo`H0009oo`8004]oo`8000Aoo`<003Yoo`8000Eoo`8004]oo`80
00=oo`<000Ioo`03001oogoo01Eoo`03001oogoo01Aoo`8000Ioo`8000=oo`03001oogoo04Yoo`80
00Aoo`8003aoo`<0009oo`8003Eoo`00<goo00<007ooOol00Woo10000goo0P00<goo0P0017oo0`00
0Woo00<007ooOol0B7oo00<007ooOol00Woo0P003Woo00<007ooOol0;7oo1P000Woo00<007ooOol0
Agoo00<007ooOol00Woo0`00?Woo0P001Goo00<007ooOol0Agoo00<007ooOol00Woo0P001goo00<0
07ooOol05Woo00<007ooOol04goo0P002Goo0P000Woo00<007ooOol0B7oo00<007ooOol00Woo0P00
@7oo0`000Woo00<007ooOol0<Woo000aOol20003Ool30006Ool00`00Oomoo`0cOol20005Ool60016
Ool20003Ool2000?Ool00`00Oomoo`0_Ool600000goo001oo`16Ool00`00Oomoo`040012Ool30003
Ool00`00Oomoo`15Ool01000Oomoogoo0`0027oo00<007ooOol05goo00<007ooOol04Goo0P0037oo
0P0000=oo`000000AWoo0P000goo0`00@goo1P00<Woo000`Ool01000Oomoogoo0`001goo0P00=Woo
2`0000=oo`00Ool0@goo00<007oo000010003goo00<007ooOol0<Goo0P0000=oo`0000000`00AGoo
00<007ooOol00`00Agoo0`0000=oo`00Ool0A7oo00<007ooOol00`002Woo00<007ooOol05goo0P00
47oo0`003goo1000A7oo00@007ooOomoo`<004Moo`D0035oo`00;goo00<007ooOol010001goo0P00
@Goo1000@Goo0P000Woo0`0047oo0P00<goo0P000Woo00<007oo00000`00@Goo0P000Woo0`00Bgoo
1000@Goo0P0000=oo`0000001@001goo0P006Woo0P002goo1@004goo0`00@Woo00@007ooOomoo`80
04]oo`@0031oo`00;Woo00<007ooOol0100027oo00<007ooOol0@Goo1000?goo00<007ooOol00`00
4Woo00<007ooOol0<Goo0P000goo0P0000=oo`0000000P00?goo00@007ooOomoo`<004eoo`800003
Ool007oo03ioo`03001oogoo00<000Aoo`8000Eoo`8001eoo`/001Uoo`03001oo`00041oo`04001o
ogooOol2001>Ool3000_Ool002aoo`8000=oo`<000Qoo`8004Aoo`800003Ool007oo03aoo`04001o
ogooOol2000BOol00`00Oomoo`0aOol20005Ool200001Goo000007oo0000?Goo00@007ooOomoo`80
051oo`800003Ool007oo03aoo`04001oogooOol20006Ool20002Ool30012Ool200000goo0000000l
Ool20004Ool2001?Ool4000]Ool002]oo`03001oogoo009oo`8000Yoo`03001oogoo04Aoo`800003
Ool007oo03Yoo`04001oogooOol2000COol00`00Oomoo`0`Ool00`00Oomoo`06Ool200001Goo0000
07oo0000>goo00@007ooOomoo`<0055oo`800003Ool007oo03Yoo`04001oogooOol20008Ool40015
Ool01@00Oomoogoo0000>Woo00<007ooOol00goo00<007oo0000D7oo00@007ooOol002aoo`00:Woo
00<007ooOol00Woo0P002Woo00<007ooOol0AWoo0P0000=oo`000000>7oo00<007ooOol00Woo0P00
4Woo00<007ooOol0<7oo00<007ooOol027oo1@0000=oo`000000>7oo00<007ooOol00Woo0P00Dgoo
00@007ooOol003Qoo`8000=oo`80059oo`8000=oo`03001oogoo03Ioo`03001oogoo00=oo`04001o
ogoo001@Ool20002Ool00`00Oomoo`0YOol002Uoo`03001oogoo009oo`<000Yoo`03001oogoo04Mo
o`80009oo`03001oogoo03Aoo`03001oogoo009oo`8001=oo`03001oogoo02moo`03001oogoo00Yo
o`04001oo`000003Ool00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Oomoo`1DOol01000Oomoo`00
=Woo00<007ooOol00goo0P00Dgoo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00goo00D0
07ooOomoo`00055oo`80009oo`03001oogoo02Qoo`00:7oo00<007ooOol00Woo0`002Woo00<007oo
Ool0BGoo00D007ooOomoo`0003Aoo`03001oogoo009oo`8001=oo`03001oogoo02moo`8000eoo`@0
00=oo`03001oogoo039oo`03001oogoo009oo`8005Ioo`80009oo`03001oogoo039oo`03001oogoo
00=oo`8005Eoo`8000=oo`03001oogoo039oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
051oo`80009oo`03001oogoo02Moo`00:7oo00<007ooOol00Woo0P002goo00<007ooOol0BGoo0P00
0Woo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol04Goo0P00<Goo00<007ooOol03Goo1000
0Woo00<007ooOol0<Goo00<007ooOol00goo00<007ooOol0EWoo00@007ooOol003Aoo`03001oogoo
009oo`<005Ioo`05001oogooOol0000dOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1@
Ool20002Ool00`00Oomoo`0WOol002Moo`03001oogoo009oo`8000]oo`03001oogoo04]oo`80009o
o`03001oogoo031oo`03001oogoo009oo`80019oo`80035oo`03001oogoo00moo`@0009oo`03001o
ogoo02moo`03001oogoo00=oo`03001oogoo05Qoo`04001oogoo000bOol00`00Oomoo`03Ool3001G
Ool20002Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1AOol20002
Ool00`00Oomoo`0VOol002Ioo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo04]oo`8000=o
o`03001oogoo02ioo`03001oogoo009oo`80019oo`80039oo`03001oogoo011oo`<000=oo`03001o
ogoo02eoo`03001oogoo00=oo`8005]oo`03001oogoo008002moo`03001oogoo00=oo`<005Uoo`80
009oo`03001oogoo02ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo055oo`8000=oo`03
001oogoo02Eoo`009Goo00<007ooOol00goo0P0037oo00<007ooOol0C7oo0P000goo00<007ooOol0
;7oo00<007ooOol00goo0P004Goo0P00<goo00<007ooOol03goo0`0000=oo`00Ool00Woo00<007oo
Ool0:goo00<007ooOol00goo0P00G7oo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol00goo
0`00Fgoo00D007ooOomoo`0002ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo059oo`<0
00=oo`03001oogoo02Aoo`0097oo00<007ooOol00goo0P003Goo00<007ooOol0CGoo0P000goo00<0
07ooOol0:Woo00<007ooOol00goo0P004Goo0P00<goo00<007ooOol03goo0P0000Aoo`00000000Ao
o`03001oogoo02Yoo`03001oogoo00=oo`03001oogoo05aoo`05001oogooOol0000/Ool00`00Oomo
o`03Ool3001KOol20004Ool00`00Oomoo`0ZOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomo
o`1BOol01000Ool000000goo00<007ooOol08goo000TOol00`00Oomoo`02Ool2000>Ool00`00Oomo
o`1=Ool20003Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool3000@Ool2000dOol00`00Oomoo`0?Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo02Uoo`03001oogoo00=oo`8005moo`05001oogooOol0
000[Ool00`00Oomoo`03Ool3001KOol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`1BOol200000goo00000002Ool00`00Oomoo`0SOol002=oo`03001o
ogoo00=oo`8000ioo`03001oogoo04ioo`8000=oo`03001oogoo02Qoo`03001oogoo00=oo`03001o
o`0000moo`8003Eoo`03001oogoo00eoo`8000Eoo`<000=oo`03001oogoo02Qoo`03001oogoo009o
o`80065oo`04001oogoo000ZOol00`00Oomoo`03Ool2001LOol00`00Oomoo`05Ool00`00Oomoo`0X
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2001DOol200000goo00000003Ool00`00Oomoo`0ROol0
029oo`03001oogoo00=oo`8000ioo`80055oo`8000=oo`03001oogoo02Ioo`03001oogoo00=oo`@0
00ioo`8003Ioo`03001oogoo00aoo`8000Moo`<0009oo`03001oogoo02Moo`03001oogoo00=oo`03
001oogoo061oo`05001oogooOol0000YOol00`00Oomoo`03Ool2001LOol00`00Oomoo`06Ool00`00
Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1COol20002Ool20003Ool00`00
Oomoo`0QOol0029oo`03001oogoo009oo`<000ioo`03001oogoo051oo`8000=oo`03001oogoo02Io
o`03001oogoo009oo`800003Ool007oo00eoo`03001oogoo03Ioo`03001oogoo00]oo`8000Uoo`80
00=oo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo069oo`04001oogoo000XOol00`00Oomo
o`04Ool2001KOol20008Ool00`00Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`1BOol20004Ool20002Ool00`00Oomoo`0QOol0025oo`03001oogoo00=oo`8000moo`03001oogoo
051oo`<000=oo`03001oogoo02Aoo`03001oogoo009oo`80009oo`03001oogoo00]oo`03001oogoo
03Moo`03001oogoo00Yoo`8000Yoo`<0009oo`03001oogoo02Eoo`03001oogoo009oo`8006Eoo`04
001oogoo000WOol00`00Oomoo`03Ool01000Ool00000FWoo00<007ooOol027oo00<007ooOol097oo
00<007ooOol00goo00<007ooOol01goo00<007ooOol0DGoo0P001Goo0P000goo00<007ooOol087oo
000QOol00`00Oomoo`02Ool2000@Ool00`00Oomoo`1@Ool40003Ool00`00Oomoo`0ROol00`00Oomo
o`03Ool01000Oomoo`003Goo00<007ooOol0>7oo00<007ooOol02Goo0P0037oo0P000goo00<007oo
Ool08goo00<007ooOol00Woo0P00IWoo00D007ooOomoo`0002Eoo`03001oogoo00=oo`80009oo`03
001oogoo05Qoo`03001oogoo00Uoo`03001oogoo02=oo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo05=oo`03001oogoo00Aoo`8000=oo`03001oogoo01moo`0087oo00<007ooOol00Woo0P00
4Goo00<007ooOol0D7oo00<007oo00000P000Woo00<007ooOol08Goo00<007ooOol00goo00D007oo
Oomoo`0000aoo`03001oogoo03Uoo`03001oogoo00Qoo`8000moo`80009oo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo06Ioo`05001oogooOol0000SOol00`00Oomoo`03Ool20003Ool00`00
Oomoo`1HOol00`00Oomoo`0:Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`1COol20005Ool30002Ool00`00Oomoo`0OOol001moo`03001oogoo00=oo`80011oo`03001o
ogoo055oo`03001oo`00008000=oo`03001oogoo021oo`03001oogoo009oo`8000=oo`8000]oo`03
001oogoo03Uoo`8000Qoo`80011oo`8000=oo`03001oogoo021oo`03001oogoo009oo`03001oogoo
06Moo`05001oogooOol0000ROol00`00Oomoo`03Ool20004Ool00`00Oomoo`1HOol00`00Oomoo`0:
Ool00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool20015Ool30004
Ool30002Ool00`00Oomoo`0NOol001moo`03001oogoo009oo`<0011oo`03001oogoo055oo`03001o
ogoo00<0009oo`03001oogoo01moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo03Yoo`8000Aoo`<001=oo`80009oo`03001oogoo01moo`03001oogoo009oo`8006Yoo`05
001oogooOol0000QOol00`00Oomoo`02Ool30004Ool00`00Oomoo`1HOol00`00Oomoo`0;Ool00`00
Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`09Ool400000goo000000020014
Ool80002Ool00`00Oomoo`0NOol001ioo`03001oogoo009oo`<0015oo`03001oogoo055oo`03001o
ogoo00@0009oo`03001oogoo01ioo`03001oogoo009oo`8000Eoo`03001oogoo00Qoo`03001oogoo
03aoo`D001Ioo`8000=oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo06Uoo`80009oo`03
001oogoo01ioo`03001oogoo00=oo`8000Eoo`03001oogoo05Qoo`03001oogoo00]oo`03001oogoo
01ioo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`8000Moo`8004Uoo`<0009oo`03
001oogoo01eoo`007Woo00<007ooOol00Woo0`004Goo00<007ooOol0D7oo00H007ooOomoo`00Ool2
0002Ool00`00Oomoo`0NOol01000Oomoogoo0P001Woo00<007ooOol027oo00<007ooOol0F7oo0P00
0Woo00<007ooOol07Goo00<007ooOol00Woo0P00K7oo0P000Woo00<007ooOol07Goo00<007ooOol0
0Woo0P001Woo00<007ooOol0F7oo00<007ooOol02goo00<007ooOol07Woo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0B7oo0P000Woo00<007ooOol0
7Goo000MOol00`00Oomoo`02Ool3000AOol2001BOol01P00Oomoogoo001oo`<0009oo`03001oogoo
01aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Moo`8005Yoo`<0009oo`03001oogoo
01aoo`04001oogooOol2001^Ool01000Oomoo`007Woo00<007ooOol00Woo0P001goo00<007ooOol0
FGoo00<007ooOol02goo00<007ooOol077oo00<007ooOol017oo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol0B7oo0`000Woo00<007ooOol077oo000MOol00`00Oomoo`02
Ool2000BOol00`00Oomoo`1AOol01@00Oomoogoo00000goo00@007ooOol001ioo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo05Yoo`80009oo`03001oogoo01]oo`03001o
ogoo009oo`8006ioo`80009oo`03001oogoo01]oo`03001oogoo009oo`8000Moo`03001oogoo05Uo
o`03001oogoo00]oo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo00Yoo`03001oogoo04Uoo`<00003Ool007oo01eoo`007Goo00@007ooOomoo`8001=o
o`03001oogoo051oo`03001oogoo009oo`04001oogooOol200000goo001oo`0LOol00`00Oomoo`02
Ool00`00Oomoo`06Ool20007Ool2001LOol20002Ool00`00Oomoo`0KOol00`00Oomoo`02Ool2001_
Ool01000Oomoo`007Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FGoo00<007ooOol0
37oo00<007ooOol06goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2goo00<007ooOol0BGoo0`0000=oo`00Ool07Goo000LOol00`00Oomoo`02Ool2000COol00`00Oomo
o`1@Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol06Woo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol017oo0P00GWoo0P000Woo00<007ooOol06Woo00<007ooOol00Woo00<0
07ooOol0KWoo00D007ooOomoo`0001]oo`03001oogoo009oo`8000Qoo`03001oogoo05Yoo`03001o
ogoo00]oo`03001oogoo01Yoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Yoo`8004Yoo`@0009oo`03001oogoo01]oo`0077oo00<007ooOol00Woo0`004Woo00<007oo
Ool0Cgoo00<007ooOol00goo00<007ooOol00Woo00@007ooOol001]oo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00=oo`8005moo`80009oo`03001oogoo01Uoo`03001oogoo009oo`80075o
o`04001oogoo000KOol00`00Oomoo`02Ool20008Ool00`00Oomoo`1JOol00`00Oomoo`0<Ool00`00
Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`1:Ool30002Ool00`00Oomoo`0KOol001aoo`03001oogoo009oo`8001=oo`03001oogoo04io
o`8000Eoo`03001oogoo009oo`05001oogooOol0000JOol00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool00`00Oomoo`1OOol01@00Oomoogoo00006Woo00<007ooOol00Woo0P00LGoo00@0
07ooOol001]oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05Yoo`03001oogoo00aoo`03
001oogoo01Uoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`80
04eoo`8000=oo`03001oogoo01Yoo`006goo00<007ooOol00Woo0`004Woo0P00Cgoo0P001Woo00<0
07ooOol00Woo00D007ooOomoo`0001Yoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo061oo`05001oogooOol0000JOol00`00Oomoo`02Ool2001aOol01000Oomoo`006Woo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol0G7oo00<007ooOol02goo00<007ooOol067oo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0C7oo
0P000goo00<007ooOol06Woo000KOol00`00Oomoo`02Ool00`00Ool0000AOol2001@Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01@00Oomoogoo00006Goo00<007ooOol00goo00<007ooOol027oo00@0
07ooOomoo`80069oo`05001oogooOol0000IOol00`00Oomoo`03Ool2001aOol01@00Oomoogoo0000
6Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0G7oo00<007ooOol037oo00<007ooOol0
5goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
C7oo0`000Woo00<007ooOol06Woo000KOol00`00Oomoo`02Ool00`00Ool0000?Ool2001BOol00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1QOol20003Ool00`00Oomoo`0FOol00`00Oomoo`02
Ool3001aOol01@00Oomoogoo00006Goo00<007ooOol00Woo0P001goo00<007ooOol0GGoo00<007oo
Ool037oo00<007ooOol05goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02goo0P00CGoo0`000goo00<007ooOol06Goo000JOol00`00Oomoo`03Ool00`00Ool0000=Ool3
001COol00`00Oomoo`05Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0FOol00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1QOol20003Ool00`00Oomoo`0FOol00`00Oomo
o`02Ool3001aOol01@00Oomoogoo000067oo00<007ooOol00goo0P001Woo0P00Ggoo00<007ooOol0
37oo00<007ooOol05Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0
3Goo00<007ooOol0Bgoo0`000goo00<007ooOol06Goo000JOol00`00Oomoo`03Ool00`00Ool0000<
Ool2001EOol00`00Oomoo`04Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`0EOol00`00Oomoo`03
Ool20007Ool20004Ool00`00Oomoo`1ROol20003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool3001a
Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`03Ool20006Ool00`00Oomoo`1OOol00`00
Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0>Ool00`00Oomoo`1:Ool30003Ool00`00Oomoo`0IOol001Yoo`03001oogoo00=oo`04001o
o`00000:Ool2001FOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`1ROol20003Ool00`00Oomoo`0E
Ool00`00Oomoo`03Ool3001bOol01@00Oomoogoo00005goo00<007ooOol00goo0P001Goo00<007oo
Ool0H7oo00<007ooOol037oo00<007ooOol05Goo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool00Woo00<007ooOol03goo0P00BWoo0P0000=oo`00Ool00goo00<007ooOol067oo000IOol00`00
Oomoo`03Ool200000goo00000009Ool2001HOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`03Ool20006Ool2001UOol01@00Oomo
ogoo00005goo00<007ooOol00goo0`00LWoo00D007ooOomoo`0001Moo`03001oogoo00=oo`8000Ao
o`80069oo`03001oogoo00aoo`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo009oo`03001oogoo011oo`03001oogoo04Qoo`800003Ool007oo00=oo`03001oogoo01Qoo`00
6Goo00<007ooOol00goo1@0027oo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol057oo00<007ooOol00Woo0`000goo0P001goo00<007ooOol0I7oo00<0
07ooOol00Woo00<007ooOol057oo00<007ooOol00Woo1000LWoo00D007ooOomoo`0001Moo`03001o
ogoo009oo`<000Aoo`03001oogoo065oo`03001oogoo00aoo`03001oogoo01Aoo`03001oogoo00=o
o`8000eoo`05001oogooOol0000COol2001<Ool00`00Oomoo`02Ool00`00Oomoo`0HOol001Uoo`03
001oogoo00Eoo`03001oo`0000Moo`8005]oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo01Aoo`04001oogooOol50002Ool00`00Oomoo`06Ool00`00Oomoo`1TOol00`00
Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool5001bOol01@00Oomoogoo00005Woo00<007oo
Ool00Woo0P0000=oo`0000000Woo00<007ooOol0HWoo00<007ooOol037oo00<007ooOol057oo00<0
07ooOol01Goo0P002goo00@007ooOol001Eoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo
01Qoo`006Goo00<007ooOol01Goo00<007oo00001Woo0P00G7oo0P000Woo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol04goo00<007ooOol00Woo0`0000Aoo`00Ool000Qoo`8006Ioo`03001o
ogoo009oo`03001oogoo01=oo`03001oogoo009oo`D0079oo`03001oogoo009oo`03001oogoo01=o
o`03001oogoo009oo`03001oogoo00@006Eoo`03001oogoo00eoo`03001oogoo01=oo`03001oogoo
00Moo`<000Moo`05001oogooOol0000FOol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`0H
Ool001Uoo`03001oogoo00Eoo`03001oo`0000Eoo`8005ioo`800003Ool007oo00Ioo`03001oogoo
009oo`03001oogoo01=oo`03001oogoo009oo`800003Ool00000008000Qoo`03001oogoo06Eoo`03
001oogoo009oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo0080079oo`03001oogoo009o
o`03001oogoo01=oo`04001oogooOol20002Ool3001VOol00`00Oomoo`0=Ool00`00Oomoo`0COol0
0`00Oomoo`0:Ool40003Ool01000Ool000005goo0P00BWoo00<007ooOol00goo00<007ooOol05goo
000HOol00`00Oomoo`06Ool30004Ool2001POol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomo
o`0COol00`00Oomoo`02Ool60009Ool00`00Oomoo`1UOol00`00Oomoo`02Ool00`00Oomoo`0COol0
1000Oomoogoo0P000Woo0P00LWoo00<007ooOol00Woo00<007ooOol04goo00D007ooOomoo`0000=o
o`8006Moo`03001oogoo00eoo`03001oogoo019oo`03001oogoo00moo`D001Yoo`03001oogoo04Uo
o`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol01Woo0`000goo0P00HWoo00<007oo
Ool01Woo0P0017oo00<007ooOol04Woo00<007ooOol00Woo1@002Goo00<007ooOol0IWoo00<007oo
Ool00Woo00<007ooOol04goo00@007ooOomoo`80009oo`03001oogoo075oo`03001oogoo009oo`03
001oogoo019oo`03001oogoo009oo`04001oogooOol2001WOol00`00Oomoo`0=Ool00`00Oomoo`0B
Ool00`00Oomoo`0AOol00`00Oomoo`0JOol2001:Ool00`00Oomoo`02Ool00`00Oomoo`0GOol001Qo
o`03001oogoo00Ioo`<000=oo`03001oogoo065oo`8000Moo`03001oogoo00=oo`03001oogoo019o
o`03001oogoo009oo`D000Uoo`03001oogoo06Eoo`8000Eoo`03001oogoo019oo`04001oogooOol3
00000goo001oo`1bOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`05
001UOol00`00Oomoo`0=Ool00`00Oomoo`0BOol00`00Oomoo`0@Ool2000MOol00`00Oomoo`18Ool0
0`00Oomoo`02Ool00`00Oomoo`0GOol001Qoo`03001oogoo00=oo`H000=oo`03001oogoo061oo`@0
00Ioo`03001oogoo00=oo`03001oogoo019oo`03001oogoo009oo`D000Qoo`03001oogoo06Ioo`80
00Eoo`03001oogoo019oo`03001oogoo009oo`@007=oo`03001oogoo009oo`03001oogoo019oo`03
001oogoo009oo`D0009oo`8006=oo`03001oogoo00ioo`03001oogoo019oo`03001oogoo009oo`@0
00Uoo`8001moo`03001oogoo04Moo`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol0
0goo0`000Woo00@007ooOomoo`80065oo`03001oogoo008000Eoo`8000Aoo`03001oogoo019oo`03
001oogoo009oo`D000Moo`8006Qoo`8000Eoo`03001oogoo019oo`03001oogoo009oo`<007Aoo`03
001oogoo00=oo`03001oogoo015oo`03001oogoo00=oo`<000Aoo`80069oo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo009oo`D000Eoo`@0021oo`8004Qoo`03001oogoo009oo`03001oogoo
01Moo`0067oo00<007ooOol00goo0P000goo00<007ooOol00Woo00<007ooOol0GWoo0P000goo0P00
17oo0P0017oo00<007ooOol04Woo00<007ooOol00Woo0P0000=oo`00Ool01goo00<007ooOol0Igoo
0P001Goo00<007ooOol04Goo00<007ooOol00goo0`00M7oo00<007ooOol00goo00<007ooOol04Goo
00<007ooOol00goo0P001Woo0P00H7oo00<007ooOol03goo00<007ooOol04Woo00<007ooOol00goo
0P0000=oo`00000010009Goo0P00Agoo00<007ooOol00Woo00<007ooOol05goo000HOol00`00Oomo
o`02Ool30003Ool20003Ool2001OOol00`00Oomoo`03Ool20003Ool20004Ool00`00Oomoo`0AOol0
0`00Oomoo`03Ool40008Ool00`00Oomoo`1WOol20005Ool00`00Oomoo`0AOol00`00Oomoo`03Ool3
001eOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`03Ool20007Ool00`00Oomoo`1NOol0
0`00Oomoo`0?Ool00`00Oomoo`0BOol00`00Oomoo`0bOol20016Ool00`00Oomoo`02Ool00`00Oomo
o`0GOol001Qoo`03001oogoo009oo`8000Eoo`8000=oo`03001oogoo05aoo`03001oogoo00Eoo`80
009oo`8000Aoo`03001oogoo015oo`03001oogoo00=oo`@000Qoo`03001oogoo06Moo`<000Aoo`03
001oogoo015oo`03001oogoo00=oo`8007Ioo`03001oogoo009oo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo05eoo`03001oogoo015oo`03001oogoo015oo`03001oogoo
03Aoo`03001oogoo04=oo`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol00Woo0P00
1goo1@00Fgoo0P002Goo0P0000=oo`00000017oo00<007ooOol04Goo00<007ooOol00goo0P0000=o
o`00Ool01Woo00<007ooOol0J7oo0`0017oo00<007ooOol04Goo00<007ooOol00goo0P00MWoo00<0
07ooOol00Woo00<007ooOol04Goo00<007ooOol00Woo0P0027oo00<007ooOol0G7oo00<007ooOol0
4Woo00<007ooOol04Goo00<007ooOol0=Goo00<007ooOol0@Woo00<007ooOol00Woo00<007ooOol0
5goo000HOol00`00Oomoo`02Ool20009Ool3001HOol4000;Ool40004Ool00`00Oomoo`0AOol00`00
Oomoo`03Ool40007Ool00`00Oomoo`1XOol30004Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00
Oomoo`1eOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`02Ool20008Ool00`00Oomoo`1L
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0fOol20012Ool00`00Oomoo`02Ool00`00
Oomoo`0GOol001Qoo`03001oogoo009oo`03001oogoo00Yoo`8005Aoo`<0015oo`8000Aoo`03001o
ogoo015oo`03001oogoo00=oo`800003Ool007oo00Ioo`03001oogoo06Qoo`<000Aoo`03001oogoo
015oo`03001oogoo009oo`8007Moo`03001oogoo009oo`03001oogoo015oo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo05]oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo03Qoo`03
001oogoo03moo`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol00Woo00<007ooOol0
2Woo0P00Dgoo0P004goo0P0017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol00P001Woo
00<007ooOol0J7oo00<007oo000017oo00<007ooOol04Goo00<007ooOol00Woo0P00Mgoo00<007oo
Ool00Woo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0Fgoo00<007oo
Ool04goo00<007ooOol04Goo00<007ooOol0>7oo0P00@7oo00<007ooOol00Woo00<007ooOol05goo
000HOol01000Oomoogoo0P0037oo0P00DWoo0P0057oo0P0017oo00<007ooOol04Goo00<007ooOol0
0goo00<007ooOol00P001Woo00<007ooOol0J7oo00<007oo000017oo00<007ooOol04Goo00<007oo
Ool00Woo0P00Mgoo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol0FWoo00<007ooOol04goo00<007ooOol04Goo00<007ooOol0>Woo00<007ooOol0?Goo
00<007ooOol00Woo00<007ooOol05goo000HOol01000Oomoogoo0P0037oo0`00D7oo0P005Goo0P00
17oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol00`001Goo00<007ooOol0J7oo00<007oo
000017oo00<007ooOol04Goo00<007ooOol00Woo0P00Mgoo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol0FWoo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol0>goo00<007ooOol0?7oo00<007ooOol00Woo00<007ooOol05goo000HOol00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Ool0001@Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomo
o`0BOol00`00Oomoo`02Ool01P00Oomoo`00Ool000Eoo`03001oogoo06Qoo`03001oo`0000Aoo`03
001oogoo015oo`03001oogoo009oo`8007Moo`03001oogoo009oo`03001oogoo015oo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo05Yoo`03001oogoo019oo`03001oogoo019oo`03001oogoo
03aoo`<003]oo`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol00Woo00<007ooOol0
2Woo00<007oo0000Cgoo00<007ooOol05Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol0
0Woo00D007ooOol007oo008000Aoo`03001oogoo06Qoo`03001oo`0000Aoo`03001oogoo019oo`03
001oogoo009oo`03001oogoo07Eoo`03001oogoo009oo`03001oogoo015oo`03001oogoo009oo`80
00Uoo`03001oogoo05Yoo`03001oogoo019oo`03001oogoo019oo`03001oogoo03moo`03001oogoo
03Qoo`03001oogoo009oo`03001oogoo01Moo`0067oo00<007ooOol00Woo00<007ooOol02Woo00<0
07oo0000CWoo00<007ooOol05Woo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogooOol2001ZOol00`00Ool00004Ool00`00Oomoo`0BOol00`00Oomoo`02
Ool00`00Oomoo`1eOol01@00Oomoogoo000057oo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool0FWoo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0@7oo0P00>7oo00<007ooOol00Woo
00<007ooOol05goo000HOol00`00Oomoo`02Ool2000;Ool01000Ool00000C7oo0P005goo0P001Goo
00<007ooOol04Woo00<007ooOol00Woo00@007ooOol0009oo`05001oogooOol0001[Ool30004Ool0
0`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`1eOol01@00Oomoogoo000057oo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol0FWoo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
@Woo00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol05goo000HOol00`00Oomoo`02Ool2000;
Ool01000Oomoo`00C7oo00<007ooOol05Woo0P001Goo00<007ooOol04Woo00<007ooOol00Woo00@0
07ooOol000=oo`04001oogoo001[Ool00`00Ool00003Ool00`00Oomoo`0COol00`00Oomoo`02Ool2
001eOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`1JOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`13Ool2000eOol20003Ool00`00Oomo
o`0GOol001Qoo`03001oogoo00=oo`03001oogoo00Uoo`04001oogoo001;Ool00`00Oomoo`0GOol2
0004Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`020002Ool01000Ool00000Jgoo00<0
07oo00000goo00<007ooOol04goo00<007ooOol00Woo0`00M7oo00<007ooOol00Woo00<007ooOol0
4goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0FWoo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol0AGoo0P00<goo00<007ooOol00Woo00<007ooOol05goo000IOol00`00Oomoo`02
Ool00`00Oomoo`09Ool01000Ool00000Bgoo00<007ooOol05goo0P0017oo00<007ooOol04goo00<0
07ooOol00Woo0P000Woo00@007ooOomoo`8006aoo`03001oo`0000=oo`03001oogoo01=oo`03001o
ogoo009oo`03001oo`0007Aoo`03001oogoo009oo`03001oogoo01=oo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo05Yoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo04Ioo`03001o
ogoo031oo`03001oogoo009oo`03001oogoo01Moo`006Goo00<007ooOol00Woo00<007ooOol02Goo
00<007oo0000Bgoo00<007ooOol067oo0P0017oo00<007ooOol04goo00<007ooOol00goo00@007oo
Ool000=oo`8006aoo`<000=oo`03001oogoo01=oo`03001oogoo009oo`<007Aoo`03001oogoo009o
o`03001oogoo01=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05Yoo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo04Moo`03001oogoo02moo`05001oogooOol0000JOol001Uoo`03
001oogoo009oo`03001oogoo00Aoo`P004]oo`03001oogoo01Qoo`8000Aoo`03001oogoo01Aoo`03
001oogoo009oo`04001oogoo0003Ool2001/Ool20004Ool00`00Oomoo`0COol00`00Oomoo`02Ool2
00000goo001oo`1bOol01@00Oomoogoo00005Woo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool0FWoo00<007ooOol04Goo00<007ooOol057oo00<007ooOol0B7oo0P00;Woo00<007ooOol00Woo
00<007ooOol067oo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20005Ool3001;Ool00`00Oomo
o`0GOol00`00Ool00004Ool00`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000goo0P00K7oo
0P0017oo00<007ooOol057oo00<007ooOol00Woo00@007oo0000075oo`03001oogoo009oo`03001o
ogoo01Eoo`05001oogooOol00009Ool00`00Oomoo`1JOol00`00Oomoo`0AOol00`00Oomoo`0DOol0
0`00Oomoo`1:Ool2000/Ool00`00Oomoo`02Ool00`00Oomoo`0HOol001Uoo`03001oogoo009oo`80
009oo`8000Eoo`8004eoo`03001oogoo01Moo`03001oo`0000Aoo`03001oogoo01Aoo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`1ZOol20003Ool00`00Oomoo`0EOol00`00Oomoo`02Ool0
1000Oomoo`00LGoo00<007ooOol00Woo00<007ooOol05Goo00@007ooOomoo`8000Qoo`03001oogoo
05Yoo`03001oogoo015oo`03001oogoo01Aoo`03001oogoo04aoo`03001oogoo02Uoo`03001oogoo
009oo`03001oogoo01Qoo`006Woo00@007ooOomoo`800003Ool0000000Ioo`03001oogoo04aoo`03
001oogoo01Moo`8000Eoo`03001oogoo01Aoo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`1ZOol20003Ool00`00Oomoo`0EOol00`00Oomoo`02Ool01000Oomoo`00L7oo00<007ooOol0
0goo00<007ooOol05Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0Fgoo00<007ooOol0
4Goo00<007ooOol05Goo00<007ooOol0C7oo00<007ooOol0:7oo00<007ooOol00Woo00<007ooOol0
67oo000JOol01000Oomoogoo0P0000=oo`00Ool01Woo00<007ooOol0C7oo00<007ooOol05goo0P00
17oo00<007ooOol05Goo00<007ooOol00Woo0P000Woo00D007ooOomoo`0006]oo`8000Aoo`03001o
ogoo01Eoo`03001oogoo009oo`05001oogooOol0001_Ool00`00Oomoo`03Ool00`00Oomoo`0EOol0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1KOol00`00Oomoo`0AOol00`00Oomoo`0EOol0
0`00Oomoo`1=Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0IOol001Yoo`04001oogoo
Ool200000goo001oo`05Ool00`00Oomoo`1=Ool00`00Oomoo`0GOol20004Ool00`00Oomoo`0FOol0
1000Oomoogoo0P000Woo00<007ooOol00P00Jgoo0P0017oo00<007ooOol05Woo00D007ooOomoo`00
00=oo`03001oogoo06eoo`03001oogoo009oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo05]oo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo04ioo`03001oogoo
02Eoo`03001oogoo009oo`03001oogoo01Uoo`006goo00@007ooOomoo`@00003Ool0000000<004mo
o`03001oogoo01Moo`8000Aoo`03001oogoo01Ioo`03001oogoo009oo`80009oo`04001oo`000007
Ool00`00Oomoo`1OOol40004Ool00`00Oomoo`0FOol01000Oomoogoo0P000Woo00<007ooOol0K7oo
00<007ooOol00goo00<007ooOol05goo00D007ooOomoo`0000Moo`03001oogoo05]oo`03001oogoo
011oo`03001oogoo01Moo`03001oogoo04ioo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo
01Uoo`006goo00@007ooOomoo`H0009oo`8004moo`03001oogoo01Moo`03001oogoo009oo`03001o
ogoo01Moo`03001oogoo009oo`80009oo`04001oo`000004Ool5001NOol20002Ool00`00Oomoo`02
Ool00`00Oomoo`0GOol01000Oomoogoo0P000Woo00<007ooOol0K7oo00<007ooOol00goo00<007oo
Ool05goo00@007ooOomoo`8000Ioo`03001oogoo05]oo`03001oogoo011oo`03001oogoo01Moo`03
001oogoo04moo`03001oogoo02=oo`05001oogooOol0000LOol001]oo`04001oogooOol70002Ool0
0`00Oomoo`1=Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoogoo0P00
0goo00<007oo00000goo00<007ooOol00Woo00<007ooOol0FWoo0P0017oo00<007ooOol00Woo00<0
07ooOol067oo00L007ooOomoo`00Ool0001_Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomo
ogoo0P001Goo0P00GGoo00<007ooOol03goo00<007ooOol067oo00<007ooOol0D7oo00<007ooOol0
8Goo00<007ooOol00Woo00<007ooOol06Woo000LOol00`00Oomoo`040002Ool2001AOol00`00Oomo
o`0FOol20004Ool00`00Oomoo`0HOol01@00Oomoogoo000017oo00<007oo00000goo00<007ooOol0
0Woo0P00FWoo0P0017oo0P0017oo00<007ooOol067oo00L007ooOomoo`00Ool0001^Ool00`00Oomo
o`03Ool00`00Oomoo`0IOol00`00Oomoo`020005Ool00`00Oomoo`1KOol00`00Oomoo`0@Ool00`00
Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0JOol001ao
o`03001oogoo00@000Aoo`8004moo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo01Uoo`04
001oogooOol20003Ool2000017oo001oo`001Woo00<007ooOol0Egoo0P001Goo0P000goo00<007oo
Ool06Goo00L007ooOomoo`00Ool0001^Ool00`00Oomoo`03Ool00`00Oomoo`0IOol01@00Oomoogoo
00001Goo00<007ooOol0Fgoo00<007ooOol047oo00<007ooOol06Goo00<007ooOol0D7oo00<007oo
Ool087oo00D007ooOomoo`0001eoo`0077oo00@007ooOomoo`8000Ioo`<004eoo`03001oogoo01Eo
o`8000Aoo`03001oogoo01Yoo`03001oogoo0080009oo`03001oo`0000800003Ool007oo00Ioo`03
001oogoo05Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01Uoo`04001oogooOol3001^
Ool00`00Oomoo`02Ool00`00Oomoo`0JOol01@00Oomoogoo00001Goo00<007ooOol0Fgoo00<007oo
Ool03goo00<007ooOol06Woo00<007ooOol0DGoo00<007ooOol07Woo00<007ooOol00Woo00<007oo
Ool06goo000MOol00`00Oomoo`030008Ool00`00Oomoo`1:Ool00`00Oomoo`0EOol20004Ool00`00
Oomoo`0JOol00`00Oomoo`020002Ool01000Ool000000Woo00<007ooOol01Goo00<007ooOol0EGoo
00<007ooOol017oo0P000goo00<007ooOol06goo00<007ooOol00`00KWoo00<007ooOol00Woo00<0
07ooOol06goo00@007ooOol000Eoo`03001oogoo05]oo`03001oogoo00moo`03001oogoo01]oo`03
001oogoo055oo`03001oogoo01eoo`03001oogoo009oo`03001oogoo01]oo`007Goo00<007ooOol0
0`002Goo00<007ooOol0BGoo00<007ooOol05Goo0P000goo00<007ooOol077oo00@007oo0000009o
o`<0009oo`8000Qoo`03001oogoo01eoo`P002ioo`8000Ioo`8000=oo`03001oogoo01]oo`03001o
ogoo008006ioo`03001oogoo00=oo`03001oogoo01]oo`04001oogoo0004Ool00`00Oomoo`1LOol0
0`00Oomoo`0>Ool00`00Oomoo`0LOol00`00Oomoo`1BOol00`00Oomoo`0LOol01@00Oomoogoo0000
7Woo000MOol00`00Oomoo`040008Ool00`00Oomoo`19Ool00`00Oomoo`0DOol20004Ool00`00Oomo
o`0LOol00`00Oomoo`0600000goo0000000:Ool00`00Oomoo`0JOol30007Ool5000YOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Ool00002001]Ool00`00Oomoo`02Ool00`00
Oomoo`0LOol00`00Oomoo`020003Ool00`00Oomoo`1LOol00`00Oomoo`0>Ool00`00Oomoo`0LOol0
0`00Oomoo`1BOol00`00Oomoo`0KOol20003Ool00`00Oomoo`0LOol001ioo`06001oo`00001oo`00
2Goo00<007ooOol0B7oo00<007ooOol057oo0P000goo00<007ooOol07Woo00<007oo00001P0037oo
00<007ooOol06Woo00<007ooOol037oo0P009goo00<007ooOol017oo0P000goo00<007ooOol07Goo
00<007ooOol00P00KGoo00<007ooOol00Woo00<007ooOol07Goo00@007oo0000009oo`03001oogoo
05aoo`03001oogoo00ioo`03001oogoo01ioo`03001oogoo059oo`03001oogoo01Yoo`05001oogoo
Ool0000OOol001ioo`03001oo`0000<000Uoo`8004Uoo`03001oogoo01Aoo`8000=oo`03001oogoo
01ioo`03001oo`0000@000ioo`03001oogoo01Yoo`8000moo`8002Aoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo01ioo`04001oo`00001/Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00
Oomoo`04001NOol00`00Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`1COol00`00Oomoo`0IOol0
1@00Oomoogoo00007goo000OOol00`00Ool00002000:Ool00`00Oomoo`17Ool00`00Oomoo`0DOol0
1@00Oomoogoo00008Goo00<007oo00000`0047oo00<007ooOol06Woo0P0047oo0P008Woo00<007oo
Ool017oo0P000goo00<007ooOol07goo00@007oo000006aoo`03001oogoo009oo`03001oogoo01mo
o`03001oo`00065oo`03001oogoo00ioo`03001oogoo01moo`03001oogoo059oo`03001oogoo01Qo
o`05001oogooOol0000POol001moo`03001oo`0000<000Uoo`8004Qoo`03001oogoo01=oo`8000=o
o`03001oogoo021oo`D0011oo`03001oogoo01]oo`03001oogoo00moo`03001oogoo021oo`03001o
ogoo00Aoo`8000=oo`03001oogoo021oo`<006]oo`03001oogoo009oo`03001oogoo021oo`04001o
o`00001OOol00`00Oomoo`0>Ool00`00Oomoo`0POol00`00Oomoo`1COol00`00Oomoo`0GOol01@00
Oomoogoo000087oo000POol5000:Ool00`00Oomoo`16Ool00`00Oomoo`0COol20002Ool00`00Oomo
o`0QOol6000?Ool00`00Oomoo`0LOol00`00Oomoo`0?Ool2000POol00`00Oomoo`04Ool20002Ool0
0`00Oomoo`0QOol01000Ool00000JWoo00<007ooOol00Woo00<007ooOol08Goo00<007oo0000Ggoo
00<007ooOol03Woo00<007ooOol08Goo00<007ooOol0Dgoo00<007ooOol05Goo00D007ooOomoo`00
025oo`0087oo00<007oo00000`002Goo0P00Agoo00<007ooOol04goo00D007ooOomoo`0002Aoo`D0
00moo`03001oogoo01eoo`03001oogoo011oo`03001oogoo01eoo`03001oogoo00=oo`80009oo`03
001oogoo02=oo`04001oo`00001YOol01@00Oomoogoo00009Goo00<007oo0000GWoo00<007ooOol0
3Goo00<007ooOol08Woo00<007ooOol0Dgoo00<007ooOol05Goo00D007ooOomoo`00025oo`008Goo
00<007oo00000P002Woo00<007ooOol0AGoo00<007ooOol04Woo0P000Woo00<007ooOol08goo00<0
07oo00000P003goo00<007ooOol07Woo00<007ooOol047oo00<007ooOol077oo00<007ooOol00goo
0P000Woo00<007ooOol08goo00@007ooOol006Qoo`03001oogoo009oo`03001oogoo02=oo`04001o
ogoo001MOol00`00Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomoo`1COol00`00Oomoo`0DOol01000
Oomoo`008Woo000QOol00`00Oomoo`03000:Ool00`00Oomoo`14Ool00`00Oomoo`0AOol30002Ool0
0`00Oomoo`0TOol00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool2000MOol20004Ool0
1000Oomoo`009goo00@007ooOol006Moo`05001oogooOol0000WOol00`00Ool0001LOol00`00Oomo
o`0=Ool00`00Oomoo`0TOol00`00Oomoo`1COol00`00Oomoo`0COol01@00Oomoogoo00008Woo000R
Ool00`00Oomoo`02000;Ool20014Ool00`00Oomoo`0@Ool30002Ool00`00Oomoo`0VOol00`00Oomo
o`0?Ool00`00Oomoo`0POol00`00Oomoo`0@Ool00`00Oomoo`0KOol20002Ool20002Ool00`00Oomo
o`0VOol01000Oomoo`00IGoo00D007ooOomoo`0002Uoo`03001oo`0005]oo`03001oogoo00aoo`03
001oogoo02Ioo`03001oogoo05=oo`8001=oo`04001oogoo000SOol002=oo`03001oogoo008000ao
o`80049oo`03001oogoo011oo`05001oo`00Ool0000ZOol00`00Oomoo`0>Ool00`00Oomoo`0QOol0
0`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`0200000goo001oo`0YOol01000Oomoo`00I7oo
00@007ooOol002Yoo`03001oogoo008005Uoo`03001oogoo00]oo`03001oogoo02Qoo`03001oogoo
05Aoo`03001oogoo011oo`03001oo`0002Aoo`0097oo00<007ooOol00P003Goo0`00?goo0P003goo
0P0000Aoo`00Ool002aoo`03001oogoo00eoo`03001oogoo029oo`03001oogoo00moo`03001oogoo
01Uoo`H00003Ool007oo02Yoo`03001oogoo0080069oo`04001oogoo000/Ool01@00Oomoogoo0000
F7oo00<007ooOol02Woo00<007ooOol0:Woo00<007ooOol0Dgoo0P0047oo0`009Goo000TOol01000
Oomoogoo0P003Woo0P0087oo0`0077oo00<007ooOol03Goo00H007ooOol007oo000/Ool00`00Oomo
o`0=Ool00`00Oomoo`0SOol2000@Ool00`00Oomoo`0GOol20002Ool300000goo001oo`0[Ool00`00
Oomoo`02001QOol01000Oomoo`00;7oo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol02goo
00<007ooOol0:Woo00<007ooOol0EGoo00<007ooOol03Goo00<007oo00009Goo000UOol01000Oomo
ogoo0P003goo0P0077oo0`0000Aoo`00000001Yoo`03001oogoo00Qoo`800003Ool00000009oo`<0
02ioo`03001oogoo00aoo`03001oogoo02Eoo`8000ioo`03001oogoo01Ioo`03001oogoo009oo`@0
02eoo`04001oogooOol2001OOol200000goo001oo`0]Ool00`00Oomoo`02Ool00`00Oomoo`1COol0
0`00Oomoo`0:Ool00`00Oomoo`0/Ool00`00Oomoo`1EOol3000;Ool3000VOol002Ioo`03001oogoo
00<000moo`8001Uoo`8000Ioo`<001Qoo`03001oogoo00Moo`D0009oo`<0031oo`03001oogoo00]o
o`03001oogoo02Moo`8000=oo`/001Ioo`03001oogoo009oo`@002moo`04001oogooOol2001NOol3
000`Ool01@00Oomoogoo0000EGoo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Egoo0`00
1goo0`009goo000VOol01000Oomoogoo0`003goo0P0067oo00<007ooOol01goo0P005Woo00<007oo
Ool01goo0P001Goo0P0000=oo`00Ool0;goo00<007ooOol02goo0P00:Woo0`002Woo0`004goo00@0
07ooOomoo`@00003Ool007oo02ioo`03001oogoo009oo`8005aoo`800003Ool007oo02moo`03001o
ogoo009oo`03001oogoo059oo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05Yoo`L0009o
o`03001oogoo02Eoo`009goo00@007ooOomoo`<0011oo`03001oogoo01Eoo`03001oogoo00Qoo`80
01Eoo`03001oogoo00Ioo`8000Eoo`800003Ool007oo035oo`03001oogoo00]oo`03001oogoo03Io
o`04001oo`00000AOol01P00Ool00000Ool0009oo`03001oogoo02moo`03001oogoo009oo`8005Yo
o`@0039oo`03001oogoo009oo`03001oogoo055oo`03001oogoo00Qoo`03001oogoo031oo`03001o
ogoo065oo`03001oogoo02Ioo`00:7oo00@007ooOomoo`<0011oo`8001Eoo`03001oogoo00Uoo`80
01Aoo`03001oogoo00Eoo`8000Aoo`80009oo`03001oogoo039oo`03001oogoo00Yoo`03001oogoo
03Moo`04001oo`00000?Ool300000goo00000002Ool00`00Oomoo`0aOol20003Ool2001HOol20000
0goo001oo`0cOol00`00Oomoo`02Ool2001AOol20008Ool00`00Oomoo`0bOol00`00Oomoo`1OOol0
0`00Oomoo`0WOol002Uoo`03001oogoo009oo`80011oo`8001Aoo`03001oogoo00Yoo`80019oo`03
001oogoo00Ioo`03001oogoo009oo`80009oo`03001oogoo03Aoo`03001oogoo00Uoo`8003Uoo`03
001oogoo008000]oo`<0009oo`05001oogooOol0000fOol01000Oomoogoo0P00EWoo0P0000=oo`00
Ool0=Goo00<007ooOol00goo00<007ooOol0Cgoo00<007ooOol01Goo00<007ooOol0=7oo00<007oo
Ool0GGoo00<007ooOol0:7oo000ZOol01000Oomoogoo0`0047oo0`004Woo00<007ooOol037oo0P00
47oo00<007ooOol01Goo00@007ooOomoo`80009oo`8003Qoo`03001oogoo00Uoo`03001oogoo03Mo
o`8000=oo`8000Ioo`<00003Ool007oo0080009oo`8003Qoo`04001oogooOol2001DOol01000Oomo
o`00>7oo0P000goo00<007ooOol0Cgoo10000goo00<007ooOol0=Woo00<007ooOol0Fgoo00<007oo
Ool0:Goo000[Ool00`00Oomoo`02Ool2000AOol<0007Ool7000:Ool3000<Ool00`00Oomoo`05Ool0
1000Oomoogoo0P000Woo00<007ooOol0>Goo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol0
0Woo1P0017oo0`000Woo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol0Cgoo0P000Woo00<0
07ooOol0>Goo00D007ooOomoo`00051oo`8000Aoo`03001oogoo03Qoo`03001oogoo05Uoo`03001o
ogoo02Yoo`00;7oo0P000Woo0`006goo0`001Goo0`000goo0`002Woo0`002Woo00<007ooOol01Goo
00@007oo000000=oo`03001oogoo03]oo`03001oogoo00Moo`03001oogoo03Uoo`8000aoo`<0009o
o`03001oogoo03]oo`04001oogooOol2001?Ool20002Ool00`00Oomoo`0kOol01000Oomoogoo0P00
CGoo0P0017oo00<007ooOol0>Woo0P00Egoo0P00;Goo000^Ool01000Oomoogoo0P0077oo0P000goo
0P0000=oo`00000017oo00<007ooOol02Woo0P0027oo00<007ooOol01Goo10000goo00<007ooOol0
?7oo00<007ooOol01goo00<007ooOol0>goo0P002Goo0P0017oo00<007ooOol0?7oo00@007ooOomo
o`8002=oo`P0029oo`05001oogooOol0000nOol00`00Oomoo`02Ool20019Ool30005Ool00`00Oomo
o`0mOol00`00Oomoo`1COol00`00Oomoo`0]Ool002moo`03001oogoo00@001aoo`800003Ool007oo
00=oo`80009oo`8000eoo`03001oogoo00Eoo`03001oogoo00Aoo`@000=oo`03001oogoo03ioo`03
001oogoo009oo`<00003Ool007oo03ioo`<000Aoo`<000Aoo`03001oogoo03ioo`04001oogooOol2
000QOol20007Ool2000NOol20003Ool00`00Oomoo`0nOol00`00Oomoo`02Ool20016Ool20007Ool0
0`00Oomoo`0oOol00`00Oomoo`1AOol00`00Oomoo`0^Ool002moo`03001oogoo009oo`@001]oo`<0
00Eoo`@000moo`03001oogoo00=oo`8000Eoo`<000Eoo`03001oogoo03moo`80009oo`D0045oo`<0
0003Ool0000000Aoo`80049oo`04001oogooOol2000POol00`00Oomoo`08Ool2000JOol20004Ool0
0`00Oomoo`10Ool20003Ool3000oOol50008Ool00`00Oomoo`10Ool00`00Oomoo`1AOol00`00Oomo
o`0^Ool0031oo`03001oogoo009oo`D001Yoo`8001Uoo`03001oogoo009oo`03001oogoo009oo`<0
00Ioo`03001oogoo049oo`04001oogooOol30012Ool40004Ool00`00Oomoo`13Ool01000Oomoogoo
0`007Goo00<007ooOol02goo0P005Woo0P001Goo00<007ooOol0@goo00<007ooOol00Woo0`00>Woo
0`0037oo00<007ooOol0@Woo00<007ooOol0Cgoo00<007ooOol0;goo000aOol20003Ool5000JOol3
000HOol01@00Oomoogoo00000Woo10001Goo0P00AWoo0P0017oo0P00@7oo0P001Goo00<007ooOol0
AGoo00<007ooOol00Woo0P0077oo00<007ooOol03Goo00<007ooOol04Woo00<007ooOol017oo00<0
07ooOol0AGoo00<007ooOol017oo0P00=Woo0P003Goo0P00AWoo0P00CGoo0P00<Woo000cOol20003
Ool5000IOol3000HOol00`00Ool00002Ool40004Ool2001:Ool20004Ool3000kOol30004Ool20019
Ool20004Ool3000HOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool20019Ool20006
Ool2000bOol2000=Ool2001:Ool20019Ool2000dOol003Eoo`03001oogoo00=oo`@001Qoo`<001Qo
o`L000=oo`8004ioo`03001oogoo00Aoo`03001oogoo03Moo`8000Aoo`8004eoo`8000Aoo`<001Io
o`03001oogoo011oo`03001oogoo00eoo`8000Aoo`8004eoo`8000Ioo`8002ioo`8000ioo`03001o
ogoo04aoo`8004Eoo`8003Ioo`00=Woo0P001Goo1@005Woo00@007oo000001Ioo`D000Aoo`03001o
ogoo04moo`8000Eoo`@003=oo`8000Aoo`80055oo`8000Eoo`<001=oo`03001oogoo015oo`03001o
ogoo00Yoo`8000Aoo`80055oo`8000Ioo`8002]oo`03001oogoo00aoo`80055oo`03001oogoo045o
o`03001oogoo03Ioo`00>7oo00<007ooOol01Goo100057oo0P000Woo0P004Woo1@001Goo00<007oo
Ool0DWoo00<007ooOol01Goo0`00<7oo0P0017oo00<007ooOol0Dgoo00<007ooOol01Goo0`003goo
00<007ooOol04goo00<007ooOol01goo0P001Goo00<007ooOol0Dgoo00<007ooOol01Goo0`009goo
0P003Goo00<007ooOol0DWoo00<007ooOol0?goo00<007ooOol0=goo000iOol20007Ool5000BOol2
0003Ool40006Ool;0005Ool2001FOol20008Ool2000[Ool30004Ool2001GOol20007Ool3000=Ool0
0`00Oomoo`0DOol00`00Oomoo`04Ool30004Ool2001GOol00`00Oomoo`07Ool3000TOol00`00Oomo
o`0:Ool2001FOol2000mOol2000jOol003]oo`8000Qoo`L000ioo`8000Ioo`l000Eoo`8005Yoo`80
00Qoo`<002Eoo`@000Aoo`8005]oo`8000Qoo`<000Uoo`03001oogoo01Eoo`L000Eoo`8005Yoo`80
00Yoo`<001moo`8000]oo`8005Yoo`8003Uoo`8003aoo`00?Goo0`0027oo1P003Woo10000Woo2000
2Goo0`00GWoo0`0027oo0P0077oo20001Goo0P00Ggoo0`001goo0`001goo00<007ooOol07Woo0`00
GWoo0`002Woo100067oo10002Goo0`00GWoo0`00<goo0`00?Woo0010Ool30007Ool50003OolC000;
Ool3001TOol20008Ool4000>Ool:000:Ool3001TOol20008Ool40002Ool3000MOol2001TOol3000;
OolH000;Ool2001TOol3000]Ool30011Ool004=oo`<000Qoo`h0015oo`<006Uoo`<000Uoo`l0011o
o`<006Uoo`<000Qoo`L001Uoo`<006Uoo`<002Moo`@006Uoo`<002Moo`<004Aoo`00AWoo0`002Goo
0P005Woo0`00Kgoo10008Goo0`00Kgoo0`0027oo0`005goo0`00Kgoo0`008Goo0`00L7oo0`008Goo
0`00Agoo0019Ool3000KOol3001fOol3000KOol3001eOol4000JOol4001eOol3000KOol3001fOol3
000KOol3001:Ool004aoo`H000ioo`L007aoo`H000ioo`L007aoo`H000ioo`H007aoo`L000ioo`H0
07aoo`L000ioo`H004eoo`00DWoo3P00RGoo3P00RGoo3P00RGoo3P00RGoo3P00Dgoo003oOoooOooo
OolBOol00?mooomooomooa9oo`00ogooogooogoo4Woo003oOoooOoooOolBOol00?mooomooomooa9o
o`00ogooogooogoo4Woo0000\
\>"],
  ImageRangeCache->{{{0, 782}, {143.938, 0}} -> {-0.141095, -0.023153, \
0.00675472, 0.00675472}, {{20.875, 157.938}, {140.5, 3.375}} -> {-232.874, \
-187.537, 2.60468, 2.60468}, {{171.625, 308.75}, {140.5, 3.375}} -> \
{-625.326, -187.451, 2.60349, 2.60349}, {{322.438, 459.5}, {140.5, 3.375}} -> \
{-1018.35, -187.537, 2.60468, 2.60468}, {{473.188, 610.313}, {140.5, 3.375}} -> \
{-1410.44, -187.451, 2.60349, 2.60349}, {{624, 761.063}, {140.5, 3.375}} -> \
{-1803.82, -187.537, 2.60468, 2.60468}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .18519 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00440917 0.190476 [
[ 0 0 0 0 ]
[ 1 .18519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .18519 L
0 .18519 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00440917 0.200176 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
Mistroke
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
Mistroke
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
Mistroke
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
Mistroke
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
Mistroke
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
Mistroke
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
Mistroke
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
Mistroke
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
Mistroke
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
Mistroke
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
Mistroke
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
Mistroke
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
Mistroke
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
Mistroke
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
Mistroke
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
Mistroke
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
Mistroke
.07393 .49306 L
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
Mistroke
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
Mistroke
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
Mistroke
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
Mistroke
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
Mistroke
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
Mistroke
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
Mistroke
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
Mistroke
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
Mistroke
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
Mistroke
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
Mistroke
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
Mistroke
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
Mistroke
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
Mistroke
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
Mistroke
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
Mistroke
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
Mistroke
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mistroke
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
.08376 .46683 L
Mistroke
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
Mistroke
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
Mistroke
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
Mistroke
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
Mistroke
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
Mistroke
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
Mistroke
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
Mistroke
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
Mistroke
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
Mistroke
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
Mistroke
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
Mistroke
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
Mistroke
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
Mistroke
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
Mistroke
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
Mistroke
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
Mistroke
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
Mistroke
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
Mistroke
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
Mistroke
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
Mistroke
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
Mistroke
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
Mistroke
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
Mistroke
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
Mistroke
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
Mistroke
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
Mistroke
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
Mistroke
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
Mistroke
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
Mistroke
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
Mistroke
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
Mistroke
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
Mistroke
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
Mistroke
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
Mistroke
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
Mistroke
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
Mistroke
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
Mistroke
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
Mistroke
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
Mistroke
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
Mistroke
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
Mistroke
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
Mistroke
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
Mistroke
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
Mistroke
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
Mistroke
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
Mistroke
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
Mistroke
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
Mistroke
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
Mistroke
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
Mistroke
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
Mistroke
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
Mistroke
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
Mistroke
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
Mistroke
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
Mistroke
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
Mistroke
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
Mistroke
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
Mistroke
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
Mistroke
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
Mistroke
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
Mistroke
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
Mistroke
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
Mistroke
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
Mistroke
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
Mistroke
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
Mistroke
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
Mistroke
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
Mistroke
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
Mistroke
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
Mistroke
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
Mistroke
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
Mistroke
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
Mistroke
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
Mistroke
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
Mistroke
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
Mistroke
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
Mistroke
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
Mistroke
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
Mistroke
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
Mistroke
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
Mistroke
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
Mistroke
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
Mistroke
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
Mistroke
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
Mistroke
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
Mistroke
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
Mistroke
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
Mistroke
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
Mistroke
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
Mistroke
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
Mistroke
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mistroke
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
Mistroke
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
Mistroke
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
.09393 .45432 L
Mistroke
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
Mistroke
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
Mistroke
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
Mistroke
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
Mistroke
.08616 .46396 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.00440917 0.39418 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.08641 .46384 m
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
Mistroke
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
Mistroke
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
Mistroke
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
Mistroke
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
Mistroke
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
Mistroke
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
Mistroke
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
Mistroke
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
Mistroke
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
Mistroke
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
Mistroke
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
Mistroke
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
Mistroke
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
Mistroke
.08427 .40697 L
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
Mistroke
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
Mistroke
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
Mistroke
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
Mistroke
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
Mistroke
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
Mistroke
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
Mistroke
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
Mistroke
.08664 .41128 L
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
Mistroke
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
Mistroke
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
Mistroke
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
Mistroke
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
Mistroke
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
Mistroke
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
Mistroke
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
Mistroke
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
Mistroke
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
Mistroke
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
Mistroke
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
Mistroke
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
Mistroke
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
Mistroke
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
Mistroke
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
Mistroke
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
Mistroke
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
Mistroke
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
Mistroke
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
.12789 .49481 L
Mistroke
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
Mistroke
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
Mistroke
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
Mistroke
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
Mistroke
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
Mistroke
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
Mistroke
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
Mistroke
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
Mistroke
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
Mistroke
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
Mistroke
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
Mistroke
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
Mistroke
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
Mistroke
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
Mistroke
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
Mistroke
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
Mistroke
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
Mistroke
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
Mistroke
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
Mistroke
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
Mistroke
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
Mistroke
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
Mistroke
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
Mistroke
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
Mistroke
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
Mistroke
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
Mistroke
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
Mistroke
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
Mistroke
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
Mistroke
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.00440917 0.588183 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.0867 .38865 m
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
Mistroke
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
Mistroke
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
Mistroke
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
Mistroke
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
Mistroke
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
Mistroke
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
Mistroke
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
Mistroke
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
Mistroke
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
Mistroke
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
Mistroke
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
Mistroke
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
Mistroke
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
Mistroke
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
Mistroke
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
Mistroke
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
Mistroke
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
Mistroke
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
.40845 .03975 L
Mistroke
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
.37468 .03856 L
.37324 .03866 L
Mistroke
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
.34922 .0546 L
.34895 .05457 L
Mistroke
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
Mistroke
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
Mistroke
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
Mistroke
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
Mistroke
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
Mistroke
.17776 .18827 L
.17776 .18843 L
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
Mistroke
.20713 .16263 L
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
Mistroke
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
.24049 .12506 L
.24062 .12497 L
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
Mistroke
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
Mistroke
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
Mistroke
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
Mistroke
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
Mistroke
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
Mistroke
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
Mistroke
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
Mistroke
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
Mistroke
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
Mistroke
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
Mistroke
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
Mistroke
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
Mistroke
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
Mistroke
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
Mistroke
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
.38497 .03476 L
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
Mistroke
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
Mistroke
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
Mistroke
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
Mistroke
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
Mistroke
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
Mistroke
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
Mistroke
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
Mistroke
.22913 .12907 L
.22906 .12906 L
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
Mistroke
.18368 .17374 L
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
Mistroke
.13266 .25432 L
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
Mistroke
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
Mistroke
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
Mistroke
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
Mistroke
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
Mistroke
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
Mistroke
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
Mistroke
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
Mistroke
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
Mistroke
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
Mistroke
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
Mistroke
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
Mistroke
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
Mistroke
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
Mistroke
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
Mistroke
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
Mistroke
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
Mistroke
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
Mistroke
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
Mistroke
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
Mistroke
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
Mistroke
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
Mistroke
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
.09956 .71632 L
.09957 .71627 L
Mistroke
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
Mistroke
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
Mistroke
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
Mistroke
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
Mistroke
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
Mistroke
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
Mistroke
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
Mistroke
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
Mistroke
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
Mistroke
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
Mistroke
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
Mistroke
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
Mistroke
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
Mistroke
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
Mistroke
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
Mistroke
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
Mistroke
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
Mistroke
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
Mistroke
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
Mistroke
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
Mistroke
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
Mistroke
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
Mistroke
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
Mistroke
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
Mistroke
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
Mistroke
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
Mistroke
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
Mistroke
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
Mistroke
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
Mistroke
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
Mistroke
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
Mistroke
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
Mistroke
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
Mistroke
.68712 .92334 L
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
Mistroke
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
Mistroke
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
Mistroke
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
Mistroke
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
Mistroke
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
Mistroke
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
Mistroke
.44346 .95772 L
.44185 .95749 L
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
Mistroke
.27837 .90376 L
.27567 .90242 L
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
Mistroke
.17523 .81774 L
.17373 .81587 L
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
Mistroke
.10367 .73155 L
.10338 .73033 L
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
Mistroke
.08096 .61705 L
.08098 .61694 L
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
Mistroke
.06832 .5245 L
.06827 .52082 L
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
Mistroke
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
Mistroke
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
Mistroke
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.00440917 0.782187 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.0842 .41135 m
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
Mistroke
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
Mistroke
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
Mistroke
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
Mistroke
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
Mistroke
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
Mistroke
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
Mistroke
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
Mistroke
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
Mistroke
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
Mistroke
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
Mistroke
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
Mistroke
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
Mistroke
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
Mistroke
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
Mistroke
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
Mistroke
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
Mistroke
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
Mistroke
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
Mistroke
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
Mistroke
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
Mistroke
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
Mistroke
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
Mistroke
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
Mistroke
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
Mistroke
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
Mistroke
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
Mistroke
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
Mistroke
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
Mistroke
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
Mistroke
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
Mistroke
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
Mistroke
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
Mistroke
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
Mistroke
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
Mistroke
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
Mistroke
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
Mistroke
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
Mistroke
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
Mistroke
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
Mistroke
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
Mistroke
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
Mistroke
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
Mistroke
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
Mistroke
.38469 .94483 L
.38691 .94552 L
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
Mistroke
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
Mistroke
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
Mistroke
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mistroke
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
Mistroke
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
Mistroke
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
Mistroke
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
Mistroke
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
Mistroke
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
Mistroke
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
Mistroke
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
Mistroke
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
Mistroke
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
Mistroke
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
.8538 .79278 L
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
Mistroke
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
Mistroke
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
.89035 .70456 L
Mistroke
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
.86127 .71566 L
Mistroke
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
.84297 .74542 L
Mistroke
.84311 .74552 L
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
Mistroke
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
.8138 .81459 L
Mistroke
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
Mistroke
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
Mistroke
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
Mistroke
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
Mistroke
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
Mistroke
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
Mistroke
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
Mistroke
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
Mistroke
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
Mistroke
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
Mistroke
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
Mistroke
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
Mistroke
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
Mistroke
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
Mistroke
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
Mistroke
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
Mistroke
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
Mistroke
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
Mistroke
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
Mistroke
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
Mistroke
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
Mistroke
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
Mistroke
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
Mistroke
.07451 .48129 L
.07456 .48123 L
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
Mistroke
.07161 .48603 L
.07157 .48599 L
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
Mistroke
.07408 .49316 L
.07422 .49344 L
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
.08194 .46818 L
Mistroke
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
Mistroke
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
Mistroke
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
.08937 .41149 L
.08908 .41118 L
.08868 .41073 L
.08821 .41015 L
.08771 .40943 L
.0872 .4086 L
.08671 .4078 L
.08625 .40694 L
.08578 .40606 L
.0853 .40516 L
.08486 .40443 L
.0845 .4038 L
.08425 .40328 L
.08409 .40289 L
.084 .40259 L
.08399 .40236 L
.08407 .40215 L
.0842 .40189 L
.08434 .40146 L
.0845 .40079 L
.08468 .39986 L
.08488 .39859 L
.08512 .39692 L
.08539 .39515 L
.08568 .39276 L
.08601 .39019 L
.08637 .3874 L
.08678 .38417 L
.08722 .38054 L
.08769 .37667 L
.08815 .37239 L
.08863 .36874 L
.08911 .36398 L
.08963 .36015 L
.0902 .35568 L
.09085 .351 L
.09157 .34648 L
.09229 .34188 L
.09304 .33794 L
Mistroke
.09381 .33363 L
.09457 .33014 L
.09523 .32673 L
.09598 .32352 L
.09662 .32057 L
.09724 .31839 L
.09785 .31632 L
.09843 .31466 L
.09894 .31324 L
.09937 .31212 L
.09972 .31147 L
.09999 .31095 L
.1002 .31061 L
.10036 .3104 L
.10049 .31032 L
.10059 .31026 L
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
.10062 .30982 L
.10056 .30963 L
.10053 .30937 L
.10055 .30906 L
.10063 .30868 L
.10078 .30827 L
.10096 .30785 L
.10118 .30744 L
.1014 .30709 L
.10158 .3068 L
.10172 .30662 L
.10187 .30646 L
.10204 .30632 L
.10227 .3062 L
.10255 .30602 L
.1029 .30572 L
.10333 .30524 L
.10386 .30449 L
.10454 .30339 L
.10539 .3019 L
.10643 .30015 L
.10752 .29802 L
.10892 .29582 L
.11039 .29324 L
.11209 .2902 L
.11384 .28711 L
.11574 .28413 L
.11752 .28085 L
.11941 .2775 L
.12129 .27414 L
.12307 .27098 L
Mistroke
.1249 .26778 L
.12671 .2647 L
.12853 .26157 L
.13049 .25844 L
.1324 .25523 L
.13444 .25188 L
.13649 .24866 L
.1386 .24501 L
.14076 .24164 L
.14299 .23805 L
.14531 .23434 L
.1475 .23089 L
.14976 .22731 L
.15224 .22351 L
.15436 .22016 L
.15671 .21649 L
.15906 .21276 L
.16165 .20913 L
.1639 .20533 L
.16633 .2017 L
.16879 .1981 L
.17113 .19446 L
.17346 .19099 L
.17579 .18749 L
.17798 .18398 L
.17999 .18071 L
.18202 .17732 L
.18397 .1738 L
.18584 .17083 L
.18755 .16781 L
.18925 .16488 L
.19079 .16256 L
.19232 .16023 L
.19363 .15828 L
.19484 .15646 L
.19604 .15493 L
.197 .15367 L
.19786 .15264 L
.19859 .15187 L
.19917 .15136 L
.19957 .1511 L
.19978 .15106 L
.19982 .15116 L
.19975 .15133 L
.19964 .15145 L
.19956 .15143 L
.1996 .15123 L
.19979 .1508 L
.20016 .15014 L
.20073 .14926 L
Mistroke
.20149 .14819 L
.20247 .14694 L
.20371 .1455 L
.20515 .14393 L
.20678 .14223 L
.20874 .14038 L
.21096 .13837 L
.21312 .13637 L
.2157 .13425 L
.21838 .13218 L
.22103 .13014 L
.22393 .12818 L
.22664 .1263 L
.22936 .12468 L
.23195 .12312 L
.2343 .12185 L
.23642 .12069 L
.23828 .11976 L
.23985 .11901 L
.24105 .11846 L
.242 .11811 L
.24272 .11794 L
.24322 .1179 L
.24355 .11796 L
.24375 .11809 L
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
.24425 .11881 L
.24447 .11856 L
.24481 .11814 L
.24533 .11754 L
.24608 .11676 L
.2471 .1158 L
.24843 .11478 L
.24997 .11356 L
.25179 .11211 L
.25405 .11064 L
.25651 .10894 L
.25932 .10708 L
.2627 .10514 L
.26561 .10319 L
.26893 .10107 L
.27257 .09909 L
.27569 .09696 L
.27906 .09495 L
Mistroke
.28232 .09285 L
.28565 .09059 L
.28874 .08849 L
.29197 .08615 L
.2954 .08397 L
.29875 .08165 L
.30248 .0792 L
.30607 .07692 L
.30991 .07448 L
.31399 .07207 L
.318 .06956 L
.32208 .06703 L
.32671 .06433 L
.33062 .06172 L
.33505 .05898 L
.33922 .0563 L
.34365 .0536 L
.34758 .05118 L
.35139 .04886 L
.35495 .04663 L
.35829 .04472 L
.36117 .04318 L
.36375 .0418 L
.36607 .04063 L
.36783 .03972 L
.36939 .03905 L
.37057 .03862 L
.37147 .0384 L
.37209 .03831 L
.37245 .03834 L
.37259 .03844 L
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
Mistroke
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
.37178 .03891 L
.37207 .03897 L
.37251 .03905 L
.37313 .03913 L
.37392 .03919 L
.37491 .0392 L
.3761 .03914 L
.3775 .03901 L
.37906 .0388 L
.38089 .03852 L
.38273 .03818 L
.38483 .03781 L
.38699 .03742 L
.38932 .03704 L
.39142 .03666 L
.39365 .03628 L
.39576 .03594 L
.39777 .03564 L
.39958 .03541 L
.40122 .03526 L
.40265 .03519 L
.40388 .03519 L
.40483 .03524 L
.40557 .03533 L
.40612 .03542 L
.40648 .03549 L
.40666 .03552 L
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
Mistroke
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
.40813 .03792 L
.4081 .03768 L
.40811 .03738 L
.40821 .03705 L
.40842 .03673 L
.40879 .03646 L
.40934 .03633 L
.41011 .0364 L
.41111 .03666 L
.41241 .03706 L
.41393 .03753 L
.4158 .03803 L
.41784 .03852 L
.4202 .03894 L
.42281 .03923 L
.42581 .03939 L
.42851 .03942 L
.43164 .03934 L
.435 .03915 L
.43803 .03889 L
Mistroke
.44126 .0386 L
.44449 .03828 L
.44801 .03803 L
.4509 .03779 L
.45414 .03762 L
.45758 .0375 L
.46068 .0374 L
.46394 .03726 L
.46717 .03704 L
.47057 .03673 L
.47423 .03637 L
.47754 .03598 L
.48106 .03559 L
.48474 .03528 L
.48809 .03504 L
.49179 .03489 L
.49522 .03485 L
.49887 .03495 L
.50249 .03524 L
.50586 .03571 L
.50943 .03633 L
.51277 .03706 L
.51608 .03792 L
.51945 .03887 L
.52288 .03985 L
.52618 .04078 L
.52948 .0416 L
.53279 .04234 L
.53611 .04304 L
.53938 .04371 L
.54263 .04441 L
.54579 .04515 L
.54897 .04595 L
.55192 .04682 L
.55474 .04777 L
.5574 .04875 L
.55975 .04973 L
.56187 .05057 L
.5637 .05148 L
.56524 .05242 L
.5664 .05323 L
.56725 .05396 L
.56783 .0546 L
.56816 .05512 L
.56829 .0555 L
.56832 .05573 L
.56836 .05583 L
.56851 .05583 L
.56884 .05579 L
.56941 .05577 L
Mistroke
.57029 .05578 L
.57153 .0558 L
.57308 .05584 L
.57513 .05588 L
.57758 .05586 L
.58033 .05577 L
.58339 .0556 L
.5867 .05534 L
.58988 .055 L
.59311 .05459 L
.59606 .05415 L
.59896 .05374 L
.60141 .05336 L
.60382 .05304 L
.60608 .05283 L
.608 .05277 L
.60989 .0529 L
.61179 .05325 L
.61374 .05382 L
.61579 .05462 L
.61783 .05558 L
.62 .05673 L
.62215 .05807 L
.62451 .05946 L
.62708 .06095 L
.63 .06241 L
.63257 .06381 L
.63533 .06515 L
.63805 .06633 L
.6409 .06734 L
.64344 .06823 L
.64607 .06899 L
.64869 .06963 L
.65132 .0702 L
.6542 .07073 L
.65707 .07125 L
.66011 .07179 L
.66342 .0724 L
.66668 .07308 L
.67012 .07385 L
.67371 .07464 L
.6771 .07557 L
.68062 .07666 L
.68395 .07793 L
.68741 .07922 L
.69048 .08062 L
.69368 .08213 L
.69688 .08364 L
.69977 .08512 L
.70295 .08662 L
Mistroke
.70566 .0879 L
.70825 .08922 L
.71068 .09037 L
.71285 .09144 L
.71491 .09237 L
.7164 .09311 L
.71767 .09366 L
.7187 .09397 L
.71942 .09407 L
.71984 .09398 L
.71998 .09373 L
.71989 .09338 L
.71965 .09302 L
.71935 .09273 L
.71907 .09253 L
.7188 .09243 L
.71862 .09244 L
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
.71997 .09534 L
.71983 .09519 L
.71969 .095 L
.71961 .09475 L
.71967 .09454 L
.71992 .09443 L
.72042 .09447 L
.7212 .09469 L
.72227 .09511 L
.72366 .09572 L
.72525 .09651 L
.72702 .0974 L
.72906 .09839 L
.73131 .09949 L
.73377 .10061 L
.73614 .10165 L
.7384 .10261 L
.74059 .10348 L
.74258 .10421 L
.74426 .10479 L
.7457 .10522 L
.74687 .1055 L
.74775 .10567 L
Mistroke
.74843 .10575 L
.74895 .10577 L
.74936 .10577 L
.74965 .10573 L
.74986 .1057 L
.75002 .10567 L
.75013 .10563 L
.75023 .10561 L
.75033 .10558 L
.75045 .10555 L
.75057 .10551 L
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
.75054 .10576 L
.75039 .10589 L
.75026 .10607 L
.75018 .10632 L
.75019 .10666 L
.75032 .10707 L
.75061 .10755 L
.75109 .10811 L
.7518 .10871 L
.75274 .10942 L
.75389 .11023 L
.75538 .11118 L
.75705 .11227 L
.75895 .11349 L
.76111 .11487 L
.76346 .11636 L
.76585 .11795 L
.76824 .11961 L
.77057 .12111 L
.77271 .12261 L
.77456 .12388 L
.77625 .12505 L
.77777 .12618 L
.77895 .12714 L
.77995 .12799 L
.78078 .12878 L
.78146 .12961 L
.78204 .13052 L
.78253 .13147 L
.78295 .13248 L
.78334 .13351 L
.78372 .13467 L
.78404 .1357 L
Mistroke
.78429 .13685 L
.78451 .13788 L
.78474 .13891 L
.785 .14004 L
.78531 .14095 L
.78573 .14184 L
.78629 .14271 L
.7871 .14361 L
.7882 .1445 L
.7896 .14547 L
.79116 .14649 L
.79296 .14787 L
.79495 .14946 L
.79702 .15126 L
.79939 .15325 L
.80206 .15544 L
.80438 .15771 L
.80677 .16011 L
.80905 .16251 L
.8111 .16499 L
.81293 .16729 L
.81464 .16968 L
.81613 .17194 L
.8175 .17423 L
.81883 .17656 L
.8201 .17879 L
.82136 .18079 L
.82263 .18278 L
.82387 .18466 L
.82514 .1865 L
.82644 .18818 L
.82771 .18985 L
.82905 .19145 L
.83039 .19303 L
.8317 .19457 L
.83308 .19619 L
.83449 .19798 L
.83592 .19981 L
.8375 .20194 L
.83922 .20411 L
.84081 .2066 L
.84256 .20898 L
.8443 .21164 L
.84609 .21425 L
.84792 .21689 L
.84954 .21937 L
.85111 .22168 L
.85248 .22379 L
.85364 .22535 L
.85451 .22663 L
Mistroke
.85516 .2276 L
.85557 .22825 L
.8557 .22855 L
.8556 .22852 L
.85533 .22823 L
.85492 .22775 L
.85442 .22716 L
.8539 .22655 L
.85338 .22594 L
.85289 .22538 L
.85249 .22496 L
.85219 .22467 L
.852 .22448 L
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
.8518 .2244 L
.85206 .22475 L
.85247 .22526 L
.85305 .22596 L
.8538 .22684 L
.85467 .22788 L
.85571 .22917 L
.85693 .23063 L
.85824 .23236 L
.85977 .23429 L
.86154 .23655 L
.86315 .23888 L
.86487 .24155 L
.86681 .24426 L
.86891 .24721 L
.87071 .25019 L
.87266 .25337 L
.8746 .25667 L
.87647 .25971 L
.8783 .2629 L
.88015 .26622 L
.88189 .26916 L
.8835 .27198 L
.88513 .27497 L
.88668 .27778 L
.88814 .28035 L
.88958 .28294 L
.89089 .28552 L
Mistroke
.89216 .28784 L
.89342 .29021 L
.89455 .29226 L
.89563 .29432 L
.89663 .29603 L
.89753 .29764 L
.89835 .29907 L
.89901 .3002 L
.89954 .3011 L
.89994 .30176 L
.90019 .30219 L
.90031 .30241 L
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
Mistroke
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
.89967 .30148 L
.89971 .30188 L
.89986 .30248 L
.90011 .30327 L
.9005 .30425 L
.901 .30543 L
.90161 .30667 L
Mistroke
.9023 .30815 L
.90301 .30987 L
.90382 .31174 L
.90459 .31371 L
.90536 .31588 L
.9061 .31802 L
.90678 .32055 L
.90735 .3225 L
.90782 .32486 L
.9082 .32728 L
.90851 .32942 L
.90876 .33159 L
.90898 .3339 L
.90918 .33618 L
.90941 .33834 L
.90962 .34036 L
.90981 .34222 L
.90993 .34377 L
.91 .345 L
.91005 .34605 L
.91008 .34692 L
.91008 .34761 L
.91007 .34811 L
.91006 .34847 L
.91004 .34869 L
.91002 .34885 L
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
.91079 .34958 L
.91068 .34937 L
.9105 .34902 L
.91028 .34851 L
.91007 .34786 L
.90987 .34712 L
.90968 .34635 L
.90949 .34562 L
.9093 .345 L
.90911 .34453 L
.9089 .34427 L
.90868 .34425 L
.90843 .34449 L
.90815 .345 L
.90784 .34578 L
Mistroke
.90751 .34677 L
.90718 .3478 L
.90684 .34891 L
.9065 .35002 L
.90621 .35107 L
.90599 .35188 L
.90586 .35246 L
.90585 .35276 L
.90597 .35281 L
.90621 .35264 L
.90654 .35228 L
.90691 .35176 L
.9073 .3511 L
.90767 .35035 L
.90798 .34955 L
.90821 .3488 L
.90836 .34807 L
.90845 .3474 L
.90848 .34679 L
.90845 .34621 L
.90837 .34564 L
.90826 .34511 L
.90816 .34457 L
.90807 .34401 L
.90802 .34339 L
.90804 .34274 L
.90812 .34204 L
.90828 .3413 L
.90852 .34051 L
.90881 .33964 L
.90911 .33868 L
.90942 .33764 L
.90971 .33658 L
.90996 .33542 L
.91015 .33426 L
.91029 .33308 L
.91036 .3319 L
.91036 .33076 L
.91031 .32962 L
.91019 .32853 L
.91002 .32744 L
.90981 .32637 L
.90956 .32537 L
.90931 .32447 L
.90906 .32369 L
.90884 .32295 L
.90865 .32223 L
.90848 .32151 L
.90833 .32077 L
.9082 .32001 L
Mistroke
.90808 .31922 L
.90796 .31839 L
.90784 .31757 L
.90772 .31679 L
.90758 .31606 L
.90743 .31542 L
.90725 .31479 L
.90704 .31421 L
.90683 .31367 L
.90663 .31321 L
.90642 .3128 L
.90624 .31246 L
.90608 .31222 L
.90595 .31206 L
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
Mistroke
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
.90599 .31404 L
.90598 .31389 L
.90598 .31373 L
.90597 .31359 L
.90597 .31343 L
.90596 .31325 L
.90598 .31304 L
.90603 .31281 L
.90608 .31254 L
.90613 .31224 L
.90615 .31188 L
.90615 .31147 L
.90608 .311 L
.90592 .31043 L
.90564 .30975 L
.90524 .30896 L
.90474 .30811 L
.90415 .3072 L
.9035 .30627 L
.90289 .30542 L
.90222 .30462 L
.90151 .3039 L
.90073 .30327 L
.9001 .30276 L
.89954 .30236 L
.89905 .30205 L
.89866 .30187 L
.89847 .3018 L
.89848 .30184 L
.89861 .30206 L
.89884 .30231 L
.8991 .30254 L
.89931 .30274 L
.89943 .30292 L
.89943 .30311 L
.8993 .30332 L
.89903 .30357 L
.89858 .3039 L
.89795 .30429 L
.89717 .30474 L
.89638 .30525 L
.89554 .30576 L
.89464 .30625 L
.89372 .30667 L
.89291 .30703 L
Mistroke
.8925 .30728 L
.89224 .30737 L
.89221 .30731 L
.8924 .30712 L
.89273 .3068 L
.89313 .30643 L
.89367 .30604 L
.89439 .30573 L
.89503 .30555 L
.89571 .3056 L
.89643 .30593 L
.89706 .30659 L
.89763 .30759 L
.8982 .30887 L
.89881 .31045 L
.89948 .31243 L
.90021 .31473 L
.90097 .31725 L
.90189 .31999 L
.90294 .3227 L
.90395 .32564 L
.90517 .32869 L
.90647 .33192 L
.9077 .33535 L
.90902 .33876 L
.9103 .34242 L
.9115 .34636 L
.91257 .34999 L
.91354 .35378 L
.9144 .35802 L
.91517 .36144 L
.91589 .36549 L
.91653 .36902 L
.91714 .37285 L
.9177 .37674 L
.9182 .38039 L
.91864 .38415 L
.91901 .38805 L
.91933 .39178 L
.91962 .39544 L
.91988 .3993 L
.92012 .40302 L
.92033 .40693 L
.92052 .41056 L
.92071 .41421 L
.92088 .41765 L
.92105 .42099 L
.92122 .42426 L
.92141 .42729 L
.92163 .43041 L
Mistroke
.92187 .43319 L
.92214 .4359 L
.92243 .43866 L
.92271 .44108 L
.92298 .44347 L
.92324 .44559 L
.92348 .44739 L
.92368 .44893 L
.92384 .45003 L
.92395 .45079 L
.92401 .45119 L
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
.92083 .44535 L
.9209 .4452 L
.92105 .44508 L
.92123 .44504 L
.92139 .44512 L
.92151 .44541 L
.92155 .44597 L
.92145 .44683 L
.92122 .448 L
.92087 .44953 L
.92045 .45121 L
Mistroke
.91996 .45322 L
.91941 .45552 L
.91884 .45789 L
.91832 .46022 L
.91784 .46281 L
.91743 .46585 L
.91712 .46843 L
.91694 .47107 L
.91691 .47382 L
.91702 .47667 L
.9173 .47923 L
.91769 .48205 L
.91815 .48482 L
.9187 .48774 L
.91929 .49088 L
.9199 .49384 L
.92054 .49694 L
.92119 .49974 L
.92183 .50242 L
.92249 .50482 L
.92311 .50683 L
.92373 .50853 L
.92432 .51001 L
.9249 .51133 L
.92546 .51245 L
.92601 .51355 L
.92658 .51469 L
.92716 .51583 L
.92775 .51719 L
.92836 .51881 L
.92899 .52058 L
.92962 .52279 L
.93024 .52526 L
.93081 .52817 L
.9313 .53113 L
.93168 .53453 L
.93196 .53753 L
.93211 .5407 L
.93215 .54386 L
.93209 .54678 L
.93193 .54963 L
.93171 .55209 L
.93146 .55436 L
.9312 .55628 L
.93093 .55798 L
.93069 .55938 L
.9305 .56045 L
.93037 .56124 L
.9303 .56176 L
.9303 .56203 L
Mistroke
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
.93141 .56043 L
.93121 .56074 L
.93093 .56128 L
.93058 .5621 L
.93015 .56321 L
.92965 .56464 L
.92909 .56627 L
.92845 .56815 L
.92773 .57031 L
.92693 .57259 L
.92607 .57519 L
.92524 .57772 L
.92438 .58051 L
.92362 .58335 L
.92287 .5864 L
.92223 .58928 L
.92161 .59236 L
.92101 .59535 L
.92042 .59841 L
.91983 .60138 L
.91923 .60431 L
.91861 .60715 L
.91803 .60974 L
.91746 .61212 L
.91694 .61425 L
.91648 .61606 L
.91608 .61766 L
.91573 .61886 L
.91544 .61978 L
.91524 .62043 L
.91514 .62081 L
.91516 .62094 L
.91527 .62087 L
.91547 .62067 L
.91571 .62042 L
.91597 .62021 L
.9162 .6201 L
.91638 .62013 L
.91644 .62031 L
.91636 .62067 L
.91612 .62121 L
.91567 .62194 L
Mistroke
.91503 .62288 L
.91422 .62402 L
.91328 .62533 L
.91215 .62684 L
.9108 .62849 L
.90954 .63015 L
.90812 .63184 L
.90667 .63357 L
.90556 .63524 L
.90426 .63714 L
.90325 .63887 L
.90234 .64068 L
.90152 .6426 L
.90084 .64465 L
.90036 .64683 L
.90005 .64891 L
.89986 .65121 L
.89972 .65378 L
.89958 .6563 L
.89944 .65912 L
.89926 .66214 L
.89895 .66521 L
.89854 .66856 L
.89805 .67156 L
.89759 .67446 L
.89714 .67711 L
.89672 .67944 L
.89635 .68152 L
.89603 .6832 L
.89578 .68463 L
.8956 .68578 L
.89548 .68661 L
.89542 .68711 L
.8954 .68734 L
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
.89542 .68653 L
.89515 .68679 L
.89483 .68709 L
.89451 .68741 L
.89421 .68774 L
.89395 .68805 L
.89371 .68835 L
.89349 .68867 L
Mistroke
.89329 .68905 L
.8931 .68952 L
.89295 .69011 L
.89285 .69084 L
.8928 .69176 L
.89275 .69298 L
.89267 .69459 L
.89251 .69652 L
.89222 .69888 L
.89177 .70178 L
.89112 .70498 L
.89027 .70847 L
.88923 .71261 L
.8881 .71663 L
.88687 .72084 L
.8856 .72542 L
.8843 .72946 L
.88295 .73409 L
.88157 .7381 L
.88015 .74245 L
.87874 .74658 L
.87731 .75081 L
.8759 .75486 L
.87453 .75907 L
.87325 .76258 L
.87202 .76618 L
.87086 .76967 L
.86974 .77273 L
.86868 .77583 L
.86768 .77844 L
.86672 .78094 L
.86579 .7833 L
.86496 .78527 L
.86416 .78708 L
.86344 .78861 L
.86285 .78981 L
.86241 .79066 L
.86204 .7914 L
.8617 .79203 L
.86134 .79265 L
.86105 .79316 L
.86074 .79366 L
.86046 .79413 L
.86026 .79451 L
.86012 .79482 L
.86002 .79504 L
.85993 .79518 L
.8598 .79528 L
.85962 .79544 L
.85931 .79569 L
Mistroke
.85889 .79603 L
.85841 .79643 L
.8579 .79685 L
.8574 .79722 L
.85697 .79751 L
.85662 .7977 L
.85636 .7978 L
.85619 .79785 L
.85603 .79789 L
.85593 .79794 L
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
.85437 .79941 L
.8541 .79961 L
.85373 .79993 L
.85324 .80039 L
.85262 .80097 L
.85187 .80169 L
.85099 .80255 L
.85003 .80351 L
.849 .80455 L
.848 .80559 L
.8469 .80647 L
.84567 .8077 L
.84438 .80899 L
Mistroke
.84309 .81021 L
.84189 .81126 L
.8408 .81211 L
.83987 .81278 L
.83905 .81331 L
.83832 .81375 L
.83764 .81412 L
.83703 .81444 L
.83641 .81477 L
.83587 .81504 L
.83546 .81522 L
.8352 .81526 L
.83509 .81517 L
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
.83583 .81428 L
.83577 .81451 L
.83565 .81484 L
.83544 .8153 L
.83513 .81586 L
.83474 .81646 L
.83435 .81689 L
.83395 .81724 L
.83353 .81751 L
.83303 .81776 L
.83259 .81797 L
.83209 .81819 L
.83161 .81841 L
.83112 .81861 L
.83063 .81884 L
.83014 .81909 L
.82967 .81936 L
.82917 .81967 L
.82856 .82007 L
.82794 .82058 L
.82731 .8212 L
.82651 .822 L
.82566 .82294 L
.82476 .82394 L
.82394 .82487 L
.82305 .82575 L
.82217 .82655 L
.82136 .82725 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.00440917 0.97619 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.82055 .82789 m
.81995 .82848 L
.8194 .82903 L
.819 .82948 L
.81878 .8298 L
.81872 .82997 L
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
.81963 .82919 L
.81952 .82892 L
.81933 .82861 L
.81907 .82826 L
.81874 .82789 L
.81836 .82751 L
.81801 .82715 L
.81773 .82678 L
.81755 .82642 L
.81752 .82608 L
.81764 .82577 L
.81787 .82552 L
.81818 .82533 L
.81856 .8252 L
.81902 .82514 L
.81952 .82515 L
.82005 .82519 L
.82059 .8252 L
.82115 .82516 L
.82172 .82501 L
.8223 .82476 L
.82291 .82439 L
.82352 .8239 L
.82416 .82325 L
.82492 .82243 L
.82588 .82142 L
.82705 .82025 L
.82852 .81895 L
.83023 .8175 L
.83218 .81592 L
.83442 .81426 L
.83674 .81254 L
.83926 .81076 L
.84192 .80896 L
.84449 .80712 L
.84703 .80535 L
.84965 .80356 L
Mistroke
.85191 .80177 L
.85418 .80012 L
.85622 .79847 L
.85806 .79687 L
.85969 .79526 L
.86114 .79372 L
.86228 .79223 L
.86327 .79077 L
.86411 .78941 L
.86478 .78815 L
.86533 .78697 L
.86575 .78586 L
.86605 .78486 L
.86624 .78385 L
.86634 .78292 L
.86635 .78193 L
.86627 .78105 L
.86613 .78016 L
.86597 .77932 L
.86579 .77854 L
.86562 .77788 L
.86546 .7773 L
.86533 .77683 L
.86523 .77644 L
.86519 .77615 L
.86519 .77598 L
.86524 .77593 L
.86535 .77602 L
.86554 .77619 L
.86579 .77644 L
.86612 .77669 L
.86657 .77685 L
.867 .77687 L
.86753 .77666 L
.86814 .77615 L
.86883 .77528 L
.86963 .77402 L
.8705 .77239 L
.8715 .77032 L
.87255 .76784 L
.87371 .76473 L
.87487 .76187 L
.87611 .75815 L
.8773 .75491 L
.87855 .75096 L
.87983 .74688 L
.88105 .74316 L
.88231 .73938 L
.8835 .73559 L
.88465 .73191 L
Mistroke
.88573 .72837 L
.88673 .72506 L
.88757 .72201 L
.88832 .71933 L
.88899 .71676 L
.88953 .71471 L
.88998 .71287 L
.89032 .71131 L
.89057 .71013 L
.89074 .70927 L
.89085 .70871 L
.89089 .70838 L
.89087 .70824 L
.8908 .70822 L
.89066 .70825 L
.89046 .70824 L
.89018 .70813 L
.88982 .7079 L
.88938 .70753 L
.88887 .70706 L
.88828 .70649 L
.8877 .70588 L
.88709 .70525 L
.88648 .70466 L
.8859 .70412 L
.88542 .70367 L
.88506 .7033 L
.88484 .70304 L
.88478 .70287 L
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
Mistroke
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
.88236 .70926 L
.88242 .70908 L
.88257 .70876 L
.8828 .70828 L
.88307 .70767 L
.88343 .7069 L
.88388 .70597 L
.88438 .70484 L
.885 .70346 L
.8857 .70182 L
.88649 .6999 L
.8874 .69781 L
.88837 .69538 L
.88944 .69276 L
.8905 .68991 L
.89158 .68674 L
.89268 .68371 L
.89372 .68038 L
.89479 .67707 L
.89578 .67363 L
.89684 .67025 L
.8978 .66675 L
.89892 .66323 L
.89997 .65976 L
.90113 .65614 L
.90243 .65252 L
.90366 .64886 L
.90496 .64507 L
.90646 .64134 L
.90765 .63756 L
.90917 .63368 L
.91063 .62977 L
.91198 .62593 L
.9135 .62196 L
.91497 .61798 L
Mistroke
.91631 .61402 L
.91757 .61014 L
.91874 .60634 L
.91974 .60253 L
.92073 .59875 L
.92165 .59506 L
.92252 .59134 L
.92346 .58749 L
.92438 .58402 L
.92537 .58032 L
.9263 .57664 L
.92723 .57272 L
.92804 .56919 L
.9288 .56542 L
.92944 .56144 L
.92995 .55776 L
.93037 .55379 L
.93069 .5498 L
.93092 .54546 L
.93103 .54157 L
.93104 .5373 L
.93094 .53288 L
.93076 .52856 L
.93053 .52417 L
.93028 .51978 L
.93003 .51521 L
.92979 .51104 L
.92957 .50655 L
.92937 .50205 L
.92916 .49767 L
.92891 .49345 L
.92862 .48895 L
.9283 .48449 L
.92795 .47991 L
.92759 .47562 L
.92724 .47162 L
.9269 .46781 L
.92658 .46399 L
.92627 .46065 L
.92598 .45747 L
.92566 .45408 L
.92535 .45148 L
.92503 .44905 L
.92471 .44671 L
.92438 .44446 L
.92405 .44232 L
.92371 .44037 L
.92335 .43836 L
.92297 .43618 L
.9226 .43384 L
Mistroke
.92223 .43135 L
.92188 .4286 L
.92155 .42567 L
.92125 .42253 L
.92099 .41919 L
.92078 .41569 L
.9206 .4123 L
.92041 .40862 L
.92019 .40483 L
.91992 .40103 L
.91957 .39691 L
.91916 .39279 L
.91868 .38851 L
.91811 .3838 L
.91749 .37957 L
.91681 .37503 L
.91611 .37042 L
.9154 .36583 L
.91469 .36124 L
.914 .35683 L
.91334 .35265 L
.91271 .34864 L
.91211 .34488 L
.91155 .34142 L
.91102 .33832 L
.91054 .33556 L
.9101 .33322 L
.90971 .3312 L
.90937 .32955 L
.90909 .3282 L
.90884 .32715 L
.90864 .32635 L
.90848 .32572 L
.90836 .32521 L
.90829 .32473 L
.90825 .32426 L
.90822 .32377 L
.90821 .32326 L
.9082 .32262 L
.90819 .32183 L
.90816 .32087 L
.90808 .31977 L
.90793 .31851 L
.90768 .31704 L
.90733 .31545 L
.90688 .31365 L
.90632 .31172 L
.90565 .30963 L
.90487 .30753 L
.90399 .30528 L
Mistroke
.90297 .3029 L
.90182 .30036 L
.90043 .29758 L
.89902 .29481 L
.89741 .29175 L
.89565 .28849 L
.89375 .28507 L
.89163 .28156 L
.88962 .27792 L
.88745 .27435 L
.88504 .27063 L
.88294 .26712 L
.88062 .26341 L
.87813 .25957 L
.87581 .25592 L
.87339 .2522 L
.87101 .24853 L
.86849 .24499 L
.86629 .24171 L
.86402 .23833 L
.86184 .2351 L
.85951 .23176 L
.85736 .22866 L
.85514 .22543 L
.85295 .22217 L
.8508 .21895 L
.84871 .21584 L
.8467 .21267 L
.84462 .20944 L
.84267 .20656 L
.84061 .20332 L
.83847 .20003 L
.83642 .19699 L
.83422 .194 L
.83188 .19062 L
.82975 .18749 L
.82742 .1843 L
.82513 .18109 L
.82279 .17797 L
.82039 .17474 L
.81814 .17172 L
.81586 .16864 L
.81365 .16557 L
.81149 .16266 L
.80948 .15978 L
.80751 .15706 L
.80555 .15425 L
.80366 .15173 L
.80169 .14907 L
.79972 .1465 L
Mistroke
.79777 .14387 L
.79578 .14132 L
.79385 .13882 L
.79195 .13633 L
.79017 .13422 L
.78852 .13228 L
.787 .13048 L
.78567 .12885 L
.78459 .12758 L
.78373 .12653 L
.78313 .12573 L
.78279 .1252 L
.78268 .1249 L
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
Mistroke
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
.78498 .12519 L
.78479 .12517 L
.78451 .12515 L
.78411 .12516 L
.78358 .12522 L
.78292 .12534 L
.78212 .12555 L
.78121 .12585 L
.78022 .12623 L
.77917 .12671 L
.77812 .12726 L
.77717 .12787 L
.77623 .12853 L
.77543 .1292 L
.77476 .12986 L
.77422 .13042 L
.77381 .13087 L
.77354 .13113 L
.77341 .1312 L
.77338 .13105 L
.77343 .13067 L
.7735 .13009 L
.77353 .12932 L
.7734 .12832 L
.77305 .12708 L
.77246 .12573 L
.77161 .12414 L
.77054 .1224 L
.76922 .12062 L
.76764 .11865 L
.76591 .11687 L
.76406 .11503 L
.76205 .11325 L
.76001 .11162 L
.75752 .1099 L
.75539 .10851 L
.75322 .10716 L
.75084 .10583 L
.74828 .10455 L
Mistroke
.74552 .10329 L
.74241 .10199 L
.73956 .10063 L
.73628 .09934 L
.73284 .09788 L
.72919 .09629 L
.72534 .09477 L
.72125 .09303 L
.71657 .09115 L
.71253 .0892 L
.70763 .08704 L
.70333 .08521 L
.6996 .08335 L
.69515 .08142 L
.69123 .0797 L
.68712 .07795 L
.68341 .0765 L
.67955 .07491 L
.67612 .07358 L
.67254 .07228 L
.66967 .07101 L
.66683 .06983 L
.66404 .06875 L
.6619 .06779 L
.65999 .06697 L
.65838 .06633 L
.65716 .06581 L
.65623 .06539 L
.65558 .06505 L
.65518 .06476 L
.65501 .06455 L
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
Mistroke
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
.65572 .06477 L
.65532 .06459 L
.65476 .06433 L
.65406 .06399 L
.65321 .06358 L
.65223 .06314 L
.65124 .06267 L
.6501 .0622 L
.64899 .06174 L
.64785 .06128 L
.64673 .06085 L
.64572 .06047 L
.6449 .06016 L
.64429 .05995 L
.64386 .05982 L
.64359 .05978 L
.64339 .05979 L
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
Mistroke
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
Mistroke
.63684 .05739 L
.6367 .05755 L
.63649 .05785 L
.63621 .05828 L
.63584 .0588 L
.63539 .0594 L
.63485 .06009 L
.63428 .06077 L
.63368 .0615 L
.63311 .06212 L
.6326 .06264 L
.63219 .06304 L
.6319 .06332 L
.63175 .06345 L
.63174 .06346 L
.63183 .06335 L
.63198 .06315 L
.63213 .0629 L
.63234 .06264 L
.63259 .06244 L
.63292 .06234 L
.63336 .06237 L
.63398 .06264 L
.63482 .0629 L
.63588 .06327 L
.63717 .06378 L
.63863 .06441 L
.64037 .0651 L
.64224 .0658 L
.64419 .06648 L
.64648 .06712 L
.64877 .06768 L
.65142 .06817 L
.65379 .06863 L
.65625 .0691 L
.65864 .06957 L
.66092 .07005 L
.66303 .07054 L
.665 .07105 L
.66682 .07157 L
.66854 .07212 L
.6701 .0727 L
.67152 .0733 L
.67283 .07387 L
.67399 .07439 L
.67496 .07485 L
.67574 .07526 L
.67632 .07559 L
.67672 .07584 L
.67697 .07601 L
Mistroke
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
.67668 .07597 L
.67685 .07627 L
.67707 .07666 L
.67733 .07707 L
.67762 .07747 L
.67791 .07782 L
.67822 .07812 L
.67854 .07836 L
.67888 .07854 L
.67918 .07865 L
.67943 .07868 L
.67959 .0786 L
.67965 .0784 L
.67959 .07806 L
.67942 .07758 L
.67911 .077 L
.67865 .07634 L
.67799 .07566 L
.67711 .07496 L
.67598 .07423 L
.67457 .07346 L
.67294 .07265 L
.67098 .07173 L
.66864 .0707 L
.6663 .06958 L
.66339 .06832 L
.66041 .0669 L
.65722 .06555 L
.6533 .06383 L
.64998 .06238 L
.64613 .06087 L
.64215 .05919 L
.63772 .05739 L
.63365 .0558 L
.62937 .05425 L
.62459 .05238 L
.62057 .05088 L
.61573 .04936 L
.61158 .04774 L
Mistroke
.6065 .04618 L
.60254 .04458 L
.59804 .04301 L
.59401 .04179 L
.59 .04058 L
.5864 .03946 L
.58317 .03859 L
.58025 .0378 L
.57763 .03713 L
.57526 .03659 L
.57365 .03623 L
.57224 .03602 L
.57115 .03591 L
.57035 .03591 L
.56984 .03597 L
.56957 .03605 L
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
.57246 .03635 L
.57223 .03635 L
.57191 .03634 L
Mistroke
.57148 .03632 L
.57095 .0363 L
.57031 .03628 L
.56958 .03626 L
.56877 .03623 L
.56788 .0362 L
.56689 .03617 L
.56581 .03613 L
.56465 .03609 L
.56346 .03605 L
.56222 .036 L
.56096 .03596 L
.55969 .03592 L
.55849 .03588 L
.55728 .03584 L
.55605 .0358 L
.55472 .03576 L
.55344 .03572 L
.55209 .03567 L
.55065 .03563 L
.54914 .03558 L
.54757 .03553 L
.54604 .03548 L
.54482 .03543 L
.54358 .03539 L
.54242 .03536 L
.54154 .03533 L
.5407 .03533 L
.53992 .03534 L
.53921 .03535 L
.53856 .03533 L
.53787 .03528 L
.53704 .03517 L
.53597 .03503 L
.53457 .03485 L
.53286 .03466 L
.53052 .03445 L
.52755 .03425 L
.52476 .03406 L
.52105 .03386 L
.51654 .0337 L
.51267 .03355 L
.50794 .03343 L
.5033 .03333 L
.4993 .03327 L
.49487 .03325 L
.49121 .03327 L
.48752 .03331 L
.4847 .03336 L
.48218 .03341 L
Mistroke
.4801 .03344 L
.47858 .03344 L
.47734 .0334 L
.47639 .03334 L
.47572 .03329 L
.4752 .03325 L
.47473 .03322 L
.47427 .0332 L
.4738 .03319 L
.4733 .03318 L
.47276 .03316 L
.47221 .03314 L
.47164 .03312 L
.47103 .0331 L
.47042 .03308 L
.46989 .03307 L
.46947 .03306 L
.46917 .03305 L
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
.46966 .03306 L
.46939 .03305 L
.4689 .03304 L
.46815 .03302 L
.46712 .03299 L
.46584 .03295 L
.46431 .0329 L
.46253 .03285 L
.46054 .03279 L
.45868 .03272 L
.45662 .03266 L
.45473 .0326 L
.45288 .03254 L
.45115 .03249 L
.44977 .03244 L
.44865 .03238 L
.44779 .03231 L
.4472 .03222 L
.44682 .03214 L
Mistroke
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
.44046 .03656 L
.44008 .03649 L
.43947 .03641 L
.43857 .03632 L
.43733 .03622 L
.43574 .03612 L
.43377 .03602 L
.43133 .03593 L
.42862 .03582 L
.4254 .03573 L
.42215 .03563 L
.41865 .03551 L
.41497 .03538 L
.41097 .03525 L
.4075 .03512 L
.40366 .03502 L
.40003 .03496 L
.3964 .03494 L
.39311 .03499 L
.38963 .03512 L
.38645 .03534 L
.3832 .03567 L
.38012 .03614 L
.37691 .03676 L
.37412 .03746 L
.37144 .03824 L
.36879 .03907 L
.36651 .03996 L
Mistroke
.36426 .04087 L
.36238 .04181 L
.36063 .04275 L
.35914 .04363 L
.35786 .04447 L
.35679 .04527 L
.35593 .046 L
.35529 .04667 L
.35481 .04727 L
.35445 .04778 L
.35416 .04824 L
.35393 .04862 L
.35371 .04895 L
.3535 .04921 L
.35334 .04942 L
.35324 .04958 L
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
.354 .04888 L
.35369 .04881 L
.35315 .04884 L
.35232 .04902 L
Mistroke
.35115 .04942 L
.34964 .05007 L
.3477 .05101 L
.34527 .05223 L
.34269 .05361 L
.33959 .05519 L
.3363 .05708 L
.33265 .05912 L
.32896 .06132 L
.32485 .06377 L
.3211 .06601 L
.31713 .06847 L
.31302 .07078 L
.30937 .07299 L
.30547 .07529 L
.30211 .07726 L
.29864 .07928 L
.29567 .08109 L
.29277 .08291 L
.29025 .08456 L
.28803 .08611 L
.28616 .08746 L
.28458 .08868 L
.28336 .08971 L
.28245 .09049 L
.28177 .09112 L
.28127 .09163 L
.28087 .09207 L
.28049 .09246 L
.28007 .09287 L
.2796 .0933 L
.27909 .09379 L
.27851 .09432 L
.27787 .09488 L
.27725 .09542 L
.27662 .09604 L
.27609 .09662 L
.27563 .09719 L
.27524 .09772 L
.27492 .09816 L
.27468 .09848 L
.27446 .09864 L
.27415 .0987 L
.27367 .09873 L
.27293 .09876 L
.27185 .09889 L
.27033 .09922 L
.26834 .09983 L
.2663 .10078 L
.26346 .10196 L
Mistroke
.26065 .10344 L
.2572 .1053 L
.25351 .10746 L
.24949 .10981 L
.24575 .11216 L
.24106 .1148 L
.23718 .11756 L
.2324 .1206 L
.22875 .12339 L
.22455 .12638 L
.22062 .1293 L
.21651 .13231 L
.21297 .13501 L
.20922 .13773 L
.20633 .14018 L
.20353 .14255 L
.20112 .14463 L
.1991 .14645 L
.19746 .14808 L
.19625 .14936 L
.19535 .15037 L
.19474 .15111 L
.19436 .15159 L
.19418 .15185 L
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
.19471 .15121 L
.19443 .15165 L
.19406 .15228 L
.19363 .15307 L
.19315 .15401 L
.19265 .15507 L
Mistroke
.19215 .15611 L
.19166 .15722 L
.19118 .15834 L
.19073 .15945 L
.19034 .16043 L
.19002 .1613 L
.1898 .16202 L
.18969 .16254 L
.18969 .16283 L
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
.19037 .16208 L
.19013 .1624 L
.18972 .163 L
.18908 .16393 L
.18817 .16523 L
.18696 .16696 L
.18559 .16886 L
.1839 .17132 L
.182 .17398 L
.17981 .17718 L
.17758 .18036 L
.17527 .1839 L
.17277 .18781 L
.17036 .1914 L
.16782 .19534 L
.16535 .19956 L
.16295 .20341 L
.16052 .2075 L
.15802 .2119 L
.15562 .21601 L
.15325 .22006 L
.15074 .22467 L
.14837 .22852 L
.14581 .233 L
.14335 .2369 L
.1408 .24113 L
.13817 .24544 L
.13566 .24941 L
.13314 .2534 L
.13068 .25729 L
.12822 .26124 L
.12592 .26485 L
.12363 .26855 L
.12132 .27246 L
.11904 .27624 L
Mistroke
.11688 .27975 L
.11461 .2837 L
.11236 .28755 L
.11015 .29105 L
.10791 .29492 L
.10592 .2984 L
.10397 .30193 L
.10217 .30535 L
.10057 .30841 L
.09909 .31131 L
.09791 .31373 L
.09692 .31593 L
.09611 .3178 L
.09552 .31925 L
.09513 .32038 L
.09495 .32117 L
.09493 .32164 L
.09503 .32184 L
.09518 .32181 L
.09535 .32164 L
.09549 .32138 L
.09557 .32112 L
.09557 .32091 L
.09548 .32084 L
.09532 .32098 L
.09508 .32138 L
.09478 .32211 L
.09438 .32326 L
.09389 .32488 L
.0933 .32698 L
.09261 .32974 L
.09183 .3328 L
.091 .33662 L
.09014 .34117 L
.08926 .34566 L
.08842 .35113 L
.08762 .35606 L
.08689 .36169 L
.08625 .36762 L
.08569 .37342 L
.08521 .37823 L
.08483 .38335 L
.08453 .38859 L
.08433 .39282 L
.08422 .39615 L
.08416 .39929 L
.08415 .40209 L
.08417 .40407 L
.0842 .4056 L
.08423 .40667 L
Mistroke
.08425 .40734 L
.08426 .40768 L
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
.08422 .41159 L
.08438 .41176 L
.08458 .41195 L
.08483 .41213 L
.08513 .41228 L
.08548 .41241 L
.08589 .41253 L
.08638 .41265 L
.08698 .41281 L
Mistroke
.08769 .41301 L
.08848 .41327 L
.08934 .41361 L
.09027 .41406 L
.09123 .41463 L
.09212 .41537 L
.09304 .41627 L
.0939 .41729 L
.09478 .41851 L
.09551 .41996 L
.09616 .42158 L
.09669 .42341 L
.09709 .42547 L
.09732 .42781 L
.09738 .43036 L
.09727 .43317 L
.09701 .43617 L
.09659 .43946 L
.09603 .44253 L
.09532 .44586 L
.09445 .44943 L
.09335 .45287 L
.092 .45647 L
.09051 .46027 L
.08874 .46404 L
.08675 .46757 L
.08434 .47139 L
.08251 .47519 L
.08008 .4793 L
.07828 .48308 L
.07594 .48713 L
.07407 .49136 L
.07243 .49569 L
.07099 .49994 L
.06969 .5043 L
.06866 .50799 L
.06793 .51165 L
.06748 .51482 L
.06726 .51758 L
.06721 .51978 L
.06725 .52145 L
.06733 .52266 L
.06743 .52348 L
.06745 .52401 L
.0674 .52433 L
.06735 .52457 L
.06735 .52489 L
.06741 .52544 L
.06753 .52631 L
.0677 .52755 L
Mistroke
.06794 .52932 L
.06824 .53177 L
.06863 .53473 L
.0691 .53839 L
.06967 .5425 L
.07035 .54705 L
.07106 .55225 L
.07183 .55708 L
.0726 .56291 L
.07331 .56802 L
.07401 .57374 L
.0747 .5799 L
.07537 .58514 L
.07608 .5915 L
.07679 .59671 L
.07753 .60276 L
.07834 .6082 L
.0792 .61357 L
.0801 .61908 L
.08099 .62433 L
.08159 .62952 L
.08248 .6353 L
.08334 .63999 L
.08422 .64523 L
.0851 .65021 L
.08591 .65472 L
.08662 .65931 L
.08718 .66295 L
.08759 .66638 L
.08789 .66968 L
.08808 .67215 L
.0882 .67436 L
.0883 .67634 L
.08841 .67798 L
.08857 .67933 L
.08877 .68044 L
.08903 .68143 L
.08933 .68241 L
.08969 .68339 L
.09008 .68452 L
.09051 .68584 L
.09097 .6874 L
.09144 .68911 L
.09187 .69097 L
.09226 .69285 L
.09259 .69466 L
.09286 .69632 L
.09306 .69774 L
.09318 .69899 L
.09324 .70003 L
Mistroke
.09324 .70085 L
.09321 .70143 L
.09316 .70178 L
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
.09321 .70088 L
.09344 .70151 L
.09375 .7025 L
.09413 .70386 L
.09458 .70556 L
.0951 .70768 L
.09571 .71018 L
.09638 .71256 L
.09708 .71564 L
.09782 .71849 L
.09856 .7216 L
.09928 .72482 L
.09995 .72775 L
.10056 .73056 L
.10111 .73293 L
.10158 .73499 L
.10197 .73663 L
.10229 .73798 L
.10254 .73906 L
.10272 .73989 L
.10282 .74053 L
.10287 .74102 L
.10289 .74136 L
.10287 .74162 L
.10283 .74185 L
.10278 .74208 L
.10274 .74234 L
.1027 .74268 L
.10267 .7431 L
.10266 .74357 L
.10265 .74401 L
.10265 .74437 L
.10264 .74468 L
.10264 .74492 L
.10264 .74509 L
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
Mistroke
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
.10247 .74294 L
.10262 .74313 L
.10287 .74344 L
.10321 .74387 L
.10368 .74441 L
.1043 .74506 L
.10509 .74585 L
.10608 .74679 L
.10724 .74791 L
.10864 .74923 L
.11017 .75064 L
.11198 .75227 L
.11392 .75419 L
.11612 .75637 L
.11846 .7589 L
.12125 .76172 L
.12417 .76481 L
.12691 .76815 L
.12995 .77172 L
.13309 .77529 L
.13626 .77909 L
.1395 .78304 L
.14289 .78682 L
.14633 .79084 L
.14996 .79486 L
.1533 .79868 L
.15706 .80255 L
.16064 .80647 L
.16442 .81051 L
.16821 .8141 L
.17204 .81798 L
.17613 .82183 L
.18001 .82589 L
.18408 .82982 L
.18814 .83384 L
Mistroke
.19236 .83795 L
.19642 .84192 L
.20051 .84582 L
.20478 .84976 L
.2088 .85366 L
.21297 .85729 L
.21701 .86104 L
.22109 .8649 L
.22497 .86829 L
.22888 .87194 L
.23236 .87509 L
.2357 .87803 L
.23855 .88073 L
.24118 .88313 L
.24338 .88526 L
.24512 .88715 L
.24647 .88853 L
.24739 .8896 L
.24791 .89036 L
.2481 .89081 L
.24802 .89097 L
.24775 .89083 L
.24735 .89055 L
.24696 .89022 L
.24668 .88994 L
.24659 .88979 L
.24677 .88983 L
.24725 .8901 L
.24804 .89057 L
.24914 .89131 L
.25057 .89221 L
.25232 .89327 L
.25419 .89441 L
.25649 .89569 L
.25898 .89714 L
.26162 .8986 L
.26462 .90022 L
.26775 .90186 L
.27116 .90357 L
.27464 .90531 L
.27862 .9069 L
.28251 .90862 L
.28619 .91029 L
.2903 .91199 L
.29485 .91374 L
.29884 .91547 L
.3036 .91719 L
.30788 .91892 L
.31246 .92056 L
.31702 .92218 L
Mistroke
.32145 .92378 L
.32583 .92536 L
.33026 .9269 L
.33471 .92847 L
.33901 .92997 L
.34341 .93151 L
.34799 .93302 L
.35218 .9346 L
.35669 .93607 L
.3612 .93771 L
.36562 .93917 L
.37015 .94067 L
.37472 .94219 L
.37928 .94376 L
.38383 .94534 L
.38824 .94683 L
.39271 .94818 L
.39712 .94957 L
.40157 .951 L
.406 .95237 L
.41005 .95371 L
.41409 .95503 L
.41824 .95639 L
.42224 .95772 L
.42609 .95899 L
.43003 .96023 L
.43382 .96141 L
.43765 .96258 L
.44139 .96361 L
.44525 .96455 L
.44895 .96536 L
.45254 .96601 L
.4561 .96653 L
.45955 .96693 L
.46266 .9672 L
.46566 .96734 L
.46827 .96735 L
.47065 .96726 L
.47275 .96708 L
.47446 .96686 L
.47588 .96665 L
.47697 .96646 L
.47774 .9663 L
.47822 .96618 L
.4785 .9661 L
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
Mistroke
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
.47597 .96608 L
.4759 .96594 L
.47585 .96579 L
.47581 .96567 L
.47581 .96558 L
.47589 .96551 L
.47617 .96544 L
.47671 .96536 L
.47757 .96527 L
.47876 .96518 L
.48039 .96509 L
.48239 .96501 L
.4849 .96496 L
.48782 .96491 L
.4911 .96482 L
.49492 .96465 L
.49912 .96435 L
.5037 .96389 L
.50854 .96325 L
.51372 .96243 L
.5191 .96147 L
.52438 .96046 L
.5301 .95941 L
.53546 .95834 L
.54136 .95728 L
.54686 .95623 L
.55274 .95518 L
.5582 .95417 L
Mistroke
.56412 .9532 L
.56989 .9523 L
.57564 .95145 L
.58143 .95066 L
.58668 .94989 L
.59227 .94911 L
.59757 .9483 L
.60304 .94742 L
.60815 .94661 L
.61344 .94568 L
.61807 .94467 L
.62294 .94368 L
.62756 .94268 L
.63235 .94168 L
.6363 .94072 L
.6402 .93983 L
.64405 .93902 L
.64765 .93828 L
.65114 .93762 L
.65468 .93699 L
.65778 .93639 L
.66071 .93577 L
.66365 .9351 L
.6665 .93433 L
.66936 .93345 L
.67199 .93244 L
.67474 .93131 L
.67757 .93006 L
.68057 .92867 L
.68376 .92707 L
.68708 .92524 L
.69067 .92333 L
.69428 .92115 L
.69824 .91882 L
.70216 .9163 L
.7061 .91381 L
.71002 .91107 L
.71401 .90846 L
.7178 .90586 L
.72179 .90298 L
.72573 .90007 L
.72959 .89751 L
.73326 .89475 L
.73699 .89202 L
.74073 .88921 L
.74445 .88644 L
.74838 .88346 L
.75192 .88079 L
.75572 .87794 L
.75967 .87506 L
Mistroke
.76346 .87216 L
.76737 .8693 L
.7713 .86638 L
.77537 .86332 L
.77909 .86047 L
.78286 .85746 L
.78667 .85456 L
.79005 .85174 L
.79354 .84897 L
.79697 .84624 L
.80046 .84354 L
.80385 .8408 L
.80736 .83809 L
.8108 .83534 L
.81423 .83253 L
.81779 .82978 L
.82121 .82696 L
.82459 .82425 L
.82794 .82159 L
.83111 .81894 L
.8342 .81641 L
.83717 .81405 L
.83978 .81178 L
.84222 .80965 L
.84433 .80769 L
.84615 .80596 L
.84769 .80445 L
.84893 .80318 L
.84995 .80215 L
.85075 .80134 L
.85142 .80071 L
.85195 .80021 L
.85237 .79981 L
.8527 .79946 L
.85294 .79914 L
.85314 .79881 L
.85325 .79846 L
.85333 .79805 L
.8534 .79757 L
.85348 .79697 L
.85359 .79627 L
.85367 .79555 L
.85371 .79488 L
.85369 .79428 L
.85363 .79379 L
.85355 .79348 L
.85345 .79336 L
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
Mistroke
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
.85295 .79839 L
.8533 .79833 L
.85389 .79807 L
.85452 .79766 L
.8554 .79693 L
.85646 .79586 L
.85765 .79438 L
.85911 .79246 L
.86074 .79002 L
.86257 .78714 L
.86455 .78379 L
.86664 .77986 L
.86873 .77599 L
.87084 .77154 L
.87287 .76678 L
.87479 .76219 L
.87656 .75737 L
.8782 .75268 L
.87969 .74824 L
.88099 .74412 L
.88214 .74051 L
.88312 .73704 L
.88393 .73431 L
.8846 .73169 L
.88516 .72947 L
.88564 .7274 L
.88606 .72545 L
.88643 .72362 L
.8868 .72185 L
.88724 .71996 L
.8878 .7178 L
.88849 .71533 L
.88935 .71251 L
.8903 .70909 L
Mistroke
.89144 .7054 L
.89266 .7011 L
.89399 .69669 L
.89549 .69164 L
.89694 .68691 L
.89868 .68164 L
.90036 .67572 L
.90197 .67049 L
.90378 .66468 L
.90545 .65876 L
.90721 .65249 L
.90882 .64688 L
.91043 .64093 L
.91205 .63459 L
.91341 .62926 L
.91483 .62355 L
.91628 .61783 L
.9176 .61214 L
.91898 .60648 L
.92027 .60095 L
.92151 .59586 L
.92268 .59096 L
.9238 .58634 L
.92481 .58227 L
.9257 .57866 L
.9265 .57546 L
.92716 .57271 L
.92767 .5706 L
.92805 .56901 L
.92828 .56787 L
.92839 .56718 L
.92841 .5669 L
.92835 .56694 L
.92823 .56718 L
.92808 .56752 L
.92793 .56791 L
.92779 .56827 L
.92769 .56854 L
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
.92768 .56796 L
.92766 .5678 L
.92765 .56762 L
Mistroke
.92766 .56739 L
.92771 .56705 L
.92779 .5666 L
.92791 .56603 L
.92807 .56539 L
.92826 .56468 L
.9285 .56393 L
.92876 .56316 L
.92905 .56238 L
.92936 .56161 L
.92968 .56086 L
.92998 .56014 L
.93026 .55948 L
.9305 .55888 L
.93071 .55836 L
.93087 .55799 L
.931 .55772 L
.93108 .55755 L
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
.93103 .55653 L
.9311 .55607 L
Mistroke
.93119 .55526 L
.9313 .55392 L
.93142 .55197 L
.93154 .54939 L
.93164 .54643 L
.93172 .54298 L
.93176 .53899 L
.93177 .53458 L
.93175 .52994 L
.93166 .52488 L
.9315 .52034 L
.93126 .51545 L
.93095 .51071 L
.93059 .50622 L
.93016 .50201 L
.92967 .49764 L
.92922 .49331 L
.92874 .48874 L
.92826 .48428 L
.92782 .47999 L
.92738 .47545 L
.927 .47067 L
.92666 .46666 L
.92638 .4624 L
.92613 .45846 L
.92594 .45532 L
.9258 .45227 L
.9257 .44999 L
.92562 .44807 L
.92555 .44663 L
.92546 .44568 L
.92534 .44497 L
.92516 .44425 L
.92491 .44336 L
.9246 .44216 L
.92425 .44059 L
.92386 .43845 L
.92342 .43584 L
.92297 .43266 L
.92253 .429 L
.92211 .42511 L
.92171 .42092 L
.92132 .41653 L
.92095 .41256 L
.92059 .40822 L
.92023 .40385 L
.91985 .39957 L
.91943 .39543 L
.91894 .39113 L
.91839 .38676 L
Mistroke
.9178 .38214 L
.91722 .3782 L
.91657 .37398 L
.91591 .36984 L
.91525 .36577 L
.91462 .36198 L
.91406 .3583 L
.91358 .35503 L
.91319 .35228 L
.91286 .3498 L
.91263 .34775 L
.91249 .34613 L
.91243 .34498 L
.91244 .34428 L
.91249 .34387 L
.91255 .34368 L
.91261 .34366 L
.91266 .34371 L
.91267 .34374 L
.91264 .34366 L
.91256 .34343 L
.91243 .343 L
.91226 .34235 L
.91207 .34147 L
.91185 .34035 L
.91163 .33906 L
.91139 .33757 L
.91114 .336 L
.91092 .33449 L
.9107 .33291 L
.91051 .33146 L
.91035 .33002 L
.91023 .32874 L
.91016 .32762 L
.91013 .32672 L
.91013 .32606 L
.91015 .32561 L
.91018 .3253 L
.91019 .32503 L
.91018 .32473 L
.91014 .32428 L
.91005 .32364 L
.9099 .32276 L
.90968 .32165 L
.90939 .32035 L
.90902 .31887 L
.90859 .31735 L
.90811 .31572 L
.90757 .31405 L
.90701 .31237 L
Mistroke
.90645 .3107 L
.9059 .30913 L
.90539 .30766 L
.90492 .30637 L
.90453 .30533 L
.90421 .30454 L
.90396 .304 L
.90378 .30368 L
.90366 .30353 L
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
Mistroke
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
.89591 .30151 L
.89609 .3013 L
.89632 .30095 L
.89659 .30041 L
.89681 .29963 L
.89696 .29858 L
.89695 .29722 L
.89673 .2955 L
.89631 .29358 L
.89566 .2913 L
.89472 .28869 L
.89351 .28576 L
.89202 .28266 L
.8902 .27887 L
.88834 .27559 L
.88615 .27182 L
.88382 .26788 L
Mistroke
.88147 .26375 L
.87878 .25932 L
.87638 .25527 L
.87372 .25103 L
.87084 .24635 L
.86826 .24245 L
.86549 .23818 L
.86274 .23389 L
.85979 .22991 L
.85737 .22577 L
.85479 .22212 L
.85236 .21847 L
.8499 .21506 L
.84766 .21176 L
.84546 .20852 L
.84327 .20546 L
.8411 .20236 L
.83889 .19927 L
.83666 .19611 L
.83438 .19291 L
.83197 .18941 L
.82958 .1861 L
.82701 .18252 L
.82444 .17926 L
.82153 .17544 L
.81886 .17169 L
.81617 .16786 L
.81352 .16428 L
.81069 .16038 L
.80795 .1566 L
.80518 .15285 L
.80256 .14919 L
.79999 .14574 L
.79755 .14241 L
.79539 .13934 L
.79333 .13649 L
.79146 .13388 L
.78982 .13161 L
.78841 .1297 L
.78724 .12809 L
.78635 .12689 L
.78565 .12598 L
.78514 .12535 L
.7848 .12498 L
.78461 .12481 L
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
Mistroke
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
.78487 .12528 L
.78473 .12507 L
.78458 .12482 L
.78446 .12456 L
.78435 .12428 L
.78424 .12399 L
.78407 .12367 L
.78382 .12329 L
.78348 .12286 L
.78305 .1224 L
.7825 .1219 L
.78185 .12149 L
.78112 .12107 L
.78034 .12067 L
.77955 .12028 L
.77888 .11988 L
.77812 .11947 L
.77739 .11908 L
.77662 .1187 L
.77583 .11837 L
.77507 .11816 L
.77437 .1181 L
.7737 .11816 L
.77299 .11839 L
.77219 .11874 L
.77123 .11916 L
.77005 .11963 L
.76879 .12019 L
.76728 .1208 L
.76546 .12144 L
.76347 .12215 L
Mistroke
.76143 .12289 L
.75911 .12373 L
.75679 .12465 L
.75425 .12563 L
.75199 .12667 L
.74956 .1277 L
.74708 .1288 L
.74504 .12993 L
.74297 .13111 L
.7409 .13235 L
.73896 .13357 L
.73712 .13495 L
.73542 .13624 L
.73375 .13755 L
.73225 .1388 L
.73086 .13993 L
.7296 .1409 L
.72852 .14165 L
.72769 .14214 L
.727 .1424 L
.72645 .14247 L
.72606 .1424 L
.72584 .14224 L
.7258 .142 L
.72593 .14177 L
.72624 .14153 L
.72668 .14141 L
.72725 .14145 L
.72794 .14172 L
.72872 .14231 L
.72957 .14329 L
.73053 .14456 L
.73159 .14636 L
.73282 .14836 L
.73423 .15081 L
.73565 .15344 L
.73727 .15638 L
.73899 .15916 L
.74078 .16231 L
.74268 .16522 L
.74463 .16835 L
.7466 .17146 L
.7487 .17466 L
.7508 .17797 L
.75287 .18118 L
.75505 .18458 L
.75707 .18802 L
.75915 .19152 L
.76127 .19527 L
.76321 .19849 L
Mistroke
.76515 .2018 L
.76707 .20511 L
.76876 .20786 L
.77039 .21054 L
.77182 .21286 L
.77305 .21495 L
.77406 .21652 L
.77484 .21785 L
.7754 .2187 L
.77577 .2193 L
.77601 .2196 L
.77612 .21965 L
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
.77541 .21886 L
.77552 .21916 L
.77579 .21962 L
.77624 .22027 L
.7769 .22112 L
.77778 .22211 L
.77887 .22326 L
.78015 .22456 L
.78137 .22591 L
.78295 .22728 L
.78442 .2286 L
.78594 .22975 L
.78744 .23079 L
.7888 .23162 L
.78998 .23233 L
.79104 .23298 L
.79188 .23344 L
.79264 .23388 L
.79334 .23428 L
.79403 .23469 L
.79478 .23515 L
.79566 .23571 L
.79672 .23642 L
.79794 .23727 L
.7994 .2384 L
.80114 .23973 L
.80316 .24134 L
.80549 .24318 L
.80817 .24516 L
.81094 .24736 L
.81401 .24946 L
.81702 .25162 L
Mistroke
.82028 .25389 L
.82364 .25606 L
.82685 .25806 L
.83032 .26008 L
.83374 .26199 L
.83725 .26378 L
.8408 .26531 L
.8447 .26664 L
.84788 .26776 L
.85135 .26862 L
.8549 .26929 L
.85797 .2698 L
.86101 .27017 L
.86384 .27041 L
.86644 .27055 L
.86861 .27063 L
.87061 .27065 L
.87232 .27063 L
.87377 .27058 L
.87508 .27055 L
.87625 .27056 L
.87737 .27064 L
.87846 .27083 L
.87949 .27113 L
.88055 .27151 L
.88154 .27195 L
.88257 .27244 L
.88358 .27295 L
.88457 .27349 L
.88546 .27406 L
.88625 .27465 L
.88689 .27524 L
.88739 .27586 L
.88776 .2765 L
.88802 .27716 L
.88819 .27782 L
.88831 .27849 L
.88843 .27916 L
.88857 .2798 L
.88872 .28042 L
.88887 .281 L
.88905 .2815 L
.88923 .2819 L
.88939 .2822 L
.8895 .28239 L
.88953 .28248 L
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
Mistroke
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
.88668 .28544 L
.88683 .28543 L
.88704 .28527 L
.88725 .28494 L
.88744 .28451 L
.88753 .28394 L
.88749 .28325 L
.88731 .28242 L
.88697 .2814 L
.88648 .28012 L
.88586 .27853 L
.88511 .27673 L
.88415 .27449 L
.88293 .27195 L
.88149 .26902 L
.87983 .26586 L
.87791 .26238 L
.87595 .25887 L
.87381 .25531 L
.87177 .25184 L
.86986 .24844 L
.86813 .24552 L
.86655 .24283 L
.86513 .24032 L
.86405 .23849 L
.86318 .23694 L
.86253 .23566 L
.86213 .23485 L
.86196 .23433 L
.86199 .23411 L
.86218 .23412 L
.86247 .23427 L
.8628 .2345 L
.86312 .23473 L
.86341 .23494 L
.86365 .2351 L
.86384 .23518 L
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
Mistroke
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
.86385 .23539 L
.86348 .23536 L
.86298 .23526 L
.86237 .23508 L
.86167 .23483 L
.86092 .2345 L
.86019 .23412 L
.85943 .2337 L
.85867 .23325 L
.85793 .23281 L
.85727 .23236 L
.85671 .23191 L
.85628 .23147 L
.85599 .23107 L
.85582 .23074 L
.85576 .23052 L
.8558 .23044 L
.85588 .2305 L
.85597 .2307 L
.85605 .23101 L
.85613 .23139 L
.8562 .23184 L
.85625 .23233 L
.85627 .23283 L
.85626 .23333 L
.85624 .23381 L
.85622 .23428 L
.85619 .23469 L
.85613 .23502 L
.85603 .2352 L
.85588 .23522 L
.85563 .23503 L
.85534 .2346 L
.8549 .23391 L
.85417 .23297 L
.85351 .23181 L
.85274 .23037 L
.85187 .22861 L
.85091 .22661 L
.84979 .22419 L
.84854 .22175 L
.84713 .21887 L
.84556 .21584 L
.84382 .21247 L
.84194 .20909 L
.83992 .2055 L
.83777 .20165 L
Mistroke
.83546 .19768 L
.83291 .19358 L
.83025 .18899 L
.82742 .18487 L
.82438 .18022 L
.82116 .17544 L
.81791 .17086 L
.81461 .16597 L
.81118 .16103 L
.80779 .15616 L
.80444 .15158 L
.80091 .14651 L
.79763 .14232 L
.79419 .13795 L
.79078 .13393 L
.78725 .13026 L
.78406 .12706 L
.78077 .12414 L
.77764 .12145 L
.77466 .11935 L
.77169 .1174 L
.76854 .11561 L
.7658 .11398 L
.76293 .11242 L
.7599 .11099 L
.75695 .10952 L
.75375 .10797 L
.75062 .10639 L
.74706 .10468 L
.74354 .10287 L
.73949 .10087 L
.73545 .0989 L
.73103 .09673 L
.7259 .09457 L
.72143 .09248 L
.71609 .09028 L
.71118 .08818 L
.70575 .08596 L
.70078 .0839 L
.69564 .08179 L
.69063 .07974 L
.68597 .07769 L
.68151 .07588 L
.6773 .07406 L
.67317 .07241 L
.66971 .07083 L
.66631 .06938 L
.66298 .06802 L
.66022 .06686 L
.65754 .06578 L
Mistroke
.65495 .06478 L
.65262 .06383 L
.65028 .06292 L
.64786 .062 L
.64552 .06108 L
.64283 .06004 L
.64019 .05891 L
.63723 .05773 L
.63396 .05646 L
.63066 .05513 L
.62697 .05374 L
.62336 .05225 L
.61938 .05071 L
.61566 .04921 L
.61178 .04768 L
.60789 .04618 L
.60399 .0447 L
.60037 .04326 L
.59674 .042 L
.59316 .04081 L
.58992 .03972 L
.58679 .0388 L
.58372 .03798 L
.58088 .03728 L
.57796 .03671 L
.57523 .03629 L
.5724 .03601 L
.56944 .03586 L
.56659 .0358 L
.56341 .0358 L
.56019 .03581 L
.55691 .03581 L
.55316 .03575 L
.54972 .03561 L
.54595 .03541 L
.54162 .03517 L
.53797 .0349 L
.53379 .03463 L
.52953 .03436 L
.52515 .03411 L
.5207 .03389 L
.51631 .03369 L
.51153 .03353 L
.50736 .03339 L
.50264 .03328 L
.49839 .0332 L
.49461 .03316 L
.49059 .03316 L
.48731 .03318 L
.48399 .03323 L
Mistroke
.48158 .03328 L
.47948 .03333 L
.47767 .03336 L
.47628 .03335 L
.47511 .03332 L
.4741 .03327 L
.4732 .03321 L
.47225 .03316 L
.4711 .03311 L
.46959 .03307 L
.46781 .03301 L
.46549 .03294 L
.46255 .03286 L
.45948 .03275 L
.45581 .03264 L
.45192 .03251 L
.44795 .03237 L
.44401 .03222 L
.4402 .03207 L
.43661 .03196 L
.43372 .03187 L
.43073 .03183 L
.4285 .03181 L
.42657 .03179 L
.425 .03177 L
.42385 .03174 L
.42311 .03173 L
.42266 .03174 L
.42244 .0318 L
.42238 .03192 L
.4224 .03209 L
.42244 .0323 L
.42241 .03255 L
.4223 .03282 L
.42214 .0331 L
.42196 .0334 L
.42177 .03371 L
.42156 .03404 L
.42128 .03437 L
.42091 .03472 L
.42039 .035 L
.41971 .0353 L
.41886 .03557 L
.41789 .0357 L
.41684 .03575 L
.41573 .03571 L
.41461 .03562 L
.41353 .0355 L
.41247 .03537 L
.41144 .03527 L
Mistroke
.41045 .03517 L
.40955 .03509 L
.40875 .03502 L
.40806 .03497 L
.40752 .03495 L
.40712 .03495 L
.40684 .03496 L
.40664 .03502 L
.40651 .0351 L
.4064 .03519 L
.4063 .03529 L
.4062 .03538 L
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
.40694 .03536 L
.40664 .03526 L
.40604 .03518 L
.40505 .03514 L
.40361 .03515 L
.40162 .03523 L
.39931 .0354 L
.39654 .03565 L
.39312 .03599 L
.3897 .03645 L
.38557 .03704 L
.38185 .03774 L
.37767 .03858 L
.37372 .03958 L
.37024 .04064 L
.36679 .0418 L
.36397 .04301 L
.36131 .04412 L
.35931 .0452 L
.35775 .04619 L
.35662 .04707 L
.35588 .04781 L
Mistroke
.35545 .04843 L
.35524 .04895 L
.35518 .04936 L
.35521 .04965 L
.35529 .04982 L
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
.35571 .04931 L
.35534 .04924 L
.35486 .04921 L
.35428 .04925 L
.35362 .04938 L
.35289 .04961 L
.35212 .04996 L
.35134 .0504 L
.35053 .05094 L
.34971 .05152 L
.34893 .05216 L
.34823 .05282 L
.34763 .05349 L
.34717 .05412 L
.34682 .05475 L
.3466 .05532 L
.34649 .0558 L
.34648 .05613 L
.34653 .05628 L
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
Mistroke
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
.34666 .05386 L
.34629 .05392 L
.34581 .05407 L
.34514 .05437 L
.34428 .05481 L
.34321 .05535 L
.34193 .05598 L
.34047 .05667 L
.33893 .0574 L
.33721 .05817 L
.33532 .05897 L
.33346 .05979 L
.33153 .06063 L
.32957 .06148 L
.32776 .06229 L
.32602 .06313 L
.32435 .06394 L
.32283 .06469 L
.32143 .06541 L
.32029 .06611 L
.31934 .06678 L
.3186 .06747 L
.31807 .06805 L
.31774 .0686 L
.31759 .06907 L
.31759 .06941 L
.31767 .06974 L
.31781 .07004 L
.31798 .07032 L
.31816 .07056 L
.31833 .07075 L
.31848 .07088 L
.3186 .07096 L
.3187 .07095 L
.31879 .07085 L
Mistroke
.31885 .07063 L
.31891 .07037 L
.31896 .07003 L
.31901 .06968 L
.31906 .06934 L
.31915 .06902 L
.31925 .06871 L
.31932 .06845 L
.3193 .06828 L
.31913 .06821 L
.31878 .06828 L
.31819 .06851 L
.3173 .06901 L
.31604 .06971 L
.31432 .07073 L
.31218 .07206 L
.30952 .07368 L
.30614 .07567 L
.30307 .0777 L
.29929 .08004 L
.29484 .08244 L
.29103 .08495 L
.28657 .08742 L
.28236 .09004 L
.27752 .09253 L
.27389 .095 L
.26981 .09743 L
.26584 .09993 L
.26231 .10211 L
.25849 .10436 L
.2553 .10653 L
.25194 .10861 L
.24872 .11072 L
.2456 .11274 L
.24235 .11472 L
.23942 .11669 L
.23634 .11858 L
.23328 .12046 L
.2301 .12235 L
.2273 .12414 L
.22434 .12595 L
.2215 .1277 L
.21892 .12938 L
.21635 .13102 L
.21394 .13259 L
.21202 .13398 L
.2103 .13526 L
.20877 .13642 L
.20744 .13745 L
.20638 .1383 L
Mistroke
.2055 .13902 L
.20482 .1396 L
.20433 .14005 L
.20397 .14038 L
.20373 .14061 L
.20355 .14077 L
.20342 .14089 L
.20326 .14103 L
.20306 .14123 L
.20282 .14149 L
.20256 .14182 L
.20223 .14226 L
.20184 .14279 L
.20144 .14342 L
.20101 .1441 L
.20059 .14485 L
.20018 .14562 L
.19978 .14645 L
.1994 .14728 L
.19903 .14809 L
.19868 .14883 L
.19834 .14946 L
.19801 .14998 L
.19772 .15034 L
.19748 .15055 L
.1973 .15061 L
.19717 .15051 L
.19713 .15027 L
.19718 .14994 L
.1973 .14957 L
.19744 .14923 L
.19755 .14894 L
.19758 .14878 L
.19749 .1488 L
.19725 .14904 L
.19683 .14956 L
.19624 .15032 L
.19549 .15135 L
.1946 .15262 L
.1936 .15412 L
.19259 .15569 L
.19159 .15729 L
.19057 .15887 L
.18954 .1604 L
.1886 .16183 L
.18774 .16321 L
.18697 .16461 L
.18628 .16588 L
.18558 .16722 L
.18483 .16866 L
Mistroke
.18396 .17029 L
.18294 .17216 L
.18166 .17434 L
.18024 .17663 L
.17847 .17933 L
.17643 .18242 L
.1742 .18578 L
.17176 .18956 L
.16904 .19359 L
.16644 .19778 L
.16367 .20211 L
.16085 .20645 L
.15814 .2109 L
.15554 .21502 L
.15289 .21921 L
.15033 .22385 L
.14779 .22768 L
.1451 .23198 L
.14257 .23625 L
.13994 .24068 L
.13727 .24545 L
.13459 .24977 L
.13192 .25431 L
.12919 .25922 L
.12661 .26337 L
.1239 .26793 L
.12116 .27263 L
.11836 .27717 L
.11573 .28162 L
.1131 .28608 L
.11058 .29056 L
.1081 .29521 L
.10591 .29943 L
.10377 .30384 L
.10167 .30872 L
.09984 .31276 L
.09806 .31744 L
.09638 .32198 L
.09482 .32629 L
.0934 .3308 L
.09209 .33521 L
.09092 .3395 L
.0899 .3437 L
.08896 .34797 L
.08812 .35248 L
.08734 .35665 L
.08663 .3615 L
.08599 .36571 L
.08548 .37044 L
.08507 .37492 L
Mistroke
.08475 .37942 L
.08452 .38355 L
.08438 .38778 L
.0843 .39114 L
.08426 .3943 L
.08425 .39716 L
.08426 .39943 L
.08427 .4012 L
.0843 .40239 L
.08433 .40305 L
.08433 .4033 L
.08432 .40327 L
.08429 .40308 L
.08423 .40289 L
.08414 .40274 L
.08405 .40274 L
.08396 .40291 L
.08391 .4032 L
.08394 .40361 L
.08413 .40415 L
.08448 .40483 L
.085 .40569 L
.08574 .40675 L
.08672 .40803 L
.08777 .40948 L
.08906 .41116 L
.09025 .41305 L
.09145 .4152 L
.09278 .41747 L
.09377 .42008 L
.09465 .42291 L
.09537 .42611 L
.09586 .42939 L
.0961 .43303 L
.09607 .43668 L
.09574 .44058 L
.09516 .44419 L
.0944 .44796 L
.0934 .45178 L
.09235 .4552 L
.09114 .45866 L
.0898 .46202 L
.08829 .46525 L
.08678 .46844 L
.08496 .47167 L
.08331 .47488 L
.0814 .47826 L
.07955 .48173 L
.0775 .48562 L
.0755 .4896 L
Mistroke
.07386 .49374 L
.07227 .4985 L
.07078 .50315 L
.06959 .50823 L
.0687 .51338 L
.0681 .51858 L
.06779 .5238 L
.06771 .52895 L
.06781 .53383 L
.06806 .53836 L
.06843 .54243 L
.0689 .54626 L
.0694 .54933 L
.06992 .5523 L
.07043 .5548 L
.07094 .55719 L
.07145 .55967 L
.07194 .56227 L
.07244 .56479 L
.07292 .56762 L
.07341 .57082 L
.07391 .57386 L
.07442 .57733 L
.07494 .58102 L
.07543 .58402 L
.07593 .58745 L
.0764 .59065 L
.07681 .59315 L
.07715 .59534 L
.07741 .59715 L
.07761 .59847 L
.07777 .59927 L
.07789 .59962 L
.07799 .59966 L
.07807 .59954 L
.07814 .59937 L
.07824 .5992 L
.07838 .59912 L
.07857 .59919 L
.07884 .59941 L
.07916 .59969 L
.07954 .59992 L
.07996 .60008 L
.0804 .60015 L
.08084 .60018 L
.08126 .60016 L
.08164 .60011 L
.08195 .60009 L
.0822 .60014 L
.08238 .60034 L
Mistroke
.0825 .60074 L
.08257 .60142 L
.08263 .60245 L
.08266 .60389 L
.08267 .60571 L
.08265 .60805 L
.08263 .61079 L
.08262 .61409 L
.08267 .61763 L
.0828 .62172 L
.08302 .62593 L
.08333 .63046 L
.0837 .63521 L
.08414 .6401 L
.08463 .64522 L
.08519 .65058 L
.08579 .65595 L
.08646 .66132 L
.0872 .66705 L
.08797 .67244 L
.0888 .6776 L
.08967 .68325 L
.09053 .68798 L
.09142 .69295 L
.09229 .69773 L
.09313 .70177 L
.09396 .7058 L
.09474 .7094 L
.09551 .7127 L
.09627 .71541 L
.09699 .71784 L
.09764 .71983 L
.09818 .72153 L
.09861 .72296 L
.09893 .72412 L
.09915 .72503 L
.09931 .72574 L
.0994 .72625 L
.09947 .72657 L
.09954 .72674 L
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
Mistroke
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
.10294 .72838 L
.10292 .72867 L
.10291 .72911 L
.1029 .72974 L
.10288 .73038 L
.10287 .73118 L
.10285 .732 L
.10284 .73291 L
.10281 .73385 L
.10276 .73477 L
.10271 .73561 L
.10265 .73638 L
.10262 .73705 L
.10263 .73761 L
.10268 .73805 L
.10278 .73835 L
.10293 .73851 L
.10312 .73854 L
.10336 .73851 L
.10361 .73844 L
.10389 .73834 L
.10416 .73825 L
.10443 .73817 L
.10468 .7381 L
.10487 .73806 L
.10501 .73804 L
.1051 .73803 L
.10514 .73802 L
.10516 .73802 L
.10518 .73803 L
.10527 .73805 L
.10547 .73808 L
.10579 .73816 L
.10623 .73831 L
.10681 .73853 L
.10751 .73882 L
.10825 .7392 L
.10908 .7396 L
.10989 .74005 L
.11073 .74049 L
Mistroke
.11155 .74088 L
.1124 .74123 L
.11319 .74152 L
.114 .74172 L
.11486 .74187 L
.11577 .74193 L
.11675 .74187 L
.11786 .74164 L
.11903 .74128 L
.12046 .74072 L
.12192 .73999 L
.12351 .73913 L
.12536 .7382 L
.12699 .73724 L
.12874 .73631 L
.13053 .73536 L
.13211 .73447 L
.13346 .73365 L
.13462 .73294 L
.1355 .73236 L
.13609 .73197 L
.13637 .73177 L
.13632 .73173 L
.13596 .73185 L
.13539 .73214 L
.1348 .73258 L
.13431 .73319 L
.13392 .73398 L
.13366 .7349 L
.13352 .73596 L
.13351 .73715 L
.13369 .73848 L
.13417 .73987 L
.13481 .7411 L
.13585 .74243 L
.13694 .74385 L
.13822 .74546 L
.1395 .7472 L
.14082 .74902 L
.14207 .75109 L
.14314 .75351 L
.14409 .75622 L
.145 .75929 L
.14589 .76286 L
.1468 .76659 L
.14773 .77007 L
.1488 .77373 L
.15005 .77799 L
.15144 .78255 L
.15298 .78705 L
Mistroke
.15458 .79127 L
.15626 .79552 L
.15786 .79941 L
.15942 .80275 L
.16093 .80595 L
.16229 .80851 L
.16356 .81076 L
.16462 .81238 L
.16555 .81365 L
.16631 .81459 L
.16687 .81522 L
.16722 .81556 L
.16739 .81568 L
.16741 .81563 L
.16738 .8155 L
.16737 .81532 L
.16744 .81514 L
.16762 .815 L
.16796 .81496 L
.16845 .81503 L
.16905 .81517 L
.16974 .81535 L
.17049 .81556 L
.17125 .81581 L
.17203 .81609 L
.1728 .81639 L
.1735 .81668 L
.17411 .81695 L
.17457 .81711 L
.17488 .81715 L
.17501 .81707 L
.17502 .81694 L
.17493 .81678 L
.17479 .81664 L
.17464 .8166 L
.17456 .81674 L
.17462 .81714 L
.17488 .81782 L
.1754 .8188 L
.17621 .82008 L
.1773 .82169 L
.1786 .82338 L
.18015 .82539 L
.1819 .82757 L
.18381 .82979 L
.1857 .83194 L
.18761 .83402 L
.18942 .83571 L
.191 .83715 L
.19245 .83829 L
Mistroke
.19362 .8391 L
.19454 .83957 L
.19518 .83971 L
.19556 .83963 L
.19572 .83938 L
.19575 .83907 L
.19567 .83872 L
.19553 .83839 L
.19539 .83813 L
.19527 .83797 L
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
.19462 .8378 L
.19476 .83818 L
.19506 .83875 L
.19554 .83951 L
.19623 .84044 L
.19713 .84153 L
.19822 .84286 L
.19958 .84435 L
.20113 .84617 L
.20297 .8481 L
.20498 .85033 L
.20731 .85281 L
.20988 .85549 L
.21268 .85835 L
.21579 .86152 L
.21894 .86445 L
.22226 .8677 L
.22574 .87122 L
.22955 .87459 L
.23298 .87806 L
.23668 .88154 L
.24068 .88462 L
.24397 .88765 L
.24754 .89048 L
.25125 .89325 L
.2544 .89566 L
Mistroke
.25771 .898 L
.261 .9 L
.2643 .90193 L
.26782 .90377 L
.27114 .90561 L
.27464 .90718 L
.27833 .90889 L
.28223 .91045 L
.28601 .91203 L
.29001 .91354 L
.29393 .91502 L
.29775 .91631 L
.30153 .91755 L
.30495 .91867 L
.30816 .9196 L
.31108 .92039 L
.31368 .92106 L
.31596 .92159 L
.31793 .92199 L
.31959 .92228 L
.32096 .92246 L
.32207 .92255 L
.32296 .92256 L
.32364 .92253 L
.32415 .92249 L
.32452 .92247 L
.32476 .92245 L
.32489 .92245 L
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
.32406 .92214 L
.32468 .92244 L
.32565 .92286 L
.32703 .92342 L
.32887 .92412 L
.33105 .92499 L
.33351 .92594 L
.33664 .92722 L
.33995 .92849 L
.34385 .92992 L
.3482 .93154 L
Mistroke
.35276 .93329 L
.35721 .93516 L
.36208 .93683 L
.36707 .93864 L
.3721 .94035 L
.37676 .94206 L
.38164 .94382 L
.38642 .94542 L
.39114 .94709 L
.39584 .94871 L
.40045 .95029 L
.40499 .95178 L
.40917 .95323 L
.41354 .95455 L
.4179 .95585 L
.42252 .95716 L
.42626 .95841 L
.4304 .95967 L
.43433 .96086 L
.43841 .96203 L
.44212 .96311 L
.44584 .96406 L
.44941 .96493 L
.45264 .96567 L
.45573 .96625 L
.45833 .96671 L
.46074 .96705 L
.46278 .96731 L
.46445 .96746 L
.46577 .96754 L
.46678 .96757 L
.46746 .96754 L
.46787 .96748 L
.4681 .9674 L
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
Mistroke
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
.46546 .96059 L
.46553 .96078 L
.46562 .96102 L
.46567 .96127 L
.46569 .96148 L
.4657 .96171 L
.46572 .96193 L
.46576 .96214 L
.46581 .96235 L
.4659 .96255 L
.46599 .96279 L
.46606 .96305 L
.46612 .96325 L
.46621 .96345 L
.46636 .96365 L
.46657 .96382 L
.4668 .96396 L
.46704 .96405 L
.46728 .96406 L
.46746 .96399 L
.46752 .96381 L
Mistroke
.46747 .96355 L
.46727 .96323 L
.46694 .96283 L
.46651 .96243 L
.46607 .96212 L
.4657 .96194 L
.46537 .96193 L
.46511 .96207 L
.46493 .96231 L
.46491 .96255 L
.46504 .96298 L
.4654 .96356 L
.46604 .96426 L
.46699 .96498 L
.46828 .96567 L
.46996 .96626 L
.47199 .96672 L
.47439 .96701 L
.47719 .96709 L
.48039 .96696 L
.48401 .96663 L
.48783 .96618 L
.49238 .96563 L
.49663 .96505 L
.50143 .96443 L
.50687 .96379 L
.51156 .96315 L
.51674 .96251 L
.52197 .9619 L
.52765 .96131 L
.53252 .96074 L
.53789 .96017 L
.54335 .95959 L
.5485 .95896 L
.55386 .95826 L
.55927 .95746 L
.56478 .95658 L
.5702 .9556 L
.57584 .95455 L
.58135 .95348 L
.5869 .95236 L
.59201 .95127 L
.59707 .95019 L
.60189 .94916 L
.60627 .94824 L
.61018 .94747 L
.6137 .94687 L
.61672 .94641 L
.61908 .94609 L
.62106 .94589 L
Mistroke
.62257 .94578 L
.62363 .94572 L
.62431 .94569 L
.62466 .94569 L
.62471 .94571 L
.62453 .94573 L
.62418 .94574 L
.62375 .94575 L
.6233 .94575 L
.62287 .9457 L
.62248 .9456 L
.62218 .94545 L
.62197 .94523 L
.62197 .94496 L
.62224 .94463 L
.62279 .94426 L
.62367 .94383 L
.62487 .94336 L
.62645 .94286 L
.62846 .94236 L
.63094 .94179 L
.63381 .94121 L
.63697 .94059 L
.64052 .93994 L
.64436 .93925 L
.64833 .93856 L
.65227 .93786 L
.65627 .93718 L
.65979 .93652 L
.66333 .93591 L
.66649 .93537 L
.66912 .93487 L
.67152 .9344 L
.67363 .93396 L
.67535 .93358 L
.67689 .9333 L
.67817 .93313 L
.67927 .93304 L
.68009 .93302 L
.68069 .93303 L
.68122 .93304 L
.68174 .933 L
.68229 .93285 L
.68291 .93254 L
.6835 .93209 L
.6841 .93151 L
.68463 .93081 L
.68507 .93004 L
.68549 .9292 L
.68585 .9283 L
Mistroke
.68615 .92738 L
.68641 .9265 L
.68664 .92572 L
.68683 .92513 L
.68702 .92467 L
.68714 .92442 L
.68725 .92427 L
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
.68542 .92679 L
.68555 .92666 L
.68579 .92638 L
.68607 .92596 L
.68639 .92548 L
.68669 .92501 L
.68696 .92458 L
.68718 .92425 L
.68731 .92395 L
.68735 .92362 L
.68726 .92328 L
.68705 .92297 L
.68671 .92266 L
.68626 .92228 L
.68569 .9218 L
.68501 .92118 L
.68424 .92031 L
.68336 .91937 L
.68236 .91809 L
.68128 .91671 L
.68006 .91543 L
.67872 .91379 L
.67727 .91214 L
.67571 .91042 L
.67423 .90875 L
Mistroke
.67267 .90721 L
.67109 .90575 L
.6696 .90437 L
.66808 .90308 L
.6668 .90185 L
.66559 .90075 L
.66448 .8998 L
.66351 .89895 L
.6627 .89813 L
.66206 .89737 L
.66155 .89663 L
.66113 .89591 L
.66079 .89522 L
.66051 .89456 L
.66029 .89395 L
.66007 .8934 L
.65985 .89289 L
.65965 .89245 L
.65949 .89208 L
.65939 .89177 L
.65933 .89151 L
.6593 .89128 L
.65929 .89107 L
.6593 .89088 L
.65931 .89071 L
.65931 .89055 L
.65932 .89037 L
.65934 .89017 L
.65939 .88996 L
.65946 .88977 L
.65956 .88961 L
.65967 .8895 L
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
.66007 .88978 L
.66027 .88973 L
.66053 .88961 L
.66087 .88938 L
.66127 .88907 L
Mistroke
.6617 .88868 L
.66212 .88823 L
.66253 .88773 L
.66293 .8872 L
.66331 .88667 L
.66363 .88618 L
.66387 .88573 L
.664 .88536 L
.66399 .88508 L
.66382 .8849 L
.66348 .8848 L
.66297 .88475 L
.66231 .8847 L
.66153 .88464 L
.66068 .88454 L
.65984 .88435 L
.65902 .88414 L
.65822 .88385 L
.65744 .88352 L
.65674 .8832 L
.65615 .88287 L
.6557 .88252 L
.65535 .88216 L
.65507 .88174 L
.6548 .88125 L
.65453 .88067 L
.65422 .88002 L
.65381 .87929 L
.65329 .87848 L
.65272 .87762 L
.6521 .87668 L
.65149 .87576 L
.6509 .8748 L
.65032 .87382 L
.64981 .87294 L
.64936 .87212 L
.64897 .87132 L
.64864 .87055 L
.64838 .86978 L
.64818 .86902 L
.64802 .86826 L
.64788 .86746 L
.64776 .86664 L
.64762 .86572 L
.64745 .86475 L
.64723 .86367 L
.64695 .86247 L
.64664 .86129 L
.6463 .86013 L
.64597 .85904 L
Mistroke
.64565 .85806 L
.64536 .85723 L
.64511 .85657 L
.6449 .85609 L
.64471 .85571 L
.64453 .85539 L
.64436 .8551 L
.64419 .85481 L
.64406 .85451 L
.64396 .85422 L
.6439 .85395 L
.64389 .85372 L
.6439 .85352 L
.64393 .85335 L
.64397 .85319 L
.644 .853 L
.64401 .8528 L
.64401 .85259 L
.64401 .85241 L
.64401 .85226 L
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
Mistroke
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
.64213 .84433 L
.64208 .84458 L
.64202 .84495 L
.64194 .8454 L
.64175 .84592 L
.64142 .84648 L
.64096 .84704 L
.64036 .84754 L
.63961 .84794 L
.63873 .84825 L
.63781 .84847 L
.63686 .84861 L
.63586 .84869 L
.63485 .84873 L
.63386 .84875 L
.63295 .84877 L
.63227 .84876 L
.63176 .84871 L
.63138 .84859 L
.63115 .84844 L
.63102 .84835 L
.63095 .84835 L
.63087 .84849 L
.63071 .84879 L
.63043 .84927 L
.63003 .84996 L
.6295 .85086 L
.6288 .85198 L
.62787 .85334 L
.62688 .85475 L
.62557 .85656 L
.62439 .8583 L
.62316 .86013 L
.62188 .86203 L
.62061 .8639 L
Mistroke
.61941 .86562 L
.61839 .86705 L
.61749 .86827 L
.6167 .86928 L
.61601 .87009 L
.61541 .87071 L
.61488 .87115 L
.61444 .87141 L
.61411 .87149 L
.61392 .87139 L
.61382 .87123 L
.61378 .87106 L
.61375 .87097 L
.61369 .87104 L
.61359 .87131 L
.61344 .87179 L
.61325 .87251 L
.61303 .8735 L
.61281 .87482 L
.61259 .87652 L
.61238 .87862 L
.61211 .88085 L
.6118 .88348 L
.61148 .88658 L
.61117 .88965 L
.61091 .8932 L
.61073 .89659 L
.61063 .90017 L
.61063 .9039 L
.61073 .90704 L
.61095 .91028 L
.61123 .91342 L
.61162 .91612 L
.61208 .91866 L
.61259 .92093 L
.61317 .92296 L
.61379 .92483 L
.61442 .92662 L
.61504 .92845 L
.61565 .92984 L
.61625 .93136 L
.61683 .93273 L
.61736 .93402 L
.6178 .9352 L
.61814 .93635 L
.61835 .93736 L
.61843 .93823 L
.61835 .93897 L
.61809 .93961 L
.61765 .94009 L
Mistroke
.61714 .94043 L
.61655 .94071 L
.61593 .94097 L
.61527 .94119 L
.6148 .94147 L
.61434 .94184 L
.61397 .94225 L
.61368 .94264 L
.61354 .94305 L
.61357 .94348 L
.61371 .94389 L
.61395 .94424 L
.61424 .94451 L
.61454 .94469 L
.61473 .94478 L
.61479 .94477 L
.61466 .9447 L
.61437 .94461 L
.61393 .94444 L
.61334 .94421 L
.61261 .94401 L
.6118 .94383 L
.61095 .94363 L
.61011 .94344 L
.60932 .94324 L
.60864 .94312 L
.60805 .94297 L
.6076 .94283 L
.60727 .94275 L
.60706 .94269 L
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
Mistroke
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
.61203 .94337 L
.61171 .94336 L
.61121 .94331 L
.61053 .94319 L
.60979 .94307 L
.60905 .94297 L
.60826 .94282 L
.60758 .94263 L
.60707 .94244 L
.60675 .94225 L
.60665 .94212 L
.60674 .94204 L
.607 .94202 L
.60742 .94205 L
.60794 .9421 L
.60855 .94217 L
.60922 .94227 L
.60988 .94237 L
.61053 .9424 L
.61113 .94239 L
.61176 .94235 L
.61238 .94233 L
.61306 .94232 L
.61377 .94234 L
.61454 .94241 L
.61539 .94255 L
.61629 .94276 L
.61718 .94304 L
.61802 .94336 L
.61885 .9437 L
.61964 .94402 L
.62042 .94429 L
.62114 .9445 L
.62186 .94464 L
.62263 .94468 L
.6234 .94458 L
.62423 .94435 L
.62512 .94403 L
.62606 .94367 L
.62695 .94323 L
.62794 .94279 L
.62901 .94235 L
.63014 .94196 L
.63131 .94165 L
Mistroke
.63242 .94141 L
.63343 .94122 L
.63428 .94107 L
.63494 .94092 L
.6354 .9408 L
.6357 .94069 L
.63581 .9405 L
.63581 .94022 L
.63572 .93981 L
.63557 .93926 L
.63527 .93857 L
.63484 .9377 L
.63424 .93666 L
.63347 .93545 L
.63254 .93414 L
.63146 .93274 L
.63022 .93106 L
.62897 .92969 L
.62761 .92807 L
.62622 .92642 L
.62492 .92483 L
.62359 .92326 L
.62238 .92184 L
.62124 .92054 L
.62018 .91935 L
.61928 .91843 L
.61851 .91768 L
.61791 .91716 L
.61751 .91688 L
.61731 .91684 L
.61726 .91695 L
.61735 .91712 L
.61754 .91731 L
.61783 .91748 L
.61819 .91763 L
.61867 .91777 L
.6193 .91791 L
.62009 .91812 L
.62107 .91838 L
.62225 .91868 L
.62369 .91907 L
.62541 .91958 L
.62735 .92023 L
.62951 .921 L
.63184 .92179 L
.63439 .92263 L
.63681 .92349 L
.63945 .9244 L
.64195 .92516 L
.64451 .92581 L
Mistroke
.64712 .92644 L
.6495 .92694 L
.65169 .92733 L
.65381 .92765 L
.65574 .92784 L
.65746 .92801 L
.65904 .92818 L
.6604 .92835 L
.66162 .92856 L
.6627 .92879 L
.66365 .92906 L
.66436 .92938 L
.66499 .92969 L
.6655 .92998 L
.66588 .93023 L
.66614 .93045 L
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
.66554 .93161 L
.66541 .93182 L
.66526 .93211 L
.66513 .93247 L
.66509 .93288 L
.66514 .93326 L
.66532 .93356 L
.66562 .93382 L
.666 .934 L
.66652 .93409 L
.66712 .93403 L
Mistroke
.66784 .9338 L
.66867 .93336 L
.66956 .93272 L
.6705 .93189 L
.67143 .9309 L
.67234 .92983 L
.67316 .92868 L
.67384 .92752 L
.67432 .92642 L
.67461 .92546 L
.6748 .92463 L
.67491 .92395 L
.67494 .92344 L
.67493 .92312 L
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
.67365 .92482 L
.67374 .92497 L
.67393 .92509 L
.67425 .92515 L
.67473 .92516 L
.67536 .92517 L
.67614 .92519 L
.67707 .92518 L
.67819 .92518 L
.67954 .9251 L
.68115 .92491 L
Mistroke
.68314 .92453 L
.68537 .92394 L
.68796 .92314 L
.69086 .92214 L
.69396 .92093 L
.69744 .91953 L
.7011 .91793 L
.70454 .9162 L
.70837 .9142 L
.71221 .9119 L
.71631 .90933 L
.72061 .90669 L
.72432 .90387 L
.72835 .90099 L
.7324 .89805 L
.73626 .8951 L
.73982 .89221 L
.74351 .88918 L
.74714 .88613 L
.75048 .88324 L
.75404 .88025 L
.75725 .87738 L
.76017 .87467 L
.76307 .8721 L
.76558 .8698 L
.76788 .86767 L
.76984 .8657 L
.77146 .86404 L
.77283 .86256 L
.7739 .86126 L
.77467 .86017 L
.77517 .85927 L
.7754 .85854 L
.77541 .85798 L
.77525 .85751 L
.77499 .8571 L
.77466 .85675 L
.77431 .85642 L
.77395 .8561 L
.7736 .85578 L
.77325 .85548 L
.77294 .85519 L
.7727 .85492 L
.77254 .85466 L
.77244 .85438 L
.77234 .85404 L
.77226 .85359 L
.77215 .85304 L
.77197 .8524 L
.77168 .85167 L
Mistroke
.77125 .85085 L
.77067 .84995 L
.76993 .84897 L
.76906 .84796 L
.7681 .84692 L
.76711 .84602 L
.76607 .84516 L
.76505 .84449 L
.76406 .84389 L
.76321 .84348 L
.76248 .8431 L
.7619 .84281 L
.76149 .84265 L
.76124 .8426 L
.76111 .84263 L
.76104 .84273 L
.76097 .84282 L
.76081 .84298 L
.76051 .84315 L
.76003 .84333 L
.75937 .84348 L
.75846 .8437 L
.75727 .84406 L
.7558 .84461 L
.75418 .84543 L
.75238 .84643 L
.75037 .84744 L
.7482 .8488 L
.74581 .8498 L
.74378 .85103 L
.74179 .85223 L
.73972 .85329 L
.73794 .85426 L
.73662 .85516 L
.73534 .85592 L
.73437 .85654 L
.73362 .85698 L
.73309 .85724 L
.73275 .85732 L
.73255 .85723 L
.73241 .85703 L
.73218 .8567 L
.73176 .8563 L
.73111 .85582 L
.73018 .85528 L
.7288 .85465 L
.72717 .85388 L
.72511 .85296 L
.72291 .85193 L
.72052 .85077 L
Mistroke
.71785 .84951 L
.71532 .84824 L
.71241 .84691 L
.70988 .84557 L
.70726 .84419 L
.70468 .84282 L
.70258 .8416 L
.70049 .84042 L
.69876 .83944 L
.69717 .8386 L
.69569 .8379 L
.6943 .83734 L
.69299 .83687 L
.69165 .83651 L
.69024 .83623 L
.68874 .83603 L
.68713 .83589 L
.68561 .8358 L
.6838 .83571 L
.68173 .83559 L
.67967 .83539 L
.6774 .83513 L
.67497 .83479 L
.67268 .83441 L
.67028 .83401 L
.66804 .83359 L
.66603 .8332 L
.66415 .83284 L
.66256 .83252 L
.66117 .83224 L
.66002 .83199 L
.65905 .83174 L
.65828 .83146 L
.65769 .83118 L
.65725 .83094 L
.65695 .83079 L
.65678 .8307 L
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
.65678 .83132 L
.65645 .83107 L
.65605 .83059 L
.6556 .82989 L
Mistroke
.65511 .82898 L
.65459 .82793 L
.654 .82676 L
.65333 .82558 L
.65259 .82452 L
.65179 .8234 L
.65097 .82245 L
.65015 .82159 L
.64934 .82085 L
.64852 .82023 L
.64767 .81974 L
.64678 .81937 L
.64583 .81913 L
.64473 .81896 L
.64348 .81881 L
.64211 .81862 L
.64066 .81833 L
.63917 .81789 L
.63767 .8173 L
.63634 .81657 L
.63495 .8158 L
.63365 .81501 L
.63235 .81424 L
.63106 .8135 L
.62988 .81281 L
.62877 .8122 L
.62775 .81163 L
.62684 .81111 L
.62604 .81064 L
.62537 .81022 L
.62476 .80987 L
.62418 .80958 L
.62364 .80934 L
.62314 .80913 L
.62272 .80896 L
.62235 .80882 L
.62205 .80869 L
.62183 .80856 L
.62169 .80842 L
.62161 .80828 L
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
Mistroke
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
.62185 .80852 L
.62162 .80856 L
.62131 .80856 L
.62089 .80847 L
.62035 .80827 L
.6197 .80795 L
.61896 .8075 L
.61815 .80694 L
.6173 .80628 L
.61645 .80557 L
.61561 .80481 L
.61475 .80402 L
.6139 .80323 L
.61303 .80249 L
.61217 .80182 L
.61125 .80121 L
.61026 .80064 L
.60918 .80012 L
.608 .79964 L
.60674 .79918 L
.60555 .79873 L
.60425 .79826 L
.60304 .79776 L
.60184 .79725 L
.6007 .79673 L
.59966 .79622 L
.59877 .7957 L
.59803 .7952 L
.59748 .79476 L
.59711 .79439 L
.59693 .7941 L
.59691 .79387 L
.59699 .7937 L
.59715 .79361 L
.59735 .7936 L
.59757 .79368 L
.59773 .79384 L
.59776 .79408 L
.59758 .79438 L
.59717 .79474 L
.5965 .79518 L
.59553 .79568 L
.59422 .79626 L
.59275 .79688 L
.59094 .79756 L
.58882 .79828 L
.58671 .79903 L
Mistroke
.58446 .79978 L
.58171 .8005 L
.57928 .80116 L
.57666 .80175 L
.57405 .80224 L
.57158 .80266 L
.56924 .80301 L
.56735 .80331 L
.56566 .80358 L
.56419 .80382 L
.56295 .80401 L
.56201 .80414 L
.56126 .80422 L
.56069 .80425 L
.56031 .80425 L
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
.56161 .80363 L
.56133 .80378 L
.56084 .80409 L
.56011 .8046 L
Mistroke
.55912 .80534 L
.55783 .80636 L
.55637 .80765 L
.55465 .80922 L
.55263 .81113 L
.55038 .81324 L
.54806 .81561 L
.54542 .81833 L
.54274 .82083 L
.53982 .82396 L
.53712 .82656 L
.53413 .82935 L
.53118 .83228 L
.52823 .83505 L
.52506 .83792 L
.52235 .84036 L
.51927 .84307 L
.51665 .84533 L
.51394 .84765 L
.51143 .85006 L
.50876 .85248 L
.50657 .85479 L
.5044 .85729 L
.5023 .85978 L
.50028 .86236 L
.49828 .86511 L
.49645 .86752 L
.49458 .87029 L
.49262 .8729 L
.49058 .87577 L
.48864 .87863 L
.48679 .88107 L
.48482 .88357 L
.48273 .88609 L
.4807 .88827 L
.47878 .89026 L
.47692 .8921 L
.47523 .8937 L
.47372 .89504 L
.47232 .89619 L
.47103 .89717 L
.46984 .89794 L
.46877 .89853 L
.46769 .89897 L
.46655 .89925 L
.46536 .89941 L
.46409 .89945 L
.46274 .89942 L
.46133 .89932 L
.46008 .89918 L
Mistroke
.45876 .89902 L
.45746 .89885 L
.45624 .89867 L
.45504 .8985 L
.45399 .89834 L
.45307 .8982 L
.45234 .89808 L
.45181 .89797 L
.45152 .89784 L
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
.45211 .89744 L
.45177 .89779 L
.45121 .89835 L
.4504 .89916 L
.44939 .90031 L
.44815 .90183 L
.44682 .90352 L
.4453 .90551 L
.44354 .90787 L
.44161 .91037 L
.43955 .91343 L
.43747 .91623 L
.43522 .91936 L
.43301 .92274 L
.43097 .92585 L
.42892 .9292 L
.42692 .93252 L
.42523 .93513 L
.42371 .93769 L
.42238 .94017 L
.42123 .94248 L
.42039 .94418 L
.41974 .94566 L
.41922 .94691 L
.41879 .94786 L
.41837 .94853 L
.41783 .94894 L
.41708 .94914 L
.41605 .94918 L
.41466 .94907 L
.41289 .94884 L
.41121 .94844 L
.40913 .94796 L
.40647 .94747 L
.40414 .94695 L
Mistroke
.40147 .94642 L
.39836 .94583 L
.39579 .94519 L
.3931 .94453 L
.39065 .94386 L
.3884 .94321 L
.38634 .94258 L
.38467 .94199 L
.3833 .94148 L
.38214 .94107 L
.38117 .94077 L
.38043 .94054 L
.37992 .94035 L
.37961 .94018 L
.3795 .94002 L
.37954 .93988 L
.3797 .93974 L
.37994 .9396 L
.38021 .93948 L
.3805 .9394 L
.38078 .93936 L
.38104 .93936 L
.38128 .93938 L
.38148 .9394 L
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
.38195 .93988 L
Mistroke
.38163 .93965 L
.38113 .93925 L
.38044 .93864 L
.37954 .93782 L
.37844 .93679 L
.37726 .93562 L
.37584 .93421 L
.37419 .93259 L
.37251 .93082 L
.37064 .92886 L
.36869 .92669 L
.36675 .92451 L
.3647 .92217 L
.36274 .91978 L
.36072 .91743 L
.35873 .91494 L
.35676 .91252 L
.35478 .90996 L
.35279 .90735 L
.3508 .90464 L
.34888 .90186 L
.34693 .89896 L
.3451 .89609 L
.34323 .89316 L
.34137 .89027 L
.33958 .88731 L
.33774 .88444 L
.33599 .88156 L
.3343 .87869 L
.33266 .8758 L
.33111 .873 L
.32967 .87021 L
.3282 .86746 L
.32689 .86464 L
.32555 .86188 L
.32418 .85901 L
.32285 .8562 L
.32154 .85338 L
.32027 .85043 L
.31909 .84787 L
.31794 .84538 L
.31684 .84299 L
.3159 .84098 L
.31495 .83906 L
.31411 .83754 L
.31332 .83618 L
.31264 .83497 L
.31211 .83388 L
.31177 .83284 L
.31162 .83183 L
Mistroke
.31165 .83071 L
.3118 .82934 L
.31203 .82764 L
.31228 .82562 L
.31251 .82364 L
.3127 .82128 L
.31281 .81843 L
.31296 .81559 L
.31312 .81256 L
.31329 .8099 L
.31345 .8073 L
.31359 .80504 L
.31371 .80286 L
.31379 .80113 L
.31384 .79961 L
.31391 .79835 L
.31403 .79729 L
.31421 .79634 L
.31449 .79544 L
.31486 .79456 L
.31532 .79365 L
.31584 .79275 L
.31637 .79181 L
.31685 .79083 L
.31734 .78977 L
.31782 .78865 L
.31827 .78758 L
.31869 .78666 L
.31908 .78591 L
.3194 .78533 L
.31963 .78497 L
.31981 .78482 L
.31994 .78484 L
.32 .78497 L
.32002 .78512 L
.32002 .78523 L
.32 .78524 L
.31994 .78507 L
.31981 .78465 L
.31958 .78393 L
.3192 .78285 L
.31863 .78148 L
.31785 .77972 L
.31693 .77777 L
.31573 .77542 L
.31438 .77291 L
.31271 .76997 L
.31103 .76702 L
.30904 .76373 L
.30693 .76026 L
Mistroke
.30495 .75698 L
.30271 .75348 L
.30043 .74999 L
.29806 .74641 L
.29581 .74309 L
.29357 .73975 L
.29135 .7364 L
.28931 .73334 L
.28727 .73017 L
.28529 .72699 L
.28336 .72373 L
.28158 .7206 L
.27984 .71732 L
.27816 .71402 L
.2766 .71053 L
.2751 .70721 L
.27364 .70372 L
.27229 .70023 L
.27097 .69694 L
.2698 .69352 L
.26869 .68996 L
.26775 .68706 L
.26688 .68413 L
.2661 .68125 L
.26544 .67882 L
.26487 .67652 L
.26438 .6744 L
.26396 .6726 L
.26364 .67089 L
.26338 .66927 L
.26318 .66768 L
.26303 .66616 L
.26289 .66467 L
.26275 .6632 L
.26263 .66181 L
.26252 .66053 L
.26243 .65935 L
.26237 .65829 L
.26233 .65736 L
.26232 .65654 L
.26233 .65582 L
.26237 .65518 L
.26241 .65464 L
.26245 .65419 L
.26246 .65383 L
.26247 .65353 L
.26247 .6533 L
.26247 .6531 L
.26247 .65293 L
.26248 .65279 L
Mistroke
.26248 .65266 L
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
.26247 .65286 L
.26248 .65253 L
.26248 .65199 L
.26249 .65119 L
.2625 .65013 L
.26252 .64878 L
.26253 .64738 L
.26254 .64555 L
.26253 .64372 L
.2625 .64163 L
.26246 .63942 L
.26244 .63712 L
.26244 .63489 L
.26251 .6326 L
.26265 .6304 L
.26288 .62833 L
.2632 .62621 L
.26359 .62423 L
.26405 .62231 L
.26455 .62039 L
.26504 .61868 L
.26555 .61702 L
.26604 .6155 L
.26649 .61412 L
.2669 .61292 L
.26728 .61197 L
.26762 .61123 L
.26793 .61076 L
.26823 .61057 L
.26852 .61063 L
.26881 .6109 L
.26914 .61134 L
.2695 .61189 L
.26991 .61252 L
.2704 .61316 L
Mistroke
.27095 .61382 L
.27152 .61447 L
.27207 .61505 L
.27255 .61552 L
.27289 .61584 L
.27304 .61596 L
.27297 .61587 L
.27268 .61553 L
.27217 .61495 L
.2715 .61409 L
.27069 .61295 L
.2698 .61151 L
.26893 .60996 L
.26799 .60789 L
.26712 .60567 L
.2663 .60303 L
.26555 .60005 L
.26494 .59688 L
.26444 .59361 L
.26411 .5901 L
.26388 .58613 L
.26374 .58291 L
.26365 .57915 L
.26355 .5756 L
.26342 .5718 L
.26324 .56827 L
.26303 .56452 L
.26281 .56068 L
.26255 .55739 L
.26227 .55381 L
.26197 .55024 L
.26164 .54658 L
.26129 .5429 L
.26093 .5393 L
.26056 .53548 L
.26019 .53166 L
.25983 .5283 L
.25947 .52464 L
.25908 .52092 L
.25865 .51779 L
.25817 .51447 L
.25766 .51135 L
.25716 .5084 L
.25671 .50586 L
.25635 .50361 L
.2561 .50164 L
.25592 .50001 L
.25573 .49875 L
.25547 .49767 L
.25509 .49673 L
Mistroke
.25454 .49593 L
.25379 .49524 L
.25286 .4946 L
.25177 .494 L
.25058 .49343 L
.24936 .4929 L
.24834 .49245 L
.24705 .492 L
.246 .49152 L
.24499 .49096 L
.24407 .49038 L
.24334 .48988 L
.24284 .4895 L
.24255 .48929 L
.2424 .48924 L
.24227 .48936 L
.24208 .48963 L
.2417 .49001 L
.24099 .49048 L
.23992 .49101 L
.23845 .49157 L
.23673 .49216 L
.23468 .49279 L
.23223 .49346 L
.22961 .49415 L
.22693 .49482 L
.22382 .49544 L
.22074 .49597 L
.21787 .49639 L
.21437 .49671 L
.21149 .49693 L
.20839 .49707 L
.20523 .49713 L
.202 .49711 L
.19854 .49704 L
.19566 .49688 L
.19221 .49662 L
.18918 .49623 L
.18578 .49572 L
.18254 .4951 L
.17904 .49437 L
.17587 .49355 L
.17236 .49266 L
.16926 .49169 L
.16597 .49061 L
.163 .48942 L
.15999 .48819 L
.15704 .48685 L
.15416 .48552 L
.15136 .48415 L
Mistroke
.14858 .48276 L
.14579 .48148 L
.14322 .48024 L
.14047 .47905 L
.13773 .47792 L
.13509 .47686 L
.13222 .47582 L
.12952 .47478 L
.12668 .47376 L
.12397 .4727 L
.12115 .47161 L
.1187 .47054 L
.11609 .46945 L
.11397 .4683 L
.11195 .46706 L
.11012 .46579 L
.10852 .46433 L
.10717 .46279 L
.10604 .46104 L
.10511 .45915 L
.10434 .45718 L
.10367 .45497 L
.1031 .45283 L
.10259 .45051 L
.10211 .44801 L
.10164 .44572 L
.10116 .44332 L
.10072 .44087 L
.10031 .43883 L
.0999 .43682 L
.09956 .43501 L
.09927 .43346 L
.09905 .43224 L
.09892 .43135 L
.0989 .43071 L
.09898 .43026 L
.09912 .42995 L
.09933 .42972 L
.09964 .42949 L
.10007 .42922 L
.10066 .42889 L
.1014 .42848 L
.10231 .42802 L
.10335 .42751 L
.10445 .42694 L
.10563 .42629 L
.10682 .42559 L
.10791 .42489 L
.109 .42425 L
.10992 .42369 L
Mistroke
.11073 .42325 L
.11143 .42292 L
.11201 .42273 L
.11249 .42267 L
.1129 .42276 L
.11329 .42295 L
.11367 .42325 L
.11407 .42367 L
.11452 .42421 L
.11503 .42486 L
.11565 .42561 L
.11637 .42643 L
.11715 .4273 L
.11796 .42816 L
.11873 .42901 L
.11945 .42982 L
.12009 .43057 L
.12067 .43128 L
.12118 .43187 L
.12165 .43242 L
.12214 .43301 L
.12269 .43358 L
.12334 .43423 L
.12412 .43496 L
.12503 .43583 L
.12617 .43687 L
.12755 .43816 L
.12903 .4397 L
.13079 .44123 L
.13253 .44301 L
.13451 .44483 L
.13655 .44689 L
.13857 .44868 L
.14071 .45045 L
.14253 .45208 L
.14433 .45355 L
.14596 .45478 L
.14731 .45574 L
.14849 .45648 L
.14946 .45701 L
.1502 .45734 L
.15074 .45753 L
.15109 .45762 L
.15128 .45764 L
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
Mistroke
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
.15076 .45723 L
.15102 .45723 L
.15139 .45723 L
.1519 .45723 L
.15256 .45722 L
.15336 .45722 L
.15438 .45722 L
.15557 .45721 L
.15697 .45721 L
.15844 .4572 L
.16008 .45719 L
.16171 .45718 L
.16336 .45712 L
.16497 .45701 L
.16639 .45686 L
.16767 .45667 L
.16881 .45651 L
.1697 .45641 L
.17041 .45642 L
.17095 .45661 L
.17131 .45704 L
.17151 .45776 L
.17161 .45883 L
.17165 .46031 L
.17169 .46224 L
.17176 .46409 L
.17188 .46671 L
.17208 .46961 L
.17245 .47238 L
.17298 .47567 L
.17374 .4795 L
.17461 .48256 L
.17563 .48608 L
.17682 .48924 L
.17807 .4924 L
.17945 .49505 L
.18084 .49752 L
.18231 .49974 L
.18387 .50157 L
.18545 .50324 L
.18721 .50472 L
.18916 .506 L
.19119 .50715 L
.19351 .50819 L
.19565 .50908 L
.198 .5099 L
.2005 .51065 L
Mistroke
.2028 .51131 L
.20525 .51192 L
.20784 .51244 L
.21008 .51283 L
.21257 .51308 L
.21468 .51314 L
.21689 .51307 L
.21895 .51275 L
.22091 .51224 L
.22281 .51156 L
.22467 .51077 L
.22644 .50989 L
.22819 .50899 L
.2299 .508 L
.23161 .50699 L
.2331 .50589 L
.23463 .50474 L
.2361 .50357 L
.23737 .50245 L
.23857 .50147 L
.23966 .50061 L
.24061 .49992 L
.24139 .4994 L
.24205 .49902 L
.24258 .49876 L
.24301 .49861 L
.24335 .49855 L
.24364 .49859 L
.24389 .49876 L
.24412 .49903 L
.24429 .49936 L
.2444 .4997 L
.24446 .5 L
.24446 .50024 L
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
Mistroke
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
.2438 .50047 L
.24377 .50027 L
.24385 .49994 L
.24405 .49944 L
.24441 .49876 L
.24498 .49788 L
.24579 .49681 L
.24687 .49551 L
.24812 .494 L
.24964 .49223 L
.2514 .49028 L
.25336 .48806 L
.25546 .48569 L
.25779 .48297 L
.26002 .48042 L
.26233 .47757 L
.26459 .47477 L
.26684 .47182 L
.26878 .46892 L
.2707 .46596 L
.27244 .46276 L
.27409 .45955 L
.27563 .45666 L
.27711 .45348 L
.27855 .45003 L
.27995 .44643 L
.28141 .44353 L
.28283 .44019 L
.28428 .43664 L
.28577 .43349 L
.28729 .43014 L
.28883 .42656 L
.29038 .42357 L
.29192 .4203 L
.29345 .41729 L
.29498 .41422 L
.29648 .41153 L
.2979 .40878 L
Mistroke
.29928 .40624 L
.30057 .40371 L
.30183 .40121 L
.30296 .39896 L
.30402 .39675 L
.30501 .39482 L
.30591 .39304 L
.30675 .39151 L
.30754 .39017 L
.3083 .3891 L
.30909 .38823 L
.30991 .38756 L
.31077 .38709 L
.31172 .38678 L
.31276 .38659 L
.31392 .38652 L
.31507 .3865 L
.31633 .38653 L
.31766 .38659 L
.31893 .38667 L
.32019 .3867 L
.3213 .38669 L
.32237 .38656 L
.32325 .38652 L
.32395 .38651 L
.32447 .38653 L
.32479 .38658 L
.32491 .38665 L
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
.32441 .38688 L
.32504 .3867 L
.326 .38643 L
.32728 .38607 L
.32883 .38562 L
.33065 .38511 L
.33266 .38455 L
.33488 .38396 L
.33728 .38334 L
.33979 .38268 L
.34241 .38198 L
.34501 .38123 L
.34762 .38043 L
.3502 .37957 L
.35276 .37865 L
.35528 .37768 L
Mistroke
.35784 .37667 L
.36043 .37562 L
.36307 .37458 L
.36576 .3735 L
.36845 .37242 L
.37105 .3714 L
.3735 .37047 L
.37574 .36963 L
.37773 .36891 L
.37939 .36833 L
.38074 .36791 L
.38177 .36769 L
.38247 .36766 L
.38287 .36782 L
.38297 .3681 L
.38285 .36844 L
.38255 .36876 L
.38214 .36904 L
.38167 .36927 L
.38119 .36947 L
.38074 .36966 L
.38033 .36984 L
.37997 .37002 L
.37969 .3702 L
.37956 .37035 L
.37962 .37054 L
.37992 .37075 L
.38049 .37101 L
.38132 .37133 L
.38237 .37178 L
.38359 .37237 L
.38493 .37308 L
.38629 .3739 L
.38762 .3748 L
.38883 .37569 L
.38993 .37656 L
.3909 .37732 L
.39172 .37794 L
.39244 .37839 L
.3931 .37863 L
.39379 .37863 L
.39455 .37836 L
.39547 .37776 L
.39662 .37682 L
.39804 .37555 L
.3997 .37402 L
.40161 .37229 L
.40373 .37051 L
.40596 .36868 L
.4082 .36678 L
Mistroke
.41035 .36486 L
.41234 .36291 L
.41415 .36103 L
.41572 .35912 L
.41703 .35734 L
.41818 .35562 L
.41932 .35381 L
.42062 .35183 L
.4222 .34967 L
.42415 .34722 L
.42652 .34434 L
.42922 .34084 L
.43226 .33686 L
.43556 .33218 L
.43889 .32824 L
.44227 .32366 L
.4456 .31974 L
.44862 .31609 L
.4514 .31286 L
.45383 .30981 L
.45584 .30693 L
.45737 .30463 L
.4584 .30314 L
.45898 .30236 L
.45918 .30205 L
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
.45847 .30371 L
.45876 .30382 L
.45925 .30384 L
.46007 .30373 L
.46138 .30345 L
.46327 .30298 L
.4657 .30232 L
.46873 .30149 L
.47231 .30049 L
.47639 .29939 L
.48054 .29831 L
.48486 .29721 L
.48901 .29621 L
.49324 .29523 L
.49796 .29421 L
.50243 .29321 L
.50716 .29219 L
.51214 .29118 L
Mistroke
.51732 .29014 L
.52261 .28908 L
.52746 .28802 L
.53224 .28695 L
.53677 .2859 L
.54087 .28489 L
.54437 .2839 L
.54769 .28291 L
.55093 .28195 L
.55391 .28109 L
.55634 .28037 L
.55817 .27984 L
.55948 .27948 L
.56042 .27923 L
.56123 .27907 L
.56222 .27894 L
.56353 .27876 L
.56528 .27841 L
.56791 .27782 L
.57124 .27697 L
.57537 .27589 L
.58055 .27456 L
.58704 .27301 L
.59455 .27133 L
.60315 .26954 L
.61209 .26772 L
.61954 .26593 L
.62673 .26428 L
.63349 .26281 L
.63972 .26142 L
.64615 .26014 L
.6525 .25903 L
.65733 .25818 L
.66003 .25763 L
.66113 .25736 L
.66138 .25729 L
.66118 .25737 L
.66051 .25752 L
.65976 .25766 L
.65982 .25773 L
.66052 .25771 L
.66167 .25767 L
.66321 .2577 L
.66517 .25785 L
.66753 .25811 L
.67029 .2585 L
.67346 .259 L
.67697 .25959 L
.6807 .26023 L
.68442 .26091 L
Mistroke
.68807 .26159 L
.69147 .26228 L
.69461 .26296 L
.6974 .26363 L
.69979 .26425 L
.70176 .26482 L
.70339 .26527 L
.70475 .26556 L
.7059 .26564 L
.70692 .2655 L
.70788 .26513 L
.70894 .26454 L
.71023 .26374 L
.71182 .26274 L
.71368 .26153 L
.71579 .26017 L
.71821 .25856 L
.72093 .25679 L
.72382 .2549 L
.7268 .25288 L
.7298 .25087 L
.73286 .24877 L
.73593 .24663 L
.73905 .24456 L
.74221 .24249 L
.74545 .24049 L
.74878 .23848 L
.75219 .23646 L
.75568 .23443 L
.75921 .23239 L
.76263 .23032 L
.76594 .22825 L
.76897 .22631 L
.7718 .22436 L
.77439 .22239 L
.77675 .22043 L
.77885 .21854 L
.78073 .21667 L
.78239 .21473 L
.78387 .21266 L
.78521 .21052 L
.78647 .2083 L
.78771 .20596 L
.78901 .20355 L
.79035 .20109 L
.79169 .19873 L
.79295 .19648 L
.7941 .19447 L
.79513 .19261 L
.79603 .19109 L
Mistroke
.79677 .18983 L
.79734 .18886 L
.79778 .18817 L
.79819 .18773 L
.79864 .18749 L
.79922 .18741 L
.79998 .18744 L
.80098 .18752 L
.80223 .18758 L
.80372 .18755 L
.80539 .18739 L
.80721 .1871 L
.8091 .18673 L
.811 .18633 L
.81286 .18593 L
.81462 .18558 L
.81622 .18533 L
.81762 .18518 L
.81881 .18516 L
.8198 .18531 L
.8206 .18563 L
.82123 .18608 L
.82172 .18661 L
.8221 .18718 L
.82243 .18777 L
.82275 .18836 L
.8231 .18893 L
.82346 .18945 L
.82372 .18967 L
.82402 .18993 L
.82426 .19007 L
.82443 .19011 L
.82454 .19004 L
.82458 .18987 L
.82454 .18965 L
.82446 .1894 L
.82438 .18922 L
.82429 .18905 L
.8242 .18893 L
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
.8241 .18908 L
.82395 .18887 L
Mistroke
.82374 .18851 L
.82348 .18797 L
.82319 .18723 L
.82285 .18629 L
.82252 .18517 L
.82212 .18384 L
.82168 .18232 L
.82119 .18075 L
.82069 .17911 L
.82016 .1774 L
.81962 .17571 L
.81907 .17412 L
.81855 .17269 L
.81804 .17138 L
.81758 .17023 L
.81716 .16932 L
.81675 .1686 L
.81633 .16807 L
.81587 .16774 L
.81537 .16756 L
.81481 .16749 L
.81414 .16749 L
.81353 .16752 L
.81285 .16758 L
.81215 .16762 L
.81146 .16762 L
.81076 .16758 L
.8101 .16751 L
.80944 .16743 L
.80883 .1674 L
.80832 .16744 L
.80793 .16754 L
.80768 .16769 L
.80757 .16791 L
.80758 .1682 L
.80763 .16858 L
.80769 .16906 L
.80774 .16965 L
.80774 .17033 L
.80767 .17111 L
.80757 .17196 L
.80746 .17284 L
.80738 .17373 L
.80731 .17458 L
.80725 .17532 L
.80722 .17596 L
.80721 .17647 L
.80722 .17688 L
.80725 .17719 L
.80732 .17741 L
Mistroke
.80743 .17756 L
.80759 .1777 L
.80777 .17787 L
.80796 .17815 L
.80818 .17857 L
.80846 .17919 L
.80881 .18008 L
.80925 .18127 L
.80987 .18256 L
.81071 .18416 L
.81185 .18606 L
.81323 .18801 L
.81485 .19031 L
.81679 .1926 L
.81904 .19516 L
.82094 .19757 L
.82327 .2 L
.82554 .20231 L
.82784 .20448 L
.83001 .20643 L
.83212 .20819 L
.83372 .20984 L
.83516 .21115 L
.83644 .2123 L
.83744 .21322 L
.83818 .21388 L
.83863 .21426 L
.83885 .2144 L
.83896 .21436 L
.83901 .21424 L
.839 .2141 L
.83897 .21404 L
.839 .21412 L
.83911 .21437 L
.83929 .21482 L
.8395 .21544 L
.83977 .21622 L
.84007 .21714 L
.84039 .21813 L
.84072 .21926 L
.84106 .22054 L
.84139 .22197 L
.84169 .22335 L
.84195 .22473 L
.84218 .22604 L
.84236 .2272 L
.84249 .22811 L
.8426 .22885 L
.84269 .22944 L
.84276 .22987 L
Mistroke
.84279 .23014 L
.84278 .23028 L
.84274 .23027 L
.84266 .23011 L
.84257 .22979 L
.84247 .22932 L
.84237 .22872 L
.84226 .22804 L
.84211 .22733 L
.84194 .22664 L
.84174 .22598 L
.84148 .22529 L
.84116 .22454 L
.84076 .22371 L
.84032 .22277 L
.83987 .22179 L
.83936 .22065 L
.83878 .21934 L
.83826 .21789 L
.83768 .21634 L
.83704 .21486 L
.83642 .21334 L
.83575 .21171 L
.83512 .21025 L
.8345 .20876 L
.83395 .20744 L
.8335 .20621 L
.83312 .20524 L
.83281 .20436 L
.83256 .20379 L
.83238 .20332 L
.83224 .20307 L
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
Mistroke
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
Mistroke
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
.82987 .19484 L
.82988 .19449 L
.82983 .19397 L
.8297 .19328 L
.82947 .19239 L
.82914 .19128 L
.8287 .19006 L
.82813 .18864 L
.82741 .18692 L
.82653 .18521 L
.82555 .18326 L
.82438 .18112 L
.82309 .17894 L
.82171 .17654 L
.82014 .17423 L
.81856 .17179 L
.81688 .16928 L
.81522 .16688 L
.8136 .16456 L
.81205 .16234 L
.81061 .16024 L
.80937 .15846 L
Mistroke
.80821 .15677 L
.80733 .15555 L
.80658 .15452 L
.80598 .1537 L
.80553 .15311 L
.80523 .15275 L
.80506 .15256 L
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
.80575 .15345 L
.80545 .15323 L
.80492 .15282 L
.80414 .15217 L
.80311 .15119 L
.8018 .14986 L
.80015 .14816 L
.79828 .14616 L
.7966 .14434 L
.79452 .14205 L
.79236 .1398 L
.79012 .13723 L
.78751 .13443 L
.78551 .13196 L
.78354 .12962 L
.78149 .12709 L
.77975 .1249 L
.7783 .12319 L
.77701 .1216 L
.77594 .12021 L
.77512 .11914 L
.77448 .11837 L
.77395 .1177 L
.77354 .11725 L
.77318 .11687 L
.77282 .11658 L
.77245 .11636 L
.77202 .11618 L
.77149 .11601 L
Mistroke
.77083 .11582 L
.77004 .11563 L
.76931 .11545 L
.76847 .11528 L
.7676 .11509 L
.76677 .1149 L
.76608 .11474 L
.76554 .11461 L
.76513 .1145 L
.76484 .11444 L
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
Mistroke
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
Mistroke
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
Mistroke
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
Mistroke
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
Mistroke
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
Mistroke
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
Mistroke
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
Mistroke
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
.76851 .11563 L
.76862 .11554 L
.76876 .11551 L
.76897 .11555 L
.76922 .11568 L
.76952 .11589 L
.76984 .11617 L
.7702 .11651 L
.77061 .11692 L
.77109 .11739 L
Mistroke
.77165 .11793 L
.7723 .11855 L
.77305 .11923 L
.77391 .11998 L
.77486 .12082 L
.77592 .12172 L
.77706 .12266 L
.77811 .1236 L
.77922 .12444 L
.78034 .12531 L
.78131 .12617 L
.78225 .127 L
.78313 .12771 L
.78391 .12839 L
.78456 .129 L
.78513 .1295 L
.78561 .12991 L
.78603 .13025 L
.78643 .13054 L
.78686 .13086 L
.78737 .13127 L
.78801 .13188 L
.78877 .13271 L
.78972 .13384 L
.79078 .13516 L
.79206 .1368 L
.79355 .1388 L
.79526 .14104 L
.79724 .14366 L
.79924 .14656 L
.80149 .14979 L
.80398 .15344 L
.8065 .15683 L
.80909 .16072 L
.81184 .16421 L
.81451 .16811 L
.81737 .17156 L
.82028 .17535 L
.8229 .179 L
.82536 .18235 L
.82799 .18588 L
.83057 .18947 L
.8331 .19281 L
.83582 .1966 L
.83826 .20002 L
.84112 .20427 L
.84373 .20785 L
.84634 .21216 L
.8492 .21652 L
.85201 .22124 L
Mistroke
.85528 .22665 L
.85798 .23087 L
.86098 .23564 L
.86398 .24063 L
.86659 .24445 L
.86919 .24842 L
.87164 .25218 L
.87372 .2554 L
.87545 .25792 L
.87698 .26015 L
.87821 .26193 L
.87912 .2633 L
.87976 .26427 L
.88015 .26488 L
.88034 .26522 L
.8804 .2654 L
.88038 .2655 L
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
.88164 .26609 L
.88177 .26645 L
.88203 .26701 L
.88247 .26786 L
.88312 .26906 L
.88401 .27059 L
.88504 .27225 L
.88624 .27428 L
.8876 .2764 L
.88907 .27877 L
.89051 .28111 L
.89198 .28358 L
.89336 .2857 L
.89455 .28771 L
.89567 .28949 L
.89658 .29098 L
.8973 .29215 L
.89781 .29304 L
Mistroke
.89811 .29366 L
.89824 .29403 L
.89827 .29422 L
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
.89769 .29343 L
.89775 .29376 L
.89786 .29422 L
.89804 .29481 L
.89827 .29551 L
.89855 .29627 L
.89889 .2971 L
.89925 .29796 L
.89964 .2988 L
.90004 .2996 L
.90043 .30031 L
.9008 .30093 L
.90113 .30141 L
.90141 .30177 L
Mistroke
.90164 .302 L
.90181 .30213 L
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
.90361 .30418 L
Mistroke
.90345 .30423 L
.90325 .30419 L
.90302 .30401 L
.90272 .30362 L
.90233 .30297 L
.90184 .30203 L
.90121 .3008 L
.90043 .29919 L
.89944 .29718 L
.89822 .29465 L
.89678 .29193 L
.89506 .2883 L
.89308 .28494 L
.89076 .28079 L
.88831 .27657 L
.88551 .27199 L
.88254 .2668 L
.87943 .26229 L
.87615 .25691 L
.87282 .25169 L
.86959 .24721 L
.86627 .24211 L
.86288 .23653 L
.8597 .232 L
.85648 .22691 L
.85327 .22218 L
.85011 .21742 L
.84679 .21239 L
.84358 .20782 L
.84027 .2031 L
.83683 .19806 L
.83326 .19324 L
.82969 .18808 L
.82609 .18332 L
.82224 .17786 L
.81864 .17315 L
.81487 .16799 L
.81097 .16224 L
.80736 .15763 L
.80369 .15248 L
.80006 .14716 L
.79648 .14261 L
.79314 .13806 L
.78981 .13401 L
.7865 .12999 L
.78342 .12688 L
.78026 .12376 L
.77714 .12093 L
.77414 .11865 L
.7711 .11657 L
Mistroke
.76854 .11477 L
.76605 .11332 L
.76387 .11207 L
.76175 .11101 L
.75967 .11016 L
.75778 .10923 L
.756 .10836 L
.75416 .10742 L
.75219 .10638 L
.75001 .10525 L
.74757 .10405 L
.74483 .1028 L
.74232 .10156 L
.73909 .10026 L
.73564 .09886 L
.73169 .09729 L
.72676 .09549 L
.72253 .09366 L
.71737 .09161 L
.71217 .0894 L
.70663 .08715 L
.70094 .08474 L
.69503 .08243 L
.68954 .08003 L
.68362 .07759 L
.67764 .07518 L
.672 .07277 L
.66569 .07038 L
.66051 .06801 L
.65482 .06568 L
.64916 .06331 L
.64373 .06119 L
.63887 .0591 L
.63392 .05711 L
.6292 .05517 L
.62475 .05339 L
.62023 .05163 L
.6162 .04999 L
.61205 .0484 L
.60851 .04694 L
.60486 .04552 L
.60153 .04418 L
.59841 .04296 L
.59547 .04184 L
.59297 .04084 L
.59064 .03996 L
.58867 .03923 L
.58688 .0386 L
.58529 .03809 L
.58391 .03762 L
Mistroke
.58271 .03723 L
.5817 .03692 L
.58091 .0367 L
.58033 .03656 L
.57987 .03647 L
.57952 .03641 L
.57925 .03639 L
.57903 .03641 L
.57887 .03645 L
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
.57891 .03657 L
.57852 .03656 L
Mistroke
.57803 .03654 L
.57745 .03652 L
.57681 .0365 L
.57618 .03647 L
.57556 .03645 L
.57501 .03643 L
.57444 .03641 L
.57392 .0364 L
.57346 .03638 L
.57304 .03637 L
.57263 .03636 L
.57221 .03634 L
.57172 .03633 L
.57117 .03631 L
.57055 .03629 L
.56981 .03626 L
.56898 .03623 L
.56796 .0362 L
.56683 .03616 L
.56565 .03612 L
.56449 .03608 L
.56332 .03604 L
.56219 .036 L
.56115 .03597 L
.56023 .03594 L
.55947 .03592 L
.55889 .0359 L
.55843 .03588 L
.55807 .03587 L
.55778 .03586 L
.55755 .03586 L
.55737 .03585 L
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
.5577 .03586 L
.55723 .03585 L
.55649 .03583 L
.55546 .0358 L
.55415 .03575 L
.55255 .0357 L
.55088 .03564 L
Mistroke
.54897 .03557 L
.54684 .0355 L
.54468 .03543 L
.54261 .03535 L
.54054 .03528 L
.5386 .03522 L
.53706 .03517 L
.53572 .03512 L
.53461 .03509 L
.53377 .03506 L
.53322 .03504 L
.53293 .03501 L
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
.53341 .03493 L
.53343 .03522 L
.53343 .03563 L
.53344 .03617 L
.53344 .03683 L
.53345 .0376 L
.53346 .03837 L
.5335 .03919 L
.5336 .03998 L
.53374 .04076 L
.53387 .04141 L
.53393 .04204 L
.53389 .04261 L
.53372 .04311 L
.53338 .04357 L
.53286 .04407 L
.53219 .0446 L
.5314 .04517 L
.53053 .04577 L
.5296 .0464 L
.52869 .04699 L
.52781 .04763 L
.52692 .04828 L
.52608 .04894 L
.52534 .04955 L
.52479 .0501 L
.52446 .05047 L
.52434 .05069 L
.5244 .05072 L
.52464 .05054 L
.52502 .0502 L
.52553 .04973 L
Mistroke
.52616 .04921 L
.52692 .04868 L
.52789 .04815 L
.52918 .04765 L
.53087 .04722 L
.53298 .04685 L
.53546 .04656 L
.53836 .0464 L
.54147 .04637 L
.54516 .04651 L
.54884 .0468 L
.55322 .04731 L
.55718 .04802 L
.56155 .0489 L
.5662 .04981 L
.57052 .05085 L
.57444 .05194 L
.57843 .05303 L
.58219 .05409 L
.58575 .05508 L
.58911 .05602 L
.59238 .05685 L
.59568 .05748 L
.59885 .05794 L
.60227 .05827 L
.60576 .05849 L
.60948 .05866 L
.61351 .05883 L
.61768 .05907 L
.6219 .05941 L
.62692 .0599 L
.63115 .06058 L
.63605 .0615 L
.64119 .06269 L
.6471 .064 L
.65185 .06563 L
.65755 .06748 L
.66309 .06951 L
.66875 .07159 L
.6741 .07393 L
.67954 .07609 L
.68474 .07841 L
.68914 .0805 L
.6936 .08252 L
.69779 .08446 L
.70126 .08607 L
.70411 .08751 L
.70675 .08877 L
.7087 .0898 L
.71025 .09059 L
Mistroke
.71133 .09118 L
.71195 .09158 L
.71226 .09183 L
.71236 .09197 L
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
.71245 .09177 L
.71258 .09176 L
.71275 .09175 L
.71295 .09173 L
.7132 .09172 L
.71349 .09171 L
.71382 .09172 L
.71414 .09173 L
.71446 .09174 L
.71477 .09176 L
.71507 .09181 L
.71538 .09191 L
.7157 .09208 L
.71609 .09236 L
.71658 .09275 L
.71722 .09329 L
.71806 .09402 L
.71915 .09494 L
.72049 .09608 L
.72217 .09742 L
.72409 .09874 L
.72638 .10035 L
.7291 .10194 L
.73196 .10368 L
.7352 .10546 L
.73878 .10735 L
.7425 .10917 L
.7465 .11113 L
.75035 .11289 L
.75433 .11465 L
.75843 .11637 L
.76188 .11788 L
.76527 .11928 L
.76827 .12054 L
.77091 .12165 L
.77326 .1226 L
.77515 .12335 L
.77668 .12402 L
.77796 .12461 L
.77897 .12513 L
Mistroke
.77972 .12557 L
.78028 .12597 L
.7807 .12632 L
.781 .12666 L
.78125 .12701 L
.78145 .12736 L
.78165 .12771 L
.78189 .12806 L
.7822 .12842 L
.78254 .12878 L
.78286 .12909 L
.78315 .12932 L
.78341 .12948 L
.78364 .12957 L
.78386 .12963 L
.78409 .1297 L
.78437 .12982 L
.78474 .13003 L
.78519 .13035 L
.78575 .1308 L
.78637 .13134 L
.78705 .13194 L
.78777 .13258 L
.7885 .13322 L
.78921 .13384 L
.7899 .13442 L
.79055 .13495 L
.79115 .13541 L
.7917 .13579 L
.79216 .13606 L
.79256 .13623 L
.79286 .1363 L
.79308 .13626 L
.79322 .13616 L
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
.79275 .13592 L
.79284 .13625 L
.79305 .13676 L
.79343 .13753 L
.79399 .13867 L
.79474 .14012 L
.79574 .14196 L
.79692 .14407 L
.79841 .14642 L
.80012 .14927 L
Mistroke
.80205 .15205 L
.8041 .15506 L
.80634 .15804 L
.8084 .16087 L
.81056 .16382 L
.81241 .16639 L
.81417 .16841 L
.81574 .17028 L
.81708 .17197 L
.81814 .17327 L
.81898 .17422 L
.8196 .17482 L
.81999 .17512 L
.82019 .17521 L
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
.81772 .17386 L
.81787 .17382 L
.81804 .17381 L
.81821 .17384 L
.81838 .1739 L
.81854 .17401 L
.81874 .17421 L
Mistroke
.81898 .17452 L
.81927 .17497 L
.81963 .17561 L
.82004 .17646 L
.82051 .17747 L
.82106 .17868 L
.82163 .18009 L
.82228 .18165 L
.82297 .1831 L
.82366 .18466 L
.8244 .18627 L
.82511 .18767 L
.82581 .18902 L
.82646 .1903 L
.82702 .19134 L
.82749 .19222 L
.82784 .19291 L
.82808 .19338 L
.82822 .19361 L
.82824 .19361 L
.82817 .19341 L
.82801 .19308 L
.82779 .19262 L
.82754 .19207 L
.82725 .19143 L
.82694 .19069 L
.82661 .1899 L
.82625 .18904 L
.82585 .18805 L
.82534 .18691 L
.82477 .18569 L
.82407 .18431 L
.82322 .18274 L
.82219 .18095 L
.82109 .17904 L
.81975 .17687 L
.81838 .17455 L
.81677 .17187 L
.81505 .16905 L
.81316 .16618 L
.81124 .16332 L
.80938 .16039 L
.80751 .15753 L
.80566 .15453 L
.80411 .15218 L
.80259 .14982 L
.80125 .1478 L
.79994 .14592 L
.7989 .1445 L
.79794 .14332 L
Mistroke
.79707 .1424 L
.79629 .14176 L
.79562 .14137 L
.79505 .14117 L
.79461 .14112 L
.79423 .14117 L
.79392 .14127 L
.79366 .1414 L
.79346 .14154 L
.7933 .14167 L
.79318 .14178 L
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
.79336 .14219 L
.793 .14246 L
.7925 .14284 L
.79187 .14335 L
.79115 .144 L
.79034 .14478 L
.78954 .14558 L
.78872 .14644 L
.78785 .14731 L
.78695 .14814 L
.78613 .14886 L
.78542 .14947 L
.78485 .1499 L
.78449 .15012 L
.78422 .15011 L
.78404 .14983 L
.78392 .14929 L
.78383 .14846 L
.78367 .14744 L
.78338 .14618 L
.78293 .14462 L
.78234 .14289 L
.7816 .14092 L
.78072 .13879 L
.77985 .13652 L
.77877 .13409 L
Mistroke
.7776 .13169 L
.7764 .12925 L
.77517 .12682 L
.774 .12457 L
.7728 .12244 L
.77168 .12041 L
.77059 .11883 L
.76956 .11744 L
.7686 .11627 L
.76778 .11539 L
.76698 .11476 L
.76622 .11435 L
.76552 .11412 L
.76488 .11402 L
.7643 .114 L
.76378 .11404 L
.76335 .11411 L
.76302 .11417 L
.7628 .11422 L
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
Mistroke
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
.76297 .11454 L
.76264 .11446 L
.76219 .11431 L
.76161 .1141 L
.7609 .11384 L
.76008 .11357 L
.7592 .11331 L
.75826 .11309 L
.75724 .11291 L
.75618 .11279 L
.75515 .11272 L
.75418 .11268 L
.75331 .11268 L
.7526 .1127 L
.75201 .1128 L
.75156 .11297 L
.75123 .1132 L
.751 .11347 L
.75086 .11376 L
.75079 .11403 L
.75077 .11424 L
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
Mistroke
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
.75067 .10967 L
.75076 .10987 L
.75093 .11019 L
.75121 .11062 L
.75163 .11121 L
.75223 .11195 L
.75304 .11285 L
.75406 .11395 L
.7553 .11528 L
.7567 .11677 L
.75823 .11857 L
.75998 .12051 L
.76186 .12278 L
.76385 .12502 L
.76592 .1275 L
.76799 .13005 L
.77004 .1326 L
.77201 .1353 L
.77382 .13752 L
.77549 .13991 L
.77699 .1424 L
.77829 .14486 L
.77932 .14691 L
.78014 .14895 L
.78076 .15114 L
.78124 .15348 L
.78163 .15587 L
.782 .15788 L
.7824 .16048 L
Mistroke
.78291 .16294 L
.78359 .16599 L
.78449 .16896 L
.78566 .17195 L
.78712 .17526 L
.7888 .17848 L
.79081 .18177 L
.79316 .18501 L
.79582 .18783 L
.79875 .1907 L
.80213 .1933 L
.80535 .19571 L
.80901 .19783 L
.81252 .19972 L
.81597 .20133 L
.81916 .20264 L
.82209 .20374 L
.82516 .20459 L
.82751 .20522 L
.82944 .20564 L
.83122 .20586 L
.83251 .20588 L
.83347 .20571 L
.83413 .2054 L
.83455 .20494 L
.83475 .20435 L
.8348 .20363 L
.83471 .20273 L
.83417 .20164 L
.83392 .2004 L
.83368 .19895 L
.83342 .19729 L
.83304 .19552 L
.83253 .19355 L
.83192 .19145 L
.83126 .18953 L
.83042 .18741 L
.82945 .18545 L
.82828 .18346 L
.82702 .18147 L
.82568 .17969 L
.82432 .17797 L
.82296 .17632 L
.82161 .1748 L
.82028 .17331 L
.819 .17183 L
.81778 .17041 L
.81655 .16896 L
.81533 .16743 L
.81408 .16582 L
Mistroke
.81284 .16424 L
.81166 .16262 L
.81058 .16103 L
.8096 .15948 L
.80873 .1581 L
.80798 .15685 L
.80736 .15575 L
.80687 .15487 L
.80646 .15417 L
.80611 .15364 L
.80582 .15325 L
.80559 .15301 L
.80545 .15289 L
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
.80597 .15368 L
.80553 .15323 L
.80477 .1524 L
.8037 .15116 L
.80235 .14953 L
.80065 .1474 L
.79855 .14475 L
.79633 .1421 L
.79344 .13917 L
.79056 .13611 L
.78718 .13263 L
.78356 .1285 L
.7799 .12527 L
.77585 .12208 L
.77234 .11891 L
.76835 .11605 L
.76456 .11339 L
.76036 .11102 L
.75598 .10875 L
.75199 .10675 L
.74722 .10466 L
.74262 .10251 L
.73764 .10026 L
.73205 .0979 L
.72738 .09578 L
.72249 .09357 L
.71694 .0912 L
.71264 .08924 L
.70794 .0873 L
.70359 .08546 L
.69942 .08384 L
Mistroke
.696 .08249 L
.6929 .08136 L
.6904 .08045 L
.68824 .07979 L
.68649 .07937 L
.68509 .07913 L
.68398 .079 L
.6831 .07896 L
.68243 .07899 L
.68191 .07903 L
.68153 .07911 L
.68124 .07919 L
.68099 .07925 L
.68079 .07935 L
.68066 .07948 L
.68058 .07965 L
.68055 .07983 L
.68058 .08002 L
.68064 .08018 L
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
Mistroke
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
.67716 .08038 L
.67665 .08011 L
.67587 .07963 L
.67476 .07893 L
.67327 .07797 L
.67151 .07679 L
.66925 .07537 L
.66675 .07372 L
.66375 .07185 L
.66048 .07003 L
.65695 .0678 L
.65314 .0659 L
.64935 .0638 L
.64546 .06169 L
.64141 .05966 L
.63773 .05783 L
.63389 .05602 L
.63007 .05443 L
.62628 .05299 L
.62263 .05169 L
.61899 .05055 L
.61563 .04959 L
.6122 .04872 L
.60896 .04794 L
.60561 .04721 L
.60204 .0465 L
.59853 .04576 L
.59462 .04499 L
.59069 .04416 L
.58637 .04328 L
.58241 .04236 L
.57818 .04151 L
.57428 .0406 L
.5706 .03967 L
Mistroke
.56706 .03873 L
.56365 .03793 L
.561 .03719 L
.55861 .03654 L
.55652 .03602 L
.555 .03564 L
.55381 .03541 L
.55299 .03533 L
.55245 .03536 L
.55202 .03546 L
.55156 .03558 L
.5509 .03569 L
.54993 .03577 L
.54862 .03579 L
.54684 .03576 L
.54449 .0357 L
.54169 .0356 L
.53845 .03549 L
.53467 .03538 L
.53106 .03525 L
.52725 .0351 L
.52351 .03494 L
.51997 .03477 L
.51643 .0346 L
.51372 .03445 L
.51129 .03433 L
.50915 .03423 L
.50767 .03416 L
.50661 .03414 L
.50604 .03414 L
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
.51004 .0341 L
.5097 .03418 L
.50907 .03434 L
.50807 .03456 L
.50665 .03484 L
.50481 .03517 L
Mistroke
.50273 .03552 L
.50016 .03589 L
.49735 .03624 L
.49426 .03658 L
.49122 .03691 L
.48815 .03722 L
.4855 .03749 L
.48299 .0377 L
.48115 .03784 L
.47966 .03791 L
.4786 .03792 L
.47798 .03788 L
.47776 .03781 L
.47778 .03774 L
.47791 .03767 L
.47801 .0376 L
.47801 .03753 L
.47786 .03746 L
.47752 .03741 L
.47689 .03739 L
.47601 .0374 L
.47486 .03746 L
.47359 .03758 L
.47234 .03779 L
.47109 .0381 L
.46992 .03855 L
.46888 .03913 L
.46804 .03985 L
.46736 .04067 L
.46685 .04159 L
.46647 .04262 L
.46618 .04371 L
.46595 .04477 L
.46575 .04566 L
.46558 .04638 L
.46548 .04694 L
.46546 .04733 L
.46549 .04756 L
.46559 .0476 L
.46567 .04749 L
.46562 .04729 L
.46538 .04708 L
.4649 .04689 L
.46414 .04677 L
.46306 .04666 L
.46161 .0466 L
.45984 .04663 L
.45805 .04642 L
.45586 .04654 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{783, 144.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<?0000T1000`40O003h00Oogooogooogoo4Woo
003oOoooOoooOolBOol00?mooomooomooa9oo`00ogooogooogoo4Woo003oOoooOoooOolBOol00?mo
oomooomooa9oo`00EGoo2@00SWoo2@00SWoo2000SWoo2@00SWoo2@00EWoo001=Ool80009Ool8001n
Ool80009Ool8001nOol80008Ool8001nOol80009Ool8001nOol90008Ool8001>Ool004Uoo`@001Uo
o`D007Aoo`D001Uoo`@007Aooa@000Yoo`D007=ooaH000Uoo`D007=oob<004Yoo`00AGoo10008Woo
0`00KWoo0`008Woo1000KWoo2@0000=oo`0000002`003Woo0`00KWoo0`001goo0P002goo1@002Woo
0`00KWoo0`0037oo0P001goo00<007ooOol00Woo1`0000=oo`0000000P00AWoo0013Ool2000YOol3
001XOol3000YOol3001YOol600000goo000000040005Ool00`00Oomoo`0EOol3001XOol4000JOol3
0004Ool30004Ool3001YOol3000=Ool20007Ool90002Ool40003Ool30013Ool0041oo`<002ioo`80
06Aoo`8002moo`8006Aoo`D002]oo`8006Aoo`800003Ool007oo01eoo`D0009oo`<000Eoo`8006Ao
o`D001moo`X000=oo`80045oo`00?Woo0P00<goo0P00H7oo0P00<goo0P00H7oo1@00;goo0P00H7oo
0P0000=oo`000000:7oo0`001Goo0P00H7oo1000:Goo1@000goo0P00?goo000lOol2000gOol2001L
Ool2000gOol2001LOol5000cOol2001LOol200000goo0000000/Ool50003Ool2001LOol5000]Ool4
0003Ool2000mOol003Yoo`8003]oo`8005Qoo`8003]oo`8005Qoo`L003Eoo`8005Qoo`80009oo`80
039oo`<0009oo`8005Qoo`800003Ool00000035oo`D0009oo`8003]oo`00>Goo00<007ooOol0?Goo
0P00E7oo0P00?goo00<007ooOol0Dgoo0P0000=oo`0000000P00>Goo0P00EGoo00<007ooOol00P00
=Woo0`000Woo0P00E7oo0P0000=oo`000000=goo0`000Woo00<007ooOol0>7oo000gOol20012Ool2
001@Ool20012Ool2001AOol200000goo00000003000lOol2001AOol2000017oo00000000>Goo0`00
0Woo0P00D7oo0P0000Aoo`00000003Yoo`H003Qoo`00=Woo00<007ooOol0A7oo00<007ooOol0C7oo
00<007ooOol0A7oo00<007ooOol0CGoo00<007oo00001P00?Woo00<007ooOol0CGoo00<007ooOol0
0P00?Woo1@00CWoo00<007ooOol00`00?7oo1P00=goo000dOol20018Ool00`00Oomoo`1:Ool00`00
Oomoo`16Ool2001;Ool200000goo000000040011Ool2001;Ool2000017oo00000000@Goo0P0000=o
o`00Ool0Bgoo00<007oo00000P00@7oo1P00=Goo000cOol00`00Oomoo`19Ool00`00Oomoo`18Ool0
0`00Oomoo`19Ool00`00Oomoo`17Ool00`00Ool000060014Ool00`00Oomoo`17Ool00`00Ool00002
0014Ool4001:Ool01000Ool00000A7oo1@00=7oo000bOol00`00Oomoo`1;Ool20016Ool2001=Ool2
0016Ool00`00Oomoo`030019Ool00`00Oomoo`14Ool200000goo00000018Ool40016Ool40017Ool5
000cOol0035oo`03001oogoo04ioo`03001oogoo049oo`03001oogoo04moo`03001oogoo049oo`03
001oo`0000<004]oo`03001oogoo049oo`04001oogoo001;Ool200000goo001oo`13Ool01000Ool0
0000AWoo0P0000=oo`0000000`00<Woo000_Ool2001BOol00`00Oomoo`10Ool00`00Oomoo`1AOol0
0`00Oomoo`0oOol7001=Ool20011Ool01000Ool00000CGoo00@007ooOol0049oo`<004Ioo`8000Ao
o`H0031oo`00;Woo00<007ooOol0Dgoo00<007ooOol0?Woo00<007ooOol0Dgoo00<007ooOol0?Goo
00<007oo00000P0000=oo`00Ool0Cgoo00<007ooOol0?Goo00@007oo000004ioo`80009oo`03001o
ogoo03ioo`<004Moo`8000Eoo`@00003Ool007oo02ioo`00;Goo00<007ooOol0EGoo0P00?7oo0P00
Egoo00<007ooOol0>goo00<007ooOol00`00Dgoo00<007ooOol0>goo00@007oo0000055oo`800003
Ool0000003aoo`800003Ool0000004Qoo`03001oogoo00=oo`800005Ool00000Ool0000^Ool002ao
o`03001oogoo05Qoo`03001oogoo03Qoo`03001oogoo05Qoo`03001oogoo03Uoo`03001oogoo00@0
05Aoo`03001oogoo03Uoo`04001oogoo001COol01@00Oomoogoo0000>Woo00<007ooOol00P00BGoo
0P0017oo0P000Woo0P0000=oo`00Ool0;7oo000ZOol2001LOol00`00Oomoo`0fOol00`00Oomoo`1J
Ool2000hOol00`00Oomoo`04001FOol00`00Oomoo`0fOol20002Ool2001DOol01@00Oomoogoo0000
>7oo00D007ooOomoo`0004]oo`03001oogoo00=oo`03001oogoo0080009oo`8002]oo`00:Goo00<0
07ooOol0GGoo00<007ooOol0=7oo00<007ooOol0GGoo00<007ooOol0=7oo00@007ooOomoo`<005Qo
o`03001oogoo03Aoo`03001oogoo009oo`03001oogoo05=oo`8000=oo`03001oogoo03Aoo`05001o
ogooOol0001=Ool00`00Oomoo`02Ool00`00Oomoo`030003Ool00`00Oomoo`0XOol002Qoo`03001o
ogoo05moo`03001oogoo039oo`03001oogoo05moo`03001oogoo039oo`04001oogooOol4001IOol0
0`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`0bOol0
1000Oomoogoo0P00CGoo0P000goo0P0000=oo`00Ool00P000goo00<007ooOol09goo000XOol00`00
Oomoo`1OOol00`00Oomoo`0bOol00`00Oomoo`1OOol00`00Oomoo`0bOol00`00Oomoo`04001JOol0
0`00Oomoo`0bOol01000Oomoogoo0P00F7oo00D007ooOomoo`0003Aoo`05001oogooOol0001?Ool0
0`00Oomoo`02Ool60003Ool00`00Oomoo`0WOol002Moo`03001oogoo065oo`03001oogoo031oo`03
001oogoo065oo`03001oogoo031oo`05001oogooOol0001NOol00`00Oomoo`0`Ool00`00Oomoo`02
Ool00`00Oomoo`1GOol20003Ool00`00Oomoo`0`Ool01@00Oomoogoo0000DGoo00@007ooOomoo`L0
00=oo`03001oogoo02Ioo`009Woo00<007ooOol0Hgoo00<007ooOol0;Woo00<007ooOol0Hgoo00<0
07ooOol0;Goo0P000goo0P00Ggoo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol0FGoo0P00
0goo00<007ooOol0;Woo00@007ooOomoo`80055oo`03001oogoo0080009oo`D000=oo`03001oogoo
02Eoo`009Goo00<007ooOol0IGoo00<007ooOol0;7oo00<007ooOol00Woo0P00HGoo00<007ooOol0
:goo00<007ooOol00goo00<007ooOol0Ggoo00<007ooOol0;7oo00<007ooOol00Woo0P00G7oo0P00
0goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0DGoo00<007oo00001Goo0`0017oo00<0
07ooOol097oo000TOol00`00Oomoo`1WOol00`00Oomoo`0ZOol00`00Oomoo`03Ool2001ROol00`00
Oomoo`0ZOol00`00Oomoo`02Ool2001ROol00`00Oomoo`0ZOol00`00Oomoo`03Ool00`00Oomoo`1L
Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool2001COol20007Ool30004Ool00`00
Oomoo`0SOol002Aoo`03001oogoo06Moo`03001oogoo02Yoo`03001oogoo009oo`8006=oo`03001o
ogoo02Uoo`03001oogoo009oo`<0069oo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo05eo
o`8000=oo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo055oo`@000Ioo`@000=oo`03001o
ogoo02=oo`008goo00<007ooOol0JGoo00<007ooOol0:7oo00<007ooOol00Woo0P00IGoo00<007oo
Ool0:7oo00<007ooOol00Woo0P00I7oo00<007ooOol0:7oo00<007ooOol00goo00<007ooOol0GWoo
00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo00<007ooOol0DGoo0P000Woo0P001Woo
10000goo00<007ooOol08Woo000SOol00`00Oomoo`1ZOol00`00Oomoo`0VOol00`00Oomoo`03Ool0
0`00Oomoo`1TOol00`00Oomoo`0WOol00`00Oomoo`02Ool3001UOol00`00Oomoo`0VOol00`00Oomo
o`03Ool00`00Oomoo`1POol00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`02Ool2001AOol2
0005Ool30006Ool20003Ool00`00Oomoo`0ROol0029oo`03001oogoo06]oo`03001oogoo02Ioo`03
001oogoo009oo`8006Moo`03001oogoo02Ioo`03001oogoo009oo`8006Ioo`03001oogoo02Ioo`03
001oogoo009oo`80069oo`8000=oo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo04moo`80
00Qoo`8000Ioo`8000=oo`03001oogoo025oo`008Woo00<007ooOol0K7oo00<007ooOol097oo00<0
07ooOol00Woo0P00J7oo00<007ooOol09Goo00<007ooOol00Woo0P00J7oo00<007ooOol097oo00<0
07ooOol00goo00<007ooOol0HWoo00<007ooOol00Woo00<007ooOol097oo00<007ooOol00Woo0P00
Agoo0P001Woo0P002goo0`001Goo00D007ooOomoo`0002=oo`008Goo00<007ooOol0KWoo00<007oo
Ool08goo00<007ooOol00Woo0P00JGoo00<007ooOol08goo00<007ooOol00Woo0P00JWoo00<007oo
Ool08goo00<007ooOol00Woo0P00IGoo00<007ooOol00Woo00<007ooOol08goo00<007ooOol00Woo
00<007ooOol0@Goo1@0000=oo`0000001P003Woo0P0017oo0P000goo00<007ooOol087oo000POol0
0`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomoo`02Ool3001ZOol00`00Oomoo`0QOol00`00Oomo
o`03Ool2001[Ool00`00Oomoo`0QOol00`00Oomoo`02Ool2001VOol20003Ool00`00Oomoo`0ROol0
0`00Oomoo`02Ool00`00Oomoo`0nOol4000;Ool00`00Oomoo`0@Ool70003Ool00`00Oomoo`0OOol0
01moo`03001oogoo075oo`03001oogoo021oo`03001oogoo00=oo`<006]oo`03001oogoo021oo`03
001oogoo009oo`<006]oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo06Ioo`03001oogoo
009oo`03001oogoo021oo`03001oogoo009oo`8003]oo`D002Moo`8000Aoo`03001oogoo01ioo`00
7goo00<007ooOol0LGoo00<007ooOol087oo00<007ooOol00Woo0`00K7oo00<007ooOol07goo00<0
07ooOol00goo0P00KGoo00<007ooOol07goo00<007ooOol00Woo0P00J7oo0P000goo00<007ooOol0
87oo00<007ooOol00Woo00<007ooOol0=Woo1000;Goo0P000goo00<007ooOol07Woo000NOol00`00
Oomoo`1cOol00`00Oomoo`0NOol00`00Oomoo`03Ool2001^Ool00`00Oomoo`0NOol00`00Oomoo`02
Ool3001]Ool00`00Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`1XOol00`00Oomoo`02Ool00`00
Oomoo`0NOol00`00Oomoo`02Ool2000dOol5000aOol20003Ool00`00Oomoo`0MOol001ioo`03001o
ogoo07=oo`03001oogoo01ioo`03001oogoo009oo`8006moo`03001oogoo01eoo`03001oogoo009o
o`<006moo`03001oogoo01eoo`03001oogoo009oo`8006Yoo`8000=oo`03001oogoo01ioo`03001o
ogoo009oo`03001oogoo02eoo`03001oo`0000<003Ioo`8000=oo`03001oogoo01eoo`007Goo00<0
07ooOol0MGoo00<007ooOol077oo00<007ooOol00Woo0`00L7oo00<007ooOol077oo00<007ooOol0
0Woo0P00L7oo00<007ooOol077oo00<007ooOol00Woo0P00Jgoo0`000goo00<007ooOol077oo00<0
07ooOol00Woo0P00;goo0P00>Woo0P0017oo00<007ooOol077oo000MOol00`00Oomoo`1eOol00`00
Oomoo`0LOol00`00Oomoo`02Ool2001aOol00`00Oomoo`0KOol00`00Oomoo`02Ool2001bOol00`00
Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`1[Ool20003Ool00`00Oomoo`0LOol00`00Oomoo`02
Ool00`00Oomoo`0]Ool00`00Oomoo`0kOol20003Ool00`00Oomoo`0LOol001eoo`03001oogoo07Eo
o`03001oogoo01aoo`04001oogooOol3001bOol00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomo
o`1aOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`1[Ool20004Ool00`00Oomoo`0KOol0
1000Oomoogoo0P00;Woo00<007ooOol0?Goo00D007ooOomoo`0001ioo`0077oo00<007ooOol0Mgoo
00<007ooOol06Woo00<007ooOol00Woo0P00Lgoo00<007ooOol06Goo00<007ooOol00goo0P00Lgoo
00<007ooOol06Goo00<007ooOol00goo00<007ooOol0Jgoo0P0017oo00<007ooOol06Woo00<007oo
Ool00Woo00<007ooOol0;7oo00<007ooOol0?Woo00<007ooOol00Woo00<007ooOol06goo000LOol0
0`00Oomoo`1gOol00`00Oomoo`0JOol00`00Oomoo`02Ool2001cOol00`00Oomoo`0IOol00`00Oomo
o`03Ool00`00Oomoo`1bOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`1]Ool00`00Oomo
o`02Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`0nOol00`00Oomo
o`02Ool00`00Oomoo`0KOol001aoo`03001oogoo07Qoo`03001oogoo01Uoo`03001oogoo009oo`80
07Aoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo079oo`03001oogoo01Uoo`03001oogoo
009oo`03001oogoo06eoo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo
02]oo`03001oogoo03moo`03001oogoo00=oo`03001oogoo01Yoo`006goo00<007ooOol0NGoo00<0
07ooOol067oo00<007ooOol00Woo0P00MGoo00<007ooOol067oo00<007ooOol00Woo0P00M7oo00<0
07ooOol067oo00<007ooOol00goo00<007ooOol0KGoo0P0017oo00<007ooOol067oo00<007ooOol0
0Woo00<007ooOol0:goo00<007ooOol0@7oo00<007ooOol00goo00<007ooOol06Woo000KOol00`00
Oomoo`1iOol00`00Oomoo`0GOol00`00Oomoo`03Ool2001eOol00`00Oomoo`0GOol00`00Oomoo`03
Ool2001eOol00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`1^Ool00`00Oomoo`02Ool00`00
Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0ZOol20012Ool00`00Oomoo`03Ool00`00Oomoo`0J
Ool001]oo`03001oogoo07Yoo`03001oogoo01Ioo`03001oogoo00=oo`8007Ioo`03001oogoo01Io
o`03001oogoo00=oo`03001oogoo07Aoo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo06io
o`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo02Ioo`03001oogoo0080
04Aoo`03001oogoo00=oo`03001oogoo01Uoo`006Woo00<007ooOol0Ngoo00<007ooOol05Woo00<0
07ooOol00goo0P00MWoo00<007ooOol05Woo00<007ooOol00goo00<007ooOol0M7oo00<007ooOol0
5Woo00<007ooOol017oo00<007ooOol0KWoo00<007ooOol00goo00<007ooOol05Woo00<007ooOol0
0goo00<007ooOol08goo100000=oo`000000AGoo00<007ooOol00goo00<007ooOol06Goo000JOol0
0`00Oomoo`1kOol00`00Oomoo`0FOol00`00Oomoo`03Ool2001fOol00`00Oomoo`0FOol00`00Oomo
o`03Ool00`00Oomoo`1eOol00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1^Ool00`00Oomo
o`03Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`0POol40003Ool20016Ool00`00Oomo
o`03Ool00`00Oomoo`0IOol001Yoo`03001oogoo07]oo`03001oogoo01Ioo`03001oogoo00=oo`03
001oogoo07Eoo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo07Eoo`03001oogoo01Eoo`03
001oogoo00=oo`80071oo`8000Aoo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo01aoo`D0
04ioo`03001oogoo00=oo`03001oogoo01Uoo`006Woo00<007ooOol0O7oo00<007ooOol057oo00<0
07ooOol017oo00<007ooOol0MGoo00<007ooOol05Goo00<007ooOol017oo00<007ooOol0MGoo00<0
07ooOol05Goo00<007ooOol00goo00<007ooOol0L7oo00<007ooOol00goo00<007ooOol057oo00<0
07ooOol017oo00<007ooOol06goo00<007ooOol0DGoo00<007ooOol00goo00<007ooOol06Goo000J
Ool00`00Oomoo`04Ool2001fOol00`00Oomoo`0DOol00`00Oomoo`04Ool2001gOol00`00Oomoo`0D
Ool00`00Oomoo`04Ool00`00Oomoo`1eOol00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1`
Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0JOol2001COol00`00
Oomoo`04Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Eoo`8007Ioo`03001oogoo01Aoo`03001o
ogoo00Aoo`8007Moo`03001oogoo01Aoo`03001oogoo00Aoo`8007Ioo`03001oogoo01Aoo`03001o
ogoo00Aoo`80075oo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo00Aoo`8001]oo`03001o
ogoo059oo`03001oogoo00Aoo`03001oogoo01Qoo`006Goo00<007ooOol01Goo0P00MWoo00<007oo
Ool057oo00<007ooOol017oo0`00MWoo00<007ooOol04goo00<007ooOol01Goo0P00Mgoo00<007oo
Ool04goo00<007ooOol017oo0`00L7oo00<007ooOol00goo00<007ooOol057oo00<007ooOol017oo
0P006Woo0P00E7oo00<007ooOol017oo00<007ooOol067oo000IOol00`00Oomoo`06Ool00`00Oomo
o`1eOol00`00Oomoo`0COol00`00Oomoo`05Ool4001dOol00`00Oomoo`0COol00`00Oomoo`06Ool0
0`00Oomoo`1eOol00`00Oomoo`0COol00`00Oomoo`06Ool2001_Ool00`00Oomoo`04Ool00`00Oomo
o`0COol00`00Oomoo`05Ool4000GOol00`00Oomoo`1COol20005Ool00`00Oomoo`0HOol001Uoo`03
001oogoo00Ioo`03001oo`00008007=oo`03001oogoo019oo`03001oogoo00Moo`04001oo`00001c
Ool00`00Oomoo`0COol00`00Oomoo`06Ool00`00Oomoo`1eOol00`00Oomoo`0COol00`00Oomoo`06
Ool00`00Oomoo`1^Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`06Ool5000FOol00`00
Oomoo`1DOol00`00Oomoo`03Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`H0079oo`03001o
ogoo019oo`03001oogoo00Ioo`800003Ool0000007Aoo`03001oogoo019oo`03001oogoo00Ioo`03
001oogoo07Eoo`03001oogoo01=oo`03001oogoo00Ioo`03001oogoo06ioo`03001oogoo00Aoo`03
001oogoo019oo`03001oogoo00Ioo`80009oo`8001Aoo`03001oogoo05Eoo`03001oogoo00=oo`03
001oogoo01Qoo`0067oo00<007ooOol01goo0`0000=oo`00Ool0LWoo00<007ooOol04Woo00<007oo
Ool01Woo1000MGoo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol0MGoo00<007ooOol04Woo
00<007ooOol01goo00<007ooOol0KWoo00<007ooOol017oo00<007ooOol04Woo00<007ooOol01Woo
0P000goo0P004goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol067oo000HOol00`00Oomo
o`06Ool2000017oo00000000Lgoo00<007ooOol04Woo00<007ooOol01Woo0P00Mgoo00<007ooOol0
4Woo00<007ooOol01Woo00<007ooOol0MGoo00<007ooOol04Woo00<007ooOol01Woo0P000Woo1000
JWoo00<007ooOol017oo00<007ooOol04Woo00<007ooOol01Woo0`000goo0P004Goo00<007ooOol0
EWoo00<007ooOol017oo00<007ooOol05goo000HOol00`00Oomoo`04Ool4001gOol00`00Oomoo`0B
Ool00`00Oomoo`05Ool2001hOol00`00Oomoo`0BOol00`00Oomoo`05Ool2001gOol00`00Oomoo`0B
Ool00`00Oomoo`06Ool7001ZOol20006Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00Ool00004
Ool5000=Ool00`00Oomoo`1FOol00`00Oomoo`04Ool00`00Oomoo`0GOol001Qoo`03001oogoo00Ao
o`<007Qoo`03001oogoo019oo`03001oogoo00Aoo`H007Eoo`03001oogoo015oo`03001oogoo00Eo
o`8007Qoo`03001oogoo019oo`03001oogoo00Eoo`<000=oo`@006Qoo`03001oogoo00Eoo`03001o
ogoo019oo`03001oogoo00Eoo`03001oogoo008000Moo`03001oogoo00Yoo`8005Qoo`03001oogoo
00Aoo`03001oogoo01Moo`0067oo00<007ooOol017oo0P00NGoo00<007ooOol04Woo00<007ooOol0
0goo10000Woo0P00M7oo00<007ooOol04Goo00<007ooOol017oo0`00NGoo00<007ooOol04Goo00<0
07ooOol017oo0P001goo1000IWoo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Goo00<0
07ooOol00Woo0`0017oo00<007ooOol02Woo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0
5goo000HOol00`00Oomoo`03Ool3001iOol00`00Oomoo`0BOol00`00Oomoo`03Ool40003Ool2001c
Ool00`00Oomoo`0AOol00`00Oomoo`04Ool2001jOol00`00Oomoo`0AOol00`00Oomoo`03Ool20009
Ool4001UOol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`05Ool30002
Ool00`00Oomoo`09Ool00`00Oomoo`1HOol00`00Oomoo`04Ool00`00Oomoo`0GOol001Qoo`03001o
ogoo00=oo`8007Yoo`03001oogoo019oo`03001oogoo00Ioo`L0079oo`03001oogoo015oo`03001o
ogoo00Aoo`03001oogoo07Uoo`03001oogoo015oo`03001oogoo00=oo`80079oo`8000Ioo`03001o
ogoo019oo`03001oogoo00=oo`8000Uoo`D000Moo`<005]oo`03001oogoo00Aoo`03001oogoo01Mo
o`0067oo00<007ooOol00goo0`00NGoo00<007ooOol04Woo00<007ooOol02goo0P00LWoo00<007oo
Ool04Goo00<007ooOol00goo0`00NWoo00<007ooOol04Goo00<007ooOol00goo0P00Lgoo00<007oo
Ool017oo00<007ooOol04Woo00<007ooOol00goo00<007ooOol02goo3000G7oo00<007ooOol00goo
00<007ooOol05goo000HOol00`00Oomoo`03Ool00`00Oomoo`1iOol00`00Oomoo`0BOol00`00Oomo
o`0;Ool2001bOol00`00Oomoo`0AOol00`00Oomoo`03Ool2001kOol00`00Oomoo`0AOol00`00Oomo
o`03Ool2001cOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0<Ool2
0005Ool4001LOol00`00Oomoo`03Ool00`00Oomoo`0GOol001Qoo`03001oogoo07moo`03001oogoo
019oo`03001oogoo00]oo`80079oo`03001oogoo015oo`03001oogoo00=oo`8007]oo`03001oogoo
015oo`03001oogoo00=oo`03001oogoo079oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo
00=oo`03001oogoo00eoo`L000=oo`03001oogoo05Uoo`03001oogoo00=oo`03001oogoo01Moo`00
67oo00<007ooOol0Ogoo00<007ooOol04Woo00<007ooOol02goo1000L7oo00<007ooOol04Goo00<0
07ooOol00goo0P00Ngoo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0Lgoo00<007ooOol0
0goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol0FGoo00<007ooOol0
0goo00<007ooOol05goo000HOol00`00Oomoo`1oOol00`00Oomoo`0BOol00`00Oomoo`0=Ool2001`
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1jOol00`00Oomoo`0AOol00`00Oomoo`03
Ool00`00Oomoo`1cOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0G
Ool00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`0GOol001Qoo`03001oogoo07moo`03001o
ogoo019oo`03001oogoo00eoo`<006moo`03001oogoo015oo`03001oogoo00=oo`03001oogoo07Uo
o`8001=oo`03001oogoo00=oo`03001oogoo07=oo`03001oogoo00=oo`03001oogoo019oo`03001o
ogoo00=oo`03001oogoo01Moo`03001oogoo05Uoo`03001oogoo00=oo`03001oogoo01Moo`0067oo
00<007ooOol0Ogoo00<007ooOol04Woo00<007ooOol03Goo00<007oo0000Kgoo00<007ooOol04Woo
00<007ooOol00Woo0P00NWoo00<007ooOol04Woo00<007ooOol00goo00<007ooOol0Lgoo00<007oo
Ool00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol0FGoo00<007oo
Ool00goo00<007ooOol05goo000HOol00`00Oomoo`1oOol00`00Oomoo`0BOol00`00Oomoo`0=Ool3
001_Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`1hOol00`00Oomoo`0BOol00`00Oomo
o`03Ool2001dOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0GOol0
0`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`0GOol001Qoo`03001oogoo07moo`03001oogoo
019oo`03001oogoo00ioo`<006ioo`03001oogoo019oo`03001oogoo00=oo`03001oogoo07Qoo`03
001oogoo019oo`03001oogoo00=oo`8007Aoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo
00=oo`03001oogoo01Moo`03001oogoo05Uoo`03001oogoo00=oo`03001oogoo01Moo`0067oo00<0
07ooOol0Ogoo00<007ooOol04Woo00<007ooOol03goo0`00KGoo00<007ooOol04Woo00<007ooOol0
0goo00<007ooOol0N7oo00<007ooOol04Woo00<007ooOol00goo0P00M7oo00<007ooOol00goo00<0
07ooOol04Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol0F7oo0P0017oo00<007ooOol0
67oo000IOol00`00Oomoo`1nOol00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`1/Ool00`00
Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`1hOol00`00Oomoo`0COol00`00Oomoo`03Ool00`00
Oomoo`1bOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0GOol00`00
Oomoo`1HOol20004Ool00`00Oomoo`0HOol001Uoo`03001oogoo07ioo`03001oogoo01=oo`03001o
ogoo07eoo`03001oogoo01=oo`03001oogoo00=oo`8007Uoo`03001oogoo01=oo`03001oogoo00=o
o`03001oogoo075oo`8000Eoo`03001oogoo01=oo`03001oogoo009oo`8001Qoo`03001oogoo05Qo
o`03001oogoo00=oo`03001oogoo01Qoo`006Goo00<007ooOol0OGoo00<007ooOol057oo00<007oo
Ool0OGoo00<007ooOol04goo00<007ooOol00goo0P00NGoo00<007ooOol04goo00<007ooOol00goo
00<007ooOol0LGoo00<007ooOol00goo00<007ooOol057oo00<007ooOol00goo00<007ooOol05Woo
00<007ooOol0F7oo00<007ooOol00goo00<007ooOol067oo000IOol00`00Oomoo`1mOol00`00Oomo
o`0DOol00`00Oomoo`1mOol00`00Oomoo`0DOol00`00Oomoo`03Ool2001hOol00`00Oomoo`0COol0
0`00Oomoo`03Ool00`00Oomoo`1aOol00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`03Ool0
0`00Oomoo`0FOol2001IOol00`00Oomoo`03Ool00`00Oomoo`0HOol001Uoo`03001oogoo07eoo`03
001oogoo01Aoo`03001oogoo07eoo`03001oogoo01Aoo`03001oogoo00=oo`8007Moo`03001oogoo
01Aoo`03001oogoo00=oo`03001oogoo075oo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo
00=oo`8001Qoo`03001oogoo05Ioo`8000Eoo`03001oogoo01Qoo`006Woo00<007ooOol0O7oo00<0
07ooOol057oo00<007ooOol0O7oo00<007ooOol05Goo00<007ooOol00goo00<007ooOol0MWoo00<0
07ooOol05Goo00<007ooOol00Woo00<007ooOol0L7oo0P001Goo00<007ooOol057oo00<007ooOol0
0goo0P0067oo00<007ooOol0EWoo00<007ooOol00goo00<007ooOol06Goo000JOol00`00Oomoo`1l
Ool00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1f
Ool00`00Oomoo`0EOol00`00Oomoo`02Ool2001aOol00`00Oomoo`04Ool00`00Oomoo`0EOol00`00
Oomoo`02Ool2000HOol2001GOol00`00Oomoo`03Ool00`00Oomoo`0IOol001Yoo`03001oogoo07]o
o`03001oogoo01Ioo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo07Io
o`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo06moo`03001oogoo00=oo`03001oogoo01Io
o`03001oogoo009oo`8001Moo`<005Ioo`8000Eoo`03001oogoo01Uoo`006Woo00<007ooOol0Ngoo
00<007ooOol05Woo00<007ooOol0Ngoo00<007ooOol05Woo00<007ooOol00Woo0P00MWoo00<007oo
Ool05Woo00<007ooOol00goo00<007ooOol0KWoo0P001Goo00<007ooOol05Woo00<007ooOol00Woo
0P005goo00<007ooOol0EWoo0P001Goo00<007ooOol06Goo000KOol00`00Oomoo`1jOol00`00Oomo
o`0FOol00`00Oomoo`1kOol00`00Oomoo`0FOol00`00Oomoo`02Ool00`00Oomoo`1eOol00`00Oomo
o`0GOol00`00Oomoo`02Ool00`00Oomoo`1^Ool00`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomo
o`03Ool00`00Oomoo`0EOol00`00Oomoo`1FOol00`00Oomoo`04Ool00`00Oomoo`0IOol001]oo`03
001oogoo07Uoo`03001oogoo01Moo`03001oogoo07Yoo`03001oogoo01Moo`03001oogoo009oo`80
07Ioo`03001oogoo01Moo`03001oogoo009oo`03001oogoo06eoo`03001oogoo00Aoo`03001oogoo
01Moo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo05Eoo`8000Eoo`03001oogoo01Yoo`00
6goo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol0
0Woo00<007ooOol0Lgoo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0KGoo00<007ooOol0
17oo00<007ooOol067oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0EGoo0P001Goo00<0
07ooOol06Woo000LOol00`00Oomoo`1hOol00`00Oomoo`0IOol00`00Oomoo`1hOol00`00Oomoo`0H
Ool00`00Oomoo`02Ool00`00Oomoo`1cOol00`00Oomoo`0IOol01000Oomoogoo0P00KWoo00<007oo
Ool017oo00<007ooOol06Goo00D007ooOomoo`0001Moo`03001oogoo05Eoo`8000Eoo`03001oogoo
01Yoo`0077oo00<007ooOol0Mgoo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol06Goo00<0
07ooOol00Woo0P00M7oo00<007ooOol06Goo00@007ooOomoo`8006ioo`03001oogoo00=oo`03001o
ogoo01Yoo`05001oogooOol0000GOol00`00Oomoo`1DOol20005Ool00`00Oomoo`0KOol001aoo`03
001oogoo07Moo`03001oogoo01Yoo`03001oogoo07Moo`03001oogoo01Uoo`03001oogoo009oo`80
07Aoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo06Uoo`@000Eoo`03001oogoo01Yoo`05
001oogooOol0000GOol00`00Oomoo`1DOol20005Ool00`00Oomoo`0KOol001eoo`03001oogoo07Eo
o`03001oogoo01aoo`03001oogoo07Ioo`03001oogoo01Yoo`04001oogooOol2001cOol00`00Oomo
o`0KOol01@00Oomoogoo0000Jgoo10001Goo00<007ooOol06goo00<007ooOol00P005goo00<007oo
Ool0Dgoo0P0017oo00<007ooOol077oo000MOol00`00Oomoo`1eOol00`00Oomoo`0LOol00`00Oomo
o`1eOol00`00Oomoo`0KOol01000Oomoogoo0P00Lgoo00<007ooOol06goo00D007ooOomoo`0006]o
o`04001oo`000004Ool00`00Oomoo`0LOol01@00Oomoogoo00005goo00<007ooOol0DWoo0P001Goo
00<007ooOol077oo000MOol00`00Oomoo`1eOol00`00Oomoo`0LOol00`00Oomoo`1eOol00`00Oomo
o`0LOol00`00Oomoo`02001bOol00`00Oomoo`0LOol01000Oomoogoo0P00JWoo00<007oo00001Goo
00<007ooOol077oo00D007ooOomoo`0001Moo`03001oogoo059oo`8000Eoo`03001oogoo01aoo`00
7Woo00<007ooOol0Lgoo00<007ooOol07Woo00<007ooOol0Lgoo00<007ooOol07Goo00D007ooOomo
o`00079oo`03001oogoo01eoo`03001oogoo008006Yoo`<000Aoo`03001oogoo01ioo`04001oogoo
000GOol2001BOol30004Ool00`00Oomoo`0MOol001ioo`03001oogoo07=oo`03001oogoo01ioo`03
001oogoo07=oo`03001oogoo01ioo`03001oogoo0080071oo`03001oogoo01ioo`03001oogoo00<0
06Moo`<00003Ool007oo00=oo`03001oogoo01ioo`04001oogoo000HOol00`00Oomoo`1@Ool20005
Ool00`00Oomoo`0MOol001moo`03001oogoo075oo`03001oogoo021oo`03001oogoo075oo`03001o
ogoo01moo`03001oogoo0080071oo`03001oogoo01moo`03001oogoo008006Eoo`<00004Ool00000
0003Ool00`00Oomoo`0POol01000Ool000005goo0P00DWoo00<007ooOol00Woo00<007ooOol07Woo
000OOol00`00Oomoo`1aOol00`00Oomoo`0POol00`00Oomoo`1aOol00`00Oomoo`0POol01000Ool0
0000Kgoo00<007ooOol087oo00H007ooOol007oo001TOol01000Oomoogoo0P0017oo00<007ooOol0
87oo00@007ooOol001Qoo`03001oogoo051oo`03001oogoo009oo`03001oogoo01ioo`0087oo00<0
07ooOol0Kgoo00<007ooOol08Woo00<007ooOol0Kgoo00<007ooOol08Goo00@007ooOol006moo`03
001oogoo025oo`03001oo`00009oo`03001oogoo061oo`8000=oo`8000=oo`03001oogoo029oo`04
001oo`000003Ool00`00Oomoo`0AOol2001@Ool20003Ool00`00Oomoo`0OOol0025oo`03001oogoo
06ioo`03001oogoo029oo`03001oogoo06ioo`03001oogoo02=oo`03001oo`0006ioo`03001oogoo
029oo`06001oo`00001oo`00HWoo00<007ooOol00Woo0P000goo00<007ooOol08Woo00D007oo0000
07oo00<001Aoo`8004moo`05001oogooOol0000ROol0025oo`03001oogoo06eoo`03001oogoo02Ao
o`03001oogoo06eoo`03001oogoo02=oo`04001oo`00001]Ool00`00Oomoo`0SOol00`00Ool00002
Ool00`00Oomoo`1OOol00`00Oomoo`02Ool01@00Oomoogoo00009Woo1@0000=oo`00Ool057oo00<0
07ooOol0CGoo00D007ooOomoo`00029oo`008Woo00<007ooOol0K7oo00<007ooOol097oo00<007oo
Ool0K7oo00<007ooOol09Goo00@007oo000006]oo`03001oogoo02Aoo`06001oo`00001oo`00HGoo
00@007ooOomoo`8000=oo`03001oogoo02Aoo`04001oo`000003Ool00`00Oomoo`0BOol2001>Ool0
1000Oomoo`008goo000SOol00`00Oomoo`1ZOol00`00Oomoo`0VOol00`00Oomoo`1[Ool00`00Oomo
o`0VOol01000Ool00000JGoo00<007ooOol09Woo00@007oo001oo`8005moo`8000=oo`80009oo`03
001oogoo02Ioo`04001oo`000002Ool00`00Oomoo`0COol00`00Oomoo`1;Ool01@00Oomoogoo0000
8goo000SOol00`00Oomoo`1YOol00`00Oomoo`0XOol00`00Oomoo`1YOol00`00Oomoo`0XOol4001W
Ool00`00Oomoo`0XOol01@00Ool007oo0000Ggoo00@007ooOomoo`<00003Ool007oo02Uoo`06001o
o`00001oo`005Woo00<007ooOol0BWoo00@007ooOol002Aoo`0097oo00<007ooOol0Igoo00<007oo
Ool0:Woo00<007ooOol0Igoo00<007ooOol0:Goo00<007oo00000P00IGoo00<007ooOol0:Woo00<0
07oo00000P00GGoo0P000goo0P0000=oo`00Ool0:goo00H007oo000007oo000EOol2001:Ool20000
0goo001oo`0TOol002Aoo`03001oogoo06Moo`03001oogoo02Yoo`03001oogoo06Moo`03001oogoo
02Yoo`03001oo`00008006Aoo`03001oogoo02Yoo`03001oogoo008005eoo`8000=oo`800003Ool0
07oo02]oo`06001oogoo001oo`005Woo00<007ooOol0B7oo00@007ooOol002Eoo`009Goo00<007oo
Ool0IGoo00<007ooOol0;7oo00<007ooOol0IGoo00<007ooOol0:goo00<007ooOol01000HGoo00<0
07ooOol0;7oo00<007ooOol00P00Fgoo0P000goo0P0000=oo`00Ool0;Goo00<007ooOol00P005Woo
00<007ooOol0Agoo0P0000=oo`00Ool09Goo000VOol00`00Oomoo`1SOol00`00Oomoo`0^Ool00`00
Oomoo`1SOol00`00Oomoo`0]Ool00`00Oomoo`03001POol00`00Oomoo`0^Ool00`00Oomoo`02001J
Ool01000Oomoogoo1000<7oo00<007ooOol00P0057oo0P0097oo0`008Goo0P0000=oo`00Ool09Woo
000VOol00`00Oomoo`1SOol00`00Oomoo`0^Ool00`00Oomoo`1SOol00`00Oomoo`0^Ool00`00Oomo
o`03001OOol00`00Oomoo`0^Ool01000Oomoogoo0P00FGoo00<007ooOol00`0000=oo`00Ool0;goo
00<007ooOol00P0057oo00<007ooOol07goo1@0000Aoo`00000001ioo`80009oo`03001oogoo02Eo
o`009goo00<007ooOol0HGoo00<007ooOol0<7oo00<007ooOol0HGoo00<007ooOol0<7oo00<007oo
Ool00P00GWoo00<007ooOol0<7oo00@007ooOomoo`8005Moo`800006Ool00000001oo`00<Woo00<0
07ooOol00P004goo00<007ooOol07Woo0P001goo0`006goo0P000Woo00<007ooOol09Woo000XOol0
0`00Oomoo`1OOol00`00Oomoo`0bOol00`00Oomoo`1OOol00`00Oomoo`0bOol00`00Oomoo`02001L
Ool00`00Oomoo`0bOol01000Oomoogoo0P00EWoo1@0000=oo`00Ool0<goo00<007ooOol00P004Woo
00<007ooOol07Goo0P002Woo0`0067oo0P000Woo00<007ooOol09goo000YOol00`00Oomoo`1MOol0
0`00Oomoo`0dOol00`00Oomoo`1MOol00`00Oomoo`0dOol00`00Oomoo`03001IOol00`00Oomoo`0d
Ool01000Oomoogoo0P00EGoo0`000Woo00<007ooOol0=7oo00<007ooOol00P004Goo00<007ooOol0
77oo0P003Goo0P005Goo0`000Woo00<007ooOol0:7oo000ZOol2001LOol00`00Oomoo`0fOol00`00
Oomoo`1JOol2000hOol00`00Oomoo`02001HOol00`00Oomoo`0fOol20002Ool3001BOol30002Ool0
0`00Oomoo`0fOol00`00Oomoo`02000@Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool4000BOol20000
0goo0000000[Ool002aoo`03001oogoo05Qoo`03001oogoo03Qoo`03001oogoo05Qoo`03001oogoo
03Uoo`03001oogoo008005Ioo`03001oogoo03Uoo`05001oogoo001oo`02001>Ool40002Ool00`00
Oomoo`0hOol00`00Oomoo`02000?Ool2000KOol2000COol50007Ool00`00Oomoo`02Ool20002Ool0
0`00Oomoo`0[Ool002eoo`03001oogoo05Ioo`03001oogoo03Yoo`03001oogoo05Ioo`03001oogoo
03]oo`03001oogoo008005Aoo`03001oogoo03]oo`05001oogoo001oo`02001<Ool40002Ool00`00
Oomoo`0jOol00`00Oomoo`02000?Ool00`00Oomoo`0HOol00`00Oomoo`0=Ool30007Ool30003Ool4
0002Ool20002Ool00`00Oomoo`0/Ool002eoo`03001oogoo05Eoo`03001oogoo03aoo`03001oogoo
05Eoo`03001oogoo03]oo`04001oogooOol2001COol00`00Oomoo`0kOol01`00Oomoogoo001oo`00
04]oo`<000=oo`03001oogoo03aoo`03001oogoo008000ioo`8001Qoo`03001oogoo00eoo`@000Uo
o`@000=oo`04001oo`000003Ool00`00Oomoo`0/Ool002ioo`03001oogoo05=oo`03001oogoo03io
o`03001oogoo05=oo`03001oogoo03eoo`04001oogooOol2001AOol00`00Oomoo`0mOol01000Oomo
ogoo0`00BGoo0`000goo00<007ooOol0?Woo00<007ooOol00P003Woo00<007ooOol05Goo00<007oo
Ool03Goo0P000Woo00<007ooOol02Goo00<007ooOol00Woo0`000goo00<007ooOol0;Goo000_Ool0
0`00Oomoo`1AOol00`00Oomoo`10Ool00`00Oomoo`1@Ool20011Ool20002Ool3001=Ool20011Ool0
1000Oomoogoo0P00B7oo0`000goo00<007ooOol0@7oo00<007ooOol00P003Goo00<007ooOol057oo
0P003Woo0P000goo00<007ooOol03Goo0P000goo0P00<7oo000`Ool00`00Oomoo`1?Ool00`00Oomo
o`12Ool00`00Oomoo`1>Ool00`00Oomoo`13Ool00`00Oomoo`03001;Ool00`00Oomoo`12Ool01000
Oomoogoo0P00AWoo0`000goo00<007ooOol0@Woo00@007ooOomoo`8000aoo`03001oogoo019oo`80
00moo`03001oogoo009oo`8000eoo`8000=oo`03001oogoo031oo`00<Goo0P00CGoo0P00AWoo0P00
CGoo00<007ooOol0AGoo00<007ooOol00`00BGoo00<007ooOol0A7oo0P000Woo0P00A7oo0P000goo
0P00AWoo0P000Woo0P002goo0P004Woo0P0047oo00<007ooOol00goo0P002goo0P000goo00<007oo
Ool0<Goo000cOol20019Ool2001:Ool20019Ool20019Ool20002Ool3000mOol20006Ool20019Ool2
000017oo00000000@7oo0`000Woo0P00BWoo0P0000=oo`0000002goo00<007ooOol047oo00<007oo
Ool03goo00<007ooOol017oo00<007ooOol01goo0P000goo0P00=7oo000eOol20016Ool00`00Oomo
o`1<Ool00`00Oomoo`14Ool2001=Ool2000017oo00000000?7oo0P0017oo0P00CGoo0P0000Aoo`00
000003eoo`<0009oo`03001oogoo04aoo`03001oo`00008000Yoo`03001oogoo00]oo`@0019oo`03
001oogoo00Aoo`03001oogoo00Ioo`80009oo`8003Ioo`00=goo0P00@Woo0P00D7oo0P00@Woo0P00
DGoo1P0000=oo`00Ool0=Woo0P000goo0P00DGoo1P00>Woo0P000Woo0P00D7oo0P0000=oo`000000
2Goo0P002goo0P005Goo00<007ooOol017oo0P001Woo0P0000=oo`000000>7oo000iOol00`00Oomo
o`0nOol00`00Oomoo`1BOol00`00Oomoo`0nOol00`00Oomoo`1COol00`00Oomoo`04000dOol30003
Ool00`00Oomoo`1COol00`00Oomoo`03000fOol30002Ool00`00Oomoo`1BOol00`00Ool000030007
Ool00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`06Ool01000Oomoogoo0P000Woo00<007oo
Ool0>7oo000jOol00`00Oomoo`0kOol2001FOol2000mOol00`00Oomoo`1EOol20002Ool5000`Ool3
0002Ool2001GOol01000Oomoogoo1000<Woo0P000Woo0P00EWoo0P000Woo1@0017oo00<007ooOol0
1goo00<007ooOol05Goo10001Goo1@000Woo00<007ooOol0>Goo000kOol2000iOol2001JOol2000i
Ool2001JOol20003Ool50005Ool00`00Oomoo`0SOol400000goo0000001JOol20004Ool4000ZOol0
0`00Oomoo`0300000goo0000001JOol20003Ool40003Ool00`00Oomoo`05Ool2000GOol300000goo
000000060002Ool2000lOol003eoo`<003=oo`<005ioo`<003=oo`<005ioo`<000=oo`D00003Ool0
0000029oo`P005ioo`<000Aoo`@002Aoo`X005ioo`<000=oo`H000Ioo`03001oogoo01Moo`03001o
o`00009oo`P003ioo`00@7oo0`00;Goo0`00I7oo0P00;Woo0`00I7oo0P0017oo1P007Woo2000I7oo
0`000goo100000=oo`00Ool077oo1P0000Aoo`00000006Aoo`8000Aoo`D000=oo`03001oogoo01Io
o`P00004Ool000000011Ool004=oo`<002Moo`<006Uoo`@002Moo`<006Uoo`<000Aoo`D001=oo`X0
009oo`<006Uoo`<000=oo`L001Aoo`P00004Ool00000001YOol40003Ool6000DOol80002Ool30014
Ool004Ioo`<0025oo`<0071oo`<0025oo`<006moo`<000Aoo`L00003Ool00000010000Aoo`<006mo
o`<000Aooa/0009oo`<0071oo`<000=oo`@000Aoo`03001oogoo00Moo`P000Aoo`<004Moo`00BGoo
0`006goo0`00MWoo0`006goo0`00MGoo10000Woo4@001goo1000MGoo0`000goo1@000goo2P001Woo
0`00MWoo0`000goo4@001goo0`00BWoo001<Ool7000>Ool6001lOol6000>Ool7001lOol;0009Ool6
001lOol;000:Ool6001lOol600000goo000000030008Ool7001=Ool005=oo`h008Qoo`h008Uoo`h0
08Uoo`h008Qoo`h005Aoo`00ogooogooogoo4Woo003oOoooOoooOolBOol00?mooomooomooa9oo`00
ogooogooogoo4Woo003oOoooOoooOolBOol00?mooomooomooa9oo`00\
\>"],
  ImageRangeCache->{{{0, 782}, {143.813, 0}} -> {-0.14339, -0.023153, \
0.0067606, 0.0067606}, {{21.1875, 158.125}, {140.375, 3.375}} -> {-233.739, \
-187.545, 2.60706, 2.60706}, {{171.813, 308.813}, {140.375, 3.375}} -> \
{-626.222, -187.459, 2.60587, 2.60587}, {{322.5, 459.438}, {140.375, 3.375}} -> \
{-1019.28, -187.545, 2.60706, 2.60706}, {{473.125, 610.125}, {140.375, \
3.375}} -> {-1411.4, -187.459, 2.60587, 2.60587}, {{623.813, 760.75}, \
{140.375, 3.375}} -> {-1804.82, -187.545, 2.60706, 2.60706}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          
          TagBox[\(\[SkeletonIndicator]  
              GraphicsArray  \[SkeletonIndicator]\),
            False,
            Editable->False], "}"}], ",", 
        RowBox[{"{", 
          
          TagBox[\(\[SkeletonIndicator]  
              GraphicsArray  \[SkeletonIndicator]\),
            False,
            Editable->False], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Here we already get some qualitative insight: the outburst of activity \
corresponds to a period in which the center was intensely explored for the \
first time in the session.  But nice as these dynamic graph may be, they do \
not yet exploit anything of what we know of the structure of exploration. We \
know (refs) that one of the keys to the patterning of exploratory activity is \
the performance of stopping activity (which we called lingering in (drai & \
al.)). 
It is therefore natural to look at the locations at which a stop was \
performed. For a start we can represent stops by the point at which they \
began :\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[
        Partition[
          Flatten[Script[{"\<See[PointPlot[stopindex],PlotLabel->sessionname2,\
TextStyle->{FontSize->14},DisplayFunction->Identity]\>"}, twofiles], 1], 
          2]]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.008 w
.09259 .43598 Mdot
.16763 .59735 Mdot
.11271 .74058 Mdot
.55929 .94148 Mdot
.59979 .93558 Mdot
.73649 .88291 Mdot
.89054 .73049 Mdot
.93286 .59052 Mdot
.93248 .399 Mdot
.93397 .43941 Mdot
.72 .89132 Mdot
.10141 .64087 Mdot
.08279 .63676 Mdot
.0865 .70383 Mdot
.06439 .53817 Mdot
.07265 .46017 Mdot
.09276 .42384 Mdot
.10352 .33575 Mdot
.22263 .14106 Mdot
.46055 .04902 Mdot
.58803 .05232 Mdot
.84847 .21047 Mdot
.80167 .1448 Mdot
.78954 .13664 Mdot
.35403 .9199 Mdot
.06241 .51624 Mdot
.067 .46688 Mdot
.09596 .31658 Mdot
.19108 .17548 Mdot
.20946 .14838 Mdot
.28809 .1057 Mdot
.38893 .05069 Mdot
.46295 .04679 Mdot
.49796 .05924 Mdot
.37458 .05516 Mdot
.15113 .24549 Mdot
.08265 .40069 Mdot
.0897 .43611 Mdot
.06636 .48478 Mdot
.07003 .45925 Mdot
.05995 .5166 Mdot
.09172 .71681 Mdot
.12355 .7529 Mdot
.09387 .72866 Mdot
.10972 .74569 Mdot
.46015 .94941 Mdot
.08618 .69578 Mdot
.58564 .057 Mdot
.88908 .26946 Mdot
.91149 .30632 Mdot
.76494 .12322 Mdot
.50948 .05058 Mdot
.31342 .0871 Mdot
.21609 .14649 Mdot
.19041 .18014 Mdot
.19905 .17667 Mdot
.07994 .40085 Mdot
.07299 .45316 Mdot
.06881 .41224 Mdot
.06216 .44408 Mdot
.06958 .47348 Mdot
.08933 .45288 Mdot
.08642 .47198 Mdot
.08202 .67227 Mdot
.08413 .68694 Mdot
.14681 .68894 Mdot
.89472 .71425 Mdot
.88012 .76181 Mdot
.85878 .79823 Mdot
.85719 .79281 Mdot
.85693 .77453 Mdot
.83901 .74702 Mdot
.91935 .62556 Mdot
.93925 .54231 Mdot
.94097 .52494 Mdot
.91564 .31565 Mdot
.89757 .28435 Mdot
.91989 .32169 Mdot
.83471 .18817 Mdot
.79727 .14451 Mdot
.71229 .09862 Mdot
.22237 .13476 Mdot
.08283 .40255 Mdot
.08989 .44329 Mdot
.06484 .44363 Mdot
.06326 .41478 Mdot
.07317 .44346 Mdot
.08655 .69943 Mdot
.08901 .70902 Mdot
.06207 .52896 Mdot
.08205 .6671 Mdot
.10238 .72916 Mdot
.11796 .40706 Mdot
.16823 .33663 Mdot
.23768 .13021 Mdot
.32053 .08756 Mdot
.38873 .05118 Mdot
.41591 .04753 Mdot
.44721 .04652 Mdot
.39604 .04688 Mdot
.61001 .06231 Mdot
.60164 .05748 Mdot
.70458 .10303 Mdot
.79389 .13695 Mdot
.82297 .1748 Mdot
.93013 .38896 Mdot
.93354 .42846 Mdot
.73599 .8786 Mdot
.80359 .8363 Mdot
.94108 .53587 Mdot
.9359 .55783 Mdot
.91977 .32757 Mdot
.91065 .30154 Mdot
.80364 .14439 Mdot
.39736 .04703 Mdot
.07992 .401 Mdot
.09 .43161 Mdot
.06207 .44185 Mdot
.06317 .49622 Mdot
.07507 .62377 Mdot
.08424 .68416 Mdot
.09879 .73262 Mdot
.42251 .06337 Mdot
.43669 .05303 Mdot
.21643 .14191 Mdot
.20627 .15766 Mdot
.07988 .40133 Mdot
.07225 .60733 Mdot
.09429 .72501 Mdot
.06658 .47658 Mdot
.07019 .45525 Mdot
.09317 .31859 Mdot
.34603 .07209 Mdot
.6036 .05736 Mdot
.57865 .05032 Mdot
.5947 .05713 Mdot
.50577 .04847 Mdot
.66713 .08107 Mdot
.54366 .04924 Mdot
.45742 .04892 Mdot
.37949 .05563 Mdot
.3894 .05052 Mdot
.24504 .12617 Mdot
.21899 .14662 Mdot
.08018 .40021 Mdot
.06255 .43649 Mdot
.06543 .49305 Mdot
.06258 .5144 Mdot
.06621 .48964 Mdot
.06309 .41451 Mdot
.08001 .4002 Mdot
.06255 .43675 Mdot
.0751 .63043 Mdot
.09163 .71591 Mdot
.11031 .74089 Mdot
.44192 .95556 Mdot
.85813 .79782 Mdot
.80011 .14403 Mdot
.77375 .12966 Mdot
.07971 .40178 Mdot
.07008 .45672 Mdot
.06573 .41415 Mdot
.0669 .54583 Mdot
.09423 .72136 Mdot
.07557 .61778 Mdot
.0688 .57001 Mdot
.07544 .45554 Mdot
.09148 .38762 Mdot
.0865 .36616 Mdot
.10724 .29987 Mdot
.22514 .13667 Mdot
.24193 .12678 Mdot
.38935 .04624 Mdot
.49794 .09333 Mdot
.79848 .13721 Mdot
.23091 .8663 Mdot
.07013 .45541 Mdot
.10466 .30004 Mdot
.11285 .28816 Mdot
.08011 .40045 Mdot
.06302 .49689 Mdot
.08929 .70973 Mdot
.08676 .44091 Mdot
.15075 .24392 Mdot
.21433 .14578 Mdot
.38944 .05087 Mdot
.53307 .05121 Mdot
.45995 .04664 Mdot
.4958 .04857 Mdot
.6083 .05729 Mdot
.57689 .05691 Mdot
.54444 .05576 Mdot
.5117 .06174 Mdot
.46734 .04885 Mdot
.40334 .04706 Mdot
.39582 .05608 Mdot
.44181 .04841 Mdot
.39469 .07293 Mdot
.362 .07973 Mdot
.32716 .09129 Mdot
.32355 .13302 Mdot
.21449 .14148 Mdot
.19035 .17638 Mdot
.09282 .33544 Mdot
.08273 .40124 Mdot
.06287 .42465 Mdot
.06241 .44072 Mdot
.06687 .473 Mdot
.21776 .14939 Mdot
.22745 .13705 Mdot
.30359 .09337 Mdot
.34016 .0768 Mdot
.41521 .0475 Mdot
.49365 .05005 Mdot
.52167 .05084 Mdot
.55624 .05177 Mdot
.597 .05439 Mdot
.76635 .12377 Mdot
.80435 .14752 Mdot
.81951 .16701 Mdot
.83074 .18885 Mdot
.91964 .32127 Mdot
.89311 .27357 Mdot
.91985 .3254 Mdot
.92999 .38564 Mdot
.89765 .27851 Mdot
.88052 .25673 Mdot
.78693 .13665 Mdot
.583 .05245 Mdot
.07965 .40118 Mdot
.09645 .41176 Mdot
.35142 .29361 Mdot
.86354 .79286 Mdot
.9422 .56114 Mdot
.80167 .14461 Mdot
.74117 .11217 Mdot
.7805 .13012 Mdot
.83204 .18789 Mdot
.83804 .23149 Mdot
.88955 .28483 Mdot
.9248 .35338 Mdot
.92149 .37464 Mdot
.91142 .39033 Mdot
.9198 .32611 Mdot
.8871 .26757 Mdot
.79797 .13687 Mdot
.60364 .05363 Mdot
.3958 .04681 Mdot
.4728 .06913 Mdot
.49568 .05001 Mdot
.64212 .07348 Mdot
.68511 .11142 Mdot
.79857 .14146 Mdot
.84178 .19959 Mdot
.92199 .32768 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.008 w
.11062 .44328 Mdot
.12972 .43769 Mdot
.07379 .49831 Mdot
.07632 .4808 Mdot
.09439 .44937 Mdot
.08829 .46464 Mdot
.07876 .46951 Mdot
.07057 .49125 Mdot
.07895 .497 Mdot
.07144 .48911 Mdot
.07449 .47663 Mdot
.09928 .44585 Mdot
.09706 .42296 Mdot
.09294 .41386 Mdot
.09738 .40673 Mdot
.09372 .45324 Mdot
.08261 .46503 Mdot
.09631 .44653 Mdot
.11514 .44134 Mdot
.12277 .43416 Mdot
.1146 .44148 Mdot
.11295 .42512 Mdot
.10477 .42522 Mdot
.09215 .41129 Mdot
.08447 .395 Mdot
.10083 .33086 Mdot
.09779 .32142 Mdot
.11333 .29236 Mdot
.16727 .21947 Mdot
.08427 .40697 Mdot
.08724 .38357 Mdot
.08419 .41164 Mdot
.08276 .46504 Mdot
.11417 .46929 Mdot
.12431 .48033 Mdot
.1463 .52197 Mdot
.14739 .55002 Mdot
.17193 .56115 Mdot
.12793 .49492 Mdot
.08021 .46474 Mdot
.09701 .42519 Mdot
.08407 .41146 Mdot
.08454 .39045 Mdot
.08419 .40693 Mdot
.09541 .33017 Mdot
.10578 .30311 Mdot
.18969 .17457 Mdot
.22595 .14135 Mdot
.3724 .05237 Mdot
.41535 .04018 Mdot
.41338 .04979 Mdot
.34868 .05632 Mdot
.28211 .10325 Mdot
.2739 .10277 Mdot
.25996 .10951 Mdot
.22593 .1329 Mdot
.22643 .14055 Mdot
.17776 .18843 Mdot
.20713 .16263 Mdot
.24062 .12497 Mdot
.35768 .045 Mdot
.44214 .04065 Mdot
.47574 .04847 Mdot
.51246 .03843 Mdot
.40578 .0338 Mdot
.40609 .04654 Mdot
.38497 .03476 Mdot
.34842 .04947 Mdot
.34111 .05581 Mdot
.31155 .07266 Mdot
.29022 .08358 Mdot
.23768 .11853 Mdot
.22837 .12963 Mdot
.19716 .15105 Mdot
.14841 .23058 Mdot
.09756 .31517 Mdot
.09827 .32567 Mdot
.08436 .40243 Mdot
.07173 .47922 Mdot
.07835 .58898 Mdot
.10268 .73861 Mdot
.22811 .86791 Mdot
.5034 .96476 Mdot
.29888 .91058 Mdot
.10577 .74262 Mdot
.09962 .71651 Mdot
.08637 .65434 Mdot
.08473 .62507 Mdot
.08295 .46465 Mdot
.07438 .48114 Mdot
.0714 .49318 Mdot
.06967 .54045 Mdot
.07427 .55772 Mdot
.08112 .58633 Mdot
.0831 .5975 Mdot
.08007 .60551 Mdot
.07973 .61708 Mdot
.10135 .73879 Mdot
.12859 .76948 Mdot
.13721 .77621 Mdot
.15705 .80297 Mdot
.2397 .88185 Mdot
.25859 .89245 Mdot
.47587 .96656 Mdot
.65303 .93745 Mdot
.64925 .93908 Mdot
.6574 .9378 Mdot
.65987 .93732 Mdot
.65081 .94096 Mdot
.66629 .9347 Mdot
.6847 .92617 Mdot
.68731 .92601 Mdot
.72443 .89473 Mdot
.49628 .95589 Mdot
.08098 .61694 Mdot
.07169 .5532 Mdot
.07448 .48054 Mdot
.09705 .42939 Mdot
.08923 .4066 Mdot
.08419 .41145 Mdot
.07146 .49316 Mdot
.09317 .69599 Mdot
.10295 .74191 Mdot
.25158 .89098 Mdot
.25906 .89527 Mdot
.3951 .94887 Mdot
.50307 .95851 Mdot
.67231 .93392 Mdot
.7462 .88232 Mdot
.78995 .85371 Mdot
.87173 .75623 Mdot
.89864 .66886 Mdot
.88019 .67265 Mdot
.88099 .71322 Mdot
.87676 .75474 Mdot
.866 .76997 Mdot
.86655 .7769 Mdot
.85322 .80006 Mdot
.84151 .80028 Mdot
.85238 .79364 Mdot
.87517 .76164 Mdot
.87788 .751 Mdot
.87992 .74236 Mdot
.89014 .69498 Mdot
.84311 .74552 Mdot
.81497 .81507 Mdot
.80878 .83529 Mdot
.7829 .84984 Mdot
.68468 .92812 Mdot
.6781 .93334 Mdot
.64082 .93339 Mdot
.42669 .95537 Mdot
.08294 .46909 Mdot
.09079 .46259 Mdot
.13843 .45022 Mdot
.16678 .47998 Mdot
.07287 .48144 Mdot
.08811 .46473 Mdot
.08931 .41113 Mdot
.084 .40259 Mdot
.10059 .31026 Mdot
.19964 .15145 Mdot
.24375 .11809 Mdot
.37259 .03844 Mdot
.40666 .03552 Mdot
.56832 .05573 Mdot
.71862 .09244 Mdot
.75057 .10551 Mdot
.8557 .22855 Mdot
.852 .22448 Mdot
.90031 .30241 Mdot
.91002 .34885 Mdot
.90585 .35276 Mdot
.90595 .31206 Mdot
.89847 .3018 Mdot
.92401 .45119 Mdot
.9303 .56203 Mdot
.91516 .62094 Mdot
.8954 .68734 Mdot
.85593 .79794 Mdot
.83509 .81517 Mdot
.81872 .82997 Mdot
.86519 .77598 Mdot
.89089 .70838 Mdot
.88478 .70287 Mdot
.78268 .1249 Mdot
.77341 .1312 Mdot
.65501 .06455 Mdot
.64339 .05979 Mdot
.63175 .06345 Mdot
.67697 .07601 Mdot
.56957 .03605 Mdot
.46917 .03305 Mdot
.44682 .03214 Mdot
.35324 .04958 Mdot
.27446 .09864 Mdot
.19418 .15185 Mdot
.18969 .16283 Mdot
.09557 .32091 Mdot
.08426 .40768 Mdot
.0674 .52433 Mdot
.09316 .70178 Mdot
.10264 .74509 Mdot
.24659 .88979 Mdot
.4785 .9661 Mdot
.85345 .79336 Mdot
.92769 .56854 Mdot
.93108 .55755 Mdot
.91261 .34366 Mdot
.90366 .30353 Mdot
.78461 .12481 Mdot
.77612 .21965 Mdot
.88953 .28248 Mdot
.86384 .23518 Mdot
.85576 .23052 Mdot
.42244 .0318 Mdot
.4062 .03538 Mdot
.35529 .04982 Mdot
.34653 .05628 Mdot
.3186 .07096 Mdot
.19758 .14878 Mdot
.08433 .4033 Mdot
.07789 .59962 Mdot
.09954 .72674 Mdot
.10501 .73804 Mdot
.16739 .81568 Mdot
.17501 .81707 Mdot
.19527 .83797 Mdot
.32489 .92245 Mdot
.4681 .9674 Mdot
.62466 .94569 Mdot
.68725 .92427 Mdot
.65967 .8895 Mdot
.64401 .85226 Mdot
.63102 .84835 Mdot
.61375 .87097 Mdot
.61479 .94477 Mdot
.60706 .94269 Mdot
.60665 .94212 Mdot
.61731 .91684 Mdot
.66614 .93045 Mdot
.67493 .92312 Mdot
.76124 .8426 Mdot
.73275 .85732 Mdot
.65678 .8307 Mdot
.62161 .80828 Mdot
.59691 .79387 Mdot
.56031 .80425 Mdot
.45152 .89784 Mdot
.38148 .9394 Mdot
.31981 .78482 Mdot
.26248 .65266 Mdot
.27304 .61596 Mdot
.24255 .48929 Mdot
.15128 .45764 Mdot
.24446 .50024 Mdot
.32491 .38665 Mdot
.37962 .37054 Mdot
.45918 .30205 Mdot
.66113 .25736 Mdot
.8242 .18893 Mdot
.83885 .2144 Mdot
.84278 .23028 Mdot
.83224 .20307 Mdot
.80506 .15256 Mdot
.76484 .11444 Mdot
.88038 .2655 Mdot
.89827 .29422 Mdot
.90181 .30213 Mdot
.57887 .03645 Mdot
.55737 .03585 Mdot
.53293 .03501 Mdot
.52434 .05069 Mdot
.71236 .09197 Mdot
.79322 .13616 Mdot
.82019 .17521 Mdot
.82822 .19361 Mdot
.79318 .14178 Mdot
.7628 .11422 Mdot
.75077 .11424 Mdot
.80545 .15289 Mdot
.68064 .08018 Mdot
.50604 .03414 Mdot
.47798 .03788 Mdot
.46549 .04756 Mdot
.42196 .04009 Mdot
.08404 .40223 Mdot
.07383 .48739 Mdot
.08033 .59909 Mdot
.09582 .70188 Mdot
.12633 .74507 Mdot
.88183 .74523 Mdot
.92098 .46608 Mdot
.89055 .5725 Mdot
.89522 .58068 Mdot
.87264 .61937 Mdot
.7486 .64158 Mdot
.73221 .61191 Mdot
.89917 .30807 Mdot
.87416 .26619 Mdot
.86457 .27146 Mdot
.84172 .20548 Mdot
.75188 .1086 Mdot
.47448 .03336 Mdot
.46918 .04203 Mdot
.483 .12298 Mdot
.50628 .22169 Mdot
.35891 .30775 Mdot
.29508 .26793 Mdot
.1774 .19178 Mdot
.20002 .1742 Mdot
.26448 .13321 Mdot
.06998 .51667 Mdot
.07199 .54575 Mdot
.10305 .73396 Mdot
.51843 .96185 Mdot
.73177 .89518 Mdot
.73811 .88704 Mdot
.85924 .79698 Mdot
.86276 .75883 Mdot
.93284 .5443 Mdot
.77494 .12091 Mdot
.08891 .66413 Mdot
.1005 .72145 Mdot
.12851 .75634 Mdot
.15441 .78582 Mdot
.16731 .81028 Mdot
.48892 .96513 Mdot
.53859 .92513 Mdot
.58395 .9238 Mdot
.70204 .88478 Mdot
.71852 .8857 Mdot
.873 .76417 Mdot
.86382 .78341 Mdot
.92713 .49716 Mdot
.37844 .93936 Mdot
.25836 .8952 Mdot
.11198 .67801 Mdot
.07 .52832 Mdot
.08277 .46972 Mdot
.0908 .46439 Mdot
.14363 .51964 Mdot
.32839 .70397 Mdot
.43192 .59865 Mdot
.89815 .30033 Mdot
.89273 .29378 Mdot
.90415 .31237 Mdot
.67817 .08971 Mdot
.74269 .16235 Mdot
.64841 .10591 Mdot
.66091 .11333 Mdot
.65662 .12602 Mdot
.65261 .13234 Mdot
.42708 .07944 Mdot
.4385 .07383 Mdot
.43133 .0406 Mdot
.46509 .04137 Mdot
.22564 .12981 Mdot
.07438 .55838 Mdot
.09586 .69085 Mdot
.11352 .72801 Mdot
.1036 .73252 Mdot
.11532 .75601 Mdot
.21234 .85531 Mdot
.73856 .89181 Mdot
.74235 .88206 Mdot
.81264 .83023 Mdot
.80626 .83291 Mdot
.55838 .91783 Mdot
.23882 .87478 Mdot
.4966 .79705 Mdot
.90793 .32161 Mdot
.36416 .04116 Mdot
.26343 .10379 Mdot
.08992 .34962 Mdot
.08408 .41164 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{526.813, 250.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0000nQ000`40O003h00Oogooogoo47oo003o
OoooOol@Ool00?mooomooa1oo`00ogooogoo47oo003oOoooOol@Ool00?mooomooa1oo`00ogooogoo
47oo003oOoooOol@Ool00?mooomooa1oo`00ogooogoo47oo003oOoooOol@Ool007QooaP00>iooaP0
07Qoo`00LGoo1`0067oo2000g7oo00<007oo00001`0017oo0P001Woo00<007ooOol02Goo1`00LGoo
001[Ool6000WOol5003@Ool00`00Oomoo`06000>Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo
00H007ooOol007oo0002Ool5001/Ool006Uoo`80039oo`800<aoo`04001oogooOol20005Ool01`00
Ool007oo001oo`0000Aoo`8001moo`<006Uoo`00I7oo1@000Woo10000Woo00<007ooOol017oo00@0
07oo000002=oo`<00<Qoo`D000Eoo`03001oogoo00Yoo`03001oogoo025oo`8006Moo`00HGoo0`00
1goo00<007ooOol02Goo00<007ooOol00`001Goo00@007oo0000009oo`03001oo`00009oo`03001o
o`0000Aoo`<000]oo`D00<1oo`<000=oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo01Ioo`D0069oo`00Ggoo0P001goo0P000Woo00<007ooOol01Woo00<007ooOol05Goo
00<007ooOol017oo00L007oo001oo`00Ool0000<Ool2002lOol4000_Ool00`00Oomoo`0AOol3001O
Ool005eoo`8002Aoo`04001oogoo000BOol3000=Ool3002fOol30013Ool00`00Oomoo`04Ool2001M
Ool005Yoo`<001Eoo`03001oogoo02Ioo`03001oogoo00ioo`800;9oo`8004Aoo`03001oogoo009o
o`03001oogoo00=oo`<005Yoo`00F7oo0P008goo00<007ooOol0;Woo0P00[Woo0P0000=oo`00Ool0
DGoo0P00F7oo001EOol3000:Ool00`00Oomoo`07Ool00`00Oomoo`0cOol00`00Oomoo`0;Ool3002X
Ool30002Ool00`00Oomoo`0HOol00`00Oomoo`0hOol2001FOol005Aoo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo04]oo`03001oogoo0:Aoo`03001oogoo01aoo`03001oogoo03Aoo`03001o
ogoo00Eoo`8005Aoo`00Dgoo00<007ooOol0DWoo00<007ooOol02Goo00<007ooOol0XWoo00<007oo
0000GWoo00<007ooOol0DGoo001AOol20008Ool2001HOol2002POol2001ROol2001AOol004moo`80
00Moo`03001oogoo00=oo`03001oogoo029oo`03001oogoo035oo`<009Yoo`<005Uoo`03001oogoo
00Aoo`03001oo`0000=oo`8004moo`00C7oo0`00Jgoo00<007ooOol0UGoo0P00Jgoo00<007ooOol0
C7oo001;Ool00`00Oomoo`1ROol00`00Ool00008Ool00`00Oomoo`2COol00`00Oomoo`04Ool00`00
Oomoo`1UOol2001<Ool004Yoo`03001oogoo00Qoo`03001oogoo06Aoo`80099oo`03001oogoo009o
o`05001oogooOol0001?Ool00`00Oomoo`0DOol01000Ool00000BWoo0018Ool2001ROol00`00Oomo
o`09Ool00`00Oomoo`03Ool2002>Ool20005Ool00`00Oomoo`1XOol01000Oomoogoo0P00B7oo0017
Ool00`00Oomoo`1fOol00`00Oomoo`2:Ool00`00Oomoo`1LOol00`00Oomoo`0AOol01000Ool00000
0Woo00<007ooOol0AGoo0016Ool00`00Oomoo`1hOol00`00Oomoo`27Ool20003Ool2001cOol00`00
Ool00016Ool004Eoo`03001oogoo07Eoo`03001oogoo009oo`03001oogoo08Eoo`03001oogoo00=o
o`03001oogoo039oo`03001oogoo02=oo`03001oogoo01Uoo`8004Eoo`00A7oo00<007ooOol00goo
0`00LWoo0P000Woo00<007ooOol0Pgoo00@007ooOomoo`8007Yoo`03001oogoo049oo`00@Woo0P00
0goo00<007ooOol04goo00<007ooOol0I7oo0P00PGoo0P0017oo00<007ooOol01Woo00<007ooOol0
DGoo00<007ooOol067oo00<007ooOol00Woo0P00@Woo0011Ool00`00Oomoo`03Ool2001iOol30000
0goo001oo`1nOol00`00Oomoo`20Ool01000Oomoo`00@Goo0010Ool00`00Oomoo`02Ool00`00Ool0
001lOol200000goo001oo`1lOol00`00Oomoo`05Ool00`00Oomoo`1iOol01@00Oomoogoo0000@7oo
000oOol00`00Oomoo`02Ool3001mOol300000goo001oo`1jOol01000Oomoo`00QWoo00<007ooOol0
?Goo000nOol00`00Oomoo`05Ool00`00Oomoo`20Ool00`00Oomoo`1hOol01000Ool00000Pgoo0P00
0Woo00<007ooOol0?7oo000lOol20005Ool00`00Oomoo`24Ool2001fOol2002<Ool2000lOol003]o
o`03001oogoo08ioo`03001oogoo079oo`03001oogoo00Eoo`03001oogoo079oo`03001oogoo015o
o`03001oogoo03Uoo`00>Woo00<007ooOol0S7oo00D007ooOomoo`00079oo`03001oogoo009oo`03
001oogoo08]oo`03001oogoo03Qoo`00>Goo00<007ooOol0TWoo00<007ooOol0KWoo00<007ooOol0
TWoo00<007ooOol0=goo000hOol00`00Oomoo`05Ool00`00Oomoo`27Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool00`00Oomoo`04Ool00`00Ool00027Ool00`00Oomoo`03Ool00`00Oomoo`0fOol003Mo
o`03001oogoo00Ioo`03001oo`0008eoo`03001oogoo06Yoo`03001oogoo09Eoo`03001oogoo03Io
o`00=goo00<007ooOol0Ugoo00<007ooOol0J7oo00<007ooOol0Ugoo00<007ooOol0=Goo000fOol0
0`00Oomoo`2BOol20004Ool00`00Oomoo`1WOol00`00Oomoo`05Ool00`00Oomoo`2:Ool00`00Oomo
o`04Ool00`00Oomoo`0dOol003Eoo`03001oogoo09Yoo`03001oogoo06Ioo`03001oogoo00Eoo`03
001oogoo08]oo`03001oogoo00Aoo`03001oogoo03=oo`00=7oo00<007ooOol0W7oo00<007ooOol0
I7oo00<007ooOol0W7oo00<007ooOol0<Woo000cOol00`00Oomoo`2HOol00`00Oomoo`03Ool00`00
Oomoo`1ROol00`00Oomoo`2EOol00`00Oomoo`06Ool00`00Oomoo`0aOol0039oo`03001oogoo0:1o
o`03001oogoo061oo`03001oogoo09Qoo`03001oogoo00Aoo`03001oogoo035oo`00<Woo00<007oo
Ool0VWoo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol0XGoo00<007ooOol0<7oo000aOol0
0`00Oomoo`2ROol00`00Oomoo`1MOol00`00Oomoo`2JOol00`00Oomoo`06Ool00`00Oomoo`0_Ool0
031oo`03001oogoo0:Aoo`03001oogoo05aoo`03001oogoo00Moo`03001oogoo04Moo`03001oogoo
03Qoo`03001oogoo01Eoo`03001oogoo02ioo`00;goo00<007ooOol0YWoo00<007ooOol0FWoo00<0
07ooOol0WWoo00<007ooOol01Goo00<007ooOol0;Goo000_Ool00`00Oomoo`2WOol00`00Oomoo`1H
Ool00`00Oomoo`05Ool00`00Oomoo`2EOol01000Oomoo`001goo00<007ooOol0;7oo000^Ool00`00
Oomoo`2LOol00`00Oomoo`09Ool00`00Oomoo`1GOol00`00Oomoo`2ROol00`00Oomoo`04Ool00`00
Oomoo`0/Ool002eoo`03001oogoo0:Yoo`03001oogoo05Ioo`03001oogoo0:Yoo`03001oogoo02]o
o`00;7oo00<007ooOol027oo00<007ooOol0XGoo00<007ooOol0E7oo00<007ooOol0[7oo00<007oo
Ool0:Woo000/Ool00`00Oomoo`08Ool00`00Oomoo`2QOol00`00Oomoo`1DOol00`00Oomoo`2/Ool0
0`00Oomoo`0ZOol002]oo`03001oogoo0:ioo`03001oogoo059oo`03001oogoo0:ioo`03001oogoo
02Uoo`00:goo00<007ooOol0Z7oo00<007ooOol00goo00<007ooOol0DWoo00<007ooOol0N7oo00<0
07ooOol0<goo00<007ooOol0:Goo000[Ool00`00Oomoo`2_Ool00`00Oomoo`1@Ool00`00Oomoo`2`
Ool00`00Oomoo`0XOol002Yoo`03001oogoo0:]oo`03001oogoo00=oo`03001oogoo04ioo`03001o
ogoo02Yoo`03001oogoo07aoo`8000Ioo`03001oogoo02Qoo`00:Goo00<007ooOol0[7oo00<007oo
Ool017oo00<007ooOol0CGoo00<007ooOol0YWoo00<007ooOol02Goo00<007ooOol09goo000XOol0
0`00Oomoo`2^Ool00`00Oomoo`03Ool00`00Oomoo`1<Ool00`00Oomoo`2cOol00`00Oomoo`0WOol0
02Qoo`03001oogoo0:moo`03001oogoo00=oo`03001oogoo04]oo`03001oogoo0;Aoo`03001oogoo
02Ioo`009goo00<007ooOol0[Woo00<007oo00001Goo00<007ooOol0BWoo00<007ooOol0[Woo00<0
07ooOol01Goo00<007ooOol09Goo000WOol00`00Oomoo`05Ool00`00Oomoo`2^Ool00`00Oomoo`1:
Ool00`00Oomoo`2fOol00`00Oomoo`0UOol002Ioo`03001oogoo03Yoo`03001oogoo07]oo`03001o
ogoo04Qoo`03001oogoo00Ioo`03001oogoo0:Moo`8000Ioo`03001oogoo02Aoo`009Woo00<007oo
Ool017oo0P00/Woo00<007ooOol0B7oo00<007ooOol0^7oo00<007ooOol097oo000VOol00`00Oomo
o`2dOol00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`00Oomoo`1:Ool00`00Oomo
o`1MOol20006Ool00`00Oomoo`0SOol002Eoo`03001oogoo0;Eoo`03001oogoo009oo`03001oogoo
04Ioo`03001oogoo03aoo`03001oogoo07=oo`03001oogoo00Eoo`03001oogoo02=oo`009Goo00<0
07ooOol0^goo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0[7oo00<007ooOol01Goo00<0
07ooOol08Woo000TOol00`00Oomoo`04Ool00`00Oomoo`2`Ool00`00Oomoo`02Ool00`00Oomoo`13
Ool00`00Oomoo`05Ool00`00Oomoo`2eOol00`00Oomoo`0ROol002Aoo`03001oogoo00=oo`03001o
ogoo0;9oo`05001oogooOol00015Ool00`00Oomoo`05Ool00`00Oomoo`2^Ool00`00Oomoo`04Ool0
0`00Oomoo`0ROol002=oo`03001oogoo0;Uoo`03001oogoo009oo`03001oogoo049oo`03001oogoo
00Eoo`03001oogoo0;Ioo`03001oogoo025oo`008goo00<007ooOol0^Goo00<007ooOol00Woo00<0
07ooOol0@Woo00<007ooOol01Goo0P00]goo00<007ooOol08Goo000SOol00`00Oomoo`04Ool01000
Oomoo`003Goo00<007ooOol0Ygoo00<007ooOol0@Goo00<007ooOol0_goo00<007ooOol087oo000R
Ool00`00Oomoo`30Ool00`00Oomoo`10Ool00`00Oomoo`30Ool00`00Oomoo`0POol0029oo`03001o
ogoo0<1oo`03001oogoo041oo`03001oogoo0;Qoo`03001oogoo00Eoo`03001oogoo021oo`008Goo
00<007ooOol0`Woo00<007ooOol0?Woo00<007ooOol01Goo00<007ooOol0/7oo00<007ooOol01goo
00<007ooOol07goo000QOol00`00Oomoo`2lOol00`00Oomoo`03Ool00`00Oomoo`0nOol00`00Oomo
o`2gOol00`00Oomoo`08Ool00`00Oomoo`0OOol0025oo`03001oogoo0<=oo`03001oogoo03eoo`03
001oogoo0<=oo`03001oogoo01ioo`0087oo00<007ooOol0a7oo00<007ooOol0?7oo00<007ooOol0
a7oo00<007ooOol07Woo000POol00`00Oomoo`06Ool00`00Oomoo`2kOol00`00Oomoo`0lOol00`00
Oomoo`34Ool00`00Oomoo`0NOol0021oo`03001oogoo0<Eoo`03001oogoo03Yoo`03001oogoo04Mo
o`03001oogoo07]oo`03001oogoo01ioo`0087oo00<007ooOol0_7oo00<007ooOol01Woo00<007oo
Ool0>Woo00<007ooOol0aGoo00<007ooOol07Woo000POol00`00Oomoo`35Ool00`00Oomoo`0jOol0
0`00Oomoo`36Ool00`00Oomoo`0MOol001moo`03001oogoo0;moo`03001oogoo00Aoo`03001oogoo
03Yoo`03001oogoo00Moo`03001oogoo035oo`03001oogoo08Qoo`03001oogoo01eoo`007goo00<0
07ooOol027oo00<007ooOol0/7oo00D007ooOomoo`0000Ioo`03001oogoo03Yoo`03001oogoo00Io
o`03001oogoo0;eoo`03001oogoo01eoo`007Woo00<007ooOol0b7oo00<007ooOol0>7oo00<007oo
Ool01goo00<007ooOol0_Woo00<007ooOol077oo000NOol00`00Oomoo`07Ool00`00Oomoo`2gOol0
0`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`38Ool00`00Oomoo`0LOol001ioo`03001oogoo
00Ioo`800<1oo`03001oogoo03Qoo`03001oogoo00Moo`03001oogoo0;ioo`03001oogoo01aoo`00
7Woo00<007ooOol03goo00<007ooOol0]Woo00<007ooOol0=goo00<007ooOol027oo0P0000=oo`00
Ool0_7oo00<007ooOol077oo000NOol00`00Oomoo`03Ool20005Ool00`00Oomoo`2kOol00`00Oomo
o`0gOol00`00Oomoo`08Ool3002nOol00`00Oomoo`0LOol001eoo`03001oogoo00Aoo`03001oogoo
0<=oo`03001oogoo03Ioo`03001oogoo0<Yoo`03001oogoo01]oo`007Goo00<007ooOol02Woo00<0
07ooOol0_Goo00<007ooOol0=Woo00<007ooOol02goo00<007ooOol0_7oo00<007ooOol06goo000M
Ool00`00Oomoo`04Ool00`00Oomoo`2kOol00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`0;
Ool01000Ool00000^goo00<007ooOol06goo000MOol00`00Oomoo`0:Ool00`00Oomoo`2mOol00`00
Oomoo`0eOol00`00Oomoo`0<Ool00`00Oomoo`2lOol00`00Oomoo`0KOol001eoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo0;eoo`03001oogoo03Eoo`03001oogoo019oo`03001oogoo0;Io
o`03001oogoo01]oo`0077oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0]Woo00<007oo
Ool01Woo00<007ooOol0=7oo00<007ooOol047oo00@007ooOol00;Moo`03001oogoo01]oo`0077oo
00<007ooOol01Goo00<007oo00000goo00<007ooOol0_Woo00<007ooOol0=7oo00<007ooOol037oo
00@007ooOol00;]oo`03001oogoo01]oo`0077oo00<007ooOol0c7oo00<007ooOol0=7oo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol0Z7oo00<007ooOol02Goo00<007ooOol06Woo000LOol0
0`00Oomoo`06Ool30002Ool00`00Oomoo`2nOol00`00Oomoo`0dOol00`00Oomoo`0;Ool00`00Oomo
o`2nOol00`00Oomoo`0JOol001aoo`03001oogoo00Ioo`800<Aoo`03001oogoo03Aoo`03001oogoo
01Qoo`03001oogoo0;5oo`03001oogoo01Yoo`0077oo00<007ooOol0c7oo00<007ooOol0=7oo00<0
07ooOol027oo1000`7oo00<007ooOol06Woo000LOol00`00Oomoo`06Ool00`00Oomoo`33Ool00`00
Oomoo`0dOol00`00Oomoo`08Ool20006Ool00`00Oomoo`2]Ool00`00Oomoo`09Ool00`00Oomoo`0J
Ool001aoo`03001oogoo00Ioo`05001oogooOol00031Ool00`00Oomoo`0dOol00`00Oomoo`3<Ool0
0`00Oomoo`0JOol001aoo`03001oogoo00Ioo`03001oogoo0<=oo`03001oogoo03=oo`03001oogoo
00Qoo`03001oogoo0<9oo`03001oogoo01Yoo`0077oo00<007ooOol0c7oo00<007ooOol0<goo00<0
07ooOol01goo0P002Woo00<007ooOol01Woo00<007ooOol0[Woo00<007ooOol06Woo000LOol00`00
Oomoo`06Ool00`00Oomoo`33Ool00`00Oomoo`0cOol00`00Oomoo`08Ool00`00Oomoo`32Ool00`00
Oomoo`0JOol001aoo`03001oogoo00Ioo`03001oogoo0<=oo`03001oogoo03=oo`03001oogoo00Mo
o`03001oogoo02=oo`03001oogoo09eoo`03001oogoo01Yoo`0077oo00<007ooOol01Goo00<007oo
Ool0a7oo00<007ooOol0<goo00<007ooOol01goo00<007oo00002Woo00<007ooOol0Zgoo00<007oo
Ool027oo00<007ooOol06Woo000LOol00`00Oomoo`3<Ool00`00Oomoo`0cOol00`00Oomoo`08Ool0
0`00Oomoo`0ROol00`00Oomoo`2MOol00`00Oomoo`0JOol001aoo`03001oogoo0<aoo`03001oogoo
03=oo`03001oogoo0<eoo`03001oogoo01Yoo`0077oo00<007ooOol0c7oo00<007ooOol0<goo00<0
07ooOol0cGoo00<007ooOol06Woo000LOol00`00Oomoo`05Ool00`00Oomoo`34Ool00`00Oomoo`0c
Ool00`00Oomoo`3=Ool00`00Oomoo`0JOol001aoo`03001oogoo00Aoo`800<Ioo`03001oogoo03=o
o`03001oogoo00Moo`03001oogoo00eoo`03001oogoo0;=oo`03001oogoo01Yoo`0077oo00<007oo
Ool0c7oo00<007ooOol0<goo00<007ooOol01goo00<007ooOol03Woo00<007ooOol0/Woo00<007oo
Ool06Woo000LOol00`00Oomoo`05Ool00`00Oomoo`2lOol00`00Oomoo`05Ool00`00Oomoo`0cOol0
0`00Oomoo`07Ool00`00Oomoo`33Ool00`00Oomoo`0JOol001aoo`03001oogoo0<aoo`03001oogoo
03=oo`03001oogoo0<eoo`03001oogoo01Yoo`0077oo00<007ooOol01Goo00<007ooOol0_7oo00<0
07ooOol01Goo00<007ooOol0=7oo00<007ooOol0c7oo00<007ooOol06Woo000LOol00`00Oomoo`34
Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00`00Oomoo`06Ool00`00Oomoo`33Ool00`00Oomoo`0J
Ool001aoo`03001oogoo00Ioo`03001oogoo0<=oo`03001oogoo03Aoo`03001oogoo00Moo`03001o
ogoo0;Qoo`03001oogoo00Moo`03001oogoo01Yoo`0077oo00<007ooOol0c7oo00<007ooOol0=7oo
00<007ooOol05goo00<007ooOol0/Woo00<007ooOol06Woo000LOol00`00Oomoo`3<Ool00`00Oomo
o`0dOol00`00Oomoo`06Ool00`00Oomoo`33Ool00`00Oomoo`0JOol001aoo`03001oogoo0<=oo`03
001oo`0000Ioo`03001oogoo03Aoo`03001oogoo00Moo`03001oogoo019oo`03001oogoo0:=oo`03
001oogoo00Ioo`03001oogoo01]oo`0077oo00<007ooOol0c7oo00<007ooOol0=7oo00<007ooOol0
`Woo00<007ooOol01Woo00<007ooOol06goo000MOol00`00Oomoo`05Ool00`00Oomoo`33Ool00`00
Oomoo`0dOol00`00Oomoo`31Ool00`00Oomoo`07Ool00`00Oomoo`0KOol001eoo`03001oogoo0<Yo
o`03001oogoo03Eoo`03001oogoo0;Uoo`03001oogoo00moo`03001oogoo01]oo`007Goo00<007oo
Ool0bWoo00<007ooOol0=Goo00<007ooOol0bgoo00<007ooOol06goo000MOol00`00Oomoo`3:Ool0
0`00Oomoo`0fOol00`00Oomoo`2iOol00`00Oomoo`0>Ool00`00Oomoo`0KOol001eoo`03001oogoo
0<Yoo`03001oogoo03Ioo`03001oogoo00Qoo`03001oogoo0;moo`03001oogoo01]oo`007Woo00<0
07ooOol0`Goo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol0`7oo00<0
07ooOol06goo000NOol00`00Oomoo`0JOol00`00Oomoo`2[Ool00`00Oomoo`0gOol00`00Oomoo`08
Ool00`00Oomoo`2nOol00`00Oomoo`0LOol001ioo`03001oogoo0<Qoo`03001oogoo03Moo`03001o
ogoo00Moo`03001oogoo04Yoo`03001oogoo079oo`03001oogoo01aoo`007Woo00<007ooOol0b7oo
00<007ooOol0>7oo00<007ooOol01Woo00<007ooOol0_goo00<007ooOol077oo000NOol00`00Oomo
o`05Ool00`00Oomoo`30Ool00`00Oomoo`0hOol00`00Oomoo`38Ool00`00Oomoo`0LOol001moo`03
001oogoo0<Moo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo069oo`03001oogoo031oo`03
001oogoo01aoo`007goo00<007ooOol01Goo00<007ooOol0_Woo00<007ooOol0>Woo00<007ooOol0
1Goo00<007ooOol0ZWoo00<007ooOol01Woo00<007ooOol027oo00<007ooOol07Goo000OOol00`00
Oomoo`04Ool00`00Oomoo`2oOol00`00Oomoo`0jOol00`00Oomoo`06Ool00`00Oomoo`2mOol00`00
Oomoo`0MOol0021oo`03001oogoo0;aoo`03001oogoo00Ioo`03001oogoo03Yoo`03001oogoo0<Eo
o`03001oogoo01ioo`0087oo00<007ooOol017oo00<007ooOol0_Woo00<007ooOol0>Woo00<007oo
Ool0aGoo00<007ooOol07Woo000POol00`00Oomoo`05Ool00`00Oomoo`2mOol00`00Oomoo`0kOol0
0`00Oomoo`34Ool00`00Oomoo`0NOol0021oo`03001oogoo00Uoo`03001oogoo0;Qoo`03001oogoo
03aoo`03001oogoo09Ioo`03001oogoo02]oo`03001oogoo01ioo`0087oo00<007ooOol0a7oo00<0
07ooOol0?7oo00<007ooOol0a7oo00<007ooOol07Woo000QOol00`00Oomoo`32Ool00`00Oomoo`0n
Ool00`00Oomoo`0[Ool00`00Oomoo`2DOol00`00Oomoo`0OOol0025oo`03001oogoo0<9oo`03001o
ogoo03ioo`03001oogoo00Eoo`03001oogoo0;Yoo`03001oogoo01moo`008Woo00<007ooOol0`Goo
00<007ooOol0?goo00<007ooOol0`Goo00<007ooOol07goo000ROol00`00Oomoo`30Ool00`00Oomo
o`10Ool00`00Oomoo`04Ool00`00Oomoo`2iOol00`00Oomoo`0POol0029oo`03001oogoo00=oo`03
001oogoo0;Yoo`03001oogoo041oo`03001oogoo0;Eoo`03001oogoo00Qoo`03001oogoo021oo`00
8goo00<007ooOol00Woo00<007ooOol0^Goo00<007ooOol0@Goo00<007ooOol0/Goo00<007ooOol0
2goo00<007ooOol08Goo000SOol00`00Oomoo`2nOol00`00Oomoo`11Ool00`00Oomoo`09Ool00`00
Oomoo`2cOol00`00Oomoo`0QOol002Aoo`05001oogooOol0002kOol00`00Oomoo`12Ool00`00Oomo
o`2nOol00`00Oomoo`0QOol002Aoo`05001oogooOol0000=Ool00`00Oomoo`2ZOol00`00Oomoo`13
Ool00`00Oomoo`2cOol00`00Oomoo`07Ool00`00Oomoo`0ROol002Aoo`03001oogoo0;aoo`03001o
ogoo04Aoo`03001oogoo00Aoo`03001oogoo0;Eoo`03001oogoo029oo`009Goo00D007ooOomoo`00
0;Qoo`03001oogoo04Eoo`03001oogoo00=oo`03001oogoo0:]oo`03001oogoo00Moo`03001oogoo
02=oo`009Goo00D007ooOomoo`000;Qoo`03001oogoo04Ioo`03001oogoo009oo`800:]oo`03001o
ogoo00Qoo`03001oogoo02=oo`009Woo00@007ooOol00;Qoo`03001oogoo04Moo`03001oogoo03Ao
o`03001oogoo089oo`03001oogoo02=oo`009Woo00D007ooOomoo`000;Ioo`03001oogoo04Qoo`03
001oogoo0:moo`03001oogoo00Ioo`03001oogoo02Aoo`009goo00@007ooOol00:ioo`03001oogoo
00Eoo`03001oogoo04Uoo`03001oogoo009oo`03001oogoo0:Moo`03001oogoo00Qoo`03001oogoo
02Aoo`009goo00D007ooOomoo`000;Aoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo0;5o
o`03001oogoo02Eoo`00:7oo00@007ooOol00;Aoo`03001oogoo04]oo`03001oogoo0;Aoo`03001o
ogoo02Ioo`00:7oo00<007ooOol00P00Zgoo00<007ooOol017oo00<007ooOol0C7oo00D007ooOomo
o`00009oo`03001oogoo0:aoo`03001oogoo02Moo`00:Goo00@007ooOol00;9oo`03001oogoo04ao
o`05001oogooOol0002aOol00`00Oomoo`0WOol002Uoo`03001oogoo0;9oo`03001oogoo04ioo`03
001oogoo00800:moo`03001oogoo02Qoo`00:Woo00@007ooOomoo`800:ioo`03001oogoo04ioo`03
001oogoo00800:Qoo`03001oogoo00Aoo`03001oogoo02Qoo`00:goo00@007ooOol009ioo`03001o
ogoo00eoo`03001oogoo051oo`03001oo`0000Aoo`03001oogoo09Yoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo02Qoo`00:goo00<007ooOol00goo00<007ooOol0Z7oo00<007ooOol0DWoo
00<007ooOol0Ygoo00<007ooOol017oo00<007ooOol0:Goo000/Ool00`00Oomoo`2]Ool00`00Oomo
o`1COol01000Oomoo`000Woo00<007ooOol0Wgoo0P001Woo00<007ooOol0:Goo000/Ool00`00Oomo
o`2WOol00`00Oomoo`02Ool00`00Oomoo`1DOol00`00Oomoo`2SOol01000Oomoo`001Goo00<007oo
Ool0:Woo000]Ool00`00Oomoo`2ZOol00`00Oomoo`1FOol00`00Oomoo`2TOol00`00Oomoo`03Ool0
0`00Oomoo`0[Ool002ioo`03001oogoo0:Qoo`03001oogoo05Moo`03001oogoo009oo`03001oogoo
09ioo`03001oogoo00=oo`03001oogoo02aoo`00;goo00<007ooOol0Wgoo00<007ooOol01Goo00<0
07ooOol0F7oo00<007ooOol00goo00<007ooOol0W7oo00<007ooOol00goo00<007ooOol0;7oo000_
Ool00`00Oomoo`2VOol00`00Oomoo`1JOol00`00Oomoo`2QOol00`00Oomoo`02Ool00`00Oomoo`0]
Ool0031oo`03001oogoo0:Aoo`03001oogoo05]oo`03001oogoo00Eoo`03001oogoo029oo`03001o
ogoo07=oo`03001oogoo009oo`03001oogoo02ioo`00<7oo00<007ooOol0Y7oo00<007ooOol0G7oo
00<007ooOol0Y7oo00<007ooOol0;Woo000aOol00`00Oomoo`2MOol00`00Ool00002Ool00`00Oomo
o`1MOol00`00Oomoo`1UOol00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`0_Ool0039oo`03
001oogoo09aoo`8000=oo`03001oogoo05ioo`03001oogoo04ioo`03001oogoo04aoo`05001oogoo
Ool0000bOol0039oo`03001oogoo0:1oo`03001oogoo061oo`03001oogoo00=oo`03001oogoo05Eo
o`03001oogoo03Yoo`04001oogoo0003Ool00`00Oomoo`0aOol003=oo`03001oogoo09ioo`03001o
ogoo069oo`03001oogoo06Moo`03001oogoo03Aoo`03001oogoo035oo`00=7oo00<007ooOol0W7oo
00<007ooOol0I7oo00<007ooOol00goo00<007ooOol0UWoo00<007ooOol0<Woo000eOol00`00Oomo
o`2JOol00`00Oomoo`1VOol00`00Oomoo`02Ool00`00Ool0002;Ool01@00Oomoogoo00001Goo00<0
07ooOol0<goo000fOol00`00Oomoo`2HOol00`00Oomoo`1WOol2002IOol2000fOol003Moo`03001o
ogoo09Ioo`03001oogoo06Yoo`03001oogoo09Eoo`03001oogoo03Ioo`00>7oo00<007ooOol0U7oo
00<007ooOol0K7oo00<007ooOol0JWoo00<007ooOol07goo0P001Woo00<007ooOol0=Woo000iOol0
0`00Oomoo`29Ool00`00Oomoo`06Ool00`00Oomoo`1^Ool00`00Oomoo`2:Ool00`00Oomoo`05Ool0
0`00Oomoo`0gOol003Yoo`03001oogoo091oo`03001oogoo071oo`03001oogoo00=oo`03001oogoo
08Yoo`03001oogoo03Qoo`00>goo00<007ooOol0SWoo00<007ooOol0LWoo00<007ooOol0OWoo00<0
07ooOol03Goo00<007ooOol0>Goo000lOol00`00Oomoo`2<Ool00`00Oomoo`1dOol00`00Oomoo`1P
Ool00`00Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`0jOol003eoo`03001oogoo08Yoo`03001o
ogoo07Ioo`03001oogoo069oo`03001oogoo01eoo`03001oogoo00Eoo`03001oogoo03]oo`00?Woo
00<007ooOol0R7oo00<007ooOol0N7oo00<007ooOol00goo00<007ooOol0Kgoo00<007ooOol047oo
00<007ooOol0?7oo000oOol20026Ool2001kOol20027Ool2000oOol0045oo`03001oogoo00Eoo`03
001oogoo07Yoo`03001oogoo07eoo`03001oogoo00Eoo`03001oogoo07]oo`03001oogoo03moo`00
@Woo00<007ooOol0P7oo00<007ooOol0Ogoo00<007ooOol0F7oo00<007ooOol09Woo00<007ooOol0
@7oo0013Ool00`00Oomoo`1nOol00`00Oomoo`21Ool00`00Oomoo`05Ool00`00Oomoo`1gOol00`00
Oomoo`11Ool004Aoo`03001oogoo071oo`03001oogoo00Uoo`03001oogoo08=oo`03001oogoo00Ao
o`03001oogoo06]oo`03001oogoo00Qoo`03001oogoo049oo`00AGoo0P00L7oo00<007ooOol01goo
0P00Qgoo0P00JGoo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`8004Eoo`00Agoo00<007ooOol0
JGoo00<007ooOol02Woo00<007ooOol0RGoo0P0017oo0P00F7oo00<007ooOol03Woo00<007ooOol0
1Woo00<007ooOol0AGoo0018Ool00`00Oomoo`1dOol00`00Oomoo`2<Ool00`00Oomoo`03Ool00`00
Oomoo`1SOol200000goo001oo`06Ool00`00Oomoo`16Ool004Uoo`80079oo`80091oo`8002eoo`03
001oogoo049oo`8004Uoo`00Bgoo0P00KWoo0P00U7oo0P00KWoo0P00Bgoo001=Ool00`00Oomoo`1Z
Ool00`00Oomoo`2FOol00`00Oomoo`1YOol2001=Ool004ioo`8006Qoo`8009Yoo`03001oogoo00Io
o`03001oogoo05ioo`03001oogoo04eoo`00D7oo0P00I7oo0P00WGoo0P00?goo00<007ooOol02Woo
00<007ooOol05Woo0P00D7oo001BOol2000?Ool00`00Oomoo`1>Ool2002QOol30009Ool00`00Oomo
o`19Ool00`00Oomoo`08Ool2001BOol005Aoo`8005aoo`800:Ioo`8003Eoo`03001oogoo00Moo`03
001oogoo01=oo`8000Eoo`8005Aoo`00EWoo0P00FGoo00<007ooOol0Z7oo0P00Cgoo00D007ooOomo
o`0000Aoo`8005Ioo`00F7oo0P00?goo00<007ooOol04goo0P00[Goo00<007ooOol0Agoo00<007oo
Ool00Woo00@007oo000000Aoo`03001oogoo05Ioo`00FWoo00<007ooOol0<goo00<007ooOol06Woo
0P00/7oo0P003Goo0P00>Goo10001Woo0P00FGoo001KOol2001>Ool2002dOol2000mOol01@00Ool0
07oo000037oo0P00Fgoo001MOol5000IOol00`00Oomoo`0XOol5002hOol5000:Ool00`00Oomoo`0g
Ool5001MOol0069oo`80041oo`800<9oo`8000moo`03001oogoo02eoo`<0069oo`00I7oo0`0047oo
00<007ooOol09goo0`00aWoo0`006goo00<007oo000077oo0P00IGoo001WOol5000`Ool5003<Ool5
000KOol00`00Oomoo`0BOol5001WOol006aoo`8002aoo`800=Ioo`8000ioo`05001oo`00Ool00003
Ool00`00Oomoo`0BOol3001/Ool006ioo`D0029oo`D00=Yoo`D0025oo`D006moo`00Lgoo2`0037oo
2`00i7oo2P003Goo2P00M7oo001nOol<003iOol=001nOol00?mooomooa1oo`00ogooogoo47oo003o
OoooOol@Ool00?mooomooa1oo`00ogooogoo47oo003oOoooOol@Ool00?mooomooa1oo`00ogooogoo
47oo002MOol8003oOol7Ool8001KOol00?mooomooa1oo`00ogooogoo47oo002=Ool01000Oomoo`00
ogoo2goo00@007ooOol006moo`00E7oo0`0017oo10001Woo00@007ooOomoo`<000=oo`80009oo`<0
0004Ool00000Ool70002Ool50005Ool01000Oomoo`001Goo0`003Woo1@0017oo0P00YWoo1@0017oo
0`0000Aoo`00001oo`T00004Ool000000002Ool30003Ool20002Ool3000017oo000007oo1`000Woo
1@001Goo00@007ooOol000Moo`<000aoo`D005Aoo`00Dgoo00D007ooOomoo`00009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oo`0000=oo`8000Eoo`03
001oogoo009oo`03001oogoo00Uoo`04001oogoo0003Ool01@00Oomoogoo00003goo00<007ooOol0
17oo0P00Ygoo00D007ooOomoo`00009oo`04001oogooOol20005Ool00`00Oomoo`02Ool20003Ool0
1000Oomoo`001Goo00<007oo00000goo0P001Goo00<007ooOol00Woo00<007ooOol02Goo00@007oo
Ool000Moo`03001oogoo00eoo`03001oogoo05Aoo`00DWoo00<007ooOol02Woo00<007ooOol00goo
00<007ooOol00Woo00@007ooOol0009oo`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Qoo`H000Ioo`03001oogoo00eoo`03001oogoo0:eoo`05001oogooOol00002Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00H007ooOol007oo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`08Ool60006Ool0
0`00Oomoo`0=Ool00`00Oomoo`1DOol0059oo`03001oogoo00Yoo`03001oogoo00Aoo`0;001oogoo
Ool007oo001oo`00Ool00002Ool50005Ool00`00Oomoo`02Ool60006Ool01000Oomoo`001goo00<0
07ooOol03Goo00<007ooOol0[Goo00D007ooOomoo`0000=oo`D000Eoo`03001oogoo009oo`03001o
ogoo009oo`0:001oogoo001oo`00Ool007oo0002Ool50005Ool00`00Oomoo`02Ool60006Ool01000
Oomoo`000goo1P003Woo00<007ooOol0E7oo001BOol00`00Oomoo`0:Ool00`00Oomoo`04Ool03@00
Oomoogoo001oo`00Ool007oo001oo`0000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`04001oogoo0005Ool2000@Ool00`00Oomoo`2]Ool40003Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20003Ool03000Oomoo`00Ool007oo001oo`00Ool0
00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo
0004Ool01000Oomoo`003goo00<007ooOol0E7oo001BOol00`00Oomoo`06Ool40007Ool02`00Oomo
ogoo001oo`00Ool007oo00000Woo10001Woo00<007ooOol00goo10001Woo1P001Woo00<007ooOol0
3Goo00<007ooOol0[Goo00D007ooOomoo`0000=oo`@000Ioo`03001oogoo009oo`03001oo`000080
00=oo`07001oo`00Ool007oo00000Woo10001Woo00<007ooOol00goo10001Woo1P000goo00@007oo
Ool000moo`03001oogoo05Aoo`00Dgoo00<007ooOol00P000goo00<007ooOol02Goo00<007ooOol0
0P000goo0P0037oo00<007ooOol03Woo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo0:eo
o`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomoo`05Ool20003Ool2000<Ool00`00Oomo
o`0>Ool01000Oomoo`001Goo00<007oo00003goo00<007ooOol0E7oo001DOol200000goo001oo`02
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool000020003Ool2000<Ool00`00Oomoo`0?Ool0
1000Oomoo`000Woo00D007ooOomoo`0000eoo`<00:ioo`D000ioo`03001oogoo009oo`03001oogoo
00Aoo`<000=oo`8000aoo`03001oogoo00moo`04001oogoo0004Ool00`00Ool0000=Ool3001FOol0
05]oo`D0009oo`H001Aoo`80015oo`04001oogoo0003Ool3000@Ool00`00Oomoo`2nOol20003Ool2
000IOol2000AOol01000Oomoo`001Goo0P003goo00<007ooOol0E7oo003oOoooOol@Ool00?mooomo
oa1oo`00ogooogoo47oo003oOoooOol@Ool00?mooomooa1oo`00ogooogoo47oo003oOoooOol@Ool0
0?mooomooa1oo`00ogooogoo47oo0000\
\>"],
  ImageRangeCache->{{{0, 525.813}, {249.813, 0}} -> {-0.0524238, -0.0238146, \
0.00400304, 0.00400304}, {{13.0625, 251}, {243.813, 5.9375}} -> {-216.011, \
-188.318, 1.63606, 1.63606}, {{274.75, 512.688}, {243.813, 5.9375}} -> \
{-644.146, -188.318, 1.63606, 1.63606}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Even this rather meagre graph suggests that we may find regions of higher \
concentration of stopping episodes. It might pay to examine the path traced \
during a stopping episode rather than to summarize it by a point located at \
its point of origin. \
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[
        Partition[
          Flatten[Script[{"\<See[Map[PathPlot,lingering],PlotLabel->\
sessionname2,TextStyle->{FontSize->14},DisplayFunction->Identity]\>"}, 
              twofiles], 1], 2]]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.09259 .43598 m
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09259 .43598 L
.09257 .43598 L
.09254 .43598 L
.09249 .43598 L
.09245 .43598 L
.09241 .43594 L
.09239 .43588 L
.0924 .43577 L
.09244 .43564 L
s
.16763 .59735 m
.16759 .59743 L
.16764 .59741 L
.16774 .59735 L
.16785 .59727 L
.16794 .5972 L
.16797 .5971 L
.16795 .59696 L
s
.11271 .74058 m
.11274 .74062 L
.11281 .74062 L
s
.55929 .94148 m
0 0 rlineto s
.59979 .93558 m
.59992 .93564 L
.6 .9357 L
.60012 .93573 L
s
.73649 .88291 m
.73646 .88285 L
.73639 .88285 L
.73636 .88287 L
.73643 .88287 L
s
.89054 .73049 m
0 0 rlineto s
.93286 .59052 m
.93288 .59041 L
.93286 .59046 L
.93282 .5906 L
.93276 .5908 L
.93271 .59101 L
.93267 .59116 L
.93265 .59123 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59124 L
.93265 .59125 L
.93265 .59127 L
.93267 .59133 L
.93269 .59142 L
.93271 .59154 L
.93271 .59166 L
.93268 .59177 L
Mistroke
.93265 .59184 L
.9326 .59181 L
Mfstroke
.93248 .399 m
.9325 .39887 L
.93254 .39902 L
.93258 .39934 L
.93261 .39972 L
.93262 .40008 L
.93259 .40035 L
.93251 .40045 L
.93239 .40036 L
.93223 .40008 L
.93204 .39966 L
.93181 .39917 L
.93158 .39867 L
.93136 .3982 L
.93115 .39777 L
.93093 .39739 L
.93073 .39706 L
.93056 .39678 L
.93041 .39654 L
.93031 .39632 L
.93025 .39612 L
.93023 .39591 L
.93023 .39565 L
.93025 .39533 L
.93027 .39494 L
.93028 .3945 L
.93028 .39404 L
.93026 .39362 L
.93026 .39323 L
.93027 .39291 L
.9303 .39269 L
.93033 .39261 L
.93034 .39269 L
.93034 .39294 L
.93031 .39339 L
.93024 .39399 L
.93015 .39472 L
.93001 .39554 L
.92983 .3964 L
.92962 .39724 L
.9294 .398 L
.9292 .39866 L
.92902 .39922 L
.92887 .3997 L
.92877 .40008 L
.92873 .40036 L
.92876 .40057 L
.92886 .4007 L
.92901 .40078 L
.92921 .4008 L
Mistroke
.92946 .40077 L
.9297 .4007 L
.92993 .40062 L
.93015 .40056 L
.93033 .40053 L
.93046 .40053 L
.93055 .40052 L
.93059 .40047 L
.93058 .40036 L
.93053 .4002 L
.93046 .40004 L
.93041 .39991 L
.93039 .39986 L
.93042 .39992 L
Mfstroke
.93397 .43941 m
.93399 .43963 L
s
.72 .89132 m
.72 .89125 L
.71998 .89126 L
.71996 .89131 L
.71997 .89137 L
.72005 .89139 L
.72023 .89133 L
.72051 .89119 L
.72092 .89098 L
.72143 .89072 L
.72201 .89043 L
.72261 .89013 L
.72318 .88983 L
.72374 .88953 L
.72427 .88925 L
.72473 .88899 L
.72512 .88876 L
.72543 .88858 L
.72564 .88846 L
.72573 .8884 L
.72569 .88838 L
.72555 .88841 L
.72535 .88847 L
.72513 .88853 L
.72494 .88858 L
.7248 .88861 L
.72473 .88862 L
.72473 .88862 L
.72476 .88862 L
.7248 .88861 L
.72483 .88861 L
.72484 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72485 .88861 L
.72486 .88861 L
.72487 .8886 L
.72488 .8886 L
.72488 .8886 L
.72486 .88861 L
.72484 .88861 L
.7248 .88861 L
.72477 .88862 L
.72473 .88862 L
.7247 .88862 L
Mistroke
.72467 .88863 L
.72465 .88863 L
.72464 .88863 L
.72464 .88863 L
.72464 .88863 L
.72465 .88863 L
.72466 .88863 L
.72469 .88862 L
.72472 .88862 L
.72477 .88859 L
.72484 .88851 L
.72491 .8884 L
.72498 .8883 L
.72501 .88825 L
.725 .88829 L
.72494 .88843 L
.72484 .8887 L
.72469 .88912 L
.72452 .88968 L
.72432 .89033 L
.72409 .89104 L
.72385 .89178 L
.72361 .8925 L
.72336 .89322 L
.7231 .89396 L
.72284 .89469 L
.7226 .89535 L
.7224 .89587 L
.72227 .89618 L
.72225 .89626 L
.72234 .89613 L
.72254 .89581 L
.72284 .89536 L
.72321 .89481 L
.72364 .89423 L
.72409 .89366 L
.72455 .89312 L
.72503 .8926 L
.7255 .8921 L
.72595 .89165 L
.72636 .89127 L
.72671 .89096 L
.72699 .89075 L
.72717 .89061 L
.72726 .89051 L
.72728 .89045 L
.72729 .89038 L
Mfstroke
.10141 .64087 m
.10142 .64104 L
.10148 .64116 L
.10159 .64119 L
.10173 .64113 L
s
.08279 .63676 m
.08273 .63676 L
.08274 .63676 L
.08278 .63676 L
.08281 .63676 L
.08284 .63676 L
.08288 .63676 L
.08292 .63676 L
.08296 .63676 L
.08298 .63676 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08298 .63675 L
.08299 .63675 L
.083 .63671 L
.08304 .63662 L
.08309 .6365 L
.08313 .63639 L
.08315 .63631 L
.08314 .63629 L
.08308 .63638 L
s
.0865 .70383 m
.0865 .7039 L
s
.06439 .53817 m
.06442 .53813 L
.06445 .53816 L
.06448 .53824 L
.06449 .53831 L
.06449 .53837 L
.06449 .53842 L
.06449 .53849 L
.06449 .53858 L
.06448 .53867 L
.06448 .53874 L
.06448 .53878 L
.06448 .53875 L
.06448 .53865 L
.06449 .53846 L
.0645 .53817 L
.06451 .5378 L
.06453 .53736 L
.06455 .53688 L
.06456 .53637 L
.06458 .53587 L
.0646 .53538 L
.06462 .53489 L
.06463 .53443 L
.06465 .53406 L
.06466 .53379 L
.06466 .53365 L
.06466 .5336 L
.06466 .5336 L
.06467 .53362 L
.06469 .53362 L
.06471 .53354 L
.06472 .53335 L
.06472 .53302 L
.0647 .53257 L
.06467 .53203 L
.06464 .53141 L
.06461 .53077 L
.06458 .53009 L
.06456 .5294 L
.06456 .52871 L
.06456 .52806 L
.06458 .52749 L
.06459 .52702 L
.06461 .52665 L
.06463 .52638 L
.06466 .52621 L
.06471 .52612 L
.06476 .52609 L
.06482 .52608 L
Mistroke
.06488 .52609 L
.06492 .52612 L
.06496 .52615 L
.06498 .52619 L
.06497 .52623 L
.06495 .52624 L
.06493 .52624 L
.06494 .52623 L
.06497 .5262 L
.06504 .52616 L
.06512 .52614 L
.06516 .52615 L
.06513 .5262 L
.06502 .52629 L
Mfstroke
.07265 .46017 m
.07276 .46027 L
.07283 .46034 L
.07285 .46037 L
.07283 .46038 L
.07279 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07267 .46038 L
.07264 .46038 L
.0726 .46038 L
.07256 .46038 L
.07254 .46038 L
.07255 .46038 L
.07261 .46038 L
.07272 .46038 L
.07288 .46038 L
.07309 .46037 L
.07333 .46037 L
.0736 .46036 L
.07388 .46036 L
.07416 .46036 L
.07444 .46035 L
.07471 .46035 L
.07497 .46034 L
.07519 .46034 L
.07537 .46034 L
.07549 .46033 L
.07556 .46033 L
.07558 .46033 L
.07556 .46033 L
.07552 .46033 L
.07548 .46033 L
.07544 .46034 L
.07543 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07543 .46033 L
.07544 .4603 L
.07549 .46022 L
.07558 .46011 L
.07566 .46001 L
.07569 .45997 L
.07567 .46001 L
.07556 .46017 L
.07535 .46046 L
.07502 .46091 L
.07458 .46151 L
.07405 .46222 L
.07349 .46301 L
.07291 .46381 L
.07235 .46458 L
.07182 .46533 L
.07128 .46604 L
.07075 .46669 L
.07026 .46719 L
.06987 .46748 L
.0696 .4675 L
.06944 .46725 L
.06937 .46677 L
.06941 .46614 L
.06954 .46542 L
Mistroke
.06973 .46465 L
.06993 .4639 L
.07014 .46315 L
.07034 .46243 L
.07053 .46169 L
.07069 .46095 L
.0708 .46026 L
.07087 .45969 L
.07089 .45927 L
.07089 .45902 L
.07086 .4589 L
.0708 .45881 L
.07071 .45874 L
.07061 .45864 L
.07053 .45853 L
.07048 .45839 L
.07048 .45825 L
.07052 .45813 L
.07061 .45803 L
.07075 .45795 L
.07087 .45789 L
.07101 .45775 L
.07112 .45754 L
.07117 .45728 L
.0712 .45695 L
.07122 .45665 L
.07124 .45643 L
.07125 .45631 L
.07127 .45633 L
Mfstroke
.09276 .42384 m
.09278 .42375 L
.09282 .42378 L
.09287 .42391 L
.09291 .4241 L
.09294 .42429 L
.09296 .42443 L
.09294 .42448 L
.09291 .4244 L
s
.10352 .33575 m
.10368 .33587 L
.10384 .33596 L
.10395 .33606 L
.104 .33613 L
.10397 .33614 L
.10389 .33607 L
s
.22263 .14106 m
.22267 .1411 L
.22256 .14121 L
.22234 .14132 L
.22199 .14143 L
.22155 .1415 L
.22104 .14155 L
.22049 .14157 L
.21993 .14155 L
.21938 .14154 L
.21885 .14152 L
.21831 .1415 L
.2178 .14148 L
.21733 .14147 L
.21696 .14145 L
.2167 .14145 L
.21658 .14145 L
.21657 .14147 L
s
.46055 .04902 m
.46059 .04902 L
.4605 .04902 L
.46035 .04901 L
.46021 .04901 L
.46016 .04901 L
s
.58803 .05232 m
0 0 rlineto s
.84847 .21047 m
.84858 .21058 L
.84862 .21061 L
.84858 .21055 L
.84848 .21043 L
s
.80167 .1448 m
.80167 .14472 L
.80181 .14482 L
.80201 .14501 L
.80222 .14523 L
.80238 .14542 L
.80245 .14552 L
.80241 .14547 L
s
.78954 .13664 m
.78961 .13674 L
.78962 .13679 L
.78959 .13681 L
.78953 .13679 L
.78946 .13676 L
.78939 .13672 L
.78935 .13669 L
.78933 .13667 L
.78931 .13664 L
.78925 .13657 L
.78915 .13645 L
.78903 .13632 L
.78891 .13621 L
.78882 .13615 L
.78882 .13618 L
s
.35403 .9199 m
.35411 .91987 L
.35429 .91989 L
.35448 .91994 L
.3546 .91998 L
s
.06241 .51624 m
.06245 .5162 L
.06249 .51628 L
.06252 .51642 L
.06253 .51658 L
.06252 .5167 L
.06252 .51675 L
s
.067 .46688 m
.06701 .46677 L
.06701 .46665 L
.06702 .46647 L
.06703 .46619 L
.06704 .46581 L
.06705 .46533 L
.06706 .46474 L
.06705 .46409 L
.06703 .46341 L
.06701 .46276 L
.06701 .46221 L
.06703 .46177 L
.06708 .46147 L
.06716 .46132 L
.06728 .46129 L
.06744 .46139 L
.06766 .46158 L
.06793 .46185 L
.06827 .46215 L
.06866 .46244 L
.06909 .46265 L
.06955 .46279 L
.07004 .46278 L
.07054 .46258 L
.07102 .46225 L
.07144 .46175 L
.07182 .46114 L
.07214 .46047 L
.07239 .45982 L
.07257 .45927 L
.07267 .45884 L
.07273 .45859 L
.07275 .45848 L
s
.09596 .31658 m
.09596 .31646 L
.09595 .31643 L
.09594 .31646 L
.09594 .31651 L
.09594 .31656 L
.09593 .31661 L
.09593 .31665 L
.09593 .31669 L
.09593 .31672 L
.09593 .31674 L
.09593 .31674 L
.09593 .31675 L
.09591 .31678 L
.09588 .31683 L
.09583 .31691 L
.09579 .31698 L
.09576 .31704 L
.09575 .31706 L
.09579 .31702 L
.0959 .31689 L
.09608 .31664 L
.09631 .31626 L
.09658 .31575 L
.09687 .3151 L
.09719 .31435 L
.09753 .31356 L
.0979 .31274 L
.09827 .31192 L
.09865 .31107 L
.09905 .31021 L
.0994 .3094 L
.09975 .30861 L
.10012 .30786 L
.10047 .30715 L
.10079 .30649 L
.10113 .3059 L
.1015 .30537 L
.1019 .30488 L
.10233 .30444 L
.10274 .30403 L
.10312 .30365 L
.10347 .30329 L
.10378 .30295 L
.10403 .30267 L
.10422 .30248 L
.10435 .30237 L
.10444 .30234 L
.1045 .30238 L
.10451 .30245 L
Mistroke
.1045 .30252 L
.10445 .30258 L
.10441 .30261 L
.10437 .30261 L
.10436 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30261 L
.10435 .30258 L
.10435 .30253 L
.10436 .30246 L
.10436 .30239 L
.10436 .30235 L
.10436 .30237 L
.10436 .30245 L
.10435 .30264 L
.10434 .30292 L
.10434 .30328 L
.10433 .30369 L
.10432 .30414 L
.10431 .30462 L
.1043 .3051 L
.10429 .30556 L
.10428 .30601 L
.10428 .30643 L
.10427 .3068 L
.10426 .30711 L
.10426 .30735 L
.10426 .30748 L
.10425 .30753 L
.10424 .30751 L
.10421 .30745 L
.10416 .30738 L
.10412 .30733 L
.1041 .30732 L
.10411 .3073 L
.10416 .30726 L
.10425 .30719 L
.10438 .30713 L
.10454 .3071 L
.10474 .30712 L
.10498 .30721 L
.10529 .30743 L
.10567 .30777 L
.10609 .30822 L
.10654 .30873 L
Mistroke
.107 .30924 L
.10742 .30971 L
.10778 .3101 L
.10806 .3104 L
.10823 .3106 L
.1083 .31069 L
.10828 .31065 L
.10818 .31049 L
.10804 .31022 L
.10788 .30987 L
.10769 .30948 L
.10749 .30905 L
.10731 .30859 L
.10717 .30813 L
.10712 .30773 L
.10721 .3074 L
.10748 .30709 L
.10795 .30678 L
.10859 .30645 L
.10935 .3061 L
.11024 .30573 L
.11122 .30531 L
.11216 .30488 L
.11314 .30444 L
.11407 .30402 L
.11493 .30362 L
.11576 .30326 L
.11642 .30295 L
.11699 .3027 L
.11745 .30248 L
.11779 .30231 L
.11801 .30216 L
.11813 .30202 L
.11815 .30187 L
.11811 .30168 L
.11805 .30147 L
.11798 .30122 L
.11792 .30098 L
.11788 .30076 L
.11787 .30057 L
.11787 .30042 L
.11787 .30032 L
.11787 .30026 L
.11787 .30024 L
.11787 .30026 L
.11787 .3003 L
.11785 .30036 L
.11781 .30045 L
.11774 .30054 L
.11766 .30065 L
Mistroke
.11761 .30075 L
.11759 .30083 L
.11764 .30086 L
.11776 .30082 L
Mfstroke
.19108 .17548 m
.19108 .17535 L
.19103 .17533 L
.19096 .17535 L
.19092 .17535 L
.19095 .17529 L
s
.20946 .14838 m
.20944 .14829 L
.20939 .14822 L
.20934 .14818 L
.20929 .14815 L
.20926 .14812 L
.20924 .1481 L
.20924 .14808 L
.20924 .14807 L
.20924 .14808 L
.20923 .14812 L
.20922 .14815 L
.20918 .14816 L
.20912 .14818 L
.20905 .1482 L
.20898 .14826 L
.20893 .14834 L
.20891 .14842 L
.20896 .14848 L
.20908 .14848 L
s
.28809 .1057 m
.2882 .10571 L
.28827 .10588 L
.2883 .10614 L
.2883 .10647 L
.28828 .10685 L
.28824 .10725 L
.2882 .10762 L
.28816 .10795 L
.28815 .10824 L
.28815 .10843 L
.28815 .10861 L
.28815 .10875 L
.28815 .10887 L
.28815 .10893 L
.28815 .10899 L
.28815 .10902 L
.28815 .10901 L
.28815 .10897 L
.28815 .10892 L
.28815 .10885 L
.28815 .10877 L
.28815 .10866 L
.28815 .10855 L
.28815 .10846 L
.28815 .10839 L
.28815 .10835 L
.28815 .10837 L
.28815 .10843 L
.28815 .10853 L
.28815 .10862 L
.28815 .10869 L
.28815 .10877 L
.28815 .10885 L
.28815 .10892 L
.28815 .109 L
.28815 .10906 L
.28815 .1091 L
.28815 .10911 L
.28815 .10909 L
.28815 .10904 L
.28815 .10896 L
.28815 .10887 L
.28815 .10878 L
.28815 .1087 L
.28815 .10862 L
.28815 .10854 L
.28815 .10846 L
.28815 .1084 L
.28816 .10836 L
Mistroke
.28818 .10834 L
.2882 .10835 L
.2882 .10838 L
.28819 .10845 L
.28815 .10852 L
.2881 .10859 L
.28804 .10866 L
.28797 .10872 L
.28791 .10877 L
.28786 .10881 L
.28782 .10887 L
.2878 .10897 L
.28779 .10905 L
.28779 .10913 L
.28779 .10918 L
.28781 .10919 L
.28784 .10919 L
.28789 .10919 L
.28795 .10924 L
.28802 .10932 L
.28809 .10942 L
.28814 .10951 L
.28819 .10955 L
.28821 .10952 L
.2882 .10941 L
.28818 .10918 L
.28816 .10885 L
.28815 .10844 L
.28815 .10801 L
.28815 .10764 L
.28815 .10732 L
.28815 .10705 L
.28815 .10682 L
.28815 .10663 L
.28815 .10648 L
.28815 .10635 L
.28815 .10626 L
.28815 .1062 L
.28815 .10618 L
.28815 .10619 L
.28815 .10621 L
.28815 .10622 L
.28815 .10616 L
.28815 .10603 L
.28815 .10579 L
.28815 .10557 L
.28815 .10532 L
.28815 .10511 L
.28815 .10498 L
.28815 .10492 L
Mistroke
.28815 .10494 L
.28815 .10498 L
.28815 .10503 L
.28815 .10506 L
.28815 .10508 L
.28815 .10511 L
.28815 .10512 L
.28815 .1051 L
.28815 .10501 L
.28815 .10488 L
.28815 .10473 L
.28815 .10461 L
.28815 .10455 L
.28815 .1046 L
.28815 .10474 L
.28815 .105 L
.28815 .10535 L
.28815 .10578 L
.28815 .10624 L
.28815 .1067 L
.28815 .10716 L
.28815 .10761 L
.28815 .10806 L
.28815 .10849 L
.28815 .10888 L
.28815 .10918 L
.28815 .10938 L
.28815 .10949 L
.28815 .10953 L
.28815 .1095 L
.28815 .10943 L
.28815 .10936 L
.28815 .1093 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
Mistroke
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10927 L
.28815 .10928 L
.28815 .10929 L
.28815 .1093 L
.28815 .1093 L
.28815 .10929 L
.28815 .10929 L
.28815 .10931 L
.28815 .10934 L
.28815 .10937 L
.28815 .10936 L
.28815 .1093 L
.28815 .10916 L
.28815 .10894 L
.28816 .10862 L
.28818 .10826 L
.28822 .10782 L
.28824 .10737 L
.28823 .10695 L
.28818 .10657 L
.28811 .10619 L
.28801 .10584 L
.2879 .10553 L
.28779 .10528 L
.28769 .10508 L
Mistroke
.28761 .10493 L
.28756 .10483 L
.28753 .1048 L
.28752 .10482 L
.28753 .1049 L
.28754 .10497 L
.28759 .10499 L
.28766 .10496 L
.28776 .10489 L
.28787 .10481 L
.28799 .10473 L
.28809 .10466 L
.28818 .10461 L
.28823 .10458 L
.28825 .10459 L
.28823 .10462 L
.28819 .10464 L
.28818 .10463 L
.2882 .10458 L
.28824 .1045 L
.28827 .10444 L
.28829 .10441 L
.28828 .10443 L
.28822 .10453 L
.28812 .10472 L
.28797 .10499 L
.28776 .10535 L
.28751 .10581 L
.28722 .10633 L
.28692 .10687 L
.28664 .10736 L
.28639 .10778 L
.28618 .10812 L
.28605 .10837 L
.28598 .1085 L
Mfstroke
.38893 .05069 m
.38903 .05061 L
s
.46295 .04679 m
.46285 .04673 L
.46278 .04671 L
.46275 .04672 L
.46272 .04674 L
.46267 .04675 L
.46258 .04674 L
.46247 .04672 L
.46236 .0467 L
.46228 .04671 L
.46227 .04676 L
s
.49796 .05924 m
.49781 .05933 L
.49774 .05936 L
.49776 .05933 L
.49783 .05927 L
.49792 .05922 L
.498 .05922 L
.49807 .05927 L
.49811 .05933 L
.49812 .05936 L
.49811 .05934 L
.49806 .05925 L
.49797 .05907 L
.49783 .05881 L
.49765 .05846 L
.49745 .05805 L
.49722 .05761 L
.49698 .05714 L
.49673 .05669 L
.49649 .05624 L
.49625 .0558 L
.49604 .05538 L
.49585 .055 L
.4957 .0547 L
.4956 .05449 L
.49554 .05437 L
.49552 .05434 L
.49553 .05436 L
.49557 .05442 L
.49561 .0545 L
.49564 .05455 L
.49565 .05457 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49566 .05458 L
.49569 .05458 L
.49574 .05458 L
.49582 .05458 L
.49589 .05459 L
.49597 .05459 L
.49604 .05459 L
.49607 .05461 L
.49603 .05466 L
s
.37458 .05516 m
.37459 .05503 L
.37454 .05493 L
.37442 .05487 L
s
.15113 .24549 m
0 0 rlineto s
.08265 .40069 m
.08273 .40077 L
.08281 .40072 L
.08287 .4006 L
.0829 .40046 L
.0829 .40032 L
.08288 .4002 L
.08285 .40013 L
.08283 .40009 L
.08281 .40008 L
.08275 .40007 L
.08267 .40004 L
.08256 .4 L
.08246 .39993 L
.08242 .39985 L
.08247 .39976 L
s
.0897 .43611 m
.08971 .43612 L
.08978 .43603 L
.08988 .43593 L
s
.06636 .48478 m
.06637 .48492 L
.06637 .485 L
.06637 .48502 L
.06637 .48498 L
.06638 .48491 L
.06638 .48486 L
.06638 .48485 L
.06638 .48491 L
.06637 .48497 L
.06637 .48501 L
.06637 .48499 L
.06638 .48489 L
.06639 .48469 L
.0664 .48441 L
.06641 .48405 L
.06642 .48362 L
.06644 .48316 L
.06646 .48269 L
.06647 .48223 L
.06649 .48177 L
.06651 .4813 L
.06652 .48084 L
.06653 .4804 L
.06654 .48002 L
.06652 .47973 L
.0665 .47952 L
.06649 .47939 L
.06649 .47928 L
s
.07003 .45925 m
.07002 .4592 L
.07001 .45925 L
.06999 .45936 L
.06995 .4595 L
.06991 .45961 L
.06986 .45975 L
.06983 .45991 L
.06984 .46009 L
.06989 .46026 L
.07 .46039 L
.07016 .46044 L
.07037 .46038 L
.07062 .4602 L
.07089 .4599 L
.07119 .45955 L
.07149 .45908 L
.07178 .45857 L
.07207 .45806 L
.07234 .4576 L
.07257 .45713 L
.07276 .45669 L
.0729 .45628 L
.07298 .45593 L
.07301 .45564 L
.073 .45543 L
.07296 .4553 L
.07292 .45526 L
.07288 .4553 L
.07286 .45537 L
.07286 .45545 L
.07288 .45552 L
.07293 .45558 L
.07301 .45562 L
.07308 .45566 L
.07312 .45567 L
.07309 .45566 L
.07299 .45561 L
.07279 .45552 L
.07248 .45538 L
.07206 .4552 L
.07157 .45499 L
.07104 .45476 L
.0705 .45452 L
.06997 .45428 L
.06946 .45403 L
.06895 .4538 L
.06845 .45358 L
.06799 .45339 L
.06763 .45324 L
Mistroke
.06738 .45314 L
.06725 .45308 L
.0672 .45306 L
.06722 .45308 L
.06729 .45311 L
.06738 .45315 L
.06744 .45318 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06747 .4532 L
.06745 .45318 L
.06742 .45316 L
.06737 .45312 L
.06733 .45308 L
.0673 .45306 L
.06728 .45308 L
.0673 .45313 L
.06738 .45323 L
.06752 .45337 L
.06773 .45355 L
.06803 .45376 L
.0684 .45399 L
.06883 .45423 L
.0693 .45448 L
.06981 .45472 L
.07033 .45496 L
.07086 .45517 L
.07136 .45536 L
.0718 .45551 L
.07219 .45561 L
.07251 .45567 L
.07276 .45568 L
.07292 .45567 L
.07301 .45563 L
.07304 .45559 L
.07304 .45555 L
.07301 .45554 L
.07296 .45554 L
.07292 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45553 L
Mistroke
.07286 .45551 L
.07286 .45545 L
.07286 .45538 L
.07286 .4553 L
.07287 .45527 L
.07286 .45529 L
.07286 .4554 L
.07285 .45559 L
.07284 .45588 L
.07283 .45624 L
.07282 .45667 L
.0728 .45715 L
.07278 .45765 L
.07277 .45814 L
.07275 .45864 L
.07273 .45912 L
.07272 .45958 L
.07273 .46 L
.07277 .46036 L
.07285 .46065 L
.07292 .46084 L
.07294 .46092 L
.07291 .46086 L
.0728 .46069 L
.0726 .46043 L
.07228 .46009 L
.07186 .4597 L
.07135 .45927 L
.07078 .4588 L
.07018 .45831 L
.06962 .45782 L
.06911 .45734 L
.06861 .45686 L
.06817 .45642 L
.06782 .45603 L
.06763 .45572 L
.06761 .4555 L
.06774 .45538 L
.06797 .45533 L
.06829 .45536 L
.06865 .45542 L
.06902 .4555 L
.06937 .45556 L
.06965 .45558 L
.06988 .45558 L
.07006 .45558 L
.07018 .45558 L
.07026 .45558 L
.07028 .45558 L
.07027 .45558 L
Mistroke
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45555 L
.07013 .45549 L
.07013 .45542 L
.07013 .45535 L
.07013 .45531 L
.07011 .45534 L
.07008 .45544 L
.07003 .45563 L
.06998 .45592 L
.06995 .45629 L
.06995 .45672 L
.06999 .45719 L
.07008 .45769 L
.07023 .45818 L
.07042 .45867 L
.07064 .45915 L
.0709 .4596 L
.07116 .45998 L
.07143 .46029 L
.07171 .46051 L
.07197 .46063 L
.07223 .46066 L
.07245 .46063 L
.07263 .46056 L
.07275 .46047 L
.07283 .46041 L
.07285 .46038 L
.07283 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46037 L
.07267 .46035 L
.07264 .46029 L
.0726 .46022 L
Mistroke
.07257 .46015 L
.07255 .46011 L
.07256 .46014 L
.07262 .46024 L
.07272 .46043 L
.07287 .46071 L
.07306 .46108 L
.07329 .4615 L
.07354 .46197 L
.07381 .46247 L
.07407 .46296 L
.07434 .46345 L
.07459 .46393 L
.07483 .46437 L
.07504 .46476 L
.0752 .46507 L
.07532 .46529 L
.07539 .46541 L
.07541 .46545 L
.07539 .46542 L
.07535 .46535 L
.07531 .46527 L
.07528 .46521 L
.07526 .46518 L
.07526 .46517 L
.07527 .46511 L
.07528 .46499 L
.07529 .46482 L
.0753 .46465 L
.07532 .46451 L
.07535 .46445 L
.07539 .46451 L
Mfstroke
.05995 .5166 m
.05994 .51646 L
.0599 .51637 L
.05986 .51629 L
.05983 .51619 L
.05981 .51605 L
.05982 .51586 L
.05983 .51562 L
.05983 .51538 L
.05984 .51518 L
.05985 .51502 L
.05985 .51492 L
.05985 .51487 L
.05985 .51489 L
s
.09172 .71681 m
0 0 rlineto s
.12355 .7529 m
.12362 .75288 L
.12358 .75281 L
s
.09387 .72866 m
.09389 .72879 L
.09393 .72884 L
.09396 .72883 L
.09396 .72876 L
.09393 .72866 L
.09389 .72856 L
.09387 .72851 L
.09389 .72854 L
.09394 .72864 L
.09404 .72882 L
.0942 .7291 L
.09439 .72947 L
.09462 .72991 L
.09486 .73039 L
.09509 .7309 L
.09532 .7314 L
.09555 .7319 L
.09579 .73239 L
.09605 .73284 L
.09632 .73324 L
.0966 .73355 L
.09688 .73377 L
.09715 .73389 L
.09741 .73392 L
.09767 .73388 L
.09791 .7338 L
.09814 .7337 L
.09839 .73363 L
.09865 .73359 L
.09889 .73357 L
.09911 .73356 L
.09927 .73356 L
.09935 .73355 L
.09938 .73355 L
.09935 .73355 L
.0993 .73353 L
.09924 .73346 L
.0992 .73334 L
.0992 .73323 L
.09929 .73317 L
s
.10972 .74569 m
.10967 .74583 L
.10964 .74593 L
.10967 .74606 L
s
.46015 .94941 m
.46015 .94938 L
.46003 .94937 L
.45986 .94938 L
.45971 .94937 L
.45963 .94932 L
.45964 .94924 L
.45972 .94916 L
.45976 .94912 L
.45974 .94915 L
s
.08618 .69578 m
.08613 .69593 L
.08626 .69616 L
.08653 .69647 L
.0869 .69681 L
.08731 .69715 L
.08771 .69747 L
.08806 .69776 L
.08838 .69802 L
.08866 .69827 L
.08891 .69849 L
.08912 .69868 L
.08929 .69884 L
.08941 .69895 L
.08948 .69901 L
.0895 .69903 L
.08948 .69901 L
.08944 .69897 L
.0894 .69893 L
.08936 .6989 L
.08934 .69889 L
.08934 .69888 L
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .69901 L
.08934 .69903 L
.08934 .69902 L
.08934 .69896 L
.08934 .69887 L
.08934 .69875 L
s
.58564 .057 m
.58571 .057 L
.58567 .05699 L
.5857 .05698 L
s
.88908 .26946 m
.88894 .26939 L
.8889 .26941 L
.88893 .26948 L
.889 .26959 L
.88908 .2697 L
.88916 .26978 L
.88922 .26984 L
.88925 .26988 L
.88926 .26991 L
.88926 .26995 L
.88926 .26998 L
.88928 .27002 L
.8893 .27006 L
.88934 .27008 L
.88937 .27005 L
.88939 .26994 L
.88938 .26972 L
.88933 .26939 L
.88923 .26897 L
.88908 .2685 L
.88889 .26805 L
.88867 .26763 L
.88842 .26723 L
.88817 .26687 L
.88792 .26653 L
.88768 .2662 L
.88745 .26587 L
.88725 .26556 L
.88707 .26526 L
.88693 .26501 L
.88684 .26479 L
.88679 .26462 L
.88679 .26449 L
.88683 .26436 L
.88689 .26426 L
.88695 .26421 L
.887 .26422 L
s
.91149 .30632 m
.91156 .3064 L
.91154 .30646 L
s
.76494 .12322 m
.76486 .12313 L
.76493 .12309 L
.76512 .1231 L
.76541 .12316 L
.76576 .12325 L
.76615 .12339 L
.76656 .12356 L
.76701 .12375 L
.7675 .12397 L
.76806 .12419 L
.76867 .12442 L
.76932 .12464 L
.76998 .12484 L
.77066 .12503 L
.77132 .12523 L
.77195 .12544 L
.77252 .12565 L
.773 .12585 L
.77338 .12603 L
.77368 .12619 L
.77388 .12631 L
.774 .12642 L
.77404 .12649 L
.77401 .12652 L
s
.50948 .05058 m
.50942 .05042 L
.50939 .05022 L
.50936 .04999 L
.5093 .04975 L
.50924 .04951 L
.50924 .04928 L
.50932 .04905 L
.50948 .04883 L
.5097 .04863 L
.50999 .04846 L
.5103 .04831 L
.51064 .04821 L
.51101 .04816 L
.51141 .04816 L
.51186 .0482 L
.51237 .04827 L
.51293 .04835 L
.51355 .04843 L
.51419 .04849 L
.51483 .04854 L
.51546 .04858 L
.51608 .04861 L
.5167 .04864 L
.51727 .04865 L
.5178 .04867 L
.51827 .04867 L
.51864 .04866 L
.5189 .04863 L
.51902 .04858 L
s
.31342 .0871 m
.31346 .08714 L
.31337 .08717 L
s
.21609 .14649 m
.21623 .14653 L
.21643 .1465 L
.21662 .14643 L
.21677 .14635 L
.21687 .14626 L
.21694 .14619 L
.21697 .14613 L
.21698 .1461 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21698 .14609 L
.21699 .14609 L
.21702 .1461 L
.21711 .1461 L
.21723 .1461 L
.21735 .14611 L
.2174 .14611 L
.21736 .14611 L
.21719 .1461 L
.21688 .14609 L
.21643 .14608 L
.21584 .14606 L
.21514 .14603 L
.21437 .14599 L
.21353 .14594 L
.21271 .14587 L
.21191 .14578 L
.21116 .14569 L
.2105 .1456 L
.20997 .14554 L
.20961 .14553 L
.20944 .14561 L
s
.19041 .18014 m
.19029 .18027 L
.19002 .18044 L
.18965 .18063 L
.18921 .18085 L
.18873 .18108 L
.18817 .1813 L
.18759 .18153 L
.18697 .18174 L
.18634 .18194 L
.18576 .18212 L
.18526 .18228 L
.18486 .18241 L
.18457 .1825 L
.1844 .18253 L
.18436 .18251 L
.18446 .18244 L
.18475 .18234 L
s
.19905 .17667 m
.19907 .17681 L
.19903 .17694 L
.19888 .17709 L
.19859 .17726 L
.19817 .17747 L
.19759 .17772 L
.19687 .178 L
.19602 .17827 L
.19513 .17851 L
.19417 .17878 L
.19316 .17906 L
.19215 .17935 L
.19117 .17966 L
.19032 .17996 L
.18958 .18018 L
.189 .1803 L
.18863 .18033 L
.1884 .18029 L
.18827 .18021 L
.1882 .18013 L
.18814 .18008 L
.18801 .18005 L
.18778 .18003 L
.18746 .18002 L
.18705 .18001 L
.18656 .17999 L
.18603 .17998 L
.18547 .17996 L
.18494 .17994 L
.18445 .17993 L
.18391 .17991 L
.18341 .17989 L
.183 .17985 L
.18273 .17981 L
.1826 .17977 L
.18262 .17976 L
s
.07994 .40085 m
.07998 .40086 L
.08003 .40076 L
.08007 .4006 L
.08009 .40042 L
.0801 .40027 L
.0801 .40016 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
.0802 .40006 L
.08028 .40002 L
.08036 .39998 L
.08039 .39996 L
.08036 .39998 L
.08024 .40003 L
.08002 .40013 L
.07967 .40029 L
.0792 .40051 L
.07864 .40076 L
.07804 .40104 L
.07745 .40131 L
.07692 .40155 L
.07644 .40176 L
.07601 .40191 L
.07565 .40199 L
.0754 .402 L
.07529 .40194 L
.07533 .40181 L
.07549 .40163 L
.07575 .40139 L
Mistroke
.07608 .40112 L
.07644 .40084 L
.0768 .40057 L
.07707 .40035 L
.07724 .40017 L
.07732 .40006 L
.07737 .4 L
.0774 .39998 L
.07742 .39998 L
.07745 .39999 L
.07752 .39999 L
Mfstroke
.07299 .45316 m
.07287 .45306 L
.0728 .453 L
.07278 .45298 L
.0728 .45299 L
.07284 .45303 L
.07288 .45307 L
.07292 .4531 L
.07293 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07295 .45312 L
.07299 .45312 L
.07308 .45315 L
.07321 .4532 L
.07334 .45328 L
.07338 .45335 L
.0733 .45339 L
s
.06881 .41224 m
.06882 .41213 L
.06882 .41207 L
.06882 .41205 L
.06882 .41207 L
.06882 .4121 L
.06882 .41215 L
.06881 .41218 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06881 .41219 L
.06882 .41216 L
.06882 .41209 L
.06882 .41199 L
.06883 .41188 L
.06883 .41184 L
.06883 .41187 L
.06882 .41201 L
.06881 .41228 L
.0688 .41269 L
.06878 .41323 L
.06876 .41388 L
.06874 .41459 L
.06872 .41533 L
.06871 .41602 L
.06872 .41665 L
.06874 .41726 L
.06876 .41788 L
.06876 .41846 L
.06873 .41896 L
.06866 .41939 L
.06854 .41976 L
.06837 .42011 L
.06815 .42045 L
.0679 .42079 L
.06762 .42114 L
.06732 .42155 L
.06703 .42202 L
Mistroke
.06674 .42252 L
.06645 .42301 L
.06618 .42347 L
.06596 .42384 L
.06581 .42407 L
.06572 .42417 L
.06569 .42418 L
.06569 .42417 L
.0657 .42416 L
.06567 .42423 L
.0656 .42442 L
.06546 .42479 L
.06525 .42532 L
.06496 .42597 L
.06463 .42669 L
.06427 .42744 L
.06393 .42815 L
.06361 .42885 L
.06332 .42954 L
.0631 .43022 L
.06297 .43083 L
.06294 .43132 L
.06304 .43162 L
.06325 .43175 L
.06355 .43173 L
.0639 .43162 L
.06425 .43148 L
.06457 .43137 L
.06484 .43135 L
.06501 .43144 L
.06508 .43164 L
.06504 .43194 L
.0649 .43233 L
.06469 .43284 L
.0644 .43346 L
.06408 .43418 L
.06374 .43495 L
.06338 .43578 L
.06306 .43666 L
.06278 .43753 L
.06257 .43836 L
.06242 .43911 L
.06232 .43979 L
.06227 .44039 L
.06227 .44088 L
.0623 .44124 L
.06234 .44146 L
.06237 .44155 L
.06237 .4415 L
.06235 .44131 L
Mistroke
.06232 .44099 L
.06229 .44053 L
.06229 .43996 L
.06233 .43929 L
.06241 .43856 L
.06255 .43779 L
.06276 .43698 L
.06303 .43618 L
.06335 .4354 L
.06369 .43465 L
.06402 .43395 L
.06431 .43331 L
.06455 .4327 L
.06474 .43214 L
.06485 .43162 L
.06489 .43111 L
.06484 .43057 L
.06471 .42998 L
.06451 .42933 L
.06427 .42866 L
.064 .42794 L
.0637 .42716 L
.06342 .42628 L
.06319 .42529 L
.06301 .42429 L
.06289 .42324 L
.06281 .42216 L
.06278 .42115 L
.0628 .42014 L
.06289 .41912 L
.06302 .4181 L
.06319 .41711 L
.0634 .41623 L
.06363 .41539 L
.0639 .41466 L
.06419 .41402 L
.06449 .41349 L
.06478 .41303 L
.06507 .41265 L
.06536 .41235 L
.06562 .41214 L
.06585 .41202 L
.06603 .41198 L
.06615 .412 L
.0662 .41203 L
.06619 .41206 L
.06613 .4121 L
.06605 .41214 L
.06596 .41219 L
.06591 .41223 L
Mistroke
.06591 .41226 L
.06597 .41229 L
.06609 .41232 L
.06628 .41235 L
.06654 .41237 L
.06687 .41239 L
.06728 .41239 L
.06775 .41239 L
.06828 .41239 L
.06889 .41237 L
.06958 .41235 L
.07031 .41233 L
.07106 .41229 L
.07184 .41225 L
.07262 .41221 L
.07336 .41217 L
.07405 .41213 L
.07471 .4121 L
.07534 .41206 L
.07594 .41202 L
.07646 .41197 L
.07686 .41191 L
.07712 .41185 L
.0772 .41183 L
Mfstroke
.06216 .44408 m
.06214 .44411 L
.06217 .44401 L
.06221 .44381 L
.06227 .44356 L
.06231 .4433 L
.06234 .44306 L
.06235 .44281 L
.06236 .44255 L
.06236 .4423 L
.06237 .44205 L
.06238 .4418 L
.06239 .44158 L
.0624 .44138 L
.0624 .44123 L
.0624 .44112 L
.06241 .44106 L
.06241 .44104 L
.06241 .44106 L
.0624 .44109 L
.0624 .44113 L
.0624 .44117 L
.0624 .44118 L
.0624 .44118 L
.0624 .44116 L
.06241 .4411 L
.06241 .441 L
.06241 .44089 L
.06242 .44083 L
.06241 .44085 L
.06241 .44098 L
.0624 .44123 L
.06238 .44159 L
.06237 .44207 L
.06235 .44266 L
.06233 .44331 L
.06231 .444 L
.06228 .44471 L
.06226 .44536 L
.06222 .44603 L
.06216 .44669 L
.06209 .44737 L
.06202 .44784 L
.06195 .44821 L
.06189 .44839 L
.06188 .44844 L
.06194 .44842 L
s
.06958 .47348 m
.06955 .47354 L
.06959 .47345 L
.06965 .47322 L
.06971 .47295 L
.06972 .47255 L
.06968 .47203 L
.06957 .47138 L
.06941 .4706 L
.06924 .4697 L
.06907 .46873 L
.06895 .46767 L
.06887 .46655 L
.06885 .46544 L
.06887 .4643 L
.06889 .4632 L
.06892 .46226 L
.06897 .46141 L
.06904 .46065 L
.06914 .45997 L
.06928 .45939 L
.06945 .45892 L
.06962 .45853 L
.06975 .45824 L
.06985 .45803 L
.06987 .45788 L
.06982 .45774 L
.06973 .45761 L
.06965 .45748 L
.0696 .45733 L
.06959 .45718 L
.06961 .45702 L
.06965 .45688 L
.0697 .45675 L
.06974 .45659 L
.06978 .45656 L
.0698 .45638 L
.06982 .4562 L
.06986 .45604 L
.06992 .45589 L
.06999 .45575 L
.07006 .45562 L
.07012 .45552 L
.07017 .45547 L
.07019 .45547 L
.07018 .4555 L
.07016 .45552 L
.07014 .45554 L
.07014 .45558 L
.07017 .45562 L
Mistroke
.07021 .45566 L
.07025 .4557 L
.07027 .45572 L
.07026 .45571 L
.0702 .45565 L
.07009 .45556 L
.06993 .45542 L
.06973 .45524 L
.06949 .45502 L
.06921 .45477 L
.0689 .4545 L
.06858 .45421 L
.06826 .45392 L
.06793 .45367 L
.06763 .45346 L
.06738 .45332 L
.06721 .45328 L
.06715 .45335 L
Mfstroke
.08933 .45288 m
.08944 .45288 L
.08949 .45288 L
.08951 .45288 L
.08949 .45287 L
.08945 .45286 L
.08941 .45283 L
.08936 .45279 L
.08933 .45276 L
.08932 .45274 L
.08931 .45274 L
.08931 .45277 L
.08931 .45281 L
.08931 .45287 L
.08931 .45299 L
s
.08642 .47198 m
.08639 .47187 L
s
.08202 .67227 m
.08197 .6723 L
.08194 .67222 L
.08193 .67207 L
.08193 .67189 L
.08193 .67174 L
.08194 .67168 L
.08194 .67167 L
.08194 .67166 L
.08194 .67161 L
.08194 .67151 L
.08194 .67138 L
.08195 .67126 L
.08195 .67116 L
.08194 .67113 L
.0819 .67122 L
s
.08413 .68694 m
.08421 .6869 L
.08424 .68677 L
.08424 .68663 L
.08421 .68651 L
.0842 .68645 L
.08421 .6865 L
s
.14681 .68894 m
.14689 .6888 L
.14685 .68878 L
.14676 .68885 L
.14663 .68896 L
.14648 .68908 L
.14635 .68917 L
.14629 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14628 .68921 L
.14626 .68922 L
.14623 .68925 L
.14618 .68931 L
.14614 .6894 L
.1461 .68949 L
.14608 .6896 L
.14609 .68972 L
.14616 .68981 L
.14627 .68984 L
s
.89472 .71425 m
0 0 rlineto s
.88012 .76181 m
.88014 .76194 L
.88014 .76198 L
.88014 .76193 L
.88014 .76181 L
.88013 .76164 L
.88013 .76146 L
.88013 .76131 L
.88013 .76124 L
.88013 .76126 L
.88013 .76131 L
.88013 .76135 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88013 .76137 L
.88016 .76134 L
.88021 .76128 L
.88028 .76119 L
.88035 .76107 L
.88042 .76094 L
.88047 .7608 L
.88049 .76071 L
.88046 .76071 L
s
.85878 .79823 m
.85879 .79827 L
.85887 .79817 L
.85898 .79798 L
.8591 .79776 L
.8592 .79756 L
.85927 .79744 L
.8593 .79738 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79737 L
.85931 .79736 L
.85932 .79733 L
.85935 .79725 L
.85938 .79714 L
.85941 .79704 L
.85944 .79701 L
.85945 .79708 L
s
.85719 .79281 m
.85718 .79267 L
.85716 .79269 L
.85714 .79282 L
.85713 .79301 L
.85713 .79321 L
.85713 .79337 L
.85713 .79344 L
.85713 .79337 L
s
.85693 .77453 m
.85693 .77451 L
.85693 .77471 L
.85694 .77513 L
.85695 .77573 L
.85695 .77634 L
.85696 .77697 L
.85697 .77758 L
.85698 .77816 L
.85698 .77864 L
.85698 .77901 L
.85699 .77927 L
.85699 .77945 L
.85699 .77957 L
.85699 .77961 L
.85699 .77958 L
.85699 .77952 L
.85699 .77944 L
.85699 .77938 L
.85699 .77935 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
Mistroke
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77934 L
.85699 .77935 L
.85699 .77937 L
.85699 .77943 L
.85699 .7795 L
.85699 .77957 L
.85701 .77964 L
.85705 .77969 L
.85711 .77971 L
.85717 .77967 L
Mfstroke
.83901 .74702 m
.83894 .7469 L
.83892 .74677 L
s
.91935 .62556 m
.91932 .62548 L
.91933 .62543 L
.91939 .62536 L
.91951 .62524 L
.91972 .62502 L
.92007 .62467 L
.92053 .62416 L
.92103 .62352 L
.92153 .62281 L
.92199 .62214 L
.92237 .62153 L
.92261 .62103 L
.92269 .62069 L
.92263 .62054 L
.92245 .62057 L
.9222 .62078 L
.9219 .62114 L
.92158 .62162 L
.92122 .62223 L
.92079 .6229 L
.92032 .62359 L
.91985 .62426 L
.91945 .62483 L
.91918 .62528 L
.91902 .6256 L
.91896 .62578 L
.91896 .62584 L
.91901 .62584 L
.91904 .62582 L
.91902 .62583 L
.91896 .62591 L
.91889 .62605 L
.91886 .6262 L
.91889 .62626 L
s
.93925 .54231 m
.93923 .54247 L
.93925 .5425 L
.93928 .54244 L
.93931 .54234 L
.93933 .54226 L
.93934 .54223 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93935 .54222 L
.93934 .54224 L
.93933 .5423 L
.93931 .54241 L
.93929 .54256 L
.93926 .54272 L
.93925 .54282 L
.93926 .54281 L
s
.94097 .52494 m
.94097 .5249 L
.94096 .52496 L
.94094 .52506 L
.9409 .52515 L
.94083 .52518 L
s
.91564 .31565 m
0 0 rlineto s
.89757 .28435 m
.89758 .28439 L
.89767 .28455 L
.89783 .28483 L
.89806 .2852 L
.89834 .28565 L
.89866 .28614 L
.89903 .28662 L
.8994 .28707 L
.89978 .28748 L
.90016 .28785 L
.90056 .28819 L
.90096 .28848 L
.90136 .28874 L
.90174 .28898 L
.90209 .28921 L
.90242 .28947 L
.90273 .2898 L
.90303 .29021 L
.90331 .29071 L
.90359 .29128 L
.90387 .29194 L
.90413 .29264 L
.90437 .29334 L
.90458 .29399 L
.90475 .29457 L
.90488 .29506 L
.90494 .29542 L
.90494 .29564 L
.90488 .29575 L
.90477 .29574 L
.90465 .29565 L
.90454 .29554 L
.90447 .29547 L
.90445 .29549 L
s
.91989 .32169 m
.91998 .32174 L
.91999 .32186 L
.91993 .32207 L
.91982 .32234 L
.91969 .3226 L
.91954 .3228 L
.91941 .32289 L
.91929 .32287 L
.9192 .32273 L
.91914 .32248 L
.9191 .32213 L
.91907 .32162 L
.91905 .32098 L
.91904 .32023 L
.91906 .31939 L
.9191 .31854 L
.91916 .31771 L
.91924 .31695 L
.91933 .3163 L
.91941 .3158 L
.91947 .31544 L
.91952 .31517 L
.91955 .315 L
.91958 .31494 L
.91966 .31497 L
.91978 .31507 L
.9199 .3152 L
.91995 .31529 L
.91991 .31528 L
s
.83471 .18817 m
.83458 .18796 L
.83452 .18785 L
.83444 .18775 L
s
.79727 .14451 m
.79731 .14443 L
.79744 .14451 L
.79761 .1447 L
.7978 .14495 L
.79794 .1452 L
.79801 .14534 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14536 L
.79802 .14539 L
.79802 .14544 L
.79803 .14552 L
.79807 .1456 L
.79815 .14568 L
.79826 .14573 L
.79837 .14571 L
s
.71229 .09862 m
.71219 .09848 L
.71217 .09837 L
.7122 .09829 L
.71226 .09821 L
.7123 .09813 L
.71231 .09805 L
.71228 .09799 L
.71223 .09795 L
.71218 .09795 L
.71216 .09804 L
s
.22237 .13476 m
.22224 .13469 L
s
.08283 .40255 m
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08287 .40258 L
.08283 .40256 L
.08281 .40253 L
.08279 .40252 L
.08277 .4025 L
.08275 .40247 L
.08272 .40244 L
.08269 .4024 L
.08266 .40236 L
.08263 .40233 L
.08261 .40231 L
.0826 .40229 L
.08259 .40228 L
.08259 .40228 L
.08259 .40227 L
.08259 .40228 L
.08261 .4023 L
.08263 .40232 L
.08265 .40236 L
.08268 .40239 L
.08272 .40243 L
.08275 .40247 L
.08277 .4025 L
.08278 .40251 L
.08279 .40252 L
.08278 .40251 L
.08277 .4025 L
.08276 .40249 L
.08276 .40248 L
.08274 .40248 L
.08271 .40248 L
.08266 .40248 L
.08262 .40248 L
.0826 .40248 L
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08316 .40248 L
.0834 .40248 L
.0837 .40248 L
.08405 .40247 L
.08445 .40247 L
.08485 .40247 L
.08518 .40247 L
.08541 .40246 L
Mistroke
.08548 .40246 L
.08535 .40247 L
.08498 .40247 L
.08441 .40247 L
.08372 .40248 L
.08297 .40248 L
.08222 .40249 L
.08152 .40249 L
.08088 .4025 L
.08028 .4025 L
.07973 .40251 L
.07927 .40251 L
.07895 .40248 L
Mfstroke
.08989 .44329 m
.08989 .44331 L
.08978 .44329 L
.08957 .44325 L
.08925 .44318 L
.08884 .44304 L
.08836 .44284 L
.08783 .44259 L
.08728 .44231 L
.08674 .44203 L
.0862 .44175 L
.0857 .44148 L
.08525 .44124 L
.08489 .44101 L
.08462 .44084 L
.08442 .44074 L
.08427 .44073 L
.08413 .4408 L
.08395 .44093 L
.08371 .44109 L
.08338 .44126 L
.08295 .4414 L
.08244 .44151 L
.08187 .44158 L
.08132 .44162 L
.08078 .44165 L
.08025 .44165 L
.07974 .44163 L
.07929 .44158 L
.07895 .4415 L
.07877 .4414 L
.07873 .44128 L
.07877 .44115 L
.07887 .44103 L
.07897 .44092 L
.07902 .44083 L
.07896 .44078 L
s
.06484 .44363 m
.06468 .4437 L
.06463 .44372 L
.06466 .4437 L
.06476 .44366 L
.06491 .44363 L
.06501 .44363 L
.06505 .44365 L
.06505 .44369 L
.06505 .4437 L
.06505 .44369 L
.06506 .44364 L
.06506 .44354 L
.06506 .4434 L
.06507 .44322 L
.06508 .443 L
.06509 .44276 L
.06509 .44251 L
.0651 .44226 L
.06511 .44201 L
.06512 .44177 L
.06513 .44154 L
.06513 .44135 L
.06514 .44119 L
.06514 .44108 L
.06514 .44102 L
.06514 .441 L
.06514 .44102 L
.06514 .44106 L
.06514 .4411 L
.06514 .44113 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06514 .44115 L
.06515 .44115 L
.06518 .44115 L
.06522 .44115 L
.06527 .44115 L
.06529 .44115 L
.06528 .44115 L
.06523 .44115 L
.06513 .44115 L
.06497 .44115 L
.06476 .44116 L
.06451 .44116 L
Mistroke
.06425 .44116 L
.06397 .44117 L
.06366 .44117 L
.06341 .44118 L
.06314 .44118 L
.06288 .44118 L
.06264 .44118 L
.06246 .44117 L
.06234 .44114 L
.06227 .4411 L
.06225 .44107 L
.06226 .44105 L
.0623 .44106 L
.06235 .44111 L
.06239 .44121 L
.0624 .44135 L
.06239 .44153 L
.06238 .44175 L
.06237 .44199 L
.06235 .44226 L
.06231 .44254 L
.06225 .44283 L
.0622 .44311 L
.06217 .44335 L
.06218 .44353 L
.06224 .44364 L
.06235 .44365 L
.06251 .44356 L
.06273 .44339 L
.06298 .44316 L
.06325 .44288 L
.06355 .44259 L
.06384 .4423 L
.06415 .44205 L
.06446 .44185 L
.06477 .4417 L
.06503 .44158 L
.06523 .44146 L
.06534 .44134 L
.06536 .44119 L
Mfstroke
.06326 .41478 m
.06326 .41485 L
.06325 .41511 L
.06324 .4155 L
.06321 .41596 L
.06316 .41641 L
.0631 .41683 L
.06305 .41718 L
.06302 .41742 L
.06303 .41754 L
.06309 .41753 L
.06321 .41737 L
.06338 .41708 L
.0636 .41667 L
.06386 .41613 L
.06415 .41551 L
.06445 .41485 L
.06475 .41422 L
.06505 .41367 L
.06534 .41323 L
.0656 .41288 L
.06583 .41261 L
.06602 .41241 L
.06615 .41226 L
.06622 .41216 L
.06624 .41211 L
.06623 .41208 L
.06619 .41207 L
.06614 .41209 L
.0661 .41213 L
.06608 .41217 L
.06608 .4122 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
.06608 .41222 L
Mistroke
.06608 .41222 L
.06608 .41222 L
.0661 .4122 L
.06613 .41217 L
.06618 .41212 L
.06622 .41208 L
.06624 .41204 L
.0662 .41201 L
.06611 .41202 L
.06595 .41208 L
.06574 .41224 L
.06549 .41252 L
.06523 .41292 L
.06497 .41341 L
.06476 .41395 L
.06462 .41453 L
.06456 .415 L
.06457 .41547 L
.06466 .41587 L
.06486 .41617 L
.06512 .41638 L
.06546 .41648 L
.06587 .4165 L
.06634 .41638 L
.06685 .41621 L
.06733 .41594 L
.0678 .41562 L
.06824 .41529 L
.06865 .415 L
.06902 .41478 L
.06939 .4146 L
.06977 .41448 L
.07019 .41445 L
.07063 .41445 L
.07113 .41446 L
.07167 .41443 L
.07228 .41436 L
.07293 .41425 L
.07358 .41409 L
.07422 .41391 L
.07482 .4137 L
.07535 .41348 L
.0758 .41324 L
.07617 .41302 L
.07648 .41282 L
.07673 .41263 L
.07692 .41246 L
.07706 .41233 L
.07713 .41223 L
.07717 .41215 L
Mistroke
.07718 .41207 L
.0772 .41196 L
.07725 .41183 L
.07729 .41172 L
.0773 .41167 L
.07727 .41173 L
Mfstroke
.07317 .44346 m
.07331 .44345 L
.07338 .44345 L
.07341 .44345 L
.0734 .44345 L
.07341 .44345 L
.07349 .44345 L
.07358 .44345 L
.0736 .44345 L
.07356 .44345 L
.07343 .44345 L
.07316 .44346 L
.0727 .44346 L
.07204 .44347 L
.07125 .44348 L
.07042 .44349 L
.06962 .4435 L
.06888 .44351 L
.06817 .44353 L
.06744 .44354 L
.06667 .44355 L
.06592 .44355 L
.06534 .44353 L
.06501 .44348 L
.06487 .44341 L
.06486 .44334 L
.06491 .4433 L
.06501 .44332 L
.06509 .44341 L
s
.08655 .69943 m
.08668 .69939 L
.08675 .69928 L
.08677 .69918 L
.08676 .69907 L
.08672 .69892 L
.08666 .69873 L
.0866 .69856 L
.08655 .69848 L
.0865 .69853 L
s
.08901 .70902 m
.0891 .70903 L
.08912 .70901 L
.0891 .70901 L
s
.06207 .52896 m
.06205 .52907 L
.06203 .52898 L
.062 .52877 L
.06198 .52854 L
.06196 .52835 L
.06195 .52827 L
s
.08205 .6671 m
.08215 .66713 L
.08221 .6671 L
.08223 .66703 L
.08221 .66694 L
.08218 .66686 L
.08213 .66677 L
.0821 .66671 L
.08208 .66668 L
.08208 .66667 L
.08209 .66667 L
.08213 .66667 L
.08221 .66666 L
.0823 .66666 L
.08234 .66666 L
.08232 .66666 L
.08221 .66667 L
s
.10238 .72916 m
.10236 .72921 L
.10231 .72912 L
.10226 .72895 L
.10224 .72873 L
.10227 .7285 L
.10234 .72831 L
.10242 .72819 L
.10246 .72814 L
.10243 .72817 L
.10231 .72828 L
.1021 .72849 L
.10177 .72879 L
.10135 .72919 L
.10086 .72965 L
.10031 .73017 L
.09974 .73071 L
.09919 .73125 L
.09864 .73178 L
.0981 .73231 L
.09758 .73279 L
.09712 .73322 L
.09676 .73355 L
.09651 .73379 L
.09636 .73393 L
.09632 .73397 L
.09635 .73393 L
.09643 .73386 L
.09652 .73377 L
.09658 .7337 L
.09662 .73367 L
.09662 .73366 L
.09662 .73366 L
.0966 .73365 L
.09657 .73362 L
.09652 .73358 L
.09647 .73354 L
.09642 .73353 L
.09639 .73354 L
.09641 .7336 L
.09649 .73369 L
.09665 .73383 L
.09687 .73401 L
.09717 .73422 L
.09753 .73445 L
.09796 .73467 L
.09844 .73485 L
.099 .73501 L
.09962 .73516 L
.10031 .73533 L
Mistroke
.10101 .73553 L
.10176 .73577 L
.10253 .73606 L
.10332 .73639 L
.10408 .73676 L
.10484 .73716 L
.10558 .73758 L
.10628 .73803 L
.10695 .73848 L
.10759 .73895 L
.10819 .73942 L
.10871 .73986 L
.10916 .74025 L
.10953 .74056 L
.1098 .74077 L
.11 .74089 L
.11015 .74092 L
.11032 .74088 L
.11046 .7408 L
.11051 .74072 L
.11045 .74066 L
.11028 .74064 L
.10998 .74065 L
.10953 .74067 L
.1089 .74069 L
.10814 .74073 L
.10734 .74079 L
.10659 .74088 L
.10589 .74099 L
.1052 .7411 L
.10447 .74116 L
.10368 .74117 L
.1029 .74109 L
.10221 .74092 L
.10165 .74064 L
.1012 .74028 L
.10081 .73985 L
.10051 .73937 L
.10032 .73886 L
.10021 .73835 L
.10003 .73784 L
.09986 .73735 L
.09976 .73688 L
.09974 .73648 L
.09979 .73615 L
.09992 .73592 L
.10012 .73578 L
.10041 .73573 L
.10078 .73575 L
.1012 .7358 L
Mistroke
.10166 .73587 L
.10212 .73591 L
.10256 .73593 L
.10296 .73592 L
.10332 .7359 L
.10363 .73589 L
.1039 .73588 L
.10413 .73587 L
.10434 .73586 L
.10453 .73587 L
.10472 .7359 L
.10489 .73596 L
.10501 .73604 L
.10508 .73613 L
.10508 .73619 L
.105 .73617 L
.10483 .73606 L
.10459 .73582 L
.10427 .73546 L
.10388 .73497 L
.10343 .73437 L
.10292 .73369 L
.10242 .733 L
.10188 .73225 L
.10134 .73149 L
.10088 .73077 L
.1005 .73009 L
.10019 .72947 L
.09991 .72897 L
.09967 .72864 L
.09946 .72846 L
.09926 .72841 L
.09904 .72843 L
.09878 .72848 L
.09845 .72849 L
.09804 .72844 L
.09754 .72829 L
.09692 .72801 L
.09626 .72764 L
.09551 .7272 L
.09467 .72671 L
.09376 .72622 L
.0928 .72576 L
.09183 .72536 L
.09098 .72502 L
.09009 .72484 L
.08928 .72479 L
.08852 .72491 L
.08784 .7252 L
.08725 .72567 L
Mistroke
.08679 .72622 L
.08646 .72684 L
.08627 .72739 L
.08618 .72789 L
.08619 .72826 L
.08628 .72847 L
.08643 .72851 L
.08663 .72836 L
.08684 .72805 L
.08709 .72762 L
.08735 .72711 L
.08761 .72656 L
.08782 .72597 L
.08799 .72539 L
.08808 .72486 L
.08812 .72442 L
.08812 .72406 L
.08812 .72377 L
.08816 .72356 L
.08828 .72344 L
.08851 .72343 L
.08885 .72352 L
.08929 .7237 L
.08984 .72395 L
.09048 .72426 L
.0912 .72465 L
.09197 .72515 L
.09267 .72571 L
.09342 .72628 L
.09425 .72681 L
.09497 .7273 L
.09563 .7277 L
.0962 .72798 L
.09662 .72808 L
.09691 .72799 L
.09706 .72769 L
.09711 .7272 L
.09707 .72656 L
.09701 .72583 L
.09694 .72502 L
.09689 .72418 L
.09684 .72336 L
.0968 .72262 L
.09677 .722 L
.09676 .7215 L
.09678 .72115 L
.09684 .72096 L
.09695 .72093 L
.09711 .72103 L
.09731 .72123 L
Mistroke
.09754 .72148 L
.0978 .72177 L
.09808 .72206 L
.09835 .72236 L
.09862 .72264 L
.09888 .7229 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72358 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
Mistroke
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09959 .72354 L
.09962 .72357 L
.09966 .72361 L
.0997 .72364 L
.09972 .72366 L
.09971 .72365 L
.09965 .7236 L
.09954 .7235 L
.09939 .72336 L
.09919 .72318 L
.09895 .72296 L
.09869 .72273 L
.09841 .72248 L
.09814 .72223 L
.09787 .72198 L
.0976 .72174 L
.09736 .72151 L
.09714 .72132 L
.09697 .72117 L
.09685 .72106 L
.09678 .72099 L
.09675 .72096 L
.09673 .72095 L
.09673 .72095 L
.09674 .72095 L
.09675 .72096 L
.09678 .72099 L
.09684 .72105 L
.09694 .72114 L
.0971 .72129 L
.0973 .72147 L
.09754 .72168 L
.0978 .72192 L
Mistroke
.09807 .72217 L
.09835 .72242 L
.09862 .72267 L
.09888 .72291 L
.09913 .72313 L
.09934 .72332 L
.09952 .72348 L
.09964 .72359 L
.0997 .72365 L
.09972 .72367 L
.09971 .72365 L
.09967 .72361 L
.09962 .72357 L
.09959 .72354 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72352 L
.09957 .72354 L
.09957 .72357 L
.09957 .72361 L
.09957 .72365 L
.09957 .72367 L
.09957 .72366 L
.09956 .72361 L
.09955 .72352 L
.09951 .72341 L
Mistroke
Mfstroke
.11796 .40706 m
.11801 .40689 L
s
.16823 .33663 m
0 0 rlineto s
.23768 .13021 m
.23749 .1302 L
.23706 .13024 L
.23641 .13029 L
.23558 .13036 L
.23461 .13043 L
.23362 .13049 L
.23253 .13054 L
.23151 .13063 L
.23052 .13077 L
.22961 .13096 L
.22881 .13121 L
.22815 .13151 L
.22765 .13186 L
.22732 .13224 L
.22712 .13256 L
.22708 .13296 L
.22715 .13338 L
.22729 .13371 L
.22744 .13404 L
.22752 .13432 L
.2275 .13457 L
.22734 .13479 L
.22704 .13497 L
.22661 .13513 L
.22608 .13528 L
.22552 .13544 L
.225 .13561 L
.22454 .1358 L
.22414 .13601 L
.22382 .13622 L
.22354 .13644 L
.22331 .13664 L
.22315 .13682 L
.22311 .13697 L
.22322 .13708 L
.22349 .13712 L
.22387 .1371 L
.2243 .13703 L
.22472 .13694 L
.22505 .13688 L
.2252 .13688 L
.22514 .13696 L
.22489 .13714 L
.22451 .1374 L
.22405 .13773 L
.22355 .13813 L
.22302 .13857 L
.22249 .13903 L
.22196 .13949 L
Mistroke
.22144 .13997 L
.22095 .14046 L
.22051 .14093 L
.22012 .14133 L
.21977 .14165 L
.21949 .14184 L
.21927 .1419 L
Mfstroke
.32053 .08756 m
.3204 .08765 L
.32037 .08767 L
.32041 .08761 L
.32045 .08754 L
.32048 .08748 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.3205 .08745 L
.32048 .08747 L
.32045 .08753 L
.32041 .0876 L
.32035 .08766 L
.32029 .0877 L
.32024 .08768 L
.32021 .08762 L
.32024 .08749 L
s
.38873 .05118 m
.38881 .05115 L
.3889 .051 L
.38897 .05074 L
.38902 .0504 L
.38904 .05 L
.38902 .04955 L
.38898 .04907 L
.38893 .04857 L
.38885 .04813 L
.38872 .04771 L
.38856 .04731 L
.38842 .04696 L
.38831 .04668 L
.38829 .04652 L
.38837 .04645 L
s
.41591 .04753 m
.41593 .04753 L
.41585 .04753 L
.41571 .04752 L
.41554 .04751 L
.41538 .04751 L
.41524 .0475 L
.41514 .0475 L
.41506 .0475 L
.415 .04749 L
.41498 .04749 L
.41503 .0475 L
s
.44721 .04652 m
.44713 .04639 L
s
.39604 .04688 m
.39583 .04677 L
.39562 .0466 L
.39542 .04638 L
.39522 .04613 L
.39501 .04588 L
.39479 .04565 L
.3946 .04546 L
.39446 .04531 L
.39441 .04522 L
.39446 .04518 L
s
.61001 .06231 m
.60986 .06214 L
.60957 .06187 L
.60916 .06154 L
.60864 .06115 L
.60802 .06071 L
.6073 .0602 L
.60652 .05958 L
.60569 .05889 L
.60481 .05811 L
.60394 .05728 L
.6031 .05648 L
.60232 .05576 L
.6016 .05519 L
.60096 .05477 L
.60033 .05448 L
.59968 .0543 L
.59897 .05422 L
.59817 .05427 L
.59727 .05444 L
.59633 .05472 L
.59536 .05505 L
.59434 .05539 L
.59329 .05573 L
.59223 .05603 L
.59112 .05621 L
.58998 .05624 L
.58888 .05608 L
.58782 .05577 L
.58683 .05536 L
.58595 .05491 L
.5852 .05449 L
.58455 .05406 L
.584 .05367 L
.58354 .05328 L
.58316 .0529 L
.58287 .05253 L
.58267 .05221 L
.58257 .05196 L
.58258 .05176 L
s
.60164 .05748 m
.60177 .05741 L
.60179 .05735 L
.60176 .05731 L
.60171 .0573 L
.60165 .0573 L
.6016 .05731 L
.60154 .05732 L
.60147 .05734 L
.60136 .05735 L
.60121 .05737 L
.60101 .05738 L
.60077 .05739 L
.60051 .05739 L
.60025 .05739 L
.60003 .05739 L
.59986 .05741 L
.59975 .05746 L
.59971 .05752 L
.59973 .05756 L
.59981 .05757 L
.59991 .05753 L
.60004 .05742 L
.60016 .05722 L
.60028 .05691 L
.60035 .0565 L
.60037 .05602 L
.60031 .05552 L
.60018 .055 L
.59999 .05451 L
.59978 .05408 L
.59958 .05376 L
.59939 .05359 L
.59924 .05358 L
s
.70458 .10303 m
0 0 rlineto s
.79389 .13695 m
.79398 .13692 L
.79399 .13688 L
.79395 .13684 L
.79388 .1368 L
.7938 .13677 L
.79374 .13675 L
.79369 .13675 L
.79365 .13675 L
.79362 .13672 L
.7936 .13667 L
.79359 .1366 L
.79356 .13654 L
.79351 .1365 L
.79345 .1365 L
.7934 .13654 L
.79337 .13664 L
s
.82297 .1748 m
.82299 .17481 L
.82283 .17463 L
.82251 .17422 L
.8221 .17364 L
.82166 .17291 L
.82123 .17211 L
.82084 .17132 L
.82051 .1706 L
.82027 .17 L
.82013 .16955 L
.8201 .16927 L
s
.93013 .38896 m
.93017 .38893 L
.93019 .38869 L
.93018 .38831 L
.93015 .38786 L
.93008 .38736 L
.92997 .38691 L
.92983 .38656 L
.92966 .38632 L
.92948 .38622 L
.92932 .38628 L
.92918 .3865 L
.92909 .38681 L
.92901 .38717 L
.92894 .38757 L
.92888 .38799 L
.92883 .38836 L
.92881 .38863 L
.92882 .38882 L
.92886 .38891 L
.92893 .38893 L
.92902 .3889 L
.92911 .38889 L
.92922 .38891 L
.92933 .38903 L
s
.93354 .42846 m
0 0 rlineto s
.73599 .8786 m
0 0 rlineto s
.80359 .8363 m
.80364 .83635 L
.80356 .83656 L
.80338 .83694 L
.80311 .83744 L
.80276 .83805 L
.80234 .83874 L
.80188 .83947 L
.80139 .84023 L
.80091 .84097 L
.80044 .8417 L
.8 .84242 L
.7996 .8431 L
.79924 .84371 L
.79896 .84419 L
.79878 .84454 L
.79869 .84475 L
.79868 .84484 L
.79871 .84484 L
.79876 .84475 L
.79879 .84462 L
.79878 .84449 L
.79874 .84438 L
.79865 .84427 L
.79855 .84416 L
.79845 .84404 L
.79837 .84389 L
.79832 .84369 L
.79832 .84342 L
.79837 .84307 L
.79846 .84264 L
.79861 .84213 L
.79882 .84158 L
.79907 .841 L
.79936 .84041 L
.79967 .83983 L
.80001 .83928 L
.80038 .83872 L
.80075 .83819 L
.80107 .83772 L
.80128 .83732 L
.80136 .83706 L
.8013 .83696 L
.80107 .83705 L
.80068 .83733 L
.80013 .83776 L
.79947 .83829 L
.79875 .83889 L
.79802 .8395 L
.79735 .84007 L
Mistroke
.79673 .84061 L
.79617 .84112 L
.79568 .8416 L
.79531 .84201 L
.79508 .84233 L
.795 .84255 L
.79507 .84266 L
.79525 .84268 L
.79553 .84262 L
.79585 .84252 L
.79617 .84242 L
.79643 .84233 L
.79661 .84229 L
.79671 .84227 L
.79677 .84227 L
.79679 .84226 L
.79677 .84226 L
.79674 .84227 L
.7967 .84227 L
.79667 .84227 L
.79666 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
.79665 .84228 L
Mistroke
.79665 .84228 L
.79665 .84228 L
.79665 .84232 L
.79665 .84241 L
.79665 .84256 L
.79665 .84273 L
.79664 .84293 L
.7966 .84309 L
.79653 .84318 L
.79643 .84314 L
Mfstroke
.94108 .53587 m
.94114 .53591 L
.94119 .53586 L
.94125 .53573 L
.9413 .5356 L
.94134 .53551 L
.94134 .53547 L
.94129 .53546 L
.9412 .53545 L
.94106 .53547 L
.94086 .53552 L
.9406 .53562 L
.94034 .53579 L
.94012 .53602 L
.93996 .53632 L
.93985 .53667 L
.93979 .53707 L
.93976 .53752 L
.93975 .53799 L
.93975 .53847 L
.93984 .53892 L
.94001 .53932 L
.94023 .53962 L
.94049 .53979 L
.94076 .53982 L
.94102 .53971 L
.94125 .53947 L
.9414 .53912 L
.94144 .53868 L
.94142 .53817 L
.94137 .5376 L
.94133 .537 L
.94131 .53643 L
.94129 .53592 L
.94128 .53552 L
.94126 .53527 L
.94122 .53521 L
s
.9359 .55783 m
.93594 .55783 L
.93614 .55782 L
.9365 .5578 L
.93697 .55778 L
.93752 .55775 L
.93813 .55773 L
.93878 .55769 L
.93939 .55764 L
.93999 .55757 L
.94057 .55751 L
.94106 .55747 L
.94147 .55749 L
.94176 .55755 L
.94192 .55766 L
.94192 .55779 L
.94178 .55794 L
.9415 .55809 L
.94113 .55822 L
.9407 .55832 L
.94023 .5584 L
.93977 .55844 L
.93935 .55849 L
.93893 .55855 L
.93855 .55858 L
.93821 .55856 L
.93793 .55845 L
.93773 .55824 L
.93762 .55795 L
.93757 .55761 L
.93758 .55727 L
.93762 .55697 L
.93768 .55676 L
.93773 .55667 L
.93775 .55667 L
.93775 .55673 L
.93775 .55678 L
.93775 .55678 L
.93775 .55673 L
.93775 .55664 L
.93775 .55653 L
.93774 .55637 L
.93774 .55617 L
.93773 .55591 L
.93772 .5556 L
.93771 .55525 L
.9377 .55482 L
.93769 .55438 L
.93768 .55407 L
.93767 .55396 L
Mistroke
.93768 .554 L
.93768 .55416 L
.93769 .55437 L
.9377 .55455 L
.93771 .55451 L
Mfstroke
.91977 .32757 m
.91981 .32778 L
.91984 .32793 L
.91986 .32804 L
.91987 .32809 L
.9199 .32808 L
.91996 .32799 L
s
.91065 .30154 m
.91064 .30151 L
.91069 .30158 L
.91075 .30168 L
.91077 .30181 L
.91076 .30191 L
.91073 .30198 L
s
.80364 .14439 m
.80372 .14444 L
.80388 .14462 L
.80406 .14487 L
.80421 .14511 L
.80431 .14531 L
.80438 .14544 L
.80444 .14553 L
.80449 .1456 L
.80452 .14567 L
.80454 .14571 L
.80453 .14568 L
.80448 .14559 L
.80439 .14542 L
.80426 .14517 L
.8041 .14485 L
.80392 .14448 L
.80373 .14408 L
.80353 .14365 L
.80334 .14321 L
.80312 .14276 L
.80289 .14231 L
.80263 .14185 L
.80237 .14143 L
.8021 .14105 L
.80183 .14076 L
.80159 .14055 L
.80136 .14046 L
.80115 .14047 L
.80096 .14056 L
.80078 .14066 L
.80059 .14071 L
.80041 .14069 L
.80024 .14058 L
.8001 .14042 L
.8 .14024 L
.79994 .14005 L
.79993 .13989 L
.79994 .13977 L
.79997 .13968 L
.80001 .13964 L
.80003 .13961 L
.80005 .1396 L
.80005 .1396 L
.80005 .13963 L
.80007 .13973 L
.8001 .13993 L
.80014 .14021 L
.80018 .14057 L
.80023 .14096 L
Mistroke
.80028 .14136 L
.80032 .14171 L
.80034 .14197 L
.80034 .14211 L
.80028 .14214 L
Mfstroke
.39736 .04703 m
.39735 .04704 L
.39751 .04706 L
.39776 .04707 L
.39803 .04708 L
.39824 .04708 L
.39838 .04707 L
.39847 .04705 L
.39852 .04702 L
.39853 .04697 L
.39853 .0469 L
.39853 .04682 L
.39853 .04675 L
.39853 .04673 L
.39853 .04676 L
.39853 .04685 L
.39853 .04696 L
.39853 .04709 L
.39853 .04724 L
.39853 .04742 L
.39853 .04763 L
.39853 .0479 L
.39853 .04822 L
.39853 .04857 L
.39853 .04894 L
.39853 .04931 L
.39853 .04971 L
.39853 .05007 L
.39853 .05036 L
.39854 .05064 L
.39859 .05088 L
.39868 .05107 L
.39883 .05124 L
.39899 .05137 L
.39912 .05147 L
.39918 .05151 L
.39909 .05148 L
s
.07992 .401 m
.07993 .401 L
.07998 .40088 L
.08003 .40071 L
.08007 .40052 L
.0801 .40034 L
.0801 .40022 L
.0801 .40014 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08005 .40006 L
.08001 .40002 L
.07997 .39999 L
.07993 .39997 L
.07991 .39998 L
.07992 .40002 L
.07996 .40009 L
Mfstroke
.09 .43161 m
.09 .43172 L
.09002 .43175 L
.09011 .43169 L
.09025 .43158 L
.09038 .43145 L
.09046 .43134 L
.09047 .43127 L
.0904 .43122 L
s
.06207 .44185 m
.06205 .44186 L
.06207 .4418 L
.06213 .44169 L
.06222 .44157 L
.06232 .44145 L
.06237 .4414 L
.06239 .44142 L
.06239 .44153 L
.06238 .4417 L
.06238 .44191 L
.06237 .44216 L
.06236 .44244 L
.06235 .4427 L
.06234 .4429 L
.06234 .44305 L
.06234 .44317 L
.06233 .44329 L
.06233 .44341 L
.06232 .44356 L
.06229 .44374 L
s
.06317 .49622 m
.0631 .49619 L
.06305 .49617 L
.063 .49636 L
s
.07507 .62377 m
.07512 .62393 L
.07514 .62418 L
s
.08424 .68416 m
.08437 .68407 L
.08444 .68401 L
.08446 .68398 L
.08445 .68399 L
.08441 .68402 L
.08436 .68405 L
.08432 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.08431 .68407 L
.0843 .68406 L
.08429 .68402 L
.08426 .68394 L
.08422 .68382 L
.08419 .68372 L
.08417 .68366 L
.08418 .6837 L
.08423 .68386 L
.08433 .68415 L
.08448 .68459 L
.08467 .68515 L
.0849 .68581 L
.08514 .68653 L
.0854 .6873 L
.08566 .68805 L
.08592 .68879 L
.08617 .68951 L
.08639 .69018 L
.08656 .69073 L
.08669 .69114 L
.08676 .69141 L
.0868 .69155 L
.08683 .69163 L
.08687 .69169 L
.08694 .69177 L
.08705 .69193 L
.08721 .69221 L
.08743 .69261 L
.08768 .69309 L
Mistroke
.08795 .69361 L
.08821 .69411 L
.08848 .69462 L
.08874 .69511 L
.08897 .69556 L
.08918 .69596 L
.08935 .69628 L
.08947 .6965 L
.08953 .69662 L
.08956 .69666 L
.08954 .69663 L
.0895 .69656 L
.08946 .69648 L
.08942 .69641 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69638 L
.08941 .69637 L
.08941 .69634 L
.08941 .69625 L
.08941 .69613 L
.0894 .69602 L
.08937 .69595 L
.08933 .69594 L
.08929 .696 L
Mfstroke
.09879 .73262 m
.09875 .73252 L
.09861 .73223 L
.09841 .73182 L
.09816 .73134 L
.09788 .73081 L
.09759 .73025 L
.0973 .7297 L
.09703 .7292 L
.09682 .72881 L
.09668 .72857 L
.09661 .72845 L
.09659 .72842 L
.0966 .72845 L
.09664 .72854 L
.09668 .72865 L
.09672 .72871 L
.09674 .7287 L
.09674 .72861 L
.09675 .72846 L
.09675 .72825 L
.09676 .72797 L
.09677 .72761 L
.09677 .72726 L
.09678 .72688 L
.09679 .72648 L
.0968 .72609 L
.09681 .72569 L
.09681 .72532 L
.09682 .72494 L
.09682 .72465 L
.09683 .72437 L
.09684 .72413 L
.09684 .72393 L
.09684 .72382 L
.09685 .72375 L
.09685 .72373 L
.09685 .72374 L
.09685 .72375 L
.09685 .72374 L
.09685 .72374 L
.09685 .72374 L
.09685 .72376 L
.09685 .72378 L
.09685 .72379 L
.09685 .7238 L
.09684 .72382 L
.09685 .72382 L
.09685 .72378 L
.09685 .72371 L
Mistroke
.09685 .7236 L
.09686 .72349 L
.09686 .72341 L
.09687 .72342 L
.09689 .72355 L
.0969 .7238 L
.0969 .72415 L
.09687 .72455 L
.09683 .72497 L
.09677 .72535 L
.09671 .72564 L
.09664 .72585 L
.09658 .72597 L
.09654 .72602 L
.09651 .726 L
.09649 .72591 L
.09649 .72575 L
.09649 .72548 L
.0965 .72513 L
.09653 .72473 L
.09657 .7243 L
.09662 .72391 L
.09668 .7236 L
.09675 .72341 L
.09681 .72335 L
.09686 .72338 L
.0969 .72345 L
.09691 .72353 L
.09691 .72359 L
.09689 .72362 L
.09687 .72363 L
.09686 .72363 L
.09686 .72363 L
.09686 .72365 L
.09686 .72368 L
.09685 .72372 L
.09685 .72375 L
.09685 .72377 L
.09683 .72376 L
.09679 .72371 L
.09673 .72361 L
Mfstroke
.42251 .06337 m
.4225 .06329 L
.42251 .06327 L
.42252 .06333 L
.42255 .06344 L
.42259 .06359 L
.42262 .06373 L
.42264 .06382 L
.42263 .06381 L
.42258 .06371 L
.42248 .06351 L
.42234 .06321 L
.42216 .06284 L
.42194 .06243 L
.42171 .06203 L
.42146 .06166 L
.42122 .06137 L
.42097 .06115 L
.42073 .06102 L
.42051 .06096 L
.42031 .06099 L
.42016 .06113 L
.42005 .06134 L
.41999 .06163 L
.41997 .062 L
.41999 .06242 L
.42002 .06284 L
.42007 .0632 L
.4201 .06348 L
.42011 .06364 L
.42011 .06372 L
.42011 .06374 L
.42011 .06371 L
.42011 .06367 L
.42011 .06362 L
.42011 .06357 L
.42011 .06355 L
.42011 .06356 L
.42011 .06358 L
.42011 .06359 L
.42011 .06359 L
.42011 .06357 L
.42011 .06353 L
.42011 .06348 L
.42011 .06341 L
.42011 .06334 L
.42011 .06327 L
.42011 .0632 L
.42011 .06314 L
.42011 .06307 L
Mistroke
.42011 .06302 L
.42011 .06298 L
.42011 .06296 L
.42011 .06295 L
.42012 .06298 L
.42013 .06304 L
.42016 .06311 L
.4202 .0632 L
.42023 .06327 L
.42025 .06335 L
.42024 .06343 L
.42019 .06351 L
.42009 .06357 L
.41993 .06358 L
.41972 .06354 L
.41946 .06339 L
.41919 .06312 L
.41892 .06273 L
.41869 .06233 L
.41849 .06189 L
.41835 .06148 L
.41826 .06113 L
.41825 .06089 L
.41831 .06074 L
.41844 .06068 L
.41863 .06073 L
.41886 .06086 L
.41912 .06107 L
.4194 .06133 L
.41967 .06168 L
.41989 .0621 L
.42006 .06256 L
.42017 .063 L
.42024 .06338 L
.42026 .06363 L
.42024 .06377 L
.42021 .0638 L
.42016 .06377 L
.42013 .0637 L
.42012 .06363 L
.42011 .06357 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
Mistroke
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42011 .06354 L
.42012 .06353 L
.42014 .06351 L
.42019 .06347 L
.42027 .0634 L
.42034 .06333 L
.42037 .0633 L
.42035 .06334 L
.42025 .06348 L
.42006 .06372 L
.41978 .06403 L
.41942 .06438 L
.41899 .06473 L
.41852 .06503 L
.41803 .06527 L
.41755 .06543 L
.41707 .06552 L
.4166 .06555 L
.41615 .06552 L
.41576 .06542 L
.41545 .06527 L
Mistroke
.41523 .06503 L
.41512 .06473 L
.41511 .06442 L
.41518 .06411 L
.41528 .06384 L
.41539 .06361 L
.41547 .06345 L
.41548 .06334 L
.41542 .06322 L
.4153 .06303 L
.4151 .06273 L
.41484 .06232 L
.41451 .06178 L
.41412 .06116 L
.41369 .06051 L
.41323 .05984 L
.41276 .05915 L
.41229 .05849 L
.41185 .05787 L
.41145 .05733 L
.4111 .05689 L
.41082 .05656 L
.41061 .05634 L
.41047 .05622 L
.41039 .05617 L
.41037 .05616 L
.41038 .05616 L
.41041 .05617 L
.41045 .05619 L
.41049 .05624 L
.41052 .05633 L
.41054 .05645 L
.41054 .05662 L
.41052 .05683 L
.41048 .05707 L
.41042 .05733 L
.41035 .05761 L
.4103 .05786 L
.4103 .05807 L
.41036 .0582 L
.4105 .05822 L
.41074 .05812 L
.41106 .05788 L
.41145 .0575 L
.4119 .057 L
.41238 .05641 L
.41287 .05574 L
.41337 .05505 L
.41385 .05437 L
.41431 .05375 L
Mistroke
.41473 .05319 L
.41507 .05272 L
.41534 .05233 L
.41551 .05205 L
.41559 .05187 L
.41559 .05178 L
.41554 .05177 L
.41547 .0518 L
.4154 .05187 L
.41535 .05194 L
.41533 .05201 L
.41533 .05203 L
.41533 .05204 L
.41534 .05201 L
.41535 .05196 L
.41536 .05189 L
.41536 .05182 L
.41535 .05179 L
.41532 .05181 L
.41529 .05191 L
.41525 .05209 L
.41521 .05236 L
.41518 .0527 L
.41515 .0531 L
.41513 .05355 L
.41512 .05401 L
.41512 .05447 L
.41512 .05493 L
.41513 .05538 L
.41515 .0558 L
.41517 .05617 L
.4152 .05647 L
.41524 .05668 L
.41528 .05679 L
.41532 .05683 L
.41534 .05683 L
.41536 .05681 L
.41537 .05681 L
.41536 .05682 L
.41534 .05682 L
.41533 .0568 L
.41533 .0567 L
.41533 .05652 L
.41533 .05625 L
.41533 .0559 L
.41533 .0555 L
.41533 .05504 L
.41531 .05456 L
.41528 .0541 L
.41524 .05365 L
Mistroke
.41518 .05321 L
.41511 .05279 L
.41504 .05243 L
.41501 .05215 L
.41506 .05197 L
.41522 .05189 L
.41551 .05188 L
.41592 .05192 L
.41646 .052 L
.4171 .05209 L
.41778 .05217 L
.41853 .05221 L
.41929 .05222 L
.42002 .05223 L
.42071 .05226 L
.42133 .05232 L
.42187 .0524 L
.42227 .05247 L
.42257 .05249 L
.42275 .05247 L
.42284 .05238 L
.42286 .05222 L
.42286 .05198 L
.42288 .05164 L
.42295 .05124 L
.42307 .0508 L
.42326 .05035 L
.4235 .04989 L
.42376 .04944 L
.42402 .04897 L
.42427 .0485 L
.4245 .04808 L
.42469 .04773 L
.42484 .04749 L
.42493 .0474 L
.42496 .04746 L
Mfstroke
.43669 .05303 m
.43676 .0531 L
s
.21643 .14191 m
.2164 .14186 L
.21649 .1418 L
.21666 .14175 L
.21679 .14168 L
.21686 .14159 L
.2169 .14145 L
.21695 .14126 L
.21698 .14103 L
.217 .14079 L
.217 .14056 L
.217 .14038 L
.21701 .14026 L
.21701 .14018 L
.21701 .14015 L
.21701 .14015 L
.21701 .14017 L
.21702 .14018 L
.21705 .14024 L
.21709 .14034 L
.21713 .1405 L
.21716 .14071 L
.21716 .14095 L
.21714 .14117 L
.21712 .14137 L
s
.20627 .15766 m
.20621 .1578 L
.20624 .15782 L
.20635 .15773 L
.20647 .1576 L
.20657 .15748 L
.2066 .15741 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15737 L
.20661 .15738 L
.20661 .15738 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .15729 L
.20661 .15726 L
.20661 .15723 L
.20661 .15721 L
Mistroke
.20661 .15719 L
.20661 .15719 L
.20661 .15718 L
.20661 .15718 L
.20661 .15719 L
.20661 .1572 L
.20661 .15722 L
.20661 .15725 L
.20661 .15728 L
.20661 .15731 L
.20661 .15734 L
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
.20661 .15739 L
.2066 .1574 L
.2066 .15741 L
.2066 .15741 L
.20661 .15739 L
.20661 .15737 L
.20661 .15733 L
.20661 .15729 L
.20661 .15725 L
.20661 .15721 L
.20661 .15718 L
.20661 .15716 L
.20661 .15715 L
.20661 .15715 L
.20661 .15717 L
.20661 .15719 L
.20661 .15724 L
.20661 .15727 L
.20661 .15729 L
.20661 .15728 L
.20661 .15724 L
.20661 .15717 L
.20661 .15708 L
.20661 .15698 L
.20661 .15688 L
.20661 .15678 L
.20661 .15668 L
.20661 .15661 L
.20661 .15657 L
.20661 .15655 L
.20661 .15655 L
.20661 .15658 L
.20661 .15664 L
.20661 .15675 L
.20661 .1569 L
.20661 .15702 L
Mistroke
.20661 .15716 L
.20661 .15728 L
.20661 .15735 L
.20661 .15742 L
.20661 .15745 L
.20661 .15743 L
.20661 .15738 L
.20661 .15733 L
.20661 .15727 L
.20661 .1572 L
.20661 .15712 L
.20661 .15705 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .15731 L
.20661 .15738 L
.20661 .15743 L
.20661 .15745 L
.20661 .15744 L
.20661 .1574 L
.20661 .15735 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15726 L
.20661 .15727 L
.20661 .15729 L
.20661 .1573 L
.20661 .15731 L
.20661 .15732 L
.20661 .15735 L
.20661 .15736 L
.20661 .15735 L
.20661 .1573 L
.20661 .15722 L
.20661 .15712 L
.20661 .15701 L
.20661 .1569 L
Mistroke
.20661 .15682 L
.20661 .15676 L
.20661 .15673 L
.20661 .15672 L
.20661 .15674 L
.20661 .15678 L
.20661 .15681 L
.20661 .15688 L
.20661 .15696 L
.20661 .15704 L
.20661 .15714 L
.20661 .15723 L
.20661 .1573 L
.20661 .15737 L
.20661 .15742 L
.20661 .15746 L
.20661 .15747 L
.20661 .15747 L
.20661 .15745 L
.20661 .15741 L
.20661 .15737 L
.20661 .15731 L
.20661 .15724 L
.20661 .15716 L
.20661 .15709 L
.20661 .15704 L
.20661 .157 L
.20661 .15698 L
.20661 .15697 L
.20661 .15697 L
.20661 .15697 L
.20661 .15698 L
.20661 .15702 L
.20661 .15707 L
.20661 .15714 L
.20661 .15722 L
.20661 .1573 L
.20661 .15736 L
.20661 .15741 L
.20661 .15743 L
.20661 .15743 L
.20661 .1574 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
Mistroke
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15736 L
.20661 .15737 L
.20661 .15738 L
.20661 .15738 L
.20661 .15738 L
.20661 .15737 L
.20661 .15736 L
.20661 .15734 L
.20661 .15732 L
.20661 .1573 L
.20661 .15728 L
.20661 .15726 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15725 L
.20661 .15727 L
.20661 .15732 L
.20661 .15737 L
.20661 .1574 L
.20661 .15741 L
.20661 .15738 L
.20661 .15734 L
.20661 .15731 L
.20661 .15727 L
.20661 .15723 L
.20661 .15715 L
.20661 .157 L
.20661 .15678 L
.20661 .15649 L
.20661 .15622 L
.20661 .15602 L
.20661 .15585 L
.20661 .15572 L
.20661 .15561 L
.20662 .15552 L
.20662 .15537 L
.20662 .15527 L
.20662 .15512 L
.20662 .15493 L
.20662 .15471 L
.20662 .15449 L
Mistroke
.20662 .15425 L
.20662 .15407 L
.20662 .15388 L
.20662 .15367 L
.20663 .15341 L
.20663 .1531 L
.20663 .1528 L
.20663 .15258 L
.20663 .15249 L
.20663 .15255 L
.20663 .15273 L
.20663 .15298 L
.20663 .15323 L
.20663 .15344 L
.20663 .15358 L
.20662 .15367 L
.20662 .15371 L
.20662 .15371 L
.20662 .15365 L
.20663 .15357 L
.20663 .15346 L
.20663 .15336 L
.20663 .15326 L
.20663 .15317 L
.20663 .15312 L
.20663 .15313 L
.20663 .1532 L
.20663 .1533 L
.20663 .15343 L
.20663 .15358 L
.20662 .15376 L
.20662 .1539 L
.20662 .15399 L
.20662 .15407 L
.20662 .15413 L
.20662 .15418 L
.20662 .15423 L
.20662 .15431 L
.20662 .15443 L
.20662 .15461 L
.20662 .15483 L
.20662 .15509 L
.20662 .15538 L
.20661 .15567 L
.20661 .15588 L
.20661 .15599 L
.20661 .15596 L
.20661 .15583 L
.20661 .15561 L
.20662 .1553 L
Mistroke
.20662 .15493 L
.20662 .15455 L
.20662 .15414 L
.20662 .15374 L
.20663 .15336 L
.20663 .15303 L
.20663 .15277 L
.20663 .15261 L
.20663 .15254 L
.20663 .15252 L
.20663 .15254 L
.20663 .15258 L
.20663 .15264 L
.20663 .15269 L
.20663 .15272 L
.20663 .15272 L
.20663 .1527 L
.20663 .15267 L
.20663 .15263 L
.20663 .15262 L
.20663 .15265 L
.20663 .1527 L
.20663 .15277 L
.20663 .15285 L
.20663 .15295 L
.20663 .15303 L
.20663 .1531 L
.20663 .15316 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .15361 L
.20662 .15372 L
.20662 .15381 L
.20662 .15388 L
.20662 .15393 L
.20662 .15403 L
.20662 .15417 L
.20662 .15437 L
.20662 .1546 L
.20662 .15484 L
.20662 .15507 L
.20662 .15526 L
.20662 .15534 L
.20662 .15532 L
.20662 .15522 L
.20662 .15501 L
.20662 .15476 L
.20662 .15449 L
.20662 .15425 L
Mistroke
.20662 .15401 L
.20662 .1538 L
.20663 .1536 L
.20663 .15343 L
.20663 .15333 L
.20663 .15329 L
.20663 .15331 L
.20663 .15337 L
.20663 .15344 L
.20663 .15352 L
.20663 .1536 L
.20663 .15362 L
.20663 .15361 L
.20663 .15352 L
.20663 .15338 L
.20663 .1532 L
.20663 .15301 L
.20663 .15284 L
.20663 .1527 L
.20663 .15262 L
.20663 .1526 L
.20663 .15264 L
.20663 .15271 L
.20663 .15277 L
.20663 .15278 L
.20663 .15275 L
.20663 .15273 L
.20663 .15277 L
.20663 .15286 L
.20663 .15298 L
.20663 .15314 L
.20663 .1533 L
.20663 .15346 L
.20663 .15359 L
.20662 .15367 L
.20662 .15372 L
.20662 .15372 L
.20662 .15368 L
.20663 .15361 L
.20663 .15359 L
.20663 .15355 L
.20663 .15349 L
.20663 .1534 L
.20663 .1533 L
.20663 .1532 L
.20663 .15311 L
.20663 .15305 L
.20663 .15301 L
.20663 .15302 L
.20663 .15309 L
Mistroke
.20663 .15318 L
.20663 .15326 L
.20663 .15328 L
.20663 .15327 L
.20663 .15323 L
.20663 .15317 L
.20663 .15308 L
.20663 .15298 L
.20663 .15288 L
.20663 .15282 L
.20663 .15279 L
.20663 .15279 L
.20663 .15281 L
.20663 .15282 L
.20663 .15283 L
.20663 .15287 L
.20663 .15294 L
.20663 .15303 L
.20663 .15313 L
.20663 .15326 L
.20663 .15338 L
.20663 .1535 L
.20663 .1536 L
.20662 .15367 L
.20662 .1537 L
.20662 .1537 L
.20662 .15368 L
.20662 .15363 L
.20663 .15355 L
.20663 .15343 L
.20663 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .1529 L
.20663 .15277 L
.20663 .15267 L
.20663 .15264 L
.20663 .15267 L
.20663 .15275 L
.20663 .15289 L
.20663 .1531 L
.20663 .15341 L
.20662 .15381 L
.20662 .15422 L
.20662 .15464 L
.20662 .155 L
.20662 .15527 L
.20662 .15545 L
.20662 .15555 L
.20662 .15555 L
Mistroke
.20662 .15544 L
.20662 .15523 L
.20662 .15495 L
.20662 .15465 L
.20662 .15428 L
.20662 .15389 L
.20663 .1535 L
.20663 .15316 L
.20663 .1529 L
.20663 .15273 L
.20663 .15263 L
.20663 .15257 L
.20663 .15259 L
.20663 .15268 L
.20663 .15282 L
.20663 .15295 L
.20663 .15306 L
.20663 .15315 L
.20663 .15324 L
.20663 .15332 L
.20663 .15339 L
.20663 .15344 L
.20663 .15348 L
.20663 .1535 L
.20663 .15352 L
.20663 .15352 L
.20663 .15348 L
.20663 .15341 L
.20663 .15329 L
.20663 .15319 L
.20663 .15306 L
.20663 .15294 L
.20663 .15286 L
.20663 .15283 L
.20663 .15285 L
.20663 .1529 L
.20663 .15297 L
.20663 .15303 L
.20663 .15307 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15303 L
.20663 .15302 L
.20663 .15305 L
.20663 .15306 L
.20663 .15308 L
.20663 .1531 L
.20663 .15312 L
.20663 .15312 L
Mistroke
.20663 .15311 L
.20663 .1531 L
.20663 .15309 L
.20663 .15308 L
.20663 .15307 L
.20663 .15306 L
.20663 .15307 L
.20663 .15308 L
.20663 .15311 L
.20663 .15314 L
.20663 .15319 L
.20662 .15326 L
.20662 .15334 L
.20662 .15341 L
.20662 .15351 L
.20662 .15361 L
.20662 .15367 L
.20662 .1537 L
.20662 .15369 L
.20662 .15363 L
.20662 .15354 L
.20662 .15343 L
.20662 .15328 L
.20663 .15316 L
.20663 .15303 L
.20663 .15291 L
.20663 .15282 L
.20663 .15275 L
.20663 .15271 L
.20663 .15271 L
.20663 .15271 L
.20663 .1527 L
.20663 .15269 L
.20663 .15268 L
.20663 .15269 L
.20663 .15271 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
Mistroke
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15272 L
.20663 .15269 L
.20663 .15265 L
.20663 .1526 L
.20663 .15255 L
.20663 .15252 L
.20663 .15254 L
.20663 .15261 L
.20663 .15274 L
.20663 .15295 L
.20663 .15321 L
.20663 .15355 L
.20662 .15395 L
.20662 .1544 L
.20662 .15485 L
.20662 .15526 L
.20661 .15562 L
.20661 .15587 L
.20661 .15606 L
.20661 .15617 L
.20661 .15621 L
.20661 .15617 L
.20661 .15604 L
.20661 .15582 L
.20662 .15556 L
.20662 .15527 L
.20662 .15497 L
.20662 .15467 L
.20662 .15442 L
.20662 .15416 L
.20662 .15396 L
.20662 .15384 L
.20662 .15375 L
.20662 .15367 L
.20663 .15362 L
Mistroke
.20663 .15356 L
.20663 .15351 L
.20663 .15343 L
.20663 .15337 L
.20663 .15337 L
.20663 .15345 L
.20663 .15356 L
.20662 .15368 L
.20662 .1538 L
.20662 .15386 L
.20662 .15385 L
.20662 .15378 L
.20662 .15367 L
.20663 .15354 L
.20663 .15341 L
.20663 .15334 L
.20663 .15337 L
.20663 .15348 L
.20662 .1537 L
.20662 .15398 L
.20662 .1543 L
.20662 .15462 L
.20662 .15488 L
.20662 .15509 L
.20662 .15526 L
.20662 .15537 L
.20662 .15541 L
.20662 .15538 L
.20662 .15522 L
.20662 .15496 L
.20662 .15461 L
.20662 .15418 L
.20662 .15369 L
.20663 .1532 L
.20663 .15276 L
.20663 .15243 L
.20663 .15228 L
.20663 .15231 L
.20663 .15249 L
.20663 .15278 L
.20663 .15311 L
.20663 .15345 L
.20662 .15375 L
.20662 .15397 L
.20662 .15412 L
.20662 .15422 L
.20662 .15428 L
.20662 .15432 L
.20662 .15432 L
.20662 .15427 L
Mistroke
.20662 .15414 L
.20662 .15395 L
.20662 .15372 L
.20663 .15347 L
.20663 .1532 L
.20663 .15295 L
.20663 .15279 L
.20663 .15272 L
.20663 .15277 L
.20663 .1529 L
.20663 .15305 L
.20663 .15317 L
.20663 .15327 L
.20663 .15334 L
.20663 .15341 L
.20663 .15345 L
.20663 .15346 L
.20663 .15344 L
.20663 .15341 L
.20663 .1534 L
.20663 .1534 L
.20663 .15345 L
.20663 .15356 L
.20662 .15374 L
.20662 .15396 L
.20662 .15421 L
.20662 .15443 L
.20662 .1546 L
.20662 .15471 L
.20662 .15479 L
.20662 .15487 L
.20662 .15492 L
.20662 .15489 L
.20662 .15481 L
.20662 .15466 L
.20662 .15442 L
.20662 .15411 L
.20662 .15379 L
.20663 .15351 L
.20663 .15329 L
.20663 .15321 L
.20663 .15326 L
.20663 .15341 L
.20663 .15359 L
.20662 .15378 L
.20662 .15394 L
.20662 .15408 L
.20662 .15416 L
.20662 .15419 L
.20662 .15418 L
Mistroke
.20662 .15418 L
.20662 .15416 L
.20662 .15411 L
.20662 .15407 L
.20662 .15399 L
.20662 .1539 L
.20662 .15381 L
.20662 .15376 L
.20662 .15373 L
.20662 .15373 L
.20662 .15372 L
.20662 .15373 L
.20662 .15369 L
.20662 .15361 L
.20662 .15346 L
.20662 .15334 L
.20663 .15321 L
.20663 .15309 L
.20663 .153 L
.20663 .15301 L
.20663 .15313 L
.20663 .15337 L
.20662 .15368 L
.20662 .15406 L
.20662 .15445 L
.20662 .15482 L
.2066 .15509 L
.20657 .15526 L
.20653 .15534 L
.20649 .15531 L
.20648 .15519 L
.20649 .15499 L
.20655 .15472 L
.20665 .15436 L
.2068 .15395 L
.207 .15354 L
.20723 .15316 L
.20749 .15287 L
.20776 .15268 L
.20802 .15258 L
.20828 .15255 L
.20853 .15258 L
.20875 .15266 L
.20893 .15278 L
.20905 .1529 L
.20914 .15299 L
.20921 .15303 L
.20927 .15299 L
.20935 .15287 L
.20947 .15269 L
Mistroke
.20961 .15247 L
.20976 .15224 L
.20994 .15201 L
.21013 .15176 L
.21033 .15149 L
.21052 .15119 L
.21071 .15088 L
.2109 .15054 L
.21109 .1502 L
.21127 .14984 L
.21142 .14952 L
.21152 .14925 L
.21157 .14907 L
.21159 .14891 L
.21161 .14878 L
.21162 .14867 L
.21167 .14856 L
.21173 .14842 L
.2118 .14828 L
.21185 .14816 L
.21188 .14809 L
.21189 .14808 L
.21187 .14812 L
.21184 .14818 L
.21182 .14823 L
.21182 .14824 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
Mistroke
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14825 L
.21182 .14824 L
.21182 .14823 L
.21183 .1482 L
.21184 .14818 L
.21184 .14817 L
.21183 .14819 L
.21182 .14824 L
.21179 .14831 L
.21176 .14839 L
.21173 .14847 L
.21171 .14855 L
.21168 .14861 L
.21167 .14866 L
.21166 .14869 L
.21167 .14869 L
.2117 .14868 L
.21174 .14868 L
.21178 .14866 L
.21181 .14863 L
.21182 .14858 L
.21178 .14852 L
.21168 .14845 L
.21154 .14839 L
.21136 .14833 L
.21118 .14829 L
.21102 .14827 L
.21088 .14828 L
.21077 .1483 L
.2107 .14833 L
.21068 .14834 L
.21069 .14833 L
.21073 .14832 L
.21079 .1483 L
.21091 .14828 L
.21108 .14826 L
Mistroke
.21128 .14824 L
.21149 .14822 L
.2117 .14821 L
.21187 .1482 L
.212 .14821 L
.21207 .14822 L
.21207 .14824 L
.21202 .14826 L
.21193 .14828 L
.2118 .14831 L
.21164 .14833 L
.21144 .14835 L
.2112 .14836 L
.21095 .14836 L
.21067 .14836 L
.21039 .14835 L
.21011 .14833 L
.20985 .14828 L
.20963 .14823 L
.20944 .14819 L
.20929 .14817 L
.2092 .14818 L
.20916 .14822 L
.20917 .1483 L
.20921 .14841 L
.20925 .14854 L
.20929 .14867 L
.20932 .14878 L
.20933 .14886 L
.20934 .1489 L
.20933 .14889 L
.20933 .14887 L
.20932 .14888 L
.2093 .1489 L
.20927 .14893 L
.20925 .14893 L
.20923 .14892 L
.20922 .1489 L
.20921 .14889 L
.20921 .14891 L
.20922 .14899 L
.20922 .1491 L
.20923 .1493 L
.20923 .14954 L
.20923 .1498 L
.20923 .15007 L
.20922 .15033 L
.20922 .15056 L
.20922 .1508 L
.20922 .15101 L
Mistroke
.20922 .15123 L
.20922 .15151 L
.20922 .15176 L
.20922 .15205 L
.20922 .1523 L
.20922 .1525 L
.20922 .15259 L
.20922 .15262 L
.20922 .15259 L
.20922 .15254 L
.20922 .15241 L
.20922 .15237 L
.20922 .15234 L
.20922 .15233 L
.20922 .15232 L
.20922 .15232 L
.20922 .15232 L
.20922 .15233 L
.20922 .15236 L
.20922 .15243 L
.20922 .15252 L
.20921 .15262 L
.20921 .15272 L
.20921 .1528 L
.20921 .15286 L
.20921 .15289 L
.20921 .15289 L
.20921 .15286 L
.20921 .15282 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.2092 .1528 L
.20917 .1528 L
.20913 .1528 L
.20909 .1528 L
.20907 .1528 L
.20908 .1528 L
.20915 .1528 L
.20928 .15281 L
.20946 .15281 L
.20969 .15283 L
.20993 .15286 L
.21016 .15287 L
.21038 .15288 L
.21056 .15288 L
.21071 .15288 L
.21081 .15285 L
.21086 .15281 L
.21087 .15276 L
.21081 .15269 L
.21071 .15262 L
.21056 .15253 L
.21037 .15244 L
.21015 .15235 L
.20994 .15227 L
.20976 .15219 L
.20963 .15211 L
.20954 .15205 L
.2095 .152 L
.2095 .15199 L
.20954 .15202 L
.20961 .15207 L
.2097 .15212 L
.20979 .15218 L
.20988 .15223 L
.20996 .15229 L
.21002 .15232 L
.21006 .15237 L
.21007 .15243 L
.21004 .15248 L
.21001 .15252 L
.20996 .15257 L
.2099 .15262 L
.20981 .15265 L
.20971 .15267 L
.20959 .15269 L
.20947 .15271 L
Mistroke
.20935 .15272 L
.20925 .15274 L
.20917 .15276 L
.20912 .15279 L
.20911 .15281 L
.20913 .15283 L
.20917 .15284 L
.2092 .15283 L
.20921 .15282 L
.20921 .15281 L
.20921 .1528 L
.20921 .15281 L
.20921 .15281 L
.20921 .15283 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
.20921 .15279 L
.20921 .15276 L
.20921 .15274 L
.20921 .15272 L
.20921 .1527 L
.20921 .15267 L
.20921 .15265 L
.20921 .15262 L
.20922 .15258 L
.20922 .15253 L
.20922 .15248 L
.20922 .15242 L
.20922 .15237 L
.20922 .15233 L
.20922 .15231 L
.20922 .15231 L
.20922 .15231 L
.20922 .15233 L
.20922 .15236 L
.20922 .1524 L
.20922 .15241 L
.20922 .15246 L
.20922 .15252 L
.20921 .1526 L
.20921 .15267 L
.20921 .15274 L
.20921 .15279 L
.20921 .15282 L
.20921 .15284 L
.20921 .15284 L
.20921 .15284 L
.20921 .15283 L
.20921 .15282 L
Mistroke
.20921 .15281 L
.20921 .15281 L
.2092 .15282 L
.20919 .15284 L
.20918 .15286 L
.20916 .15289 L
.20914 .15292 L
.20913 .15295 L
.20913 .15296 L
.20915 .15292 L
.2092 .15283 L
.2093 .15266 L
.20944 .15241 L
.20962 .15209 L
.20984 .15171 L
.21008 .15128 L
.21033 .15085 L
.21059 .15039 L
.21084 .14996 L
.21108 .14953 L
.21131 .14913 L
.21153 .14876 L
.21171 .14844 L
.21185 .14819 L
.21193 .14805 L
.21196 .148 L
.21194 .14803 L
.21187 .14813 L
.21179 .14827 L
.21169 .14843 L
.21161 .14857 L
.21154 .14866 L
.2115 .14871 L
.21148 .14873 L
.21147 .14875 L
.21147 .14876 L
.21147 .14878 L
.21149 .14879 L
.21152 .14877 L
.21157 .14873 L
.21163 .14866 L
.21169 .14859 L
.21176 .14851 L
.21183 .14843 L
.2119 .14837 L
.21196 .14834 L
.21199 .14834 L
.21199 .14836 L
.21196 .14837 L
.21189 .14836 L
Mistroke
.21179 .14832 L
.21163 .14828 L
.21142 .14824 L
.21117 .14821 L
.21091 .14817 L
.21066 .14814 L
.21042 .14813 L
.21019 .14814 L
.20998 .14814 L
.20979 .14813 L
.20963 .14813 L
.20951 .14817 L
.20941 .14826 L
.20933 .14837 L
.20929 .1485 L
.20928 .14863 L
.2093 .14877 L
.20934 .1489 L
.20939 .14901 L
.20943 .14911 L
.20949 .14917 L
.20959 .14919 L
.20976 .14914 L
.20998 .14906 L
.21023 .14894 L
.21048 .14882 L
.21071 .14875 L
.21092 .14874 L
.21104 .14883 L
.2111 .14898 L
.21109 .1492 L
.21103 .14946 L
.21094 .14973 L
.21083 .15001 L
.21071 .15027 L
.21059 .15048 L
.21051 .1506 L
.21046 .15065 L
.21046 .15064 L
.21051 .15053 L
.21062 .15036 L
.21079 .15008 L
.21101 .14971 L
.21122 .14935 L
.21144 .14897 L
.21163 .14865 L
.21176 .1484 L
.21184 .14826 L
.21188 .14817 L
.21191 .14809 L
Mistroke
.21194 .14802 L
.21198 .14796 L
.212 .14795 L
.21198 .14799 L
.21192 .1481 L
.2118 .14827 L
.21164 .1485 L
.21144 .14878 L
.21121 .14912 L
.21095 .1495 L
.21068 .14992 L
.21042 .15036 L
.21015 .1508 L
.20989 .15123 L
.20965 .15168 L
.20943 .15199 L
.20927 .15231 L
.20915 .15256 L
.20908 .15273 L
.20906 .15283 L
.20908 .15288 L
.20912 .15288 L
.20916 .15288 L
.20919 .15287 L
.20921 .15287 L
.20921 .15287 L
.20921 .15285 L
.20921 .15283 L
.20921 .15281 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
Mistroke
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20921 .1528 L
.20922 .1528 L
.20924 .15276 L
.20931 .15266 L
.20943 .1525 L
.20959 .15229 L
.20976 .15206 L
.20992 .15185 L
.21002 .15173 L
.21 .15176 L
Mfstroke
.07988 .40133 m
.07992 .4014 L
.07997 .40124 L
.08002 .40095 L
.08007 .40065 L
.08009 .4004 L
.0801 .40024 L
.0801 .40015 L
.08009 .4001 L
.08006 .40006 L
.08001 .40002 L
.07997 .39999 L
.07995 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08072 .40066 L
.08098 .40089 L
.08126 .40114 L
.08151 .40139 L
.08175 .40164 L
.08198 .40188 L
.08218 .4021 L
.08236 .40229 L
.08252 .40244 L
.08265 .40255 L
.08279 .40261 L
.08296 .40263 L
.08316 .40261 L
.08342 .40257 L
.08376 .40251 L
.08418 .40245 L
.08468 .40242 L
.08524 .40242 L
.0858 .40244 L
.08631 .40247 L
.08676 .40252 L
.08712 .40257 L
.08741 .40259 L
.08759 .40257 L
.08768 .40253 L
.08768 .40248 L
.08764 .40243 L
.08759 .4024 L
.08755 .40244 L
.08754 .40254 L
s
.07225 .60733 m
0 0 rlineto s
.09429 .72501 m
.0944 .72499 L
.09444 .7248 L
.09442 .72451 L
.09437 .72419 L
.09431 .72395 L
.09425 .72383 L
.0942 .72378 L
.09416 .72375 L
.09415 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09416 .72375 L
.09419 .72378 L
.09423 .72382 L
.09427 .72386 L
.09429 .72388 L
.09427 .72386 L
.09422 .72381 L
.09411 .72371 L
.09396 .72357 L
.09375 .72339 L
.09352 .72318 L
.09326 .72294 L
.09298 .72269 L
.09271 .72244 L
.09244 .72219 L
.09218 .72195 L
.09193 .72173 L
.09172 .72153 L
.09154 .72138 L
.09142 .72127 L
.09136 .72121 L
.09133 .72119 L
.09134 .72119 L
.09135 .7212 L
.09135 .7212 L
.09134 .7212 L
.09134 .72119 L
.09135 .72121 L
.09141 .72126 L
.09152 .72136 L
.09167 .7215 L
.09187 .72168 L
.09211 .72189 L
.09237 .72213 L
.09264 .72238 L
.09291 .72263 L
Mistroke
.09318 .72288 L
.09345 .72312 L
.09369 .72335 L
.09391 .72354 L
.09408 .72369 L
.0942 .7238 L
.09427 .72386 L
.09429 .72388 L
.09428 .72386 L
.09424 .72383 L
.09419 .72379 L
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .72291 L
.09417 .72264 L
Mistroke
.09417 .72238 L
.09418 .72212 L
.09419 .72187 L
.09419 .72164 L
.0942 .72143 L
.0942 .72127 L
.09421 .72117 L
.09422 .72113 L
.09425 .72117 L
.09429 .72126 L
.09433 .72137 L
.09435 .72145 L
.09433 .72146 L
.09428 .72137 L
.09417 .72118 L
.09402 .72089 L
.09382 .72052 L
.09359 .72008 L
.09334 .7196 L
.09307 .71909 L
.09281 .71858 L
.09254 .71808 L
.09229 .71759 L
.09205 .71713 L
.09183 .71674 L
.09167 .71642 L
.09155 .7162 L
.09149 .71607 L
.09148 .71605 L
.09153 .7161 L
.0916 .71618 L
.09168 .71626 L
.09174 .71631 L
.09174 .71633 L
.09169 .71634 L
.09159 .71635 L
.09143 .71635 L
.09122 .71634 L
.09098 .71629 L
.09072 .71619 L
.09045 .71604 L
.09018 .71581 L
.08991 .71553 L
.08966 .71518 L
.08943 .71479 L
.08923 .71437 L
.08906 .71395 L
.08894 .71351 L
.08882 .71305 L
.08876 .71266 L
Mistroke
.08875 .71226 L
.08878 .71192 L
.08884 .71163 L
.08893 .71141 L
.08905 .71128 L
.0892 .71123 L
.08941 .71123 L
.08965 .71125 L
.08991 .71128 L
.09018 .7113 L
.09046 .71131 L
.09074 .71132 L
.09101 .71133 L
.09126 .71132 L
.09149 .71131 L
.09167 .71131 L
.09179 .7113 L
.09186 .7113 L
.09189 .7113 L
.09187 .7113 L
.09183 .7113 L
.09179 .7113 L
.09175 .71128 L
.09174 .71122 L
.09174 .71115 L
.09174 .71109 L
.09174 .71106 L
.09174 .71109 L
.09174 .71119 L
.09173 .71135 L
.09173 .71158 L
.09172 .71189 L
.09171 .71227 L
.0917 .71269 L
.09169 .71316 L
.09168 .71364 L
.09167 .71412 L
.09165 .7146 L
.09164 .71509 L
.09163 .71548 L
.09162 .71584 L
.09162 .71612 L
.09161 .71631 L
.09161 .71641 L
.09161 .71645 L
.09161 .71644 L
.09161 .71641 L
.09161 .71639 L
.09161 .71638 L
.09161 .71637 L
Mistroke
.09161 .71636 L
.09161 .71634 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09159 .71632 L
.09156 .71632 L
.09152 .71632 L
.09148 .71632 L
.09146 .71633 L
.09148 .71632 L
.09153 .71632 L
.09164 .71632 L
.0918 .71631 L
.09201 .7163 L
.09225 .71629 L
.09251 .71628 L
.09279 .71627 L
.09307 .71626 L
.09334 .71625 L
.09361 .71624 L
.09386 .71623 L
.09408 .71622 L
.09426 .71622 L
.09439 .71621 L
.09445 .71621 L
.09448 .71621 L
.09446 .71621 L
.09442 .71621 L
.09438 .71621 L
.09434 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
.09433 .71621 L
Mistroke
.09433 .71621 L
.09433 .71621 L
.09433 .71622 L
.09433 .71624 L
.09433 .7163 L
.09433 .71638 L
.09433 .71645 L
.09432 .71649 L
.09432 .71647 L
.09431 .71636 L
.09431 .71616 L
.09431 .71587 L
.09431 .71549 L
.09432 .71504 L
.09432 .71455 L
.09433 .71404 L
.09435 .71352 L
.09436 .71301 L
.09437 .71251 L
.09439 .71205 L
.0944 .71164 L
.09442 .71131 L
.09443 .71108 L
.09445 .71095 L
.09445 .71091 L
.09446 .71094 L
.09446 .71101 L
.09446 .7111 L
.09446 .71116 L
.09445 .71119 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
.09445 .7112 L
Mistroke
.09445 .7112 L
.09445 .7112 L
.09445 .71122 L
.09445 .71125 L
.09445 .71129 L
.09445 .71139 L
.09444 .71155 L
.09444 .71174 L
.09444 .71189 L
.09445 .71196 L
.09449 .71189 L
Mfstroke
.06658 .47658 m
.06672 .47653 L
.06679 .47664 L
.06681 .47682 L
.06679 .47705 L
.06675 .47734 L
.06669 .47763 L
.06664 .47788 L
.06661 .47805 L
.06659 .47808 L
.06657 .47794 L
s
.07019 .45525 m
.07026 .45523 L
.07028 .45529 L
.07026 .45538 L
.07022 .45547 L
.07017 .45554 L
.07014 .45559 L
.07012 .45563 L
.07012 .45562 L
.07012 .45559 L
.07012 .45557 L
.07012 .45555 L
.07013 .45554 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .4556 L
.07015 .45562 L
.07019 .45566 L
.07024 .4557 L
.07026 .45572 L
.07026 .45571 L
.07022 .45565 L
.07013 .45556 L
.06998 .45542 L
.06979 .45524 L
Mistroke
.06955 .45503 L
.06927 .4548 L
.06896 .45455 L
.06862 .4543 L
.06835 .45405 L
.06806 .45381 L
.06782 .45359 L
.06764 .4534 L
.06756 .45325 L
.06759 .45314 L
.06773 .45307 L
.06795 .45305 L
.06822 .45306 L
.06854 .45309 L
.06887 .45313 L
.06919 .45316 L
.06949 .45317 L
.06975 .45317 L
.06997 .45316 L
.07015 .45316 L
.07027 .45316 L
.07034 .45316 L
.07036 .45316 L
.07035 .45316 L
.07031 .45316 L
.07026 .45316 L
.07022 .45316 L
.0702 .45316 L
.07019 .45314 L
.07016 .45312 L
.07011 .45308 L
.07008 .45304 L
.07005 .45302 L
.07007 .45303 L
.07012 .45309 L
.07023 .45318 L
.07039 .45332 L
.07059 .4535 L
.07082 .45371 L
.07108 .45395 L
.07136 .4542 L
.07161 .45445 L
.07182 .45471 L
.07199 .45498 L
.07214 .45524 L
.07227 .45547 L
.07238 .45564 L
.07248 .45575 L
.07264 .45579 L
Mfstroke
.09317 .31859 m
0 0 rlineto s
.34603 .07209 m
.34603 .07198 L
.34589 .07195 L
.34571 .07197 L
.34554 .072 L
.34539 .07207 L
.34528 .07215 L
.34521 .07223 L
.34517 .07228 L
.34514 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
Mistroke
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34512 .07231 L
.34515 .07229 L
.3452 .07225 L
.34528 .07219 L
.34534 .07215 L
.34536 .07214 L
.34533 .07219 L
.34523 .07229 L
.34506 .07245 L
.34479 .07264 L
.34444 .07287 L
.34402 .07312 L
.34356 .07333 L
.34311 .07348 L
.34268 .07358 L
.34229 .07365 L
.34192 .07372 L
.34159 .07382 L
.34131 .07392 L
.34109 .07406 L
.34093 .07419 L
.34083 .07432 L
.34078 .07449 L
.34078 .07465 L
.34079 .07484 L
.34081 .07503 L
.34079 .07532 L
.34071 .07567 L
.3406 .07603 L
.34049 .07635 L
.34037 .0766 L
.34027 .07677 L
.34018 .07688 L
.34012 .07691 L
.3401 .0769 L
.34013 .07685 L
.34016 .07678 L
.34019 .07674 L
.34021 .07671 L
.34021 .07671 L
Mistroke
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.34021 .07671 L
.3402 .07673 L
.34017 .07678 L
.34013 .07685 L
.34009 .07692 L
.34007 .07695 L
.34008 .07694 L
.34011 .07685 L
Mfstroke
.6036 .05736 m
.60369 .05737 L
.60375 .05737 L
.60378 .05737 L
.60378 .05737 L
.60376 .05737 L
.60373 .05737 L
.60369 .05737 L
.60366 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05736 L
.60364 .05735 L
.60364 .05731 L
.60362 .05726 L
.60358 .05721 L
.60352 .05717 L
.60345 .05717 L
.6034 .05722 L
.6034 .05734 L
.60346 .05752 L
.6036 .05778 L
.60382 .05812 L
.6041 .05851 L
.60445 .05894 L
.60483 .05939 L
.60525 .05982 L
.60569 .06028 L
.60619 .06067 L
.6067 .06108 L
.60723 .06143 L
.60775 .06172 L
.60825 .06191 L
.6087 .06202 L
.60909 .06206 L
.60941 .06206 L
.60965 .06202 L
.60984 .06198 L
.61 .06195 L
.61014 .06194 L
.61028 .06193 L
.6104 .06192 L
Mistroke
.6105 .06192 L
.61055 .06193 L
.61057 .06193 L
.61055 .06193 L
.61052 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61045 .06193 L
.6105 .06195 L
.61057 .062 L
.61064 .06207 L
.61068 .06213 L
.61066 .06216 L
.61057 .06214 L
.6104 .06204 L
.61014 .06186 L
.60979 .0616 L
.60939 .06126 L
.60895 .06086 L
.60851 .06041 L
.60808 .05996 L
.60773 .0595 L
.60733 .05906 L
.60693 .05862 L
.60653 .0582 L
.60613 .05783 L
.60575 .05753 L
.60536 .05732 L
.60498 .0572 L
.6046 .05715 L
.60423 .05716 L
.60385 .05721 L
.60345 .05728 L
.603 .05732 L
.60255 .05733 L
.60213 .05733 L
.60176 .05732 L
.60147 .05731 L
.60127 .05731 L
.60115 .05731 L
.60112 .05731 L
.60115 .05731 L
.60121 .05733 L
.60129 .05736 L
Mistroke
.60136 .05739 L
.60141 .05739 L
.60146 .05736 L
.60149 .05731 L
.60152 .05724 L
.60156 .05718 L
.60159 .05715 L
.60162 .05716 L
.6016 .05716 L
.60154 .05712 L
Mfstroke
.57865 .05032 m
.57866 .05017 L
.57866 .05006 L
.57866 .04997 L
.57866 .04991 L
.57866 .04985 L
.57866 .04981 L
.57866 .0498 L
.5787 .04984 L
.57877 .04996 L
s
.5947 .05713 m
.5948 .05704 L
.59496 .05681 L
.59519 .05646 L
.59548 .05602 L
.59581 .05554 L
.59617 .05505 L
.59658 .0546 L
.59702 .05417 L
.59746 .05375 L
.59788 .05334 L
.59826 .05296 L
.5986 .05262 L
.5989 .05233 L
.59916 .05209 L
.59939 .05189 L
.59954 .05171 L
.5996 .05155 L
.59956 .05139 L
.59942 .0512 L
.59915 .051 L
.59876 .05084 L
.59827 .05072 L
.5977 .05063 L
.59707 .05059 L
.5964 .05057 L
.59571 .05058 L
.59504 .0506 L
.59437 .05062 L
.59373 .05064 L
.59316 .05063 L
.59269 .05061 L
.59235 .05059 L
.59213 .05056 L
.59202 .05051 L
.59201 .05046 L
.59207 .0504 L
.5922 .05035 L
.59238 .05032 L
s
.50577 .04847 m
.50572 .04847 L
.50585 .04847 L
.50611 .04846 L
.50642 .04844 L
.50671 .04841 L
.50695 .04836 L
.50713 .0483 L
.50725 .04825 L
.50737 .0482 L
s
.66713 .08107 m
.66719 .081 L
.66712 .08093 L
s
.54366 .04924 m
.54366 .04914 L
.54369 .04908 L
.54375 .04907 L
.54387 .04909 L
.54407 .04915 L
.54435 .04922 L
.54472 .04928 L
.54516 .04932 L
.54567 .04938 L
.54625 .04941 L
.54689 .04944 L
.54756 .04947 L
.54824 .04949 L
.5489 .04951 L
.54952 .04952 L
.55007 .04952 L
.55055 .04952 L
.55092 .0495 L
.5512 .04948 L
.55137 .04946 L
.55146 .04943 L
.55147 .04941 L
.55144 .0494 L
.55138 .04939 L
.55132 .0494 L
.55127 .0494 L
.55126 .0494 L
.55131 .04938 L
.55142 .04934 L
.55152 .04931 L
.55159 .0493 L
.55159 .04931 L
.55151 .04935 L
s
.45742 .04892 m
.45733 .04892 L
.45736 .04892 L
.45747 .04892 L
.45762 .04893 L
.45778 .04893 L
.45792 .04894 L
.45801 .04894 L
.45807 .04894 L
.4581 .04894 L
.45811 .04894 L
.45811 .04894 L
.45811 .04894 L
.45814 .04896 L
.45819 .04899 L
.45827 .04903 L
.45834 .04906 L
.45837 .04908 L
.45835 .04907 L
.45825 .04901 L
.45806 .04892 L
.45778 .04878 L
.45742 .04859 L
.457 .04838 L
.45654 .04814 L
.45605 .04789 L
.45556 .04764 L
.45506 .04739 L
.45458 .04714 L
.45411 .04689 L
.45369 .04666 L
.45336 .04647 L
.45313 .04634 L
.45302 .04629 L
.45304 .04632 L
s
.37949 .05563 m
.37951 .05549 L
.37976 .05529 L
.38022 .05502 L
.38084 .05469 L
.38162 .05431 L
.38253 .0539 L
.38349 .05346 L
.38448 .05304 L
.38543 .05262 L
.38636 .05222 L
.38726 .05187 L
.3881 .05159 L
.38884 .05138 L
.38945 .05122 L
.38991 .0511 L
.39025 .051 L
.39048 .05086 L
.39063 .05068 L
.39072 .05042 L
.39077 .05008 L
.3908 .04966 L
.3908 .0492 L
.39079 .04874 L
.39076 .04832 L
.39074 .04791 L
.39072 .04752 L
.39073 .04718 L
.39078 .04691 L
.39086 .04669 L
.39095 .0465 L
.39104 .04633 L
.39111 .04618 L
.39115 .04605 L
.39119 .04593 L
.39122 .0458 L
.39128 .04569 L
.39139 .04561 L
.3916 .04556 L
.3919 .04554 L
.39227 .04557 L
.39271 .04564 L
.39317 .04574 L
.39365 .04588 L
.39413 .04607 L
.39458 .04627 L
.39499 .04648 L
.39536 .04665 L
.3957 .04675 L
.39599 .04677 L
Mistroke
.39622 .04675 L
.39639 .04671 L
.3965 .0467 L
.39659 .04675 L
.39668 .04691 L
.39677 .04716 L
.3969 .04751 L
.39705 .04792 L
.39724 .04838 L
.39744 .04885 L
.39765 .04932 L
.39784 .04978 L
.398 .05023 L
.39815 .05066 L
.39826 .05103 L
.39835 .05133 L
.39841 .05154 L
.39846 .05166 L
.39851 .0517 L
.39857 .05168 L
.39864 .05161 L
.39869 .05154 L
.39873 .05149 L
.39873 .05146 L
.39872 .05147 L
.39869 .05148 L
.39863 .05148 L
.39851 .05147 L
.39831 .05144 L
.39804 .05141 L
.39771 .05138 L
.39732 .05134 L
.39689 .0513 L
.39642 .05126 L
.39594 .05123 L
.39547 .05121 L
.39503 .05119 L
.39462 .05117 L
.39427 .05116 L
.39398 .05115 L
.39377 .05116 L
.39363 .05117 L
.39356 .05119 L
.39354 .05122 L
.39355 .05125 L
.39358 .05127 L
.39362 .05129 L
.39367 .0513 L
.3937 .0513 L
.39373 .0513 L
Mistroke
.39376 .05131 L
.3938 .05133 L
.39384 .05133 L
.39386 .05132 L
.39384 .05129 L
.39379 .05124 L
.3937 .05119 L
Mfstroke
.3894 .05052 m
.38953 .05051 L
.38958 .05054 L
.38959 .0506 L
.38959 .05068 L
.38964 .05077 L
.38978 .05082 L
.38999 .05084 L
.39021 .05086 L
.39045 .0509 L
.39069 .05095 L
.39091 .05101 L
.39111 .05108 L
.39126 .05114 L
.39137 .05119 L
.39143 .05123 L
.39145 .05125 L
.39143 .05125 L
.3914 .05122 L
.39136 .0512 L
.39133 .0512 L
.39134 .05122 L
.39139 .05127 L
.39147 .05134 L
.39154 .05141 L
.39158 .05145 L
.39155 .05142 L
.39145 .05131 L
s
.24504 .12617 m
.24505 .12618 L
.24512 .12617 L
.24512 .12623 L
s
.21899 .14662 m
.21898 .14666 L
.21905 .14661 L
.21916 .14651 L
.21931 .14639 L
.21943 .14628 L
.21951 .14622 L
.21954 .14618 L
.21956 .14618 L
.21959 .14616 L
.21968 .14614 L
.2198 .14611 L
.21991 .14607 L
.21997 .14606 L
.21993 .14607 L
.21976 .14611 L
.21946 .1462 L
.21901 .14632 L
.21842 .14648 L
.21773 .14666 L
.21697 .14686 L
.21618 .14708 L
.21539 .14729 L
.21462 .14748 L
.21386 .14763 L
.21314 .14775 L
.21251 .14784 L
.21203 .14789 L
.21174 .14792 L
.21166 .14792 L
s
.08018 .40021 m
.08024 .40014 L
.08024 .40011 L
.08021 .40011 L
.08016 .40011 L
.08013 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08012 .40009 L
.08016 .40006 L
.08021 .40002 L
.08025 .39998 L
.08027 .39997 L
.08025 .39998 L
.08018 .40003 L
.08006 .40013 L
.07988 .40027 L
.07965 .40046 L
.07939 .40067 L
.07911 .40091 L
.07882 .40115 L
.07854 .40138 L
.0783 .40159 L
.07807 .40178 L
.07785 .40195 L
.07765 .40211 L
.07747 .40228 L
.07733 .40242 L
.07723 .40256 L
s
.06255 .43649 m
.06255 .43659 L
.06253 .43664 L
.0625 .43672 L
.06245 .43687 L
.0624 .43714 L
.06237 .43753 L
.06236 .43804 L
.06238 .43866 L
.06244 .43933 L
.06253 .44004 L
.06267 .44076 L
.06287 .44145 L
.06313 .44209 L
.06345 .44264 L
.06382 .44309 L
.06422 .44343 L
.06465 .44365 L
.0651 .44377 L
.06556 .4438 L
.06604 .44378 L
.06651 .44373 L
.06696 .44368 L
.06739 .44363 L
.06778 .44358 L
.06817 .44354 L
.06855 .44352 L
.06894 .44351 L
.06934 .44351 L
.06975 .4435 L
.07019 .4435 L
.07066 .44349 L
.07117 .44348 L
.07167 .44348 L
.07212 .44347 L
.07248 .44348 L
.07273 .44351 L
.07284 .44355 L
.07279 .44359 L
s
.06543 .49305 m
.06542 .49323 L
.06552 .49332 L
.06566 .49337 L
.06579 .49348 L
s
.06258 .5144 m
.06259 .51447 L
.0626 .51448 L
.0626 .51442 L
.06261 .51434 L
.06263 .51422 L
.06269 .5141 L
.06277 .51399 L
.06285 .51395 L
.06288 .51397 L
.06286 .51402 L
.06275 .51411 L
.06255 .51422 L
.06223 .51435 L
.06181 .51448 L
.06131 .5146 L
.06076 .5147 L
.06021 .51477 L
.05967 .51482 L
.05916 .51484 L
.05864 .51485 L
.05813 .51484 L
.05766 .5148 L
.05729 .51472 L
.05704 .51462 L
.05691 .5145 L
.05686 .51438 L
.05689 .51429 L
.05696 .51425 L
.05705 .51426 L
.05711 .51432 L
.05713 .51438 L
.05713 .51439 L
.05713 .51433 L
s
.06621 .48964 m
.06622 .48954 L
.06622 .48948 L
.06622 .48947 L
.06622 .48948 L
.06622 .48952 L
.06622 .48956 L
.06621 .48959 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48961 L
.06621 .48962 L
.06622 .48964 L
Mistroke
.06624 .4897 L
.06626 .48978 L
.06626 .48986 L
.06624 .48992 L
.06621 .48994 L
.06616 .48991 L
.0661 .48978 L
.06605 .48954 L
.06601 .48919 L
.06598 .4887 L
.06597 .48808 L
.06598 .48732 L
.066 .48649 L
.06603 .4856 L
.06606 .48467 L
.06611 .4837 L
.06618 .48268 L
.06626 .48166 L
.06635 .48058 L
.06645 .47947 L
.06654 .47833 L
.06661 .47719 L
.06664 .47604 L
.06666 .47489 L
.06669 .47376 L
.06674 .47282 L
.06683 .47174 L
.06698 .4708 L
.06716 .46985 L
.06733 .46889 L
.06748 .46796 L
.06761 .4671 L
.06774 .46631 L
.06788 .46556 L
.06803 .46481 L
.0682 .46405 L
.0684 .46325 L
.0686 .46239 L
.0688 .46147 L
.06899 .46049 L
.06915 .45951 L
.06927 .4586 L
.0694 .4578 L
.06952 .4571 L
.06967 .45652 L
.06982 .45606 L
.06999 .45572 L
.07013 .45549 L
.07022 .45536 L
.07026 .45532 L
Mistroke
.07025 .45534 L
.07021 .45541 L
.07016 .4555 L
.07013 .45558 L
.07011 .45563 L
.07011 .45562 L
.07011 .45558 L
.07011 .45556 L
.07011 .45559 L
.07011 .45566 L
.0701 .45575 L
.0701 .45588 L
.07009 .45603 L
.07009 .4562 L
.07008 .45636 L
.07008 .45651 L
.07007 .45664 L
.07007 .45673 L
.07006 .4568 L
.07006 .45683 L
.07006 .45684 L
.07006 .45678 L
.07007 .45668 L
.07008 .45649 L
.07009 .45633 L
.0701 .45612 L
.0701 .45592 L
.07011 .45575 L
.07012 .45562 L
.07012 .45555 L
.07012 .45553 L
.07012 .45552 L
.07012 .45553 L
.07013 .45553 L
.07013 .45553 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07014 .4556 L
.07019 .45562 L
.07027 .45566 L
Mistroke
.07035 .4557 L
.07038 .45571 L
.07036 .4557 L
.07026 .45565 L
Mfstroke
.06309 .41451 m
.06312 .41443 L
.0632 .41441 L
.06334 .41444 L
.06354 .4145 L
.06381 .41455 L
.06415 .41458 L
.06455 .41453 L
.06498 .41442 L
.06546 .41425 L
.06599 .41405 L
.06655 .41382 L
.06718 .41358 L
.06776 .41333 L
.06837 .4131 L
.06899 .41287 L
.06962 .41265 L
.07024 .41246 L
.07076 .41231 L
.07126 .41219 L
.07176 .41211 L
.07226 .41207 L
.07276 .41205 L
.07322 .41206 L
.07368 .41208 L
.07414 .4121 L
.07459 .41213 L
.07501 .41214 L
.07538 .41214 L
.07571 .41213 L
.07599 .41213 L
.07624 .41213 L
.07647 .41213 L
.07667 .41213 L
.07685 .41212 L
.07699 .41212 L
.07709 .41212 L
.07714 .41212 L
.07715 .41212 L
.07714 .41212 L
.07709 .41212 L
.07705 .41212 L
.07702 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
Mistroke
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41213 L
.07701 .41215 L
.07701 .4122 L
.07702 .41227 L
.07702 .41234 L
.07701 .41237 L
.077 .41235 L
.07699 .41225 L
.07698 .41206 L
.07697 .41178 L
.07696 .41142 L
.07696 .41099 L
.07697 .41052 L
.07698 .41003 L
.077 .40955 L
.07701 .40908 L
.07702 .40861 L
.07704 .40816 L
.07706 .40776 L
.07708 .40745 L
.07711 .40725 L
.07713 .40719 L
.07715 .40722 L
.07716 .40732 L
.07716 .40743 L
.07717 .40751 L
.07716 .40752 L
Mistroke
.07715 .40742 L
.07712 .40722 L
.07709 .40692 L
.07706 .40649 L
.07706 .40594 L
.07709 .40526 L
.07717 .40449 L
.0773 .40364 L
.07749 .40269 L
.07773 .40165 L
.07801 .40063 L
.0783 .39961 L
.07861 .39865 L
.07891 .39779 L
.0792 .39708 L
.07948 .39647 L
.07975 .39596 L
.07999 .39556 L
.08018 .39527 L
.08031 .39509 L
.08038 .39501 L
.08041 .395 L
.08039 .39505 L
.08035 .39512 L
.0803 .39521 L
.08027 .39528 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08025 .39531 L
.08027 .39529 L
.0803 .39524 L
.08034 .39517 L
.08038 .3951 L
.0804 .39507 L
Mistroke
.08039 .39509 L
.08033 .39519 L
.08022 .39537 L
.08005 .39565 L
.07983 .39602 L
.07957 .39645 L
.07929 .39692 L
.079 .39742 L
.07871 .3979 L
.07843 .39836 L
.07815 .39883 L
.07788 .39928 L
.07764 .39968 L
.07745 .4 L
.07732 .40022 L
.07725 .40034 L
.07722 .40038 L
.07724 .40035 L
.07728 .40027 L
.07733 .40017 L
.07736 .40008 L
.07738 .40002 L
.07738 .39999 L
.07738 .4 L
.07738 .40005 L
.07738 .40015 L
.07737 .40029 L
.07737 .40047 L
.07736 .40068 L
.07735 .40092 L
.07735 .40117 L
.07734 .40142 L
.07733 .40166 L
.07732 .4019 L
.07732 .40213 L
.07731 .40232 L
.07731 .40247 L
.0773 .40258 L
.0773 .40264 L
.0773 .40266 L
.0773 .40265 L
.0773 .40261 L
.0773 .40257 L
.0773 .40254 L
.07731 .40253 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
Mistroke
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07726 .40252 L
.07721 .40252 L
.07717 .40252 L
.07716 .40252 L
.07717 .40252 L
.07723 .40252 L
Mistroke
.07734 .40252 L
.0775 .40252 L
.0777 .40252 L
.07795 .40252 L
.07821 .40252 L
.07849 .40251 L
.07877 .40251 L
.07905 .40251 L
.07932 .40251 L
.07957 .40251 L
.0798 .4025 L
.07997 .4025 L
.08009 .4025 L
.08015 .4025 L
.08014 .4025 L
.08008 .4025 L
.08 .4025 L
.07994 .4025 L
.07991 .40251 L
.07995 .40252 L
.08005 .40255 L
.08021 .40258 L
.08041 .40262 L
.08065 .40263 L
.08091 .40262 L
.08119 .40257 L
.08147 .40247 L
.08174 .40233 L
.082 .40215 L
.08225 .40194 L
.08248 .4017 L
.08268 .40147 L
.08285 .40126 L
.08297 .40109 L
.08304 .40092 L
.08306 .40074 L
.08302 .40053 L
.08293 .40029 L
.08281 .40004 L
.08266 .39976 L
.08246 .39945 L
.08224 .39912 L
.08199 .39875 L
.08172 .39832 L
.08146 .3978 L
.08119 .39722 L
.08093 .39655 L
.0807 .39582 L
.0805 .39506 L
.08034 .3943 L
Mistroke
.08024 .39357 L
.08019 .39292 L
.08018 .39238 L
.08021 .39191 L
.08026 .3915 L
.08032 .39114 L
.08036 .39082 L
.08039 .39056 L
.0804 .39038 L
.0804 .39029 L
.0804 .39027 L
.0804 .3903 L
.0804 .39037 L
.0804 .39045 L
.0804 .3905 L
.08039 .39052 L
.08039 .39053 L
.08039 .39053 L
.08039 .39054 L
.08039 .39057 L
.08039 .3906 L
.08039 .39064 L
.08037 .39065 L
.08034 .39062 L
.0803 .39054 L
.08027 .39044 L
.08025 .39031 L
.08027 .39019 L
.08033 .39007 L
.08044 .38994 L
.08061 .38981 L
.08082 .38967 L
.08106 .38951 L
.08134 .38935 L
.08162 .38917 L
.08191 .389 L
.08219 .38884 L
.08246 .38871 L
.08272 .38862 L
.08294 .38854 L
.08312 .38847 L
.08324 .3884 L
.08332 .38833 L
.08334 .38824 L
.08333 .38815 L
.08329 .38808 L
.08325 .38803 L
.08321 .38802 L
.0832 .38804 L
.08319 .38808 L
Mistroke
.08319 .38811 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08319 .38812 L
.08317 .38812 L
.08314 .38812 L
.08309 .38812 L
.08305 .38812 L
.08303 .38814 L
.08303 .38819 L
.08305 .38827 L
.08312 .38834 L
.08324 .38837 L
Mistroke
.08343 .38834 L
.08369 .38824 L
.08403 .38806 L
.08443 .38778 L
.08488 .38741 L
.08536 .38698 L
.08588 .38651 L
.0864 .38602 L
.08692 .38554 L
.08739 .38507 L
.0878 .3846 L
.08816 .38416 L
.08845 .38376 L
.08866 .38344 L
.08881 .38322 L
.0889 .3831 L
.08894 .38306 L
.08894 .38308 L
.08892 .38315 L
.08888 .38323 L
.08883 .38329 L
.08879 .38331 L
.08878 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08877 .38332 L
.08879 .38334 L
.08883 .3834 L
.08891 .38347 L
.08899 .38354 L
Mistroke
.08902 .38357 L
.08899 .38354 L
.0889 .38343 L
.0887 .38324 L
.08839 .38295 L
.08798 .38258 L
.08749 .38215 L
.08696 .38164 L
.08642 .38109 L
.08589 .38053 L
.08537 .38 L
.08484 .37951 L
.08432 .37908 L
.08385 .37877 L
.08349 .37864 L
.08329 .37871 L
.08326 .37896 L
.08336 .37935 L
.08357 .37984 L
.08385 .38039 L
.08418 .38096 L
.08451 .3815 L
.08481 .382 L
.08509 .38246 L
.08536 .38286 L
.08561 .38319 L
.08583 .3834 L
.08602 .38345 L
.08619 .38338 L
.0863 .38327 L
.08636 .38315 L
.08635 .38307 L
.0863 .38308 L
Mfstroke
.08001 .4002 m
.08005 .40033 L
.0801 .40037 L
.08015 .40034 L
.08024 .40026 L
.08032 .40016 L
.08035 .40006 L
.08033 .40001 L
.08023 .40004 L
.08004 .40013 L
.07972 .40027 L
.07929 .40046 L
.07878 .40068 L
.07823 .40091 L
.07768 .40117 L
.07715 .40142 L
.07665 .40167 L
.07614 .40192 L
.07562 .40215 L
.07514 .40234 L
.07475 .40246 L
.0745 .4025 L
.07438 .40248 L
.07435 .40243 L
.07441 .40235 L
.07453 .40229 L
.07468 .40232 L
s
.06255 .43675 m
.06254 .43686 L
.06254 .43685 L
.06255 .43677 L
.06255 .43662 L
.06256 .43645 L
.06257 .43627 L
.06257 .43611 L
.06257 .43601 L
.06258 .436 L
.06257 .43609 L
.06257 .43631 L
.06255 .43666 L
.06254 .43713 L
.06252 .43771 L
.0625 .43837 L
.06247 .4391 L
.06245 .43983 L
.06242 .44058 L
.0624 .44131 L
.06237 .44198 L
.06233 .44258 L
.06227 .44308 L
.06218 .44344 L
.0621 .44368 L
.06205 .44379 L
.06207 .44379 L
.06217 .44372 L
.06236 .44361 L
.06267 .44351 L
.06307 .44343 L
.06354 .44337 L
.06403 .44332 L
.06453 .44326 L
.06504 .44322 L
.06554 .44324 L
.06608 .44335 L
.06665 .44354 L
.06722 .4438 L
.06775 .4441 L
.06822 .4444 L
.06862 .44467 L
.06896 .44489 L
.06923 .44506 L
.06943 .44516 L
.06962 .44521 L
.06983 .44522 L
.07006 .44518 L
.07028 .4451 L
.07045 .44494 L
Mistroke
.07057 .44471 L
.07065 .44439 L
.07072 .44404 L
.0708 .44369 L
.07084 .44343 L
.07084 .44327 L
.07079 .44324 L
.07068 .44334 L
.07047 .44352 L
.07015 .44371 L
.06973 .44388 L
.06923 .44399 L
.06869 .44407 L
.06813 .44412 L
.0676 .44414 L
.06709 .44415 L
.06657 .44415 L
.06606 .44413 L
.06559 .44408 L
.06522 .444 L
.06497 .4439 L
.06483 .44378 L
.06479 .44367 L
.06481 .44357 L
.06488 .4435 L
.06498 .44346 L
.06505 .44344 L
.06511 .44342 L
.06516 .44338 L
.0652 .44333 L
.06522 .44329 L
.06521 .44331 L
.06514 .44341 L
Mfstroke
.0751 .63043 m
.07518 .63046 L
.07521 .63036 L
.07521 .63019 L
.07518 .63 L
.07514 .62982 L
.0751 .62968 L
.07506 .62961 L
.07505 .62957 L
.07504 .62953 L
.07503 .62945 L
.075 .62934 L
.07496 .62923 L
.07493 .62916 L
.0749 .62917 L
.07491 .62926 L
s
.09163 .71591 m
.09162 .71598 L
.09161 .71625 L
.09159 .7167 L
.09157 .71726 L
.09155 .71787 L
.09154 .7185 L
.09156 .71913 L
.09164 .71977 L
.09176 .72041 L
.09192 .72106 L
.09212 .72169 L
.09234 .72227 L
.09257 .72276 L
.09279 .72313 L
.09299 .72337 L
.0932 .72351 L
.09341 .72357 L
.09363 .72358 L
.09387 .72359 L
.09411 .72362 L
.09437 .72369 L
.09464 .72377 L
.09491 .72381 L
.09517 .72381 L
.09543 .72378 L
.09566 .72373 L
.09591 .72368 L
.09617 .72362 L
.09642 .72355 L
.09664 .72346 L
.09679 .72337 L
.09686 .7233 L
.09685 .72327 L
.09679 .7233 L
s
.11031 .74089 m
.11043 .74088 L
.11044 .74081 L
.11037 .74073 L
.11022 .74071 L
s
.44192 .95556 m
.44184 .95557 L
.44201 .95555 L
.44236 .95552 L
.4428 .95549 L
.44324 .95545 L
.44361 .95542 L
.44386 .95541 L
.44393 .9554 L
.44376 .95542 L
.44335 .95545 L
.44275 .9555 L
.44206 .95555 L
.44137 .9556 L
.44074 .95565 L
.44019 .95569 L
.43972 .95573 L
.43936 .95575 L
.43913 .95577 L
.43905 .95577 L
.43912 .95576 L
.43933 .95575 L
.43962 .95572 L
.43998 .95572 L
.44035 .95573 L
.44073 .95578 L
.44107 .95582 L
.44136 .95581 L
.44164 .95572 L
.44194 .95554 L
.44227 .95528 L
.44264 .95499 L
.44303 .95467 L
.44345 .95437 L
.44394 .95411 L
.4445 .95393 L
.44515 .95385 L
.44584 .95384 L
.44655 .95386 L
.44724 .95388 L
.4479 .95386 L
.44851 .95386 L
.4491 .95385 L
.44968 .95381 L
.45028 .95369 L
.4509 .9535 L
.45156 .95322 L
.45223 .95285 L
.45291 .95239 L
.45356 .95184 L
Mistroke
.45416 .95123 L
.45472 .95065 L
.45523 .95018 L
.45569 .94984 L
.4561 .94963 L
.45645 .94951 L
.45671 .94948 L
.45689 .94948 L
.45698 .9495 L
.45699 .94948 L
.45693 .94941 L
.45683 .94926 L
.45673 .94906 L
.45665 .94883 L
.4566 .94858 L
.45658 .94833 L
.45658 .94808 L
.45662 .94786 L
.4567 .94769 L
.45681 .94756 L
.45692 .94747 L
.45701 .9474 L
.45706 .94731 L
.45706 .9472 L
Mfstroke
.85813 .79782 m
.85798 .79798 L
.85778 .7983 L
.85759 .79871 L
.85743 .79918 L
.85727 .79969 L
.85708 .80025 L
.85682 .80085 L
.85647 .80146 L
.85599 .80207 L
.85539 .80261 L
.8547 .80308 L
.85393 .80347 L
.85313 .80378 L
.85233 .80402 L
.85158 .80419 L
.85087 .80435 L
.85021 .80451 L
.84963 .8047 L
.84914 .80491 L
.84875 .80512 L
.84846 .80528 L
.84828 .80537 L
.8482 .80539 L
.84822 .80537 L
.84832 .80533 L
.84848 .80527 L
.84864 .80523 L
.84881 .8052 L
.84898 .80518 L
.84917 .80516 L
.84938 .80514 L
.84962 .80514 L
.84987 .80514 L
.85013 .80515 L
.85038 .80516 L
.85059 .80516 L
.85075 .80513 L
.85084 .80508 L
.85085 .80498 L
.85078 .80485 L
.85063 .8047 L
.85043 .80451 L
.85018 .8043 L
.84994 .80405 L
.84971 .80375 L
.8495 .80342 L
.84931 .80311 L
.84912 .80286 L
.84893 .80273 L
Mistroke
.84873 .80278 L
.84849 .80303 L
.84824 .80348 L
.848 .80407 L
.84779 .80475 L
.84761 .80545 L
.8475 .8061 L
.84745 .80666 L
.84749 .80711 L
.84763 .80746 L
.84789 .8077 L
.84827 .8078 L
.84872 .80776 L
.84921 .80758 L
.84974 .80721 L
.85028 .80671 L
.85081 .8061 L
.8513 .80545 L
.85172 .80482 L
.85205 .80429 L
.85229 .80388 L
.85243 .80359 L
.85251 .80338 L
.85253 .8032 L
.85252 .80305 L
.8525 .80291 L
.85251 .80278 L
.85255 .80269 L
.8526 .80266 L
.85267 .8027 L
Mfstroke
.80011 .14403 m
.80013 .14393 L
.80041 .14411 L
.80081 .14445 L
.80127 .14486 L
.80172 .14526 L
.80208 .14553 L
.80228 .14562 L
.80234 .14556 L
.80227 .14539 L
.80211 .14513 L
.80187 .14481 L
.8016 .14442 L
.80132 .144 L
.80104 .14355 L
.80078 .1431 L
.80055 .14265 L
.80034 .14221 L
.80015 .14179 L
.8 .14139 L
.79989 .14105 L
.79983 .14079 L
.79981 .14065 L
.79982 .14064 L
.79985 .14076 L
.79991 .141 L
.79998 .14133 L
.80006 .14171 L
.80014 .14211 L
.80026 .14254 L
.80042 .14299 L
.80061 .14343 L
.80083 .14388 L
.80106 .14432 L
.80129 .14472 L
.80152 .14506 L
.80174 .14534 L
.80194 .14554 L
.80211 .14565 L
.80225 .14568 L
.80238 .14565 L
.80249 .1456 L
.80259 .14556 L
.80269 .14558 L
.80278 .14567 L
.80285 .1458 L
.80286 .14591 L
.80278 .14595 L
s
.77375 .12966 m
.77367 .12973 L
.77371 .12982 L
.77381 .12991 L
.77392 .12997 L
.77403 .13 L
.77411 .13001 L
.77417 .13001 L
.7742 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
Mistroke
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77421 .13001 L
.77422 .13001 L
.77429 .13002 L
.77445 .13004 L
.77471 .1301 L
.77501 .13017 L
.7753 .13026 L
.77552 .13036 L
.77559 .13048 L
Mfstroke
.07971 .40178 m
.07971 .40164 L
.0798 .40131 L
.07996 .40088 L
.08018 .40053 L
.08044 .40032 L
.08072 .40018 L
.081 .40011 L
.08129 .4001 L
.08157 .4001 L
.08186 .40009 L
.08213 .40009 L
.08239 .40009 L
.0826 .40009 L
.08276 .40007 L
.08285 .40004 L
.08288 .4 L
.08286 .39997 L
.08282 .39995 L
.08279 .39996 L
.0828 .40001 L
.08287 .40011 L
s
.07008 .45672 m
.07008 .45662 L
.07008 .45661 L
.07008 .4567 L
.07007 .45689 L
.07006 .45719 L
.07005 .45755 L
.07004 .45792 L
.07003 .45824 L
.07002 .45845 L
.07002 .45859 L
.07002 .45868 L
.07002 .45867 L
.07002 .45863 L
.07001 .45855 L
.06998 .45843 L
.06994 .4582 L
.06991 .45789 L
.0699 .45751 L
.06993 .45706 L
.07 .45662 L
.07013 .45623 L
.0703 .45591 L
.07051 .45566 L
.07076 .45549 L
.07104 .45538 L
.07132 .45535 L
.0716 .45537 L
.07189 .45541 L
.07216 .45546 L
.07241 .45551 L
.07263 .45554 L
.0728 .45554 L
.07293 .45554 L
.073 .45554 L
.07302 .45554 L
.073 .45554 L
.07296 .45554 L
.07291 .45554 L
.07288 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
Mistroke
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07295 .45554 L
.07305 .45556 L
.07315 .45561 L
.07321 .45571 L
.0732 .45582 L
.07311 .45594 L
Mfstroke
.06573 .41415 m
.0659 .41415 L
.06603 .41423 L
.06613 .41437 L
.06621 .41451 L
.06629 .41464 L
.06643 .41472 L
.06664 .41474 L
.06695 .41469 L
.06736 .41459 L
.06785 .41444 L
.06841 .41426 L
.06903 .41404 L
.06969 .41379 L
.07039 .41354 L
.07107 .41328 L
.07178 .41302 L
.0725 .41278 L
.07318 .41255 L
.07383 .41235 L
.07446 .41219 L
.07504 .41208 L
.07556 .41201 L
.07598 .41199 L
.07632 .412 L
.07659 .41203 L
.07678 .41207 L
.07692 .4121 L
.07703 .41212 L
.07711 .41212 L
.07716 .41212 L
.07717 .41212 L
.07715 .41212 L
.07711 .41212 L
.07706 .41212 L
.07703 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41212 L
.07701 .41213 L
.07702 .41215 L
.07705 .41221 L
.0771 .41228 L
.07713 .41235 L
.07715 .41239 L
.07714 .41237 L
.07707 .41227 L
.07693 .41208 L
.07673 .41181 L
Mistroke
.07649 .41146 L
.07624 .41107 L
.076 .41067 L
.07578 .41026 L
.07561 .40985 L
.07546 .40941 L
.07537 .40893 L
.07533 .4084 L
.07538 .40784 L
.07552 .40725 L
.07576 .40661 L
.0761 .40593 L
.07653 .40524 L
.07703 .40453 L
.07756 .40386 L
.07807 .40317 L
.07855 .40247 L
.07894 .40181 L
.07927 .40124 L
.07953 .40077 L
.07973 .40036 L
.07987 .39999 L
.07998 .39969 L
.08007 .39943 L
.08014 .39922 L
.08022 .39904 L
.08031 .39885 L
.08044 .39862 L
.0806 .39835 L
.08081 .39803 L
.08107 .39767 L
.08137 .39726 L
.08166 .39681 L
.08196 .39633 L
.08224 .39591 L
.0825 .39563 L
.08273 .39546 L
.08291 .39543 L
.08303 .39554 L
.08309 .39576 L
.08311 .39607 L
.08308 .39644 L
.08303 .39684 L
.08297 .39727 L
.0829 .39774 L
.08283 .39825 L
.08275 .39877 L
.08266 .39927 L
.08258 .39967 L
.08253 .39997 L
Mistroke
.08253 .40016 L
.08263 .40025 L
.08284 .40025 L
.08318 .4002 L
.08364 .40014 L
.08422 .4001 L
.08491 .40013 L
.0856 .40024 L
.08638 .40041 L
.08718 .40062 L
.08795 .40085 L
.08874 .40109 L
.08941 .40133 L
.09 .40158 L
.09049 .40182 L
.09086 .40204 L
.0911 .40223 L
.09122 .40238 L
.09124 .40249 L
.0912 .40255 L
.09113 .40257 L
.09106 .40255 L
.09099 .40252 L
.09095 .40248 L
.09093 .40244 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09093 .40243 L
.09098 .40243 L
.09106 .40242 L
.09114 .40242 L
.09119 .40242 L
.09117 .40242 L
.09108 .40243 L
.09089 .40243 L
.09058 .40243 L
.09016 .40243 L
.08966 .40244 L
.08912 .40244 L
.08857 .40244 L
.08801 .40245 L
.08755 .40245 L
.08702 .40246 L
.0865 .40246 L
.08602 .40246 L
Mistroke
.08565 .40246 L
.0854 .40247 L
.08526 .40247 L
.08521 .40247 L
.08522 .40247 L
.0853 .40247 L
.08539 .40246 L
.08546 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08549 .40246 L
.0855 .40244 L
.08554 .40239 L
.08558 .40231 L
.08562 .40225 L
.08564 .40223 L
.08562 .40231 L
Mfstroke
.0669 .54583 m
.06702 .54581 L
.06708 .54581 L
.06711 .54581 L
.06709 .54581 L
.06705 .54581 L
.06701 .54581 L
.06698 .54581 L
.06697 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54581 L
.06696 .54579 L
.06697 .54574 L
.06697 .54566 L
.06698 .54559 L
.06698 .54556 L
.06698 .54558 L
.06697 .54568 L
.06695 .54587 L
.06693 .54616 L
.06691 .54654 L
.06688 .54698 L
.06686 .54747 L
.06684 .54797 L
.06682 .54846 L
.0668 .54894 L
.06679 .54941 L
.06677 .54987 L
.06676 .55028 L
.06675 .55061 L
.06675 .55083 L
.06675 .55095 L
.06676 .55099 L
.06678 .55097 L
.06679 .5509 L
.0668 .55081 L
.06681 .55075 L
.0668 .55073 L
.0668 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55073 L
.06679 .55072 L
.06678 .55069 L
.06675 .55063 L
Mistroke
.0667 .55055 L
.06664 .55041 L
.06657 .55025 L
.06651 .55008 L
.06647 .54997 L
.06645 .54996 L
Mfstroke
.09423 .72136 m
.09432 .72148 L
.09436 .72152 L
.09436 .72151 L
.09434 .72146 L
.0943 .72138 L
.09426 .7213 L
.09422 .72125 L
.09421 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
Mistroke
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72123 L
.0942 .72122 L
.0942 .7212 L
.0942 .72116 L
.0942 .72112 L
.09421 .7211 L
.09421 .7211 L
.0942 .72113 L
.0942 .72122 L
.0942 .72135 L
.0942 .72154 L
.09419 .72176 L
.09418 .722 L
.09418 .72225 L
.09417 .72253 L
.09417 .72275 L
.09416 .723 L
.09416 .72325 L
.09415 .72347 L
.09415 .72365 L
.09414 .72377 L
.09414 .72385 L
.09414 .72388 L
.09414 .72387 L
.09414 .72384 L
.09414 .72379 L
.09414 .72376 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
Mistroke
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09416 .72378 L
.09422 .72382 L
.0943 .72385 L
.09433 .72387 L
.09431 .72385 L
.09424 .7238 L
.09407 .72371 L
.09378 .72358 L
.09334 .7234 L
.0928 .7232 L
.09224 .72297 L
.09174 .72274 L
.09128 .7225 L
.09081 .72226 L
.09034 .72203 L
.08984 .72182 L
.08935 .72163 L
.08896 .72149 L
.08872 .72138 L
.08861 .72132 L
.08857 .72131 L
.08859 .72132 L
.08866 .72136 L
.08874 .72139 L
.08877 .72142 L
.08877 .72144 L
.08876 .72144 L
.08873 .72144 L
.08869 .72145 L
.08865 .72145 L
.08863 .72145 L
.08864 .72145 L
.0887 .72144 L
.0888 .72144 L
.08896 .72143 L
.08917 .72143 L
.08941 .72142 L
.08968 .72141 L
.08996 .72139 L
.09023 .72138 L
.09049 .72137 L
.09075 .72136 L
.091 .72135 L
.09123 .72134 L
.09141 .72134 L
.09154 .72133 L
Mistroke
.09161 .72133 L
.09163 .72133 L
.09162 .72133 L
.09158 .72133 L
.09153 .72133 L
.0915 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09149 .72133 L
.09148 .72133 L
.09147 .72132 L
.09145 .72129 L
.09141 .72125 L
.09137 .72122 L
.09135 .7212 L
.09136 .72121 L
.09142 .72126 L
.09152 .72136 L
.09167 .7215 L
.09188 .72168 L
.09211 .7219 L
.09238 .72213 L
.09265 .72238 L
.09291 .72263 L
.09317 .72288 L
.09343 .72312 L
.09367 .72334 L
.09389 .72353 L
.09407 .72369 L
.09419 .7238 L
.09426 .72386 L
.09428 .72388 L
.09427 .72386 L
.09423 .72383 L
.09419 .72379 L
Mistroke
.09416 .72375 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72374 L
.09414 .72375 L
.09414 .72378 L
.09414 .72382 L
.09414 .72386 L
.09414 .72388 L
.09414 .72387 L
.09414 .72381 L
.09414 .72371 L
.09415 .72356 L
.09415 .72337 L
.09416 .72315 L
.09416 .7229 L
.09417 .72264 L
.09417 .72238 L
.09418 .72212 L
.0942 .72188 L
.09423 .7217 L
.09428 .72158 L
.09432 .72149 L
.09434 .72141 L
.09433 .72133 L
.09427 .72122 L
.09417 .72105 L
.09402 .7208 L
.09382 .72046 L
.09359 .72005 L
.09333 .71959 L
.09307 .71909 L
.09281 .71859 L
.09256 .71812 L
.09231 .71764 L
.09207 .71718 L
.09185 .71677 L
.09168 .71645 L
.09156 .71622 L
.09149 .7161 L
.09147 .71606 L
.09148 .71608 L
.09152 .71615 L
.09156 .71623 L
.09159 .71629 L
.09161 .71631 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09162 .71634 L
.09163 .71636 L
.09166 .71641 L
.09169 .71647 L
.09172 .71652 L
.09172 .71654 L
.09167 .71648 L
.09157 .7163 L
.09136 .71611 L
.0911 .71584 L
.09087 .71552 L
.09044 .71522 L
.09025 .71484 L
.0901 .7144 L
.09003 .71397 L
.08997 .71358 L
.08996 .71317 L
.09002 .71265 L
.09013 .71217 L
.09026 .71179 L
.09043 .71147 L
.09064 .71131 L
.09096 .71122 L
Mistroke
.09128 .71119 L
.09155 .71121 L
.09171 .71124 L
.09182 .71128 L
.0919 .71129 L
.09193 .71124 L
.09192 .71117 L
.09186 .71114 L
.09175 .71115 L
.09156 .71122 L
.0913 .71139 L
.09102 .71168 L
.09077 .7121 L
.09057 .71259 L
.09044 .71314 L
.09039 .71359 L
.09037 .71403 L
.09035 .71447 L
.09034 .71488 L
.09036 .71537 L
.09043 .71583 L
.09058 .71619 L
.09079 .71639 L
.09104 .71648 L
.09132 .71651 L
.09155 .71649 L
.09168 .71641 L
.09172 .71633 L
.09173 .71632 L
.09171 .71632 L
.09168 .71632 L
.09164 .71632 L
.09162 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
Mistroke
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71632 L
.09161 .71633 L
.09161 .71637 L
.0916 .71644 L
.0916 .71651 L
.0916 .71654 L
.0916 .71652 L
.09161 .71643 L
.09161 .71626 L
.09162 .71597 L
.09163 .71558 L
.09164 .71512 L
.09165 .71462 L
.09166 .71411 L
.09168 .71364 L
.09169 .71319 L
.0917 .71273 L
.09171 .71226 L
.09172 .71182 L
.09173 .71147 L
.09174 .71124 L
.09174 .71112 L
.09174 .71108 L
.09174 .71109 L
.09174 .71116 L
.09174 .71124 L
.09174 .71129 L
.09173 .7113 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09173 .71131 L
.09174 .71131 L
.09174 .71132 L
.09177 .71134 L
.09181 .71138 L
.09184 .71142 L
.09186 .71143 L
.09185 .71143 L
.0918 .71138 L
.0917 .71129 L
.09155 .71116 L
Mistroke
.09134 .71099 L
.0911 .71079 L
.09083 .71056 L
.09056 .71034 L
.09031 .71016 L
.09006 .70999 L
.08981 .70978 L
.08956 .70952 L
.08934 .70921 L
.08916 .70888 L
.08905 .70849 L
.08899 .70804 L
.08898 .70754 L
.08901 .70704 L
.08905 .70654 L
.08911 .7061 L
.08915 .70573 L
.08917 .70538 L
.08918 .70499 L
.08919 .70458 L
.0892 .70423 L
.08921 .70393 L
.08922 .70365 L
.08923 .70332 L
.08923 .70293 L
.08924 .70254 L
.08925 .70215 L
.08927 .7017 L
.08928 .70121 L
.08929 .70074 L
.08931 .70026 L
.08932 .69979 L
.08933 .69936 L
.08934 .69903 L
.08934 .69881 L
.08935 .6987 L
.08935 .69866 L
.08935 .69868 L
.08934 .69875 L
.08934 .69882 L
.08934 .69887 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
.08934 .69888 L
Mistroke
.08934 .69888 L
.08934 .69888 L
.08934 .69889 L
.08934 .6989 L
.08934 .69893 L
.08934 .69897 L
.08934 .699 L
.08934 .69902 L
.08934 .69901 L
.08934 .69895 L
.08934 .69885 L
.08934 .69871 L
.08935 .69852 L
.08935 .69829 L
.08936 .69805 L
.08937 .69779 L
.08938 .69754 L
.08938 .69728 L
.08939 .69704 L
.08939 .6968 L
.0894 .6966 L
.0894 .69644 L
.08941 .69632 L
.08941 .69626 L
.08941 .69624 L
.08941 .69625 L
.08941 .69629 L
.08941 .69634 L
.08941 .69638 L
.08944 .69643 L
.08948 .6965 L
.08951 .69657 L
.08953 .6966 L
.08952 .69658 L
.08947 .69649 L
.08937 .69632 L
.08922 .69604 L
.08902 .69566 L
.08879 .6952 L
.08853 .69472 L
.08827 .69422 L
.08802 .69375 L
.08777 .6933 L
.08753 .69283 L
.08729 .69237 L
.08709 .69197 L
.08695 .69171 L
.08687 .69156 L
.08683 .69149 L
.08681 .69146 L
Mistroke
.08678 .69141 L
.08673 .69131 L
.08662 .69112 L
.08645 .69079 L
.08622 .69034 L
.08596 .68984 L
.08569 .68933 L
.08544 .68886 L
.0852 .68841 L
.08496 .68796 L
.08471 .6875 L
.08449 .68707 L
.08432 .68673 L
.0842 .68651 L
.08413 .68639 L
.08411 .68635 L
.08412 .68636 L
.08416 .68643 L
.0842 .68651 L
.08423 .68655 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08424 .68657 L
.08427 .68656 L
.08431 .68648 L
.08435 .68633 L
.08437 .68628 L
.08436 .68633 L
.0843 .68646 L
.0842 .68676 L
.08403 .68732 L
.08379 .68819 L
.08351 .68933 L
.08321 .69045 L
.08291 .69151 L
.08262 .69244 L
.08235 .69332 L
.08207 .69419 L
.08179 .69507 L
.08152 .69599 L
.08131 .69661 L
.08116 .69672 L
.08106 .6965 L
.08103 .69612 L
.08107 .69559 L
Mistroke
.08117 .69486 L
.08133 .69414 L
.08152 .69341 L
.08176 .69262 L
.08204 .69179 L
.08234 .69095 L
.08264 .69013 L
.08291 .68935 L
.08318 .68865 L
.08345 .68801 L
.08372 .68742 L
.08397 .68686 L
.08416 .68631 L
.0843 .68579 L
.08438 .68533 L
.08441 .68497 L
.0844 .68467 L
.08437 .68447 L
.08433 .68435 L
.08431 .68429 L
.0843 .68425 L
.0843 .68423 L
.0843 .6842 L
.0843 .68415 L
.0843 .684 L
Mfstroke
.07557 .61778 m
.07558 .61768 L
.07556 .61756 L
s
.0688 .57001 m
.06884 .56992 L
.06885 .56991 L
.06885 .56997 L
.06885 .57006 L
.06884 .57017 L
.06884 .57027 L
.06884 .57037 L
.06883 .57044 L
.06883 .57049 L
.06883 .57054 L
.06883 .57059 L
.06884 .57064 L
.06887 .57066 L
.06892 .57063 L
s
.07544 .45554 m
.0755 .45549 L
.0755 .45547 L
.07548 .45548 L
.07545 .45551 L
.07543 .45555 L
.07544 .45562 L
.07553 .4557 L
.07573 .45576 L
.07605 .45579 L
.07649 .45579 L
.07703 .45574 L
.07766 .45566 L
.07827 .45552 L
.07905 .45533 L
.07976 .4551 L
.08049 .45485 L
.08123 .45458 L
.08193 .45432 L
.08252 .45407 L
.083 .45382 L
.08338 .45358 L
.08367 .45335 L
.08385 .45316 L
.08396 .453 L
.08402 .45289 L
.08404 .45283 L
.08403 .45281 L
.08401 .45283 L
.08396 .45287 L
.08392 .45291 L
.0839 .45292 L
.08392 .45287 L
.08396 .4528 L
.08401 .45272 L
.08403 .45267 L
.08401 .45267 L
.08394 .45275 L
.08382 .45293 L
.08365 .45324 L
.08342 .45369 L
.08314 .45423 L
.08283 .4548 L
.08251 .45536 L
.0822 .45594 L
.08189 .45647 L
.08159 .457 L
.08128 .45754 L
.08087 .45804 L
.08067 .45848 L
Mistroke
.08054 .45887 L
.08048 .45913 L
.08047 .45935 L
.08052 .45947 L
.0806 .45951 L
.0807 .45956 L
.08078 .45964 L
.08084 .45977 L
.08088 .45993 L
.0809 .46008 L
.08091 .46022 L
.08091 .46032 L
.08091 .46039 L
.0809 .46039 L
.08089 .46036 L
.08088 .46031 L
.08088 .46027 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08088 .46025 L
.08089 .46025 L
.0809 .46027 L
.08093 .46032 L
.08097 .46039 L
.08101 .46046 L
.08103 .46048 L
.08102 .46042 L
.08096 .46028 L
.08086 .46007 L
.0807 .45985 L
.08047 .45962 L
.08019 .45939 L
.07987 .45917 L
.07953 .45895 L
.07918 .45872 L
.0789 .45848 L
Mistroke
.07864 .45824 L
.07843 .45803 L
.07832 .45784 L
Mfstroke
.09148 .38762 m
0 0 rlineto s
.0865 .36616 m
.08654 .36613 L
.08654 .36618 L
.08654 .3663 L
.08653 .36644 L
.08653 .36655 L
.08653 .36661 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08653 .36662 L
.08652 .36664 L
.08651 .36667 L
.08647 .3667 L
.08643 .36674 L
.08639 .36676 L
.08637 .36675 L
.08638 .36669 L
.08644 .3666 L
.08656 .36646 L
.08672 .36628 L
.08693 .36606 L
.08718 .36583 L
.08745 .36558 L
.08774 .36533 L
.08803 .36509 L
.08832 .36488 L
.08858 .36472 L
.0888 .36463 L
.08898 .3646 L
.08911 .3646 L
.08922 .36463 L
.0893 .36463 L
.08938 .36456 L
s
.10724 .29987 m
.10732 .29996 L
.10734 .30006 L
.10732 .30015 L
.10727 .30022 L
.10721 .30025 L
.10716 .30027 L
.10712 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
Mistroke
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.1071 .30027 L
.10708 .30027 L
.10705 .30027 L
.10701 .30027 L
.10697 .30027 L
.10694 .30027 L
.10696 .30027 L
.10702 .30027 L
.10713 .30027 L
.10729 .30027 L
.10749 .30028 L
.10773 .30028 L
.10799 .30028 L
.10827 .30028 L
.10855 .30029 L
.10883 .30029 L
.1091 .30029 L
.10935 .30029 L
.10957 .3003 L
.10974 .3003 L
.10986 .3003 L
.10993 .3003 L
.10995 .3003 L
.10994 .3003 L
.1099 .3003 L
.10985 .3003 L
.10981 .3003 L
.1098 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
Mistroke
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .3003 L
.10979 .30033 L
.10979 .30039 L
.10979 .30046 L
.10979 .30054 L
.10976 .3006 L
.10971 .30063 L
.10964 .30059 L
Mfstroke
.22514 .13667 m
.22522 .13659 L
.22522 .13659 L
.22515 .13665 L
.22505 .13676 L
.22494 .13689 L
.22487 .13699 L
.22487 .13705 L
.22493 .13705 L
.22502 .137 L
.22509 .13693 L
.22508 .13687 L
.22497 .13683 L
.22473 .13685 L
.22436 .13694 L
.22385 .13711 L
.22323 .13736 L
.22252 .13769 L
.22176 .13808 L
.22102 .1385 L
.22025 .13896 L
.21946 .13941 L
.21875 .13986 L
.21809 .1403 L
.21753 .14071 L
.2171 .14107 L
.21682 .14136 L
.21667 .14156 L
.21663 .14168 L
.21668 .14172 L
.21678 .14169 L
.21687 .14162 L
.21693 .14155 L
.21696 .14149 L
.21695 .14146 L
.21691 .14145 L
.21687 .14145 L
.21685 .14145 L
.21686 .14145 L
.21692 .14145 L
.21702 .14146 L
.21718 .14146 L
.21737 .14147 L
.2176 .14148 L
.21785 .14149 L
.21812 .14149 L
.21838 .14151 L
.21863 .14154 L
.21884 .14161 L
.219 .14169 L
Mistroke
.21911 .14176 L
.21917 .14182 L
.21919 .14185 L
.2192 .14184 L
.21927 .14176 L
Mfstroke
.24193 .12678 m
.24196 .1268 L
.24178 .12693 L
.24149 .12674 L
.24117 .12688 L
.2409 .12702 L
.24073 .12716 L
s
.38935 .04624 m
.38943 .04619 L
.3894 .0462 L
.38932 .04625 L
.38922 .04632 L
.38913 .04639 L
.38904 .04647 L
.38899 .04653 L
.38894 .04655 L
.38889 .04656 L
.38884 .04655 L
.38879 .04655 L
.38872 .04655 L
.38867 .04655 L
.38863 .04655 L
.38864 .04655 L
.38871 .04655 L
.38885 .04655 L
.38909 .04656 L
.38942 .04657 L
.38986 .04659 L
.39041 .04661 L
.39104 .04663 L
.39178 .04666 L
.39258 .04669 L
.39343 .04672 L
.39429 .04675 L
.39513 .04678 L
.39592 .04681 L
.39663 .04684 L
.39723 .04686 L
.39772 .04688 L
.3981 .04689 L
.39838 .0469 L
.39857 .04691 L
.39868 .04691 L
.39874 .04692 L
.39875 .04692 L
.39873 .04691 L
.39868 .04691 L
.39863 .04691 L
.39858 .04691 L
.39855 .04691 L
.39854 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
Mistroke
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39853 .04691 L
.39851 .0469 L
.39846 .04688 L
.39839 .04682 L
.3983 .04674 L
.39821 .04667 L
.39813 .04663 L
.3981 .04663 L
.39817 .04668 L
Mfstroke
.49794 .09333 m
.49797 .0934 L
.498 .09337 L
.49802 .09326 L
.49802 .0931 L
.49801 .09295 L
.498 .09286 L
.49799 .09282 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49799 .09281 L
.49798 .09281 L
.49797 .09277 L
.49794 .09269 L
.4979 .09257 L
.49785 .09243 L
.49779 .0923 L
.49773 .09221 L
.4977 .09217 L
.49769 .09224 L
s
.79848 .13721 m
.79847 .13709 L
.79839 .13698 L
.79829 .13692 L
.79819 .13687 L
.79809 .13684 L
.798 .13683 L
.79794 .13682 L
.79789 .13682 L
.79788 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79787 .13682 L
.79788 .1368 L
.79789 .13678 L
.79791 .13677 L
.79794 .13677 L
.79796 .13677 L
.79795 .13676 L
.79791 .13674 L
.79783 .13674 L
.79774 .13676 L
.79763 .13684 L
s
.23091 .8663 m
0 0 rlineto s
.07013 .45541 m
.07013 .45531 L
.07013 .45529 L
.07013 .45533 L
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07013 .45557 L
.07014 .45555 L
.07018 .45549 L
.07022 .45541 L
.07027 .45533 L
.07029 .4553 L
.07027 .45532 L
.07021 .45543 L
.07009 .45563 L
.06992 .45593 L
.0697 .45633 L
.06944 .45682 L
.06915 .45738 L
.06885 .45797 L
.06855 .45851 L
.06824 .459 L
Mistroke
.06794 .45938 L
.06764 .45965 L
.06738 .45975 L
.06716 .4597 L
.06703 .45949 L
.06698 .45914 L
.06704 .45867 L
.06719 .45813 L
.06741 .45755 L
.06768 .45697 L
.06797 .45645 L
.06827 .45602 L
.06857 .4557 L
.06887 .45547 L
.06916 .45534 L
.06943 .4553 L
.06968 .45533 L
.0699 .4554 L
.07007 .45548 L
.0702 .45554 L
.07026 .45557 L
.07029 .45558 L
.07027 .45558 L
.07023 .45558 L
.07018 .45558 L
.07014 .45558 L
.07013 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.0701 .45558 L
.07007 .45558 L
.07003 .45558 L
.06999 .45558 L
.06996 .45558 L
.06998 .45558 L
.07004 .45558 L
.07015 .45558 L
.07031 .45558 L
.07052 .45557 L
.07076 .45557 L
.07103 .45557 L
.07131 .45556 L
.0716 .45556 L
.07188 .45555 L
.07214 .45555 L
.07236 .45555 L
.07253 .45554 L
.07267 .45554 L
.07276 .45554 L
.07282 .45554 L
.07284 .45556 L
.07283 .45558 L
.07283 .45562 L
.0729 .45566 L
Mfstroke
.10466 .30004 m
.10472 .2999 L
.10471 .29987 L
.10465 .29991 L
.10457 .29999 L
.10449 .30006 L
.10443 .30011 L
.10441 .30016 L
.1044 .3002 L
.1044 .30023 L
.1044 .30024 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30025 L
.1044 .30024 L
.10439 .30023 L
.10435 .3002 L
.10431 .30016 L
.10427 .30013 L
.10425 .30011 L
.10427 .30012 L
.10433 .30017 L
.10443 .30027 L
.10459 .30041 L
.10479 .30059 L
.10502 .3008 L
.10528 .30104 L
.10556 .30129 L
.10583 .30153 L
.1061 .30178 L
.10636 .30202 L
.10661 .30225 L
.10682 .30244 L
.10699 .30259 L
.10711 .3027 L
.10718 .30276 L
.1072 .30278 L
.10719 .30276 L
.10715 .30273 L
.1071 .30268 L
Mistroke
.10707 .30265 L
.10705 .30264 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30263 L
.10705 .30264 L
.10706 .30265 L
.10707 .30266 L
.10707 .30269 L
.10707 .30272 L
.10706 .30274 L
.10702 .30278 L
.10696 .30282 L
.10687 .30287 L
.10676 .30291 L
.10665 .30291 L
.10657 .30282 L
Mfstroke
.11285 .28816 m
.11289 .28826 L
.11291 .28833 L
.1129 .2884 L
.11284 .28853 L
s
.08011 .40045 m
.08018 .40026 L
.0802 .40014 L
.08019 .40009 L
.08017 .40006 L
.08019 .40002 L
.08023 .39998 L
.08026 .39997 L
.08024 .39998 L
.08019 .40003 L
.08008 .40013 L
.07991 .40027 L
.07967 .40046 L
.0794 .40067 L
.0791 .40091 L
.07882 .40116 L
.07852 .40141 L
.07826 .40167 L
.078 .40191 L
.07775 .40213 L
.07749 .40233 L
.07729 .40248 L
.07716 .40259 L
.07711 .40265 L
.07711 .40267 L
.07715 .40265 L
.07722 .40261 L
.07729 .40257 L
.07734 .40254 L
.07734 .40252 L
.07733 .40252 L
.07731 .40252 L
.0773 .40252 L
.07728 .40252 L
.07725 .40252 L
.0772 .40252 L
.07715 .40252 L
.0771 .40252 L
.07708 .40252 L
.07711 .40252 L
.07721 .40252 L
.07739 .40252 L
.07765 .40252 L
.078 .40252 L
.07843 .40251 L
.07892 .40251 L
.07941 .40251 L
.07995 .4025 L
.08049 .4025 L
.08104 .4025 L
Mistroke
.08152 .40249 L
.08196 .40249 L
.08234 .40249 L
.08263 .40248 L
.08283 .40248 L
.08295 .40248 L
.08299 .40248 L
.08297 .40248 L
.08292 .40248 L
.08287 .40248 L
.08282 .40248 L
.08278 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40248 L
.08276 .40249 L
.08278 .4025 L
.08281 .40253 L
.08285 .40257 L
.08289 .4026 L
.08291 .40262 L
.08289 .40261 L
.08284 .40256 L
.08273 .40246 L
.08257 .40232 L
.08237 .40214 L
.08214 .40193 L
.08188 .4017 L
.0816 .40145 L
.08133 .4012 L
.08106 .40095 L
.08079 .40071 L
.08055 .40049 L
Mistroke
.08033 .4003 L
.08016 .40015 L
.08004 .40004 L
.07997 .39998 L
.07995 .39996 L
.07997 .39998 L
.08001 .40002 L
.08005 .40006 L
.08009 .40009 L
.0801 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08011 .40009 L
.08012 .40006 L
.08016 .40002 L
.08021 .39998 L
.08024 .39997 L
.08024 .39998 L
.08021 .40003 L
.08012 .40013 L
.07998 .40027 L
.07977 .40046 L
.07952 .40067 L
.07925 .40091 L
.07897 .40116 L
.07867 .40141 L
Mistroke
.0784 .40167 L
.07816 .40191 L
.07788 .40213 L
.07762 .40233 L
.07741 .40248 L
.07727 .40259 L
.07718 .40265 L
.07714 .40267 L
.07712 .40265 L
.07711 .40261 L
.07713 .40257 L
.07716 .40254 L
.07718 .40253 L
.07723 .40252 L
.07733 .40252 L
.07749 .40252 L
.0777 .40252 L
.07794 .40252 L
.07821 .40252 L
.07849 .40253 L
.07877 .40256 L
.07905 .40259 L
.07932 .40263 L
.07957 .40264 L
.07979 .40263 L
.07997 .40258 L
.0801 .40248 L
.08017 .40234 L
.0802 .40216 L
.08019 .40194 L
.08016 .40171 L
.08012 .40146 L
.08009 .40121 L
.08008 .40096 L
.08009 .40072 L
.08009 .4005 L
.0801 .4003 L
.0801 .40015 L
.08011 .40004 L
.08011 .39998 L
.08011 .39996 L
.08011 .39998 L
.08011 .40001 L
.08011 .40006 L
.08011 .40009 L
.08011 .4001 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
Mistroke
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.0801 .4001 L
.08009 .40009 L
.08006 .40006 L
.08002 .40002 L
.07998 .39999 L
.07996 .39997 L
.07997 .39998 L
.08003 .40003 L
.08013 .40013 L
.08029 .40027 L
.08049 .40045 L
.08073 .40066 L
.08099 .40089 L
.08126 .40114 L
.08153 .40139 L
.08181 .40164 L
.08207 .40188 L
.08232 .4021 L
.08253 .40229 L
.0827 .40244 L
.08282 .40255 L
.08289 .40261 L
.08291 .40263 L
.0829 .40261 L
.08286 .40257 L
.08281 .40253 L
.08276 .4025 L
.08271 .40249 L
.08267 .40248 L
.08263 .40248 L
.08261 .40248 L
Mistroke
.08262 .40248 L
.08268 .40248 L
.08279 .40248 L
.08295 .40248 L
.08315 .40248 L
.0834 .40248 L
.08366 .40248 L
.08395 .40247 L
.08422 .40247 L
.0845 .40247 L
.08478 .40247 L
.08503 .40247 L
.08525 .40247 L
.08543 .40246 L
.08555 .40246 L
.08562 .40246 L
.08564 .40246 L
.08562 .40246 L
.08558 .40246 L
.08554 .40246 L
.0855 .40246 L
.08549 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
Mistroke
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40246 L
.08548 .40247 L
.08548 .40248 L
.08548 .40251 L
.08548 .40255 L
.08548 .40258 L
.08548 .4026 L
.08548 .40259 L
.08548 .40254 L
.08548 .40244 L
.08549 .4023 L
.08549 .40212 L
.0855 .40191 L
.08551 .40167 L
.08551 .40142 L
.08552 .40117 L
.08553 .40092 L
.08554 .40068 L
.08554 .40046 L
.08555 .40027 L
.08555 .40011 L
.08556 .40001 L
.08556 .39994 L
.08556 .39993 L
.08556 .39994 L
.08556 .39998 L
.08556 .40002 L
.08556 .40005 L
.08556 .40007 L
Mistroke
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08556 .40007 L
.08555 .40007 L
.08554 .40007 L
.08551 .4001 L
.08547 .40016 L
.08542 .40023 L
.0854 .4003 L
.08542 .40034 L
.08548 .40031 L
.08559 .40021 L
.08573 .40002 L
.08592 .39973 L
.08613 .39937 L
.08636 .39894 L
.08658 .39847 L
.0868 .39798 L
.08703 .39748 L
.08728 .39699 L
.08756 .39651 L
.08787 .39606 L
.08816 .39567 L
.08847 .39536 L
.08878 .39514 L
.08908 .39502 L
.08937 .39495 L
.08966 .39493 L
.08994 .39492 L
.09021 .39493 L
Mistroke
.09048 .39495 L
.09073 .395 L
.09094 .39511 L
.09109 .3953 L
.09117 .39558 L
.09119 .39594 L
.09118 .39637 L
.09115 .39684 L
.09109 .39733 L
.09102 .39783 L
.09097 .39832 L
.09094 .3988 L
.09093 .39924 L
.09093 .39963 L
.09094 .39993 L
.09095 .40014 L
.09097 .40023 L
.09099 .40023 L
.091 .40016 L
.09101 .40007 L
.09102 .4 L
.09101 .39998 L
.09099 .40002 L
.09095 .40009 L
.0909 .40019 L
Mfstroke
.06302 .49689 m
.06302 .49703 L
.06304 .49711 L
.06307 .49716 L
s
.08929 .70973 m
.08935 .70987 L
.08935 .70982 L
.0893 .70966 L
.08924 .70947 L
.08918 .70929 L
.08913 .70912 L
.0891 .70898 L
.08908 .70892 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08908 .7089 L
.08906 .7089 L
.08903 .70891 L
.08898 .70891 L
.08894 .70891 L
.0889 .70891 L
.08887 .70891 L
.08886 .70891 L
.08889 .70891 L
.089 .70891 L
.0892 .7089 L
.08952 .70889 L
.08995 .70887 L
.09049 .70885 L
.09112 .70883 L
.09183 .7088 L
.0926 .70877 L
.09339 .70874 L
.09413 .70871 L
.0949 .70868 L
.09555 .70865 L
.09614 .70863 L
.09662 .70861 L
.09698 .7086 L
.09721 .70859 L
.09733 .70858 L
.09737 .70858 L
.09736 .70858 L
.09733 .70859 L
.09732 .70859 L
.09736 .70858 L
.09749 .70858 L
.09772 .70857 L
Mistroke
.09805 .70856 L
.09844 .70854 L
.09888 .70853 L
.09936 .70851 L
.09987 .70848 L
.10037 .70845 L
.10083 .7084 L
.10125 .70834 L
.10161 .70829 L
.10193 .70826 L
.10222 .70826 L
.10248 .70831 L
.10271 .70842 L
.10293 .70859 L
.10313 .70881 L
.10333 .70906 L
.10353 .70932 L
.10374 .70956 L
.10399 .70976 L
.10429 .70991 L
.10465 .71 L
.10506 .71002 L
.10549 .70999 L
.1059 .70988 L
.1063 .70972 L
.10666 .70951 L
.10697 .70926 L
.10724 .70898 L
.10748 .7087 L
.10769 .70844 L
.10788 .70824 L
.10803 .70811 L
.10815 .70803 L
.10821 .70801 L
.10823 .70803 L
.10821 .70807 L
.10817 .70811 L
.10813 .70815 L
.10809 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
Mistroke
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10807 .70817 L
.10805 .7082 L
.10802 .70827 L
.10797 .70836 L
.10792 .70846 L
.10786 .70858 L
.1078 .70866 L
.10777 .70868 L
.10779 .70859 L
Mfstroke
.08676 .44091 m
.08668 .4408 L
.08668 .44073 L
.08671 .44068 L
.08674 .44066 L
.08675 .44066 L
.08678 .44068 L
.08683 .44072 L
.0869 .44079 L
s
.15075 .24392 m
.15081 .24385 L
.15086 .2439 L
.15083 .24408 L
.15069 .24435 L
.15042 .2447 L
.15005 .24511 L
.14959 .24555 L
.14906 .24601 L
.14851 .24648 L
.14796 .24695 L
.14743 .24742 L
.1469 .24787 L
.1464 .2483 L
.14596 .24867 L
.1456 .24897 L
.14536 .24918 L
.14522 .24929 L
.14518 .24933 L
.14521 .24933 L
.14527 .24931 L
.14533 .24931 L
.14535 .24932 L
.14534 .24935 L
.14532 .24935 L
.14533 .24928 L
s
.21433 .14578 m
.21446 .1458 L
.21453 .14584 L
.21456 .14589 L
.21456 .14593 L
.21454 .14596 L
.2145 .14599 L
.21446 .14601 L
.21442 .14601 L
.21441 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.2144 .14601 L
.21441 .14601 L
.21442 .14598 L
.21445 .14591 L
.21449 .14581 L
.21453 .14571 L
.21455 .14567 L
.21454 .1457 L
Mistroke
.21448 .14584 L
.21438 .1461 L
.21422 .14651 L
.21402 .14704 L
.21379 .14766 L
.21354 .14834 L
.21327 .14905 L
.213 .14977 L
.21272 .15048 L
.21245 .1512 L
.21218 .15189 L
.21193 .1525 L
.21172 .15295 L
.21158 .15321 L
.21153 .15324 L
Mfstroke
.38944 .05087 m
.38946 .05097 L
.3894 .05104 L
.38929 .05105 L
.38916 .05095 L
.38905 .05072 L
.38897 .0504 L
.38892 .05 L
.3889 .04954 L
.38889 .04902 L
.38889 .04844 L
.38889 .04797 L
.38889 .0475 L
.38889 .04709 L
.38889 .04679 L
.38889 .04666 L
s
.53307 .05121 m
.53312 .0512 L
.53313 .05119 L
.53309 .05118 L
.53304 .05117 L
.53297 .05117 L
.5329 .05115 L
.53284 .05115 L
.53281 .05114 L
.5328 .05115 L
.53283 .05116 L
.5329 .05119 L
.533 .05122 L
.5331 .05126 L
.53316 .05128 L
.53313 .05126 L
.533 .05121 L
s
.45995 .04664 m
.45986 .04664 L
.45986 .04667 L
.45993 .0467 L
.46006 .04674 L
s
.4958 .04857 m
0 0 rlineto s
.6083 .05729 m
.60838 .05735 L
.60834 .05746 L
.60821 .05764 L
.60802 .0579 L
.6078 .05822 L
.60758 .05859 L
.60739 .059 L
.60724 .05943 L
.60714 .05985 L
.60707 .0603 L
.60703 .06069 L
.60702 .06107 L
.60706 .06141 L
.60714 .06168 L
.60729 .06187 L
.6075 .06198 L
.60777 .06202 L
.60808 .06202 L
.6084 .062 L
.60871 .06197 L
.609 .06194 L
.60927 .06193 L
.6095 .06192 L
.60971 .06191 L
.60991 .06191 L
.61009 .06191 L
.61025 .06192 L
.61039 .06192 L
.61049 .06192 L
.61055 .06193 L
.61056 .06193 L
.61055 .06193 L
.61051 .06192 L
.61048 .06192 L
.61045 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
Mistroke
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61043 .06192 L
.61045 .06193 L
.61047 .06195 L
.61051 .06196 L
.61054 .06196 L
.61056 .06197 L
.61055 .06199 L
.6105 .06202 L
.61041 .06203 L
.61027 .06199 L
.6101 .06187 L
.6099 .06166 L
.60968 .0614 L
.60944 .06111 L
.60921 .0608 L
Mistroke
.60898 .06058 L
.60875 .0604 L
.60854 .06027 L
.60836 .06021 L
.60821 .0602 L
.60811 .06023 L
.60805 .06032 L
.60804 .06043 L
.60808 .06061 L
.60816 .06085 L
.60827 .06112 L
.60836 .0614 L
.60841 .06166 L
.60839 .06186 L
.60829 .06201 L
.60811 .06208 L
.60785 .06206 L
.6075 .06199 L
.6071 .06192 L
.60665 .06187 L
.60617 .06187 L
.60569 .0619 L
.60522 .06193 L
.60478 .0619 L
.60437 .06183 L
.60404 .06173 L
.60379 .0616 L
.60365 .06146 L
.6036 .06132 L
.60363 .0612 L
.60371 .06111 L
.60381 .06106 L
.60391 .06103 L
.60397 .06103 L
.604 .06104 L
.604 .06104 L
.60398 .06108 L
.60395 .06117 L
.60391 .06131 L
.60388 .06149 L
.60385 .06171 L
.60382 .0619 L
.60378 .06204 L
.60373 .06209 L
.60365 .06202 L
.60354 .06183 L
.60339 .06152 L
.6032 .06115 L
.60299 .06073 L
.60278 .06028 L
Mistroke
.6026 .05983 L
.60245 .05937 L
.60235 .05893 L
.6023 .05849 L
.60229 .05808 L
.60233 .05772 L
.60241 .05744 L
.60254 .05724 L
.60271 .05713 L
.60292 .05711 L
.60315 .05716 L
.60337 .05728 L
.60355 .05742 L
.60368 .05754 L
.60376 .0576 L
.60377 .05758 L
.60376 .05749 L
.60372 .05732 L
.60369 .05705 L
.60366 .05672 L
.60364 .05632 L
.60364 .05589 L
.60364 .05543 L
.60364 .05495 L
.60363 .05445 L
.60363 .05396 L
.60363 .05349 L
.60363 .0531 L
.60363 .05284 L
.60363 .05273 L
.60363 .05279 L
.60363 .05302 L
.60363 .05337 L
.60363 .05382 L
.60363 .05432 L
.60364 .05483 L
.60364 .05531 L
.60364 .05577 L
.60364 .0562 L
.60364 .05661 L
.60364 .05697 L
.60364 .05726 L
.60364 .05746 L
.60364 .05758 L
.60364 .05761 L
.60364 .05759 L
.60364 .05753 L
.60364 .05745 L
.60364 .0574 L
.60364 .05737 L
Mistroke
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60364 .05737 L
.60366 .05737 L
.60371 .05737 L
.6038 .05737 L
.6039 .05737 L
.60395 .05737 L
.60393 .05737 L
.60382 .05737 L
.6036 .05736 L
.60324 .05735 L
.60274 .05734 L
.60214 .05733 L
.6015 .05731 L
.60089 .0573 L
.60034 .05728 L
.59979 .05727 L
.59917 .05725 L
.59848 .05723 L
.59778 .05722 L
.5971 .0572 L
.59648 .05719 L
.59591 .05718 L
.59538 .05717 L
.59492 .05716 L
.59454 .05715 L
.59423 .05714 L
.59385 .05713 L
.59342 .05714 L
.59303 .05718 L
.59271 .05724 L
.59248 .0573 L
.59232 .05733 L
.59222 .05731 L
.59215 .05722 L
.59209 .05704 L
.59202 .05675 L
Mistroke
.59193 .05636 L
.59177 .05595 L
.59156 .05558 L
.59132 .05525 L
.59109 .05495 L
.59085 .05468 L
.59062 .05444 L
.59041 .05421 L
.59023 .05397 L
.59008 .05372 L
.58996 .05347 L
.58988 .05328 L
.58983 .0532 L
.58981 .05323 L
.58983 .05336 L
.58988 .05353 L
.58997 .05371 L
.5901 .05392 L
.59026 .05418 L
.59045 .05449 L
.59066 .05483 L
.59086 .05514 L
.59104 .05546 L
.59118 .05578 L
.59128 .05601 L
.59132 .05605 L
.59131 .05588 L
.59125 .05561 L
.59118 .05531 L
.59109 .05503 L
.591 .05472 L
.59088 .05442 L
.59076 .05418 L
.59064 .05401 L
.59055 .05393 L
.59049 .05391 L
.59047 .05393 L
.59046 .05397 L
.59048 .05401 L
.59049 .05405 L
.59051 .05405 L
.5905 .05396 L
.59045 .05378 L
.59038 .0535 L
.59028 .05326 L
.59017 .05303 L
.59008 .05291 L
.59001 .05293 L
.58996 .05309 L
.58995 .05337 L
Mistroke
.58997 .0537 L
.59 .054 L
.59002 .05423 L
.59003 .05437 L
.59004 .05446 L
.59004 .05448 L
.59004 .05446 L
.59004 .05437 L
.59004 .05423 L
.59004 .054 L
.59003 .05371 L
.59003 .05339 L
.59003 .05307 L
.59003 .05279 L
.59003 .05259 L
.59003 .05247 L
.59003 .05243 L
.59003 .05245 L
.59003 .05249 L
.59003 .05256 L
.59003 .0526 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59002 .05261 L
.59001 .0526 L
.59 .05258 L
.59 .05255 L
.59 .05252 L
.59 .05249 L
.59 .05248 L
.59001 .05253 L
.59005 .05267 L
.59013 .05289 L
.59023 .05317 L
.59035 .05348 L
.59047 .05379 L
.59058 .05407 L
.59067 .05425 L
.59074 .05438 L
.59077 .05445 L
.59078 .05446 L
.59076 .05443 L
.59073 .05434 L
.59068 .05421 L
.59059 .05398 L
.59049 .0537 L
.59038 .0534 L
.59027 .05309 L
Mistroke
.59016 .05283 L
.59007 .05262 L
.59 .0525 L
.58995 .05245 L
.58994 .05248 L
.58996 .05256 L
.58999 .05263 L
.59002 .05269 L
.59003 .05271 L
.59003 .05272 L
.59003 .05272 L
.59003 .05271 L
.59003 .05271 L
.59003 .0527 L
.59003 .05268 L
.59003 .05267 L
.59003 .05265 L
.59003 .05263 L
.59003 .05262 L
.59003 .05261 L
.59003 .05261 L
.59003 .05262 L
.59003 .05262 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59003 .05263 L
.59004 .05262 L
.59005 .0526 L
.59008 .05255 L
.59011 .05248 L
.59015 .05242 L
.59016 .05239 L
.59015 .05241 L
.5901 .05251 L
.59001 .05269 L
.58986 .05295 L
.58966 .05329 L
.58943 .05371 L
.58919 .0542 L
Mistroke
.58894 .05473 L
.58871 .05523 L
.5885 .05571 L
.58833 .05612 L
.58821 .05644 L
.58816 .05663 L
.58818 .05666 L
.58827 .05651 L
.58842 .05619 L
.58863 .05574 L
.58888 .05522 L
.58917 .05471 L
.58945 .05424 L
.58969 .05381 L
.58987 .05345 L
.58996 .05319 L
.58999 .05302 L
.58996 .05294 L
.58988 .05292 L
.58979 .05294 L
.58969 .053 L
.5896 .05307 L
.58954 .05315 L
.5895 .05319 L
.58948 .05321 L
.58948 .05314 L
.58949 .05302 L
.58953 .05286 L
.58959 .05269 L
.58968 .05257 L
.58978 .05252 L
.58989 .05257 L
.58998 .05274 L
.59006 .05305 L
.59011 .0534 L
.59012 .05382 L
.59011 .05427 L
.59007 .05472 L
.59005 .05514 L
.59004 .05557 L
.59004 .05599 L
.59004 .05637 L
.59004 .05669 L
.59004 .05696 L
.59004 .05715 L
.59004 .05726 L
.59004 .05729 L
.59004 .05726 L
.59004 .05719 L
.59004 .05712 L
Mistroke
.59004 .05707 L
.59004 .05704 L
.59005 .05704 L
.59011 .05704 L
.59022 .05704 L
.59034 .05703 L
.59044 .05702 L
.59048 .057 L
.59043 .05699 L
Mfstroke
.57689 .05691 m
.57683 .05684 L
.57694 .05678 L
.57718 .05673 L
.57747 .05669 L
.57778 .05668 L
.57809 .05669 L
.57836 .05672 L
.57856 .05675 L
.5787 .05676 L
.57878 .05677 L
.5788 .05677 L
.57879 .05677 L
.57875 .05676 L
.57872 .05676 L
.57868 .05676 L
.57867 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57866 .05676 L
.57867 .05676 L
.57868 .05674 L
.57871 .0567 L
.57874 .05664 L
.57878 .05658 L
.57879 .05656 L
.57878 .05663 L
.57873 .05677 L
.57864 .05698 L
.57851 .05723 L
.57833 .0575 L
.57813 .05775 L
.57791 .05799 L
.57767 .0582 L
.57744 .05836 L
.5772 .05846 L
.57697 .05849 L
.57676 .05842 L
.57658 .05827 L
Mistroke
.57643 .05797 L
.57634 .05754 L
.57631 .05698 L
.57633 .05635 L
.57638 .05567 L
.57643 .05499 L
.57645 .05434 L
.57643 .05374 L
.57636 .0532 L
.57622 .05271 L
.57605 .05225 L
.57585 .05181 L
.57562 .05141 L
.57539 .05106 L
.57515 .05079 L
.57491 .05058 L
.57469 .05041 L
.57447 .05028 L
.57429 .05015 L
.57414 .05004 L
.57404 .04995 L
.57398 .04987 L
.57396 .0498 L
.57398 .04971 L
.57401 .04965 L
.57405 .04963 L
.57408 .04968 L
.57409 .0498 L
.5741 .05001 L
.5741 .05032 L
.5741 .05074 L
.5741 .05126 L
.5741 .05188 L
.5741 .0526 L
.57413 .0534 L
.5742 .05422 L
.57431 .05509 L
.57441 .05603 L
.57445 .05698 L
.57442 .0579 L
.57428 .0587 L
.57402 .05934 L
.57362 .05988 L
.5731 .0603 L
.57248 .06063 L
.57181 .06087 L
.57111 .06105 L
.57043 .06116 L
.56977 .06121 L
.56911 .06121 L
Mistroke
.56847 .06115 L
.5679 .06108 L
.56745 .06102 L
.56717 .06102 L
.56703 .06106 L
.56701 .06113 L
.56706 .06118 L
.56714 .0612 L
.56721 .06116 L
.5672 .06103 L
.5671 .06079 L
.56693 .06043 L
.56673 .05994 L
.5665 .05934 L
.56626 .05863 L
.56602 .05791 L
.56578 .05713 L
.56553 .05628 L
.56529 .05537 L
.56507 .05443 L
.56489 .05359 L
.56477 .05279 L
.56472 .05206 L
.56476 .05145 L
.56486 .05099 L
.56503 .05071 L
.56524 .05061 L
.56548 .05066 L
.56572 .05086 L
.56596 .0512 L
.56619 .05164 L
.56643 .05217 L
.56666 .05277 L
.56688 .0534 L
.56706 .05403 L
.56721 .05462 L
.56731 .0552 L
.56737 .05573 L
.56739 .05616 L
.56737 .05646 L
.56734 .05665 L
.56734 .05674 L
.5674 .05676 L
.5675 .05673 L
.56759 .05667 L
.56765 .0566 L
.56765 .05653 L
.56756 .05649 L
Mfstroke
.54444 .05576 m
.54429 .05569 L
.54423 .05566 L
.54423 .05568 L
.54429 .05578 L
s
.5117 .06174 m
.5116 .06174 L
.51158 .06174 L
.51163 .06174 L
.51174 .06174 L
.51185 .06175 L
.51192 .06175 L
.51195 .06175 L
.51195 .06175 L
.51195 .06175 L
.51196 .06175 L
.51198 .06173 L
.51204 .06168 L
.51214 .06162 L
.51224 .06155 L
.51234 .06151 L
.51242 .06152 L
.51246 .06161 L
s
.46734 .04885 m
0 0 rlineto s
.40334 .04706 m
.40333 .04692 L
.40321 .04675 L
.40301 .04654 L
.40275 .04631 L
.40245 .04606 L
.40215 .04582 L
.40185 .04557 L
.40158 .04533 L
.40133 .04511 L
.40112 .0449 L
.40094 .04472 L
.4008 .04458 L
.40072 .04446 L
.40071 .04437 L
.40077 .04433 L
.4009 .04435 L
s
.39582 .05608 m
.39573 .05617 L
.39576 .05623 L
.3959 .05628 L
.39611 .05632 L
.39636 .05636 L
.39664 .05641 L
.39691 .05646 L
.39717 .05652 L
.39742 .05656 L
.39767 .05658 L
.39792 .05657 L
.39814 .05653 L
.39833 .05645 L
.39849 .05635 L
.3986 .05625 L
.39866 .05615 L
.39867 .05608 L
.39864 .05607 L
.39857 .05612 L
.39848 .05624 L
.39837 .05643 L
.39828 .05668 L
.39822 .05695 L
.39823 .0572 L
.39832 .05743 L
.39852 .05765 L
.39883 .05784 L
.39924 .05801 L
.39976 .05815 L
.40036 .05825 L
.40101 .05832 L
.40175 .05837 L
.40253 .05841 L
.40338 .05844 L
.40418 .05847 L
.40495 .0585 L
.40566 .05851 L
.40628 .05852 L
.40679 .05849 L
.40719 .05841 L
.40751 .05828 L
.40778 .05811 L
.40802 .05791 L
.40827 .0577 L
.40853 .05748 L
.4088 .05725 L
.40908 .05699 L
.40934 .0567 L
.40957 .0564 L
Mistroke
.40979 .05612 L
.40999 .05588 L
.41017 .05564 L
.41035 .05546 L
.41048 .05525 L
.41056 .05502 L
.41058 .05475 L
.41055 .05446 L
.41048 .05413 L
.41042 .05377 L
.4104 .05343 L
.41044 .05314 L
.41056 .05294 L
.41076 .05275 L
.41101 .0526 L
.41131 .05247 L
.41166 .05233 L
.41206 .05214 L
.41255 .05189 L
.41313 .05156 L
.41382 .0512 L
.41458 .05082 L
.41542 .05044 L
.4163 .05006 L
.4172 .04966 L
.41804 .04924 L
.41887 .04882 L
.41961 .04842 L
.42033 .04808 L
.42094 .04781 L
.4215 .04762 L
.42198 .04753 L
.42236 .0475 L
.42263 .04754 L
.42277 .04761 L
.42279 .04768 L
.42272 .04773 L
.42261 .04776 L
.42251 .04776 L
.42245 .04775 L
.42245 .04775 L
.42253 .04776 L
.42267 .04776 L
.42286 .04776 L
.42311 .04776 L
.42338 .04776 L
.42367 .04776 L
.42393 .04776 L
.42417 .04773 L
.42436 .0477 L
Mistroke
.42449 .04768 L
.42454 .04769 L
.42451 .04776 L
.42441 .0479 L
.42423 .04812 L
.424 .0484 L
.42374 .04878 L
.42345 .04915 L
.42317 .04959 L
.42291 .05001 L
.42271 .05041 L
.42255 .05079 L
.42244 .05112 L
.42238 .05137 L
.42236 .05155 L
.42237 .05163 L
.42241 .05165 L
.42245 .05162 L
.42248 .05161 L
.4225 .05151 L
.4225 .05146 L
.4225 .05145 L
.4225 .0515 L
.4225 .05162 L
.4225 .05172 L
.4225 .05178 L
.4225 .05183 L
.42248 .05183 L
.42246 .05174 L
.42242 .05154 L
.42238 .05125 L
.42236 .05088 L
.42238 .05043 L
.42243 .04995 L
.42254 .04946 L
.42271 .04895 L
.42293 .04844 L
.42318 .04799 L
.42344 .04766 L
.42367 .04748 L
.42387 .04746 L
.42402 .04761 L
.42412 .0479 L
.42416 .0483 L
.42414 .04877 L
.42406 .04926 L
.42392 .04976 L
.42373 .05022 L
.4235 .05068 L
.42325 .05111 L
Mistroke
.42299 .05153 L
.42275 .05189 L
.42257 .05218 L
.42244 .05238 L
.42238 .0525 L
.42236 .05253 L
.42238 .05251 L
.42241 .05244 L
.42247 .05239 L
.42252 .05239 L
.42258 .05243 L
.42262 .0525 L
.42264 .05253 L
.42263 .05251 L
.42258 .05241 L
.42248 .05223 L
.42235 .05196 L
.42218 .05162 L
.422 .0512 L
.42181 .05074 L
.42159 .05027 L
.42136 .04981 L
.4211 .04935 L
.4208 .04888 L
.42048 .04845 L
.42015 .04807 L
.41981 .04777 L
.41949 .04756 L
.41919 .04743 L
.41892 .04738 L
.41868 .0474 L
.41847 .04746 L
.41827 .04753 L
.41808 .04759 L
.41791 .04761 L
.41776 .0476 L
.41766 .0476 L
.4176 .04759 L
.41758 .04759 L
.4176 .04758 L
.41765 .04758 L
.41772 .04757 L
.41778 .04757 L
.41783 .04757 L
.41785 .04757 L
.41783 .04758 L
.41775 .0476 L
.41762 .04762 L
.41744 .04765 L
.41725 .04768 L
Mistroke
.41705 .0477 L
.41688 .04772 L
.41674 .04774 L
.41663 .04775 L
.41657 .04776 L
.41654 .04776 L
.41656 .04775 L
.41661 .04774 L
.41669 .04773 L
.41683 .04771 L
.417 .04768 L
.4172 .04765 L
.4174 .04762 L
.41759 .04759 L
.41774 .04758 L
.41783 .04757 L
.41786 .04757 L
.41783 .04757 L
.41776 .04758 L
.41769 .04759 L
.41762 .0476 L
.41759 .04763 L
.4176 .04766 L
.41765 .0477 L
.41775 .04772 L
.41789 .04771 L
.41807 .04767 L
.41828 .04759 L
.41851 .04746 L
.41876 .0473 L
.41901 .0471 L
.41926 .04689 L
.4195 .04666 L
.41972 .04644 L
.41991 .04621 L
.42006 .04599 L
.42017 .04578 L
.42023 .0456 L
.42025 .04546 L
.42024 .04535 L
.4202 .0453 L
.42016 .04528 L
.42013 .04529 L
.42011 .04532 L
.42011 .04536 L
.42011 .04539 L
.4201 .04539 L
.42007 .04537 L
.42003 .04533 L
.41999 .04529 L
Mistroke
.41996 .04527 L
.41994 .04528 L
.41994 .04533 L
.41997 .04543 L
Mfstroke
.44181 .04841 m
.44188 .04841 L
.44187 .04841 L
.44183 .04841 L
.44176 .04841 L
.44168 .04841 L
.44161 .0484 L
.44156 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44154 .0484 L
.44152 .0484 L
.44149 .0484 L
.44146 .0484 L
.44142 .0484 L
.4414 .0484 L
.44142 .0484 L
.44147 .0484 L
.44157 .0484 L
.44172 .04838 L
.44193 .04834 L
.44219 .04828 L
.44246 .04822 L
.44272 .0482 L
.44295 .04823 L
.44315 .04833 L
.4433 .04851 L
.44338 .04878 L
.44339 .04912 L
.44333 .04953 L
.4432 .04996 L
.44302 .05042 L
.44279 .05087 L
.44253 .05132 L
.44225 .05175 L
.44199 .05216 L
.44176 .05253 L
.44159 .05282 L
.44148 .05302 L
Mistroke
.44142 .05313 L
.4414 .05317 L
.44142 .05314 L
.44145 .05308 L
.44149 .05301 L
.44152 .05295 L
.44154 .05292 L
.44154 .05292 L
.44156 .05292 L
.44161 .05292 L
.44169 .05293 L
.44175 .05293 L
.44179 .05293 L
.44177 .05293 L
.44168 .05293 L
Mfstroke
.39469 .07293 m
.39465 .07304 L
.39459 .07307 L
s
.362 .07973 m
.36199 .0798 L
.36211 .07981 L
.36229 .07976 L
.36247 .07968 L
.36257 .0796 L
.36256 .07954 L
s
.32716 .09129 m
.32702 .09128 L
.32706 .09119 L
.32718 .09109 L
.32735 .09099 L
.32755 .09083 L
.32773 .09067 L
.32784 .09048 L
.3279 .0903 L
.32793 .09014 L
.32794 .09001 L
.32795 .08993 L
.32794 .08989 L
.32792 .08989 L
.32791 .08992 L
.32791 .08996 L
.32791 .08999 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32791 .09001 L
.32793 .08998 L
.32796 .08993 L
.328 .08986 L
.32803 .0898 L
.32805 .08977 L
.32804 .08979 L
.32799 .08988 L
.32789 .09006 L
.32774 .09032 L
.32755 .09066 L
.32733 .09106 L
.32709 .0915 L
.32684 .09197 L
.32658 .09242 L
.32632 .09285 L
.32607 .09326 L
.32584 .09362 L
.32563 .09393 L
.32544 .0942 L
.32529 .09443 L
.32519 .09462 L
Mistroke
.32516 .09482 L
Mfstroke
.32355 .13302 m
.32357 .13299 L
s
.21449 .14148 m
.21436 .14156 L
.21429 .14158 L
.21427 .14155 L
.21431 .14148 L
.21437 .14138 L
.21446 .14126 L
.21453 .14117 L
.21457 .14112 L
.21456 .14114 L
.2145 .14122 L
s
.19035 .17638 m
.19023 .17631 L
.19023 .17615 L
.19035 .17594 L
.19054 .17572 L
.19077 .17555 L
.191 .17548 L
.19126 .17547 L
.19154 .17546 L
.19184 .17542 L
.19217 .17536 L
.19247 .1753 L
.19277 .17528 L
.19302 .17531 L
.1932 .17541 L
.19331 .1756 L
.19332 .17587 L
.19324 .17622 L
.19307 .17663 L
.19283 .17708 L
.19254 .17755 L
.19222 .17802 L
.1919 .17849 L
.1916 .17894 L
.19134 .17937 L
.19113 .17974 L
.19096 .18003 L
.19083 .18024 L
.19077 .18036 L
.19075 .18039 L
.19076 .18037 L
.1908 .1803 L
.19085 .18022 L
.19088 .18016 L
.1909 .18014 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
Mistroke
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.1909 .18013 L
.19092 .1801 L
.19095 .18003 L
.19099 .17993 L
.19103 .17983 L
.19105 .17978 L
.19104 .17982 L
.19098 .17996 L
.19087 .18022 L
.19072 .18062 L
.19052 .18115 L
.19028 .18177 L
.19002 .18245 L
.18975 .18315 L
.18947 .18383 L
.18921 .1845 L
.18895 .18516 L
.18873 .18581 L
.18852 .18639 L
.18834 .18685 L
.18819 .18716 L
.18807 .18733 L
.188 .18739 L
.18795 .18736 L
.18794 .18726 L
.18793 .18714 L
.18793 .18706 L
.18792 .18703 L
.18791 .18705 L
.1879 .1871 L
.18787 .18717 L
.18784 .18724 L
.18784 .18728 L
.18787 .18725 L
.18793 .18716 L
.18805 .18698 L
.18821 .18671 L
.1884 .18637 L
.1886 .18596 L
.18881 .18551 L
.18902 .18503 L
.18926 .18457 L
.18954 .1841 L
Mistroke
.18987 .18365 L
.19025 .18324 L
.19068 .18289 L
.19114 .18262 L
.19159 .18243 L
.19199 .18231 L
.19232 .18224 L
.19256 .18222 L
.19271 .18223 L
.19278 .18223 L
.19279 .18222 L
.19273 .18219 L
.19262 .18215 L
.19245 .18212 L
.19224 .1821 L
.19199 .18209 L
.19171 .18209 L
.19143 .1821 L
.19116 .18213 L
.19096 .18218 L
.19083 .18224 L
.19076 .18232 L
.19074 .18239 L
.19075 .18245 L
.19079 .1825 L
.19083 .18252 L
.19087 .18252 L
.19088 .1825 L
.19089 .18247 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
.19089 .18246 L
Mistroke
.19089 .18246 L
.19089 .18246 L
.19089 .18245 L
.19089 .18243 L
.19089 .18238 L
.19089 .1823 L
.19089 .18224 L
.19089 .1822 L
.19089 .18223 L
.19089 .18233 L
.19089 .18251 L
.19088 .18279 L
.19088 .18314 L
.19088 .18356 L
.19087 .18401 L
.19087 .1845 L
.19088 .185 L
.19091 .1855 L
.19095 .186 L
.19098 .18648 L
.191 .18689 L
.19099 .18718 L
.19093 .18731 L
.19082 .18728 L
.19067 .18711 L
.19048 .18684 L
.19025 .18653 L
.19 .18623 L
.18973 .186 L
.18946 .18583 L
.18919 .18543 L
.18893 .18538 L
.18869 .18538 L
.18848 .18543 L
.18831 .18552 L
.18819 .18569 L
.18812 .18592 L
.1881 .1862 L
.18811 .18649 L
.18815 .18677 L
.18818 .187 L
.18818 .18716 L
.18815 .18724 L
.18812 .18724 L
.1881 .18719 L
.18811 .18712 L
.18817 .18707 L
.18827 .18704 L
.18843 .18704 L
.18863 .18705 L
Mistroke
.18888 .18707 L
.18917 .1871 L
.18948 .18713 L
.18978 .18715 L
.19005 .18716 L
.1903 .18714 L
.19049 .18709 L
.19059 .187 L
.19061 .18689 L
.19053 .18677 L
.19037 .18666 L
.19017 .18655 L
.18994 .18643 L
.18972 .18631 L
.18955 .18619 L
.18945 .18607 L
.18945 .18598 L
Mfstroke
.09282 .33544 m
0 0 rlineto s
.08273 .40124 m
.08277 .40124 L
.0828 .40108 L
.08281 .40082 L
.08282 .40054 L
.08283 .40028 L
.08283 .40013 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08283 .40009 L
.08284 .40008 L
.08286 .40007 L
.08292 .40004 L
.08301 .4 L
.08309 .39996 L
.08313 .39995 L
.0831 .39996 L
.08298 .40001 L
.08277 .40011 L
.08244 .40025 L
.08202 .40044 L
.08153 .40065 L
.08099 .40089 L
.08042 .40115 L
.07986 .4014 L
.0793 .40166 L
.07875 .4019 L
.07822 .40212 L
.07781 .40229 L
.07756 .40238 L
.07745 .40241 L
.07744 .40238 L
.07748 .40231 L
.07749 .40224 L
.0774 .40225 L
s
.06287 .42465 m
.0628 .42467 L
.06281 .42459 L
.06283 .42453 L
.06287 .42444 L
.06291 .42432 L
.06295 .42418 L
.06296 .42407 L
.06297 .42399 L
.06297 .42394 L
.06297 .42395 L
.06297 .42406 L
s
.06241 .44072 m
.06241 .44091 L
.0624 .44104 L
.06239 .44118 L
s
.06687 .473 m
.06673 .47303 L
.06666 .47298 L
.06667 .47289 L
.06671 .4728 L
.06675 .47271 L
.06679 .47264 L
.0668 .4726 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06681 .47259 L
.06682 .47259 L
.06684 .47259 L
.06687 .4726 L
.06688 .47263 L
.06685 .47268 L
.0668 .47274 L
.06674 .47279 L
.06667 .47279 L
.0666 .47273 L
.06654 .47259 L
.0665 .47237 L
.0665 .47203 L
.0665 .47154 L
.06652 .47114 L
.06653 .47066 L
.06655 .47018 L
.06655 .46974 L
.06658 .46927 L
.06664 .46881 L
.06672 .46839 L
.06681 .46804 L
Mistroke
.06689 .4678 L
.06695 .46765 L
.067 .46759 L
.06701 .46758 L
.06698 .46765 L
.06692 .46775 L
.06686 .46783 L
.06683 .46785 L
.06684 .46779 L
.0669 .46764 L
.06702 .46741 L
.0672 .46707 L
.06742 .46663 L
.06769 .46612 L
.06798 .46552 L
.06828 .46485 L
.06858 .46414 L
.06886 .46344 L
.06915 .46278 L
.06942 .46219 L
.06967 .46165 L
.06987 .46116 L
.07 .46077 L
.07008 .46047 L
.07011 .46028 L
.07009 .46018 L
.07006 .46016 L
.07001 .46018 L
.06998 .46024 L
.06996 .46033 L
.06996 .46039 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06992 .46042 L
.06988 .46042 L
.06984 .46042 L
.06982 .46042 L
.06983 .46042 L
.06989 .46042 L
.06999 .46042 L
.07015 .46042 L
.07036 .46042 L
.07061 .46041 L
.07087 .46041 L
.07115 .4604 L
.07142 .4604 L
.07168 .46039 L
.07195 .46039 L
.0722 .46039 L
.07243 .46038 L
.07262 .46038 L
.07274 .46038 L
.07281 .46038 L
.07283 .46038 L
.07282 .46038 L
.07278 .46038 L
.07274 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07269 .4605 L
.07269 .46032 L
.0727 .46004 L
.07272 .45967 L
.07273 .45923 L
.07275 .45876 L
.07276 .45826 L
.07278 .45778 L
.0728 .45732 L
.07281 .45685 L
.07283 .4564 L
Mistroke
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07286 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
.07286 .45553 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
Mistroke
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07287 .45552 L
.0729 .45547 L
.07295 .45539 L
.07299 .45532 L
.073 .45529 L
.07298 .45532 L
.07292 .45541 L
.0728 .4556 L
.07262 .45588 L
.07236 .45626 L
.07202 .4567 L
.07167 .45718 L
.07134 .45768 L
.07107 .45816 L
.07084 .45863 L
.07064 .4591 L
.07051 .45955 L
.07048 .45996 L
.07054 .46028 L
.07069 .4605 L
.07091 .46062 L
.07118 .46065 L
.07146 .46063 L
.07179 .46055 L
.07212 .46047 L
.0724 .46041 L
.0726 .46038 L
.07273 .46038 L
.0728 .46038 L
.07283 .46038 L
.07282 .46038 L
.07279 .46038 L
.07275 .46038 L
.07271 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46045 L
.07269 .46052 L
.07268 .46059 L
.07268 .46062 L
.07268 .4606 L
.07268 .4605 L
.07269 .46032 L
.0727 .46004 L
.07271 .45967 L
.07272 .45923 L
.07274 .45876 L
.07275 .45826 L
.07277 .45778 L
.07279 .45732 L
.0728 .45685 L
.07282 .4564 L
.07284 .45599 L
.07285 .45567 L
.07286 .45545 L
.07286 .45533 L
.07287 .45529 L
.07287 .45531 L
.07286 .45537 L
.07286 .45545 L
.07286 .45551 L
.07286 .45553 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07287 .45554 L
.07289 .45554 L
.07293 .45554 L
.07297 .45554 L
.07299 .45554 L
.07298 .45554 L
Mistroke
.07293 .45554 L
.07282 .45554 L
.07266 .45554 L
.07245 .45554 L
.07221 .45555 L
.07194 .45555 L
.07166 .45555 L
.07139 .45556 L
.07113 .45556 L
.07087 .45557 L
.07061 .45557 L
.07038 .45557 L
.07019 .45558 L
.07007 .45558 L
.07 .45558 L
.06998 .45558 L
.06999 .45558 L
.07003 .45558 L
.07008 .45558 L
.07011 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .45558 L
.07009 .45558 L
.07005 .45558 L
.07 .45558 L
.06998 .45558 L
.06998 .45558 L
.07002 .45558 L
.07009 .45558 L
.07021 .45558 L
.07037 .45558 L
.07057 .45557 L
.07083 .45557 L
.07114 .45556 L
.0715 .45556 L
.07189 .45555 L
.07231 .45555 L
.07276 .45554 L
.07323 .45553 L
.07369 .45553 L
.07412 .45552 L
.07448 .45551 L
.07479 .45551 L
.07505 .45551 L
.07527 .4555 L
.07545 .4555 L
.07559 .4555 L
.07568 .4555 L
.07572 .4555 L
.07574 .45549 L
.07572 .4555 L
.07568 .4555 L
.07563 .4555 L
.0756 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45549 L
.07558 .45549 L
.07558 .45549 L
.07557 .4555 L
.07557 .4555 L
.07556 .45551 L
.07556 .45551 L
.07555 .45549 L
.07555 .45545 L
.07555 .45541 L
.07555 .45539 L
.07555 .4554 L
.07554 .45543 L
.07554 .45546 L
.07554 .45553 L
.07554 .45562 L
.07554 .45577 L
.07554 .45599 L
.07554 .4563 L
.07553 .45674 L
.07553 .45715 L
.07552 .45756 L
.07551 .45798 L
.07549 .45842 L
.07548 .45887 L
.07547 .4592 L
.07546 .45957 L
.07545 .45986 L
.07545 .46009 L
.07544 .46025 L
.07543 .46037 L
.07543 .46045 L
.07542 .46049 L
.07542 .4605 L
.07542 .46046 L
.07542 .46041 L
.07542 .46037 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
Mistroke
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46034 L
.07542 .46033 L
.07542 .46031 L
.07544 .46024 L
Mistroke
.07553 .46014 L
.07557 .46009 L
.07555 .46012 L
.07549 .46021 L
.07535 .46039 L
.07506 .46069 L
.07456 .46113 L
.0739 .46165 L
.07336 .46219 L
.07288 .4627 L
.07243 .46317 L
.07196 .46361 L
.07144 .46405 L
.07093 .46451 L
.07041 .46497 L
.06999 .46535 L
.06977 .46556 L
.06968 .46564 L
.06965 .46562 L
.06967 .46554 L
.06975 .46541 L
.06979 .46526 L
.06977 .46519 L
.06972 .46519 L
.06969 .46522 L
.06969 .46524 L
.06973 .46526 L
.06982 .46527 L
.06998 .46526 L
.07019 .46526 L
.07045 .46526 L
.07072 .46525 L
.07099 .46525 L
.07125 .46524 L
.07149 .46524 L
.07174 .46523 L
.072 .46523 L
.07224 .46523 L
.07244 .46522 L
.07256 .46522 L
.07262 .46522 L
.07265 .46522 L
.07264 .46522 L
.0726 .46522 L
.07256 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
Mistroke
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07253 .46522 L
.07252 .46522 L
.0725 .46522 L
.07246 .46522 L
.07242 .46523 L
.07241 .46523 L
.07242 .46523 L
.07246 .46522 L
.07256 .46522 L
.07271 .46522 L
.07293 .46522 L
.07318 .46521 L
.07346 .46521 L
.07373 .4652 L
Mistroke
.07399 .4652 L
.07423 .46519 L
.07448 .46519 L
.07474 .46519 L
.07498 .46518 L
.07517 .46518 L
.07529 .46518 L
.07536 .46518 L
.07538 .46518 L
.07537 .46518 L
.07534 .46518 L
.07529 .46518 L
.07527 .46518 L
.07526 .46518 L
.07526 .4652 L
.07528 .46525 L
.07532 .46532 L
.07536 .46539 L
.07537 .46542 L
.07536 .4654 L
.07532 .4653 L
.07523 .46512 L
.07508 .46484 L
.07488 .46447 L
.07464 .46404 L
.07439 .46357 L
.07413 .46308 L
.07388 .4626 L
.07365 .46213 L
.07341 .46166 L
.07317 .46121 L
.07294 .46083 L
.07277 .46057 L
.07266 .46043 L
.07263 .46038 L
.07265 .46037 L
.07268 .46038 L
.07271 .46035 L
.07273 .46023 L
.07272 .46 L
.07264 .45965 L
.07251 .45921 L
.07231 .45871 L
.07207 .45816 L
.07178 .45761 L
.07155 .45709 L
.07134 .45661 L
.07111 .45618 L
.07087 .45582 L
.07066 .45555 L
Mistroke
.07041 .45544 L
.07021 .45549 L
.07008 .45568 L
.07002 .45596 L
.06999 .45631 L
.06999 .45677 L
.07002 .45719 L
.07005 .45759 L
.07005 .45799 L
.07004 .4584 L
.07004 .45876 L
.07003 .45913 L
.07002 .45953 L
.07001 .45981 L
.07 .46 L
.07 .46017 L
.06998 .46029 L
.06995 .46039 L
.06991 .46046 L
.06986 .4605 L
.06984 .46051 L
.06985 .4605 L
.06989 .46047 L
.06999 .46046 L
.07014 .46044 L
.07036 .46043 L
.07061 .46042 L
.07089 .46041 L
.07116 .4604 L
.07142 .4604 L
.07166 .46039 L
.07191 .46039 L
.07217 .46039 L
.07241 .46038 L
.0726 .46038 L
.07272 .46038 L
.07279 .46038 L
.07281 .46038 L
.0728 .46038 L
.07276 .46038 L
.07274 .46038 L
.07276 .46038 L
.07279 .46038 L
.0728 .46041 L
.07279 .46046 L
.07274 .46053 L
.07264 .46059 L
.07247 .46061 L
.07226 .46056 L
.07201 .46042 L
Mistroke
.07173 .46019 L
.07143 .45981 L
.07115 .45946 L
.07089 .45903 L
.07064 .45857 L
.0704 .4581 L
.07018 .45766 L
.07004 .45719 L
.07003 .45672 L
.07014 .45629 L
.07035 .45592 L
.07061 .45563 L
.0709 .45542 L
.07121 .45531 L
.07152 .4553 L
.07179 .45534 L
.07205 .45541 L
.07231 .45548 L
.07255 .45552 L
.07275 .45554 L
.07288 .45554 L
.07295 .45554 L
.07298 .45554 L
.07297 .45554 L
.07294 .45554 L
.0729 .45554 L
.07287 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07286 .45554 L
.07288 .45554 L
.07292 .45554 L
.07296 .45554 L
.07298 .45553 L
.07296 .45553 L
.07292 .45553 L
.07282 .45551 L
.07266 .45548 L
.07245 .45543 L
.07219 .45538 L
.07192 .45536 L
.07164 .45538 L
.07137 .45549 L
.07112 .4557 L
.07086 .45598 L
.07059 .45634 L
.07035 .45664 L
.07015 .45704 L
.07001 .45747 L
Mistroke
.06994 .45792 L
.06992 .45829 L
.06992 .45859 L
.06995 .45884 L
.06999 .45905 L
.07001 .45915 L
.07002 .45915 L
.07002 .45905 L
.07003 .45882 L
.07003 .45846 L
.07004 .45806 L
.07005 .45762 L
.07006 .45714 L
.07007 .45676 L
.07008 .45648 L
.07008 .45615 L
.0701 .45583 L
.07011 .45556 L
.07012 .45537 L
.07012 .4553 L
.07012 .45535 L
.07012 .45551 L
.07011 .45578 L
.0701 .45613 L
.07009 .45655 L
.07007 .45709 L
.07005 .45756 L
.07003 .45807 L
.07002 .45852 L
.07 .45898 L
.06999 .45944 L
.06998 .45985 L
.06997 .46019 L
.06996 .46042 L
.06995 .46056 L
.06995 .46063 L
.06995 .46063 L
.06995 .46059 L
.06995 .46053 L
.06995 .46048 L
.06996 .46044 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06998 .46042 L
.06998 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
Mistroke
.06999 .46041 L
.06999 .46041 L
.06999 .46041 L
.06998 .46042 L
.06998 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06995 .46042 L
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06997 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06995 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46043 L
.06995 .46044 L
.06995 .46045 L
.06995 .46046 L
.06996 .46046 L
.06996 .46045 L
.06996 .46044 L
.06997 .46042 L
.06997 .46038 L
.06998 .46033 L
.06999 .46026 L
Mistroke
.06999 .4602 L
.07 .46013 L
.07001 .46007 L
.07001 .46004 L
.07002 .46003 L
.07002 .46002 L
.07002 .46002 L
.07002 .46004 L
.07001 .46007 L
.07 .4601 L
.06999 .46016 L
.06998 .46022 L
.06998 .46029 L
.06997 .46036 L
.06997 .4604 L
.06997 .46043 L
.06997 .46044 L
.06997 .46045 L
.06997 .46046 L
.06997 .46046 L
.06997 .46045 L
.06997 .46042 L
.06997 .46044 L
.06997 .46043 L
.06997 .46037 L
.06997 .46026 L
.06998 .46012 L
.06998 .45997 L
.06999 .45984 L
.06999 .45972 L
.06999 .45962 L
.07 .4595 L
.07 .45938 L
.07001 .45925 L
.07002 .45917 L
.07002 .45915 L
.07002 .4592 L
.07001 .45931 L
.07001 .45943 L
.07 .45955 L
.07 .45962 L
.07 .45959 L
.07 .45947 L
.07001 .45926 L
.07002 .45893 L
.07003 .45851 L
.07004 .45803 L
.07006 .45758 L
.07007 .45713 L
.07008 .45669 L
Mistroke
.0701 .45625 L
.07011 .45586 L
.07012 .45556 L
.07013 .45539 L
.07013 .45539 L
.07012 .45553 L
.07011 .45575 L
.0701 .45601 L
.07009 .45623 L
.07009 .45638 L
.07008 .45648 L
.07008 .45656 L
.07007 .45664 L
.07007 .45672 L
.07006 .45678 L
.07006 .4568 L
.07006 .45677 L
.07007 .45668 L
.07007 .45653 L
.07008 .45633 L
.07009 .45611 L
.0701 .45594 L
.0701 .45586 L
.0701 .45583 L
.0701 .45586 L
.0701 .45591 L
.0701 .45596 L
.07009 .45602 L
.07009 .45611 L
.07009 .4562 L
.07009 .45627 L
.07008 .45634 L
.07008 .45643 L
.07008 .45654 L
.07007 .45667 L
.07007 .45682 L
.07006 .45699 L
.07006 .45723 L
.07005 .45752 L
.07004 .45782 L
.07004 .4581 L
.07003 .45835 L
.07002 .4586 L
.07002 .4589 L
.07001 .4592 L
.07 .45945 L
.07 .45962 L
.07 .45972 L
.07 .45978 L
.07 .45978 L
Mistroke
.07 .45972 L
.07 .45961 L
.07001 .45947 L
.07001 .45937 L
.07001 .45934 L
.07001 .45941 L
.07 .45952 L
.07 .45964 L
.06999 .45979 L
.06998 .45993 L
.06998 .46007 L
.06997 .46019 L
.06996 .46029 L
.06996 .46038 L
.06996 .46046 L
.06995 .46051 L
.06995 .46053 L
.06996 .46049 L
.06996 .46042 L
.06996 .46036 L
.06997 .46035 L
.06997 .46036 L
.06997 .46036 L
.06997 .46032 L
.06997 .46026 L
.06998 .46019 L
.06998 .46012 L
.06998 .46006 L
.06999 .46002 L
.06999 .45997 L
.06999 .45988 L
.06999 .45975 L
.07 .45959 L
.07 .45942 L
.07001 .45927 L
.07001 .45912 L
.07002 .459 L
.07002 .45892 L
.07002 .4589 L
.07002 .45892 L
.07002 .45899 L
.07002 .45908 L
.07001 .45917 L
.07001 .45928 L
.07 .4594 L
.07 .45954 L
.06999 .45973 L
.06998 .4599 L
.06998 .46011 L
.06997 .46028 L
Mistroke
.06996 .46039 L
.06996 .46045 L
.06996 .46045 L
.06996 .46043 L
.06996 .4604 L
.06996 .46038 L
.06996 .46036 L
.06997 .46034 L
.06997 .46031 L
.06997 .46028 L
.06997 .46027 L
.06997 .4603 L
.06997 .46033 L
.06997 .46035 L
.06997 .46033 L
.06997 .4603 L
.06997 .46026 L
.06997 .4602 L
.06998 .46013 L
.06998 .46007 L
.06998 .46002 L
.06999 .45998 L
.06999 .45995 L
.06999 .45993 L
.06999 .45992 L
.06999 .45991 L
.06999 .45994 L
.06999 .45998 L
.06998 .46005 L
.06998 .46014 L
.06997 .46024 L
.06996 .46034 L
.06996 .46042 L
.06995 .46048 L
.06995 .46051 L
.06995 .46051 L
.06995 .46047 L
.06996 .46044 L
.06996 .46043 L
.06996 .46044 L
.06996 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46041 L
.06996 .46039 L
.06996 .46035 L
.06997 .46032 L
.06997 .4603 L
.06997 .46028 L
.06997 .46027 L
Mistroke
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46026 L
.06997 .46025 L
.06997 .46025 L
.06997 .46025 L
.06997 .46026 L
.06997 .46026 L
.06997 .46027 L
.06997 .46028 L
.06997 .46028 L
.06997 .46027 L
.06997 .46027 L
.06997 .46027 L
.06997 .46029 L
.06997 .46032 L
.06996 .46035 L
.06996 .46038 L
.06996 .46041 L
.06996 .46044 L
.06995 .46047 L
.06995 .46048 L
.06995 .46047 L
.06996 .46045 L
.06996 .46042 L
.06996 .46038 L
.06996 .46035 L
.06997 .46032 L
.06997 .46029 L
.06997 .46027 L
.06997 .46025 L
.06997 .46024 L
.06997 .46024 L
.06997 .46024 L
.06997 .46025 L
.06997 .46026 L
.06997 .46028 L
.06997 .46031 L
.06996 .46034 L
.06996 .46038 L
.06996 .46041 L
.06996 .46043 L
.06996 .46045 L
.06995 .46045 L
.06996 .46045 L
.06996 .46044 L
.06996 .46044 L
.06995 .46047 L
Mistroke
.06995 .4605 L
.06995 .46051 L
.06995 .46048 L
.06996 .46043 L
.06996 .46035 L
.06997 .46026 L
.06997 .46016 L
.06998 .46007 L
.06998 .46 L
.06999 .45995 L
.06999 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45989 L
.06997 .45995 L
.06997 .46004 L
.06997 .46012 L
.06997 .46019 L
.06996 .46024 L
.06996 .46027 L
.06996 .46026 L
.06996 .46022 L
.06997 .46015 L
.06997 .46007 L
.06997 .45998 L
.06998 .45991 L
.06998 .45988 L
.06998 .45988 L
.06998 .45988 L
.06998 .4599 L
.06997 .45995 L
.06997 .46003 L
.06997 .46012 L
.06996 .46023 L
.06996 .46033 L
.06996 .46042 L
.06996 .46048 L
.06995 .46052 L
.06995 .46054 L
.06995 .46056 L
.06995 .4606 L
.06995 .46066 L
.06995 .46069 L
.06995 .46067 L
.06995 .46056 L
.06996 .46037 L
.06997 .46008 L
.06998 .45971 L
.07 .45928 L
.07001 .4588 L
Mistroke
.07003 .45826 L
.07005 .45771 L
.07007 .45714 L
.07009 .45658 L
.0701 .4561 L
.07012 .45572 L
.07012 .45551 L
.07013 .45549 L
.07012 .45566 L
.07011 .45597 L
.07009 .4564 L
.07008 .45691 L
.07006 .45746 L
.07004 .458 L
.07002 .45853 L
.07 .45904 L
.06999 .45951 L
.06997 .45991 L
.06996 .46025 L
.06996 .46044 L
.06995 .46052 L
.06996 .46048 L
.06996 .46031 L
.06997 .46005 L
.06998 .45974 L
.06999 .45942 L
.07 .45914 L
.07001 .45889 L
.07002 .45871 L
.07002 .45857 L
.07002 .45849 L
.07002 .45848 L
.07002 .45855 L
.07002 .45868 L
.07001 .45895 L
.07 .45923 L
.06999 .45955 L
.06998 .45983 L
.06997 .46003 L
.06997 .46015 L
.06997 .46018 L
.06997 .46011 L
.06997 .46001 L
.06998 .45991 L
.06998 .45984 L
.06998 .4598 L
.06998 .45979 L
.06998 .45978 L
.06998 .45974 L
.06998 .45964 L
Mistroke
.06999 .4595 L
.07 .45932 L
.07 .45907 L
.07001 .45875 L
.07003 .45838 L
.07004 .45804 L
.07005 .45774 L
.07006 .45742 L
.07007 .45708 L
.07008 .45674 L
.07009 .45646 L
.0701 .4563 L
.0701 .45624 L
.0701 .45629 L
.07009 .45642 L
.07009 .45658 L
.07008 .45678 L
.07007 .45699 L
.07007 .45719 L
.07006 .45734 L
.07006 .45745 L
.07005 .45759 L
.07005 .45773 L
.07004 .4579 L
.07004 .45809 L
.07003 .45832 L
.07002 .45859 L
.07001 .45888 L
.07 .4592 L
.06999 .45948 L
.06998 .45969 L
.06998 .45985 L
.06997 .45991 L
.06997 .45993 L
.06998 .45991 L
.06998 .45983 L
.06998 .45972 L
.06999 .45956 L
.06999 .45935 L
.07 .45909 L
.07001 .45881 L
.07002 .4585 L
.07004 .45814 L
.07005 .45773 L
.07006 .45728 L
.07008 .45687 L
.07009 .45656 L
.0701 .45629 L
.0701 .45612 L
.07011 .45608 L
Mistroke
.0701 .45614 L
.0701 .45626 L
.07009 .45641 L
.07009 .45657 L
.07008 .45671 L
.07008 .45685 L
.07008 .45697 L
.07007 .45707 L
.07007 .45707 L
.07007 .45698 L
.07008 .45685 L
.07009 .45665 L
.07009 .45643 L
.0701 .4562 L
.07011 .45598 L
.07012 .45579 L
.07012 .45568 L
.07012 .4557 L
.07011 .45587 L
.0701 .45618 L
.07009 .45656 L
.07007 .45699 L
.07006 .45736 L
.07005 .45766 L
.07004 .45787 L
.07004 .45798 L
.07004 .45797 L
.07004 .4579 L
.07005 .45777 L
.07005 .45758 L
.07006 .45735 L
.07007 .45707 L
.07008 .45677 L
.07009 .4565 L
.0701 .45624 L
.07011 .45602 L
.07011 .45581 L
.07012 .45564 L
.07012 .45554 L
.07012 .45554 L
.07012 .45565 L
.07011 .45581 L
.07011 .45598 L
.0701 .45615 L
.0701 .45631 L
.07009 .45647 L
.07009 .45663 L
.07008 .45678 L
.07008 .45691 L
.07007 .45703 L
Mistroke
.07007 .45712 L
.07007 .45717 L
.07007 .45721 L
.07007 .4572 L
.07007 .45715 L
.07007 .45706 L
.07008 .45696 L
.07008 .4568 L
.07009 .45661 L
.07009 .45648 L
.0701 .45637 L
.0701 .45633 L
.0701 .45632 L
.0701 .45636 L
.0701 .45634 L
.0701 .45629 L
.0701 .45622 L
.0701 .45618 L
.0701 .45614 L
.0701 .4561 L
.07011 .45602 L
.07011 .45594 L
.07011 .45588 L
.07011 .45586 L
.07011 .45591 L
.07011 .45601 L
.0701 .45616 L
.0701 .45634 L
.07009 .45652 L
.07008 .45672 L
.07008 .4569 L
.07007 .45703 L
.07007 .45712 L
.07007 .45717 L
.07007 .45716 L
.07007 .45711 L
.07007 .457 L
.07008 .45683 L
.07009 .45657 L
.0701 .45634 L
.07011 .45607 L
.07011 .45583 L
.07012 .45567 L
.07012 .45561 L
.07012 .45566 L
.07011 .45581 L
.07011 .45601 L
.0701 .45621 L
.07009 .4564 L
.07009 .45656 L
Mistroke
.07008 .4567 L
.07008 .45682 L
.07008 .45689 L
.07008 .4569 L
.07008 .45689 L
.07008 .45681 L
.07008 .45668 L
.07009 .45648 L
.0701 .4563 L
.07011 .45608 L
.07011 .45588 L
.07012 .45572 L
.07012 .45562 L
.07012 .45557 L
.07012 .45555 L
.07012 .45554 L
.07012 .45552 L
.07012 .4555 L
.07013 .4555 L
.07012 .45551 L
.07012 .45555 L
.07012 .45558 L
.07012 .45561 L
.07012 .45563 L
.07012 .45566 L
.07012 .45569 L
.07012 .45574 L
.07012 .45579 L
.07011 .45582 L
.07011 .45583 L
.07011 .45581 L
.07011 .45581 L
.07011 .45585 L
.07011 .45594 L
.07011 .45607 L
.0701 .45622 L
.0701 .45638 L
.07009 .45652 L
.07009 .45664 L
.07008 .45672 L
.07008 .45677 L
.07008 .45677 L
.07008 .45675 L
.07008 .45669 L
.07009 .45663 L
.07009 .45653 L
.07009 .4564 L
.0701 .45624 L
.07011 .45605 L
.07011 .45585 L
Mistroke
.07012 .45567 L
.07012 .45552 L
.07013 .45543 L
.07013 .4554 L
.07013 .45544 L
.07013 .45549 L
.07012 .45552 L
.07013 .4555 L
.07013 .45546 L
.07013 .45544 L
.07013 .45547 L
.07012 .45556 L
.07012 .4557 L
.07011 .45587 L
.07011 .45604 L
.0701 .45621 L
.0701 .45636 L
.07009 .45648 L
.07009 .45658 L
.07009 .45665 L
.07008 .4567 L
.07008 .45673 L
.07008 .45672 L
.07009 .45663 L
.07009 .4565 L
.0701 .45635 L
.0701 .4562 L
.07011 .45605 L
.07011 .45596 L
.07011 .4559 L
.07011 .45589 L
.07011 .45592 L
.07011 .45594 L
.07011 .45592 L
.07011 .45587 L
.07011 .45585 L
.07011 .45591 L
.07011 .45606 L
.0701 .45626 L
.07009 .45649 L
.07008 .45672 L
.07008 .45693 L
.07007 .45707 L
.07007 .45715 L
.07007 .45717 L
.07007 .45716 L
.07007 .45715 L
.07007 .45713 L
.07007 .45711 L
.07008 .45697 L
Mistroke
.07008 .45675 L
.07009 .45647 L
.0701 .45615 L
.07011 .45584 L
.07012 .45558 L
.07013 .45539 L
.07013 .45531 L
.07013 .45531 L
.07013 .45537 L
.07013 .45544 L
.07012 .45552 L
.07012 .45559 L
.07012 .45568 L
.07012 .45578 L
.07011 .45593 L
.0701 .45616 L
.07009 .45646 L
.07008 .45675 L
.07006 .45707 L
.07005 .45736 L
.07005 .45758 L
.07004 .45774 L
.07004 .45783 L
.07004 .45782 L
.07004 .45773 L
.07005 .45759 L
.07006 .4574 L
.07006 .45719 L
.07007 .45691 L
.07008 .4566 L
.0701 .45628 L
.07011 .45596 L
.07012 .45568 L
.07013 .45545 L
.07013 .4553 L
.07014 .45521 L
.07014 .45523 L
.07013 .45536 L
.07012 .45559 L
.07011 .45588 L
.0701 .4562 L
.07009 .45654 L
.07007 .45687 L
.07006 .45716 L
.07005 .45741 L
.07005 .45757 L
.07004 .45767 L
.07004 .4577 L
.07004 .45766 L
.07005 .45757 L
Mistroke
.07006 .45737 L
.07007 .45714 L
.07008 .45683 L
.07009 .45648 L
.0701 .45614 L
.07011 .45584 L
.07012 .4556 L
.07013 .45545 L
.07013 .45538 L
.07013 .45537 L
.07013 .45541 L
.07013 .45549 L
.07012 .45555 L
.07012 .45559 L
.07012 .45561 L
.07012 .45563 L
.07011 .45569 L
.07011 .45575 L
.0701 .45583 L
.0701 .45594 L
.07009 .45603 L
.07009 .4561 L
.07008 .45617 L
.07008 .45624 L
.07007 .45634 L
.07007 .45647 L
.07007 .45663 L
.07006 .45684 L
.07006 .45712 L
.07005 .45745 L
.07003 .45779 L
.07003 .45812 L
.07003 .45839 L
.07003 .45856 L
.07003 .45866 L
.07004 .45869 L
.07004 .45869 L
.07004 .45861 L
.07004 .45846 L
.07004 .45821 L
.07004 .45789 L
.07006 .45751 L
.07007 .45711 L
.07008 .45671 L
.0701 .4563 L
.07011 .45602 L
.07011 .45579 L
.07012 .45564 L
.07012 .45555 L
.07012 .45551 L
Mistroke
.07012 .45552 L
.07012 .45554 L
.07012 .45556 L
.07012 .45555 L
.07012 .45554 L
.07013 .45554 L
.07012 .45555 L
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07013 .45553 L
.07013 .45549 L
.07013 .45548 L
.07013 .4555 L
.07012 .45557 L
.07012 .45565 L
.07011 .45574 L
.07011 .45582 L
.07011 .45589 L
.0701 .45597 L
.0701 .45607 L
.07009 .45618 L
.07008 .4563 L
.07008 .45642 L
.07007 .45651 L
.07007 .45658 L
.07007 .4566 L
.07007 .45655 L
.07007 .45645 L
.07008 .45629 L
.07009 .45615 L
.07009 .45604 L
.0701 .45594 L
.0701 .45589 L
.0701 .4559 L
.0701 .456 L
.07009 .45617 L
.07009 .45639 L
Mistroke
.07008 .45663 L
.07007 .45688 L
.07006 .45712 L
.07006 .45732 L
.07005 .4575 L
.07004 .4576 L
.07004 .4576 L
.07005 .45752 L
.07005 .45738 L
.07006 .4572 L
.07007 .45693 L
.07008 .45663 L
.07009 .45631 L
.07011 .45601 L
.07011 .45576 L
.07012 .45558 L
.07013 .45546 L
.07013 .45539 L
.07013 .45538 L
.07013 .45543 L
.07013 .4555 L
.07012 .45555 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45556 L
.07012 .45555 L
.07012 .45553 L
.07013 .45553 L
.07012 .45552 L
.07012 .45551 L
.07012 .4555 L
.07012 .45551 L
.07012 .45554 L
.07012 .45561 L
.07011 .45574 L
.0701 .45594 L
.07009 .45622 L
.07008 .45654 L
.07007 .45683 L
.07006 .45716 L
.07005 .45751 L
.07004 .45784 L
.07003 .45814 L
.07003 .4584 L
.07002 .45859 L
.07002 .45877 L
.07002 .45892 L
.07002 .45904 L
.07002 .45911 L
Mistroke
.07002 .45916 L
.07001 .45922 L
.07001 .45929 L
.07001 .45937 L
.07001 .45943 L
.07 .45945 L
.07 .45944 L
.07001 .45933 L
.07001 .45915 L
.07002 .45896 L
.07002 .45875 L
.07003 .45851 L
.07003 .45827 L
.07004 .45804 L
.07004 .45781 L
.07005 .45756 L
.07006 .45731 L
.07006 .45708 L
.07007 .45688 L
.07007 .4567 L
.07007 .45653 L
.07008 .45642 L
.07008 .45634 L
.07008 .4563 L
.07008 .45633 L
.07008 .45639 L
.07008 .45626 L
.07008 .45648 L
.07007 .45677 L
.07006 .45715 L
.07005 .45762 L
.07004 .45817 L
.07002 .45875 L
.07001 .45929 L
.07 .45974 L
.06999 .46007 L
.06998 .4603 L
.06998 .46036 L
.06998 .46027 L
.06999 .45999 L
.07 .45959 L
.07002 .45913 L
.07003 .45864 L
.07004 .45819 L
.07005 .45776 L
.07005 .45737 L
.07006 .457 L
.07006 .45663 L
.07007 .45636 L
.07008 .45613 L
Mistroke
.07008 .45596 L
.07009 .45584 L
.07009 .45578 L
.07009 .45578 L
.07009 .4558 L
.07009 .4558 L
.07009 .45579 L
.07009 .45578 L
.07009 .45577 L
.07009 .45576 L
.07009 .45576 L
.07009 .45576 L
.07009 .45575 L
.07009 .45576 L
.07009 .45578 L
.07009 .45579 L
.07009 .45578 L
.0701 .45575 L
.0701 .45571 L
.07011 .45566 L
.07012 .45562 L
.07012 .45558 L
.07013 .45555 L
.07013 .45554 L
.07013 .45554 L
.07013 .45556 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45557 L
.07013 .45555 L
.07013 .45554 L
.07013 .45553 L
.07013 .45555 L
.07012 .45558 L
.07012 .45562 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45562 L
.07012 .45557 L
.07013 .45552 L
.07013 .45549 L
.07013 .45549 L
.07013 .45552 L
.07012 .45557 L
.07012 .45561 L
.07011 .45567 L
.07011 .45572 L
.0701 .45577 L
.0701 .45581 L
.07009 .45583 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
.07009 .45585 L
Mistroke
.07009 .45584 L
.07009 .45582 L
.0701 .45578 L
.0701 .45573 L
.07011 .45568 L
.07012 .45563 L
.07012 .45558 L
.07013 .45555 L
.07013 .45553 L
.07013 .45553 L
.07013 .45555 L
.07012 .45557 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07011 .4556 L
.07009 .45563 L
.07005 .45567 L
.07001 .4557 L
.06999 .45572 L
.07 .45571 L
.07006 .45565 L
.07016 .45556 L
.07032 .45541 L
.07054 .45522 L
.07079 .45501 L
.07107 .45476 L
.07136 .45451 L
.07163 .45425 L
.07189 .454 L
.07215 .45375 L
.07242 .45352 L
.07266 .45333 L
.07285 .45317 L
.07298 .45306 L
Mistroke
.07305 .45299 L
.07307 .45297 L
.07306 .45299 L
.07303 .45303 L
.07298 .45307 L
.07295 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07293 .4531 L
.0729 .45308 L
.07286 .45304 L
.07283 .453 L
.07281 .45298 L
.07282 .453 L
.07287 .45305 L
.07297 .45314 L
.07312 .45328 L
.07333 .45346 L
.07357 .45368 L
.07383 .45391 L
.0741 .45416 L
.07436 .4544 L
.0746 .45465 L
.07485 .45489 L
.0751 .45511 L
.07533 .4553 L
.07551 .45545 L
.07563 .45556 L
.0757 .45562 L
.07572 .45564 L
.07571 .45562 L
Mistroke
.07567 .45559 L
.07563 .45555 L
.0756 .45552 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
Mistroke
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .4555 L
.07559 .45549 L
.07559 .45547 L
.07562 .45541 L
.07567 .45534 L
.07571 .45527 L
.07571 .45523 L
.07569 .45526 L
.07563 .45536 L
.0755 .45555 L
.0753 .45584 L
.07504 .45621 L
.07476 .45665 L
.07447 .45713 L
.07419 .45763 L
.07391 .45812 L
.07367 .45861 L
.07339 .45909 L
.07312 .45955 L
.07288 .45995 L
.07271 .46027 L
.07262 .46049 L
.07257 .46061 L
.07256 .46065 L
.07258 .46062 L
.07263 .46055 L
.07267 .46047 L
.07269 .46041 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
Mistroke
.07269 .46038 L
.07269 .46038 L
.07269 .46038 L
.07269 .4604 L
.07269 .46044 L
.07269 .4605 L
.07268 .46057 L
.07269 .46058 L
.07272 .46052 L
.07276 .46037 L
.07281 .46017 L
.07283 .45993 L
.07283 .45967 L
.07279 .45943 L
.07269 .45925 L
.07254 .45912 L
.07233 .45904 L
.07208 .45902 L
.0718 .45902 L
.07153 .45905 L
.07127 .45908 L
.07102 .4592 L
.07076 .45939 L
.07049 .45966 L
.07024 .45998 L
.07005 .46031 L
.06991 .4606 L
.06984 .4608 L
.06981 .46086 L
.06983 .46076 L
.06987 .46051 L
.06993 .46017 L
.06997 .45976 L
.06999 .4593 L
.07001 .45882 L
.07003 .45832 L
.07005 .45782 L
.07006 .45733 L
.07008 .45686 L
.0701 .45641 L
.07011 .45601 L
.07012 .45569 L
.07013 .45547 L
.07013 .45535 L
.07013 .45531 L
.07013 .45533 L
.07013 .45539 L
.07013 .45546 L
.07013 .4555 L
.07012 .45549 L
Mistroke
.07012 .45545 L
.07012 .45542 L
.07012 .45544 L
.07012 .45551 L
.07011 .45567 L
.0701 .4559 L
.07009 .45624 L
.07008 .45668 L
.07006 .45711 L
.07005 .4576 L
.07003 .4581 L
.07002 .45855 L
.07001 .45901 L
.07 .45946 L
.06999 .45987 L
.06998 .4602 L
.06998 .46041 L
.06998 .46048 L
.06998 .46036 L
.06999 .46012 L
.07 .45971 L
.07001 .45917 L
.07003 .45866 L
.07004 .45816 L
.07005 .45774 L
.07006 .45745 L
.07006 .45723 L
.07006 .45709 L
.07006 .45702 L
.07006 .45699 L
.07006 .45701 L
.07006 .45706 L
.07005 .4571 L
.07005 .45716 L
.07005 .4572 L
.07005 .45724 L
.07005 .45727 L
.07006 .45714 L
.07007 .45697 L
.07008 .45668 L
.07009 .45636 L
.0701 .45605 L
.07011 .45579 L
.07012 .45559 L
.07013 .45547 L
.07013 .45543 L
.07013 .45542 L
.07013 .45545 L
.07013 .4555 L
.07012 .45554 L
Mistroke
.07012 .45556 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
.07012 .45558 L
Mistroke
.07012 .45558 L
.07012 .45558 L
.07012 .4556 L
.07013 .45562 L
.07017 .45566 L
.07026 .4557 L
.07029 .45571 L
.07027 .4557 L
.0702 .45565 L
.07005 .45556 L
.06976 .45542 L
.0693 .45524 L
.06872 .45503 L
.06817 .4548 L
.0677 .45456 L
.06725 .45432 L
.06679 .45407 L
.06631 .45384 L
.06582 .45362 L
.06532 .45342 L
.06492 .45325 L
.0647 .45308 L
.06461 .45292 L
.06458 .4528 L
.0646 .45277 L
.06467 .45284 L
.06473 .45302 L
.06474 .45332 L
.06472 .45375 L
.0647 .45431 L
.06468 .45497 L
.06465 .45568 L
.06463 .45642 L
.0646 .45713 L
.06457 .45782 L
.06455 .45851 L
.06453 .45919 L
.06451 .45981 L
.06449 .4603 L
.06448 .46063 L
.06447 .46081 L
.06447 .46087 L
.06447 .46084 L
.06445 .46075 L
.06442 .46063 L
.06438 .46055 L
.06436 .46052 L
.06437 .46051 L
.06441 .46051 L
.06449 .46051 L
Mistroke
.06463 .46051 L
.06482 .4605 L
.06506 .4605 L
.06533 .46049 L
.0656 .46049 L
.06584 .46049 L
.06605 .46048 L
.06629 .46048 L
.06656 .46048 L
.06684 .46049 L
.06711 .46051 L
.06738 .46054 L
.06766 .46059 L
.06796 .46064 L
.06823 .46066 L
.06848 .46061 L
.06871 .46049 L
.06893 .46028 L
.06918 .45999 L
.06944 .45964 L
.06967 .45925 L
.06988 .45891 L
.07004 .45862 L
.07014 .45844 L
.07019 .45828 L
.07019 .45815 L
.07016 .45801 L
.0701 .45787 L
.07007 .45772 L
.07005 .45759 L
.07004 .45749 L
.07005 .45735 L
.07007 .45728 L
.07009 .4572 L
.07009 .45712 L
.07008 .45692 L
.07008 .45663 L
.07009 .4563 L
.0701 .45597 L
.07012 .4557 L
.07012 .45551 L
.07013 .45541 L
.07013 .45538 L
.07013 .4554 L
.07013 .45545 L
.07013 .45551 L
.07012 .45556 L
.07011 .45558 L
.07007 .4556 L
.07003 .45563 L
Mistroke
.06999 .45567 L
.06997 .4557 L
.06998 .45572 L
.07004 .45571 L
.07015 .45565 L
.07032 .45555 L
.07053 .45541 L
.07078 .45522 L
.07106 .455 L
.07135 .45476 L
.07163 .45451 L
.07192 .45425 L
.07219 .454 L
.07246 .45375 L
.07269 .45352 L
.07287 .45332 L
.073 .45317 L
.07307 .45306 L
.0731 .45299 L
.07308 .45297 L
.07304 .45299 L
.07299 .45303 L
.07296 .45307 L
.07294 .4531 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
Mistroke
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07294 .45312 L
.07296 .45309 L
.07299 .45301 L
.07304 .4529 L
.07308 .4528 L
.0731 .45276 L
.07308 .4528 L
.07302 .45296 L
.0729 .45325 L
.07273 .45369 L
.0725 .45426 L
.07224 .45493 L
.07194 .4557 L
.07163 .45652 L
.07133 .45732 L
.07103 .45807 L
Mistroke
.07073 .45879 L
.07046 .45945 L
.07022 .45998 L
.07003 .46029 L
.0699 .46033 L
.06984 .46012 L
.06983 .45974 L
.06986 .45923 L
.06992 .45864 L
.06999 .45802 L
.07004 .45743 L
.07008 .4569 L
.0701 .45643 L
.07011 .45602 L
.07012 .45568 L
.07013 .4554 L
.07014 .4552 L
.07014 .45509 L
.07014 .45508 L
.07014 .45517 L
.07013 .45535 L
.07012 .45561 L
.07011 .45592 L
.0701 .45629 L
.07008 .45674 L
.07006 .45725 L
.07005 .45775 L
.07003 .45822 L
.07002 .45869 L
.07 .45916 L
.06999 .4596 L
.06999 .45997 L
.06998 .46024 L
.06998 .46042 L
.06998 .46052 L
.06998 .46056 L
.06998 .46052 L
.06999 .46045 L
.06999 .46036 L
.06999 .46029 L
.06999 .46027 L
.06998 .46029 L
.06998 .46032 L
.06997 .46036 L
.06996 .46039 L
.06996 .46042 L
.06995 .46044 L
.06995 .46046 L
.06995 .46045 L
.06995 .46044 L
Mistroke
.06996 .46043 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46044 L
.06995 .46048 L
.06995 .46054 L
.06995 .46061 L
.06995 .46064 L
.06995 .46059 L
.06996 .46047 L
.06997 .46027 L
.06998 .46004 L
.06999 .4598 L
.07 .45957 L
.07 .45935 L
.07001 .45915 L
.07002 .45891 L
.07003 .45871 L
.07003 .45854 L
.07004 .45842 L
.07004 .45837 L
.07004 .45837 L
.07004 .4584 L
.07004 .45845 L
.07003 .45854 L
.07002 .45865 L
.07 .45876 L
.06997 .45885 L
.06995 .45885 L
.06996 .45876 L
.07 .45859 L
.07006 .45839 L
.07014 .45819 L
.07023 .45799 L
.07032 .45776 L
.0704 .45751 L
.07046 .45721 L
.0705 .45693 L
.07052 .45664 L
.07054 .45639 L
.07054 .45619 L
.07054 .45597 L
.07052 .45581 L
.07048 .45562 L
Mistroke
.07041 .45545 L
.07032 .45534 L
.07024 .45534 L
.07015 .45545 L
.07008 .45564 L
.07003 .45592 L
.07001 .45621 L
.07002 .45657 L
.07004 .45698 L
.07004 .45743 L
.07004 .4579 L
.07002 .4584 L
.07001 .45895 L
.06999 .45941 L
.06998 .45988 L
.06997 .46026 L
.06996 .4605 L
.06996 .46059 L
.06997 .4605 L
.06997 .46028 L
.06998 .45998 L
.06999 .45967 L
.07 .45937 L
.07001 .45913 L
.07002 .45889 L
.07002 .45868 L
.07003 .45845 L
.07004 .45823 L
.07005 .45805 L
.07005 .45794 L
.07005 .45793 L
.07005 .45803 L
.07004 .4582 L
.07003 .45845 L
.07003 .45877 L
.07002 .45906 L
.07001 .45931 L
.07001 .45944 L
.07 .45958 L
.06999 .45974 L
.06999 .45993 L
.06998 .46013 L
.06997 .46032 L
.06996 .46045 L
.06995 .46054 L
.06995 .46057 L
.06995 .46057 L
.06995 .46053 L
.06995 .46047 L
.06996 .46044 L
Mistroke
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
.06996 .46042 L
Mistroke
.06997 .46042 L
.07001 .46042 L
.07005 .46042 L
.07009 .46042 L
.07011 .46042 L
.07009 .46042 L
.07003 .46043 L
.06992 .46044 L
.06976 .46044 L
.06956 .46044 L
.06932 .46046 L
.06905 .46051 L
.06877 .46057 L
.06849 .46062 L
.06821 .46064 L
.06795 .46059 L
.0677 .46045 L
.06748 .46022 L
.06731 .45987 L
.0672 .45953 L
.06714 .4591 L
.06714 .45863 L
.06717 .45816 L
.06722 .45771 L
.06728 .45723 L
.06733 .45677 L
.06736 .45635 L
.06737 .45599 L
.06738 .4557 L
.06739 .45549 L
.06739 .45537 L
.0674 .45535 L
.0674 .45539 L
.06739 .45546 L
.06739 .45554 L
.06739 .45559 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
.06739 .45562 L
Mistroke
.06739 .45562 L
.06739 .45564 L
.06739 .45567 L
.06738 .45571 L
.06738 .45574 L
.06738 .45576 L
.06738 .45575 L
.06738 .45569 L
.06739 .4556 L
.06739 .45545 L
.0674 .45527 L
.06741 .45506 L
.06741 .45482 L
.06742 .45457 L
.06743 .45432 L
.06744 .45407 L
.06745 .45382 L
.06746 .4536 L
.06746 .4534 L
.06747 .45325 L
.06747 .45314 L
.06747 .45308 L
.06746 .45306 L
.06743 .45307 L
.06738 .45311 L
.06734 .45315 L
.06732 .45318 L
.06733 .4532 L
.06739 .4532 L
.06749 .4532 L
.06765 .4532 L
.06785 .4532 L
.06809 .45319 L
.06834 .45319 L
.06858 .45318 L
.06881 .45318 L
.06905 .45318 L
.0693 .45317 L
.06955 .45317 L
.0698 .45317 L
.07006 .45316 L
.07033 .45316 L
.07062 .45315 L
.07094 .45315 L
.07129 .45314 L
.07167 .45314 L
.07205 .45313 L
.07247 .45313 L
.07294 .45312 L
.07343 .45311 L
Mistroke
.07394 .45311 L
.07441 .4531 L
.0749 .45309 L
.0754 .45308 L
.07591 .45308 L
.07642 .45307 L
.07694 .45306 L
.07747 .45305 L
.07795 .45303 L
.07843 .45299 L
.07889 .45295 L
.07935 .45291 L
.07978 .45288 L
.0802 .45289 L
.08062 .45293 L
.08101 .45302 L
.08137 .45316 L
.08169 .45334 L
.08198 .45355 L
.08224 .45378 L
.08249 .45403 L
.08271 .45428 L
.08293 .45453 L
.08315 .45476 L
.08337 .45498 L
.08357 .45518 L
.08373 .45533 L
.08384 .45544 L
.08391 .4555 L
.08392 .45551 L
.08391 .4555 L
.08387 .45546 L
.08382 .45542 L
.08379 .45539 L
.08378 .45538 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08378 .45537 L
.08377 .45537 L
.08376 .45537 L
.08373 .45537 L
.08369 .45538 L
.08365 .45537 L
.08363 .45535 L
.08363 .45529 L
.08367 .45522 L
Mistroke
.08374 .45514 L
.08386 .4551 L
.08402 .45511 L
.08423 .45518 L
.0845 .4553 L
.0848 .4555 L
.08516 .45579 L
.08554 .45619 L
.08598 .45668 L
.08647 .45729 L
.087 .45798 L
.08755 .45875 L
.08809 .45959 L
.08862 .46045 L
.08913 .4613 L
.0896 .46211 L
.09004 .46283 L
.09043 .46345 L
.09078 .46397 L
.09109 .46439 L
.09135 .4647 L
.09154 .46493 L
.09167 .46508 L
.09174 .46517 L
.09178 .46519 L
.09178 .46516 L
.09176 .46509 L
.09172 .46501 L
.09168 .46494 L
.09164 .46491 L
.09163 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
Mistroke
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.09162 .46491 L
.0916 .46489 L
.09157 .46486 L
.09153 .46482 L
.09147 .46479 L
.09142 .46477 L
.09139 .46479 L
.09141 .46484 L
.09147 .46494 L
Mfstroke
.21776 .14939 m
.2177 .14937 L
s
.22745 .13705 m
.22748 .13712 L
.22745 .13714 L
.22738 .13711 L
s
.30359 .09337 m
.30369 .09334 L
.30362 .0934 L
.30344 .09354 L
.30322 .0937 L
.30302 .09382 L
.30292 .09387 L
.30295 .09383 L
.30314 .09368 L
.30349 .09344 L
.30395 .09315 L
.30451 .0928 L
.30516 .09242 L
.30588 .09199 L
.30659 .09152 L
.30737 .09104 L
.30826 .09053 L
.30907 .08999 L
.30988 .08947 L
.31062 .08898 L
.31125 .08856 L
.31175 .0882 L
.31211 .08793 L
.3124 .08772 L
.31262 .08755 L
.31282 .08742 L
.31303 .0873 L
.31327 .0872 L
.31353 .08712 L
.3138 .08708 L
.31406 .08707 L
.3143 .0871 L
.31451 .08714 L
.31472 .08719 L
.31494 .08723 L
.31515 .08725 L
.31535 .08726 L
.3155 .08726 L
.31561 .08727 L
.31568 .08727 L
.31569 .08727 L
.31567 .08727 L
.31562 .08727 L
.31555 .08727 L
.31548 .08726 L
.31543 .08726 L
.31541 .08726 L
.31542 .08726 L
.31547 .08726 L
.31557 .08727 L
Mistroke
.31572 .08727 L
.31591 .08728 L
.31613 .08729 L
.31637 .0873 L
.31663 .08731 L
.31689 .08732 L
.31715 .08732 L
.3174 .08733 L
.31765 .08734 L
.31787 .08735 L
.31809 .08736 L
.3183 .08737 L
.31845 .08738 L
.31849 .08738 L
.31842 .08738 L
.31822 .08737 L
.31786 .08736 L
.31733 .08734 L
.31662 .08731 L
.31579 .08729 L
.31495 .08726 L
.31416 .08723 L
.3135 .0872 L
.31291 .08717 L
.31235 .08715 L
.31185 .08716 L
.31153 .08721 L
Mfstroke
.34016 .0768 m
.34009 .07692 L
.34007 .07696 L
.34008 .07694 L
.34012 .07688 L
.34016 .0768 L
.34019 .07674 L
.34019 .07671 L
.34014 .07671 L
.34007 .0767 L
.33998 .0767 L
.33991 .0767 L
.33988 .07669 L
.33995 .0767 L
.34012 .0767 L
.34041 .07671 L
.34083 .07673 L
.34137 .07675 L
.34202 .07677 L
.34273 .0768 L
.34339 .07682 L
.34411 .07685 L
.34488 .07688 L
.34556 .07691 L
.3462 .07693 L
.34679 .07695 L
.34726 .07697 L
.34759 .07698 L
.34777 .07699 L
.34782 .077 L
.34778 .07703 L
.3477 .07706 L
.34765 .07707 L
.34765 .07706 L
.34771 .07704 L
.34784 .07702 L
.348 .077 L
.34815 .07697 L
.34828 .0769 L
.34837 .07677 L
.34843 .07657 L
.34846 .07631 L
.34846 .07598 L
.34844 .07566 L
.3484 .07534 L
.34832 .07498 L
.3482 .07462 L
.34805 .07427 L
.34789 .07392 L
.34773 .07355 L
Mistroke
.34759 .07318 L
.34749 .07283 L
.34745 .07259 L
.34745 .07245 L
.34748 .07239 L
.34752 .07244 L
.34755 .07265 L
.34756 .073 L
.34757 .07343 L
.34757 .07389 L
.34757 .07436 L
.34757 .07481 L
.34757 .07525 L
.34757 .07572 L
.34757 .07618 L
.34757 .07657 L
.34757 .07687 L
.34757 .07707 L
.34757 .07719 L
.34757 .07723 L
.34757 .07721 L
.34757 .07714 L
.34757 .07707 L
.34757 .07701 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
Mistroke
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34757 .07698 L
.34756 .07698 L
.34754 .077 L
.34747 .07705 L
.34739 .07713 L
.3473 .0772 L
.34722 .07726 L
.34717 .07729 L
.34716 .07728 L
.34723 .0772 L
Mfstroke
.41521 .0475 m
.41532 .04751 L
.41539 .04751 L
.41541 .04751 L
.41538 .04751 L
.41531 .04751 L
.41522 .0475 L
.41514 .0475 L
.41509 .0475 L
.41513 .0475 L
.41525 .0475 L
s
.49365 .05005 m
.4937 .05006 L
.49364 .05006 L
.49353 .05005 L
.4934 .05004 L
.4933 .05003 L
.49326 .05002 L
.49327 .05002 L
.49335 .05003 L
.49348 .05003 L
.49366 .05004 L
.49387 .05004 L
.4941 .05005 L
.49434 .05006 L
.49458 .05006 L
.49482 .05007 L
.49506 .05008 L
.49527 .05008 L
.49546 .05009 L
.49561 .05009 L
.49572 .0501 L
.49578 .0501 L
.4958 .0501 L
.49578 .0501 L
.49575 .0501 L
.49571 .0501 L
.49567 .0501 L
.49564 .05009 L
.49559 .05009 L
.49552 .05009 L
.49544 .05009 L
.49533 .05009 L
.49522 .05008 L
.49516 .05008 L
.49517 .05008 L
.49529 .05008 L
s
.52167 .05084 m
.52173 .05084 L
.5217 .05084 L
.52161 .05084 L
.52149 .05083 L
.52136 .05083 L
.52128 .05083 L
.52124 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52123 .05083 L
.52122 .05083 L
.52119 .05082 L
.52115 .05082 L
.5211 .05082 L
.52105 .05082 L
.521 .05082 L
.52095 .05082 L
.52091 .05082 L
.52092 .05082 L
.52103 .05082 L
s
.55624 .05177 m
.55631 .05177 L
.55628 .05177 L
.55619 .05177 L
.55606 .05176 L
.55594 .05176 L
.55585 .05176 L
.55582 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.5558 .05176 L
.55577 .05176 L
.5557 .05175 L
.5556 .05175 L
.55549 .05175 L
.55542 .05174 L
.5554 .05174 L
.55546 .05175 L
s
.597 .05439 m
.59709 .05439 L
.59713 .05432 L
.59711 .0542 L
.59706 .05403 L
.59698 .05386 L
.59691 .05368 L
.59686 .05351 L
.59684 .05349 L
.59684 .0534 L
.59684 .05334 L
.59684 .05323 L
.59684 .05314 L
.59684 .05311 L
.59684 .0532 L
.59684 .05341 L
.59684 .05374 L
.59686 .05419 L
.59688 .05471 L
.59692 .05523 L
.59696 .05575 L
.59697 .05626 L
.59696 .05669 L
.59691 .05698 L
.59682 .05709 L
.59669 .05702 L
.59652 .05676 L
.59632 .05633 L
.59609 .05579 L
.59586 .05519 L
.59562 .05463 L
.59538 .05413 L
.59514 .05373 L
.5949 .05346 L
.59468 .05334 L
.59451 .05339 L
.59439 .05358 L
.59434 .0539 L
.59437 .05433 L
.59448 .05482 L
.59465 .05533 L
.59486 .05586 L
.59509 .05635 L
.59533 .05675 L
.59556 .05705 L
.5958 .05727 L
.59604 .05739 L
.59627 .05744 L
.59649 .05744 L
.5967 .05743 L
Mistroke
.59688 .05743 L
.59702 .05744 L
.59709 .05745 L
.5971 .05742 L
.59703 .05733 L
.59691 .05715 L
.59674 .05689 L
.59654 .05655 L
.59632 .05615 L
.59609 .05572 L
.59586 .05526 L
.59562 .0548 L
.59539 .05436 L
.59516 .05391 L
.59495 .0535 L
.59476 .05314 L
.59461 .05284 L
.5945 .05264 L
.59441 .05253 L
.59436 .05249 L
.59434 .05251 L
.59436 .05258 L
.59441 .05265 L
.59449 .05271 L
.59459 .05274 L
.59473 .05274 L
.5949 .05275 L
.5951 .05275 L
.59532 .05276 L
.59556 .05277 L
.59579 .05277 L
.59603 .05278 L
.59626 .05278 L
.59647 .05279 L
.59665 .05279 L
.59679 .05279 L
.5969 .05279 L
.59695 .05278 L
.59697 .05278 L
.59695 .05277 L
.5969 .05276 L
.59686 .05274 L
.59683 .05272 L
.59683 .05272 L
.59685 .05275 L
.59687 .0528 L
.5969 .05287 L
.59693 .05298 L
.59697 .05315 L
.59702 .05342 L
Mistroke
.59708 .0537 L
.59712 .05405 L
.59714 .05439 L
.59713 .05468 L
.59707 .05485 L
.59697 .05494 L
.59682 .05496 L
.59662 .05494 L
.59639 .05492 L
.59613 .05491 L
.59587 .05492 L
.59561 .05496 L
.59536 .055 L
.59513 .05507 L
.59492 .05516 L
.59475 .05529 L
.59462 .05545 L
.59452 .05569 L
.59446 .05598 L
.59444 .05631 L
.59446 .05665 L
.59449 .05698 L
.59453 .05722 L
.59456 .05735 L
.59458 .05739 L
.59458 .05735 L
.59458 .05729 L
.59458 .05722 L
.59458 .05717 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59458 .05715 L
.59456 .05715 L
.59454 .05715 L
.5945 .05715 L
.59447 .05715 L
.59445 .05715 L
.59446 .05715 L
.59451 .05715 L
.5946 .05715 L
.59473 .05715 L
Mfstroke
.76635 .12377 m
.76623 .12381 L
.76591 .12377 L
.76549 .1237 L
.76503 .12361 L
.76461 .12353 L
.76423 .12345 L
.76391 .12341 L
.76364 .1234 L
.76342 .1234 L
.76323 .1234 L
.76309 .12339 L
.763 .12339 L
.76297 .12339 L
.76301 .12339 L
.76308 .12339 L
.76318 .12338 L
.76328 .12336 L
.76337 .12333 L
.76341 .1233 L
.7634 .12328 L
.76337 .12329 L
.76335 .12335 L
.76334 .12346 L
.76334 .12362 L
.76335 .12381 L
.76335 .12402 L
.76335 .12422 L
.76335 .12439 L
.76335 .12452 L
.76336 .1246 L
.76336 .12462 L
.76336 .12461 L
.76336 .12458 L
.76335 .12454 L
.76335 .12448 L
.76335 .1244 L
.76335 .12429 L
.76335 .12417 L
.76335 .12405 L
.76335 .12394 L
.76335 .12386 L
.76335 .12381 L
.76335 .1238 L
.76335 .12381 L
.76335 .12384 L
.76335 .12384 L
.76335 .12381 L
.76334 .12374 L
.76334 .12364 L
Mistroke
.76334 .12354 L
.76334 .12344 L
.76334 .12337 L
.76334 .12333 L
.76334 .12331 L
.76334 .12333 L
.76334 .12336 L
.76334 .12339 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .1234 L
.76334 .12339 L
.76332 .12338 L
.7633 .12338 L
.76326 .12338 L
.76323 .12339 L
.76322 .12341 L
.76323 .12343 L
.76328 .12346 L
.76336 .12348 L
.76349 .12351 L
.76365 .12353 L
.76385 .12355 L
.76406 .12356 L
.76428 .12356 L
.7645 .12357 L
.76473 .12356 L
.76494 .12356 L
.76514 .12354 L
.76532 .12352 L
.76546 .1235 L
.76555 .12347 L
.76561 .12345 L
.76562 .12343 L
.76561 .12342 L
.76558 .12341 L
.76554 .12342 L
.76551 .12343 L
.7655 .12344 L
.7655 .12344 L
.7655 .12343 L
.76548 .12342 L
.76546 .1234 L
.76542 .12336 L
.76539 .12333 L
.76536 .12331 L
.76535 .12332 L
.76536 .12337 L
Mistroke
.76542 .12345 L
Mfstroke
.80435 .14752 m
.80444 .14756 L
.80446 .14752 L
.80444 .14741 L
.80437 .14723 L
.8043 .147 L
.80424 .14675 L
.80418 .14649 L
.80415 .14624 L
.80415 .14601 L
.80421 .14583 L
.80429 .1457 L
.80439 .14563 L
.80447 .14558 L
.80451 .14555 L
.80448 .14551 L
.80437 .14544 L
.80415 .1453 L
.80384 .14509 L
.80346 .14479 L
.80302 .14442 L
.80255 .14401 L
.8021 .14356 L
.80168 .14313 L
.80126 .14272 L
.80085 .1423 L
.80049 .1419 L
.80021 .14157 L
.80003 .14133 L
.79996 .1412 L
.79996 .14116 L
.79999 .14115 L
.80004 .14114 L
.80007 .14111 L
.80003 .141 L
.79993 .1408 L
.79976 .1405 L
.79957 .14012 L
.79935 .13969 L
.79912 .13925 L
.79888 .13881 L
.79864 .13839 L
.79842 .13797 L
.79825 .13757 L
.79817 .13722 L
.79814 .13693 L
.79809 .13674 L
.79802 .13663 L
.79791 .13659 L
.79773 .13661 L
Mistroke
.79741 .13666 L
.79696 .13673 L
.79639 .13677 L
.79578 .1368 L
.79519 .13681 L
.79462 .13684 L
.79407 .13686 L
.79349 .13686 L
.79287 .13684 L
.79225 .13679 L
.79171 .13669 L
.79127 .13656 L
.79091 .13639 L
.79061 .1362 L
.79036 .13598 L
.79019 .13576 L
.79005 .13552 L
.78987 .13527 L
.78967 .13504 L
.78952 .13483 L
.78946 .13468 L
.7895 .13458 L
Mfstroke
.81951 .16701 m
.81964 .16701 L
.81973 .16701 L
.81979 .16701 L
.8198 .16701 L
.81979 .16701 L
.81976 .16701 L
.81972 .16701 L
.81969 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16701 L
.81968 .16699 L
.81968 .16697 L
.81968 .16693 L
.81967 .16687 L
.81965 .1668 L
.81959 .16674 L
.81952 .16671 L
.81945 .16671 L
.81941 .16679 L
s
.83074 .18885 m
0 0 rlineto s
.91964 .32127 m
.91965 .32145 L
.91965 .32152 L
.91965 .32152 L
.91965 .32145 L
.91965 .32138 L
.91965 .32132 L
.91965 .3213 L
.91965 .32129 L
.91965 .32129 L
.91965 .32128 L
.91965 .32127 L
.91964 .32125 L
.91964 .32123 L
.91964 .32119 L
.91964 .32116 L
.91963 .32113 L
.91963 .32111 L
.91963 .32109 L
.91963 .32109 L
.91963 .3211 L
.91963 .32111 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91964 .32112 L
.91965 .32115 L
.91967 .3212 L
.91971 .32126 L
.91974 .32133 L
.91976 .32138 L
.91975 .32138 L
.91971 .32133 L
.91964 .32122 L
s
.89311 .27357 m
.89311 .27357 L
s
.91985 .3254 m
.91984 .32554 L
.91981 .32562 L
.91979 .32564 L
.91978 .32561 L
.91978 .32555 L
.91978 .32547 L
.91978 .32542 L
.91978 .3254 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91977 .32539 L
.91978 .3254 L
.91977 .32542 L
.91976 .32547 L
.91974 .32554 L
.91971 .3256 L
.91968 .32563 L
.91967 .32561 L
.91967 .32552 L
.91971 .32535 L
.91979 .32509 L
.9199 .32477 L
.92004 .32439 L
.92021 .32397 L
.92039 .32353 L
.92059 .32309 L
.92079 .32266 L
.92098 .32224 L
.92117 .32184 L
.92135 .32149 L
.92151 .32121 L
.92163 .32102 L
.92172 .32091 L
.92177 .32087 L
.92178 .3209 L
.92177 .32096 L
.92174 .32103 L
.92171 .32109 L
.92169 .32111 L
.92169 .32114 L
.92171 .32119 L
.92175 .32125 L
.92178 .32132 L
.92179 .32135 L
.92178 .32133 L
.92174 .32124 L
.92165 .32108 L
.92153 .32083 L
Mistroke
.92137 .32051 L
.92119 .32015 L
.921 .31976 L
.92081 .31936 L
.92062 .31895 L
.92041 .31853 L
.92017 .31809 L
.91992 .31764 L
.91966 .3172 L
.91939 .31678 L
.91913 .31639 L
.91888 .31603 L
.91864 .31571 L
.91843 .31542 L
.91825 .31521 L
.91807 .31507 L
.91789 .31501 L
.91771 .31503 L
.91756 .31518 L
.91744 .31548 L
.91737 .31591 L
.91734 .31646 L
.91734 .31705 L
.91738 .31771 L
.91743 .31842 L
.91749 .31907 L
.91754 .3197 L
.91757 .32025 L
.91758 .32072 L
.91759 .32107 L
.9176 .3213 L
.9176 .32142 L
.9176 .32144 L
.9176 .32139 L
.9176 .32131 L
.91759 .32123 L
.91759 .32116 L
.91759 .32113 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91759 .32112 L
.91758 .32112 L
.91755 .32112 L
.91752 .32112 L
.91749 .32112 L
.91748 .32112 L
Mistroke
.91749 .32112 L
.91753 .32112 L
.91761 .32112 L
.91773 .32112 L
.91789 .32112 L
.91807 .32112 L
.91827 .32112 L
.91848 .32112 L
.91869 .32112 L
.9189 .32112 L
.91911 .32112 L
.9193 .32112 L
.91946 .32112 L
.91959 .32112 L
.91968 .32112 L
.91974 .32112 L
.91975 .32112 L
.91974 .32112 L
.91971 .32112 L
.91967 .32112 L
.91965 .32112 L
.91964 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91963 .32113 L
.91964 .32114 L
.91964 .32113 L
.91963 .32113 L
.91963 .32111 L
.91963 .3211 L
.91963 .32109 L
.91963 .32108 L
.91962 .32108 L
.91962 .32106 L
.91962 .32105 L
.91962 .32103 L
.91962 .32101 L
.91961 .32098 L
.91961 .32094 L
.91961 .32091 L
.91961 .32087 L
.9196 .32085 L
.9196 .32083 L
.9196 .32083 L
.9196 .32083 L
Mistroke
.91961 .32084 L
.91961 .32075 L
.91961 .32078 L
.91961 .3208 L
.91961 .32083 L
.91962 .32089 L
.91962 .32095 L
.91962 .32101 L
.91963 .32107 L
.91963 .32111 L
.91963 .32114 L
.91963 .32115 L
.91964 .32115 L
.91964 .32115 L
.91963 .32114 L
.91963 .32113 L
.91963 .32112 L
.91963 .32112 L
.91963 .32112 L
.91965 .32112 L
.91972 .32112 L
.91982 .32112 L
.9199 .32111 L
.91994 .32109 L
.91994 .32104 L
.91985 .32098 L
Mfstroke
.92999 .38564 m
.92999 .3858 L
.92999 .38588 L
.92999 .38592 L
.92999 .38592 L
.92999 .38586 L
.92999 .38573 L
s
.89765 .27851 m
.89771 .27851 L
.8978 .27862 L
.89792 .27886 L
.89809 .27924 L
.89829 .27971 L
.89851 .28024 L
.89873 .28084 L
.89894 .28151 L
.89914 .28223 L
.89934 .28295 L
.89954 .2837 L
.89974 .28445 L
.89995 .28521 L
.90017 .28593 L
.9004 .28659 L
.90062 .28715 L
.90082 .28759 L
.90099 .28798 L
.90113 .28831 L
.90124 .28857 L
.90133 .28876 L
.90139 .28885 L
.90141 .28884 L
s
.88052 .25673 m
.88046 .25666 L
.88045 .25668 L
.88048 .25678 L
.88056 .25691 L
.88073 .25709 L
.88096 .25737 L
.8812 .25768 L
.88138 .25798 L
.88146 .2582 L
.8814 .25827 L
s
.78693 .13665 m
.78704 .13669 L
.7871 .13664 L
.78706 .13652 L
.7869 .13635 L
.78669 .13615 L
.78645 .13592 L
.78619 .13569 L
.78593 .13547 L
.78567 .13524 L
.78542 .13502 L
.78521 .13482 L
.78504 .13464 L
.78494 .13451 L
.78493 .13441 L
.78501 .13436 L
.7852 .13434 L
.7855 .13436 L
.78588 .13439 L
.78632 .13441 L
.78681 .13441 L
.78735 .1344 L
.78792 .13439 L
.78851 .13442 L
.78913 .13447 L
.78976 .13457 L
.79036 .13471 L
.79094 .13488 L
.79147 .13508 L
.79194 .13529 L
.79236 .13552 L
.79271 .13575 L
.79301 .13598 L
.79325 .1362 L
.79343 .1364 L
.79356 .13657 L
.79365 .13671 L
.79371 .13681 L
.79374 .13686 L
.79375 .13685 L
.79376 .13679 L
.79376 .13669 L
.79375 .13659 L
.79373 .13653 L
.79367 .13654 L
.79359 .13662 L
.79348 .13679 L
.79334 .13704 L
.7932 .13736 L
.79306 .13774 L
Mistroke
.79295 .13816 L
.79286 .1386 L
.79281 .13903 L
.79278 .13947 L
.79279 .13989 L
.79282 .14029 L
.7929 .14064 L
.79304 .14092 L
.79323 .14112 L
.79344 .14123 L
.79362 .14126 L
.79375 .14124 L
.79379 .14118 L
Mfstroke
.583 .05245 m
.58287 .05245 L
.58282 .05245 L
.58286 .05245 L
.58297 .05245 L
.58308 .05245 L
.58317 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58321 .05246 L
.58322 .05245 L
.58324 .05243 L
.58329 .05238 L
.58337 .05231 L
.58344 .05225 L
.58347 .05222 L
.58345 .05224 L
.58336 .05233 L
.5832 .05251 L
.58298 .05276 L
.58272 .05309 L
.58243 .05347 L
.58209 .0539 L
.58167 .05435 L
.58117 .05479 L
.58059 .05522 L
.57992 .05565 L
.57915 .05604 L
.5783 .05637 L
.57736 .05664 L
.57637 .05681 L
.57533 .0569 L
.57432 .05691 L
.57331 .05686 L
.57232 .05677 L
.57137 .05669 L
.57047 .05662 L
.56964 .05657 L
.5689 .05653 L
.56825 .0565 L
.56769 .05646 L
.56721 .05641 L
.56682 .05637 L
.56647 .05632 L
Mistroke
.56616 .05624 L
.56588 .05614 L
.56563 .05605 L
.56543 .05599 L
.56526 .05596 L
.56516 .05597 L
.56513 .05602 L
Mfstroke
.07965 .40118 m
.07977 .40123 L
.07988 .40112 L
.07997 .40092 L
.08003 .40068 L
.08007 .40044 L
.0801 .40026 L
.0801 .40015 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .40011 L
.08011 .4001 L
.08014 .40009 L
.08019 .40006 L
.08026 .40002 L
.08031 .39998 L
.08031 .39996 L
.08026 .39998 L
.08014 .40003 L
.07995 .40013 L
.07971 .40027 L
.07943 .40046 L
.07912 .40067 L
.0788 .40091 L
.07848 .40116 L
.07817 .40141 L
.07788 .40167 L
.07761 .40191 L
.07737 .40213 L
.07719 .40233 L
.07706 .40248 L
.07701 .40259 L
.07701 .40265 L
.07707 .40267 L
.07716 .40265 L
.07725 .40261 L
.07732 .40257 L
.07735 .40254 L
.07735 .40252 L
.07732 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
Mistroke
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.07731 .40252 L
.0773 .40252 L
.07729 .40252 L
.07725 .40252 L
.07719 .40252 L
.07711 .40252 L
.07703 .40252 L
.07697 .40252 L
.07697 .40252 L
.07703 .40249 L
Mfstroke
.09645 .41176 m
.09646 .41182 L
.09641 .41184 L
.09633 .41182 L
.09625 .41173 L
.09617 .41157 L
.09612 .41135 L
.09611 .41108 L
.09611 .41077 L
.09612 .41045 L
.09613 .41011 L
.09614 .40975 L
.09615 .4094 L
.09616 .40906 L
.09617 .40871 L
.09618 .40837 L
.09619 .40802 L
.0962 .40769 L
.09621 .40737 L
.09622 .40711 L
.09623 .40695 L
.09623 .40689 L
.09623 .40692 L
.09623 .407 L
.09622 .40708 L
.09622 .40713 L
.09622 .40714 L
.09622 .4071 L
.09622 .40705 L
.09622 .40704 L
.09622 .40707 L
.09622 .40712 L
.09619 .40719 L
.09611 .40726 L
s
.35142 .29361 m
.35135 .29361 L
.35134 .29351 L
.35141 .29337 L
.35154 .29323 L
.35174 .29311 L
.35201 .29299 L
.3523 .29288 L
.35259 .29276 L
.35286 .29266 L
.35308 .29263 L
.35322 .29271 L
s
.86354 .79286 m
0 0 rlineto s
.9422 .56114 m
.94211 .56124 L
.9419 .56149 L
.94159 .56183 L
.94119 .56222 L
.94075 .56261 L
.9403 .56296 L
.93986 .56325 L
.93944 .56351 L
.93904 .56376 L
.93867 .56398 L
.93835 .56419 L
.93808 .56437 L
.9379 .56451 L
.9378 .56461 L
.93777 .56464 L
.93779 .56461 L
.93784 .56453 L
.93791 .56441 L
.93794 .56428 L
.93794 .56418 L
.93791 .5641 L
.93787 .56403 L
s
.80167 .14461 m
.80171 .14467 L
.80186 .14484 L
.80206 .14503 L
.80224 .14521 L
.80236 .14535 L
.80236 .14542 L
.80224 .14539 L
.80199 .14528 L
.80166 .1451 L
.80127 .14486 L
.80085 .14456 L
.80041 .14422 L
.79996 .14385 L
.79952 .14348 L
.79909 .14311 L
.79869 .14276 L
.79834 .14245 L
.79806 .14216 L
.79786 .14192 L
.79775 .14172 L
.79771 .14156 L
.79773 .14145 L
.7978 .14136 L
.79787 .14131 L
.79792 .14129 L
.79795 .14131 L
.79795 .14135 L
.79795 .14141 L
.79795 .14144 L
.79795 .14138 L
.79795 .14124 L
s
.74117 .11217 m
.7411 .11206 L
.74113 .11197 L
.74121 .11191 L
.74128 .11188 L
.74136 .11191 L
.74144 .11204 L
s
.7805 .13012 m
.78063 .13012 L
.78072 .13012 L
.78077 .13012 L
.78077 .1301 L
.78072 .13005 L
.78065 .12999 L
.78058 .12992 L
.78053 .12989 L
.7805 .12991 L
.78051 .13 L
.78057 .13016 L
.78069 .13042 L
.78087 .13075 L
.78111 .13114 L
.78142 .13156 L
.78177 .13201 L
.78216 .13244 L
.78258 .13287 L
.78301 .1333 L
.78343 .1337 L
.78383 .13406 L
.7842 .13435 L
.78451 .13455 L
.78477 .13466 L
.78496 .1347 L
.78508 .13468 L
.78515 .13462 L
.78517 .13455 L
.78515 .1345 L
.78513 .13447 L
.78509 .13447 L
.78506 .13447 L
.78503 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78501 .13447 L
.78499 .13447 L
.78495 .13445 L
.78488 .13443 L
.78481 .13439 L
.78474 .13436 L
.78469 .13434 L
.7847 .13435 L
.78479 .1344 L
.78498 .13449 L
.78528 .13462 L
Mistroke
.78571 .13479 L
.78626 .13499 L
.78694 .13521 L
.78769 .13544 L
.78857 .13568 L
.78952 .13592 L
.79053 .13615 L
.79153 .13636 L
.79248 .13655 L
.79332 .1367 L
.79403 .13681 L
.79458 .13688 L
.79495 .1369 L
.79516 .13689 L
.79521 .13686 L
.79514 .13682 L
.79497 .13679 L
.79474 .13677 L
.79448 .13677 L
.79421 .13677 L
.79398 .13679 L
.7938 .13683 L
.79371 .13686 L
.79371 .13687 L
.7938 .13686 L
.79397 .13682 L
.79419 .13674 L
.79444 .13662 L
.7947 .13646 L
.79495 .13627 L
.79517 .13607 L
.79537 .13585 L
.79554 .13563 L
.79568 .13541 L
.79577 .1352 L
.79582 .135 L
.79585 .13483 L
.7959 .1347 L
.79597 .1346 L
.79602 .13455 L
.79604 .13453 L
.79599 .13455 L
.79586 .13457 L
.79562 .13461 L
.79525 .13463 L
.79476 .13463 L
.79418 .13463 L
.79355 .13461 L
.7929 .1346 L
.79227 .13459 L
Mistroke
.79166 .13458 L
.79104 .13457 L
.79044 .13456 L
.7899 .13455 L
.78947 .13454 L
.78918 .13454 L
.78905 .13453 L
.78904 .13453 L
.78914 .13454 L
.78928 .13454 L
.7894 .13454 L
.78945 .13454 L
.78937 .13454 L
.78916 .13454 L
.78887 .13453 L
.78849 .13453 L
.78809 .13452 L
.78768 .13451 L
.78731 .13451 L
.78699 .1345 L
.78676 .13438 L
.78657 .13438 L
.78642 .13437 L
.78638 .13436 L
Mfstroke
.83204 .18789 m
0 0 rlineto s
.83804 .23149 m
.83796 .23158 L
.83792 .23159 L
.83792 .23153 L
.83795 .23144 L
.83798 .23133 L
.83801 .23124 L
.83802 .23121 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .2312 L
.83802 .23122 L
.83802 .23125 L
.83802 .2313 L
.83802 .23133 L
.83802 .23132 L
.83802 .23125 L
.83802 .23115 L
.83801 .23102 L
.838 .23087 L
.83799 .23073 L
.83796 .2306 L
.83792 .23051 L
.83788 .23045 L
.83787 .23041 L
.83788 .23041 L
.83792 .23041 L
.83801 .23042 L
.83814 .23047 L
.8383 .23056 L
.83849 .23068 L
.83871 .23084 L
.83893 .23099 L
.83915 .23114 L
.83937 .23125 L
.83959 .23133 L
.83979 .23135 L
.83996 .23132 L
.84009 .23127 L
.84018 .23123 L
.84024 .23122 L
.84025 .23121 L
.84024 .23121 L
Mistroke
.84021 .23121 L
.84017 .23121 L
.84015 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84013 .23121 L
.84014 .23118 L
.84017 .23112 L
.8402 .23102 L
.84023 .23093 L
.84024 .23089 L
.84023 .23092 L
.84019 .23105 L
.84011 .23129 L
.84 .23166 L
.83985 .23215 L
.83967 .23273 L
.83948 .23336 L
.83928 .23401 L
.83908 .23465 L
.83888 .23527 L
.83868 .23588 L
.8385 .23648 L
.83834 .23702 L
.83821 .23744 L
.83813 .23773 L
.83808 .2379 L
.83806 .23795 L
.83807 .23792 L
.8381 .23783 L
.83813 .23773 L
.83816 .23765 L
.83817 .23762 L
.83817 .23762 L
.83817 .23762 L
.83817 .23761 L
.83817 .2376 L
.83817 .23756 L
.83817 .2375 L
.83817 .23746 L
.83817 .23745 L
.83817 .2375 L
.83818 .23761 L
.83818 .23778 L
.83819 .23799 L
.83819 .23822 L
Mistroke
.8382 .23844 L
.83821 .23863 L
.83821 .23877 L
.83822 .23886 L
.83822 .2389 L
.8382 .23892 L
.83818 .23891 L
.83814 .23884 L
.83811 .23876 L
.83809 .2386 L
.83809 .23837 L
.83813 .2381 L
.83822 .23785 L
.83836 .23764 L
.83856 .23751 L
.83878 .23746 L
.83901 .2375 L
.83922 .23761 L
.8394 .23773 L
.83954 .23782 L
.83963 .2379 L
.83967 .23795 L
.83965 .23797 L
.83958 .23798 L
.83946 .23798 L
.83929 .23798 L
.83909 .23796 L
.83886 .23793 L
.83863 .23788 L
.83841 .23782 L
.83824 .23774 L
.83813 .23767 L
.83807 .23762 L
.83805 .23757 L
.83806 .23755 L
.83809 .23753 L
.83813 .2375 L
.83815 .23745 L
.83817 .2374 L
.83818 .23735 L
.83821 .23733 L
.83824 .23736 L
.83827 .23748 L
.8383 .23771 L
.83829 .23806 L
.83826 .23853 L
.83819 .23913 L
.83808 .23982 L
.83794 .24056 L
.83777 .24135 L
Mistroke
.83758 .24218 L
.83738 .24301 L
.83719 .2438 L
.83699 .2445 L
.83679 .24511 L
.83661 .24562 L
.83644 .246 L
.83631 .24627 L
.83622 .24641 L
.83617 .24646 L
.83615 .24645 L
.83616 .2464 L
.83619 .24634 L
.83623 .24626 L
.83625 .2462 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
Mistroke
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24617 L
.83627 .24616 L
.8363 .24615 L
.83636 .24613 L
.83643 .24609 L
.83648 .24606 L
.83651 .24602 L
.83651 .24598 L
.83646 .24596 L
.8363 .24599 L
.83601 .24608 L
.83564 .24626 L
.83519 .24653 L
.83465 .24691 L
.83405 .24737 L
.83348 .24791 L
.8329 .2485 L
.83231 .24913 L
.83173 .24976 L
.83115 .25038 L
.83072 .25095 L
.83036 .25147 L
.83008 .25193 L
.82988 .25231 L
.82978 .25258 L
.82976 .25275 L
.8298 .25283 L
.82986 .25284 L
.82992 .25281 L
.82998 .25274 L
.83004 .25267 L
.83009 .25261 L
.8301 .25258 L
.83008 .25258 L
.83007 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
Mistroke
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83006 .25258 L
.83007 .25258 L
.8301 .25258 L
.83019 .25258 L
.83028 .25258 L
.83032 .25258 L
.8303 .25258 L
.8302 .25258 L
.82998 .25258 L
.82963 .25258 L
.82912 .25258 L
.82852 .25258 L
.82787 .25257 L
.82724 .25257 L
.82665 .25257 L
.82609 .25257 L
.82551 .25256 L
.82491 .25254 L
.82434 .25252 L
.82388 .25249 L
.82358 .25246 L
.82339 .25242 L
.8233 .25241 L
.82329 .25244 L
.82337 .25252 L
.8235 .25267 L
.82363 .2529 L
.82376 .25319 L
.82394 .25354 L
.82416 .25396 L
.82436 .25435 L
.82459 .25474 L
.82482 .25508 L
.82505 .25541 L
.82528 .25576 L
.8255 .25616 L
.82569 .25658 L
.82585 .25702 L
Mistroke
.82597 .25746 L
.82605 .25789 L
.82608 .25828 L
.82608 .25861 L
.82606 .25887 L
.82602 .25909 L
.826 .25926 L
.82599 .25944 L
.82599 .25962 L
.826 .25979 L
.82599 .25985 L
.82599 .25981 L
.82598 .25967 L
.82598 .25948 L
.82597 .25928 L
.82596 .25908 L
.82596 .25893 L
.82596 .25886 L
.82596 .25888 L
.82596 .25896 L
.82596 .25903 L
.82597 .25908 L
.82597 .2591 L
.82597 .25911 L
.82597 .25911 L
.82596 .25911 L
.82593 .25911 L
.82589 .25908 L
.82586 .25902 L
.82584 .25893 L
.82583 .25885 L
.82585 .25877 L
.82589 .25872 L
.82597 .25873 L
Mfstroke
.88955 .28483 m
.88968 .28481 L
.88976 .28481 L
.88981 .28481 L
.88983 .28481 L
.88981 .28481 L
.88978 .28481 L
.88975 .28481 L
.88972 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28481 L
.88971 .28483 L
.88971 .28487 L
.88971 .28493 L
.88971 .28496 L
.88971 .28495 L
.88971 .28487 L
.8897 .28474 L
.8897 .28458 L
.88969 .2844 L
.88968 .28422 L
.88968 .28406 L
.88967 .28393 L
.88967 .28385 L
.88967 .2838 L
.88967 .28378 L
.88967 .28379 L
.88967 .28381 L
.88967 .28386 L
.88966 .28393 L
.88964 .28403 L
.88961 .28415 L
.88957 .28431 L
.88954 .2845 L
.88953 .28473 L
.88956 .28498 L
.88964 .28525 L
.88978 .28554 L
.88999 .28586 L
.89027 .28624 L
.8906 .28667 L
.89099 .28711 L
.89139 .28755 L
.89181 .28798 L
.89224 .28838 L
.89266 .28872 L
.89304 .289 L
.89339 .28919 L
Mistroke
.89368 .2893 L
.8939 .28934 L
.89406 .28933 L
.89416 .28932 L
.89421 .28932 L
.89421 .28932 L
.89417 .28933 L
.89409 .2893 L
.89399 .28921 L
.89388 .28903 L
.89376 .28878 L
.89366 .28845 L
.89357 .28807 L
.8935 .28763 L
.89347 .28713 L
.89346 .28662 L
.89347 .28612 L
.89345 .28566 L
.8934 .28527 L
.89333 .28498 L
.89323 .28482 L
.89312 .28479 L
Mfstroke
.9248 .35338 m
.9248 .35352 L
.92481 .35361 L
.92481 .35364 L
.92481 .35361 L
.9248 .35351 L
.9248 .35337 L
.92479 .35317 L
.92478 .35291 L
.92477 .35258 L
.92476 .35217 L
.92474 .3517 L
.92472 .35118 L
.92471 .35067 L
.92469 .35019 L
.92468 .34978 L
.92466 .34946 L
.92466 .34927 L
.92466 .34923 L
s
.92149 .37464 m
.92159 .37453 L
.92164 .37449 L
.92163 .37452 L
.92158 .37459 L
.9215 .37466 L
.92143 .37472 L
.92137 .37474 L
.92134 .37475 L
.92135 .37475 L
.92139 .37475 L
.92147 .37475 L
.92159 .37475 L
.92175 .37475 L
.92193 .37474 L
.92213 .37474 L
.92234 .37474 L
.92255 .37474 L
.92276 .37473 L
.92296 .37473 L
.92315 .37473 L
.92332 .37473 L
.92345 .37473 L
.92354 .37473 L
.92359 .37473 L
.92361 .37472 L
.92361 .3747 L
.92361 .37465 L
.92364 .37458 L
.92367 .37452 L
.9237 .37448 L
.92371 .37449 L
.92368 .37457 L
s
.91142 .39033 m
.91144 .39044 L
.91148 .39046 L
.91151 .39044 L
.91156 .39043 L
.91163 .39045 L
.91174 .39049 L
.91188 .39056 L
.91204 .39067 L
.91223 .39077 L
.91244 .39084 L
.91265 .39087 L
.91286 .39082 L
.91307 .39067 L
.91326 .39041 L
.91344 .39005 L
.91359 .38961 L
.91371 .3891 L
.91378 .38857 L
.91382 .38803 L
.91382 .38753 L
.91379 .38707 L
.91374 .38665 L
.91369 .38629 L
.91366 .38597 L
.91364 .38571 L
.91363 .38551 L
.91362 .3854 L
.91362 .38537 L
.91362 .3854 L
.91362 .38546 L
.91363 .38554 L
.91363 .3856 L
.91363 .38565 L
.91362 .38571 L
.91359 .38578 L
.91356 .38586 L
.91352 .38595 L
.91348 .38602 L
.91346 .38606 L
.91345 .38604 L
.91349 .38593 L
s
.9198 .32611 m
0 0 rlineto s
.8871 .26757 m
.88709 .26757 L
.88715 .26764 L
.8872 .26765 L
s
.79797 .13687 m
.79792 .13674 L
.79789 .13669 L
.79788 .13668 L
.79789 .13668 L
.79791 .13666 L
.79794 .13661 L
.79798 .13657 L
.79799 .13656 L
.79798 .1366 L
.79794 .1367 L
.79785 .13687 L
.79773 .13712 L
.79758 .13744 L
.79739 .13781 L
.79719 .13823 L
.79698 .13867 L
.79676 .1391 L
.79655 .13954 L
.79634 .13996 L
.79615 .14035 L
.79598 .1407 L
.79585 .14097 L
.79576 .14116 L
.7957 .14127 L
.79569 .1413 L
.7957 .14128 L
.79573 .14121 L
.79577 .14114 L
.79579 .14109 L
.79581 .14106 L
.7958 .14105 L
.79577 .14105 L
.79574 .14105 L
.7957 .14105 L
.79569 .14105 L
.7957 .14105 L
.79575 .14105 L
.79583 .14106 L
.79596 .14106 L
.79612 .14106 L
.79631 .14106 L
.79652 .14106 L
.79674 .14104 L
.79696 .141 L
.79718 .14094 L
.7974 .14088 L
.79759 .14085 L
.79777 .14087 L
.7979 .14098 L
Mistroke
.798 .1412 L
.79806 .14153 L
.79809 .14192 L
.79808 .14233 L
.79805 .14272 L
.79802 .14305 L
.798 .14331 L
.79799 .14348 L
.79799 .14357 L
.79799 .14359 L
.79799 .14353 L
.79798 .14337 L
.79798 .14315 L
.79797 .14284 L
.79797 .14245 L
.79796 .14203 L
.79795 .14161 L
.79795 .14126 L
.79794 .14101 L
.79794 .14088 L
.79794 .14085 L
.79794 .14088 L
.79794 .14094 L
.79795 .14101 L
.79796 .14109 L
.79799 .14116 L
.79802 .14123 L
.79806 .14129 L
.79807 .14133 L
.79806 .1413 L
.79801 .14121 L
.79792 .14104 L
.79779 .14079 L
.79763 .14046 L
.79743 .14008 L
.79721 .13966 L
.79698 .13921 L
.79675 .13877 L
.79652 .13834 L
.79634 .13792 L
.79622 .13753 L
.79617 .1372 L
.79615 .13696 L
.79612 .1368 L
.79604 .13671 L
.79587 .13666 L
.79559 .13664 L
.79518 .13661 L
.79463 .13654 L
.79396 .13643 L
Mistroke
.79318 .13625 L
.7923 .13602 L
.79142 .13579 L
.79044 .13555 L
.78949 .13531 L
.78854 .13508 L
.78763 .13486 L
.78684 .13468 L
.78618 .13453 L
.78569 .13442 L
.78536 .13436 L
.78515 .13434 L
.78504 .13435 L
.78499 .13439 L
.78495 .13442 L
.7849 .13445 L
.78486 .13446 L
.78485 .13447 L
.78487 .13447 L
.78491 .13447 L
.78496 .13447 L
.785 .13447 L
.78502 .13447 L
.78502 .13447 L
.78501 .13447 L
.78501 .13447 L
.78504 .13447 L
.78511 .13447 L
.7852 .13447 L
.78528 .13447 L
.7853 .13447 L
.78525 .13447 L
.7851 .13447 L
.78487 .13446 L
.78454 .13446 L
.78413 .13445 L
.78368 .13444 L
.7832 .13444 L
.78273 .13443 L
.78229 .13442 L
.78193 .13441 L
.78161 .13441 L
.78132 .1344 L
.78104 .1344 L
.78079 .1344 L
.78057 .1344 L
.78035 .13441 L
.78012 .13446 L
.77985 .13452 L
.77949 .13458 L
Mistroke
.77902 .1346 L
.77838 .13457 L
.77755 .13447 L
.77659 .13428 L
.77554 .13401 L
.77443 .13367 L
.77332 .13327 L
.77224 .13283 L
.77125 .13237 L
.7704 .13193 L
.76966 .13148 L
.76904 .13105 L
.76853 .13064 L
.76814 .13028 L
.76787 .13003 L
.76773 .1299 L
.76772 .12987 L
.7678 .12994 L
.76794 .13006 L
.76805 .13018 L
.76804 .13022 L
Mfstroke
.60364 .05363 m
.60357 .0537 L
.60351 .05388 L
.6035 .0542 L
.60352 .05461 L
.60355 .05508 L
.60359 .05554 L
.60362 .05599 L
.60364 .0564 L
.60364 .05676 L
.60364 .0571 L
.60364 .05741 L
.60364 .05766 L
.60364 .0578 L
.60364 .05782 L
.60364 .05766 L
.60364 .05743 L
.60364 .05712 L
.60364 .05675 L
.60364 .05633 L
.60364 .05588 L
.60364 .05541 L
.60365 .05493 L
.60368 .05445 L
.60371 .05397 L
.60376 .05351 L
.60384 .05313 L
.60397 .05286 L
.60412 .05275 L
s
.3958 .04681 m
.39572 .04681 L
.39572 .04682 L
.3958 .04685 L
.39594 .04689 L
.3961 .04693 L
.39622 .04695 L
.39628 .04694 L
.39623 .04689 L
.39607 .04679 L
.39579 .04665 L
.39542 .04646 L
.39499 .04625 L
.39452 .04601 L
.39402 .04575 L
.39353 .0455 L
.39302 .04523 L
.39252 .04496 L
.39204 .0447 L
.39161 .04447 L
.39128 .04429 L
.39107 .04419 L
.391 .04418 L
.39106 .04426 L
.39122 .04441 L
.39147 .04462 L
.39176 .04487 L
.39206 .04513 L
.39234 .04539 L
.3926 .04564 L
.39285 .04588 L
.3931 .04612 L
.39332 .04634 L
.39352 .04653 L
.39367 .04668 L
.39378 .04679 L
.39384 .04685 L
.39386 .04687 L
.39384 .04686 L
.39381 .04685 L
.39376 .04684 L
.39372 .04683 L
.39367 .04681 L
.39363 .04676 L
.39358 .04669 L
.39353 .04661 L
.39351 .04651 L
.39353 .04642 L
.39361 .04634 L
.39377 .04628 L
Mistroke
.394 .04625 L
.39431 .04624 L
.39469 .04624 L
.39512 .04626 L
.39558 .04629 L
.39606 .04634 L
.39655 .04642 L
.39703 .04652 L
.39747 .04663 L
.39786 .04675 L
.39819 .04685 L
.39845 .04693 L
.39862 .04698 L
.39872 .047 L
.39874 .04698 L
.39872 .04695 L
.39868 .04693 L
.39863 .04691 L
.39858 .04691 L
.39855 .04691 L
.39854 .04689 L
.39853 .04684 L
.39853 .04677 L
.39853 .04671 L
.39853 .04668 L
.39853 .0467 L
.39853 .04679 L
.39853 .04696 L
.39853 .04723 L
.39853 .04757 L
.39853 .04798 L
.39852 .04843 L
.39849 .04889 L
.39845 .04934 L
.39841 .04977 L
.39839 .05021 L
.39841 .05064 L
.39846 .05102 L
.39856 .05133 L
.39872 .05154 L
.39893 .05165 L
.39919 .0517 L
.39946 .05169 L
.39973 .05164 L
.39997 .05158 L
.40017 .05154 L
.40032 .05152 L
.4004 .05152 L
.40042 .05152 L
.40036 .05152 L
Mistroke
.40023 .05151 L
.40004 .05151 L
.3998 .0515 L
.39954 .05149 L
.39926 .05148 L
.39899 .05147 L
.39876 .05146 L
.39859 .05145 L
.39848 .05145 L
.39841 .05145 L
.39839 .05144 L
.39841 .05144 L
.39844 .05145 L
.39848 .05145 L
.39851 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39853 .05145 L
.39854 .05145 L
.39855 .05143 L
.39858 .05138 L
.39862 .05131 L
.39865 .05125 L
.39867 .05122 L
.39866 .05124 L
.3986 .05133 L
.39851 .0515 L
.39837 .05176 L
.39818 .0521 L
.39797 .0525 L
.39773 .05294 L
.39748 .0534 L
.39723 .05384 L
.39697 .05428 L
.39673 .05471 L
.39654 .05511 L
.39643 .05546 L
.39636 .05575 L
.39629 .05597 L
.39623 .05611 L
.39614 .05619 L
.39599 .05622 L
.39574 .05621 L
.3954 .05618 L
Mistroke
.39498 .05616 L
.39452 .05616 L
.39404 .05616 L
.39354 .05615 L
.39313 .05613 L
.39266 .05612 L
.3922 .05608 L
.39178 .05604 L
.39145 .05598 L
.39123 .05591 L
.39111 .05584 L
.39106 .05578 L
.39108 .05573 L
.39114 .05569 L
.39123 .05568 L
.39128 .05568 L
.3913 .0557 L
.39131 .05573 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
Mistroke
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.39131 .05574 L
.3913 .05574 L
.39129 .05574 L
.39126 .05574 L
.39122 .05573 L
.39119 .05573 L
.39117 .05573 L
.39118 .05573 L
.39124 .05573 L
.39133 .05574 L
.39147 .05574 L
.39166 .05575 L
.39187 .05576 L
.39211 .05577 L
.39236 .05577 L
.3926 .05578 L
.39285 .05579 L
.39309 .0558 L
.39332 .05581 L
.39351 .05582 L
.39367 .05582 L
.39378 .05583 L
.39384 .05583 L
.39386 .05583 L
Mistroke
.39384 .05583 L
.39381 .05583 L
.39377 .05582 L
.39374 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.3937 .05582 L
.39367 .05582 L
.39363 .05582 L
.3936 .05582 L
.39358 .05582 L
.39358 .05582 L
.3936 .05582 L
.39366 .05582 L
.39377 .05582 L
.39393 .05583 L
.39416 .05584 L
.39445 .05585 L
.3948 .05586 L
.39519 .05587 L
.39562 .05589 L
.39607 .05591 L
.39652 .05592 L
.39696 .05594 L
.39737 .05595 L
.39773 .05597 L
.39803 .05598 L
.39827 .05598 L
.39845 .05599 L
.39857 .056 L
Mistroke
.39865 .056 L
.39868 .056 L
.39868 .056 L
.39866 .056 L
.39863 .056 L
.39858 .056 L
.39855 .05599 L
.39854 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39853 .05599 L
.39854 .05599 L
.39855 .05599 L
.3986 .05598 L
.39868 .05598 L
Mistroke
.39874 .05598 L
.39877 .05599 L
.39875 .05601 L
.39866 .05603 L
.39847 .05605 L
.39819 .05606 L
.39783 .05607 L
.39739 .05607 L
.39692 .05607 L
.39643 .05606 L
.39595 .05604 L
.39549 .05603 L
.39503 .056 L
.39458 .05598 L
.39417 .05595 L
.39385 .05591 L
.39363 .05588 L
.39351 .05585 L
.39347 .05582 L
.39349 .0558 L
.39356 .0558 L
.39363 .0558 L
.39369 .0558 L
.39371 .05581 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
Mistroke
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39372 .05582 L
.39374 .05581 L
.39379 .05577 L
.39386 .05567 L
.39393 .05558 L
.39396 .05553 L
.39393 .05555 L
.39381 .05566 L
.39358 .05588 L
.39325 .05625 L
.39283 .05676 L
.39235 .05737 L
.39186 .05804 L
.39139 .05872 L
.39101 .05936 L
.3907 .05995 L
.39043 .06056 L
.39024 .0612 L
.39016 .0618 L
.39022 .06229 L
.39043 .06262 L
.39078 .0628 L
.39122 .06288 L
.39172 .06289 L
.39225 .06282 L
.39273 .06272 L
.39314 .06266 L
.39344 .06264 L
.39365 .06264 L
.39379 .06265 L
.39386 .06265 L
.39389 .06265 L
.39388 .06265 L
.39385 .06265 L
.39382 .06265 L
.39377 .06265 L
.39374 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
Mistroke
.39372 .06265 L
.39372 .06265 L
.39372 .06265 L
.39374 .06265 L
.39376 .06265 L
.3938 .06265 L
.39384 .06265 L
.39386 .06265 L
.39384 .06265 L
.39379 .06265 L
.39369 .06265 L
.39353 .06264 L
.39332 .06263 L
.39306 .06263 L
.39278 .06262 L
.39251 .06261 L
.39228 .0626 L
.39208 .06259 L
.39193 .06259 L
.39184 .06258 L
.39182 .06258 L
Mfstroke
.4728 .06913 m
.47296 .06909 L
.47294 .06915 L
.47284 .06926 L
.47268 .0694 L
.4725 .06953 L
.47236 .0696 L
.47228 .06964 L
.47225 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47224 .06965 L
.47225 .06964 L
.4723 .06961 L
.47237 .06958 L
.47245 .06954 L
.47249 .06953 L
.47248 .06954 L
.47239 .06958 L
.47222 .06967 L
.47195 .06979 L
.4716 .06995 L
.47118 .07014 L
.47072 .07035 L
.47024 .07057 L
.46973 .07079 L
.4693 .07101 L
.46883 .07122 L
.46838 .07142 L
.46798 .07159 L
.46766 .07173 L
.46744 .07182 L
.46732 .07188 L
.46727 .0719 L
.46729 .07188 L
.46736 .07185 L
.46745 .07182 L
.46751 .07179 L
.46753 .07177 L
Mistroke
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07177 L
.46754 .07179 L
.46754 .07181 L
.46754 .07185 L
.46754 .07188 L
.46754 .0719 L
.46754 .07189 L
.46754 .07184 L
.46754 .07175 L
.46754 .07162 L
.46754 .07145 L
.46754 .07125 L
.46754 .07103 L
.46754 .07082 L
.46754 .07065 L
.46754 .07049 L
.46754 .07033 L
.46754 .07017 L
.46754 .07001 L
.46754 .06983 L
Mfstroke
.49568 .05001 m
.49571 .04993 L
.49572 .04987 L
.49572 .04982 L
.49571 .04981 L
.49574 .04985 L
s
.64212 .07348 m
.64216 .07366 L
.64223 .07383 L
.64232 .07398 L
.64244 .07412 L
.64257 .07426 L
.64274 .0744 L
.64294 .07457 L
.64316 .07478 L
.64339 .07501 L
.64362 .07523 L
.64382 .07544 L
.644 .07562 L
.64415 .07576 L
.64425 .07586 L
.64431 .07592 L
.64432 .07594 L
.64431 .07592 L
.64428 .07589 L
.64424 .07585 L
.64421 .07582 L
.64419 .07581 L
.64419 .0758 L
.6442 .07577 L
.64421 .07572 L
.64423 .07564 L
.64423 .07556 L
.64424 .07549 L
.64424 .07546 L
.64421 .07549 L
s
.68511 .11142 m
.68516 .11146 L
.68507 .11153 L
.68493 .1116 L
.68476 .11164 L
.6846 .11164 L
.68445 .11161 L
.68434 .11151 L
s
.79857 .14146 m
.79869 .14152 L
.79865 .14149 L
.79852 .1414 L
.79835 .14127 L
.79816 .14112 L
.79799 .14098 L
.79787 .14087 L
.79781 .14083 L
.7978 .14088 L
.79784 .14099 L
s
.84178 .19959 m
.84177 .19967 L
.84173 .19966 L
.84168 .19959 L
.84162 .19949 L
.84157 .19939 L
.84153 .19928 L
.8415 .19919 L
.84148 .19912 L
.84147 .19907 L
.84144 .19902 L
.8414 .19898 L
.84136 .19896 L
.84132 .199 L
.8413 .19912 L
s
.92199 .32768 m
.92201 .32779 L
.92201 .32785 L
.92199 .32788 L
.92196 .32786 L
.92194 .32782 L
.92193 .32776 L
.92193 .32768 L
.92193 .32759 L
.92192 .32754 L
.92191 .32753 L
.9219 .32753 L
.9219 .32753 L
.92189 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92188 .32753 L
.92186 .32753 L
.92182 .32753 L
.9218 .32753 L
.92179 .32753 L
.92181 .32753 L
.92185 .32753 L
.92194 .32753 L
.92206 .32753 L
.92223 .32753 L
.92245 .32752 L
.92272 .32752 L
.92297 .32752 L
.92318 .32752 L
.92336 .32752 L
.92353 .32752 L
.92366 .32752 L
.92374 .32752 L
.92371 .32752 L
.9236 .32752 L
.92343 .32752 L
.92323 .32752 L
.92301 .32752 L
.92279 .32752 L
.92253 .32752 L
.92231 .32752 L
.92212 .32753 L
.92198 .32753 L
.92188 .32753 L
.92182 .32753 L
Mistroke
.92179 .32753 L
.92179 .32753 L
.92181 .32753 L
.92184 .32753 L
.92187 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
Mistroke
.92187 .32753 L
.92184 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92184 .32753 L
.92191 .32753 L
.92203 .32753 L
.92219 .32753 L
.92237 .32752 L
.92258 .32752 L
.92278 .32752 L
.92297 .32752 L
.92316 .32752 L
.92335 .32752 L
.92354 .32752 L
.92372 .32752 L
.92386 .32752 L
.92395 .32752 L
.924 .32752 L
.92402 .32752 L
.92401 .32752 L
.92398 .32752 L
.92395 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92393 .32752 L
.92395 .32752 L
.92398 .32752 L
.924 .32752 L
.92402 .32752 L
.924 .32752 L
.92397 .32752 L
.92389 .32752 L
.92377 .32752 L
.92362 .32752 L
.92343 .32752 L
.92323 .32752 L
.92302 .32752 L
.92283 .32752 L
Mistroke
.92264 .32752 L
.92245 .32752 L
.92227 .32753 L
.92209 .32753 L
.92195 .32753 L
.92186 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92183 .32753 L
.92186 .32753 L
.92188 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92187 .32753 L
Mistroke
.92184 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92184 .32753 L
.92191 .32753 L
.92203 .32753 L
.92219 .32753 L
.92237 .32752 L
.92258 .32752 L
.92278 .32752 L
.92297 .32752 L
.92316 .32752 L
.92335 .32752 L
.92354 .32752 L
.92372 .32752 L
.92386 .32752 L
.92395 .32752 L
.924 .32752 L
.92402 .32752 L
.92401 .32752 L
.92398 .32752 L
.92395 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92393 .32752 L
.92394 .32752 L
.92397 .32752 L
.924 .32752 L
.92401 .32752 L
.924 .32752 L
.92397 .32752 L
.92389 .32752 L
.92378 .32752 L
.92362 .32752 L
.92343 .32752 L
.92322 .32752 L
.92301 .32752 L
.92283 .32752 L
.92264 .32752 L
.92246 .32753 L
.92227 .32753 L
.92209 .32753 L
.92195 .32753 L
.92185 .32753 L
.92181 .32753 L
.92179 .32753 L
.9218 .32753 L
.92183 .32753 L
.92186 .32753 L
.92188 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
Mistroke
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92189 .32753 L
.92188 .32753 L
.92185 .32753 L
.92182 .32753 L
.92179 .32753 L
.92179 .32753 L
.9218 .32753 L
.92185 .32753 L
.92194 .32753 L
.92208 .32753 L
.92225 .32753 L
.92245 .32752 L
.92265 .32752 L
.92286 .32752 L
.92297 .32752 L
.92314 .32752 L
.92332 .32752 L
.92352 .32752 L
.9237 .32752 L
.92385 .32752 L
.92393 .32752 L
.92396 .32752 L
.92397 .32752 L
.92396 .32752 L
.92393 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
Mistroke
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32752 L
.92392 .32753 L
.92393 .32755 L
.92396 .32759 L
.92397 .3276 L
.92396 .32759 L
Mistroke
.92394 .32756 L
.92389 .32749 L
.92379 .32737 L
.92359 .3272 L
.92334 .32699 L
.92314 .32677 L
.92297 .32657 L
.9228 .32638 L
.92263 .3262 L
.92244 .32601 L
.92223 .32581 L
.92204 .32562 L
.92189 .32546 L
.92181 .32537 L
.92178 .32533 L
.92177 .32531 L
.92177 .32532 L
.92181 .32534 L
.92181 .32538 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
Mistroke
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92181 .32539 L
.92182 .3254 L
.92185 .32545 L
.92186 .32549 L
.92186 .32547 L
.92183 .32543 L
.92178 .32533 L
.92167 .32511 L
.92146 .32469 L
.92121 .32421 L
.92101 .32381 L
.92083 .32346 L
.92066 .32312 L
.92048 .32278 L
.92028 .32239 L
.92007 .32196 L
.91987 .32158 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.005 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.08829 .46464 m
.08831 .46466 L
s
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07895 .497 m
0 0 rlineto s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09928 .44585 m
.09939 .44577 L
s
.09706 .42296 m
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
s
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.09372 .45324 m
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.12277 .43416 m
0 0 rlineto s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.11295 .42512 m
.11305 .42509 L
.113 .42509 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.10083 .33086 m
.10083 .33098 L
.10076 .33099 L
s
.09779 .32142 m
0 0 rlineto s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.16727 .21947 m
0 0 rlineto s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.12431 .48033 m
.1244 .48048 L
.12438 .48059 L
s
.1463 .52197 m
0 0 rlineto s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.17193 .56115 m
0 0 rlineto s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.09701 .42519 m
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
s
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.18969 .17457 m
0 0 rlineto s
.22595 .14135 m
.22611 .14131 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.41338 .04979 m
0 0 rlineto s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.2739 .10277 m
0 0 rlineto s
.25996 .10951 m
0 0 rlineto s
.22593 .1329 m
0 0 rlineto s
.22643 .14055 m
.22638 .14068 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.35768 .045 m
.35761 .04507 L
.35761 .04515 L
s
.44214 .04065 m
.44237 .04064 L
s
.47574 .04847 m
.4756 .0485 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.40609 .04654 m
0 0 rlineto s
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.19716 .15105 m
.19703 .15137 L
s
.14841 .23058 m
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.09827 .32567 m
.09831 .32572 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.07835 .58898 m
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.22811 .86791 m
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.29888 .91058 m
0 0 rlineto s
.10577 .74262 m
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08637 .65434 m
.08639 .65394 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.07438 .48114 m
.07446 .48131 L
.07448 .48146 L
s
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.06967 .54045 m
.06961 .54041 L
s
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.07973 .61708 m
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.13721 .77621 m
.13728 .77623 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.2397 .88185 m
.23973 .88177 L
s
.25859 .89245 m
.25875 .89244 L
.25876 .89241 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.6574 .9378 m
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
s
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.66629 .9347 m
0 0 rlineto s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.72443 .89473 m
0 0 rlineto s
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.08098 .61694 m
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
s
.07169 .5532 m
.07169 .55301 L
.07169 .55273 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.09317 .69599 m
.09319 .69591 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.50307 .95851 m
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.7462 .88232 m
0 0 rlineto s
.78995 .85371 m
0 0 rlineto s
.87173 .75623 m
.87176 .75594 L
s
.89864 .66886 m
0 0 rlineto s
.88019 .67265 m
0 0 rlineto s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.866 .76997 m
0 0 rlineto s
.86655 .7769 m
.86655 .77678 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.84151 .80028 m
0 0 rlineto s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.87992 .74236 m
0 0 rlineto s
.89014 .69498 m
0 0 rlineto s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.7829 .84984 m
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
s
.68468 .92812 m
0 0 rlineto s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.09079 .46259 m
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
s
.13843 .45022 m
0 0 rlineto s
.16678 .47998 m
0 0 rlineto s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.084 .40259 m
.08399 .40236 L
.08407 .40215 L
s
.10059 .31026 m
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
s
.19964 .15145 m
.19956 .15143 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.56832 .05573 m
.56836 .05583 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.8557 .22855 m
0 0 rlineto s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90585 .35276 m
0 0 rlineto s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.89847 .3018 m
.89848 .30184 L
s
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.91516 .62094 m
0 0 rlineto s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.86519 .77598 m
.86524 .77593 L
s
.89089 .70838 m
.89087 .70824 L
.8908 .70822 L
.89066 .70825 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.77341 .1312 m
0 0 rlineto s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.63175 .06345 m
0 0 rlineto s
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.27446 .09864 m
0 0 rlineto s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.09557 .32091 m
.09548 .32084 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.0674 .52433 m
.06735 .52457 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.24659 .88979 m
0 0 rlineto s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.91261 .34366 m
.91266 .34371 L
.91267 .34374 L
.91264 .34366 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.85576 .23052 m
.8558 .23044 L
.85588 .2305 L
s
.42244 .0318 m
.42238 .03192 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.3186 .07096 m
.3187 .07095 L
.31879 .07085 L
s
.19758 .14878 m
0 0 rlineto s
.08433 .4033 m
.08432 .40327 L
.08429 .40308 L
.08423 .40289 L
.08414 .40274 L
.08405 .40274 L
s
.07789 .59962 m
.07799 .59966 L
.07807 .59954 L
.07814 .59937 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.10501 .73804 m
.1051 .73803 L
.10514 .73802 L
.10516 .73802 L
.10518 .73803 L
.10527 .73805 L
s
.16739 .81568 m
0 0 rlineto s
.17501 .81707 m
.17502 .81694 L
.17493 .81678 L
.17479 .81664 L
.17464 .8166 L
.17456 .81674 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.62466 .94569 m
0 0 rlineto s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.63102 .84835 m
.63095 .84835 L
.63087 .84849 L
s
.61375 .87097 m
0 0 rlineto s
.61479 .94477 m
0 0 rlineto s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.60665 .94212 m
0 0 rlineto s
.61731 .91684 m
0 0 rlineto s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.76124 .8426 m
.76111 .84263 L
.76104 .84273 L
s
.73275 .85732 m
.73255 .85723 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.59691 .79387 m
.59699 .7937 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.31981 .78482 m
.31994 .78484 L
.32 .78497 L
.32002 .78512 L
.32002 .78523 L
.32 .78524 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.27304 .61596 m
0 0 rlineto s
.24255 .48929 m
.2424 .48924 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.37962 .37054 m
0 0 rlineto s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.66113 .25736 m
0 0 rlineto s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83885 .2144 m
.83896 .21436 L
.83901 .21424 L
.839 .2141 L
.83897 .21404 L
s
.84278 .23028 m
0 0 rlineto s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.52434 .05069 m
0 0 rlineto s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.82822 .19361 m
.82824 .19361 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.47798 .03788 m
.47776 .03781 L
.47778 .03774 L
.47791 .03767 L
.47801 .0376 L
.47801 .03753 L
s
.46549 .04756 m
0 0 rlineto s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.08404 .40223 m
.08404 .40236 L
.08404 .40238 L
.08409 .40237 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.92098 .46608 m
.92101 .46596 L
.92103 .46594 L
.92098 .46604 L
s
.89055 .5725 m
0 0 rlineto s
.89522 .58068 m
.89518 .58075 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.73221 .61191 m
0 0 rlineto s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.84172 .20548 m
.84159 .20536 L
.84154 .20536 L
.84147 .20531 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.483 .12298 m
0 0 rlineto s
.50628 .22169 m
0 0 rlineto s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.73811 .88704 m
.73804 .8869 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.58395 .9238 m
0 0 rlineto s
.70204 .88478 m
0 0 rlineto s
.71852 .8857 m
0 0 rlineto s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.92713 .49716 m
0 0 rlineto s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.90415 .31237 m
.90419 .31242 L
.9042 .31249 L
.90422 .31266 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.4385 .07383 m
.43853 .07392 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.46509 .04137 m
.46512 .04134 L
.4651 .04143 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.09586 .69085 m
.09582 .69091 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.21234 .85531 m
0 0 rlineto s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.74235 .88206 m
.74229 .88216 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
.80626 .83291 m
0 0 rlineto s
.55838 .91783 m
0 0 rlineto s
.23882 .87478 m
.23876 .87471 L
.2388 .87473 L
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
s
.4966 .79705 m
0 0 rlineto s
.90793 .32161 m
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
s
.36416 .04116 m
0 0 rlineto s
.26343 .10379 m
.26345 .10379 L
.2636 .10369 L
.26382 .10356 L
.26404 .1034 L
.26423 .10327 L
.26435 .10317 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.2644 .10313 L
.26446 .10311 L
.26458 .10306 L
.26477 .10296 L
.26499 .10283 L
.26522 .10267 L
.26541 .10251 L
.26549 .10241 L
s
.08992 .34962 m
.09 .34966 L
.09008 .34958 L
.09013 .34947 L
.09015 .34936 L
.09016 .34926 L
.09016 .34917 L
.09016 .3491 L
.09016 .34906 L
.09016 .34903 L
.09016 .34903 L
.09016 .34902 L
.09016 .34898 L
.09016 .3489 L
.09018 .34878 L
.09022 .34857 L
.09028 .34823 L
.09035 .34786 L
.09041 .34765 L
.09043 .34768 L
s
.08408 .41164 m
.08414 .41164 L
.08418 .41136 L
.08421 .41093 L
.08422 .41048 L
.08423 .41004 L
.08423 .40969 L
.08423 .4095 L
.08423 .40944 L
.08423 .40955 L
.08423 .40974 L
.08422 .41001 L
.08422 .4103 L
.08421 .41061 L
.08421 .4109 L
.0842 .41115 L
.0842 .41134 L
.08419 .41149 L
.08419 .41162 L
.08419 .4117 L
.08419 .41171 L
.08419 .41166 L
.08419 .41157 L
.0842 .41145 L
.0842 .41127 L
.0842 .41103 L
.08421 .41074 L
.08421 .4104 L
.08422 .41002 L
.08423 .4096 L
.08424 .40916 L
.08424 .40871 L
.08425 .40831 L
.08426 .40797 L
.08426 .40777 L
.08426 .4077 L
.08426 .40777 L
.08426 .40795 L
.08425 .40824 L
.08425 .40859 L
.08424 .40898 L
.08423 .40936 L
.08423 .40973 L
.08422 .41007 L
.08422 .41039 L
.08421 .4107 L
.08421 .411 L
.0842 .4114 L
.0842 .41159 L
.08419 .41169 L
Mistroke
.08419 .41167 L
.0842 .4115 L
.0842 .41123 L
.08421 .41087 L
.08422 .41042 L
.08423 .40988 L
.08424 .40929 L
.08424 .40874 L
.08422 .40829 L
.08419 .4079 L
.08415 .40757 L
.08413 .4074 L
.08412 .40736 L
.08413 .40746 L
.08416 .4077 L
.08421 .40808 L
.0843 .40856 L
.08443 .40909 L
.08464 .40962 L
.08496 .41011 L
.08545 .41054 L
.08605 .4109 L
.08679 .41119 L
.08768 .41142 L
.08872 .41169 L
.08985 .41207 L
.09081 .41262 L
.09182 .41335 L
.09293 .4143 L
.09384 .41551 L
.09483 .41696 L
.09559 .41868 L
.09628 .42072 L
.09684 .42295 L
.09723 .4255 L
.09742 .42835 L
.09741 .43145 L
.0972 .43474 L
.09681 .43829 L
.09626 .4419 L
.09557 .44587 L
.09479 .44925 L
.09402 .45304 L
.09316 .4561 L
.09226 .45923 L
.09145 .462 L
.09056 .4645 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{531, 252.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008C0000o1000`40O003h00Oogooogoo5Goo003o
OoooOolEOol00?mooomooaEoo`00ogooogoo5Goo003oOoooOolEOol00?mooomooaEoo`00ogooogoo
5Goo003oOoooOolEOol00?mooomooaEoo`00ogooogoo5Goo003oOoooOolEOol007UooaP00?1ooaP0
07Yoo`00M7oo1@0067oo1@00gGoo00<007ooOol00Woo0P0000=oo`0000001@0017oo0P001Woo0P00
17oo00<007ooOol00Woo1@00MGoo001_Ool5000ROol5003EOol40002Ool60003Ool30004Ool30005
Ool20004Ool00`00Oomoo`02Ool01@00Oomoo`00Ool01@00L7oo001ZOol6000[Ool5003>Ool00`00
Ool0000900000goo001oo`040004Ool40006Ool00`00Oomoo`07Ool01P00Oomoo`00Ool000Aoo`D0
06]oo`00Igoo0`000Woo10000Woo0`000goo1P001Woo00H007oo000007oo0004Ool00`00Oomoo`0?
Ool30038Ool01000Oomoogoo0P001goo1`0000=oo`00Ool00goo0P0027oo00<007ooOol05Woo0`00
J7oo001ROol50005Ool40002Ool30003Ool00`00Ool000020006Ool200000goo000000020002Ool0
1000Ool007oo0P000goo1`001goo1@00`Woo1@0000=oo`00Ool01goo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol05Woo1@00Hgoo001POol20007Ool00`00Ool0000400000goo000000020002
Ool2000:Ool20002Ool00`00Ool00002Ool00`00Ool0000300000goo001oo`08000;Ool2002nOol6
0002Ool00`00Oomoo`0XOol00`00Oomoo`0<Ool00`00Oomoo`03Ool2001QOol005eoo`<000Uoo`<0
0003Ool0000000D0011oo`04001oogoo0006Ool00`00Oomoo`02Ool;000<Ool3002hOol3000017oo
00000000?Woo00<007oo00001Goo0`00GWoo001KOol2000?Ool200000goo00000004000?Ool01000
Oomoo`002goo100017oo0`003goo0P00]7oo0P00A7oo100000=oo`0000001Goo0P00G7oo001HOol3
000BOol00`00Oomoo`02Ool30008Ool3000_Ool3002^Ool300000goo001oo`18Ool20007Ool2001J
Ool005Ioo`8000Yoo`8000Uoo`03001oogoo00eoo`<002Aoo`03001oogoo00]oo`800:Yoo`8000=o
o`8001Yoo`03001oogoo035oo`03001oogoo00=oo`<005Moo`00EGoo00<007ooOol02Goo0`000Woo
00<007ooOol017oo00<007ooOol03Goo00<007ooOol097oo00<007ooOol03Goo00<007ooOol0YWoo
00<007ooOol00goo00<007ooOol0CGoo0P001goo00<007ooOol0E7oo001COol2000<Ool30002Ool0
0`00Oomoo`10Ool00`00Oomoo`09Ool2002TOol200000goo0000000LOol00`00Oomoo`0dOol20008
Ool2001DOol0055oo`8000Qoo`<00003Ool007oo05Ioo`800:1oo`8000=oo`8001aoo`03001oogoo
03Aoo`8000Yoo`80059oo`00Cgoo0P0027oo00<007oo00000P0000=oo`00Ool08goo00<007ooOol0
<Woo0P00W7oo0P00FWoo0P001Woo00<007ooOol00goo0P00D7oo001>Ool00`00Oomoo`08Ool30002
Ool2000TOol00`00Oomoo`0/Ool00`00Oomoo`05Ool00`00Oomoo`2HOol00`00Oomoo`02Ool00`00
Oomoo`1MOol30005Ool00`00Oomoo`1=Ool004eoo`03001oogoo00ioo`03001oogoo055oo`8000Qo
o`8009Ioo`80009oo`03001oogoo0080061oo`03001oogoo00Aoo`03001oogoo04aoo`00Bgoo0P00
2Goo00<007ooOol0IGoo0P00TWoo0P0017oo0P000Woo0P00Cgoo00<007ooOol057oo0`00C7oo001:
Ool00`00Oomoo`09Ool00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`2>
Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`1=Ool00`00Oomoo`0COol300000goo001oo`1:Ool0
04Qoo`8000]oo`8005Ioo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo08aoo`03001oogoo
05aoo`80019oo`L004Uoo`00AWoo0P00NWoo0P00RWoo0P000goo0P00FWoo0P004Woo0P0000=oo`00
00001000Agoo0015Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool00`00Oomoo`02Ool00`00Oomoo`26
Ool00`00Oomoo`03Ool2000dOol00`00Oomoo`0ROol2000IOol01000Ool00000AWoo0014Ool00`00
Oomoo`05Ool00`00Oomoo`1_Ool50002Ool00`00Oomoo`24Ool01000Oomoogoo0P0000=oo`00Ool0
FGoo0P006goo00<007oo0000AGoo0012Ool20003Ool00`00Ool00003000AOol00`00Oomoo`1OOol5
00000goo00000022Ool20004Ool20006Ool2001DOol00`00Oomoo`0HOol00`00Ool00002Ool20013
Ool0045oo`03001oogoo00Aoo`8007Ioo`T0081oo`03001oogoo00Aoo`03001oogoo00Eoo`8005=o
o`8001ioo`04001oogoo0012Ool0041oo`03001oogoo00=oo`@007Yoo`@00003Ool007oo07eoo`03
001oogoo00Eoo`03001oogoo05Yoo`8001ioo`05001oogooOol00011Ool003moo`03001oogoo00=o
o`@007aoo`@00003Ool007oo07]oo`04001oogoo0022Ool00`00Oomoo`02Ool00`00Oomoo`0nOol0
03ioo`03001oogoo00=oo`@007ioo`<0009oo`03001oogoo07Qoo`03001oogoo008008Eoo`04001o
ogoo000oOol003eoo`03001oogoo00Aoo`8008Ioo`03001oogoo07Ioo`04001oogooOol20025Ool0
1@00Oomoogoo0000?Woo000lOol00`00Oomoo`05Ool00`00Oomoo`26Ool00`00Oomoo`1dOol01@00
Oomoogoo0000NGoo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0>goo000kOol00`00Oomo
o`2=Ool01000Oomoo`00M7oo00<007ooOol00Woo00D007ooOomoo`0007Eoo`03001oogoo015oo`03
001oogoo03Yoo`00>goo00<007ooOol0SGoo00D007ooOomoo`00079oo`03001oogoo00=oo`05001o
ogooOol0002:Ool00`00Oomoo`0iOol003Uoo`8000Ioo`03001oogoo08Moo`8000=oo`03001oogoo
06eoo`8000Ioo`03001oo`0008Moo`8000=oo`8003Yoo`00>7oo00<007ooOol017oo1000R7oo0P00
17oo00<007ooOol0Jgoo00<007ooOol027oo00<007ooOol0QGoo0P001Goo00<007ooOol0=goo000g
Ool00`00Oomoo`05Ool4002?Ool00`00Oomoo`1ZOol00`00Oomoo`2HOol00`00Oomoo`0fOol003Io
o`03001oogoo00Ioo`<008]oo`8000Aoo`03001oogoo06Qoo`03001oogoo00Aoo`800003Ool007oo
08Yoo`03001oogoo00Aoo`03001oogoo03Eoo`00=Goo00<007ooOol027oo0P00S7oo00<007ooOol0
0goo00<007ooOol0IWoo00<007ooOol01Goo00@007oo000008]oo`8000Ioo`03001oogoo03Aoo`00
=7oo00<007ooOol0VGoo00<007ooOol00Woo00<007ooOol0I7oo00<007ooOol01Woo00<007ooOol0
SGoo00<007ooOol01Goo00<007ooOol0<goo000dOol00`00Oomoo`2IOol00`00Oomoo`03Ool00`00
Oomoo`1ROol00`00Oomoo`2GOol20007Ool00`00Oomoo`0bOol003=oo`03001oogoo09Yoo`03001o
ogoo00Aoo`03001oogoo061oo`03001oogoo09Qoo`800003Ool007oo00Aoo`03001oogoo039oo`00
<Woo00<007ooOol0W7oo00<007ooOol017oo00<007ooOol0Ggoo00<007ooOol0VGoo00<007oo0000
1Woo00<007ooOol0<Goo000aOol00`00Oomoo`2TOol00`00Oomoo`1NOol00`00Oomoo`2KOol00`00
Oomoo`06Ool00`00Oomoo`0`Ool0031oo`03001oogoo0:Ioo`03001oogoo05aoo`03001oogoo00Qo
o`03001oogoo04Qoo`03001oogoo03Qoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo031o
o`00<7oo00<007ooOol0YWoo00<007ooOol0G7oo00<007ooOol0SWoo00<007ooOol03Woo00<007oo
Ool017oo00<007ooOol0;goo000_Ool00`00Oomoo`2MOol00`00Oomoo`08Ool00`00Oomoo`1JOol0
0`00Oomoo`05Ool00`00Oomoo`2FOol01000Ool000001Goo00<007ooOol0;goo000_Ool00`00Oomo
o`2MOol2000:Ool00`00Oomoo`1IOol00`00Oomoo`2QOol30004Ool00`00Oomoo`0^Ool002ioo`03
001oogoo09ioo`8000Yoo`03001oogoo05Qoo`03001oogoo0:=oo`8000Eoo`03001oogoo02eoo`00
;Woo00<007ooOol01goo00<007ooOol0U7oo00<007ooOol02Woo00<007ooOol0EWoo00<007ooOol0
YGoo00<007ooOol017oo00<007ooOol0;7oo000]Ool00`00Oomoo`08Ool00`00Oomoo`2DOol00`00
Oomoo`0;Ool00`00Oomoo`1DOol00`00Oomoo`2]Ool00`00Oomoo`0/Ool002aoo`03001oogoo00Mo
o`<009=oo`@000ioo`03001oogoo05=oo`03001oogoo0:ioo`03001oogoo02]oo`00:goo00<007oo
Ool027oo0P00U7oo0`002Goo00<007ooOol00goo00<007ooOol0DWoo00<007ooOol0NWoo00<007oo
Ool0<goo00<007ooOol0:Woo000[Ool00`00Oomoo`2NOol00`00Oomoo`09Ool20005Ool00`00Oomo
o`1AOol00`00Oomoo`2aOol00`00Oomoo`0YOol002Yoo`03001oogoo09moo`03001oogoo00Yoo`80
00Aoo`03001oogoo051oo`03001oogoo0:Yoo`8000Ioo`03001oogoo02Uoo`00:Woo00<007ooOol0
[Goo00<007ooOol00goo00<007ooOol0CWoo00<007ooOol0:goo0P00OGoo0`001Woo00<007ooOol0
:Goo000YOol00`00Oomoo`2^Ool20004Ool00`00Oomoo`1>Ool00`00Oomoo`0[Ool2001lOol30008
Ool00`00Oomoo`0XOol002Uoo`03001oogoo0;1oo`03001oogoo009oo`03001oogoo04aoo`03001o
ogoo02eoo`03001oogoo07Yoo`03001oogoo00Qoo`03001oogoo02Qoo`00:7oo00<007ooOol0[goo
0`001Goo00<007ooOol0Bgoo00<007ooOol0[goo00<007ooOol017oo00<007ooOol09goo000WOol0
0`00Oomoo`05Ool00`00Oomoo`2XOol40004Ool00`00Oomoo`1:Ool00`00Oomoo`2_Ool30006Ool0
0`00Oomoo`0VOol002Moo`03001oogoo00Eoo`03001oogoo039oo`03001oogoo07=oo`@000Eoo`03
001oogoo04Uoo`03001oogoo00Eoo`03001oogoo0:Moo`04001oo`000006Ool00`00Oomoo`0UOol0
02Ioo`03001oogoo03]oo`03001oogoo07Ioo`8000Aoo`03001oogoo04Qoo`03001oogoo00Ioo`03
001oogoo0:Uoo`8000Ioo`03001oogoo02Eoo`009Woo00<007ooOol017oo1@00[7oo0P000goo00<0
07ooOol0B7oo00<007ooOol017oo0P00C7oo00<007ooOol0GWoo0P001Goo00<007ooOol09Goo000U
Ool00`00Oomoo`05Ool5002]Ool00`00Oomoo`02Ool00`00Oomoo`16Ool00`00Oomoo`05Ool2000f
Ool00`00Oomoo`0COol00`00Oomoo`1NOol20006Ool00`00Oomoo`0TOol002Eoo`03001oogoo00Eo
o`@00;=oo`03001oogoo04Ioo`03001oogoo00Aoo`03001oogoo03Ioo`8001Aoo`03001oogoo05io
o`<000Eoo`03001oogoo02Aoo`009Goo00<007ooOol017oo00<007oo0000/Goo0P000goo00<007oo
Ool0AGoo00<007ooOol017oo00<007ooOol0=Woo0P00MGoo0`001Woo00<007ooOol08goo000TOol0
0`00Oomoo`04Ool2002cOol20003Ool00`00Oomoo`14Ool00`00Oomoo`04Ool2000hOol2001fOol2
0006Ool00`00Oomoo`0SOol002Aoo`03001oogoo0;Uoo`8000Aoo`03001oogoo04=oo`03001oogoo
00Aoo`800;5oo`03001oogoo00Eoo`03001oogoo029oo`008goo00<007ooOol0^goo0P000goo00<0
07ooOol0@Woo00<007ooOol01Goo00<007ooOol0/7oo00<007ooOol01Goo00<007ooOol08Woo000S
Ool00`00Oomoo`2kOol20003Ool00`00Oomoo`12Ool00`00Oomoo`05Ool2002aOol00`00Oomoo`05
Ool00`00Oomoo`0ROol0029oo`03001oogoo00Ioo`03001oo`0000ioo`03001oogoo0:Qoo`03001o
ogoo041oo`03001oogoo00Ioo`800;Yoo`03001oogoo025oo`008Woo00<007ooOol027oo00<007oo
Ool0]goo00<007ooOol0@7oo00<007ooOol0^Woo00<007ooOol01Goo00<007ooOol08Goo000ROol0
0`00Oomoo`33Ool00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`2kOol00`00Oomoo`0POol0
025oo`03001oogoo0;ioo`03001oogoo00=oo`03001oogoo03ioo`03001oogoo00Ioo`03001oogoo
0;5oo`8000Qoo`03001oogoo021oo`008Goo00<007ooOol0_Woo00<007ooOol00goo00<007ooOol0
?Woo00<007ooOol01Woo00<007ooOol0/Woo00<007ooOol01Woo00<007ooOol087oo000POol00`00
Oomoo`2oOol00`00Oomoo`04Ool00`00Oomoo`0lOol00`00Oomoo`36Ool00`00Oomoo`0OOol0021o
o`03001oogoo00Moo`03001oogoo0;aoo`03001oogoo03aoo`03001oogoo0<Ioo`03001oogoo01mo
o`0087oo00<007ooOol01goo00<007ooOol0_Goo00<007ooOol0>goo00<007ooOol0Agoo00<007oo
Ool0O7oo00<007ooOol07goo000POol00`00Oomoo`2nOol20007Ool00`00Oomoo`0jOol00`00Oomo
o`37Ool00`00Oomoo`0OOol0021oo`03001oogoo0;ioo`8000Moo`03001oogoo03Yoo`03001oogoo
0<Moo`03001oogoo01moo`007goo00<007ooOol01goo0P00_goo00<007ooOol0>Woo00<007ooOol0
1goo00<007ooOol0_Woo00<007ooOol07Woo000OOol00`00Oomoo`07Ool3002dOol01000Oomoo`00
1Woo00<007ooOol0>Woo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0RGoo00<007ooOol0
7Woo000OOol00`00Oomoo`06Ool3002dOol20002Ool00`00Oomoo`05Ool00`00Oomoo`0iOol00`00
Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`2:Ool00`00Oomoo`0MOol001ioo`03001oogoo00Mo
o`800;Eoo`80009oo`03001oogoo00Eoo`03001oogoo03Qoo`03001oogoo00Qoo`800<1oo`03001o
ogoo01eoo`007Woo00<007ooOol01Woo1@00]goo0P001Woo00<007ooOol0>7oo00<007ooOol027oo
0P00`7oo00<007ooOol07Goo000NOol00`00Oomoo`06Ool6002fOol20006Ool00`00Oomoo`0hOol0
0`00Oomoo`08Ool4002nOol00`00Oomoo`0MOol001ioo`03001oogoo00Aoo`@000=oo`05001oogoo
Ool0002jOol00`00Oomoo`0hOol00`00Oomoo`07Ool5002nOol00`00Oomoo`0MOol001ioo`03001o
ogoo00=oo`D000=oo`03001oogoo0;aoo`03001oogoo03Qoo`03001oogoo00Moo`D00;ioo`03001o
ogoo01eoo`007Goo00<007ooOol017oo1000a7oo00<007ooOol0=Woo00<007ooOol02Goo0`00`7oo
00<007ooOol077oo000MOol00`00Oomoo`04Ool30004Ool00`00Oomoo`2nOol00`00Oomoo`0fOol0
0`00Oomoo`0;Ool300000goo001oo`2kOol00`00Oomoo`0LOol001eoo`03001oogoo00Aoo`8000Eo
o`03001oogoo0;Ioo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo00aoo`800003Ool007oo
0;]oo`03001oogoo01aoo`007Goo00<007ooOol017oo0P0017oo00<007ooOol0_goo00<007ooOol0
=Woo00<007ooOol037oo00@007oo001oo`<00;Uoo`03001oogoo01aoo`007Goo00<007ooOol017oo
0P0017oo0P00`7oo00<007ooOol0=Woo00<007ooOol037oo00<007oo00001000^Goo00<007ooOol0
77oo000MOol00`00Oomoo`04Ool8002hOol00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`0=
Ool300000goo001oo`02002hOol00`00Oomoo`0LOol001eoo`03001oogoo00Aoo`L00<9oo`03001o
ogoo03Aoo`03001oogoo00aoo`H00;1oo`8000Uoo`03001oogoo01aoo`007Goo00<007ooOol017oo
100000=oo`000000`Woo00<007ooOol0=7oo00<007ooOol037oo10000Woo00D007ooOomoo`000:]o
o`8000Yoo`03001oogoo01]oo`0077oo00<007ooOol01Woo1P00`Woo00<007ooOol0=7oo00<007oo
Ool02goo0`000Woo100017oo0P00ZGoo00<007ooOol027oo00<007ooOol06goo000LOol00`00Oomo
o`06Ool60032Ool00`00Oomoo`0dOol00`00Oomoo`08Ool00`00Ool00002000;Ool2002dOol00`00
Oomoo`0KOol001aoo`03001oogoo00Ioo`@00003Ool000000<5oo`03001oogoo03Aoo`03001oogoo
00Moo`H00;Eoo`03001oogoo00Uoo`03001oogoo01]oo`0077oo00<007ooOol01Woo0`000Woo0P00
`Goo00<007ooOol0=7oo00<007ooOol01goo1@0017oo00<007ooOol0^goo00<007ooOol06goo000L
Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`30Ool00`00Oomoo`0dOol00`00Oomoo`07Ool40005
Ool00`00Oomoo`2kOol00`00Oomoo`0KOol001aoo`03001oogoo00Ioo`800<Ioo`03001oogoo03Ao
o`03001oogoo00Moo`@000Qoo`03001oogoo00Ioo`03001oogoo0:moo`03001oogoo01]oo`0077oo
00<007ooOol01Woo00<007ooOol0aGoo00<007ooOol0=7oo00<007ooOol01goo0`002Goo00<007oo
Ool0^7oo00<007ooOol06goo000LOol00`00Oomoo`06Ool00`00Oomoo`35Ool00`00Oomoo`0dOol0
0`00Oomoo`07Ool2000:Ool00`00Oomoo`0GOol00`00Oomoo`2NOol00`00Oomoo`0KOol001aoo`03
001oogoo00Ioo`03001oogoo0<Eoo`03001oogoo03Aoo`03001oogoo00Moo`8000]oo`03001oogoo
0;Moo`03001oogoo01]oo`0077oo00<007ooOol01Goo0P00agoo00<007ooOol0=7oo00<007ooOol0
1Woo10002Goo0P00[Woo00<007ooOol027oo00<007ooOol06goo000LOol00`00Oomoo`05Ool00`00
Oomoo`36Ool00`00Oomoo`0cOol00`00Oomoo`07Ool3000:Ool2000HOol00`00Oomoo`2NOol00`00
Oomoo`0KOol001aoo`03001oogoo0<ioo`03001oogoo03=oo`03001oogoo00Moo`8002Eoo`03001o
ogoo09ioo`03001oogoo01]oo`0077oo00<007ooOol0cWoo00<007ooOol0=7oo00<007ooOol0cWoo
00<007ooOol06goo000LOol00`00Oomoo`04Ool20038Ool00`00Oomoo`0dOol00`00Oomoo`07Ool0
0`00Oomoo`34Ool00`00Oomoo`0KOol001aoo`03001oogoo00Aoo`800<Qoo`03001oogoo03Aoo`03
001oogoo00Moo`8000ioo`03001oogoo0;Aoo`03001oogoo01]oo`0077oo00<007ooOol0agoo00<0
07ooOol017oo00<007ooOol0=7oo00<007ooOol01goo0P003Woo00<007ooOol0]7oo00<007ooOol0
6goo000LOol00`00Oomoo`05Ool20030Ool00`00Oomoo`04Ool00`00Oomoo`0dOol00`00Oomoo`06
Ool30035Ool00`00Oomoo`0KOol001aoo`03001oogoo00Eoo`800<Moo`03001oogoo03Aoo`03001o
ogoo00Moo`03001oogoo0<Aoo`03001oogoo01]oo`0077oo00<007ooOol01Woo00<007ooOol0_Woo
00<007ooOol017oo00<007ooOol0=7oo00<007ooOol0cWoo00<007ooOol06goo000LOol00`00Oomo
o`06Ool00`00Oomoo`2mOol20006Ool00`00Oomoo`0dOol00`00Oomoo`07Ool00`00Oomoo`34Ool0
0`00Oomoo`0KOol001aoo`03001oogoo00Ioo`03001oogoo0;eoo`8000Ioo`03001oogoo03Aoo`03
001oogoo00Moo`800;aoo`03001oogoo00Ioo`03001oogoo01]oo`0077oo00<007ooOol01Woo00<0
07ooOol0aGoo00<007ooOol0=7oo00<007ooOol01goo0P003goo00<007ooOol0ZWoo00<007ooOol0
1Woo00<007ooOol06goo000LOol00`00Oomoo`06Ool00`00Oomoo`2mOol00`00Oomoo`05Ool00`00
Oomoo`0dOol00`00Oomoo`07Ool2000?Ool00`00Oomoo`2YOol00`00Oomoo`07Ool00`00Oomoo`0K
Ool001eoo`03001oogoo0<Eoo`8000Ioo`03001oogoo03Aoo`03001oogoo00Qoo`03001oogoo019o
o`03001oogoo0:Aoo`03001oogoo00Ioo`03001oogoo01aoo`007Goo00<007ooOol0aGoo0P001Woo
00<007ooOol0=7oo00<007ooOol027oo00<007ooOol0^Goo00<007ooOol01Woo00<007ooOol077oo
000MOol00`00Oomoo`06Ool00`00Oomoo`2lOol20006Ool00`00Oomoo`0eOol00`00Oomoo`32Ool2
0008Ool00`00Oomoo`0LOol001eoo`03001oogoo00Ioo`03001oogoo0<=oo`03001oogoo03Ioo`03
001oogoo0;Yoo`03001oogoo00Eoo`8000Qoo`03001oogoo01aoo`007Goo00<007ooOol0c7oo00<0
07ooOol0=Woo00<007ooOol0c7oo00<007ooOol077oo000MOol00`00Oomoo`3<Ool00`00Oomoo`0f
Ool00`00Oomoo`2kOol00`00Oomoo`0>Ool00`00Oomoo`0LOol001eoo`03001oogoo0<aoo`03001o
ogoo03Ioo`03001oogoo00Moo`800<=oo`03001oogoo01aoo`007Goo00<007ooOol0a7oo00<007oo
Ool01Goo00<007ooOol0=Woo00<007ooOol01goo0`00`Woo00<007ooOol077oo000NOol00`00Oomo
o`0JOol00`00Oomoo`2VOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`07Ool2001;Ool0
0`00Oomoo`1cOol00`00Oomoo`0MOol001ioo`03001oogoo01Yoo`03001oogoo0:eoo`03001oogoo
03Qoo`03001oogoo00Ioo`<004]oo`03001oogoo07=oo`03001oogoo01eoo`007Woo00<007ooOol0
1Goo00<007ooOol0`Woo00<007ooOol0>7oo00<007ooOol01Woo0P00C7oo00<007ooOol0Lgoo00<0
07ooOol07Goo000NOol00`00Oomoo`3:Ool00`00Oomoo`0hOol00`00Oomoo`07Ool00`00Oomoo`2<
Ool00`00Oomoo`0aOol00`00Oomoo`0MOol001ioo`03001oogoo0<Yoo`03001oogoo03Qoo`03001o
ogoo035oo`03001oogoo09Ioo`03001oogoo01eoo`007goo00<007ooOol01Goo00<007ooOol0^7oo
00<007ooOol01Goo00<007ooOol0>Woo00<007ooOol01Woo00<007ooOol0Zgoo0P0027oo00<007oo
Ool01goo00<007ooOol07Woo000OOol00`00Oomoo`05Ool00`00Oomoo`2gOol20007Ool00`00Oomo
o`0jOol00`00Oomoo`06Ool2002/Ool2000BOol00`00Oomoo`0NOol0021oo`03001oogoo00Aoo`03
001oogoo0;Moo`8000Moo`03001oogoo03Yoo`03001oogoo00Moo`03001oogoo0;ioo`03001oogoo
01ioo`0087oo00<007ooOol017oo00<007ooOol0]goo00<007ooOol01Woo00<007ooOol0>Woo00<0
07ooOol0agoo00<007ooOol07goo000POol00`00Oomoo`04Ool00`00Ool00030Ool00`00Oomoo`0j
Ool00`00Oomoo`37Ool00`00Oomoo`0OOol0021oo`03001oogoo00Ioo`05001oogooOol0002kOol0
0`00Oomoo`0lOol00`00Oomoo`2HOol00`00Oomoo`0[Ool00`00Oomoo`0OOol0021oo`03001oogoo
00Yoo`03001oogoo0;Uoo`03001oogoo03aoo`03001oogoo09Qoo`03001oogoo02]oo`03001oogoo
01moo`008Goo00<007ooOol0aGoo00<007ooOol0?Goo00<007ooOol0;7oo00<007ooOol0UWoo00<0
07ooOol07goo000QOol00`00Oomoo`34Ool00`00Oomoo`0nOol00`00Oomoo`0/Ool00`00Oomoo`2E
Ool00`00Oomoo`0POol0025oo`03001oogoo0<Aoo`03001oogoo03ioo`03001oogoo00Eoo`03001o
ogoo0;aoo`03001oogoo021oo`008Woo00<007ooOol017oo00<007ooOol0^goo00<007ooOol0@7oo
00<007ooOol01Goo00<007ooOol0^Woo00<007ooOol08Goo000ROol00`00Oomoo`04Ool00`00Oomo
o`2kOol00`00Oomoo`10Ool00`00Oomoo`05Ool00`00Oomoo`2_Ool00`00Oomoo`08Ool00`00Oomo
o`0QOol002=oo`03001oogoo00=oo`03001oogoo0;]oo`03001oogoo045oo`03001oogoo0;9oo`03
001oogoo00aoo`03001oogoo025oo`008goo00<007ooOol00goo00<007ooOol0^Woo00<007ooOol0
@Woo00<007ooOol02Goo00<007ooOol0]7oo00<007ooOol08Woo000TOol00`00Oomoo`02Ool00`00
Oomoo`2jOol00`00Oomoo`13Ool00`00Oomoo`08Ool00`00Oomoo`2dOol00`00Oomoo`0ROol002Ao
o`03001oogoo009oo`03001oogoo00]oo`03001oogoo0:]oo`03001oogoo04Aoo`03001oogoo0;Ao
o`03001oogoo00Moo`03001oogoo02=oo`0097oo00<007ooOol00Woo0P0037oo00<007ooOol0Zgoo
00<007ooOol0A7oo00<007ooOol0]7oo00<007ooOol01goo00<007ooOol08goo000UOol00`00Oomo
o`03000<Ool00`00Oomoo`2[Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomoo`2/Ool00`00
Oomoo`08Ool00`00Oomoo`0SOol002Eoo`03001oogoo00<00;Uoo`03001oogoo04Ioo`03001oogoo
00=oo`800:eoo`03001oogoo00Moo`03001oogoo02Aoo`009Woo00D007ooOomoo`000;Uoo`03001o
ogoo04Moo`03001oogoo009oo`80039oo`03001oogoo07Moo`8000Uoo`03001oogoo02Aoo`009Woo
00@007ooOomoo`D00;Aoo`03001oogoo04Qoo`03001oogoo00=oo`03001oogoo031oo`03001oogoo
07Moo`8000Qoo`03001oogoo02Eoo`009Woo00@007ooOomoo`D00:eoo`03001oogoo00Aoo`03001o
ogoo04Qoo`03001oogoo00=oo`03001oogoo0:Uoo`<000Qoo`03001oogoo02Eoo`009goo00<007oo
Ool00`00]Goo00<007ooOol0BWoo00<007ooOol00Woo0P00ZWoo00<007ooOol01goo00<007ooOol0
9Woo000WOol00`00Oomoo`03002eOol00`00Oomoo`1:Ool00`00Oomoo`02Ool01000Ool00000/Woo
00<007ooOol09Woo000XOol00`00Ool00003002dOol00`00Oomoo`1;Ool01000Oomoogoo1000/Goo
00<007ooOol09goo000YOol5002]Ool00`00Oomoo`03Ool00`00Oomoo`1<Ool01000Oomoogoo1000
/7oo00<007ooOol0:7oo000ZOol5002aOol00`00Oomoo`1>Ool01000Oomoogoo0P00/Goo00<007oo
Ool0:7oo000ZOol00`00Ool00003002_Ool00`00Oomoo`1@Ool00`00Oomoo`020003Ool00`00Oomo
o`2SOol00`00Oomoo`04Ool00`00Oomoo`0YOol002]oo`03001oo`00008009moo`03001oogoo00eo
o`03001oogoo055oo`03001oo`000080009oo`03001oogoo09]oo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo02Uoo`00:goo00D007ooOomoo`00009oo`03001oogoo09Yoo`03001oogoo00ao
o`03001oogoo059oo`03001oo`000080009oo`03001oogoo09]oo`03001oogoo00Aoo`8000Eoo`03
001oogoo02Yoo`00;7oo00<007ooOol0[goo00<007ooOol0DWoo00<007ooOol00`0000=oo`000000
Xgoo0P0017oo00<007ooOol0:goo000/Ool00`00Oomoo`2YOol00`00Oomoo`02Ool00`00Oomoo`1D
Ool00`00Oomoo`0200000goo0000002OOol2000017oo0000000017oo00<007ooOol0:goo000]Ool0
0`00Oomoo`2XOol00`00Oomoo`02Ool00`00Oomoo`1DOol00`00Oomoo`2TOol200000goo00000004
Ool00`00Oomoo`0/Ool002ioo`03001oogoo0:]oo`03001oogoo05Ioo`03001oogoo009oo`800:5o
o`<000Aoo`03001oogoo02aoo`00;Woo00<007ooOol0XWoo00<007ooOol01Goo00<007ooOol0F7oo
00@007ooOomoo`800:9oo`03001oogoo009oo`03001oogoo02eoo`00;goo00<007ooOol0XGoo00<0
07ooOol01Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0WWoo00<007ooOol00Woo00<0
07ooOol0;Woo000_Ool00`00Oomoo`2QOol00`00Oomoo`04Ool00`00Oomoo`1JOol00`00Oomoo`07
Ool00`00Oomoo`2HOol00`00Oomoo`02Ool00`00Oomoo`0_Ool0031oo`03001oogoo0:Ioo`03001o
ogoo05aoo`03001oogoo00Eoo`8002=oo`03001oogoo07Aoo`03001oogoo009oo`03001oogoo02mo
o`00<Goo00<007ooOol0Wgoo00<007oo00000Woo00<007ooOol0GWoo00<007ooOol017oo0P008goo
00<007ooOol0LWoo00<007oo00000goo00<007ooOol0<7oo000bOol00`00Oomoo`2NOol20003Ool0
0`00Oomoo`1OOol00`00Oomoo`1?Ool00`00Oomoo`0COol00`00Oomoo`0eOol30002Ool00`00Oomo
o`0aOol003=oo`03001oogoo09aoo`<0009oo`03001oogoo061oo`03001oogoo00=oo`03001oogoo
09Eoo`03001oo`0000800003Ool007oo03=oo`00=7oo00<007ooOol0VWoo0`000Woo00<007ooOol0
HWoo00<007ooOol00Woo0P0000=oo`00Ool0EGoo00<007ooOol0?Goo0P000Woo00<007ooOol0<Woo
000dOol00`00Oomoo`2JOol300000goo001oo`1UOol00`00Oomoo`04Ool00`00Oomoo`1DOol00`00
Oomoo`0:Ool00`00Oomoo`0cOol00`00Oomoo`0cOol003Eoo`03001oogoo09Uoo`04001oogoo001X
Ool00`00Oomoo`03Ool00`00Ool0001QOol00`00Oomoo`0WOol20003Ool00`00Oomoo`03Ool00`00
Oomoo`0dOol003Ioo`03001oogoo09Yoo`03001oogoo06Qoo`03001oogoo00Aoo`03001oogoo08Uo
o`8000=oo`03001oogoo009oo`03001oogoo03Eoo`00=goo00<007ooOol0V7oo00<007ooOol0JWoo
00<007ooOol00goo00<007ooOol0TWoo00<007ooOol0=Woo000hOol00`00Oomoo`2FOol00`00Oomo
o`1[Ool00`00Oomoo`2?Ool00`00Ool00005Ool00`00Oomoo`0gOol003Uoo`03001oogoo09Eoo`03
001oogoo06aoo`03001oogoo06aoo`03001oogoo01ioo`800003Ool007oo00=oo`03001oogoo03Qo
o`00>Woo00<007ooOol0RWoo00<007ooOol01Woo00<007ooOol0KWoo00<007ooOol01Goo00<007oo
Ool0Hgoo00<007ooOol07Woo0P001Goo00<007ooOol0>Goo000kOol00`00Oomoo`28Ool20007Ool0
0`00Oomoo`1`Ool00`00Oomoo`04Ool00`00Oomoo`1jOol00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`0iOol003]oo`03001oogoo08Qoo`8000Ioo`03001oogoo079oo`03001oogoo06Ioo`03
001oogoo02Moo`03001oogoo03Yoo`00?7oo00<007ooOol0Qgoo00<007ooOol017oo00<007ooOol0
M7oo00<007ooOol0HWoo00@007ooOol001ioo`03001oogoo00Moo`03001oogoo03]oo`00?Goo0P00
S7oo0P00N7oo0P001Woo00<007ooOol0FGoo00@007ooOol001ioo`8000Ioo`8003ioo`00?goo00<0
07ooOol0R7oo00<007ooOol0NWoo00<007ooOol0MWoo00<007ooOol03goo00<007ooOol0?Woo0010
Ool00`00Oomoo`06Ool00`00Oomoo`1mOol00`00Oomoo`1lOol00`00Oomoo`26Ool00`00Oomoo`0o
Ool0045oo`03001oogoo08Aoo`03001oogoo07ioo`03001oogoo00Eoo`03001oogoo055oo`03001o
ogoo02Qoo`03001oogoo041oo`00@Woo00<007ooOol0PWoo00<007ooOol0P7oo00<007ooOol00goo
0P0000=oo`00Ool0NWoo00<007ooOol0@Goo0013Ool2001dOol00`00Oomoo`09Ool20024Ool20006
Ool00`00Oomoo`1gOol20014Ool004Eoo`03001oogoo075oo`03001oogoo00Qoo`03001oogoo08Io
o`03001oogoo00=oo`03001oogoo06aoo`8000Qoo`03001oogoo04Aoo`00AWoo00<007ooOol0KGoo
00<007ooOol02Woo00<007ooOol0R7oo00<007ooOol0J7oo00@007ooOol000Aoo`03001oogoo00Mo
o`03001oogoo04Eoo`00Agoo0P00K7oo0`002Goo0P00S7oo0P0017oo0`00F7oo00<007ooOol03Goo
0P001goo0P00B7oo0019Ool2001ZOol30008Ool00`00Oomoo`2>Ool00`00Oomoo`02Ool2001HOol0
0`00Oomoo`0;Ool40005Ool2001:Ool004]oo`03001oogoo06Qoo`03001oogoo00Eoo`80099oo`03
001oogoo009oo`03001oogoo02Qoo`03001oogoo03Yoo`03001oogoo00Aoo`03001oogoo04Yoo`00
C7oo0P00KWoo0P00UGoo0P00Kgoo0P00CGoo001>Ool00`00Oomoo`1ZOol00`00Oomoo`2GOol20009
Ool00`00Oomoo`1POol00`00Oomoo`1=Ool004moo`03001oogoo06Qoo`03001oogoo09Yoo`03001o
ogoo06Qoo`03001oogoo04ioo`00D7oo0P004Woo0P00DWoo0P00WWoo0P00?goo00<007ooOol02Woo
00<007ooOol05goo0P00DGoo001BOol2000@Ool2001@Ool2002ROol2000:Ool00`00Oomoo`0/Ool0
0`00Oomoo`07Ool00`00Oomoo`0AOol01000Oomoo`001Woo0`00Dgoo001DOol3001LOol3002VOol3
0007Ool00`00Oomoo`0/Ool00`00Oomoo`0JOol200000goo00000004Ool2001FOol005Moo`8005Qo
o`800:aoo`8004Yoo`8000Aoo`H0009oo`8005Qoo`00FGoo0P00@7oo00<007ooOol04Goo0P00/7oo
0P00B7oo1@0000=oo`0000000P0000Aoo`00000005Yoo`00Fgoo0`00=7oo00<007ooOol01Woo00<0
07ooOol03Woo0`00]7oo0`0037oo00<007ooOol0;goo0P001Goo00<007oo00000`000goo0P00GGoo
001NOol2000KOol00`00Oomoo`0/Ool2002jOol2000:Ool00`00Oomoo`02000]Ool300000goo001o
o`03Ool30002Ool2001OOol0061oo`<001Qoo`8002Yoo`<00;ioo`8000]oo`8000Eoo`03001oogoo
031oo`<0065oo`00Hgoo0P004Woo0P0000Aoo`00000002Qoo`800<=oo`<000Qoo`03001oogoo00Ao
o`03001oogoo00aoo`<001moo`8006Aoo`00IGoo0`003goo10009goo0`00b7oo0P003Goo00<007oo
Ool01Woo00<007ooOol00goo0`000Woo00<007ooOol05goo0`00IWoo001XOol5000`Ool5003=Ool5
000AOol00`00Ool0000300000goo00000002Ool00`00Oomoo`0BOol5001YOol006eoo`8002aoo`80
0=Moo`<000ioo`H0009oo`04001oogoo000BOol2001^Ool006moo`P001aoo`P00=aoo`P000Ioo`<0
01=oo`P0071oo`00Mgoo2P0027oo2P00k7oo2P0027oo2P00N7oo0021Ool8003oOol1Ool80022Ool0
0?mooomooaEoo`00ogooogoo5Goo003oOoooOolEOol00?mooomooaEoo`00ogooogoo5Goo003oOooo
OolEOol00?mooomooaEoo`00ogooogoo5Goo002NOol8003oOol9Ool8001MOol00?mooomooaEoo`00
ogooogoo5Goo002>Ool01000Oomoo`00ogoo3Goo00@007ooOol0075oo`00EGoo0`0017oo10001Woo
00@007ooOomoo`<000=oo`80009oo`<00004Ool00000Ool70002Ool50005Ool01000Oomoo`001Goo
0`003Woo1@0017oo0P00Z7oo1@0017oo0`0000Aoo`00001oo`T00004Ool000000002Ool30003Ool2
0002Ool3000017oo000007oo1`000Woo1@001Goo00@007ooOol000Moo`<000aoo`D005Ioo`00E7oo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oo`0000=oo`8000Eoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo0003Ool0
1@00Oomoogoo00003goo00<007ooOol017oo0P00ZGoo00D007ooOomoo`00009oo`04001oogooOol2
0005Ool00`00Oomoo`02Ool20003Ool01000Oomoo`001Goo00<007oo00000goo0P001Goo00<007oo
Ool00Woo00<007ooOol02Goo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo05Ioo`00Dgoo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol00Woo00@007ooOol0009oo`03001oo`0000Ao
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`H000Ioo`03001oogoo00eoo`03001o
ogoo0:moo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo0004Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool60006Ool00`00Oomoo`0=Ool00`00Oomoo`1FOol005=oo`03001oogoo
00Yoo`03001oogoo00Aoo`0;001oogooOol007oo001oo`00Ool00002Ool50005Ool00`00Oomoo`02
Ool60006Ool01000Oomoo`001goo00<007ooOol03Goo00<007ooOol0[goo00D007ooOomoo`0000=o
o`D000Eoo`03001oogoo009oo`03001oogoo009oo`0:001oogoo001oo`00Ool007oo0002Ool50005
Ool00`00Oomoo`02Ool60006Ool01000Oomoo`000goo1P003Woo00<007ooOol0EWoo001COol00`00
Oomoo`0:Ool00`00Oomoo`04Ool03@00Oomoogoo001oo`00Ool007oo001oo`0000Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0005Ool2000@Ool0
0`00Oomoo`2_Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20003Ool0
3000Oomoo`00Ool007oo001oo`00Ool000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`04001oogoo0004Ool01000Oomoo`003goo00<007ooOol0EWoo001COol0
0`00Oomoo`06Ool40007Ool02`00Oomoogoo001oo`00Ool007oo00000Woo10001Woo00<007ooOol0
0goo10001Woo1P001Woo00<007ooOol03Goo00<007ooOol0[goo00D007ooOomoo`0000=oo`@000Io
o`03001oogoo009oo`03001oo`00008000=oo`07001oo`00Ool007oo00000Woo10001Woo00<007oo
Ool00goo10001Woo1P000goo00@007ooOol000moo`03001oogoo05Ioo`00E7oo00<007ooOol00P00
0goo00<007ooOol02Goo00<007ooOol00P000goo0P0037oo00<007ooOol03Woo00@007ooOol000Mo
o`03001oogoo00eoo`03001oogoo0:moo`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool20003Ool2000<Ool00`00Oomoo`0>Ool01000Oomoo`001Goo00<007oo00003goo00<007oo
Ool0EWoo001EOol200000goo001oo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00002
0003Ool2000<Ool00`00Oomoo`0?Ool01000Oomoo`000Woo00D007ooOomoo`0000eoo`<00;1oo`D0
00ioo`03001oogoo009oo`03001oogoo00Aoo`<000=oo`8000aoo`03001oogoo00moo`04001oogoo
0004Ool00`00Ool0000=Ool3001HOol005aoo`D0009oo`H001Aoo`80015oo`04001oogoo0003Ool3
000@Ool00`00Oomoo`30Ool20003Ool2000IOol2000AOol01000Oomoo`001Goo0P003goo00<007oo
Ool0EWoo003oOoooOolEOol00?mooomooaEoo`00ogooogoo5Goo003oOoooOolEOol00?mooomooaEo
o`00ogooogoo5Goo003oOoooOolEOol00?mooomooaEoo`00ogooogoo5Goo0000\
\>"],
  ImageRangeCache->{{{0, 530}, {251.813, 0}} -> {-0.0523798, -0.0238146, \
0.00397125, 0.00397125}, {{13.1875, 253}, {245.813, 5.9375}} -> {-215.795, \
-188.23, 1.62138, 1.62138}, {{276.938, 516.75}, {245.813, 5.9375}} -> \
{-643.434, -188.23, 1.62138, 1.62138}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Here the home base (at 9 o'clock) is a bit more visible.", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
A still better idea, for the purpose of highlighting the home base would be \
to include the temporal dimension, i.e to somehow code the duration of each \
lingering episode into the display:\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[
        Partition[
          Flatten[Script[{"\<See[TimePlot[lingering,100],PlotLabel->\
sessionname2,TextStyle->{FontSize->14},DisplayFunction->Identity]\>"}, 
              twofiles], 1], 2]]]\)], "Input"],

Cell[BoxData[
    \(255\)], "Print"],

Cell[BoxData[
    \(26176\)], "Print"],

Cell[BoxData[
    \(376\)], "Print"],

Cell[BoxData[
    \(27140\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497612 0.00243292 0.507028 0.00275978 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.413596 0.469163 scale
1.20313 1.08071 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00562652 0.00638244 scale
25.5575 69.5658 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00397855 0.00451307 scale
52.5669 133.652 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
75.8714 308.493 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
224.409 316.941 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
233.756 259.204 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107389 0.0121817 scale
81.3629 48.9603 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0119357 0.0135392 scale
73.1799 30.1162 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
581.725 262.396 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0147337 0.0167132 scale
46.7527 53.4154 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
50.3973 189.356 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781372 0.00886349 scale
17.3311 72.4297 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
92.1363 415.03 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0119357 0.0135392 scale
10.0112 40.2453 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0200625 0.0227579 scale
6.31127 20.5643 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00425325 0.00482467 scale
33.8377 89.5397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
41.6352 82.6463 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00620012 0.00703311 scale
41.4056 21.8125 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00336249 0.00381424 scale
137.821 16.462 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
266.141 65.0524 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00397855 0.00451307 scale
190.987 34.8588 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
128.662 22.5991 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
123.342 269.926 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
31.9594 125.226 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863839 0.00979896 scale
14.0802 48.4245 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0186004 0.0210993 scale
7.88909 15.4687 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00336249 0.00381424 scale
68.2411 49.1527 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0065547 0.00743532 scale
37.4449 21.6265 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.023003 0.0260934 scale
13.6382 4.55019 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
266.839 37.8009 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
97.9186 11.2585 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00986075 0.0111855 scale
50.3035 6.52449 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
149.238 23.2764 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
23.204 61.9394 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
54.2699 150.347 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0079571 0.00902614 scale
15.2078 54.5161 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.022855 0.0259256 scale
5.43294 18.0088 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542185 0.00615028 scale
21.2861 85.1002 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
80.2492 313.476 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00951055 0.0107883 scale
15.2515 67.8995 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
60.9428 253.576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00451125 0.00511734 scale
102.652 185.626 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0085065 0.00964935 scale
16.2488 72.5396 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
219.687 23.9601 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00914696 0.0103759 scale
91.3703 26.9983 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
402.13 131.151 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736684 0.00835658 scale
98.8076 16.2758 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00809794 0.00918591 scale
62.4825 7.01074 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
157.813 41.5697 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939092 0.0106526 scale
26.7546 14.926 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00620012 0.00703311 scale
36.8912 27.2852 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
26.1834 18.4178 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011648 0.0132129 scale
11.4063 30.9886 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781372 0.00886349 scale
16.224 52.0032 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0197788 0.022436 scale
6.23599 18.7569 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101989 0.0115692 scale
11.511 39.0711 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0123087 0.0139624 scale
10.062 34.4482 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00562652 0.00638244 scale
25.0777 72.1996 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
92.1695 281.191 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
23.1164 102.448 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
37.0498 165.448 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00837253 0.00949738 scale
22.8175 73.0086 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00951055 0.0107883 scale
87.0486 70.9194 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00637987 0.00723701 scale
126.876 110.696 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00425325 0.00482467 scale
189.958 164.906 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.01203 0.0136462 scale
67.1471 56.9893 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
372.529 311.146 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087683 0.00994632 scale
98.2916 63.4154 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00705322 0.00800082 scale
124.667 68.608 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00336249 0.00381424 scale
261.961 139.438 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087683 0.00994632 scale
96.1566 29.6381 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00809794 0.00918591 scale
106.509 36.0955 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
302.748 67.707 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087683 0.00994632 scale
86.1969 15.7636 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
143.443 20.7076 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
170.66 86.3828 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0118405 0.0134313 scale
11.4437 30.6202 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
15.693 44.101 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0141864 0.0160923 scale
8.43698 28.0588 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154089 0.017479 scale
7.69038 24.2182 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0079571 0.00902614 scale
15.9493 50.0037 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00451125 0.00511734 scale
30.7298 137.503 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
54.078 241.395 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
31.8373 128.184 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.006015 0.00682312 scale
22.389 98.452 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0280924 0.0318666 scale
5.42033 22.9962 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
110.404 243.713 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011253 0.0127649 scale
23.9873 11.1932 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00672498 0.00762848 scale
50.8284 13.2097 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
68.8856 9.85097 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00498738 0.00565743 scale
85.1771 10.8707 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
300.542 35.4383 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
85.6669 11.2455 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939092 0.0106526 scale
63.1653 7.11658 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863839 0.00979896 scale
67.8286 7.25485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.006015 0.00682312 scale
125.174 21.8961 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00498738 0.00565743 scale
156.05 33.0185 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736684 0.00835658 scale
118.277 47.5996 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0156996 0.0178089 scale
48.4993 47.0833 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
97.6303 53.01 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110503 0.0125349 scale
79.313 45.0144 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
234.079 80.6909 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
231.966 74.5927 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110503 0.0125349 scale
68.9097 12.5107 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
45.2857 5.94938 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0200625 0.0227579 scale
6.61681 17.9933 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00425325 0.00482467 scale
33.311 91.1647 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00672498 0.00762848 scale
17.4647 58.9855 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
45.4662 170.435 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
60.5184 260.805 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131094 0.0148706 scale
10.4269 46.3121 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0142658 0.0161824 scale
10.4691 45.5098 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0253862 0.0287969 scale
16.9517 2.66973 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
294.411 39.1434 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736684 0.00835658 scale
34.1381 18.4789 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0607485 0.0689101 scale
3.9945 2.46597 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103092 0.0116942 scale
12.8807 35.0506 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0285317 0.0323649 scale
5.09084 22.5167 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
25.4896 89.7268 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148864 0.0168864 scale
8.35597 27.421 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0161959 0.0183718 scale
22.4767 4.65931 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0156996 0.0178089 scale
37.4347 3.99015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00451125 0.00511734 scale
125.475 12.53 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00926974 0.0105151 scale
62.5713 6.74076 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00451125 0.00511734 scale
111.468 12.2017 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
302.362 39.1902 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863839 0.00979896 scale
62.0208 6.44762 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087683 0.00994632 scale
52.5507 6.31188 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154821 0.0175621 scale
25.3855 3.946 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781372 0.00886349 scale
51.3942 7.24432 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
106.037 46.9555 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00809794 0.00918591 scale
31.3376 17.3244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00951055 0.0107883 scale
13.995 37.8975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00926974 0.0105151 scale
12.6994 42.2743 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
40.0266 146.687 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863839 0.00979896 scale
13.6391 53.2067 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0186004 0.0210993 scale
6.5074 23.5571 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0330141 0.0374495 scale
3.58241 11.2939 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00766765 0.0086978 scale
17.3417 47.0084 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.013617 0.0154465 scale
8.64725 28.7968 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
22.1034 96.2286 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087683 0.00994632 scale
16.3099 72.3745 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
52.9343 218.205 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0128481 0.0145742 scale
34.817 65.5995 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133656 0.0151613 scale
60.5045 52.7976 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103092 0.0116942 scale
73.5732 13.3869 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117447 0.0133226 scale
62.6284 10.6849 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00689105 0.00781687 scale
19.238 52.484 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117447 0.0133226 scale
10.5767 34.8589 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0194327 0.0220435 scale
6.20859 19.1752 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111521 0.0126504 scale
10.9065 43.6666 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0770296 0.0873786 scale
1.8859 8.29986 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
60.7395 258.376 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00562652 0.00638244 scale
21.9105 90.2836 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0151871 0.0172275 scale
8.49666 26.9006 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00997475 0.0113149 scale
13.8891 33.1635 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167451 0.0189948 scale
9.35261 16.3208 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110503 0.0125349 scale
23.4465 11.9108 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
74.2978 33.3988 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.01345 0.015257 scale
29.8611 3.93919 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00974542 0.0110547 scale
50.8773 9.62123 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00997475 0.0113149 scale
75.8836 13.2277 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0174072 0.0197458 scale
7.14878 23.4637 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0125813 0.0142716 scale
12.2722 21.7348 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
53.6525 87.4439 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0309641 0.0351242 scale
4.29885 11.6493 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
45.3971 170.642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0165413 0.0187636 scale
8.52898 38.0461 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00425325 0.00482467 scale
32.6268 93.0426 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00751875 0.0085289 scale
25.862 29.8913 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.01203 0.0136462 scale
20.7515 11.5929 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.005824 0.00660646 scale
68.9904 9.80405 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.006015 0.00682312 scale
87.5245 9.52643 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
153.922 17.7221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0321817 0.0365053 scale
18.3859 1.94164 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.018232 0.0206815 scale
30.9664 3.41803 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0030075 0.00341156 scale
178.367 20.4042 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00620012 0.00703311 scale
81.9194 10.7193 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.006015 0.00682312 scale
68.8063 8.94312 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0239186 0.0271321 scale
17.0223 2.56891 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.01203 0.0136462 scale
37.1646 4.55217 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00212662 0.00241234 scale
191.04 35.82 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
102.595 22.289 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106331 0.0120617 scale
32.695 8.66629 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
229.047 85.3217 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
52.5395 28.5569 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0221005 0.0250697 scale
10.3532 7.51264 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00914696 0.0103759 scale
14.7951 39.5033 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00498738 0.00565743 scale
23.6517 76.5029 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
45.1552 151.87 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.097628 0.110744 scale
1.2439 4.33837 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
168.053 94.8892 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
100.182 50.5974 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131094 0.0148706 scale
24.9592 7.16916 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0168796 0.0191473 scale
21.266 4.7145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
89.1641 11.3549 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00889631 0.0100915 scale
55.3173 6.31619 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00951055 0.0107883 scale
54.327 6.00465 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00809794 0.00918591 scale
67.5036 7.14355 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0179822 0.0203982 scale
32.3653 3.34148 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150375 0.0170578 scale
48.4848 8.00279 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0126708 0.0143732 scale
60.1366 11.1166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
85.9263 17.5013 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090225 0.0102347 scale
95.5511 32.3361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00150375 0.00170578 scale
558.051 166.534 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0198928 0.0225653 scale
43.358 14.8577 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
236.503 94.3975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00721173 0.00818063 scale
116.898 35.3115 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
174.192 49.6093 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0118405 0.0134313 scale
63.0765 11.0987 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011253 0.0127649 scale
50.6414 5.19159 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127597 0.014474 scale
10.3881 28.3059 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863839 0.00979896 scale
17.0472 42.8893 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00498738 0.00565743 scale
73.9006 53.6798 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00705322 0.00800082 scale
125.037 70.934 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00837253 0.00949738 scale
90.7539 16.5446 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368342 0.00417829 scale
191.982 29.9189 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0166774 0.018918 scale
44.4542 7.54625 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0274409 0.0311276 scale
28.8413 7.79759 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0126708 0.0143732 scale
65.9854 20.5376 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00637987 0.00723701 scale
135.865 50.1367 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0085065 0.00964935 scale
101.54 39.7519 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0096287 0.0109223 scale
88.8116 36.5481 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260457 0.0029545 scale
320.183 94.1446 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0196065 0.0222406 scale
38.5821 6.71293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0079571 0.00902614 scale
73.8586 7.45834 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0326005 0.0369804 scale
12.4949 1.64384 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0132808 0.015065 scale
35.693 5.4809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00336249 0.00381424 scale
146.945 16.7635 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00809794 0.00918591 scale
76.7047 9.46015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00397855 0.00451307 scale
165.535 27.5666 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00475528 0.00539415 scale
159.204 28.5346 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00562652 0.00638244 scale
141.237 33.1033 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.111875 0.126906 scale
7.72574 2.65914 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.517914 0.00269574 0.510626 0.00272338 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.458277 0.462975 scale
1.13013 1.10293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0108543 0.0109655 scale
13.2114 41.5574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0436017 0.0440487 scale
3.71041 10.2221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0086587 0.00874748 scale
12.4707 58.2145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0492808 0.049786 scale
2.24043 9.88631 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0184406 0.0186297 scale
6.92493 24.7744 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
74.4099 288.128 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0750401 0.0758095 scale
1.49973 6.34485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110982 0.011212 scale
9.42855 44.7842 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0178504 0.0180334 scale
5.9136 27.733 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0848218 0.0856915 scale
1.28068 5.69636 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
80.8694 277.082 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
35.5647 117.877 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00911076 0.00920417 scale
13.8726 46.404 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
19.9561 63.5345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
34.7557 125.909 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0217085 0.0219311 scale
5.35458 21.7335 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00694241 0.00701359 scale
18.6679 65.4202 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
26.0583 79.2412 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
24.9292 76.1358 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
62.8615 187.295 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
22.5034 70.8361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00896261 0.0090545 scale
14.016 46.8927 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
24.0639 82.4019 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
57.8445 148.118 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
33.7325 70.6489 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0676266 0.06832 scale
1.7428 6.15062 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
17.9211 58.3423 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.062181 0.0628185 scale
1.89753 6.76505 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.051668 0.0521977 scale
2.25749 9.13642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
27.0548 87.7293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
67.5673 210.239 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
41.3064 127.927 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00834374 0.00842928 scale
19.1677 60.0027 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0642563 0.0649152 scale
1.77601 7.34112 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
39.8236 132.522 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.028295 0.0285851 scale
4.1601 14.855 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0287177 0.0290121 scale
4.11837 13.9356 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0264865 0.0267581 scale
4.44717 15.7033 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0172399 0.0174167 scale
7.46639 19.8482 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112182 0.0113332 scale
12.3514 28.1677 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
155.395 98.0148 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00462827 0.00467572 scale
85.3839 16.1451 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0080164 0.00809859 scale
54.4696 7.87421 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
49.6636 10.4798 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
52.2567 20.9667 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
155.664 97.5369 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0142653 0.0144115 scale
14.5816 14.4266 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
34.9914 26.7959 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
51.8942 27.9745 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
164.658 29.2361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
282.612 38.8599 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
302.351 43.4391 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0080164 0.00809859 scale
66.107 7.64454 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0333348 0.0336766 scale
12.8199 1.70712 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0179998 0.0181843 scale
22.6231 3.20606 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
60.8072 11.7794 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
91.1157 19.5022 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00818171 0.00826559 scale
41.1479 11.5249 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
46.8473 15.5238 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
45.021 23.4716 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
41.915 24.359 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
138.504 103.768 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
54.8846 75.2366 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
25.2485 63.3099 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
80.2644 206.392 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134936 0.013632 scale
8.73895 30.5004 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110982 0.011212 scale
9.53307 43.746 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
30.6835 161.581 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
18.1059 98.059 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
90.4374 303.285 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00784762 0.00792808 scale
66.4189 121.408 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
48.9234 260.77 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
25.6466 137.969 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
73.316 399.735 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00633752 0.0064025 scale
18.684 98.7692 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127802 0.0129113 scale
9.1219 36.8887 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
46.9117 210.68 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0271356 0.0274139 scale
3.88972 18.3889 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
63.5137 332.771 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
19.9535 103.386 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
20.2754 103.849 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00731794 0.00739297 scale
15.9567 81.9021 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104777 0.0105851 scale
10.8602 57.9313 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
34.736 188.94 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0182949 0.0184824 scale
7.3518 40.202 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
32.6908 155.794 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
103.291 471.479 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
43.4338 184.138 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
163.548 533.604 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
123.506 381.721 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
65.9838 127.295 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0108543 0.0109655 scale
61.3031 85.372 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0155237 0.0156829 scale
42.6252 59.7901 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
182.997 253.338 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0108543 0.0109655 scale
61.9066 85.3574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00767512 0.00775381 scale
86.4 121.157 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
128.193 168.716 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0179252 0.018109 scale
38.9518 51.0713 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00995347 0.0100555 scale
51.6794 94.8653 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
35.0997 188.895 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
45.7493 240.604 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
14.4866 64.938 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
22.9886 77.212 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.034441 0.0347941 scale
3.56349 12.0699 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0920433 0.092987 scale
1.28092 4.56709 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
26.321 124.461 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
77.3738 424.295 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127802 0.0129113 scale
10.636 57.7751 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
47.2905 149.475 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00940006 0.00949644 scale
30.4402 94.249 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00968072 0.00977998 scale
43.0712 96.8346 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
183.839 334.088 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
132.15 178.397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
535.292 459.743 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
180.211 144.779 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00462827 0.00467572 scale
190.287 162.219 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
532.102 471.757 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
140.115 129.723 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115707 0.0116893 scale
74.0924 68.1289 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00694241 0.00701359 scale
126.617 109.083 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00767512 0.00775381 scale
114.876 97.3418 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
156.283 136.681 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00925654 0.00935145 scale
88.7156 87.3779 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100871 0.0101905 scale
80.8043 82.097 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
241.505 257.38 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0239376 0.024183 scale
28.8028 38.5436 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
99.8462 140.958 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0177752 0.0179575 scale
25.1744 53.0966 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
17.8157 72.6869 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
37.9291 143.453 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0206983 0.0209105 scale
5.17483 23.5691 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0340501 0.0343992 scale
3.57503 13.8538 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
18.2086 62.2654 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
50.8354 177.94 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
47.1981 113.991 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
139.971 104.01 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
62.7092 31.8949 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00954143 0.00963925 scale
41.4403 6.42892 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100871 0.0101905 scale
42.4573 5.81031 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
356.735 47.6494 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
140.758 21.8914 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
189.439 31.4499 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
174.55 48.9882 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0147271 0.0148781 scale
61.3313 21.4127 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
185.896 73.3422 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0156097 0.0157697 scale
58.2093 20.7955 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
551.004 192.461 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0086587 0.00874748 scale
106.965 52.9741 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00462827 0.00467572 scale
201.399 122.131 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00462827 0.00467572 scale
194.146 148.189 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00850268 0.00858985 scale
101.229 93.1995 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
171.219 164.773 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
190.488 190.11 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
531.417 471.334 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
315.529 249.158 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00981805 0.00991871 scale
90.4844 71.3833 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113369 0.0114531 scale
69.6919 12.7537 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107302 0.0108402 scale
62.1777 8.05795 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.012675 0.012805 scale
51.7679 6.47325 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
126.857 17.9927 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0147271 0.0148781 scale
39.7201 4.00926 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
82.7758 9.52285 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00767512 0.00775381 scale
60.8277 7.20807 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00896261 0.0090545 scale
42.048 8.05014 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00731794 0.00739297 scale
30.5837 23.314 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
54.7278 45.1708 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
78.7855 203.694 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102189 0.0103237 scale
11.5384 40.777 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
62.1509 323.262 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00462827 0.00467572 scale
27.3255 151.185 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00713265 0.00720577 scale
19.0098 103.946 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00850268 0.00858985 scale
58.5086 112.231 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00713265 0.00720577 scale
120.306 110.45 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
189.38 116.43 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00896261 0.0090545 scale
104.095 62.5954 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
322.875 125.283 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0140763 0.0142207 scale
64.4031 22.4877 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0080164 0.00809859 scale
98.7887 18.0241 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
195.537 58.8152 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
145.838 48.3817 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
216.601 62.5467 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
371.815 106.409 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
270.891 33.5245 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
65.3745 8.94824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
50.5304 9.66268 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00731794 0.00739297 scale
50.6222 10.7453 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
148.466 40.0922 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
32.2632 112.748 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
39.4041 212.165 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00731794 0.00739297 scale
18.1281 98.9061 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
37.7101 200.802 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
56.1169 221.584 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
36.6983 135.682 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
64.4171 168.083 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109769 0.0110895 scale
44.3895 87.0286 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00694241 0.00701359 scale
100.576 131.636 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
113.847 149.223 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109769 0.0110895 scale
59.821 76.9425 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
278.372 363.362 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00834374 0.00842928 scale
74.4235 111.642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00784762 0.00792808 scale
86.4046 117.229 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00818171 0.00826559 scale
83.8823 111.552 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
332.483 360.928 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
453.432 519.074 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
136.286 167.84 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
107.644 135.981 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
373.553 481.774 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00911076 0.00920417 scale
63.2384 87.6363 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
117.579 221.631 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00818171 0.00826559 scale
49.3675 113.47 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
94.2041 213.1 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
47.2804 106.575 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
165.106 302.598 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
37.1683 94.6897 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0086587 0.00874748 scale
31.4169 58.4054 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
87.2337 98.9456 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
110.61 72.8004 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00490902 0.00495935 scale
169.111 42.0297 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00327268 0.00330624 scale
257.938 70.4971 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0160328 0.0161972 scale
52.2629 13.7191 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
132.582 27.982 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0426706 0.043108 scale
18.1127 3.15162 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00633752 0.0064025 scale
139.501 44.1624 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00940006 0.00949644 scale
95.894 32.7238 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112182 0.0113332 scale
80.6396 28.083 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102189 0.0103237 scale
58.1312 5.82736 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00542713 0.00548277 scale
105.606 10.8303 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
137.124 14.4618 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
180.24 28.1728 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
199.643 38.7722 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00881197 0.00890231 scale
93.7577 21.9022 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
509.655 128.805 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
135.631 27.2616 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112182 0.0113332 scale
68.7321 11.9807 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00954143 0.00963925 scale
79.5835 14.0747 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
202.607 42.8149 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112182 0.0113332 scale
61.6873 9.06363 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
85.5809 9.37045 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00365897 0.00369648 scale
135.776 16.6104 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
102.313 14.5459 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
41.514 145.158 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195678 0.0197684 scale
5.51161 25.2145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00713265 0.00720577 scale
16.0235 84.2699 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106047 0.0107134 scale
12.1625 65.9873 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
23.4956 109.906 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
220.925 185.017 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
325.764 166.903 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
549.066 356.46 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00834374 0.00842928 scale
105.067 74.3598 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
174.948 148.276 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00633752 0.0064025 scale
142.352 50.624 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00749866 0.00757554 scale
117.122 37.4323 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102189 0.0103237 scale
85.0205 27.9434 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
298.787 78.3471 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00818171 0.00826559 scale
92.9452 15.7557 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
95.3761 10.9247 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
74.6116 9.9025 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0201077 0.0203139 scale
19.0091 15.9408 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0135925 0.0137318 scale
23.6042 20.7642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
36.6326 36.8755 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
52.9664 44.3488 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
44.5017 23.2954 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100871 0.0101905 scale
10.332 51.7138 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0477632 0.0482529 scale
2.22263 11.5075 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0173174 0.017495 scale
7.85568 42.1973 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0040082 0.0040493 scale
133.678 237.034 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
130.75 156.293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
456.592 536.556 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107302 0.0108402 scale
80.5064 73.7605 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00911076 0.00920417 scale
95.1688 82.8211 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
215.891 126.644 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
119.575 21.5048 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
28.2744 153.262 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00633752 0.0064025 scale
21.0619 113.389 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
28.3234 132.716 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130907 0.0132249 scale
14.1635 59.6297 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
33.5581 136.326 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107302 0.0108402 scale
47.2852 88.8349 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00713265 0.00720577 scale
77.8253 128.23 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0086587 0.00874748 scale
101.291 87.7556 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
200.522 179.768 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00940006 0.00949644 scale
42.6529 98.7538 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00566845 0.00572657 scale
50.3471 156.268 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00633752 0.0064025 scale
22.8307 106.816 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0158649 0.0160276 scale
6.56984 33.5859 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121354 0.0122599 scale
9.60081 39.2599 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00674681 0.00681598 scale
18.4117 69.8535 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00767512 0.00775381 scale
22.8114 68.3341 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
59.8246 118.975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612263 0.0061854 scale
73.9045 98.0745 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589991 0.0059604 scale
152.76 53.129 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00954143 0.00963925 scale
93.9189 32.2006 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00283423 0.00286328 scale
319.996 114.652 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00767512 0.00775381 scale
89.8266 14.4161 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00881197 0.00890231 scale
85.2829 20.4857 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
152.658 29.1833 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00654536 0.00661247 scale
102.799 20.3812 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102189 0.0103237 scale
65.449 14.2594 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113369 0.0114531 scale
58.6615 13.3963 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00432935 0.00437374 scale
103.452 23.2959 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
280.486 58.3987 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00981805 0.00991871 scale
46.0346 6.46455 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00231414 0.00233786 scale
209.322 27.7219 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121354 0.0122599 scale
20.9255 12.2979 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106047 0.0107134 scale
10.2351 52.9821 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
78.9016 421.216 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.036443 0.0368167 scale
4.00735 19.8923 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120246 0.0121479 scale
11.3567 60.655 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113369 0.0114531 scale
13.0371 66.3251 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00995347 0.0100555 scale
75.1205 88.6856 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00163634 0.00165312 scale
459.042 533.592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0184406 0.0186297 scale
44.4101 44.6524 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106047 0.0107134 scale
25.1379 81.676 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00517457 0.00522762 scale
175.98 64.5246 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00850268 0.00858985 scale
34.1492 14.6138 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00713265 0.00720577 scale
17.319 50.6108 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0160328 0.0161972 scale
7.35118 26.2348 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{602, 286.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009J00017Q000`40O003h00OogooogooG7oo003o
OoooOomLOol00?mooomooeaoo`00ogooogooG7oo003oOoooOomLOol00?mooomooeaoo`00ogooogoo
G7oo003oOoooOomLOol00?mooomooeaoo`00ogooogooG7oo003oOoooOomLOol00?mooomooeaoo`00
ogooogooG7oo001lOol7003oOol[Ool6002WOol007]oo`03001oogoo00Eoo`03001oogoo0?moobIo
o`8000Ioo`03001oogoo0:Aoo`00NWoo00<007ooOol01goo00<007ooOol09Goo1000nWoo00<007oo
Ool01goo0P00Y7oo001iOol00`00Oomoo`09Ool00`00Oomoo`08Ool=000>Ool00`00Oomoo`02Ool2
003gOol00`00Oomoo`0:Ool00`00Oomoo`2QOol007Uoo`03001oogoo009oo`<000Eoo`03001oo`00
00L000eoo`P000Aoo`8000Moo`03001oogoo0?=oo`H000Qoo`03001oogoo0:5oo`00N7oo00@007oo
Oomoo`@00003Ool0000000D001eoo`D000Uoo`03001oogoo0?5oo`8000Eoo`03001oogoo00Ioo`03
001oogoo01aoo`<0085oo`00N7oo00<007ooOol00P0000=oo`0000002`006goo2@001Goo00<007oo
Ool0kgoo0P001goo0P001Woo7@0000=oo`00Ool00Woo0P00Ogoo001gOol01000Oomoogoo100000Io
o`00000007oo0002Ool3000017oo000000001Woo0P0017oo0P000goo0P0017oo00<007oo00000P00
0Woo1P000goo00<007ooOol0kWoo0`001Goo300000Aoo`00Oomoo`@000Eoo`@000=oo`03001oogoo
00=oo`P007ioo`00MWoo1@0000=oo`000000200000Aoo`00Oomoo`800004Ool000000003Ool00`00
Oomoo`040002Ool30002Ool400001Goo001oo`00Ool01P000Woo1@00kgoo0P0000=oo`00Ool00Woo
20000Woo0P000Woo00@007oo001oo`<000Aoo`0:001oo`00001oo`00Ool007oo0003Ool30002Ool0
0`00Oomoo`04001kOol007Aoo`800006Ool00000Ool007oo1`0000=oo`0000000P000Woo1P000goo
200000Aoo`000000009oo`@00005Ool00000001oo`070004Ool01000Ool00000k7oo0`0000=oo`00
00002P000goo00@007oo0000009oo`D000=oo`800005Ool007oo001oo`030003Ool01@00Ool007oo
00000goo0P000Woo1P00MGoo001aOol30003OolB0002Ool50002Ool00`00Ool0000400000goo001o
o`0500000goo0000000600000goo000000040005Ool00`00Oomoo`02003VOol800000goo001oo`02
Ool70002Ool30003Ool200000goo00000006Ool01000Oomoo`001goo0`0000=oo`00Ool00Woo0P00
27oo0P00Lgoo001`Ool00`00Oomoo`0300000goo0000000900001Goo001oo`00Ool00P000Woo00<0
07oo0000100000=oo`0000001P0000=oo`0000001@0000=oo`0000002@0000=oo`00Ool017oo00<0
07ooOol00Woo0P00hgoo2P0017oo100000=oo`0000000Woo0P0017oo0P0000=oo`00Ool01Woo1000
27oo0P0000=oo`0000000`002goo1000Kgoo001^Ool200000goo0000000200000goo000000090004
Ool01@00Ool00000Ool00`0000=oo`00Ool00Woo2@0000Aoo`00001ooa000003Ool007oo00Aoo`03
001oogoo00Aoo`03001oogoo0>1oo`@00003Ool00000008000Aoo`03001oogoo009oo`03001oo`00
00<000Moo`<001Aoo`<000ioo`03001oogoo00<006eoo`00K7oo0P000Woo00<007ooOol00Woo0P00
00=oo`00000017oo0P001Goo00T007oo001oo`00Ool007oo000017oo00<007oo00000Woo0P0000=o
o`0000001Woo00<007ooOol00`0000=oo`0000001P0017oo00<007ooOol01Woo0P00gWoo2@0000=o
o`0000000`002Goo00<007ooOol07Goo0P003goo00@007ooOomoo`D006Yoo`00JWoo0P000goo0P00
1Woo0`0017oo00<007ooOol017oo0P0017oo0P001Woo0P0000=oo`0000000P002Goo00L007ooOol0
07oo001oo`030002Ool20003Ool30009Ool3003HOol300000goo0000000400000goo00000002000;
Ool00`00Oomoo`0NOol2000>Ool02P00Oomoogoo001oo`00Ool007oo0P00J7oo001XOol20005Ool2
0006Ool400000goo000000020004Ool00`00Ool00004Ool20006Ool00`00Ool0000=Ool2000017oo
001oogoo20000Woo00D007oo001oo`0000]oo`800==oo`<000Eoo`04001oo`000006Ool20007Ool2
000aOol02@00Oomoogoo001oo`00Ool00003Ool3001UOol006Ioo`8000Moo`8000Ioo`800005Ool0
0000001oo`020003Ool00`00Ool00005Ool00`00Ool00004Ool00`00Oomoo`0@Ool90005Ool20002
Ool00`00Oomoo`0;Ool00`00Oomoo`3>Ool50006Ool00`00Oomoo`08Ool30003Ool00`00Oomoo`0b
Ool00`00Ool00002Ool00`00Ool00006Ool3001ROol006Eoo`P00003Ool00000008000Eoo`<0009o
o`<00003Ool007oo00<000Eoo`03001oogoo0080009oo`8001Aoo`8000Yoo`800003Ool007oo009o
o`8000Yoo`800<aoo`800004Ool007ooOol2000COol3000eOol200000goo00000002Ool00`00Ool0
00030004Ool00`00Oomoo`09Ool7001?Ool006=oo`<000=oo`<00003Ool0000000@000Aoo`8000Ao
o`H000Ioo`03001oogoo00=oo`8000=oo`<0015oo`03001oogoo00Qoo`03001oo`0000Aoo`8000ao
o`800<Qoo`80009oo`04001oogooOol2000IOol01000Ool00000<7oo1P0000Ioo`00Ool007oo0004
Ool20007Ool20007Ool2001=Ool005=oo`H000Uoo`03001oo`0000Aoo`03001oogoo00<00003Ool0
07oo0080009oo`8000Uoo`03001oogoo00Aoo`03001oogoo00Uoo`04001oogoo000AOol00`00Oomo
o`05Ool2000GOol00`00Oomoo`33Ool600000goo001oo`02000HOol4000hOol200001Goo001oogoo
00001Goo0P000goo0P002goo00<007ooOol0BWoo001@Ool30006Ool30004Ool200000goo001oo`03
Ool01000Oomoogoo1P0000=oo`0000000P002goo1P002goo00<007ooOol00Woo00<007ooOol03goo
0P0017oo00<007ooOol04Goo00<007ooOol017oo00<007ooOol0`7oo0P000Woo00@007ooOol0009o
o`03001oogoo01Uoo`8003Uoo`@0009oo`03001oogoo00Eoo`<000ioo`03001oogoo04Uoo`00CWoo
0P0037oo10000Woo00<007ooOol00goo00<007ooOol00Woo0P000goo0`007goo00D007ooOomoo`00
01=oo`@001=oo`03001oo`0000Ioo`800;ioo`8000Aoo`04001oogoo001JOol01P00Oomoo`00Ool0
00Aoo`80009oo`<000ioo`03001oogoo04Qoo`00C7oo0P003goo0P000goo00<007ooOol00goo00<0
07ooOol00Woo0`0000=oo`0000008Goo00@007oo000002]oo`03001oo`0000Qoo`03001oogoo0;Yo
o`03001oogoo00Aoo`<005Yoo`H000Aoo`@00005Ool007ooOol0000>Ool00`00Oomoo`17Ool004]o
o`03001oogoo00ioo`04001oogoo0002Ool00`00Oomoo`03Ool20002Ool20002Ool00`00Oomoo`0R
Ool00`00Oomoo`0[Ool30009Ool2002hOol200000goo0000001ROol01000Ool000001Goo1@0017oo
0P0037oo00<007ooOol0Agoo001:Ool00`00Oomoo`0=Ool20004Ool00`00Ool00007Ool200000goo
001oo`1?Ool2000:Ool20003Ool4002dOol20002Ool01@00Oomoo`00Ool00`00GWoo00<007ooOol0
1goo00<007oo00001Goo0`002goo00<007ooOol0AWoo001:Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool2000:Ool00`00Oomoo`1=Ool00`00Ool0000:Ool3000017oo001oogoo1000/Goo00<007ooOol0
0Woo00@007ooOomoo`80009oo`03001oogoo05=oo`<0011oo`03001oogoo00=oo`H000Uoo`03001o
ogoo04Ioo`00BGoo00<007ooOol037oo00@007ooOomoo`8000Aoo`03001oogoo00Qoo`03001oogoo
04ioo`8000Yoo`800003Ool007oo00/00:]oo`03001oogoo00=oo`04001oogooOol200000goo001o
o`1EOol00`00Ool00002000>Ool00`00Oomoo`02Ool2000017oo000007oo0P0027oo00<007ooOol0
AWoo0019Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOomoo`8000Qoo`03001oogoo
05ioo`03001oo`000080009oo`<000=oo`03001oogoo0:Moo`04001oogoo0003Ool40002Ool00`00
Oomoo`1EOol400000goo001oo`0<Ool00`00Oomoo`02Ool50002Ool20007Ool00`00Oomoo`16Ool0
04Qoo`03001oogoo00]oo`03001oogoo00<00004Ool000000003Ool00`00Oomoo`05Ool00`00Oomo
o`1NOol00`00Ool0000200000goo001oo`040003Ool00`00Oomoo`2TOol20002Ool4001QOol30000
0goo001oo`0;Ool00`00Oomoo`02Ool50002Ool50004Ool00`00Oomoo`16Ool004Qoo`03001oogoo
00Yoo`07001oogoo001oo`00Ool0100017oo00<007ooOol017oo00<007ooOol0Ggoo0`0000=oo`00
Ool01P000goo00<007ooOol0XGoo1P0000Aoo`000000061oo`D000eoo`03001oogoo009oo`03001o
o`0000800003Ool007oo00800003Ool0000000=oo`03001oogoo04Ioo`00B7oo00<007ooOol02Goo
00<007ooOol0100000=oo`0000000P0017oo1`0017oo0P00G7oo00@007oo0000009oo`L0009oo`03
001oogoo0:1oo`03001oogoo00P005moo`80009oo`03001oo`0000aoo`03001oogoo009oo`D00003
Ool000000080009oo`80009oo`03001oogoo04Ioo`00Agoo00<007ooOol02Goo00<007oo00001`00
0Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0Fgoo100000=oo`0000001`0000=oo`00
Ool0X7oo00L007ooOol007oo001oo`050002Ool3001JOol20002Ool00`00Ool0000<Ool00`00Oomo
o`07Ool00`00Ool000020002Ool20002Ool00`00Oomoo`16Ool004Moo`03001oogoo00Qoo`03001o
ogoo00@00003Ool0000000<000Ioo`03001oogoo06Moo`h00:1oo`07001oogooOol007oo00000Woo
0P000goo00D007ooOomoo`0005Qoo`03001oo`0000=oo`8000aoo`03001oogoo00Yoo`800004Ool0
0000Ool20019Ool004Moo`03001oogoo00Moo`03001oogoo00T000Qoo`03001oogoo06Qoo`<0009o
o`P009moo`03001oogoo009oo`03001oo`0000800003Ool007oo00=oo`04001oogoo001IOol6000>
Ool00`00Oomoo`0;Ool400000goo001oo`18Ool004Ioo`03001oogoo00Moo`04001oogooOol90008
Ool00`00Oomoo`1ZOol;002NOol00`00Oomoo`03Ool60005Ool3001JOol200000goo0000000?Ool0
0`00Oomoo`0<Ool400000goo00000017Ool004Ioo`03001oogoo00Ioo`D00003Ool0000000@000Yo
o`03001oogoo06]oo`P00003Ool0000009aoo`03001oo`0000Ioo`8006Ioo`03001oogoo011oo`03
001oogoo00]oo`04001oogoo0003Ool00`00Oomoo`14Ool004Ioo`03001oogoo00Eoo`03001oogoo
00=oo`H000]oo`03001oogoo06eoo`@00006Ool00000001oo`00VWoo00D007oo001oo`00085oo`03
001oogoo00Yoo`H0009oo`03001oogoo04=oo`00AWoo00<007ooOol017oo0P001goo0P003Goo00<0
07ooOol0Kgoo1@0000Aoo`00Ool009Qoo`04001oo`00Ool30021Ool30008Ool20002Ool40002Ool0
0`00Oomoo`12Ool004Ioo`03001oogoo00=oo`8000Uoo`03001oogoo00]oo`03001oogoo071oo`<0
00=oo`03001oo`0009Eoo`8000=oo`03001oo`00008007moo`03001oogoo008000Eoo`8000Aoo`<0
00Aoo`03001oogoo045oo`00AWoo00<007ooOol00Woo00<007oo000017oo100000=oo`00Ool037oo
00<007ooOol0LGoo00@007ooOomoo`800003Ool007oo09=oo`03001oogoo009oo`<00004Ool007oo
001nOol01000Oomoogoo1P001goo00<007ooOol017oo00<007ooOol0@7oo0017Ool01P00Oomoo`00
Ool000Eoo`80009oo`8000eoo`03001oogoo079oo`03001oo`000080009oo`03001oogoo091oo`03
001oogoo00=oo`04001oo`000003Ool00`00Oomoo`1kOol01@00Oomoogoo000057oo00<007ooOol0
?goo0017Ool00`00Ool00002Ool00`00Oomoo`02Ool30002Ool00`00Ool0000<Ool00`00Oomoo`1b
Ool50003Ool00`00Oomoo`2>Ool00`00Oomoo`05Ool6001nOol200000goo001oo`0>Ool40003Ool0
0`00Oomoo`0nOol004Moo`03001oo`0000=oo`05001oogoo001oo`03000017oo001oo`002goo00<0
07ooOol0MGoo0P001Goo00<007ooOol0S7oo00<007ooOol00Woo0P0017oo0P00PWoo00<007ooOol0
3Woo00D007ooOomoo`0000=oo`03001oogoo03eoo`00B7oo00<007ooOol00Woo00@007ooOomoo`<0
0004Ool00000000<Ool00`00Oomoo`1hOol00`00Oomoo`02Ool00`00Oomoo`2:Ool00`00Oomoo`02
Ool00`00Oomoo`02000017oo00000000Tgoo00D007ooOomoo`0000Aoo`03001oogoo03aoo`00Agoo
0P001Goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`1gOol30004Ool00`00
Oomoo`29Ool01@00Oomoogoo00001Goo00<007oo0000U7oo0P0000=oo`00Ool01Goo00<007ooOol0
>goo0016Ool00`00Ool00005Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`1iOol30004
Ool00`00Oomoo`27Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol0UGoo0`001Woo00<0
07ooOol0>Woo0015Ool01000Oomoo`001Woo00<007ooOol00goo0P002goo00<007ooOol0Ngoo00<0
07oo00000goo00<007ooOol0QWoo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Oomoo`2E
Ool00`00Ool000020005Ool00`00Oomoo`0iOol004Eoo`05001oogooOol00006Ool5000<Ool00`00
Oomoo`1jOol50004Ool00`00Oomoo`04Ool;001eOol00`00Oomoo`03Ool00`00Ool00002Ool01000
Oomoo`00Ugoo0`000Woo0P0017oo00<007ooOol0>7oo0014Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00`00Oomoo`1hOol20002Ool01000Ool000000goo00<007oo000010002goo0`00LGoo00<007oo
Ool01Goo00<007oo00000P0000=oo`00Ool0Ugoo0`000goo00<007ooOol00Woo00<007ooOol0>7oo
0014Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`1hOol00`00Oomoo`03Ool40003Ool0
0`00Oomoo`0AOol2001_Ool00`00Oomoo`05Ool20003Ool2002GOol00`00Oomoo`03Ool00`00Ool0
0004Ool00`00Oomoo`0gOol004=oo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo07Uoo`03
001oogoo00=oo`<00006Ool00000001oo`0057oo0P00K7oo00<007ooOol027oo0`00VGoo00<007oo
Ool00Woo00@007oo000000Aoo`03001oogoo03Moo`00@Woo00<007ooOol027oo0P003goo00<007oo
Ool0NGoo00<007ooOol01goo0P0017oo00<007ooOol04goo00<007ooOol0J7oo00<007ooOol0YWoo
00@007ooOomoo`800003Ool007oo00Aoo`03001oogoo03Ioo`00@Goo00<007ooOol02goo0P002goo
0P00O7oo00<007ooOol01Woo00@007ooOol000=oo`03001oogoo01Aoo`03001oogoo06Ioo`03001o
ogoo0:Moo`03001oogoo00@000Moo`03001oogoo03Eoo`00@Goo00<007ooOol03Goo0`001Woo0P00
OGoo00<007ooOol01Woo00D007ooOomoo`0000Aoo`03001oogoo01Aoo`8006Eoo`03001oogoo09ao
o`<000Yoo`800004Ool000000008Ool00`00Oomoo`0dOol0041oo`03001oogoo015oo`H007moo`03
001oogoo00Eoo`03001oogoo00=oo`05001oogooOol0000HOol00`00Oomoo`1QOol00`00Oomoo`2M
Ool00`00Ool0000<Ool20002Ool20007Ool00`00Oomoo`0cOol0041oo`03001oogoo09Ioo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01Ioo`03001oogoo061oo`03001o
ogoo09ioo`03001oogoo00ioo`04001oogoo0007Ool00`00Oomoo`0bOol003moo`03001oogoo00Io
o`<008ioo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo01Ioo`03001o
ogoo05ioo`03001oogoo00Ioo`<00:Qoo`@000Ioo`03001oogoo039oo`00?Woo00<007ooOol01goo
00@007ooOol008eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo01Mo
o`03001oogoo05eoo`03001oogoo00Ioo`800:Yoo`@000Ioo`03001oogoo035oo`00?Woo00<007oo
Ool01Woo00D007ooOomoo`0008eoo`05001oogooOol00008Ool00`00Oomoo`05Ool00`00Oomoo`0G
Ool00`00Oomoo`1KOol00`00Oomoo`2eOol20007Ool00`00Oomoo`0`Ool003eoo`03001oogoo00Qo
o`04001oo`00002>Ool00`00Ool00009Ool00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`1J
Ool00`00Oomoo`2fOol00`00Oomoo`06Ool00`00Oomoo`0`Ool003eoo`03001oogoo00Uoo`03001o
ogoo08moo`03001oogoo00Moo`03001oogoo00<000Aoo`03001oogoo01Moo`03001oogoo05Uoo`03
001oogoo0<1oo`03001oogoo02moo`00?Goo00<007ooOol0Vgoo0P001Woo0P000goo00<007oo0000
1Goo00<007ooOol05Woo00<007ooOol0F7oo00<007ooOol0`Goo00<007ooOol0;goo000lOol00`00
Oomoo`2KOol00`00Oomoo`020002Ool20005Ool50003Ool00`00Oomoo`0GOol00`00Oomoo`1GOol0
0`00Oomoo`0]Ool3002BOol00`00Oomoo`0^Ool003]oo`03001oogoo09aoo`03001oogoo009oo`80
00Qoo`<00005Ool007ooOol0000JOol00`00Oomoo`1EOol00`00Oomoo`0/Ool20003Ool00`00Oomo
o`27Ool30006Ool00`00Oomoo`0]Ool003]oo`03001oogoo09]oo`03001oogoo00eoo`<00003Ool0
07oo009oo`03001oogoo01Moo`03001oogoo05Aoo`03001oogoo02eoo`03001oogoo009oo`03001o
ogoo08=oo`H00003Ool007oo00Aoo`03001oogoo02eoo`00>Woo00<007ooOol0W7oo00<007ooOol0
3Goo00<007oo00000`000Woo00<007ooOol067oo00<007ooOol0Dgoo00<007ooOol0;7oo00<007oo
Ool017oo00<007ooOol0PWoo00<007oo00000P0000=oo`0000001Woo00<007ooOol0;7oo000jOol0
0`00Oomoo`2LOol00`00Oomoo`0=Ool70002Ool00`00Oomoo`0GOol00`00Oomoo`1BOol00`00Oomo
o`0]Ool00`00Oomoo`04Ool00`00Oomoo`21Ool00`00Oomoo`0300000goo001oo`06Ool00`00Oomo
o`0/Ool003Uoo`03001oogoo009oo`<009Moo`03001oogoo00eoo`04001oogoo0002Ool20002Ool0
0`00Oomoo`0GOol00`00Oomoo`1BOol00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`22Ool0
1000Oomoogoo0P002Goo00<007ooOol0:goo000iOol01P00Oomoogoo001oo`@009Eoo`03001oogoo
00eoo`03001oogoo00800003Ool0000000=oo`03001oogoo01Moo`03001oogoo051oo`03001oogoo
02moo`80009oo`8008Eoo`04001oo`000003Ool30006Ool00`00Oomoo`0ZOol003Qoo`03001oogoo
009oo`800003Ool000000080031oo`<0061oo`03001oogoo00ioo`05001oogoo001oo`030004Ool0
0`00Oomoo`0FOol00`00Oomoo`1?Ool00`00Oomoo`0bOol20028Ool00`00Oomoo`02Ool01000Ool0
00001Woo00<007ooOol0:Woo000hOol01000Oomoogoo0P000goo0P0000=oo`00Ool0;Woo00@007oo
Ool005moo`03001oogoo00moo`03001oo`0000<000Eoo`03001oogoo01Ioo`03001oogoo04moo`03
001oogoo00Ioo`03001oogoo03Moo`@007eoo`L000=oo`03001oogoo02Yoo`00>7oo00<007ooOol0
1P0000Aoo`00Ool002moo`03001oo`00061oo`03001oogoo00moo`800004Ool00000Ool20003Ool0
0`00Oomoo`0FOol00`00Oomoo`1>Ool00`00Oomoo`05Ool4000gOol00`00Oomoo`02Ool2001lOol2
000017oo0000000017oo00<007ooOol0:Goo000gOol01P00Oomoo`00Ool000Aoo`800003Ool007oo
02moo`03001oogoo05moo`03001oogoo015oo`04001oogooOol500000goo001oo`0GOol00`00Oomo
o`1=Ool00`00Oomoo`04Ool00`00Oomoo`02000fOol00`00Oomoo`05Ool00`00Oomoo`1hOol20000
0goo000000040002Ool00`00Oomoo`0YOol003Moo`05001oogoo001oo`020003Ool200000goo001o
o`2AOol00`00Oomoo`0EOol20003Ool2000HOol00`00Oomoo`1=Ool00`00Oomoo`04Ool00`00Oomo
o`02000eOol00`00Oomoo`07Ool00`00Oomoo`0@Ool2001VOol80003Ool00`00Oomoo`0XOol003Mo
o`03001oo`0000=oo`80009oo`800003Ool007oo091oo`03001oogoo01Eoo`<000Aoo`03001oogoo
01Ioo`03001oogoo04aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo
00Moo`03001oogoo00moo`03001oo`0006Eoo`H00004Ool000000002Ool00`00Oomoo`0XOol003Io
o`04001oogoo0003Ool01@00Ool00000Ool00P00TWoo00<007ooOol05Goo00<007oo00000`000Woo
00<007ooOol05Goo00<007ooOol0C7oo00<007ooOol017oo0`000Woo00<007ooOol0<goo00<007oo
Ool01goo00<007ooOol03goo0`00IGoo1P0000Aoo`000000009oo`03001oogoo02Qoo`00=Woo00@0
07ooOol000Aoo`800003Ool0000009=oo`03001oogoo01Aoo`04001oogoo0002Ool200000goo0000
000FOol00`00Oomoo`1;Ool00`00Oomoo`05Ool5000fOol00`00Oomoo`07Ool00`00Oomoo`1hOol9
0003Ool00`00Oomoo`0WOol003Ioo`04001oogoo0006Ool00`00Ool0002COol00`00Oomoo`0DOol0
1000Ool000000goo00@007ooOol001Ioo`03001oogoo04]oo`/003Qoo`03001oogoo00Moo`03001o
ogoo07Qoo`L00003Ool007oo009oo`03001oogoo02Moo`00=Goo00D007ooOomoo`0000Qoo`03001o
ogoo095oo`03001oogoo01Aoo`03001oogoo00<00005Ool007ooOol0000FOol00`00Oomoo`18Ool4
0004Ool00`00Oomoo`06000fOol00`00Oomoo`05Ool00`00Oomoo`1kOol300000goo00000005Ool0
0`00Oomoo`0VOol003Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo095oo`03001oogoo
01Aoo`03001oogoo00@000=oo`03001oogoo01Aoo`03001oogoo04Ioo`80009oo`03001oogoo009o
o`04001oogooOol20002Ool01000Ool00000=7oo0P001Goo00<007ooOol0O7oo0`0000=oo`000000
1Goo00<007ooOol09Woo000dOol00`00Oomoo`03Ool01000Oomoogoo1000U7oo00<007ooOol057oo
00<007ooOol00Woo00L007ooOomoo`00Ool0000EOol00`00Oomoo`15Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOomoo`8003Aoo`D0085oo`<000Moo`03001oogoo
02Eoo`00=7oo00<007ooOol017oo1P00UGoo00<007ooOol05Goo00<007ooOol01Goo00<007oo0000
5Goo00<007ooOol0A7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo0P0000=oo`00
Ool017oo0P00`goo00<007ooOol097oo000dOol00`00Oomoo`08Ool00`00Oomoo`2DOol00`00Oomo
o`0EOol20005Ool01000Oomoo`005Goo00<007ooOol0@Woo0P001Goo00@007ooOomoo`H00005Ool0
07ooOol00007Ool00`00Oomoo`30Ool00`00Oomoo`0TOol003=oo`03001oogoo0:1oo`03001oogoo
01Moo`800003Ool0000000Aoo`03001oogoo019oo`03001oogoo045oo`03001oogoo00Eoo`@000=o
o`03001oogoo00D000Qoo`03001oogoo0;Ioo`03001oogoo00Ioo`03001oogoo02Aoo`00<goo00<0
07ooOol0XGoo00<007ooOol067oo00<007oo000017oo00<007ooOol04Woo00<007ooOol0@7oo00<0
07ooOol01Goo0P001Woo10000Woo0`001goo00<007ooOol0]Goo0`0027oo00<007ooOol08goo000c
Ool00`00Oomoo`05Ool2002JOol00`00Oomoo`0GOol01000Oomoo`0017oo00<007ooOol04Woo00<0
07ooOol0?goo00<007ooOol01Woo00@007ooOomoo`X000=oo`8000Ioo`03001oogoo0;=oo`04001o
o`000008Ool00`00Oomoo`0SOol0039oo`03001oogoo00Eoo`04001oogoo002IOol00`00Oomoo`0H
Ool00`00Ool00004Ool00`00Oomoo`0BOol00`00Oomoo`0oOol00`00Oomoo`04Ool300000goo0000
0004Ool00`00Oomoo`040004Ool00`00Oomoo`04Ool00`00Oomoo`2cOol20009Ool00`00Oomoo`0S
Ool0039oo``009Uoo`03001oogoo01Uoo`03001oogoo00=oo`03001oogoo015oo`03001oogoo03io
o`8000Ioo`03001oo`00008000Ioo`@000=oo`8000=oo`03001oogoo00Aoo`03001oogoo0;9oo`03
001oogoo00Qoo`03001oogoo02=oo`00;Woo1@0017oo2@00Ugoo00<007ooOol067oo0P001Woo00<0
07ooOol047oo00<007ooOol0?Goo00<007ooOol01Goo00@007ooOol000Qoo`<000Ioo`800003Ool0
07oo00Eoo`800;ioo`03001oogoo02=oo`00;Goo00D007ooOomoo`0000Aoo`04001oogoo0003Ool2
00000goo0000002FOol00`00Oomoo`0FOol01000Oomoo`001Goo00<007ooOol047oo00<007ooOol0
?Goo00<007ooOol017oo00<007ooOol00P001Goo0`000goo0P001Woo00<007oo00001goo00<007oo
Ool0^goo00<007ooOol08goo000/Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0P0000=oo`00
00000P000Woo0P00U7oo00<007ooOol05Goo00D007ooOomoo`0000Eoo`03001oogoo00moo`03001o
ogoo03eoo`03001oogoo00Aoo`03001oogoo008000Eoo`03001oogoo00Ioo`03001oogoo00=oo`04
001oogoo0006Ool00`00Oomoo`2lOol00`00Oomoo`0ROol002Yoo`8000Eoo`03001oogoo00P000Ao
o`05001oogooOol0002COol00`00Oomoo`0EOol01@00Oomoogoo00001Woo00<007ooOol03Woo00<0
07ooOol0?Goo00<007ooOol017oo00D007oo001oo`0000Aoo`04001oogooOol600000goo001oo`04
Ool01000Oomoo`001Woo00<007ooOol0^goo00<007ooOol08Woo000YOol00`00Oomoo`05Ool40002
Ool01@00Oomoo`00Ool00P000goo00D007ooOomoo`0009=oo`03001oogoo019oo`@00004Ool00000
0005Ool00`00Oomoo`0>Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Ool00002Ool01@00Oomo
ogoo00000Woo0P000Woo00L007ooOomoo`00Ool00005Ool01000Oomoo`001Goo00<007ooOol0^goo
00<007ooOol08Woo000XOol00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`0400001Goo001o
ogoo000017oo00<007ooOol0T7oo00<007ooOol04Woo00@007ooOomoo`D000Aoo`03001oogoo00eo
o`03001oogoo03eoo`03001oogoo00Aoo`05001oo`00Ool00004Ool01000Ool007oo1@000goo0P00
1Woo00<007oo00001Goo00<007ooOol0_7oo00<007ooOol08Goo000WOol00`00Oomoo`06Ool01@00
Oomoo`00Ool02@0000Aoo`00Ool000Eoo`03001oogoo091oo`03001oogoo011oo`03001oogoo009o
o`H000=oo`03001oogoo00eoo`03001oogoo03eoo`03001oogoo00=oo`03001oo`00009oo`08001o
ogooOol007oo001oo`P0009oo`8000Eoo`04001oogoo0004Ool00`00Oomoo`0QOol2002IOol00`00
Oomoo`0QOol002Ioo`03001oogoo00Moo`04001oo`00Ool:00001Goo001oogoo00001Goo00<007oo
Ool0Sgoo00<007ooOol04Goo00@007ooOomoo`800004Ool007oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`0nOol00`00Oomoo`03Ool00`00Ool00002Ool01000Oomoogoo3@000Woo0P001Goo00<007oo
00001Goo00<007ooOol087oo0`00VGoo00<007ooOol087oo000UOol00`00Oomoo`07Ool200000goo
001oo`0:00001Goo001oogoo00001Woo00<007ooOol0Sgoo00<007ooOol047oo0P0000Eoo`00001o
o`00009oo`05001oogooOol0000>Ool00`00Oomoo`0nOol00`00Oomoo`03Ool20003OolB00000goo
0000000600000goo001oo`04Ool00`00Oomoo`0QOol00`00Oomoo`2HOol00`00Oomoo`0POol002Ao
o`03001oogoo00Qoo`800003Ool0000000800005Ool00000001oo`050002Ool00`00Oomoo`05Ool0
0`00Oomoo`2>Ool00`00Oomoo`0BOol20005Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomo
o`0nOol00`00Oomoo`03Ool00`00Ool00002Ool80002Ool60002Ool300000goo001oo`04Ool20005
Ool00`00Oomoo`2lOol00`00Oomoo`0POol002=oo`03001oogoo00Qoo`04001oo`00Ool200000goo
001oo`090002Ool20007Ool00`00Oomoo`2>Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Ool000040003OolB0005
Ool30004Ool00`00Oomoo`2lOol00`00Oomoo`0POol002=oo`03001oogoo00Qoo`04001oo`00Ool2
00000goo001oo`08000017oo001oo`0027oo00<007ooOol0Sgoo00<007ooOol04Woo0P000Woo0P00
17oo00<007ooOol02Goo00<007ooOol0?goo00<007ooOol00goo00<007oo00000Woo00@007ooOomo
o`<0009oo`03001oo`0000P00003Ool0000000Eoo`800003Ool007oo009oo`03001oogoo0;aoo`03
001oogoo021oo`008Woo00<007ooOol02Goo0P000Woo0P000Woo00<007oo00002@002Woo00<007oo
Ool0Sgoo00<007ooOol04goo0P001Woo00<007ooOol027oo00<007ooOol0@7oo00<007ooOol00goo
0`0000Aoo`00001oo`800005Ool00000001oo`0200000goo00000007000017oo000000000goo0P00
0Woo00@007ooOol00;ioo`03001oogoo021oo`008Woo00<007ooOol02Goo0P000Woo0P000Woo0P00
0Woo1`0037oo00<007ooOol0Sgoo00<007ooOol06Woo00<007ooOol027oo00<007ooOol0@7oo00<0
07ooOol00goo00<007oo00000P0000=oo`00Ool00Woo3@0000=oo`00Ool00P0000=oo`0000000Woo
0P000goo00<007oo0000_goo00<007ooOol07goo000QOol00`00Oomoo`0:Ool20002Ool=00000goo
001oo`0;Ool00`00Oomoo`2?Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`11Ool00`00
Oomoo`02Ool200000goo001oo`020004Ool200000goo0000000:0002Ool300000goo001oo`020003
Ool00`00Ool0002oOol00`00Oomoo`0OOol0025oo`03001oogoo00Yoo`8000=oo`d000ioo`03001o
ogoo08moo`03001oogoo01Yoo`03001oogoo00Eoo`03001oogoo049oo`03001oogoo009oo`06001o
o`00001oo`0017oo100000=oo`00Ool02@0000Aoo`00Oomoo`<00003Ool0000000Aoo`800;moo`03
001oogoo01moo`008Goo00<007ooOol02goo00@007ooOomoo``000moo`03001oogoo091oo`03001o
ogoo01Uoo`03001oogoo00Aoo`03001oogoo04=oo`05001oogooOol00002Ool40003Ool00`00Oomo
o`0200000goo00000002Ool90003Ool00`00Ool000020004Ool2002oOol00`00Oomoo`0OOol0021o
o`03001oogoo00aoo`04001oogooOol700000goo00000002000?Ool00`00Oomoo`2AOol2000IOol0
0`00Oomoo`02Ool20017Ool00`00Ool00002Ool50003Ool01000Oomoogoo3P0000Eoo`00Oomoo`00
009oo`8000Aoo`800;moo`03001oogoo01moo`0087oo00<007ooOol02goo00<007oo00000Woo3000
3goo00<007ooOol0Tgoo00<007ooOol03Goo0P001goo00<007ooOol00P00BGoo00<007oo00000Woo
00<007oo00000P000Woo00<007ooOol0400000=oo`00Ool00Woo100017oo0P00_goo00<007ooOol0
7goo000OOol00`00Oomoo`0<Ool00`00Ool00002Ool<000?Ool00`00Oomoo`2DOol2000>Ool00`00
Oomoo`05Ool3001;Ool20002Ool00`00Oomoo`0300000goo001oo`020003Ool500000goo00000006
000017oo001oogoo0`0000=oo`00Ool00Woo00<007ooOol0_goo00<007ooOol07Woo000OOol00`00
Oomoo`0<Ool00`00Oomoo`0>000@Ool00`00Oomoo`2EOol2000BOol3001=Ool200001Woo001oogoo
001oo`<00003Ool007oo00=oo`04001oogooOol;000017oo001oogoo0P0000=oo`0000000goo00<0
07ooOol0/goo0P002Woo00<007ooOol07Woo000OOol00`00Oomoo`0<Ool01000Oomoogoo3@0047oo
00<007ooOol0Ugoo0P003Woo0P000Woo00<007ooOol0Bgoo00@007ooOol0009oo`03001oo`000080
0003Ool007oo00=oo`03001oo`0000P00004Ool000000002Ool01@00Ool00000Ool00P000goo00<0
07ooOol0/Woo00@007ooOol000Uoo`03001oogoo01ioo`007goo00<007ooOol037oo00@007ooOomo
o``0015oo`03001oogoo09Uoo`H000Eoo`<000Aoo`03001oogoo04]oo`800006Ool007ooOol007oo
100017oo00@007oo001oo``0009oo`800003Ool007oo008000=oo`03001oogoo0;5oo`05001oogoo
Ool00009Ool00`00Oomoo`0NOol001moo`03001oogoo00aoo`04001oogooOol<000AOol00`00Oomo
o`2OOol50007Ool00`00Oomoo`1:Ool01`00Ool007oo001oo`00009oo`<000Eoo`80009oo`03001o
ogoo00D00004Ool007oo0002Ool200000goo0000000300000goo0000002cOol01@00Oomoogoo0000
2Goo00<007ooOol07Woo000OOol00`00Oomoo`0<Ool01000Oomoogoo1@0000Aoo`00001oo`<0015o
o`03001oogoo0:aoo`03001oogoo04Uoo`04001oogoo0002Ool00`00Oomoo`0200000goo001oo`02
Ool00`00Ool00002Ool600001Goo001oo`00Ool01@0000Aoo`00Oomoo`800003Ool007oo0;=oo`80
0003Ool007oo00Uoo`03001oogoo01ioo`007Woo00<007ooOol03Goo00H007ooOomoo`00Ool40000
17oo000007oo0P004Goo00<007ooOol0[7oo00<007ooOol0BGoo00@007ooOol0009oo`03001oogoo
00800003Ool00000009oo`/00003Ool0000000=oo`800004Ool007ooOol5002fOol2000;Ool00`00
Oomoo`0NOol001ioo`03001oogoo00eoo`06001oogooOol007oo2P004Woo00<007ooOol0Zgoo00<0
07ooOol0BGoo00<007ooOol00P0000Aoo`00Oomoo`80009ooa000003Ool000000080009oo`05001o
ogoo001oo`03002fOol2000;Ool00`00Oomoo`0NOol001ioo`03001oogoo00eoo`03001oogoo009o
o`/0019oo`03001oogoo0:]oo`03001oogoo04Uoo`05001oogoo001oo`020002Ool20004OolD0000
17oo001oo`000Woo0P00]goo0P002goo00<007ooOol07Woo000NOol00`00Oomoo`0=Ool00`00Oomo
o`02Ool6000017oo000000004goo00<007ooOol0Zgoo00<007ooOol0BGoo00@007ooOol0009oo`03
001oogoo008000Eooa<00003Ool007oo00D00<Aoo`03001oogoo01ioo`007Woo00<007ooOol03Goo
00<007ooOol00Woo00<007oo00001P004goo00<007ooOol0[7oo00<007ooOol0BGoo00@007ooOol0
009oo`800004Ool007oo0003Ool300000goo0000000600000goo001oo`0500000goo000000020000
0goo00000034Ool00`00Oomoo`0NOol001moo`03001oogoo00aoo`03001oogoo009oo`04001oo`00
Ool30002Ool00`00Oomoo`0@Ool00`00Oomoo`2/Ool00`00Oomoo`19Ool01000Oomoo`000goo0`00
00Aoo`00Oomoo`h000=oo`H00004Ool00000Ool20035Ool00`00Oomoo`0MOol001moo`03001oogoo
00aoo`05001oogooOol00002Ool40003Ool00`00Oomoo`0@Ool00`00Oomoo`2/Ool00`00Oomoo`19
Ool01@00Oomoogoo00000Woo00D007oo001oo`00009oo`03001oo`0000/000=oo`03001oo`000080
0007Ool00000Ool007oo00004Woo0P00/Goo00<007ooOol07Goo000OOol00`00Oomoo`0<Ool01@00
Oomoogoo00000goo0P0017oo00<007ooOol047oo00<007ooOol0[7oo00<007ooOol0BGoo00D007oo
Oomoo`0000=oo`H0009oo`H00003Ool007oo00<0009oo`04001oo`00Ool40002Ool00`00Ool0000B
Ool3002`Ool00`00Oomoo`0MOol001moo`03001oogoo00aoo`05001oogooOol00003Ool20003Ool0
0`00Oomoo`0AOol00`00Oomoo`2/Ool00`00Oomoo`19Ool01@00Oomoogoo00000goo0`0000=oo`00
00000Woo2P0000Aoo`000000009oo`03001oo`0000<0009oo`03001oo`00019oo`04001oogoo002_
Ool00`00Oomoo`0MOol001moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo011oo`03001oogoo0:eoo`03001oogoo04Uoo`03001oogoo009oo`04001oogooOol20002Ool?
0004Ool300001Goo001oogoo00000Woo00<007ooOol03goo00D007ooOomoo`000:moo`03001oogoo
01eoo`0087oo00<007ooOol02goo00<007ooOol00Woo1P0000=oo`00Ool04Woo00<007ooOol0[Goo
00<007ooOol0BWoo00D007ooOomoo`0000=oo`04001oo`00Ool200000goo00000007000017oo0000
07oo20000Woo00<007oo00004goo00@007ooOol00:moo`03001oogoo01eoo`0087oo00<007ooOol0
2goo00<007ooOol017oo1@0057oo00<007ooOol0[Goo00<007ooOol0BWoo00<007ooOol00Woo00<0
07ooOol0100000=oo`0000000Woo2`000Woo00D007oo001oo`0000=oo`03001oo`0001=oo`04001o
o`00002_Ool00`00Oomoo`0MOol0021oo`03001oogoo00]oo`03001oogoo00=oo`800003Ool00000
01Eoo`03001oogoo0:eoo`03001oogoo04]oo`05001oogooOol00002Ool2000017oo001oogoo0P00
00Ioo`00000007oo0002Ool01000Oomoogoo0P0000Aoo`00Ool0009oo`<00003Ool007oo01=oo`03
001oogoo0:moo`03001oogoo01eoo`008Goo00<007ooOol02Woo00<007ooOol00goo0P0000=oo`00
00005Goo00<007ooOol0[Goo00<007ooOol0Bgoo00<007ooOol00Woo00@007oo001oo`8000=oo`@0
0004Ool00000Ool2000017oo000007oo0P0000Ioo`00Oomoo`00Ool200000goo001oo`35Ool00`00
Oomoo`0MOol0025oo`03001oogoo00Yoo`03001oogoo00=oo`D001Eoo`03001oogoo0:Eoo`8000Io
o`03001oogoo04aoo`06001oogooOol007oo0P000Woo00@007ooOomoo`800003Ool0000000D0009o
o`@000=oo`80009oo`03001oogoo0<Aoo`03001oogoo01ioo`008Woo00<007ooOol02Goo00<007oo
Ool017oo100057oo00<007ooOol0YGoo0`001Woo00<007ooOol0C7oo00<007ooOol00Woo0P0017oo
0`0000=oo`00000010000goo0P0000=oo`00000017oo00D007ooOomoo`000<Ioo`03001oogoo01io
o`008Woo00<007ooOol02Goo00<007ooOol00goo0P0000Aoo`00Ool0019oo`03001oogoo0:Ioo`80
0003Ool007oo00Aoo`03001oogoo04eoo`03001oogoo009oo`8000Eoo`D000=oo`<00003Ool00000
009oo`03001oogoo00D00<Moo`03001oogoo01ioo`008Woo00<007ooOol02Goo00<007ooOol00goo
1P004Goo00<007ooOol0YWoo0`000Woo00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol00Woo
00<007oo000017oo00<007oo00002@0017oo0`000goo00<007ooOol0aWoo00<007ooOol07Woo000S
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Ool00003Ool2000@Ool00`00Oomoo`2WOol01@00
Ool007oo000017oo00<007ooOol0CWoo00D007ooOomoo`00009oo`8000=oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo009oo`03001oogoo0<Moo`03001oogoo01ioo`008goo00<007ooOol0
27oo00<007ooOol00goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0Ygoo0P0000=oo`00
000017oo00<007ooOol0D7oo00@007ooOol000Aoo`800003Ool0000000800003Ool0000000Ioo`<0
00=oo`03001oogoo0;eoo`8000Uoo`03001oogoo01ioo`0097oo00<007ooOol01goo00<007ooOol0
0goo0P000Woo0`003goo00<007ooOol0YWoo1@001Goo00<007ooOol0DGoo0`001Woo0P0000Aoo`00
000000Aoo`@0009oo`04001oogoo0030Ool00`00Ool00008Ool00`00Oomoo`0NOol002Eoo`03001o
ogoo00Ioo`03001oogoo00Aoo`<0009oo`03001oogoo00aoo`03001oogoo0:Moo`03001oogoo0080
00Eoo`03001oogoo059oo`8000Qoo`P000Ioo`03001oo`0000=oo`800;aoo`<000Qoo`03001oogoo
01ioo`009Woo00<007ooOol01Goo00<007ooOol017oo0P0000=oo`0000003Woo00<007ooOol0Ygoo
00<007ooOol0100017oo00<007ooOol0DWoo10001goo0`0000=oo`00Ool01goo0P0017oo0`00^Woo
00@007ooOol000Qoo`03001oogoo01ioo`009goo0P001Goo00<007ooOol01Woo00<007ooOol03Goo
00<007ooOol0Z7oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo059oo`80009oo`8000Eo
o`@00003Ool007oo00Aoo`<000Ioo`03001oogoo0;Qoo`06001oogoo001oo`001goo00<007ooOol0
7Woo000YOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool2002/Ool00`00Ool00002
Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`02Ool20002Ool02000Ool007oo001oo`00
Ool40002Ool00`00Oomoo`30Ool300000goo001oo`06Ool00`00Oomoo`0NOol002Yoo`03001oogoo
009oo`03001oogoo00Eoo`03001oo`0000Yoo`03001oogoo0:aoo`H000Aoo`03001oogoo05=oo`03
001oogoo00Aoo`X000Eoo`03001oogoo0<5oo`@000Qoo`03001oogoo01ioo`00:goo0P000Woo00<0
07ooOol017oo00@007ooOol000Uoo`03001oogoo0:moo`03001oo`0000Eoo`03001oogoo05Aoo`03
001oogoo00Ioo`D000Moo`03001oogoo0<5oo`<000Qoo`03001oogoo01moo`00;Goo0`001Woo0`00
27oo0P00^Woo00<007ooOol0E7oo00<007ooOol04Goo00<007ooOol0`Woo0`0027oo00<007ooOol0
7goo000_Ool2000>Ool2002cOol30005Ool00`00Oomoo`1EOol2000BOol00`00Oomoo`3=Ool00`00
Oomoo`0OOol002moo`03001oo`0000@000Aoo`D00;Aoo`05001oogooOol00004Ool00`00Oomoo`1E
Ool00`00Ool00009Ool20005Ool00`00Oomoo`2lOol00`00Oomoo`0?Ool00`00Oomoo`0OOol002mo
o`03001oogoo00Aoo`@00;Uoo`05001oogooOol00004Ool00`00Oomoo`1EOol01000Oomoo`001goo
0P0000=oo`00Ool00Woo00<007ooOol0_Goo00<007ooOol03goo00<007ooOol07goo000`Ool00`00
Oomoo`2oOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1FOol01000Oomoo`001Woo00D0
07oo000007oo00800=9oo`03001oogoo01moo`00<7oo00<007ooOol06Goo0`00Y7oo00D007ooOomo
o`0000Aoo`03001oogoo05Ioo`04001oogooOol500000goo00000003001AOol20020Ool00`00Oomo
o`0POol0031oo`03001oogoo01Uoo`03001oo`000:Aoo`04001oo`000005Ool00`00Oomoo`1FOol0
0`00Oomoo`06Ool6001@Ool01000Oomoo`00Ogoo00<007ooOol087oo000`Ool00`00Oomoo`0JOol0
0`00Oomoo`2TOol00`00Oomoo`04Ool00`00Oomoo`1GOol00`00Oomoo`07Ool200000goo0000001@
Ool01000Oomoo`00Ogoo00<007ooOol087oo000`Ool00`00Oomoo`38Ool00`00Oomoo`1GOol00`00
Oomoo`06Ool6001@Ool4001oOol00`00Oomoo`0POol0031oo`03001oogoo0<Qoo`03001oogoo05Mo
o`03001oogoo00Ioo`03001oo`00009oo`03001oogoo0=5oo`03001oogoo021oo`00<Goo00<007oo
Ool01Goo00<007ooOol0]Goo0P0027oo00<007ooOol0F7oo00<007ooOol01Goo1@00_7oo10004goo
00<007ooOol08Goo000aOol00`00Oomoo`04Ool2002fOol01000Oomoo`001goo00<007ooOol0F7oo
00<007ooOol01Woo1000_7oo00D007ooOomoo`00019oo`03001oogoo025oo`00<Goo00<007ooOol0
17oo0P00]Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0F7oo00<007ooOol01goo0P00
00=oo`00Ool0^Goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol08Goo000aOol00`00Oomo
o`04Ool4002dOol01@00Oomoogoo00001Goo00<007ooOol0FWoo00<007ooOol01Woo00@007ooOol0
0;]oo`04001oo`00000BOol00`00Oomoo`0ROol0035oo`03001oogoo00=oo`05001oo`00001oo`04
002`Ool01000Ool000001Woo00<007ooOol0FWoo00<007ooOol01Woo00@007oo00000;aoo`03001o
ogoo019oo`03001oogoo029oo`00<Woo00<007ooOol00goo1@000goo1000[Goo00<007ooOol01Goo
00<007ooOol0Fgoo00<007ooOol01goo00<007ooOol0dGoo00<007ooOol08Woo000bOol00`00Ool0
000300001Woo001oogoo001oo`8000Aoo`800;=oo`03001oogoo05aoo`03001oogoo0:Moo`80031o
o`03001oogoo02=oo`00<Woo0P001Goo00D007oo000007oo008000Ioo`800;5oo`03001oogoo05ao
o`03001oogoo0:Ioo`04001oogoo000_Ool00`00Oomoo`0SOol003=oo`03001oogoo00Aoo`03001o
ogoo00]oo`03001oogoo0:ioo`03001oogoo05eoo`03001oogoo031oo`8007Aoo`80031oo`03001o
ogoo02=oo`00<Goo0`005Goo00<007ooOol0[Goo00<007ooOol0GGoo00<007ooOol0;goo00@007oo
Ool00:Eoo`03001oogoo02=oo`00<7oo00@007ooOol001Ioo`03001oogoo0:aoo`03001oogoo05eo
o`03001oogoo00Eoo`8002Qoo`04001oogoo002UOol00`00Oomoo`0SOol002moo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00ioo`03001oogoo0:Yoo`03001oogoo05moo`03001oogoo00Eo
o`8002Moo`@00:Eoo`03001oogoo02=oo`00;goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
000047oo00<007ooOol0ZGoo00<007ooOol0Ggoo00<007ooOol01Goo0P00cgoo00<007ooOol097oo
000^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool4000@Ool00`00Oomoo`2XOol00`00Oomoo`1OOol0
0`00Oomoo`04Ool4003>Ool00`00Oomoo`0TOol002eoo`03001oogoo00Eoo`06001oogooOol007oo
0P0047oo00<007ooOol0Ygoo00<007ooOol0HGoo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool0agoo00<007ooOol09Goo000/Ool00`00Oomoo`06Ool01000Oomoogoo0`0000=oo`00Ool03goo
00<007ooOol0YWoo00<007ooOol0HGoo00<007ooOol02Goo00<007oo0000b7oo00<007ooOol09Goo
000/Ool00`00Oomoo`07Ool01@00Ool007oo00000Woo00<007ooOol027oo0P0017oo00<007ooOol0
YWoo00<007ooOol0HGoo00<007ooOol027oo00D007ooOomoo`000<Ioo`03001oogoo02Ioo`00;7oo
00<007ooOol01goo00@007oo001oo`80009oo`03001oogoo00Ioo`04001oogoo0004Ool00`00Oomo
o`2TOol00`00Oomoo`1SOol00`00Oomoo`08Ool00`00Ool0002kOol2000:Ool00`00Oomoo`0VOol0
02aoo`03001oogoo00Moo`04001oo`00Ool50007Ool00`00Oomoo`02Ool01@00Oomoogoo0000YWoo
00<007ooOol0Hgoo00<007ooOol02Goo00<007ooOol0^Woo00<007oo000027oo00<007ooOol09goo
000[Ool00`00Oomoo`09Ool200000goo000000040007Ool01@00Oomoogoo000017oo00<007ooOol0
XWoo00<007ooOol0IGoo00<007ooOol00goo2P00^7oo0`0027oo00<007ooOol09goo000[Ool00`00
Oomoo`09Ool:0006Ool01000Ool000001Goo00<007ooOol0XWoo00<007ooOol0IGoo00<007ooOol0
0Woo0`0000=oo`00Ool01Goo00<007ooOol0/Woo10002Goo00<007ooOol0:7oo000ZOol00`00Oomo
o`0:Ool700000goo001oo`020005Ool00`00Oomoo`05Ool00`00Oomoo`2ROol00`00Oomoo`1UOol0
0`00Oomoo`02Ool30002Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool30023Ool01@00Oomoogoo0000
27oo00<007ooOol0:7oo000ZOol00`00Oomoo`0;Ool00`00Ool000030002Ool01000Ool0000037oo
00<007ooOol0XGoo00<007ooOol0Igoo00<007ooOol00P000Woo00<007oo00001goo00<007ooOol0
:Goo00@007ooOol0089oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo02Uoo`00:Woo00<0
07ooOol02Woo0`0000=oo`0000000P0000Aoo`00Oomoo`8000]oo`03001oogoo0:5oo`03001oogoo
06Moo`03001oogoo00@0009oo`03001oogoo00Ioo`03001oogoo02Qoo`04001oo`000023Ool50007
Ool00`00Oomoo`0YOol002Yoo`03001oogoo00Yoo`<00003Ool00000009oo`80009oo`03001oo`00
00Yoo`03001oogoo0:5oo`03001oogoo06Moo`04001oo`00Ool50009Ool00`00Oomoo`0YOol00`00
Oomoo`23Ool50007Ool00`00Oomoo`0YOol002Yoo`03001oogoo00Uoo`03001oo`000080009oo`@0
00=oo`8000Yoo`03001oogoo0:1oo`03001oogoo06Uoo`8000=oo`<000Yoo`03001oogoo0:eoo`@0
00Qoo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo00D007oo000007oo00H000=oo`03001oo`00
00Uoo`03001oogoo09moo`03001oogoo06Yoo`04001oogooOol60009Ool00`00Oomoo`2]Ool20009
Ool00`00Oomoo`0ZOol002Yoo`03001oogoo00Uoo`03001oo`0000<00006Ool00000001oo`000Woo
00<007oo00002Goo00<007ooOol0Wgoo00<007ooOol0JWoo0P0000=oo`0000001P0027oo00<007oo
Ool0]goo00<007ooOol0:goo000ZOol00`00Oomoo`09Ool01000Ool007oo100000Aoo`00Ool0009o
o`03001oo`0000Uoo`03001oogoo09ioo`03001oogoo06]oo`03001oo`0000T000Moo`03001oogoo
0;Ioo`03001oogoo02aoo`00:Woo00<007ooOol02Goo00@007oo001oo`8000=oo`08001oogoo001o
o`00Ool000Uoo`03001oogoo09ioo`03001oogoo06]oo`04001oo`00Ool500000goo00000007Ool0
0`00Oomoo`2fOol00`00Oomoo`0/Ool002Yoo`03001oogoo00Uoo`04001oo`00Ool3000017oo0000
07oo0P0000Aoo`00Ool000Uoo`03001oogoo09eoo`03001oogoo06aoo`05001oo`00001oo`070006
Ool00`00Oomoo`2fOol00`00Oomoo`0]Ool002Yoo`03001oogoo00Yoo`80009oo`<0009oo`@00003
Ool007oo00Uoo`03001oogoo09eoo`03001oogoo06eoo`h000=oo`03001oogoo0:Aoo`8000Uoo`03
001oogoo00Aoo`03001oogoo02eoo`00:Woo00<007ooOol02Woo00@007oo001oo`<0009oo`800004
Ool007oo000:Ool00`00Oomoo`2=Ool00`00Oomoo`0=Ool00`00Oomoo`1^Ool00`00Ool000070002
Ool01@00Oomoogoo0000YWoo00<007oo00001Goo1@001Goo00<007ooOol0;Goo000[Ool00`00Oomo
o`0:Ool20003Ool600000goo001oo`0:Ool00`00Oomoo`2<Ool3000=Ool00`00Oomoo`1_Ool01@00
Ool00000Ool01P0000Eoo`00Oomoo`000:Moo`04001oogoo0002Ool3000017oo0000000017oo00<0
07ooOol0;Woo000[Ool00`00Oomoo`0;Ool20002Ool01P00Oomoogoo001oo`8000]oo`03001oogoo
09Aoo`@000=oo`03001oogoo075oo``0009oo`03001oogoo0:Ioo`80009oo`03001oogoo00<00003
Ool007oo009oo`03001oogoo02moo`00;7oo00<007ooOol02goo1`0000Aoo`00000000Yoo`03001o
ogoo09Eoo`05001oogooOol00002Ool00`00Oomoo`1aOol00`00Ool000030003Ool5002]Ool00`00
Ool000040004Ool00`00Oomoo`0_Ool002aoo`03001oogoo00eoo`H000eoo`03001oogoo095oo`<0
0003Ool007oo009oo`03001oo`0007Eoo`<00003Ool007oo009oo`<00:ioo`03001oogoo00D000=o
o`03001oogoo031oo`00;7oo00<007ooOol047oo00<007ooOol037oo00<007ooOol0TGoo00@007oo
Oomoo`8000=oo`03001oo`0007Moo`P00:moo`D0009oo`04001oogoo000cOol002aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo095oo`04001oogooOol3000017oo00000000NWoo00L007oo
001oo`00Ool0002`Ool600000goo001oo`0cOol002eoo`03001oogoo015oo`03001oogoo00Uoo`03
001oogoo095oo`03001oogoo00=oo`05001oo`00Ool0001lOol01P00Oomoo`00Ool000Aoo`<00:Yo
o`@0009oo`03001oogoo039oo`00;Woo00<007ooOol047oo00<007ooOol02Goo00<007ooOol0TGoo
00<007ooOol00goo00@007ooOol007eoo`06001oogooOol007oo10000goo00<007ooOol0YWoo0P00
17oo00<007ooOol0<goo000_Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`2COol00`00
Oomoo`02Ool01000Oomoo`00OWoo00<007ooOol017oo00<007ooOol00Woo00<007ooOol08Woo00<0
07ooOol0OWoo1@000goo00<007ooOol0=7oo000`Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00
Oomoo`2DOol50002Ool00`00Oomoo`1mOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0Q
Ool2001nOol00`00Ool000030003Ool00`00Oomoo`0dOol0035oo`03001oogoo00moo`03001oogoo
00Aoo`03001oogoo09Eoo`H00003Ool007oo07moo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo025oo`8007ioo`H0009oo`03001oogoo03Eoo`00<Woo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol0UWoo1`00PWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0IGoo0P00>Woo
100000=oo`0000000P00>7oo000cOol2000?Ool00`00Oomoo`02002HOol00`00Ool000050023Ool0
1000Oomoogoo0P000Woo0P00GGoo1@001Goo0P00>Woo0`0000=oo`0000000P00>Goo000eOol2000>
Ool2002JOol00`00Ool00002Ool30024Ool00`00Oomoo`02Ool3001NOol01@00Oomoogoo000037oo
00<007ooOol0<Woo2000>Goo000gOol2000:Ool200000goo001oo`2JOol60026Ool01P00Oomoogoo
001oo`@005Yoo`03001oogoo009oo`03001oogoo00Uoo`03001oo`0002aoo`8000Moo`D003Yoo`00
>Goo2P0017oo00<007ooOol0V7oo0P0000Aoo`00000008Ioo`03001oogoo009oo`80009oo`03001o
ogoo05Uoo`05001oogooOol0000:Ool01000Oomoo`00:goo00@007ooOol0009oo`03001oogoo009o
o`<003]oo`00Agoo00<007ooOol0VWoo0P00RGoo00<007ooOol00Woo00<007ooOol00P00FWoo1000
37oo0`00:Woo1P0000=oo`0000001Goo00<007ooOol0>Goo0018Ool00`00Oomoo`2>Ool00`00Oomo
o`08Ool00`00Oomoo`28Ool00`00Oomoo`03Ool4002FOol00`00Ool00003Ool200000goo00000003
Ool00`00Oomoo`0jOol004Uoo`03001oogoo08]oo`800003Ool007oo00Moo`03001oogoo08Yoo`03
001oogoo00Aoo`8009Eoo`05001oogoo001oo`0200000goo00000004Ool00`00Oomoo`0kOol004Uo
o`03001oogoo08Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo08aoo`03001oogoo07Mo
o`80025oo`03001oo`0000@00003Ool007oo00=oo`03001oogoo03aoo`00BWoo00<007ooOol0R7oo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol0SWoo00<007ooOol0MWoo00<007oo00007goo
00<007oo00000Woo0`000Woo00@007ooOol003moo`00Bgoo00<007ooOol0Qgoo00<007ooOol017oo
00D007ooOomoo`00099oo`03001oogoo00Eoo`<006eoo`03001oo`00021oo`03001oogoo009oo`80
009oo`03001oo`00041oo`00C7oo00<007ooOol0QGoo00<007ooOol01Goo00D007ooOomoo`0009=o
o`03001oogoo00Aoo`04001oogoo001]Ool00`00Oomoo`0OOol20003Ool01P00Oomoo`00Ool0045o
o`00CGoo00<007ooOol0QGoo00<007ooOol017oo00@007ooOol009Eoo`03001oogoo00=oo`03001o
o`0006Yoo`<001Yoo`8000Qoo`800003Ool00000009oo`80049oo`00CWoo00<007ooOol0Q7oo00<0
07ooOol017oo00<007oo0000Ugoo0P0017oo00<007ooOol0Igoo0P000goo00<007ooOol05goo0P00
0goo0P0017oo0P000goo0P00@goo001?Ool00`00Oomoo`23Ool20003Ool200000goo001oo`2IOol0
0`00Oomoo`1ZOol30004Ool00`00Oomoo`0KOol30003Ool60014Ool0051oo`03001oogoo08Aoo`<0
009oo`03001oogoo09Yoo`03001oogoo06Yoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo
00Qoo`8000Moo`8004Eoo`00DGoo00<007ooOol0Qgoo00<007ooOol0W7oo00<007ooOol0JWoo00<0
07ooOol00Woo00<007ooOol03goo0P004Woo00<007ooOol0AGoo001BOol00`00Oomoo`25Ool00`00
Oomoo`2NOol00`00Oomoo`08Ool3001NOol5000UOol00`00Oomoo`16Ool005=oo`03001oogoo08=o
o`03001oogoo0:1oo`03001oogoo00Aoo`<000=oo`03001oogoo08Aoo`03001oogoo04Moo`00E7oo
00<007ooOol0PGoo00<007ooOol0XWoo00<007ooOol017oo0P000goo00<007ooOol0Pgoo00<007oo
Ool0B7oo001EOol00`00Oomoo`1]Ool2000@Ool00`00Oomoo`2TOol20004Ool00`00Oomoo`02Ool0
0`00Oomoo`21Ool2001;Ool005Ioo`03001oogoo06]oo`03001oogoo008000eoo`03001oogoo0:Mo
o`03001oogoo009oo`05001oogooOol00022Ool00`00Oomoo`1;Ool005Moo`8006Yoo`03001oogoo
00=oo`8000Uoo`800:]oo`80009oo`D006=oo`03001oogoo00ioo`@000Qoo`8004ioo`00FGoo00<0
07ooOol0Igoo00<007ooOol00goo0P0027oo00<007ooOol0[Goo00H007ooOomoo`00Ool4001OOol0
0`00Ool0000?Ool300000goo001oo`05Ool00`00Oomoo`1>Ool005Yoo`03001oogoo06Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`800;5oo`06001oogooOol007oo1000GGoo00@007ooOol000ioo`@0
0003Ool007oo00Aoo`03001oogoo04moo`00Fgoo00<007ooOol0I7oo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol0/Woo0P000Woo1P00:goo0P00<7oo0`003Woo0P0000Aoo`00Ool000=oo`80
059oo`00G7oo00<007ooOol0Hgoo00<007ooOol017oo00<007ooOol00goo00<007ooOol0]Goo00P0
07ooOol007oo001oo`00:Woo00<007oo0000@Goo0`0000=oo`0000000Woo00<007ooOol0DWoo001M
Ool2001TOol00`00Oomoo`03Ool01000Oomoogoo0P00^Goo100000=oo`00Ool0:goo0P00@Woo00<0
07oo00000Woo0P00EGoo001OOol00`00Oomoo`1ROol20002Ool20002Ool00`00Oomoo`2kOol3001T
Ool5000;Ool2001GOol0061oo`8006Aoo`8000=oo`03001oogoo0;ioo`03001oogoo05moo`@0009o
o`03001oo`0000Uoo`03001oogoo05Moo`00HWoo0P00IGoo0P00`Woo0P00GWoo00<007oo00000P00
0goo00<007oo00001Woo0P00FWoo001TOol00`00Oomoo`0>Ool2001AOol00`00Oomoo`34Ool2000:
Ool3000`Ool4000KOol00`00Ool00002Ool500000goo001oo`02Ool2001LOol006Eoo`03001oogoo
00eoo`<004ioo`800<Uoo`8000Moo`04001oogoo000`Ool01000Oomoo`0067oo1P000Woo100000Ao
o`00001oo`8005ioo`00IWoo0P003Woo00<007ooOol0Bgoo0P00cGoo0P001Woo0`00<7oo00@007oo
Ool001Eoo`X00003Ool0000000800004Ool00000001POol006Qoo`<005Moo`800=5oo`80011oo`@0
02=oo`@001Eoo`03001oo`0000@00003Ool0000000D00003Ool00000065oo`00Jgoo0P00?Woo0P00
4goo0P00eGoo0P003Woo0P000Woo00<007ooOol01Woo0P00:Goo100017oo00<007oo000020000goo
1000HGoo001]Ool2000lOol2000@Ool3003IOol2000;Ool20003Ool40003Ool20002Ool2000WOol0
1000Oomoo`000goo100000=oo`000000200000=oo`000000HWoo001_Ool2000GOol3000aOol00`00
Oomoo`3LOol30009Ool20002Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00003Ool00`00Oomoo`0=00000goo001oo`1QOol0075oo`03001oogoo01=oo`04001oogooOol4
000[Ool2003ROol30006Ool50003Ool20008Ool00`00Oomoo`08Ool4000GOol01000Ool0000017oo
00<007oo00001P001goo00<007ooOol0H7oo001bOol2000COol00`00Oomoo`02Ool00`00Ool0000Y
Ool2003WOol20008Ool01000Oomoogoo0P0027oo00<007ooOol027oo00D007ooOomoo`0001Moo`03
001oogoo00Aoo`800003Ool0000000<000Ioo`8006=oo`00M7oo1@003Goo00<007ooOol00goo0`00
97oo1@00jgoo0`001Goo0P0000Aoo`00Ool000Qoo`03001oogoo009oo`800003Ool0000000800004
Ool00000000NOol50003Ool20002Ool2001UOol007Uoo`<000Yoo`03001oogoo00=oo`03001oogoo
029oo`800?=oo`H00005Ool007ooOol00008Ool01P00Oomoogoo001oo`D00003Ool0000000800003
Ool0000001Ioo`D000Yoo`8006Moo`00O7oo0P002Goo00<007ooOol00Woo00<007ooOol07goo0`00
ngoo0P000goo00<007ooOol017oo00<007ooOol00Woo00@007oo001oo`L00003Ool000000080019o
o`<007Qoo`00OWoo1@0017oo0P0000=oo`0000007Goo1@00ogoo0Goo1P000goo00<007ooOol00Woo
00D007oo000007oo00<00003Ool00000009oo`03001oo`0000eoo`H007]oo`00Pgoo1@0000=oo`00
Ool06Goo1@00ogoo2Woo2`000Woo100000=oo`0000000`0027oo2000PGoo0028Ool8000=Ool7003o
OolIOolE0029Ool0091oo`d00?moob9oo`03001oogoo09Uoo`00ogooogooG7oo003oOoooOomLOol0
0?mooomooeaoo`00ogooogooG7oo003oOoooOomLOol00?mooomooeaoo`00ogooogooG7oo003oOooo
OomLOol00?mooomooeaoo`00ogooogooG7oo002`Ool8003oOol/Ool8001_Ool00?mooomooeaoo`00
ogooogooG7oo002POol01000Oomoo`00ogoo<7oo00@007ooOol008=oo`00Igoo0`0017oo10001Woo
00@007ooOomoo`<000=oo`80009oo`<00004Ool00000Ool70002Ool50005Ool01000Oomoo`001Goo
0`003Woo1@0017oo0P00bgoo1@0017oo0`0000Aoo`00001oo`T00004Ool000000002Ool30003Ool2
0002Ool3000017oo000007oo1`000Woo1@001Goo00@007ooOol000Moo`<000aoo`D006Qoo`00IWoo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oo`0000=oo`8000Eoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo0003Ool0
1@00Oomoogoo00003goo00<007ooOol017oo0P00c7oo00D007ooOomoo`00009oo`04001oogooOol2
0005Ool00`00Oomoo`02Ool20003Ool01000Oomoo`001Goo00<007oo00000goo0P001Goo00<007oo
Ool00Woo00<007ooOol02Goo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo06Qoo`00IGoo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol00Woo00@007ooOol0009oo`03001oo`0000Ao
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`H000Ioo`03001oogoo00eoo`03001o
ogoo0=9oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo0004Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool60006Ool00`00Oomoo`0=Ool00`00Oomoo`1XOol006Eoo`03001oogoo
00Yoo`03001oogoo00Aoo`0;001oogooOol007oo001oo`00Ool00002Ool50005Ool00`00Oomoo`02
Ool60006Ool01000Oomoo`001goo00<007ooOol03Goo00<007ooOol0dWoo00D007ooOomoo`0000=o
o`D000Eoo`03001oogoo009oo`03001oogoo009oo`0:001oogoo001oo`00Ool007oo0002Ool50005
Ool00`00Oomoo`02Ool60006Ool01000Oomoo`000goo1P003Woo00<007ooOol0J7oo001UOol00`00
Oomoo`0:Ool00`00Oomoo`04Ool03@00Oomoogoo001oo`00Ool007oo001oo`0000Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0005Ool2000@Ool0
0`00Oomoo`3BOol40003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20003Ool0
3000Oomoo`00Ool007oo001oo`00Ool000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`04001oogoo0004Ool01000Oomoo`003goo00<007ooOol0J7oo001UOol0
0`00Oomoo`06Ool40007Ool02`00Oomoogoo001oo`00Ool007oo00000Woo10001Woo00<007ooOol0
0goo10001Woo1P001Woo00<007ooOol03Goo00<007ooOol0dWoo00D007ooOomoo`0000=oo`@000Io
o`03001oogoo009oo`03001oo`00008000=oo`07001oo`00Ool007oo00000Woo10001Woo00<007oo
Ool00goo10001Woo1P000goo00@007ooOol000moo`03001oogoo06Qoo`00IWoo00<007ooOol00P00
0goo00<007ooOol02Goo00<007ooOol00P000goo0P0037oo00<007ooOol03Woo00@007ooOol000Mo
o`03001oogoo00eoo`03001oogoo0=9oo`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool20003Ool2000<Ool00`00Oomoo`0>Ool01000Oomoo`001Goo00<007oo00003goo00<007oo
Ool0J7oo001WOol200000goo001oo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00002
0003Ool2000<Ool00`00Oomoo`0?Ool01000Oomoo`000Woo00D007ooOomoo`0000eoo`<00==oo`D0
00ioo`03001oogoo009oo`03001oogoo00Aoo`<000=oo`8000aoo`03001oogoo00moo`04001oogoo
0004Ool00`00Ool0000=Ool3001ZOol006ioo`D0009oo`H001Aoo`80015oo`04001oogoo0003Ool3
000@Ool00`00Oomoo`3SOol20003Ool2000IOol2000AOol01000Oomoo`001Goo0P003goo00<007oo
Ool0J7oo003oOoooOomLOol00?mooomooeaoo`00ogooogooG7oo003oOoooOomLOol00?mooomooeao
o`00ogooogooG7oo003oOoooOomLOol00?mooomooeaoo`00ogooogooG7oo0000\
\>"],
  ImageRangeCache->{{{0, 601}, {285.625, 0}} -> {-0.0520882, -0.0238146, \
0.00350113, 0.00350113}, {{14.875, 286.875}, {278.813, 6.75}} -> {-245.132, \
-193.519, 1.63124, 1.43804}, {{314.063, 586.063}, {278.813, 6.75}} -> \
{-669.23, -197.427, 1.47221, 1.45726}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["timeplot",
    FontWeight->"Bold"],
  "  returns a graph  which represents the dwell time in each of the stops by \
a circle. The circle is centered at the beginning of each segment,  its area \
is proportional to the relative dwell time in the segment  (relative to the \
sum of the dwell  times over all the list of segments). The display factor  \
(here 100) controls the  total area of the circles, we can augment or \
diminish it to make the visual display clearer ."
}], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell["\<\
In this graph, bubble size may represent relative dwell time, as above, or \
absolute dwell time, as with the following command: .\
\>", "Text",
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[
        Partition[
          Flatten[Script[{"\<See[TimePlotAbs[lingering,0.5],PlotLabel->\
sessionname2,TextStyle->{FontSize->14},DisplayFunction->Identity]\>"}, 
              twofiles], 1], 2]]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.504177 0.00260432 0.502525 0.00278626 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C57Male) show
121.625 16.188 moveto
(#3) show
138.375 16.188 moveto
(_) show
146.750 16.188 moveto
(1.) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.442735 0.473665 scale
1.13879 1.06094 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00487224 0.00521262 scale
25.7869 84.2416 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00344519 0.00368588 scale
57.3234 163.288 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
78.3315 376.609 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
265.588 388.723 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
278.691 317.73 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00929929 0.00994895 scale
97.7075 59.7741 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103356 0.0110576 scale
87.8267 36.5014 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
697.41 317.823 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127585 0.0136499 scale
55.7197 65.5033 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
52.0443 231.399 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00676622 0.00723893 scale
17.478 88.5048 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
92.2928 506.592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103356 0.0110576 scale
9.65403 48.9381 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017373 0.0185867 scale
6.16302 24.9184 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368307 0.00394037 scale
34.5256 108.744 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
42.5818 99.4648 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00536894 0.00574403 scale
46.3164 25.7711 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291172 0.00311514 scale
161.108 17.8644 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
318.651 77.6524 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00344519 0.00368588 scale
228.452 41.1788 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
153.774 26.5755 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
141.96 330.744 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
31.1322 152.617 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00748034 0.00800294 scale
13.8831 58.9771 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0161068 0.0172321 scale
8.07235 18.6675 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291172 0.00311514 scale
75.1343 58.3152 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00567599 0.00607252 scale
41.2757 25.1988 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0199192 0.0213108 scale
15.5091 5.2654 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
309.501 41.5251 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
114.158 11.8217 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00853884 0.00913538 scale
59.0982 7.29253 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
172.816 25.8602 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
23.2212 75.0188 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
55.2494 182.766 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00689039 0.00737176 scale
14.8903 66.3464 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0197911 0.0211738 scale
5.40394 21.947 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00469501 0.00502301 scale
20.6624 103.751 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
84.712 383.735 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00823559 0.00881094 scale
15.4828 82.9616 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
62.8667 309.75 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00390648 0.0041794 scale
120.228 227.851 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736613 0.00788075 scale
16.4876 88.7517 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
259.461 26.2622 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00792073 0.00847409 scale
109.554 32.4707 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
481.843 157.589 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00637926 0.00682493 scale
118.018 19.0889 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00701235 0.00750225 scale
73.5132 7.75368 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
179.595 46.6149 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00813199 0.00870011 scale
29.5819 17.386 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00536894 0.00574403 scale
40.4046 32.2073 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
28.7689 21.6945 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100865 0.0107912 scale
11.4916 37.6558 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00676622 0.00723893 scale
15.9262 63.0715 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0171272 0.0183238 scale
6.08913 22.7191 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00883168 0.00944868 scale
11.0228 47.3262 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106586 0.0114033 scale
9.88118 41.8783 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00487224 0.00521262 scale
25.3785 87.6795 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
93.437 342.258 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
22.9773 124.96 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
37.4589 202.367 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00725012 0.00775663 scale
24.5596 89.3261 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00823559 0.00881094 scale
104.375 86.8329 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0055246 0.00591056 scale
151.91 135.481 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368307 0.00394037 scale
227.685 202.075 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104173 0.0111451 scale
80.329 69.6668 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
445.265 380.106 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759283 0.00812329 scale
118.049 77.5363 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00610767 0.00653437 scale
149.699 83.6316 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291172 0.00311514 scale
314.313 169.63 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759283 0.00812329 scale
115.38 35.7503 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00701235 0.00750225 scale
127.77 43.5416 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
361.704 79.9013 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759283 0.00812329 scale
102.842 18.3719 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
170.992 24.0633 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
189.577 100.55 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102532 0.0109695 scale
11.5417 37.172 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
15.7341 53.3773 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0122846 0.0131428 scale
8.20787 34.0712 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133432 0.0142754 scale
7.51246 29.4227 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00689039 0.00737176 scale
15.5797 60.5405 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00390648 0.0041794 scale
31.2583 168.299 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
54.9568 295.258 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
31.1917 156.476 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00520864 0.00557253 scale
22.6566 120.471 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0243264 0.0260259 scale
5.54255 28.0809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
114.717 294.667 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00974448 0.0104252 scale
26.8788 13.0884 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00582344 0.00623028 scale
58.3264 15.2112 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
79.6055 10.542 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00431878 0.0046205 scale
98.8752 11.5897 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
349.965 37.4049 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
99.3615 12.1576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00813199 0.00870011 scale
74.7124 7.85507 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00748034 0.00800294 scale
80.3306 8.08828 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00520864 0.00557253 scale
149.511 25.6311 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00431878 0.0046205 scale
186.537 39.0196 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00637926 0.00682493 scale
141.944 57.668 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.013595 0.0145447 scale
58.0333 57.735 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
117.263 64.6301 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00956889 0.0102374 scale
95.1218 54.7855 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
280.914 97.4897 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
277.963 89.6098 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00956889 0.0102374 scale
82.4035 14.7469 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
52.4372 6.33584 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017373 0.0185867 scale
6.60969 21.8091 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368307 0.00394037 scale
33.4531 110.33 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00582344 0.00623028 scale
16.9814 71.695 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
44.3157 207.549 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
60.0532 318.361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011352 0.012145 scale
10.5462 56.6437 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0123534 0.0132164 scale
10.6853 55.5991 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.021983 0.0235188 scale
19.7162 2.95934 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
343.867 43.4632 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00637926 0.00682493 scale
37.8602 21.5958 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0526047 0.0562798 scale
4.41615 2.90193 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00892716 0.00955083 scale
12.8462 42.4633 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0247068 0.0264328 scale
5.23784 27.5775 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
25.1664 109.369 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0128907 0.0137913 scale
8.13763 33.2362 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0140247 0.0150045 scale
25.9221 5.30441 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.013595 0.0145447 scale
44.2091 4.31772 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00390648 0.0041794 scale
148.338 13.7723 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00802706 0.00858784 scale
73.8889 7.33013 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00390648 0.0041794 scale
130.921 13.2603 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
358.755 44.1532 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00748034 0.00800294 scale
72.9927 6.93371 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759283 0.00812329 scale
61.4856 6.92577 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134066 0.0143432 scale
29.3744 4.34353 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00676622 0.00723893 scale
59.5872 7.92797 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
119.3 55.0109 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00701235 0.00750225 scale
34.7487 20.2393 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00823559 0.00881094 scale
14.0901 46.0337 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00802706 0.00858784 scale
12.2635 51.2818 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
38.6972 178.124 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00748034 0.00800294 scale
13.1545 64.705 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0161068 0.0172321 scale
6.33706 28.639 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0285883 0.0305855 scale
3.50913 13.732 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00663974 0.00710361 scale
17.445 57.0907 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117916 0.0126153 scale
8.46792 35.0502 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
21.9085 117.454 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759283 0.00812329 scale
16.7303 88.6341 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
55.166 267.049 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111257 0.0119029 scale
40.6924 80.5188 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115739 0.0123824 scale
72.4556 64.6327 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00892716 0.00955083 scale
87.9574 15.7672 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101702 0.0108807 scale
74.8186 12.5479 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00596725 0.00638413 scale
19.287 63.6923 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101702 0.0108807 scale
10.4826 42.4393 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0168276 0.0180032 scale
6.02165 23.2236 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00965708 0.0103317 scale
10.6129 53.1537 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0667032 0.0713632 scale
1.93289 10.1576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
59.7546 314.787 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00487224 0.00521262 scale
21.5404 110.112 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131512 0.0140699 scale
8.44867 32.6995 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863755 0.00924099 scale
13.9646 40.0769 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145002 0.0155133 scale
9.63501 19.6097 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00956889 0.0102374 scale
26.0898 13.8922 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
82.9501 38.5792 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0116469 0.0124606 scale
34.6531 4.30398 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00843896 0.00902853 scale
59.6305 10.9697 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00863755 0.00924099 scale
90.6703 15.5016 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150736 0.0161267 scale
6.99501 28.4721 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0108947 0.0116558 scale
12.6346 26.1441 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
56.2565 105.607 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0268131 0.0286864 scale
4.26582 14.0882 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
44.3334 207.905 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0143238 0.0153245 scale
8.65415 46.5198 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00368307 0.00394037 scale
32.5897 112.631 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0065108 0.00696566 scale
27.7984 35.8085 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104173 0.0111451 scale
23.1471 13.72 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00504325 0.00539558 scale
79.7324 10.4827 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00520864 0.00557253 scale
103.019 10.3903 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
180.105 19.3162 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0278674 0.0298143 scale
21.7641 2.14427 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0157879 0.0168908 scale
36.4635 3.65879 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00260432 0.00278626 scale
209.786 22.0941 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00536894 0.00574403 scale
96.153 11.814 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00520864 0.00557253 scale
79.8481 9.63476 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0207121 0.0221591 scale
19.6904 2.77628 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104173 0.0111451 scale
43.3482 4.92864 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00184153 0.00197019 scale
222.022 40.854 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
117.876 24.7915 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00920766 0.00985093 scale
37.5839 10.0234 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
261.634 99.1291 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
58.3517 33.497 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0191378 0.0204748 scale
11.3237 8.84356 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00792073 0.00847409 scale
14.8092 47.8447 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00431878 0.0046205 scale
23.2195 93.122 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
43.3181 183.989 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0781296 0.0835879 scale
1.30475 5.69664 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
186.536 111.246 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
111.984 59.437 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011352 0.012145 scale
28.4418 8.18852 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0146167 0.0156379 scale
24.3919 5.28205 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
103.696 12.3029 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00770368 0.00824188 scale
64.6989 6.68658 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00823559 0.00881094 scale
63.823 6.48398 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00701235 0.00750225 scale
79.37 7.5684 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0155716 0.0166594 scale
38.1997 3.58896 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130216 0.0139313 scale
57.8746 9.348 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109722 0.0117387 scale
71.95 13.1513 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
102.832 20.7721 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00781296 0.00835879 scale
114.702 39.0846 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00130216 0.00139313 scale
669.557 200.735 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017226 0.0184294 scale
52.0575 17.9718 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
283.726 114.249 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00624494 0.00668123 scale
139.98 42.2841 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
208.784 59.5714 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102532 0.0109695 scale
75.2125 12.8848 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00974448 0.0104252 scale
59.9211 5.76293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110492 0.0118211 scale
10.2922 34.2286 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00748034 0.00800294 scale
17.431 52.0134 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00431878 0.0046205 scale
85.3019 64.8761 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00610767 0.00653437 scale
150.054 86.4047 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00725012 0.00775663 scale
108.241 19.2261 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00318963 0.00341246 scale
228.804 34.6553 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0144417 0.0154506 scale
53.1331 8.87539 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0237622 0.0254223 scale
34.504 9.32056 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109722 0.0117387 scale
79.078 24.6952 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0055246 0.00591056 scale
163.091 60.688 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736613 0.00788075 scale
121.892 48.1909 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00833789 0.0089204 scale
106.551 44.3108 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00225541 0.00241298 scale
383.248 112.579 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0169781 0.0181642 scale
46.166 7.93318 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00689039 0.00737176 scale
87.4625 8.24633 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0282302 0.0302024 scale
14.5029 1.78827 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115004 0.0123038 scale
41.8048 6.17288 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291172 0.00311514 scale
172.572 18.4262 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00701235 0.00750225 scale
90.7913 10.4809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00344519 0.00368588 scale
196.848 32.0249 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00411779 0.00440547 scale
190.32 33.5832 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00487224 0.00521262 scale
169.101 39.4811 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0781296 0.0835879 scale
11.4945 3.98108 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.510439 0.00273971 0.506386 0.00274728 [
[.5 1.0125 -52.25 0 ]
[.5 1.0125 52.25 16.9375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -113.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.9375 translate 1 -1 scale
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BalbMale) show
130.000 16.188 moveto
(#4) show
146.750 16.188 moveto
(_) show
155.125 16.188 moveto
(1) show
163.500 16.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.465751 0.467038 scale
1.09595 1.08426 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090866 0.0091117 scale
14.5104 49.7185 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.036501 0.0366018 scale
4.07715 12.1803 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0072486 0.00726862 scale
13.0232 69.5524 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0412552 0.0413691 scale
2.36504 11.8221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154375 0.0154801 scale
7.41701 29.5553 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
79.2492 343.984 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0628195 0.062993 scale
1.60635 7.60354 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00929082 0.00931648 scale
9.73542 53.4354 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0149434 0.0149846 scale
6.21279 33.1853 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0710083 0.0712044 scale
1.33534 6.79776 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
87.2135 330.684 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
38.089 140.375 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00762704 0.0076481 scale
14.8878 55.3288 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
21.3928 75.6166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
37.3936 150.413 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0181732 0.0182234 scale
5.66989 25.9518 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00581181 0.00582786 scale
20.2381 78.2397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
28.4259 94.5123 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
27.3472 90.9761 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
69.4741 224.274 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
24.4716 84.5576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00750301 0.00752373 scale
15.1619 56.0373 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
25.8129 98.3955 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
63.0785 176.401 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
36.6857 83.4959 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0566134 0.0567697 scale
1.85822 7.33701 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
19.072 69.4233 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0520545 0.0521983 scale
2.00617 8.05428 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0432536 0.0433731 scale
2.40951 10.9277 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
29.8506 105.1 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
74.0269 250.965 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
46.1027 153.256 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00698492 0.00700422 scale
21.3488 71.9567 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0537919 0.0539405 scale
1.87482 8.76521 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
42.6979 157.869 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.023687 0.0237525 scale
4.45982 17.7485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0240409 0.0241073 scale
4.40125 16.6203 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0221731 0.0222343 scale
4.79726 18.7881 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0144323 0.0144722 scale
8.07631 23.6087 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939126 0.0094172 scale
13.5115 33.4824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
177.238 112.853 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00387454 0.00388524 scale
100.182 17.9886 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0067109 0.00672943 scale
64.1107 8.61885 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
58.1221 11.7017 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
60.4504 23.9282 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
178.836 113.538 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0119421 0.0119751 scale
16.4686 16.8867 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
39.7924 31.1212 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
59.7318 32.3608 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
191.93 31.2568 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
331.4 40.753 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
355.964 46.9119 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0067109 0.00672943 scale
78.0268 8.12847 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0279061 0.0279832 scale
15.0831 1.85076 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150684 0.01511 scale
26.5356 3.44274 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
70.8824 12.7712 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
106.042 21.2559 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00684928 0.0068682 scale
47.8401 12.9321 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
54.3567 17.6088 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
51.55 26.8499 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
47.9482 28.0445 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
157.637 120.738 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
61.6415 88.9862 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
27.2123 75.0881 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
87.6077 245.996 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112961 0.0113273 scale
9.24122 36.2998 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00929082 0.00931648 scale
9.97652 52.2891 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
32.6794 193.948 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
19.468 117.683 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
103.816 365.264 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0065696 0.00658774 scale
78.262 146.12 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
53.6908 313.923 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
27.824 165.851 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
78.9061 480.468 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00530543 0.00532008 scale
19.9927 118.579 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106989 0.0107285 scale
9.8309 44.216 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
49.0381 251.588 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0227165 0.0227792 scale
4.02879 21.9494 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
65.8536 398.016 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
21.108 123.986 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
21.6592 124.642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612618 0.0061431 scale
16.9682 98.2077 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00877136 0.00879559 scale
11.6732 69.644 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
36.5878 226.431 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153155 0.0153578 scale
7.89203 48.244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
36.2252 187.431 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
114.778 567.041 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
48.5915 221.401 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
188.655 643.182 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
141.89 459.096 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
77.9199 153.504 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090866 0.0091117 scale
72.7258 102.74 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0129956 0.0130315 scale
50.571 71.9649 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
216.961 304.716 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0090866 0.0091117 scale
73.6293 102.893 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0064252 0.00644294 scale
102.543 145.864 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
152.266 203.051 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.015006 0.0150475 scale
46.2534 61.4482 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00833251 0.00835552 scale
60.9396 114.236 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
36.8725 226.22 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
48.5374 288.826 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
15.3151 77.7148 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
24.8666 92.2195 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0288321 0.0289118 scale
3.83392 14.4114 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0770537 0.0772665 scale
1.37982 5.46304 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
27.5164 148.815 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
83.1328 509.566 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106989 0.0107285 scale
11.4283 69.3314 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
54.3441 179.86 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00786923 0.00789096 scale
35.2589 113.641 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00810418 0.00812656 scale
50.5097 116.67 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
217.393 402.843 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
157.062 214.87 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
639.629 553.187 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
215.28 174.024 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00387454 0.00388524 scale
227.23 195.023 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
634.359 566.371 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
167.116 155.91 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00968635 0.0097131 scale
88.4534 81.9594 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00581181 0.00582786 scale
151.116 131.072 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0064252 0.00644294 scale
137.232 117.069 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
186.783 164.575 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00774908 0.00777048 scale
105.673 104.982 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00844436 0.00846768 scale
96.4217 98.8464 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
287.64 309.55 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0200393 0.0200946 scale
34.2448 46.4308 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
118.684 169.914 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148804 0.0149215 scale
29.6355 64.0195 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
18.8359 86.7695 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
40.5481 171.293 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0173275 0.0173753 scale
5.48609 28.2343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0285049 0.0285836 scale
3.84426 16.5759 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
19.4739 74.2382 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
54.3032 212.337 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
51.4823 135.616 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
159.148 120.759 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
71.7297 36.315 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00798757 0.00800963 scale
48.6394 7.04028 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00844436 0.00846768 scale
49.8131 6.17879 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
423.139 53.1726 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
167.415 24.7777 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
225.404 35.7534 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
208.474 57.8002 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0123287 0.0123628 scale
73.3175 25.4425 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
222.435 87.5509 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130676 0.0131037 scale
69.4772 24.6091 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
658.974 228.968 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0072486 0.00726862 scale
127.684 63.1344 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00387454 0.00388524 scale
240.64 146.269 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00387454 0.00388524 scale
232.213 178.288 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00711798 0.00713764 scale
120.624 111.89 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
204.304 198.237 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
226.921 228.456 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
634.329 566.662 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
376.746 299.212 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00821914 0.00824184 scale
108.112 85.8013 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00949064 0.00951686 scale
83.0903 14.7265 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00898275 0.00900756 scale
73.8338 8.93583 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106109 0.0106402 scale
61.3522 7.045 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
150.492 19.9195 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0123287 0.0123628 scale
46.9514 4.18353 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
97.5261 10.0591 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0064252 0.00644294 scale
71.7737 7.80234 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00750301 0.00752373 scale
49.0336 8.72306 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612618 0.0061431 scale
34.8863 27.2387 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
62.3613 52.9109 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
84.7461 241.665 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00855475 0.00857838 scale
12.1441 48.4847 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
64.7221 386.994 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00387454 0.00388524 scale
29.0564 181.289 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00597107 0.00598756 scale
20.6312 124.954 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00711798 0.00713764 scale
69.1305 135.365 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00597107 0.00598756 scale
143.807 133.053 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
226.019 139.217 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00750301 0.00752373 scale
124.447 75.0292 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
385.584 148.751 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117839 0.0118165 scale
76.8961 26.623 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0067109 0.00672943 scale
117.789 20.816 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
232.753 68.9241 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
174.027 57.1221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
258.657 73.7863 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
443.857 125.372 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
317.325 34.4268 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
76.7544 9.56947 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
59.0238 10.5595 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612618 0.0061431 scale
58.8947 11.6635 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
173.135 45.2945 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
34.5794 134.649 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
41.9613 254.74 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00612618 0.0061431 scale
19.7643 119.01 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
40.8052 241.158 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
63.0572 266.295 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
41.8805 163.459 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
74.8641 202.307 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00918928 0.00921466 scale
52.3882 104.939 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00581181 0.00582786 scale
119.445 158.396 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
134.989 179.396 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00918928 0.00921466 scale
71.0143 92.5873 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
330.439 437.353 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00698492 0.00700422 scale
88.4133 134.63 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0065696 0.00658774 scale
102.498 141.018 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00684928 0.0068682 scale
99.6192 134.267 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
396.61 434.871 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
539.078 624.036 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
161.754 201.819 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
127.734 163.597 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
442.112 578.762 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00762704 0.0076481 scale
74.763 105.329 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
138.011 266.486 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00684928 0.0068682 scale
57.9316 136.807 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
109.948 256.649 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
54.5075 127.901 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
188.881 361.077 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
41.7197 113.307 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0072486 0.00726862 scale
36.029 69.7904 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
101.605 117.974 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
129.967 86.0576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00410957 0.00412092 scale
201.897 49.3749 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00273971 0.00274728 scale
307.978 83.0604 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134218 0.0134589 scale
62.2793 16.0244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
158.142 32.5662 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0357215 0.0358201 scale
21.5722 3.61138 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00530543 0.00532008 scale
166.48 52.1007 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00786923 0.00789096 scale
114.385 38.6138 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939126 0.0094172 scale
96.2842 33.2498 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00855475 0.00857838 scale
68.9594 6.30772 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0045433 0.00455585 scale
124.779 11.3107 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
162.345 15.5823 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
214.049 31.5866 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
237.751 44.6041 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0073769 0.00739728 scale
111.761 25.5067 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
608.151 151.066 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
161.955 31.8572 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939126 0.0094172 scale
81.8484 13.7206 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00798757 0.00800963 scale
94.6346 16.0095 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
241.938 50.0993 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00939126 0.0094172 scale
73.2873 10.1708 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
100.87 9.7574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00306309 0.00307155 scale
160.394 18.0853 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
120.324 15.7692 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
43.7652 172.637 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0163811 0.0164263 scale
5.8305 30.1905 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00597107 0.00598756 scale
16.9836 101.046 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00887768 0.0089022 scale
13.0642 79.222 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
26.0567 132.24 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
263.941 222.5 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
388.947 199.129 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
656.149 427.594 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00698492 0.00700422 scale
125.599 89.3533 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
208.664 178.279 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00530543 0.00532008 scale
170.047 60.0479 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00627747 0.00629481 scale
139.857 44.2619 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00855475 0.00857838 scale
101.472 33.0237 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
356.499 91.9253 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00684928 0.0068682 scale
110.511 17.8562 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
112.388 11.5313 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
87.8687 10.6287 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0168331 0.0168796 scale
22.2277 18.9312 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113789 0.0114103 scale
27.3085 24.4954 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
41.2406 43.0583 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
60.4227 51.9549 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
51.5839 27.156 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00844436 0.00846768 scale
10.8795 61.9733 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0399848 0.0400952 scale
2.3629 13.8156 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0144972 0.0145372 scale
8.60028 50.7903 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00335545 0.00336472 scale
157.74 285.364 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
155.627 188.161 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
543.67 646.028 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00898275 0.00900756 scale
96.0118 88.6267 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00762704 0.0076481 scale
113.597 99.5541 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
258.044 151.69 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
142.281 24.5425 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
30.4749 184.203 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00530543 0.00532008 scale
23.0047 136.453 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
31.0811 159.338 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109589 0.0109891 scale
15.9004 71.7564 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
37.8613 164.085 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00898275 0.00900756 scale
55.7268 106.972 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00597107 0.00598756 scale
92.136 154.541 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0072486 0.00726862 scale
120.92 105.484 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
239.296 216.093 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00786923 0.00789096 scale
50.0342 119.059 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00474532 0.00475843 scale
58.1731 188.287 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00530543 0.00532008 scale
24.8783 128.201 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0132812 0.0133179 scale
6.82617 40.1677 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101591 0.0101872 scale
10.2095 46.9276 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00564806 0.00566366 scale
19.6156 83.3471 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0064252 0.00644294 scale
25.5665 81.9564 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
69.3914 142.663 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00512553 0.00513969 scale
86.6349 117.388 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00493909 0.00495273 scale
182.572 63.0824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00798757 0.00800963 scale
112.259 38.2365 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00237266 0.00237921 scale
382.073 135.826 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0064252 0.00644294 scale
106.658 16.2317 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0073769 0.00739728 scale
101.574 23.8885 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
180.97 33.0654 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00547943 0.00549456 scale
122.164 23.4268 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00855475 0.00857838 scale
77.8492 16.5474 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00949064 0.00951686 scale
69.7487 15.5577 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0036243 0.00363431 scale
121.502 26.1866 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
330.035 65.6868 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00821914 0.00824184 scale
53.974 6.81401 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00193727 0.00194262 scale
246.388 29.6455 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101591 0.0101872 scale
23.8554 14.0922 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00887768 0.0089022 scale
10.7494 63.4585 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
84.7242 505.577 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0305081 0.0305924 scale
4.40014 23.9216 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100663 0.0100941 scale
12.3828 72.9502 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00949064 0.00951686 scale
14.1908 79.644 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00833251 0.00835552 scale
89.4064 106.743 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00136986 0.00137364 scale
547.328 643.102 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154375 0.0154801 scale
52.8952 53.6565 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00887768 0.0089022 scale
28.7395 98.1926 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00433187 0.00434383 scale
210.281 76.6397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00711798 0.00713764 scale
39.5702 16.8683 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00597107 0.00598756 scale
18.4322 60.0596 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134218 0.0134589 scale
7.86109 31.3251 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{502.188, 239.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007f0000ka000`40O003h00Oogoomgoo003oOoog
Ool00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00
ogoomgoo003oOoogOol006Uoo`@00?Moo`D008eoo`00J7oo00<007ooOol00Woo0P001goo4@00g7oo
00<007ooOol00goo0P00Rgoo001WOol00`00Oomoo`05Ool7000AOol70004Ool4003<Ool00`00Oomo
o`06Ool00`00Oomoo`28Ool006Ioo`03001oo`0000P001eoo`@000Aoo`800<Qoo`@000Qoo`03001o
ogoo009ooa4000Aoo`<006eoo`00IGoo00<007oo00001P000Woo00<007ooOol00P005goo0P000Woo
1`0000=oo`00Ool0aWoo0P000Woo00@007oo0000009oo`L0009oo`03001oogoo00Aoo`03001oogoo
00Eoo`P006aoo`00HWoo4@000Woo10000goo0`0017oo00<007ooOol0100000Aoo`00Oomoo`800004
Ool000000003Ool40034Ool30003Ool90002Ool00`00Ool000030003Ool40003Ool20002Ool20002
Ool6001XOol0061oo`8000=oo`d00003Ool0000000@0009oo`03001oo`0000D00007Ool00000001o
o`00Ool00P0000=oo`0000000`0000=oo`00000017oo00@007oo00000<9oo`L00003Ool000000080
0007Ool00000001oo`00Ool0100017oo0P0000=oo`00Ool00`000Woo0`0000=oo`00Ool00P000Woo
1@00Hgoo001NOol20005Ool<00000goo000000050003Ool700000goo001oo`03000017oo000007oo
2@000goo00@007ooOomoo`<00;Yoo`P000=oo`H00003Ool000000080009oo`03001oo`00008000=o
o`800005Ool007ooOol00004Ool01@00Oomoo`00Ool00P001goo0P00HGoo001LOol20002Ool20003
Ool70003Ool200000goo0000000700000goo0000000500000goo000000050002Ool90003Ool00`00
Oomoo`04Ool2002gOol9000017oo000007oo1`001Goo10001Woo00<007ooOol01Woo1`002Goo1@00
G7oo001JOol20003Ool40002Ool20002Ool30003Ool20002Ool20003Ool01P00Oomoo`00Ool0009o
o`@000Moo`03001oo`0000P000=oo`03001oogoo00Ioo`800;=oo`L00005Ool00000Ool00008Ool0
0`00Oomoo`06Ool00`00Oomoo`0NOol01@00Oomoo`00Ool00P00FWoo001GOol30004Ool20002Ool2
00000goo0000000300001goo001oogoo001oo`0000=oo`05001oogooOol00003Ool2000017oo0000
00002Goo0P0000=oo`0000001P000goo0`0027oo0P00[goo0P0000=oo`000000100000Aoo`00001o
o`8000Ioo`03001oogoo01Yoo`8000]oo`03001oogoo00<0009oo`8005Qoo`00EGoo0P001goo00P0
07ooOomoo`00Ool007oo0P000Woo0P0000Aoo`00000000Aoo`04001oogoo0004Ool00`00Ool0000>
Ool20002Ool200000goo00000002Ool200000goo001oo`09Ool2002ZOol30004Ool40007Ool20002
Ool2000ZOol00`00Oomoo`0200000goo001oo`02Ool2001FOol005=oo`8000Qoo`8000Aoo`8000=o
o`H000Ioo`05001oogooOol00003Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool200000goo001oo`0;
Ool2002VOol40007Ool00`00Oomoo`08Ool2000/Ool200001Goo000007oo00001Goo0`00Dgoo001A
Ool20005Ool20002Ool40003Ool20005Ool40004Ool20004Ool4000COol20006Ool01000Oomoo`00
0goo0P002Woo0P00XWoo0P000Woo00@007oo000001Moo`03001oogoo02Ioo`<00003Ool007oo00<0
00Aoo`80055oo`00Cgoo0P000goo10000Woo1`0000=oo`0000002Woo10002goo0`004Goo1P0027oo
00<007ooOol02Woo0P00WWoo0P0017oo00@007oo000001Aoo`800003Ool007oo02Yoo`03001oogoo
00@000Eoo`8000Moo`<004Eoo`00CWoo00<007ooOol00Woo00@007ooOomoo`L00003Ool000000080
01Uoo`05001oogooOol0000]Ool00`00Oomoo`2IOol20002Ool30002Ool00`00Oomoo`0DOol2000`
Ool300000goo001oo`05Ool20003Ool20003Ool20013Ool004eoo`03001oogoo009oo`05001oogoo
Ool00003Ool400000goo001oo`0LOol01000Oomoo`009Woo0P001Woo00<007ooOol0UWoo0P0017oo
00<007oo00006Goo00<007ooOol0;goo100017oo00<007oo00000Woo0`001goo0P00@Goo0014Ool5
0003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool200001Goo001oo`00Ool00P007Goo0`009goo00<0
07oo00001Woo0P00UGoo00<007ooOol017oo0`00Bgoo00@007oo000000=oo`@0009oo`03001oo`00
00Uoo`03001oogoo03ioo`00@Goo0`001Goo0`001Woo00<007ooOol017oo0P000Woo00<007ooOol0
Agoo0P002Goo00<007ooOol0TGoo00<007ooOol0Dgoo0`001Goo0`000Woo00@007ooOol000Qoo`03
001oogoo03ioo`00@7oo00<007ooOol01Woo00@007oo000000Eoo`03001oogoo00Eoo`03001oogoo
04Eoo`8000Uoo`04001oogooOol3002@Ool20003Ool60018Ool2000?Ool00`00Oomoo`040007Ool0
0`00Oomoo`0mOol003moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo04Eoo`8000Qoo`<00003Ool007oo009oo`<008]oo`8000Aoo`03001oogoo0080
0003Ool007oo04Ioo`<000moo`03001oogoo00H000Eoo`03001oogoo03eoo`00?Woo00<007ooOol0
1Goo0P0017oo0`0017oo00<007ooOol00goo00<007ooOol0E7oo2@00R7oo00<007ooOol017oo1000
00=oo`00Ool0B7oo1@002goo00@007ooOomoo`<0009oo`8000Aoo`03001oogoo03eoo`00?Goo00<0
07ooOol01Goo00@007ooOomoo`L000Aoo`800003Ool0000005Ioo`800004Ool00000Ool300000goo
00000025Ool00`00Oomoo`04001BOol00`00Ool0000;Ool01@00Oomoo`00Ool00P000Woo10000Woo
00<007ooOol0?Goo000mOol00`00Oomoo`04Ool01P00Oomoogoo001oo`H000Ioo`03001oogoo00=o
o`03001oogoo055oo`T0009oo`03001oogoo081oo`T0055oo`@000aoo`03001oogoo00<00003Ool0
000000@00003Ool007oo03ioo`00?7oo00<007ooOol017oo00@007ooOomoo`D0009oo`03001oo`00
00]oo`80059oo`/00003Ool007oo07moo`03001oogoo00L0051oo`D000aoo`03001oogoo00=oo`03
001oo`0000800004Ool00000000oOol003aoo`03001oogoo00Aoo`03001oogoo00H00005Ool007oo
Ool0001QOol;001oOol01`00Oomoo`00Ool007oo00<000=oo`<004]oo`800003Ool0000000aoo`03
001oogoo00Ioo`H003moo`00>goo00<007ooOol00goo0P000Woo20000goo00<007ooOol0H7oo2P00
OGoo0P0017oo10001Goo00<007oo0000BWoo00<007oo00000P003Woo00<007ooOol01goo0`0000=o
o`000000?Goo000kOol00`00Oomoo`02Ool00`00Oomoo`02Ool60006Ool00`00Oomoo`1QOol9001k
Ool00`00Oomoo`05Ool20006Ool3001;Ool01000Ool000003Woo00<007ooOol027oo0`000Woo00<0
07ooOol0>Woo000kOol01@00Oomoogoo00000Woo0P0000=oo`0000000`001goo00<007ooOol0Hgoo
1P0000=oo`00Ool0N7oo00D007ooOomoo`0000Eoo`03001oogoo05=oo`03001oogoo00moo`8000Mo
o`800003Ool007oo009oo`03001oogoo03Uoo`00>goo00D007ooOol007oo0080009oo`80009oo`03
001oogoo00Ioo`03001oogoo06Aoo`D00003Ool007oo07Moo`04001oogooOol3001^Ool70002Ool4
0002Ool00`00Oomoo`0hOol003]oo`06001oogoo001oo`001Goo00<007ooOol027oo00<007ooOol0
Igoo00D007oo001oo`0007Moo`05001oogoo001oo`03001[Ool2000:Ool30003Ool00`00Oomoo`0g
Ool003]oo`<00003Ool007oo009oo`@000Yoo`03001oogoo06Moo`05001oo`00001oo`02001cOol2
0003Ool400000goo001oo`1XOol01000Oomoo`002Woo0P000goo0P00>7oo000kOol20002Ool01000
Oomoogoo0P0000=oo`0000002Goo00<007ooOol0Igoo10000goo00<007ooOol0Kgoo00<007ooOol0
0goo0P0000Aoo`00Ool006Uoo`04001oogoo000AOol00`00Oomoo`0eOol003Yoo`03001oo`00009o
o`03001oogoo00<00003Ool0000000Qoo`03001oogoo06Uoo`<000Aoo`03001oogoo06eoo`03001o
ogoo00Aoo`03001oogoo008006Yoo`@000aoo`<000=oo`03001oogoo03Aoo`00>Goo00L007ooOomo
o`00Ool00002Ool50009Ool00`00Oomoo`1`Ool00`00Oomoo`1/Ool00`00Oomoo`07Ool2001kOol0
1000Oomoo`000goo00<007ooOol0<goo000iOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Ioo`03001oogoo06aoo`8000Aoo`03001oogoo06]oo`04001oogooOol500000goo0000
001kOol00`00Ool00005Ool00`00Oomoo`0bOol003Qoo`03001oogoo00=oo`03001oogoo00800003
Ool0000000Qoo`03001oogoo06ioo`03001oogoo00=oo`03001oogoo06Uoo`03001oogoo009oo`05
001oogooOol0001oOol20005Ool00`00Oomoo`0bOol003Moo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo071oo`8000Aoo`03001oogoo06Moo`03001oogoo009oo`06001o
o`00001oo`00Ogoo1@000goo00<007ooOol0<Goo000fOol00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`1_Ool30004Ool00`00Oomoo`1VOol00`00Oomoo`04Ool50020Ool20002Ool01@00Oomo
ogoo0000<Woo000fOol00`00Oomoo`07Ool00`00Oomoo`08Ool2001`Ool60004Ool00`00Oomoo`1T
Ool00`00Oomoo`05Ool50020Ool01@00Oomoogoo000017oo00<007ooOol0;goo000eOol00`00Oomo
o`09Ool40002Ool4001aOol00`00Oomoo`02Ool30003Ool00`00Oomoo`1SOol00`00Oomoo`2:Ool0
1000Oomoogoo0P0017oo00<007ooOol0;goo000eOol00`00Oomoo`0=Ool2001eOol00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`2:Ool01000Oomoogoo0P001Goo00<007oo
Ool0;Woo000dOol00`00Oomoo`24Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`1POol0
0`00Oomoo`22Ool00`00Oomoo`06Ool2000017oo000000001Woo00<007ooOol0;Goo000cOol00`00
Oomoo`25Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`1OOol00`00Oomoo`21Ool30009
Ool00`00Ool00008Ool00`00Oomoo`0/Ool0039oo`03001oogoo08Ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo05eoo`8008Eoo`8000eoo`<000Aoo`03001oogoo02aoo`00<Woo00<007oo
Ool01Woo00<007ooOol0OGoo00<007ooOol01goo00<007ooOol00goo00<007ooOol0Fgoo00<007oo
Ool01Woo0P00S7oo0`001Goo00<007ooOol0:goo000aOol00`00Oomoo`06Ool00`00Ool0001nOol0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`1KOol00`00Oomoo`06Ool2002=Ool40004Ool0
0`00Oomoo`0ZOol0035oo`03001oogoo00Ioo`04001oogoo001nOol00`00Oomoo`05Ool00`00Oomo
o`05Ool9001COol00`00Oomoo`2HOol20005Ool00`00Oomoo`0YOol0031oo`03001oogoo00Moo`<0
07moo`8000Aoo`8000Ioo`800003Ool007oo00Ioo`80055oo`03001oogoo09moo`03001oogoo02Uo
o`00<7oo00<007ooOol0Rgoo10001Goo0`0017oo00<007ooOol01Woo0P00CWoo00<007ooOol0XGoo
00<007ooOol0:7oo000_Ool00`00Oomoo`2DOol50003Ool00`00Oomoo`08Ool2001<Ool00`00Oomo
o`2QOol00`00Oomoo`0XOol002moo`03001oogoo09=oo`03001oogoo00800003Ool007oo009oo`03
001oogoo00Uoo`03001oogoo04Qoo`03001oogoo02Eoo`@007Aoo`03001oogoo00=oo`03001oogoo
02Moo`00;Woo00<007ooOol0Tgoo00@007ooOomoo`800003Ool007oo009oo`03001oogoo00Uoo`03
001oogoo04Moo`03001oogoo02Ioo`05001oogooOol0001_Ool60005Ool00`00Oomoo`0VOol002io
o`03001oogoo09=oo`04001oogooOol50003Ool00`00Oomoo`09Ool00`00Oomoo`16Ool00`00Oomo
o`0UOol00`00Oomoo`02Ool00`00Oomoo`1]Ool00`00Ool000030006Ool00`00Oomoo`0UOol002eo
o`03001oogoo09=oo`03001oogoo009oo`03001oo`0000<0009oo`03001oogoo00Yoo`03001oogoo
04Aoo`03001oogoo02Moo`05001oogooOol0001^Ool00`00Oomoo`030007Ool00`00Oomoo`0UOol0
02eoo`03001oogoo009oo`<008eoo`03001oogoo009oo`03001oogoo00@0009oo`03001oogoo00Yo
o`03001oogoo04Aoo`03001oogoo02Moo`@0071oo`03001oo`00009oo`<000Eoo`03001oogoo02Ao
o`00;7oo00<007ooOol00Woo1@00:goo0P00Ggoo00<007ooOol00goo00D007oo001oo`0000Aoo`03
001oogoo00Yoo`03001oogoo049oo`03001oogoo09eoo`07001oogooOol007oo00001Goo00<007oo
Ool097oo000/Ool00`00Oomoo`02Ool01P00Oomoo`00Ool002Yoo`03001oo`0005eoo`03001oogoo
00Aoo`04001oo`000005Ool00`00Oomoo`0;Ool00`00Oomoo`11Ool00`00Oomoo`04Ool2002KOol5
0004Ool00`00Oomoo`0SOol002aoo`04001oogooOol3000017oo001oo`00:Woo0`00GGoo00<007oo
Ool01Goo00@007ooOomoo`8000=oo`03001oogoo00Yoo`03001oogoo041oo`03001oogoo00Aoo`<0
031oo`<006Qoo`H000=oo`03001oogoo02=oo`00:goo00<007ooOol0100000Eoo`00001oo`0008Yo
o`03001oogoo00Uoo`8000=oo`03001oogoo00Yoo`03001oogoo041oo`03001oogoo00=oo`04001o
ogoo000^Ool20003Ool00`00Oomoo`0>Ool2001FOol60003Ool00`00Oomoo`0ROol002]oo`05001o
ogoo001oo`02000017oo00000000RWoo00<007ooOol02Woo1@0000=oo`00Ool02goo00<007ooOol0
?Woo00<007ooOol017oo00@007ooOol002ioo`03001oogoo009oo`03001oogoo00ioo`<005Eoo`@0
0003Ool007oo009oo`03001oogoo029oo`00:Woo00@007ooOol000Aoo`<008]oo`03001oogoo00Yo
o`@00003Ool0000000aoo`03001oogoo03ioo`03001oogoo00Aoo`04001oogoo000]Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`1EOol60003Ool00`00Oomoo`0QOol002Yoo`04001oogoo
0006Ool00`00Oomoo`29Ool00`00Oomoo`0:Ool20002Ool200000goo001oo`0:Ool00`00Oomoo`0m
Ool00`00Oomoo`04Ool5000]Ool00`00Oomoo`04Ool00`00Oomoo`1VOol60003Ool00`00Oomoo`0Q
Ool002Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08Uoo`03001oogoo00Uoo`07001o
o`00001oo`00Ool00P002goo00<007ooOol0?Goo00<007ooOol017oo0`00<7oo00<007ooOol00Woo
00<007ooOol0Igoo1P000goo00<007ooOol08Goo000YOol00`00Oomoo`02Ool20002Ool2002<Ool0
0`00Oomoo`09Ool00`00Ool0000300000goo0000000;Ool00`00Oomoo`0lOol00`00Oomoo`03Ool4
00000goo001oo`0^Ool20002Ool2001YOol50005Ool00`00Oomoo`0POol002Qoo`03001oogoo00Eo
o`@008aoo`03001oogoo00Yoo`04001oo`000002Ool2000;Ool00`00Oomoo`0lOol00`00Oomoo`03
Ool01P00Oomoo`00Ool0035oo`8006eoo`<000Eoo`03001oogoo021oo`00:7oo00<007ooOol01Woo
0P00SGoo00<007ooOol02Woo00<007ooOol00Woo00<007oo00002goo00<007ooOol0?7oo00<007oo
Ool00Woo00@007ooOomoo`<00:Uoo`03001oogoo01moo`00:7oo00<007ooOol0UGoo00<007ooOol0
2goo00@007oo000000=oo`03001oogoo00Qoo`03001oogoo03]oo`03001oo`0000/00:Qoo`03001o
ogoo01moo`009goo00<007ooOol0UWoo00<007ooOol037oo0`000goo00<007ooOol027oo00<007oo
Ool0>goo0P001Goo0P0000=oo`0000000Woo00<007ooOol0WGoo0P001Woo00<007ooOol07goo000W
Ool00`00Oomoo`2GOol00`00Oomoo`0;Ool01000Ool000000goo00<007ooOol01Woo00<007ooOol0
>goo00<007ooOol01Goo00<007oo00001Goo0P00WGoo0P001Woo00<007ooOol07goo000WOol00`00
Oomoo`04Ool2002AOol00`00Oomoo`0<Ool30003Ool00`00Oomoo`06Ool00`00Oomoo`0jOol20002
Ool:0005Ool00`00Oomoo`2JOol20006Ool00`00Oomoo`0OOol002Moo`03001oogoo00Aoo`03001o
o`00091oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo03Uoo`05001o
o`00Ool00002Ool60002Ool20004Ool00`00Oomoo`2JOol00`00Oomoo`05Ool00`00Oomoo`0NOol0
02Ioo`03001oogoo00Aoo`04001oogoo002@Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`0hOol20002Ool200000goo00000006Ool20002Ool00`00Oomoo`02Ool00`00
Oomoo`2QOol00`00Oomoo`0NOol002Ioo`03001oogoo009oo`H0095oo`03001oogoo00Yoo`03001o
o`0000Eoo`03001oogoo00Aoo`03001oogoo03Moo`04001oogooOol200000goo001oo`02Ool40003
Ool200000goo001oo`03Ool00`00Oomoo`2QOol00`00Oomoo`0MOol002Ioo`05001oogooOol00004
Ool3002AOol00`00Oomoo`08Ool01000Oomoo`001Goo00<007ooOol00goo00<007ooOol0>7oo00L0
07ooOomoo`00Ool00003Ool00`00Oomoo`02Ool20003Ool00`00Ool00003Ool00`00Oomoo`2QOol0
0`00Oomoo`0MOol002Eoo`05001oogooOol00003Ool20003Ool00`00Oomoo`2>Ool00`00Oomoo`08
Ool50004Ool00`00Oomoo`02Ool00`00Oomoo`0hOol01000Oomoogoo0`0017oo00@007ooOomoo`@0
00=oo`03001oo`0000=oo`03001oogoo0:5oo`03001oogoo01aoo`009Goo00<007ooOol020000goo
00<007ooOol0SWoo00<007ooOol01Woo00@007oo001oo`<000Aoo`04001oogoo000kOol00`00Oomo
o`030004Ool00`00Ool000030002Ool20003Ool20003Ool00`00Oomoo`2QOol00`00Oomoo`0LOol0
02Eoo`D00003Ool0000000@0009oo`03001oogoo08moo`03001oogoo00Aoo`04001oogooOol20000
0goo00000003Ool00`00Ool0000lOol00`00Oomoo`030004Ool70002Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo01ioo`<007moo`03001oogoo01aoo`0097oo0`0000=oo`00Ool02P00TWoo00<0
07ooOol017oo00<007oo00000`0000=oo`00Ool00Woo00<007oo0000>goo00@007ooOomoo`8000Ao
o`03001oo`0000H00003Ool0000000=oo`8000=oo`03001oogoo01ioo`80081oo`03001oogoo01ao
o`008goo0`000Woo2P0000=oo`000000TWoo0P001Goo00<007oo00000goo00@007ooOomoo`8003ao
o`04001oogooOol20004Ool5000017oo000007oo0P0000Moo`00Oomoo`00Ool00003Ool00`00Oomo
o`2OOol00`00Oomoo`0LOol0025oo`800003Ool00000009oo`<00003Ool0000000P009=oo`<000Ao
o`800003Ool007oo00@003aoo`04001oogooOol20005Ool900000goo001oo`060003Ool00`00Oomo
o`2POol00`00Oomoo`0KOol0021oo`04001oogooOol200001Goo00000000Ool01P0000=oo`000000
0Woo00<007ooOol0Tgoo2@0017oo00<007ooOol0>Goo00@007ooOomoo`8000=oo`l000=oo`8000=o
o`03001oogoo0:1oo`03001oogoo01]oo`007goo00<007ooOol00Woo0P0000Eoo`00000007oo00H0
0003Ool007oo009oo`03001oogoo0:1oo`03001oogoo03Uoo`04001oogooOol2000017oo000007oo
300000=oo`00Ool00Woo100000=oo`00Ool0XGoo00<007ooOol06goo000NOol00`00Oomoo`03Ool2
0002Ool4000017oo000007oo0`0017oo00<007ooOol0Wgoo00<007ooOol0>Goo00@007ooOomoo`<0
009oo`05001oo`00001oo`0:0003Ool20002Ool2002ROol00`00Oomoo`0KOol001eoo`03001oogoo
00=oo`03001oo`00009oo`X000Ioo`03001oogoo09ioo`03001oogoo03Uoo`04001oogooOol20000
1Goo00000000Ool03@000Woo0P0017oo00<007ooOol0X7oo00<007ooOol06goo000MOol00`00Oomo
o`03Ool01000Oomoo`000Woo2@001goo00<007ooOol0WGoo00<007ooOol0>Goo00<007ooOol01P00
0goo0P000Woo00<007oo00001P0000=oo`00000017oo00<007ooOol0X7oo00<007ooOol06goo000L
Ool00`00Oomoo`04Ool01@00Oomoo`00Ool02P0027oo00<007ooOol0W7oo00<007ooOol0>Woo0P00
00Aoo`00000000Aoo``00003Ool00000008000Aoo`03001oogoo0:1oo`03001oogoo01]oo`0077oo
00<007ooOol017oo00@007ooOomoo`/000Qoo`03001oogoo09Eoo`03001oogoo00Aoo`03001oogoo
03Yoo`800003Ool007oo0080009oo`04001oogooOol600000goo00000002Ool30003Ool00`00Ool0
002ROol00`00Oomoo`0JOol001aoo`03001oogoo00Aoo`03001oogoo009oo`P00003Ool007oo00Mo
o`03001oogoo09eoo`03001oogoo03Uoo`03001oogoo00@00004Ool007ooOol600001goo00000000
Ool007oo00<000=oo`03001oo`000:9oo`03001oogoo01Yoo`006goo00<007ooOol01Goo00<007oo
Ool00Woo2@002Goo00<007ooOol0WGoo00<007ooOol0>Goo1@0000Aoo`00001oo`800003Ool007oo
00800003Ool0000000P000=oo`8009Qoo`<000Qoo`03001oogoo01Yoo`006goo00<007ooOol01Goo
00<007ooOol00Woo2@002Woo00<007ooOol0W7oo00<007ooOol0>Goo10000goo0P000goo0`0000=o
o`0000001P0000Qoo`00Ool007oo001oo`00Ugoo00@007ooOol000Qoo`03001oogoo01Yoo`006goo
00<007ooOol01Goo00<007ooOol00Woo2@002Woo00<007ooOol0W7oo00<007ooOol0>7oo00<007oo
00000P000Woo100000Aoo`00001oo`D00008Ool00000Ool007oo001oo`@009Uoo`03001oo`0000Qo
o`03001oogoo01Yoo`006goo00<007ooOol01Goo00<007ooOol00Woo2@002Woo00<007ooOol0W7oo
00<007ooOol0>7oo00D007oo001oo`00009oo`80009oo`800003Ool0000000D00004Ool00000Ool2
00000goo00000002002JOol00`00Oomoo`07Ool00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`03
001oogoo009oo`T000Yoo`03001oogoo09aoo`03001oogoo03Qoo`05001oo`00Ool00002Ool01000
Oomoogoo2P0000Aoo`00001oo`800004Ool007oo002JOol20009Ool00`00Oomoo`0JOol001]oo`03
001oogoo00Eoo`03001oogoo00=oo`P000Yoo`03001oogoo09aoo`03001oogoo03Moo`05001oogoo
001oo`040003Ool900001Goo00000000Ool01@00Vgoo0P002Goo00<007ooOol06Woo000KOol00`00
Oomoo`05Ool00`00Oomoo`03Ool7000;Ool00`00Oomoo`2LOol00`00Oomoo`0gOol01`00Oomoo`00
Ool007oo0080009oo`T000=oo`P00:Ioo`03001oogoo01Yoo`006goo00<007ooOol017oo00<007oo
Ool017oo1@003Goo00<007ooOol0W7oo00<007ooOol0=goo00D007ooOol007oo00D00003Ool00000
00L000=oo`D00003Ool000000:Ioo`03001oogoo01Yoo`006goo00<007ooOol017oo00<007ooOol0
0goo00<007oo00000P0000=oo`00Ool02goo00<007ooOol0W7oo00<007ooOol0=goo00<007ooOol0
0P0000Aoo`00001oo`/000=oo`@0009oo`03001oogoo0:Eoo`03001oogoo01Yoo`006goo00<007oo
Ool017oo00<007ooOol00goo00<007oo00000P0000=oo`00Ool02goo00<007ooOol0W7oo00<007oo
Ool0=goo00D007ooOomoo`00009oo`04001oo`00Ool<000017oo000000000Woo00<007ooOol047oo
0P00Tgoo00<007ooOol06Woo000LOol00`00Oomoo`03Ool00`00Oomoo`03Ool01P00Ool00000Ool0
00aoo`03001oogoo09eoo`03001oogoo03Qoo`04001oogoo0002Ool01@00Oomoo`00Ool02@000goo
0P0000Aoo`000000019oo`<0099oo`03001oogoo01Yoo`0077oo00<007ooOol00goo00<007ooOol0
0goo0`0000=oo`00000037oo00<007ooOol0WGoo00<007ooOol0>7oo00<007ooOol00P000Woo00<0
07oo00001`0000=oo`00Ool00Woo00@007oo001oo`8001=oo`04001oogoo002AOol00`00Oomoo`0J
Ool001aoo`03001oogoo00=oo`03001oogoo00Aoo`<000ioo`03001oogoo09eoo`03001oogoo03Qo
o`03001oogoo0080009oo`800004Ool00000Ool3000017oo001oogoo20004goo00<007oo0000TWoo
00<007ooOol06Woo000MOol00`00Oomoo`02Ool00`00Oomoo`04Ool4000<Ool00`00Oomoo`2NOol0
0`00Oomoo`0iOol01@00Ool007oo00000Woo3P0017oo0P0057oo00<007ooOol0TGoo00<007ooOol0
6Woo000MOol00`00Oomoo`03Ool00`00Oomoo`03Ool4000<Ool00`00Oomoo`2NOol00`00Oomoo`0i
Ool00`00Ool00002Ool00`00Oomoo`070002Ool30004Ool200000goo001oo`2VOol00`00Oomoo`0J
Ool001ioo`03001oogoo009oo`03001oogoo00=oo`<000aoo`03001oogoo09Qoo`8000Eoo`03001o
ogoo03Yoo`03001oo`00009oo`80009oo`T000=oo`800005Ool00000Ool0002VOol00`00Oomoo`0J
Ool001ioo`03001oogoo009oo`03001oogoo00Aoo`8000]oo`03001oogoo09Uoo`8000Eoo`03001o
ogoo03]oo`80009oo`80009oo`H000=oo`<0009oo`04001oo`00Ool2002UOol00`00Oomoo`0JOol0
01moo`05001oogooOol00005Ool40009Ool00`00Oomoo`2JOol00`00Ool00004Ool00`00Oomoo`0l
Ool00`00Ool00002Ool300001Goo001oogoo00000Woo0`000Woo00D007ooOomoo`000:Moo`03001o
ogoo01Yoo`0087oo00@007ooOol000Aoo`06001oo`00001oo`001goo00<007ooOol0VWoo100017oo
00<007ooOol0?7oo0`0017oo20000goo0P00[7oo00<007ooOol06Woo000QOol00`00Ool00005Ool2
00000goo00000006Ool00`00Oomoo`2KOol40004Ool00`00Oomoo`0lOol01000Ool000000goo1@00
1Goo0P00[Goo00<007ooOol06Woo000ROol20005Ool00`00Ool000020004Ool2002NOol30005Ool0
0`00Oomoo`0lOol20002Ool20003Ool00`00Oomoo`02Ool300000goo001oo`2SOol30006Ool00`00
Oomoo`0JOol002=oo`@0009oo`800004Ool007ooOol3002OOol01000Ool000001Goo00<007ooOol0
?7oo00<007oo00000goo200017oo00<007ooOol00goo0P00WGoo0`001Woo00<007ooOol06Woo000S
Ool01000Oomoogoo2000XGoo00<007ooOol00`000goo00<007ooOol0?Goo00<007oo00001Woo0`00
1Woo00<007ooOol00goo0`00W7oo0`001Woo00<007ooOol06Woo000SOol00`00Oomoo`2[Ool20000
0goo00000003Ool00`00Oomoo`0mOol00`00Ool00005Ool50005Ool00`00Oomoo`2QOol40006Ool0
0`00Oomoo`0JOol002=oo`03001oogoo00Eoo`800:Aoo`D000=oo`03001oogoo03eoo`03001oo`00
00Ioo`<000Eoo`03001oogoo0:9oo`@000Ioo`03001oogoo01Yoo`008goo00<007ooOol017oo00<0
07oo0000[7oo00<007ooOol0?Goo00@007ooOol000Ioo`03001oogoo00Aoo`03001oogoo0:9oo`<0
00Ioo`03001oogoo01]oo`0097oo00<007ooOol017oo0P00[7oo00<007ooOol0?Goo00@007ooOol0
00aoo`03001oogoo0:=oo`8000Moo`03001oogoo01]oo`0097oo00<007ooOol0Zgoo0P001Goo00<0
07ooOol0?Woo00<007ooOol00P002Woo00<007ooOol0[7oo00<007ooOol06goo000TOol00`00Oomo
o`2ZOol01000Oomoo`0017oo00<007ooOol0?Woo00<007ooOol00Woo0P000goo0P0000=oo`000000
X7oo0P003Goo00<007ooOol06goo000TOol00`00Oomoo`2YOol01@00Oomoogoo00000goo00<007oo
Ool0?goo00<007ooOol017oo1P00/Goo00<007ooOol06goo000TOol00`00Oomoo`0GOol2002AOol0
1000Oomoo`000goo00<007ooOol0?goo00<007ooOol01Woo1000@goo0`00Jgoo00<007ooOol06goo
000UOol00`00Oomoo`0FOol2002AOol30004Ool00`00Oomoo`0oOol00`00Oomoo`06Ool40013Ool0
0`00Ool0001[Ool00`00Oomoo`0KOol002Eoo`03001oogoo01Moo`03001oogoo09Ioo`03001oogoo
041oo`03001oogoo00Eoo`@004=oo`<006Yoo`03001oogoo01aoo`009Goo00<007ooOol0/7oo00<0
07ooOol0@7oo00<007ooOol01Goo0P0000=oo`00Ool0[goo00<007ooOol077oo000UOol00`00Oomo
o`04Ool2002YOol00`00Oomoo`11Ool00`00Oomoo`05Ool4002NOol00`00Oomoo`0?Ool00`00Oomo
o`0LOol002Eoo`03001oogoo00Aoo`800:1oo`<000Ioo`03001oogoo045oo`03001oogoo00Eoo`<0
09ioo`03001oo`00011oo`03001oogoo01aoo`009Woo00<007ooOol00goo0P00X7oo00@007ooOol0
00Eoo`03001oogoo049oo`03001oogoo00Eoo`<009eoo`03001oo`00011oo`03001oogoo01aoo`00
9Woo00<007ooOol00goo0`00Wgoo00@007ooOol000Eoo`03001oogoo049oo`03001oogoo00Eoo`03
001oo`0009eoo`<000moo`03001oogoo01eoo`009goo00<007ooOol00Woo1000WWoo10001Goo00<0
07ooOol0@Woo00<007ooOol01Goo0`00[goo00<007ooOol07Goo000WOol00`00Oomoo`03Ool00`00
Oomoo`03002SOol00`00Oomoo`14Ool00`00Oomoo`2eOol00`00Oomoo`0NOol002Moo`03001oogoo
00=oo`<00003Ool000000:=oo`03001oogoo04Aoo`03001oogoo08]oo`<002Moo`03001oogoo01io
o`009goo00<007ooOol0Zgoo00<007ooOol0AGoo00<007ooOol0:Goo00<007ooOol0Ggoo0P00:7oo
00<007ooOol07Woo000WOol00`00Oomoo`02Ool:002OOol00`00Oomoo`15Ool00`00Oomoo`0XOol0
0`00Ool00029Ool00`00Oomoo`0OOol002Qoo`04001oogoo000:Ool2002LOol00`00Oomoo`17Ool0
0`00Oomoo`04Ool2000QOol30029Ool00`00Oomoo`0OOol002Qoo`<0009oo`<000Qoo`03001oogoo
09Uoo`03001oogoo04Moo`03001oogoo00Eoo`800:aoo`03001oogoo01moo`009goo0`000goo0`00
2Goo00<007ooOol0V7oo00<007ooOol0B7oo00<007ooOol00goo00<007oo0000[7oo00<007ooOol0
7goo000VOol01000Oomoo`000goo0`002Woo00<007ooOol0Ugoo00<007ooOol0B7oo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0YGoo00<007ooOol087oo000UOol00`00Oomoo`02Ool00`00
Oomoo`0200000goo001oo`09Ool00`00Oomoo`2FOol00`00Oomoo`18Ool00`00Oomoo`07Ool4002V
Ool00`00Oomoo`0POol002Eoo`03001oogoo009oo`08001oogoo001oo`00Ool000Qoo`<009Ioo`03
001oogoo04Yoo`03001oogoo00Moo`<00:Eoo`03001oogoo025oo`0097oo00<007ooOol00goo00@0
07oo001oo`800003Ool007oo00Moo`04001oo`00002EOol00`00Oomoo`1:Ool00`00Oomoo`07Ool0
0`00Oomoo`2LOol20007Ool00`00Oomoo`0QOol002Aoo`03001oogoo00Aoo`03001oo`0000<000Qo
o`03001oogoo008009Aoo`03001oogoo04aoo`03001oogoo00=oo`800:1oo`8000Moo`03001oogoo
025oo`0097oo00<007ooOol017oo00<007oo0000100027oo0`0000=oo`00Ool0TWoo00<007ooOol0
C7oo00<007ooOol00Woo0P0000=oo`0000000P00:Goo00<007ooOol0KGoo0`0027oo00<007ooOol0
8Woo000SOol00`00Oomoo`06Ool8000:Ool00`00Oomoo`2AOol00`00Oomoo`1=Ool00`00Oomoo`05
0003Ool2000VOol3001^Ool01000Oomoo`001goo00<007ooOol08Woo000SOol00`00Oomoo`06Ool5
00000goo001oo`020008Ool00`00Oomoo`2@Ool00`00Oomoo`1>Ool01000Oomoogoo0P0000=oo`00
Ool017oo00<007ooOol08goo00<007oo0000KWoo00@007oo000000Ioo`03001oogoo02=oo`008goo
00<007ooOol01Woo1`0000Aoo`00Ool000Moo`03001oogoo091oo`03001oogoo04moo`03001oogoo
00<000Moo`03001oogoo02=oo`03001oogoo06eoo`@000Ioo`03001oogoo02=oo`008goo00<007oo
Ool01Woo0`000goo00<007ooOol00P001goo00<007ooOol0Sgoo00<007ooOol0D7oo00@007oo001o
o`<000Moo`03001oogoo099oo`8000Moo`03001oogoo02Aoo`008goo00<007ooOol01Woo1`000Woo
0P001goo00<007ooOol0Sgoo00<007ooOol0DGoo0P0000=oo`0000000P001Woo00<007ooOol0Tgoo
00<007ooOol01Goo00<007ooOol097oo000SOol00`00Oomoo`05Ool00`00Ool000060002Ool20006
Ool00`00Oomoo`2>Ool00`00Oomoo`1BOol80005Ool00`00Oomoo`2JOol00`00Oomoo`0UOol002=o
o`03001oogoo00Ioo`800008Ool007ooOol007oo001oo`8000Ioo`03001oogoo08ioo`03001oogoo
05=oo`P000Aoo`03001oogoo09Yoo`03001oogoo02Eoo`008goo00<007ooOol01Woo0P0000Aoo`00
0000009oo`800003Ool007oo00Eoo`03001oogoo08eoo`03001oogoo05Aoo`P000Aoo`03001oogoo
09Uoo`03001oogoo02Ioo`008goo00<007ooOol01goo100000=oo`0000000`001goo00<007ooOol0
SGoo00<007ooOol0E7oo2P000Woo00<007ooOol0V7oo00<007ooOol09goo000SOol00`00Oomoo`07
Ool5000017oo000000001goo00<007ooOol0Ogoo0P0037oo00<007ooOol0EWoo1`000Woo0P00SGoo
0`0017oo0`0017oo00<007ooOol09goo000TOol00`00Oomoo`07Ool5000017oo001oo`001Woo00<0
07ooOol0Ogoo0P002goo00<007ooOol0Egoo1@000Woo0`00SWoo0`000Woo00<007oo00000P000goo
00<007ooOol0:7oo000TOol00`00Oomoo`09Ool40002Ool00`00Oomoo`04Ool00`00Oomoo`27Ool3
00000goo001oo`1JOol30003Ool3002BOol00`00Ool000030003Ool00`00Oomoo`0XOol002Eoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo08Qoo`03001oogoo008005aoo`L0099oo`03001o
ogoo00<000=oo`03001oogoo02Uoo`009Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
Pgoo0`0000=oo`00Ool00Woo00<007ooOol0G7oo100000=oo`00Ool0TWoo0`0000=oo`00Ool00Woo
00<007ooOol0:Goo000VOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`24Ool01@00Oomo
o`00Ool01000GWoo00L007ooOomoo`00Ool0002DOol30002Ool00`00Oomoo`0ZOol002Moo`03001o
ogoo00Uoo`03001oogoo00Aoo`03001oogoo08Aoo`05001oogooOol00004Ool00`00Oomoo`1MOol0
0`00Oomoo`040002Ool2002>Ool20003Ool00`00Oomoo`0[Ool002Qoo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo08Ioo`04001oogoo0003Ool00`00Oomoo`1OOol01000Oomoogoo0P0000Eo
o`00Oomoo`0008aoo`8000=oo`03001oogoo02aoo`00:Goo0P002Woo00@007oo000008Uoo`@0009o
o`03001oogoo065oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`<006Uoo`D00003
Ool007oo02ioo`00:goo0P001goo0`00Rgoo100000=oo`00Ool0I7oo00<007ooOol00Woo00D007oo
Oomoo`0001eoo`<006Qoo`D00003Ool007oo02moo`00;Goo1`000Woo00<007ooOol0RGoo1@00IWoo
00<007ooOol00Woo00@007oo000004moo`8000Eoo`80035oo`H0035oo`00=goo00<007ooOol0Qgoo
00<007oo00000`00Igoo00<007ooOol00Woo0P00Cgoo00@007ooOol003Moo`H0035oo`00>7oo00<0
07ooOol0Qgoo1@00J7oo00@007ooOomoo`800003Ool007oo04aoo`04001oogoo0009Ool3000/Ool4
000bOol003Uoo`03001oogoo08Ioo`04001oo`00001ZOol01000Oomoogoo0P0000=oo`00Ool0Bgoo
00<007oo00002Woo00<007oo000097oo0`001goo00<007ooOol0<Goo000iOol00`00Oomoo`27Ool0
0`00Oomoo`1[Ool01P00Oomoogoo001oo`8004aoo`03001oogoo00Uoo`<002=oo`@00004Ool00000
0002Ool00`00Oomoo`0bOol003Yoo`03001oogoo08Eoo`03001oogoo06eoo`04001oogooOol3001m
Ool3000017oo000007oo0P000Woo00<007ooOol0<Woo000kOol00`00Oomoo`1jOol30006Ool00`00
Oomoo`1^Ool00`00Oomoo`21Ool00`00Oomoo`030004Ool00`00Oomoo`0cOol003aoo`03001oogoo
07Qoo`05001oogooOol00005Ool00`00Oomoo`1_Ool00`00Oomoo`1ROol3000JOol00`00Ool00003
00001Goo001oogoo0000=Woo000mOol00`00Oomoo`1gOol00`00Oomoo`02Ool01@00Oomoogoo0000
Lgoo0P001Goo0P00Fgoo0`006goo00<007ooOol00P0000Aoo`00000003Moo`00?Woo00<007ooOol0
MGoo00<007ooOol00goo00@007ooOol007Ioo`03001oogoo009oo`<007Qoo`80009oo`<003Uoo`00
?Woo0P00Mgoo00<007ooOol00Woo00<007oo0000N7oo00@007ooOomoo`8005Qoo`<001Ioo`8000Mo
o`H003Uoo`00@7oo00<007ooOol0M7oo0P0000Eoo`00001oo`0007Uoo`03001oogoo05Uoo`<0009o
o`03001oogoo01=oo`04001oogooOol20007Ool00`00Oomoo`0hOol0045oo`03001oogoo07Eoo`04
001oogoo001kOol00`00Oomoo`1IOol20002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool20006Ool0
0`00Oomoo`0iOol0045oo`8007Moo`8007eoo`8005Yoo`04001oo`00000?Ool00`00Oomoo`0=Ool2
000lOol004=oo`03001oogoo07=oo`03001oogoo07moo`03001oogoo00Ioo`03001oogoo04moo`03
001oogoo01ioo`03001oogoo03aoo`00A7oo00<007ooOol0LGoo00<007ooOol0PGoo00<007ooOol0
0goo0P0000=oo`00Ool0Kgoo00<007ooOol0?Goo0015Ool2001`Ool00`00Oomoo`23Ool20003Ool2
0002Ool00`00Oomoo`1[Ool20010Ool004Moo`03001oogoo06aoo`03001oogoo08Ioo`05001oogoo
Ool00002Ool00`00Oomoo`1ZOol00`00Oomoo`10Ool004Qoo`03001oogoo05aoo`@00003Ool00000
00Moo`03001oogoo08Qoo`03001oogoo00<005=oo`03001oogoo00eoo`<000Ioo`03001oogoo045o
o`00BGoo0P00G7oo00@007ooOomoo`<000Eoo`8008aoo`8000=oo`@004ioo`03001oo`0000eoo`@0
00Aoo`8004Aoo`00Bgoo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
SWoo0P0000=oo`0000000`0097oo0P00:7oo0P003Goo0P0000Aoo`00Oomoo`8004Ioo`00C7oo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0TGoo00<007oo00000`008goo
0`00=Woo0`0000Aoo`00Ool004Qoo`00C7oo0P00FGoo0P0000=oo`0000000goo0P00UGoo0`0000=o
o`00Ool08goo00<007ooOol0=Woo00D007oo001oo`0004Uoo`00CWoo0P00FGoo00@007ooOomoo`80
09Qoo`<0061oo`8004Yoo`00D7oo0P00FGoo0P00W7oo0P00DWoo10001goo0P00C7oo001BOol00`00
Oomoo`1EOol00`00Oomoo`2NOol20008Ool20014Ool70004Ool2001>Ool005=oo`03001oogoo00ao
o`8004Eoo`03001oogoo0:5oo`8000Ioo`<002Qoo`<001Moo`<00003Ool0000000<00003Ool00000
051oo`00E7oo0P0037oo00<007ooOol0@Woo0P00YWoo0P0017oo0P00:Goo00<007oo00004goo1@00
00=oo`00Ool01P00DWoo001FOol2001=Ool2002ZOol2000>Ool00`00Oomoo`0LOol3000BOol30000
0goo0000000300000goo00000002001COol005Qoo`8003Moo`80011oo`800:ioo`8000]oo`03001o
o`0002]oo`8000Eoo`h005=oo`00FWoo0`00=Goo00<007ooOol037oo0P00/Woo0`001goo0P0000Ao
o`00000000Eoo`<0025oo`03001oo`0000Aoo`P0009oo`03001oo`0005Aoo`00GGoo10004Woo0P00
:7oo1000]goo0P001Woo100000=oo`00Ool00Woo00D007ooOomoo`0000Yoo`8001Aoo`04001oogoo
0003Ool70004Ool00`00Oomoo`1COol0065oo`8000moo`03001oogoo00@0025oo`<00;eoo`8000Io
o`07001oogooOol007oo00001Goo00<007ooOol01Woo00@007ooOol001=oo`<000Ioo`80009oo`80
0003Ool0000005Ioo`00Hgoo0P003Goo00@007ooOomoo`<001moo`800<9oo`D0009oo`<00003Ool0
07oo00Eoo`03001oogoo00Eoo`80009oo`04001oogoo000DOol50006Ool00`00Oomoo`1FOol006Eo
o`D000Moo`03001oogoo009oo`03001oogoo01]oo`@00<Uoo`@000=oo`03001oogoo00=oo`04001o
ogooOol=000>Ool5001TOol006Yoo`@000Aoo`04001oo`00000IOol5003AOol50002Ool20003Ool0
0`00Ool00006000017oo000000002goo1000JGoo001^Ool6000GOol4003KOol700000goo001oo`03
00000goo000000020006Ool7001]Ool007=ooaP00>Iooa4007Aoo`00ogoomgoo003oOoogOol00?mo
ooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00UWoo2000
nWoo2000EWoo003oOoogOol00?moooMoo`00Qgoo00@007ooOol00?ioo`04001oogoo001YOol004io
o`<000Aoo`@000Ioo`04001oogooOol30003Ool20002Ool3000017oo000007oo1`000Woo1@001Goo
00@007ooOol000Eoo`<000ioo`D000Aoo`8009Yoo`D000Aoo`<00004Ool00000Ool9000017oo0000
00000Woo0`000goo0P000Woo0`0000Aoo`00001oo`L0009oo`D000Eoo`04001oogoo0007Ool3000<
Ool5001>Ool004eoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Ool00003Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
1000Oomoo`000goo00D007ooOomoo`0000moo`03001oogoo00Aoo`8009]oo`05001oogooOol00002
Ool01000Oomoogoo0P001Goo00<007ooOol00Woo0P000goo00@007ooOol000Eoo`03001oo`0000=o
o`8000Eoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo0007Ool00`00Oomoo`0=Ool00`00
Oomoo`1>Ool004aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002
Ool00`00Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`08Ool60006Ool00`00
Oomoo`0=Ool00`00Oomoo`2QOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`0017oo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol027oo1P001Woo00<007ooOol03Goo00<007ooOol0CWoo
001<Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool02`00Oomoogoo001oo`00Ool007oo00000Woo1@00
1Goo00<007ooOol00Woo1P001Woo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo0:5oo`05
001oogooOol00003Ool50005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool02P00Oomoo`00Ool007oo
001oo`000Woo1@001Goo00<007ooOol00Woo1P001Woo00@007ooOol000=oo`H000ioo`03001oogoo
04ioo`00C7oo00<007ooOol02Woo00<007ooOol017oo00d007ooOomoo`00Ool007oo001oo`00Ool0
0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomo
o`001Goo0P0047oo00<007ooOol0XGoo10000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo0P000goo00`007ooOol007oo001oo`00Ool007oo0004Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`0017oo00@007ooOol000moo`03001o
ogoo04ioo`00C7oo00<007ooOol01Woo10001goo00/007ooOomoo`00Ool007oo001oo`00009oo`@0
00Ioo`03001oogoo00=oo`@000Ioo`H000Ioo`03001oogoo00eoo`03001oogoo0:5oo`05001oogoo
Ool00003Ool40006Ool00`00Oomoo`02Ool00`00Ool000020003Ool01`00Ool007oo001oo`00009o
o`@000Ioo`03001oogoo00=oo`@000Ioo`H000=oo`04001oogoo000?Ool00`00Oomoo`1>Ool004eo
o`03001oogoo008000=oo`03001oogoo00Uoo`03001oogoo008000=oo`8000aoo`03001oogoo00io
o`04001oogoo0007Ool00`00Oomoo`0=Ool00`00Oomoo`2QOol01@00Oomoogoo00003Goo00<007oo
Ool00Woo00<007ooOol01Goo0P000goo0P0037oo00<007ooOol03Woo00@007ooOol000Eoo`03001o
o`0000moo`03001oogoo04ioo`00CWoo0P0000=oo`00Ool00Woo00<007ooOol017oo00<007ooOol0
0Woo00<007oo00000P000goo0P0037oo00<007ooOol03goo00@007ooOol0009oo`05001oogooOol0
000=Ool3002ROol5000>Ool00`00Oomoo`02Ool00`00Oomoo`04Ool30003Ool2000<Ool00`00Oomo
o`0?Ool01000Oomoo`0017oo00<007oo00003Goo0`00D7oo001EOol50002Ool6000DOol2000AOol0
1000Oomoo`000goo0`0047oo00<007ooOol0/Woo0P000goo0P006Goo0P004Goo00@007ooOol000Eo
o`8000moo`03001oogoo04ioo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol0
0?moooMoo`00ogoomgoo003oOoogOol00001\
\>"],
  ImageRangeCache->{{{0, 501.188}, {238.125, 0}} -> {-0.0523717, -0.0238146, \
0.00419952, 0.00419952}, {{12.4375, 239.25}, {232.438, 5.625}} -> {-234.722, \
-190.208, 1.85244, 1.73148}, {{261.875, 488.688}, {232.438, 5.625}} -> \
{-664.642, -194.312, 1.7609, 1.75605}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The printed numbers preceding the previous graph, by the way, mean that there \
are 376 lingering episodes in that session and that the total time spent in \
lingering is 27140 time units which  is\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Quotient[27140*0.04\ , 60] minutes\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(18\ minutes\)], "Output"]
}, Open  ]],

Cell["\<\
As in the case of the path plot, we can construct a dynamical version of  \
lingering behavior:\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Script[{"\<Print[sessionname2];Show[GraphicsArray[Partition[Table[See[\
TimePlot1[SegPerTimeSlice[lingering,i,300],50],TextStyle->{FontSize->14},\
DisplayFunction->Identity],{i,1,6}],6]]]\>"}, twofiles];\)\)], "Input"],

Cell[BoxData[
    \("C57Male#3_1."\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.003663 0.15873 [
[ 0 0 0 0 ]
[ 1 .15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15385 L
0 .15385 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.003663 0.17033 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.502745 0.00278497 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.473445 0.47619 scale
1.0619 1.05 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127078 0.0127815 scale
7.69133 34.1149 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00898579 0.00903789 scale
19.1836 66.1039 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00480311 0.00483095 scale
24.5071 153.301 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00588258 0.00591669 scale
102.353 158.148 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00679262 0.006832 scale
108.644 129.246 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0242545 0.0243951 scale
38.4828 24.218 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0269574 0.0271137 scale
34.6076 14.7228 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00339631 0.003416 scale
275.131 128.694 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0332769 0.0334698 scale
21.6886 26.6383 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00679262 0.006832 scale
15.6935 93.8276 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0176477 0.0177501 scale
4.98648 35.8771 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00339631 0.003416 scale
27.0176 206.077 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0269574 0.0271137 scale
2.58371 19.8487 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0453124 0.0455751 scale
1.72271 10.1016 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00960621 0.00966191 scale
10.1945 43.8754 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00831922 0.00836746 scale
13.0625 40.14 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0140033 0.0140845 scale
16.2176 10.0238 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759438 0.00763841 scale
61.0583 6.44244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00679262 0.006832 scale
125.023 30.8109 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00898579 0.00903789 scale
89.3478 16.0414 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131538 0.0132301 scale
60.1163 10.3393 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00679262 0.006832 scale
52.6616 134.66 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00831922 0.00836746 scale
8.16062 61.7225 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195103 0.0196234 scale
3.71137 23.8001 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.04201 0.0422536 scale
2.41109 7.49853 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00759438 0.00763841 scale
25.7888 23.0048 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148042 0.01489 scale
14.4547 9.97314 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0519535 0.0522548 scale
5.62156 2.02278 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00339631 0.003416 scale
115.587 14.9122 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107401 0.0108023 scale
43.3852 4.3361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0222711 0.0224002 scale
22.4906 2.65265 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00588258 0.00591669 scale
64.2711 9.32786 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131538 0.0132301 scale
6.69538 30.3066 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00588258 0.00591669 scale
16.1239 73.7153 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0179716 0.0180758 scale
3.98574 26.8204 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0516194 0.0519187 scale
1.46127 8.84903 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0122456 0.0123166 scale
5.34316 41.9589 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00480311 0.00483095 scale
26.7848 155.886 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214801 0.0216047 scale
4.61962 33.7394 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00588258 0.00591669 scale
19.5068 126.038 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101889 0.010248 scale
45.4709 92.661 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0192124 0.0193238 scale
4.76723 36.0208 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00588258 0.00591669 scale
99.9596 9.65574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0206589 0.0207787 scale
43.071 12.9787 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00480311 0.00483095 scale
189.9 63.4574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0166384 0.0167349 scale
46.0542 7.36962 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0182897 0.0183957 scale
28.012 2.75771 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00480311 0.00483095 scale
66.101 18.0813 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0212099 0.0213329 scale
10.4008 6.87295 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0140033 0.0140845 scale
13.9288 12.7977 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0203779 0.020496 scale
9.99664 8.62851 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0182897 0.0183957 scale
4.66383 21.8013 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.003663 0.331502 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.50189 0.00279 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.4743 scale
1.05 1.05817 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.014119 0.014063 scale
5.70295 28.6241 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133945 0.0133413 scale
5.45524 34.1286 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0339052 0.0337706 scale
2.03184 12.2755 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0174833 0.0174139 scale
3.56741 25.6347 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0210999 0.0210162 scale
3.30665 22.633 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00964512 0.00960684 scale
9.26686 47.3632 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00257777 0.00256753 scale
33.595 184.675 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00998365 0.00994402 scale
8.21644 67.7281 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00631421 0.00628915 scale
13.3651 109.45 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0143524 0.0142954 scale
10.2401 48.284 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0163032 0.0162385 scale
54.0004 46.9821 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109365 0.0108931 scale
78.5313 73.3508 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00729103 0.00726209 scale
117.59 109.292 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0206221 0.0205403 scale
41.5563 37.7497 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00364551 0.00363104 scale
230.162 205.996 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150308 0.0149712 scale
61.1723 41.8858 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120908 0.0120428 scale
77.6864 45.1788 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00576406 0.00574118 scale
163.279 91.7773 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150308 0.0149712 scale
59.7339 19.1949 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0138817 0.0138266 scale
66.2822 23.47 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00446482 0.0044471 scale
187.013 43.0798 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150308 0.0149712 scale
53.0523 9.88366 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00815161 0.00811926 scale
87.3864 12.5812 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00257777 0.00256753 scale
86.3189 53.8415 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0202974 0.0202168 scale
4.09068 20.0343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154666 0.0154052 scale
5.82675 28.9279 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0243186 0.0242221 scale
2.67203 18.408 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0264142 0.0263094 scale
2.39795 15.8533 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0136403 0.0135861 scale
5.36573 32.7975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0077333 0.0077026 scale
11.2203 90.9744 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00446482 0.0044471 scale
19.9717 159.706 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00631421 0.00628915 scale
9.86188 84.4216 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103111 0.0102701 scale
7.96814 65.0858 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0481567 0.0479655 scale
2.13075 15.227 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00257777 0.00256753 scale
45.7916 159.453 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0192902 0.0192137 scale
12.3244 6.95494 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115281 0.0114824 scale
27.8207 7.94871 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00998365 0.00994402 scale
38.9607 5.54001 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00854948 0.00851555 scale
48.6801 6.04659 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00257777 0.00256753 scale
173.549 19.618 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00815161 0.00811926 scale
48.5977 6.24195 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0160981 0.0160343 scale
37.9081 4.12741 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148081 0.0147494 scale
40.6324 4.14798 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103111 0.0102701 scale
77.0163 13.6824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00854948 0.00851555 scale
96.283 20.9241 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0126284 0.0125783 scale
73.6687 31.1234 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0269127 0.0268059 scale
29.8614 31.2215 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154666 0.0154052 scale
60.8531 34.9051 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0189426 0.0188675 scale
49.4187 29.6654 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00631421 0.00628915 scale
145.678 52.5063 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00631421 0.00628915 scale
144.251 48.4008 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0189426 0.0188675 scale
42.4344 7.83731 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154666 0.0154052 scale
25.698 3.29888 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0343917 0.0342552 scale
2.32731 11.7763 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00729103 0.00726209 scale
12.359 59.7459 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115281 0.0114824 scale
5.39724 38.6776 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00446482 0.0044471 scale
14.1596 112.021 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00364551 0.00363104 scale
20.6528 172.234 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0224724 0.0223833 scale
3.75526 30.6242 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0244548 0.0243578 scale
4.04582 30.1234 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0435177 0.043345 scale
9.7126 1.5492 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00257777 0.00256753 scale
169.449 22.1224 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0126284 0.0125783 scale
17.1534 11.5604 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0453863 0.0452061 scale
4.54675 3.56146 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.003663 0.492674 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.501953 0.00278963 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.474237 0.47619 scale
1.05844 1.05 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0713524 0.0716463 scale
2.93977 2.19635 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134588 0.0135142 scale
6.21973 29.7087 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0372485 0.0374019 scale
2.6334 19.3894 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00620808 0.00623365 scale
11.332 76.4593 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0194344 0.0195144 scale
3.81078 23.3366 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.021144 0.021231 scale
16.4912 3.39927 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0204961 0.0205805 scale
29.5286 2.79197 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0058895 0.00591376 scale
98.5415 8.52081 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121018 0.0121516 scale
49.2729 4.7039 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0058895 0.00591376 scale
86.2331 8.22658 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00277634 0.00278777 scale
240.846 29.181 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112775 0.011324 scale
48.3856 4.36861 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0114471 0.0114943 scale
40.1629 4.27343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020212 0.0202953 scale
18.8981 2.74251 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102009 0.0102429 scale
38.4319 4.95562 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0034003 0.00341431 scale
72.9493 36.9562 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.010572 0.0106155 scale
21.0122 13.8166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0124162 0.0124673 scale
6.76699 32.1136 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121018 0.0121516 scale
5.48432 35.9261 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00392633 0.0039425 scale
17.6602 125.106 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112775 0.011324 scale
5.89402 45.4381 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.024283 0.024383 scale
2.88267 20.0836 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0431003 0.0432778 scale
1.55242 9.5795 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100102 0.0100515 scale
8.36145 39.8171 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0177772 0.0178504 scale
3.73736 24.4756 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00760331 0.00763463 scale
10.3823 82.5948 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0114471 0.0114943 scale
8.32436 62.2875 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00392633 0.0039425 scale
29.0347 187.959 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167733 0.0168424 scale
26.4897 56.7485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017449 0.0175209 scale
49.2108 45.5394 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0134588 0.0135142 scale
59.5187 10.6732 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153328 0.015396 scale
50.5217 8.42623 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00899636 0.00903341 scale
9.28931 44.4981 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153328 0.015396 scale
4.82429 29.6766 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0253697 0.0254742 scale
2.74658 16.2659 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145592 0.0146192 scale
4.85946 37.3447 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0686267 0.0689093 scale
1.42962 10.4722 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.003663 0.653846 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.506724 0.00276157 0.504594 0.0027741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.469467 0.471597 scale
1.07935 1.06996 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0737947 0.0741296 scale
1.44726 9.76439 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00278818 0.00280083 scale
31.759 221.898 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00737684 0.00741031 scale
11.0779 77.4651 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0199116 0.020002 scale
4.43812 23.0368 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130777 0.0131371 scale
7.58923 28.3343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0219542 0.0220538 scale
5.45318 13.9028 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0144878 0.0145536 scale
16.2771 9.9522 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00482927 0.00485119 scale
52.2853 27.8654 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017634 0.017714 scale
22.5558 3.12351 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127771 0.012835 scale
39.5154 7.95012 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130777 0.0131371 scale
61.2629 11.0763 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0228223 0.0229258 scale
3.6368 20.087 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0164951 0.01657 scale
7.09422 18.5046 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00394309 0.00396098 scale
31.7771 74.4917 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0405966 0.0407808 scale
2.29133 9.9623 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00341481 0.00343031 scale
22.2736 146.243 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.021687 0.0217854 scale
4.70697 32.7082 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00557637 0.00560167 scale
17.8252 79.6459 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00985771 0.00990244 scale
16.4835 25.3544 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0157723 0.0158439 scale
14.2851 9.72046 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00763575 0.0076704 scale
52.1062 7.81576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00788617 0.00792195 scale
68.3995 7.60166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00394309 0.00396098 scale
118.552 14.0925 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0421929 0.0423843 scale
14.5411 1.56166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0239037 0.0240121 scale
24.3762 2.74569 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00394309 0.00396098 scale
139.677 16.3773 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00812888 0.00816576 scale
63.7616 8.64708 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00788617 0.00792195 scale
52.1812 7.08159 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0313593 0.0315016 scale
12.8842 2.06307 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0157723 0.0158439 scale
28.5037 3.63357 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00278818 0.00280083 scale
144.567 29.2127 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00482927 0.00485119 scale
76.7879 18.2512 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0139409 0.0140042 scale
24.1426 7.14573 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00197154 0.00198049 scale
168.853 71.3359 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00623457 0.00626285 scale
36.1485 23.8965 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0289756 0.0291071 scale
6.95826 6.33075 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0119924 0.0120468 scale
7.9717 33.7881 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00653887 0.00656854 scale
11.6075 65.4803 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00341481 0.00343031 scale
22.0861 130.015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0560764 0.0563309 scale
1.42466 8.48611 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.003663 0.815018 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.528786 0.00263179 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.447404 0.47619 scale
1.18191 1.05 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.106106 0.112933 scale
1.22444 4.07659 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00181836 0.00193535 scale
145.109 77.3243 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00314949 0.00335213 scale
86.595 40.8904 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0158521 0.016872 scale
21.7303 5.54824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020411 0.0217243 scale
18.5532 3.53889 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00575016 0.00612013 scale
78.144 7.79886 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107576 0.0114497 scale
48.6123 4.38352 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115003 0.0122403 scale
47.7517 4.15432 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00979216 0.0104222 scale
59.4006 4.97016 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0217444 0.0231435 scale
28.5149 2.35574 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0181836 0.0193535 scale
42.8458 6.39831 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153218 0.0163076 scale
53.191 9.06204 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109102 0.0116121 scale
75.9907 14.3901 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109102 0.0116121 scale
84.6212 27.6823 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00181836 0.00193535 scale
493.929 141.359 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0240546 0.0256023 scale
38.3914 12.7195 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00445405 0.00474063 scale
209.445 81.371 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872054 0.00928163 scale
103.48 30.0077 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00575016 0.00612013 scale
154.138 41.9517 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0143178 0.015239 scale
55.7789 8.98484 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0136074 0.0144829 scale
44.609 3.63947 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154293 0.016422 scale
8.68608 24.4404 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104457 0.0111178 scale
14.3351 37.047 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00603082 0.00641884 scale
64.57 45.7777 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00852886 0.00907762 scale
110.731 61.8345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0101242 0.0107756 scale
80.2405 13.435 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00445405 0.00474063 scale
169.623 23.6931 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0201666 0.0214641 scale
39.2913 6.06361 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0331819 0.0353169 scale
25.5121 6.5589 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153218 0.0163076 scale
58.4071 17.4729 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00771464 0.00821101 scale
120.301 43.0592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0102862 0.010948 scale
89.9283 34.2418 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0116432 0.0123923 scale
78.6297 31.5115 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.003663 0.97619 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.464554 0.00259261 0.507413 0.00275751 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.440744 0.468777 scale
1.05401 1.08241 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00281784 0.00299706 scale
292.089 93.0345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0212119 0.0225611 scale
34.9049 6.64818 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00860863 0.00915617 scale
65.1242 7.44306 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0352699 0.0375132 scale
10.4381 1.63463 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0143682 0.0152821 scale
30.5877 5.45541 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00363781 0.00386919 scale
126.617 16.6624 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00876101 0.00931824 scale
68.0549 9.40843 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00430432 0.00457809 scale
147.742 27.2909 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00514464 0.00547186 scale
144.039 28.2536 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00608722 0.00647439 scale
128.306 32.7166 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.121036 0.128734 scale
7.06526 2.62401 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{621.5, 95.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009]0000Ga000`40O003h00OogooogooKgoo003o
OoooOom_Ool00?mooomoofmoo`00ogooogooKgoo000jOol9001FOol2001UOol:001WOol2001FOol9
001?Ool2001:Ool003Aoo`H00003Ool007oo009oo`04001oogooOol7001=OolC001?Ool7000:Ool6
001>Ool300000goo0000000=0002Ool00`00Oomoo`1=Ool60009Ool60018Ool01000Oomoo`00BGoo
000bOol30005Ool70009Ool20018Ool700000goo0000000<Ool50019Ool40004Ool20003Ool00`00
Oomoo`0200000goo00000005001;Ool80009Ool500000goo001oo`1;Ool20002Ool20005Ool:0000
17oo00000000AWoo00<007ooOol04000>Woo000YOol400000goo000000060004Ool40002Ool20003
Ool20005Ool40012Ool20002Ool8000;Ool40002Ool20013Ool500000goo00000004Ool3000017oo
000007oo0`0000Aoo`00001oo`80009oo`@004=oo`T0009oo`8000Aoo`800005Ool00000Ool00002
Ool40016Ool40004Ool20005Ool300002Goo000007oo001oo`00Ool00002Ool40011Ool40002Ool0
0`00Oomoo`0;Ool4000fOol002Qoo`04001oogooOol30004Ool00`00Oomoo`07Ool40004Ool20009
Ool2000lOol40004Ool400001Goo001oogoo00002Woo0P0000=oo`00Ool00goo1000?Goo0P0000Io
o`00Oomoo`00Ool20005Ool00`00Oomoo`04Ool01000Oomoogoo10001Woo0P00@7oo00@007ooOomo
o`L00003Ool007oo009oo`L0009oo`06001oogooOol007oo0P00@goo00<007oo00000Woo00<007oo
Ool027oo00<007oo00000P0000=oo`0000000P0000=oo`00Ool01Goo00<007ooOol0?7oo0`001Goo
00H007ooOol007oo0007Ool30002Ool2000dOol002Qoo`04001oo`000003Ool00`00Oomoo`0;Ool0
0`00Ool0000BOol00`00Oomoo`0hOol01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0
27oo100027oo00<007ooOol0>7oo0P000goo00<007ooOol0100047oo10000goo0P000goo0P00?7oo
0P001Goo0`0000Aoo`00Ool000Aoo`<0009oo`80009oo`05001oogooOol00003Ool2000oOol50002
Ool00`00Oomoo`0@Ool40007Ool2000hOol40002Ool00`00Oomoo`03Ool01@00Ool007oo000027oo
0`0000Aoo`00Oomoo`<0035oo`009goo0`000goo0P0000=oo`00Ool037oo00<007ooOol04Woo0P00
=goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`0_Ool500000goo00000005Ool01000Ool000006Woo0P001Goo0P00>7oo0P000Woo2P00
1Woo00<007ooOol00Woo10000goo00<007ooOol017oo0P00>goo0P0000Eoo`00Oomoo`00009oo`03
001oogoo01eoo`8003Eoo`03001oogoo00Aoo`80009oo`80009oo`03001oo`0000]oo`03001oo`00
00Aoo`8002moo`009Woo0P0027oo00<007ooOol08Woo0P00=7oo00<007ooOol00Woo0`0017oo0P00
0goo0P005Goo0`0000=oo`00Ool0;Woo00<007ooOol00Woo0`001goo00<007ooOol08goo00<007oo
Ool0<goo0P000goo00H007ooOol007oo0002Ool00`00Oomoo`05Ool00`00Ool00005Ool20002Ool2
0008Ool2000hOol01@00Oomoogoo00000Woo10008Goo0P00<Goo0P002Goo0P0017oo0`0037oo0P00
1Woo0P00;Goo000UOol00`00Ool00008Ool00`00Oomoo`0ROol3000aOol2000>Ool3000HOol20002
Ool2000/Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Goo00<007ooOol0<7oo0P001Woo0P003Goo
00<007oo00001goo0P0037oo0P00=Goo00<007ooOol00Woo0`008goo1@00;goo00<007ooOol0:7oo
00<007ooOol0:Woo000TOol200000goo001oo`07Ool00`00Oomoo`0QOol00`00Oomoo`02000]Ool3
0002Ool00`00Oomoo`0/Ool2000YOol00`00Oomoo`03Ool01P00Ool00000Ool002]oo`03001oo`00
031oo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo035oo`03001oogoo02Uoo`800004Ool0
0000000]Ool00`00Oomoo`0ROol20006Ool00`00Oomoo`0YOol002=oo`@00003Ool007oo00Eoo`03
001oogoo02=oo`05001oo`00Ool0000ZOol8000_Ool4000UOol00`00Oomoo`02Ool300001Goo0000
07oo0000:goo00<007oo00000P00;Goo1000<7oo00<007ooOol0;Woo0P0000=oo`00Ool0:Woo1P00
:goo00<007ooOol097oo00<007ooOol01Goo10009goo000ROol400000goo00000005Ool00`00Oomo
o`0UOol5000YOol300000goo00000002000^Ool5000UOol01P00Oomoogoo001oo`<000=oo`03001o
ogoo02Uoo`<00003Ool0000002]oo`D000Ioo`03001oogoo02Ioo`04001oo`00000]Ool00`00Oomo
o`02000[Ool7000XOol2000_Ool200000goo001oo`0VOol0025oo`03001oo`0000@00003Ool00000
00<002Yoo`@002Moo`80009oo`<00003Ool007oo02ioo`@002Eoo`04001oogoo0002Ool30003Ool0
0`00Oomoo`0[Ool300000goo001oo`0XOol5000aOol3000/Ool01@00Oomoogoo0000;goo10009goo
00<007ooOol0;Woo00<007oo00000P009goo000POol00`00Ool00004000eOol00`00Oomoo`0TOol0
0`00Oomoo`05Ool00`00Oomoo`0]Ool5000TOol00`00Ool00009Ool00`00Oomoo`0_Ool2000WOol0
0`00Oomoo`03000dOol00`00Oomoo`0XOol00`00Oomoo`0dOol4000TOol00`00Oomoo`0`Ool4000W
Ool001moo`03001oo`0000@003Moo`03001oogoo029oo`03001oo`0000Eoo`03001oogoo031oo`@0
02=oo`8000Yoo`03001oogoo035oo`03001oogoo02=oo`8000=oo`03001oogoo03Aoo`03001oogoo
02Ioo`03001oogoo03Eoo`<00003Ool007oo025oo`03001oogoo039oo`04001oogoo000VOol001io
o`04001oogooOol4000hOol00`00Oomoo`0POol01000Oomoo`001Goo00<007ooOol0<Goo10008Woo
0P002Woo00<007ooOol0<Woo00<007ooOol08Goo0P0017oo00<007ooOol0=Goo00<007ooOol09Goo
00<007ooOol0>Woo00<007ooOol07Woo00<007ooOol0=goo00<007ooOol08goo000MOol00`00Oomo
o`02Ool2000kOol00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`02000eOol01000Oomoo`00
87oo0`002Woo00<007ooOol0<Woo00<007ooOol087oo00<007oo000017oo00<007ooOol0=Woo00<0
07ooOol08goo00<007ooOol0>7oo100087oo00<007ooOol0>7oo00<007ooOol08Woo000LOol00`00
Oomoo`0nOol200000goo001oo`0NOol00`00Oomoo`03Ool2000kOol00`00Oomoo`0LOol00`00Oomo
o`020007Ool2000fOol00`00Oomoo`0NOol00`00Oomoo`05000jOol00`00Oomoo`0QOol00`00Oomo
o`0hOol01000Oomoogoo0P007Woo00<007ooOol0=goo0P0000=oo`00Ool020006Woo000LOol00`00
Oomoo`0nOol20002Ool00`00Oomoo`0KOol00`00Oomoo`11Ool00`00Oomoo`0LOol00`00Oomoo`02
Ool20002Ool3000iOol00`00Oomoo`0LOol00`00Oomoo`11Ool00`00Oomoo`0POol00`00Oomoo`0h
Ool00`00Oomoo`02Ool2000LOol00`00Oomoo`0hOol200000goo00000008Ool00`00Oomoo`0GOol0
01]oo`03001oogoo04=oo`03001oogoo01Yoo`03001oogoo04=oo`03001oogoo01Yoo`03001oogoo
00Eoo`8003eoo`03001oogoo01]oo`03001oogoo049oo`03001oogoo01ioo`03001oogoo03Qoo`03
001oogoo00=oo`8001aoo`03001oogoo03Uoo`80009oo`03001oogoo00Ioo`03001oogoo01Ioo`00
6goo00<007ooOol0A7oo00<007ooOol067oo00<007ooOol0AGoo00<007ooOol06Goo00<007ooOol0
AGoo00<007ooOol06Goo00<007ooOol00`00@7oo00<007ooOol07Woo00<007ooOol0>7oo00<007oo
Ool00goo00<007oo00006Woo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol01Woo0P005goo
000JOol00`00Oomoo`13Ool4000HOol00`00Oomoo`17Ool00`00Oomoo`0GOol00`00Oomoo`16Ool0
0`00Oomoo`0HOol01`00Oomoogoo001oo`00045oo`03001oogoo01aoo`03001oogoo03Uoo`80009o
o`D001Yoo`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Aoo`006Woo
00<007ooOol0@Woo00@007ooOomoo`8001Moo`03001oogoo04Qoo`03001oogoo01Ioo`03001oogoo
04Moo`03001oogoo01Moo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo
03]oo`80009oo`@001Qoo`03001oogoo03Uoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo
01=oo`006Goo0`00A7oo00<007ooOol00P005Woo00<007ooOol0AWoo10005goo00<007ooOol0B7oo
00<007ooOol05Woo00<007ooOol0Agoo00<007ooOol06Woo00<007ooOol0@7oo100067oo00<007oo
Ool0>Goo00<007ooOol00Woo0P0000=oo`00Ool027oo00<007ooOol04goo000GOol30002Ool20012
Ool30002Ool00`00Oomoo`0COol00`00Oomoo`16Ool01@00Ool007oo00005Woo00<007ooOol0BGoo
00<007ooOol05Goo1000Agoo00<007ooOol06Goo00<007ooOol04goo0P00:goo0`0000=oo`00Ool0
5Goo00<007ooOol0>Goo00<007ooOol017oo00<007oo00002Woo00<007ooOol04Woo000GOol20004
Ool00`00Oomoo`13Ool00`00Ool0000DOol00`00Oomoo`17Ool300000goo001oo`0DOol00`00Oomo
o`1:Ool00`00Oomoo`0DOol00`00Ool000030016Ool00`00Oomoo`0HOol00`00Oomoo`0DOol2000[
Ool5000FOol00`00Oomoo`0iOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0BOol001Io
o`03001oo`0000Eoo`03001oogoo049oo`03001oo`0001Aoo`03001oogoo04Qoo`<00003Ool007oo
01=oo`03001oogoo04]oo`03001oogoo01=oo`80009oo`8004Moo`03001oogoo01Moo`03001oogoo
04=oo`@001Aoo`03001oogoo03Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo019oo`00
5Woo0P001Woo00<007ooOol0A7oo00<007ooOol04Woo00<007ooOol0BGoo10004goo00<007ooOol0
C7oo00<007ooOol04Woo00<007ooOol00`00B7oo00<007ooOol05Woo00<007ooOol0@goo00@007oo
001oo`80019oo`03001oogoo03Yoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo019oo`00
5goo00<007ooOol00P000Woo00<007ooOol0AGoo00<007ooOol04Goo00<007ooOol0BGoo10004goo
00<007ooOol0C7oo00<007ooOol04Woo00D007ooOomoo`0004Yoo`03001oogoo01Eoo`03001oogoo
04Aoo`<00003Ool007oo015oo`03001oogoo03Yoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo019oo`005Woo0P000Woo0P0000=oo`00Ool0Agoo00<007ooOol047oo00<007ooOol0Bgoo00<0
07oo00004Woo00<007ooOol0CGoo00<007ooOol04Goo00<007ooOol0CGoo00<007ooOol057oo00<0
07ooOol0AGoo1@004Goo00<007ooOol0>goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
4Woo000FOol01@00Ool00000Ool00P00BWoo00<007ooOol03goo00<007ooOol0CWoo00<007ooOol0
3goo00<007ooOol0CWoo00<007ooOol047oo00<007ooOol0CGoo00<007ooOol04Woo2000@goo0`00
00=oo`00Ool03goo00<007ooOol0>goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol04Woo
000EOol00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00Oomoo`0>Ool01000Ool00000CWoo00<007oo
Ool03goo00<007ooOol0CWoo00<007ooOol03goo00<007ooOol00`00Bgoo00<007ooOol04Goo00@0
07ooOol000Eoo`03001oogoo041oo`80009oo`03001oogoo00eoo`03001oogoo03aoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo019oo`005Goo00<007ooOol0Bgoo1@0047oo0`0000=oo`00
0000BWoo00@007ooOol0011oo`<004moo`03001oogoo00ioo`@00003Ool0000004]oo`03001oogoo
00moo`05001oogooOol00006Ool20010Ool01@00Ool007oo00003goo00<007ooOol0?7oo00<007oo
Ool02goo00<007ooOol017oo00<007ooOol04Woo000EOol00`00Ool000030018Ool01@00Oomoogoo
00003goo2000B7oo00D007oo001oo`0000moo`03001oo`0000<004eoo`03001oogoo00ioo`800003
Ool00000008004]oo`03001oogoo00ioo`05001oogooOol00002Ool30004Ool00`00Oomoo`0lOol4
00000goo001oo`0>Ool00`00Oomoo`0lOol00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0B
Ool001Eoo`06001oo`00001oo`00Agoo00<007ooOol00Woo0P003Woo0P0000=oo`00Ool00`00B7oo
00D007oo001oo`0000ioo`L004eoo`03001oogoo00ioo`03001oogoo00<00003Ool007oo04Uoo`03
001oogoo00eoo`03001oogoo009oo`03001oo`00009oo`03001oogoo00=oo`03001oogoo03]oo`<0
00=oo`03001oogoo00aoo`03001oogoo03eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
019oo`0057oo00<007oo00001000B7oo00@007ooOomoo`8000ioo`800003Ool007oo00@004Qoo`04
001oogoo000=Ool30002Ool4001<Ool00`00Oomoo`0=Ool20002Ool01@00Ool007oo0000BWoo00<0
07ooOol03Goo00<007ooOol00Woo00L007oo001oo`00Ool00005Ool00`00Oomoo`10Ool00`00Oomo
o`0;Ool00`00Oomoo`0nOol2000;Ool00`00Oomoo`03Ool00`00Oomoo`0COol001Aoo`800003Ool0
000000<004Moo`800004Ool00000000>Ool00`00Ool00005001<Ool00`00Oomoo`0;Ool2000017oo
000007oo0`00CGoo00<007ooOol037oo1`0000=oo`00Ool0BWoo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol010001Goo00<007ooOol0@7oo00<007ooOol02goo00<007ooOol0@7oo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol057oo000DOol30002Ool30019Ool01000Oomoo`003Woo
1`00CGoo00<007ooOol037oo00@007oo001oo`800003Ool007oo04aoo`03001oogoo00aoo`03001o
o`0000800003Ool0000004aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo041oo`03001oogoo00]oo`03001oogoo045oo`03001oogoo00Qoo`04001oo`00000GOol001=o
o`<00003Ool0000000@004Qoo`05001oogooOol0000=Ool8001=Ool00`00Oomoo`0;Ool7001>Ool0
0`00Oomoo`0<Ool00`00Ool00005001<Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool00`00Oomoo`0oOol00`00Oomoo`0;Ool00`00Oomoo`11Ool20009Ool2000IOol001=oo`800004
Ool007ooOol200000goo001oo`1;Ool00`00Oomoo`0:Ool00`00Ool00005001>Ool00`00Oomoo`0;
Ool00`00Ool00004001>Ool00`00Oomoo`0;Ool2000017oo000007oo0P0000=oo`00Ool0BWoo00<0
07ooOol02goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0?goo00<007ooOol02goo00<0
07ooOol0@goo0P001Woo0P006Woo000COol200000goo000000020002Ool00`00Oomoo`1:Ool00`00
Oomoo`0:Ool00`00Ool00005001>Ool00`00Oomoo`0;Ool00`00Oomoo`03001?Ool00`00Oomoo`0;
Ool200000goo001oo`02Ool00`00Ool0001;Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool00`00Oomoo`0oOol00`00Oomoo`0;Ool00`00Oomoo`15Ool600000goo001oo`0IOol001=o
o`@0009oo`04001oogoo001<Ool00`00Oomoo`0:Ool01`00Ool007oo001oo`0004moo`03001oogoo
00]oo`03001oo`0000<004moo`03001oogoo00Yoo`04001oo`00Ool40002Ool00`00Oomoo`19Ool0
0`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0oOol00`00Oomoo`0;Ool0
0`00Oomoo`1<Ool00`00Oomoo`0HOol001Aoo`H00003Ool0000004aoo`03001oogoo00Yoo`05001o
ogoo001oo`02001?Ool00`00Oomoo`0;Ool200001Goo000007oo0000CWoo00<007ooOol02goo0P00
0goo00D007ooOomoo`0004]oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo041oo`03001oogoo00]oo`03001oogoo04aoo`03001oogoo01Qoo`0057oo1@0000=oo`000000
CGoo00<007ooOol02Woo00<007ooOol00P00DGoo00<007ooOol02goo00<007oo00000P0000=oo`00
Ool0CGoo00<007ooOol02goo0P000Woo00<007ooOol00Woo00<007ooOol0BGoo00<007ooOol02goo
00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0@7oo00<007ooOol02goo00<007ooOol0C7oo
00<007ooOol067oo000DOol00`00Ool00003001?Ool00`00Oomoo`0:Ool00`00Oomoo`1COol00`00
Oomoo`0;Ool00`00Ool00003001?Ool00`00Oomoo`0<Ool01000Oomoo`0017oo00<007ooOol0BGoo
00<007ooOol037oo00D007ooOomoo`0000aoo`03001oogoo041oo`03001oogoo00]oo`03001oogoo
04aoo`03001oogoo01Qoo`0057oo00<007oo00000`00Cgoo00<007ooOol02Woo00D007ooOomoo`00
04eoo`80009oo`03001oogoo00]oo`05001oo`00Ool0001@Ool00`00Oomoo`0<Ool00`00Oomoo`03
Ool2001<Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00<007ooOol0@Goo00<007ooOol02goo
00<007ooOol0C7oo00<007ooOol067oo000DOol00`00Ool0000200000goo001oo`1=Ool00`00Oomo
o`0:Ool00`00Oomoo`02001=Ool300000goo001oo`0<Ool00`00Oomoo`02001@Ool00`00Oomoo`0<
Ool6001>Ool00`00Oomoo`0=Ool01000Oomoo`002goo00<007ooOol0@Goo00<007ooOol02goo00<0
07ooOol0C7oo00<007ooOol067oo000DOol20004Ool00`00Oomoo`1<Ool00`00Oomoo`0:Ool01@00
Oomoogoo0000C7oo100000=oo`00Ool037oo00<007oo00000Woo00<007ooOol0CGoo00<007ooOol0
37oo00<007ooOol0DGoo00<007ooOol03Goo0P0000=oo`00Ool027oo0P00A7oo00<007ooOol02goo
00<007ooOol0C7oo00<007ooOol067oo000DOol300000goo0000001?Ool00`00Oomoo`0:Ool00`00
Oomoo`1>Ool400000goo001oo`0<Ool00`00Oomoo`02001@Ool00`00Oomoo`0<Ool00`00Oomoo`1A
Ool00`00Oomoo`0?Ool20008Ool00`00Oomoo`11Ool200000goo001oo`0<Ool00`00Oomoo`1<Ool0
0`00Oomoo`0HOol001Aoo`04001oogoo001<Ool300000goo001oo`0=Ool00`00Oomoo`1=Ool01P00
Oomoo`00Ool000eoo`04001oogoo001AOol00`00Oomoo`0<Ool00`00Oomoo`02001?Ool00`00Oomo
o`0@Ool20005Ool20014Ool200000goo001oo`0<Ool00`00Oomoo`1<Ool00`00Oomoo`0HOol001Ao
o`03001oogoo04aoo`04001oogooOol2000>Ool00`00Oomoo`1=Ool5000>Ool00`00Oomoo`1BOol0
0`00Oomoo`0<Ool00`00Oomoo`02001?Ool00`00Oomoo`0@Ool00`00Ool000040016Ool01000Oomo
o`003Goo00<007ooOol0C7oo00<007ooOol067oo000DOol00`00Oomoo`09Ool20011Ool01000Oomo
ogoo0P003Woo00<007ooOol0DGoo00<007ooOol037oo00<007ooOol0DWoo00<007ooOol037oo00D0
07ooOomoo`0004moo`03001oogoo015oo`03001oogoo04aoo`03001oogoo00]oo`03001oogoo04ao
o`03001oogoo01Qoo`0057oo00<007ooOol02Goo0P00@Goo00@007ooOomoo`8000ioo`03001oogoo
055oo`03001oogoo00aoo`03001oogoo055oo`03001oogoo00eoo`03001oogoo051oo`03001oogoo
019oo`03001oogoo04aoo`03001oogoo00]oo`03001oogoo04]oo`03001oogoo01Uoo`005Goo00<0
07ooOol027oo0P00@Goo0P0000Aoo`00Ool000ioo`03001oogoo04eoo`05001oogooOol0000?Ool0
0`00Oomoo`1@Ool00`00Oomoo`0>Ool00`00Oomoo`1?Ool00`00Oomoo`0BOol00`00Oomoo`1<Ool0
0`00Oomoo`0<Ool00`00Oomoo`1:Ool00`00Oomoo`0IOol001Eoo`03001oogoo008004]oo`03001o
o`0000moo`03001oogoo008004Yoo`03001oo`00009oo`03001oogoo00eoo`04001oogoo001?Ool0
0`00Oomoo`0>Ool01000Oomoo`00CWoo00<007ooOol04Woo00<007ooOol0Bgoo00<007ooOol03Goo
00<007ooOol0BWoo00<007ooOol06Goo000EOol00`00Ool00002Ool2001;Ool00`00Oomoo`0>Ool0
1000Oomoo`00BGoo00@007ooOol0009oo`03001oogoo00ioo`04001oo`00001>Ool00`00Oomoo`0>
Ool00`00Oomoo`1?Ool00`00Oomoo`0COol00`00Oomoo`1:Ool00`00Oomoo`0=Ool00`00Oomoo`1:
Ool00`00Oomoo`0IOol001Eoo`05001oogoo001oo`02001;Ool00`00Oomoo`0>Ool00`00Oomoo`1;
Ool300000goo001oo`0@Ool00`00Ool0001>Ool00`00Oomoo`0?Ool00`00Oomoo`1>Ool00`00Oomo
o`0DOol00`00Oomoo`1:Ool00`00Oomoo`0=Ool00`00Oomoo`19Ool00`00Oomoo`0JOol001Ioo`03
001oo`00008004aoo`03001oogoo00moo`03001oo`0004ioo`03001oogoo00moo`03001oo`0000<0
04]oo`03001oogoo011oo`P004Qoo`03001oogoo01Aoo`03001oogoo04Yoo`03001oogoo00ioo`03
001oogoo04Qoo`03001oogoo01Yoo`005Woo00<007ooOol0CGoo00<007ooOol047oo1000C7oo00<0
07ooOol047oo0P0017oo0`00Agoo00<007ooOol047oo0P001goo00<007ooOol0AGoo00<007ooOol0
57oo00<007ooOol0BGoo00<007ooOol03goo00<007ooOol0B7oo00<007ooOol06Woo000GOol00`00
Ool0001<Ool00`00Oomoo`0AOol40002Ool20017Ool00`00Oomoo`0?Ool30007Ool00`00Oomoo`14
Ool00`00Oomoo`0@Ool00`00Ool00007Ool00`00Oomoo`14Ool00`00Oomoo`0EOol00`00Oomoo`18
Ool00`00Oomoo`0@Ool00`00Oomoo`17Ool00`00Oomoo`0JOol001Moo`800003Ool007oo04Uoo`03
001oogoo019oo`L00003Ool0000004Eoo`03001oogoo00ioo`05001oogoo001oo`030004Ool00`00
Oomoo`13Ool00`00Oomoo`0?Ool01@00Oomoo`00Ool00P001Goo00<007ooOol0@Woo00<007ooOol0
5Woo00<007ooOol0Agoo00<007ooOol04Goo00<007ooOol0AWoo00<007ooOol06goo000GOol30000
0goo001oo`18Ool00`00Oomoo`0BOol40002Ool30016Ool00`00Oomoo`0>Ool01@00Oomoogoo0000
0goo0P000Woo00<007ooOol0@goo00<007ooOol03goo00D007ooOomoo`00009oo`03001oogoo009o
o`03001oogoo049oo`03001oogoo01Moo`03001oogoo04Ioo`03001oogoo019oo`03001oogoo04Eo
o`03001oogoo01]oo`0067oo0`00BWoo00<007ooOol04Woo1@000Woo00<007ooOol0A7oo00<007oo
Ool03goo00@007ooOomoo`<0009oo`04001oogoo0014Ool00`00Oomoo`0?Ool01000Oomoogoo0P00
0Woo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol067oo00<007ooOol0AGoo00<007ooOol0
4goo00<007ooOol0A7oo00<007ooOol077oo000IOol00`00Ool00019Ool00`00Oomoo`0AOol01000
Ool000000Woo00<007oo0000AWoo00<007ooOol03goo00D007ooOol007oo00<00005Ool007ooOol0
0014Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool200000goo001oo`03Ool20012Ool00`00Oomoo`0I
Ool00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`13Ool00`00Oomoo`0LOol001Qoo`80009o
o`03001oogoo04Eoo`03001oogoo019oo`03001oo`0000=oo`04001oogoo0014Ool00`00Oomoo`0@
Ool01@00Oomoo`00Ool00P000Woo00@007ooOol004=oo`03001oogoo011oo`03001oogoo009oo`@0
00Aoo`80045oo`03001oogoo01Yoo`03001oogoo04=oo`03001oogoo01Eoo`03001oogoo049oo`03
001oogoo01eoo`0067oo1@00Agoo00<007ooOol04Woo00@007oo0000009oo`04001oogoo000lOol2
0002Ool01@00Oomoogoo00004Woo00H007ooOomoo`00Ool30003Ool00`00Oomoo`11Ool00`00Oomo
o`0AOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`10Ool00`00Oomoo`0KOol00`00Oomo
o`12Ool00`00Oomoo`0EOol00`00Oomoo`12Ool00`00Oomoo`0MOol001Yoo`@004Aoo`8001Ioo`D0
009oo`03001oogoo03]oo`@00004Ool00000000DOol00`00Oomoo`050003Ool00`00Oomoo`10Ool0
0`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomoo`0LOol0
0`00Oomoo`11Ool00`00Oomoo`0FOol00`00Oomoo`11Ool00`00Oomoo`0NOol001]oo`03001oogoo
04=oo`03001oogoo01Ioo`07001oogooOol007oo0000?goo00<007oo00000`005Goo00<007ooOol0
0Woo0P000goo00<007ooOol0@7oo00<007ooOol057oo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol0?goo00<007ooOol07Goo00<007ooOol0?goo00<007ooOol067oo00<007ooOol0@7oo00<0
07ooOol07Woo000LOol00`00Oomoo`12Ool00`00Oomoo`0GOol5000oOol00`00Oomoo`03000GOol0
0`00Oomoo`03Ool3000oOol200000goo001oo`0FOol20004Ool01@00Oomoogoo0000@Goo00<007oo
Ool07goo00<007ooOol0?Woo00<007ooOol06Goo00<007ooOol0?Woo00<007ooOol07goo000LOol0
0`00Oomoo`11Ool00`00Oomoo`0LOol00`00Oomoo`0nOol4000IOol60010Ool01000Oomoo`006Woo
0P000goo0`00@Goo00<007ooOol087oo00<007ooOol0?Goo00<007ooOol06goo00<007ooOol0?7oo
00<007ooOol087oo000MOol00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`0mOol4000OOol0
0`00Oomoo`0mOol01000Oomoo`0077oo1@00@Goo00<007ooOol08Woo00<007ooOol0?7oo00<007oo
Ool077oo00<007ooOol0>goo00<007ooOol087oo000MOol2000oOol2000POol2000jOol20003Ool2
000QOol00`00Oomoo`0lOol01000Ool0000087oo00<007ooOol0?Woo00<007ooOol08goo00<007oo
Ool0>goo00<007ooOol07Goo00<007ooOol0>Woo00<007ooOol08Goo000OOol00`00Oomoo`0kOol0
0`00Oomoo`0ROol00`00Oomoo`0fOol01P00Oomoo`00Ool002Aoo`03001oogoo03aoo`03001oogoo
025oo`03001oogoo03eoo`03001oogoo02Aoo`03001oogoo03Uoo`03001oogoo01moo`03001oogoo
03Qoo`03001oogoo029oo`0087oo00<007ooOol0>Woo00<007ooOol08goo00<007ooOol0=7oo00<0
07ooOol00Woo0P009Goo00<007ooOol0>Woo00<007ooOol08goo00<007ooOol0>Woo0P00:7oo00<0
07ooOol0=goo00<007ooOol087oo00<007ooOol0=goo00<007ooOol08goo000POol2000iOol2000V
Ool2000fOol00`00Oomoo`02000WOol00`00Oomoo`0hOol00`00Oomoo`0UOol2000iOol00`00Oomo
o`0YOol00`00Oomoo`0eOol00`00Oomoo`0ROol00`00Oomoo`0eOol00`00Oomoo`0TOol0029oo`03
001oogoo02aoo`8000Moo`03001oogoo02Qoo`03001oogoo03=oo`04001oo`00000YOol00`00Oomo
o`0fOol00`00Oomoo`0XOol00`00Oomoo`0eOol00`00Oomoo`0[Ool00`00Oomoo`0cOol00`00Oomo
o`0TOol00`00Oomoo`0cOol00`00Oomoo`0UOol002=oo`03001oogoo02Yoo`04001oogoo0006Ool0
0`00Oomoo`0YOol00`00Oomoo`0cOol2000[Ool00`00Oomoo`0dOol00`00Oomoo`0ZOol00`00Oomo
o`0cOol00`00Oomoo`0]Ool00`00Oomoo`0aOol00`00Oomoo`0VOol2000bOol00`00Oomoo`0VOol0
02Aoo`03001oogoo02Uoo`03001oogoo008000=oo`8002aoo`8003=oo`8002eoo`03001oogoo035o
o`8002ioo`03001oogoo035oo`03001oogoo02moo`80031oo`03001oogoo02Uoo`03001oogoo02io
o`03001oogoo02Moo`009Goo0P00:7oo00@007ooOomoo`D0031oo`8002moo`80031oo`80031oo`03
001oogoo02moo`8002moo`8003Aoo`03001oogoo02]oo`8002eoo`8002aoo`8002Yoo`009goo0P00
9Woo00<007ooOol00Woo0P00=7oo0P00:goo0P00=7oo0P00;7oo0P00=7oo0P00:goo0P00=goo0P00
:Goo0P00<Goo0P00:7oo0P00;7oo000YOol20006Ool00`00Oomoo`0LOol00`00Oomoo`02000gOol0
0`00Oomoo`0WOol00`00Oomoo`0fOol2000XOol2000hOol2000WOol2000kOol2000UOol2000eOol0
0`00Oomoo`0SOol2000^Ool002]oo`8000=oo`<001eoo`D003Qoo`8002Eoo`8003]oo`8002Aoo`80
03aoo`03001oogoo029oo`8003moo`03001oogoo025oo`03001oogoo03Ioo`80029oo`03001oogoo
02ioo`00;Goo0P000Woo00<007ooOol04goo0P001Woo0P00?Woo0P008Goo0P00?goo0P0087oo0P00
?goo0P0087oo0P00@Woo0P007goo0P00>goo0P007Woo0P00<Goo000_Ool20009Ool2000;Ool20004
Ool20012Ool2000MOol20013Ool20007Ool3000BOol20013Ool2000LOol20016Ool2000KOol2000o
Ool2000JOol2000cOol0035oo`@000Eoo`<000ioo`8004Ioo`8001Uoo`8004Moo`@000=oo`04001o
ogoo000?Ool20017Ool2000HOol2001:Ool4000EOol20013Ool2000FOol2000eOol003Eoo`@0009o
o`03001oogoo00Moo`H004Yoo`L000]oo`L004eoo`@00003Ool007oo00Uoo`H004]oo`L000]oo`H0
051oo`@000]oo`H004Moo`D000]oo`H003Moo`00>Goo3000Egoo2`00F7oo3000F7oo2`00FWoo2`00
DWoo2`00?Goo003oOoooOom_Ool00?mooomoofmoo`00ogooogooKgoo003oOoooOom_Ool00001\
\>"],
  ImageRangeCache->{{{0, 620.5}, {94.625, 0}} -> {-0.177959, -0.0230818, \
0.0102432, 0.0102432}, {{17.375, 107.438}, {92.3125, 2.25}} -> {-249.796, \
-187.668, 3.98694, 3.96395}, {{116.5, 206.563}, {92.3125, 2.25}} -> \
{-640.302, -189.094, 3.96395, 3.97975}, {{215.625, 305.688}, {92.3125, 2.25}} -> \
{-1038.19, -187.668, 3.98028, 3.96395}, {{314.75, 404.813}, {92.3125, 2.25}} -> \
{-1449.02, -191.152, 4.02072, 4.00256}, {{413.875, 504}, {92.3125, 2.25}} -> \
{-1947.19, -187.668, 4.219, 3.96395}, {{513, 603.125}, {92.3125, 2.25}} -> \
{-2376.37, -193.325, 4.28275, 4.02664}}],

Cell[BoxData[
    \("BalbMale#4_1"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.003663 0.15873 [
[ 0 0 0 0 ]
[ 1 .15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15385 L
0 .15385 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.003663 0.17033 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.517242 0.00269969 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.458948 0.47619 scale
1.12701 1.05 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106973 0.0110992 scale
13.2799 39.9469 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0429713 0.0445857 scale
3.73551 9.82041 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00853353 0.00885413 scale
12.506 56.3093 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0485683 0.050393 scale
2.24529 9.54378 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.018174 0.0188568 scale
6.96323 23.8434 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00161268 0.00167327 scale
74.7635 277.761 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0739553 0.0767337 scale
1.5074 6.12182 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109378 0.0113487 scale
9.4736 43.3107 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0175923 0.0182533 scale
5.93555 26.8078 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0835956 0.0867362 scale
1.28488 5.49839 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00161268 0.00167327 scale
81.3116 266.514 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00360607 0.00374155 scale
35.773 113.076 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00897905 0.00931639 scale
13.9413 44.4518 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00645074 0.00669309 scale
20.0628 60.8015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00360607 0.00374155 scale
34.905 121.193 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0213947 0.0221985 scale
5.37657 20.9519 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.003663 0.331502 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.506283 0.00276416 0.5 0.00280112 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.469908 0.47619 scale
1.0774 1.05 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00738812 0.0074869 scale
14.6275 59.6629 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00603238 0.00611303 scale
20.9984 72.2244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0062787 0.00636264 scale
20.0663 69.3894 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00246271 0.00249563 scale
50.4891 170.345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00651571 0.00660283 scale
17.8492 64.4027 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00953803 0.00966555 scale
10.8891 42.5563 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00522419 0.00529404 scale
18.4584 74.65 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00246271 0.00249563 scale
45.6814 132.628 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0046073 0.0046689 scale
27.107 62.6571 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0719684 0.0729306 scale
1.33837 5.58407 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00717996 0.00727596 scale
13.7953 52.7298 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0661731 0.0670578 scale
1.45286 6.14141 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0549852 0.0557203 scale
1.72156 8.34776 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00577556 0.00585278 scale
21.7468 80.1909 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00246271 0.00249563 scale
55.0735 192.504 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0046073 0.0046689 scale
34.4214 117.863 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00887942 0.00899814 scale
15.6835 55.0181 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0683817 0.069296 scale
1.34817 6.7089 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00348279 0.00352936 scale
31.2422 120.529 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0301116 0.0305142 scale
3.18914 13.4905 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0202332 0.0205037 scale
4.77186 19.0551 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.003663 0.492674 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.517929 0.00268652 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.456709 scale
1.05 1.13405 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0315709 0.0302793 scale
2.74905 13.5809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0389649 0.0373707 scale
2.16528 11.4753 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.025362 0.0243244 scale
3.76902 14.6034 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0165033 0.0158281 scale
6.42356 20.8053 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
93.97 75.4514 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00680875 0.00653019 scale
54.7031 13.5785 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117931 0.0113106 scale
35.235 6.81571 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110314 0.0105801 scale
31.6106 8.73619 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00867949 0.0083244 scale
32.51 16.5141 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
94.0614 75.0139 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020986 0.0201274 scale
8.47089 10.8867 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00992537 0.00951931 scale
20.8849 20.4343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00761241 0.00730098 scale
31.6378 21.7026 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340438 0.0032651 scale
105.132 25.0406 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
183.736 33.5763 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
197.744 36.8767 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0117931 0.0113106 scale
43.4559 6.6548 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0490396 0.0470333 scale
8.27516 1.50617 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0264798 0.0253965 scale
14.5454 2.83149 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00900713 0.00863863 scale
38.6971 9.94949 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00589655 0.00565531 scale
57.8728 16.275 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120363 0.0115439 scale
25.905 9.38248 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00992537 0.00951931 scale
29.2533 12.4673 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00867949 0.0083244 scale
27.4014 18.2836 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00900713 0.00863863 scale
25.3621 18.8433 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
81.9314 79.4015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00481451 0.00461754 scale
30.8796 56.2593 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00761241 0.00730098 scale
12.8317 46.6746 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
40.8224 151.916 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0198507 0.0190386 scale
4.26231 22.3015 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0163268 0.0156589 scale
4.394 31.8037 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00538279 0.00516257 scale
14.5891 116.887 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110314 0.0105801 scale
9.33333 70.6088 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00416949 0.00399891 scale
54.7669 217.812 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0115448 0.0110725 scale
43.6162 87.0455 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00416949 0.00399891 scale
25.382 187.721 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00761241 0.00730098 scale
13.097 99.3922 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
35.9372 288.504 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00932327 0.00894184 scale
9.11269 71.3601 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0188013 0.0180321 scale
4.41247 26.8433 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340438 0.0032651 scale
21.8983 153.135 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0399198 0.0382867 scale
1.7941 13.3624 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
28.9832 241.176 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00798397 0.00765733 scale
9.32243 74.889 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00833898 0.00799782 scale
9.75299 75.1355 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0107656 0.0103251 scale
7.72741 59.2273 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.015414 0.0147834 scale
5.21021 41.8951 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00481451 0.00461754 scale
16.579 136.501 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.026914 0.0258129 scale
3.77091 28.9422 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00722177 0.00692632 scale
17.8211 112.109 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
57.0525 339.124 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.006369 0.00610844 scale
24.6711 132.373 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00240726 0.00230877 scale
99.6404 383.026 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340438 0.0032651 scale
75.9904 273.934 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110314 0.0105801 scale
43.1576 91.2664 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159679 0.0153147 scale
40.9013 61.2198 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0228372 0.0219029 scale
28.4386 42.8824 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00538279 0.00516257 scale
122.176 181.704 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159679 0.0153147 scale
41.341 61.2217 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011291 0.0108291 scale
57.6422 86.8844 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00798397 0.00765733 scale
85.7731 121.03 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0263702 0.0252913 scale
26.0651 36.6343 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0146428 0.0140437 scale
33.9096 68.0304 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00481451 0.00461754 scale
16.8553 136.49 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340438 0.0032651 scale
21.1199 174.313 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0110314 0.0105801 scale
6.7634 47.2008 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00833898 0.00799782 scale
11.6429 56.2966 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0506669 0.048594 scale
1.76249 8.81631 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0423841 0.0406501 scale
1.99226 10.6578 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.003663 0.653846 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.523835 0.00266091 0.499619 0.00279296 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.452355 0.474803 scale
1.15803 1.05227 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.105076 0.11029 scale
1.22664 3.72898 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00481868 0.00505781 scale
24.2639 97.4691 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
69.9414 336.723 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153645 0.0161269 scale
9.55256 45.9449 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0070929 0.00744489 scale
40.6138 119.503 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113008 0.0118616 scale
26.1026 75.349 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0116382 0.0122158 scale
36.4592 77.5482 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340732 0.00357641 scale
154.646 267.581 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00622089 0.0065296 scale
110.542 142.8 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
445.889 365.796 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00590165 0.00619452 scale
150.095 114.984 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00556413 0.00584025 scale
158.499 129.07 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
443.413 375.806 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00736065 0.00772593 scale
116.774 103.414 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0139103 0.0146006 scale
61.7397 54.2894 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0083462 0.00876038 scale
105.491 86.8364 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00922707 0.00968496 scale
95.6848 77.4376 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652452 0.0068483 scale
130.25 108.709 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111283 0.0116805 scale
73.972 69.6811 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121267 0.0127285 scale
67.3981 65.5299 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00393444 0.00412968 scale
201.508 205.51 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0287779 0.030206 scale
24.082 30.8449 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00786887 0.00825936 scale
83.6029 112.843 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0213695 0.0224299 scale
21.2589 42.5218 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00786887 0.00825936 scale
16.2488 56.7865 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00393444 0.00412968 scale
34.3683 111.977 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0248836 0.0261184 scale
4.75575 18.4307 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0409351 0.0429666 scale
3.23976 10.811 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00811105 0.00851356 scale
16.5022 48.2936 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00278207 0.00292013 scale
46.2929 137.884 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00340732 0.00357641 scale
42.4615 86.8776 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
121.324 73.7345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00520477 0.00546306 scale
53.9083 21.7809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0114708 0.01204 scale
35.1302 3.28655 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121267 0.0127285 scale
35.8893 2.87072 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
299.311 27.4694 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00622089 0.0065296 scale
117.613 14.3056 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00481868 0.00505781 scale
158.151 21.0585 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00590165 0.00619452 scale
145.454 36.3418 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.017705 0.0185836 scale
51.08 16.2983 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00590165 0.00619452 scale
154.799 56.3675 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0187661 0.0196973 scale
48.4742 15.8621 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00196722 0.00206484 scale
458.704 146.258 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104095 0.0109261 scale
89.0309 41.2873 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00556413 0.00584025 scale
167.615 96.1431 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00556413 0.00584025 scale
161.689 117.57 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.010222 0.0107292 scale
84.341 74.2719 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00590165 0.00619452 scale
142.706 131.394 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.003663 0.815018 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.501382 0.00273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.464101 scale
1.05 1.08033 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00772154 0.0075255 scale
106.035 109.363 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
296.481 270.861 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00505493 0.0049266 scale
176.25 143.001 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0175108 0.0170662 scale
50.5305 40.9669 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0202197 0.0197064 scale
38.7156 6.89827 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0191377 0.0186518 scale
34.2341 4.1358 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0226063 0.0220324 scale
28.4606 3.2838 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00967946 0.00943371 scale
69.9419 9.34839 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0262662 0.0255993 scale
21.6921 1.93013 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0105227 0.0102555 scale
44.5865 4.51366 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0136888 0.0133413 scale
32.6507 3.41271 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159851 0.0155793 scale
22.1006 4.00725 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130518 0.0127204 scale
14.8792 12.7433 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
26.5627 24.8261 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
32.7569 114.918 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0182258 0.0177631 scale
4.62695 23.1643 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
23.1903 184.705 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00825467 0.0080451 scale
11.2991 86.7795 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127213 0.0123983 scale
8.07464 59.7121 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0151648 0.0147798 scale
31.5685 64.6741 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0127213 0.0123983 scale
67.0938 63.5061 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087554 0.00853312 scale
105.957 66.5865 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159851 0.0155793 scale
58.2542 35.7905 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00505493 0.0049266 scale
180.574 70.8785 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0251056 0.0244682 scale
36.0031 12.6744 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0142975 0.0139345 scale
54.8844 9.7463 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
108.602 32.7805 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109199 0.0106427 scale
81.4769 27.2075 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
120.859 34.9391 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00412734 0.00402255 scale
207.357 59.3678 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
144.764 15.8594 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0116739 0.0113775 scale
34.8111 4.2839 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133741 0.0130345 scale
26.567 4.80646 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130518 0.0127204 scale
26.5535 5.42121 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00412734 0.00402255 scale
77.2169 20.7182 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652589 0.00636021 scale
12.9392 64.0278 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00505493 0.0049266 scale
15.4087 121.479 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0130518 0.0127204 scale
7.62961 56.7906 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652589 0.00636021 scale
16.1143 115.33 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652589 0.00636021 scale
26.85 127.449 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109199 0.0106427 scale
17.8967 78.0754 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00967946 0.00943371 scale
33.5856 96.8123 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195777 0.0190806 scale
23.9201 50.1614 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.012382 0.0120676 scale
55.5072 75.8159 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0105227 0.0102555 scale
62.6922 85.9049 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195777 0.0190806 scale
32.9084 44.2831 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00412734 0.00402255 scale
152.912 209.066 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148813 0.0145035 scale
40.8008 64.3251 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0139965 0.0136411 scale
47.6091 67.5245 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145923 0.0142219 scale
46.2578 64.256 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00412734 0.00402255 scale
184.504 207.717 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
251.146 298.776 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087554 0.00853312 scale
75.0223 96.5357 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0105227 0.0102555 scale
59.098 78.2105 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
204.621 277.056 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0162493 0.0158368 scale
34.4925 50.3928 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
63.1872 127.641 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145923 0.0142219 scale
26.161 65.3846 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652589 0.00636021 scale
49.0171 122.487 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109199 0.0106427 scale
24.0368 61.09 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
83.1327 172.625 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087554 0.00853312 scale
17.2956 53.9358 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154431 0.015051 scale
15.8453 33.3433 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
45.4862 56.1412 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00772154 0.0075255 scale
59.4739 40.994 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0087554 0.00853312 scale
94.1522 23.2436 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00583693 0.00568874 scale
143.76 39.2512 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.028595 0.027869 scale
29.1093 7.61167 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109199 0.0106427 scale
73.7433 15.3129 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0761043 0.0741721 scale
10.0524 1.69592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0113032 0.0110162 scale
77.8896 24.769 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167653 0.0163397 scale
53.5922 18.4239 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020008 0.0195 scale
45.0795 15.8297 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0182258 0.0177631 scale
31.772 2.80357 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00967946 0.00943371 scale
57.5859 5.19944 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
74.5556 6.92525 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
99.6789 14.9155 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
110.993 21.1016 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0157164 0.0153174 scale
52.1906 12.0706 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00291847 0.00284437 scale
283.868 71.3725 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0105227 0.0102555 scale
75.3924 14.8603 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020008 0.0195 scale
38.1292 6.43537 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0170174 0.0165854 scale
44.1236 7.5675 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00714876 0.00696726 scale
112.708 23.4454 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.020008 0.0195 scale
34.0209 4.73179 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109199 0.0106427 scale
46.3447 4.45283 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00652589 0.00636021 scale
73.2758 8.05005 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.003663 0.97619 0.150183 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514371 0.00271659 0.496776 0.00278216 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.461819 0.472967 scale
1.11379 1.05035 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
64.0238 5.70648 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00448629 0.00459458 scale
24.7398 86.9916 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0309738 0.0317215 scale
3.26534 15.2682 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112903 0.0115628 scale
9.5268 51.4928 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167862 0.0171914 scale
7.30006 40.5698 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106795 0.0109373 scale
14.2563 67.7005 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00634458 0.00649772 scale
139.458 113.96 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00448629 0.00459458 scale
205.671 100.804 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00259016 0.00265268 scale
346.658 217.576 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0132073 0.0135261 scale
66.3149 45.498 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
110.255 90.8335 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100317 0.0102738 scale
89.8924 29.8264 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0118696 0.0121561 scale
73.908 21.7643 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0161756 0.016566 scale
53.6655 16.2936 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00448629 0.00459458 scale
188.557 44.485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0129508 0.0132634 scale
58.5932 8.15929 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00819081 0.00838852 scale
59.8024 3.99355 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103606 0.0106107 scale
46.7751 3.96297 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0318284 0.0325967 scale
11.8702 9.39082 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0215155 0.0220348 scale
14.6704 12.0845 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00897259 0.00918916 scale
22.4606 20.7494 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
32.6226 24.6939 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103606 0.0106107 scale
27.6199 12.5034 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159668 0.0163522 scale
6.10077 31.3975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0756044 0.0774293 scale
1.31487 7.00459 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0274117 0.0280734 scale
4.72535 25.9777 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00634458 0.00649772 scale
83.9016 147.062 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00897259 0.00918916 scale
82.3821 96.7781 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00259016 0.00265268 scale
287.812 332.26 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0169848 0.0173948 scale
50.8053 45.5257 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0144214 0.0147695 scale
60.0808 51.0592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
136.342 77.0809 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103606 0.0106107 scale
75.3997 11.3498 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
16.9052 94.0336 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100317 0.0102738 scale
12.6769 69.7863 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00897259 0.00918916 scale
17.1812 81.7757 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0207213 0.0212215 scale
8.64955 36.7873 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00933896 0.00956439 scale
20.5558 84.1884 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0169848 0.0173948 scale
29.6535 55.1199 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0112903 0.0115628 scale
48.8917 79.4999 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0137059 0.0140367 scale
63.9362 54.0983 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
126.572 110.918 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0148794 0.0152385 scale
26.6544 61.2449 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00897259 0.00918916 scale
31.2207 96.789 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0100317 0.0102738 scale
13.7664 65.5668 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0251126 0.0257187 scale
3.88212 20.4151 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0192092 0.0196728 scale
5.71498 23.7256 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106795 0.0109373 scale
11.0117 42.1942 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121489 0.0124422 scale
13.9016 41.5048 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00933896 0.00956439 scale
37.2847 73.1485 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0096915 0.00992543 scale
46.2674 59.9279 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00933896 0.00956439 scale
96.4411 31.221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0151031 0.0154677 scale
59.2911 18.8904 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00448629 0.00459458 scale
202.042 67.584 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0121489 0.0124422 scale
56.5687 7.18202 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0139485 0.0142851 scale
53.7565 11.3048 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
96.0918 15.042 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0103606 0.0106107 scale
64.7199 10.6345 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0161756 0.016566 scale
41.1924 7.56851 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0179452 0.0183783 scale
36.9197 7.16986 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00685293 0.00701834 scale
64.7388 11.2662 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00259016 0.00265268 scale
175.56 27.7078 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.015541 0.0159161 scale
28.8129 2.54397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00366304 0.00375146 scale
131.243 11.0597 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0192092 0.0196728 scale
12.9308 6.56642 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167862 0.0171914 scale
6.05379 32.2709 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00259016 0.00265268 scale
47.3291 258.798 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0302062 0.0309353 scale
4.62421 23.3833 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{621.5, 95.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009]0000Ga000`40O003h00OogooogooKgoo003o
OoooOom_Ool00?mooomoofmoo`00ogooogooKgoo000kOol:001HOol:001DOol3001TOol00`00Oomo
o`02Ool5001TOol3001FOol00`00Ool00008000iOol003Eoo`H000Yoo`H004aoo`H000Yoo`H004ao
o`8000=oo`03001oogoo05eoo`T000Eoo`P0055oo`800005Ool007ooOol00003Ool5001AOol60000
0goo00000006Ool6000cOol003=oo`8001Ioo`8004Qoo`8001Ioo`8004Uoo`@000=oo`03001oogoo
05]oo`800003Ool000000080011oo`8004Moo`04001oogooOolC001?Ool20002Ool7000<Ool2000a
Ool002moo`@001Yoo`<0045oo`@001Yoo`@004Eoo`05001oogooOol00003Ool00`00Oomoo`1GOol3
0002Ool00`00Ool0000=Ool00`00Oomoo`04Ool40012Ool600000goo001oo`0<0002Ool70006Ool5
000jOol40005Ool6000>Ool4000]Ool002ioo`03001oogoo01moo`8003eoo`80029oo`80049oo`80
00=ooa8004Yoo`80021oo`8003ioo`H0009oo`03001oogoo00Yoo`D0009oo`H000=oo`03001oogoo
00=oo`8003Ioo`80025oo`8002]oo`00;7oo0P0097oo0P00>Goo0P009Woo0P00?goo1`0000Aoo`00
000000=oo`03001oo`0000Moo`@004Aoo`8002Aoo`8003Yoo`<00004Ool00000000BOol02000Oomo
ogoo001oo`00Ool60008Ool2000bOol2000;Ool3000COol20002Ool2000YOol002Yoo`8002Qoo`80
03Ioo`03001oogoo02Qoo`8003aoo`D00004Ool000000002Ool00`00Ool00002Ool2000;Ool20010
Ool2000VOol4000fOol20002Ool01000Oomoo`0067oo1P0000Aoo`00000000Qoo`03001oogoo02io
o`8000eoo`8001=oo`04001oo`000003Ool00`00Oomoo`0VOol002Qoo`8002aoo`80039oo`8002eo
o`03001oogoo03Ioo`T000Eoo`03001oogoo015oo`@003]oo`03001oogoo02Ioo`800003Ool00000
03=oo`80025oo`P00003Ool0000000Moo`03001oogoo02aoo`03001oogoo021oo`D000Aoo`<002Io
o`009goo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0<goo0`0000=o
o`00Ool017oo0P000Woo0P0067oo0P00>7oo00<007oo0000:Goo0P0000=oo`00Ool0;goo0P009Goo
1P0000=oo`0000000P001Goo00<007ooOol0:Woo0P008goo10001Goo00<007oo00000P0097oo000W
Ool00`00Oomoo`0_Ool00`00Oomoo`0/Ool00`00Oomoo`0`Ool00`00Oomoo`0`Ool70007Ool2000L
Ool00`00Oomoo`0dOol01000Ool00000;Goo00<007ooOol0;7oo00<007ooOol09goo00<007ooOol0
0Woo00<007oo00000`000goo00<007ooOol0:Woo00D007oo001oo`00021oo`@000Eoo`<00003Ool0
07oo02=oo`009Goo0P00<Woo0P00;7oo00<007ooOol0<Woo0P00;Woo0P000Woo0P00:Goo0P00<Woo
0P00<Woo00<007ooOol0:goo00<007ooOol09goo00<007ooOol00Woo1`000Woo00<007ooOol0:7oo
0P000goo00<007oo00007goo0P0000=oo`00Ool01Woo10008goo000TOol00`00Oomoo`0dOol00`00
Oomoo`0XOol00`00Oomoo`0eOol00`00Oomoo`0ZOol30002Ool2000[Ool00`00Oomoo`0^Ool00`00
Oomoo`0cOol00`00Oomoo`0XOol2000[Ool01000Oomoogoo1`000Woo00<007ooOol09goo00L007oo
Ool007oo001oo`02000OOol01000Ool000001Goo00<007ooOol00goo0P008Goo000SOol00`00Oomo
o`0fOol00`00Oomoo`0VOol00`00Oomoo`0gOol00`00Oomoo`0XOol5000_Ool00`00Oomoo`0/Ool0
1000Oomoo`00=7oo00<007ooOol09Goo1000:goo00<007ooOol017oo1@0000=oo`00Ool09goo00<0
07ooOol00Woo00<007ooOol08Woo00<007ooOol017oo00<007oo00001Woo00<007ooOol07Woo000R
Ool00`00Oomoo`0gOol2000VOol00`00Oomoo`0hOol2000XOol00`00Ool00002000aOol2000/Ool0
0`00Oomoo`0fOol00`00Oomoo`0SOol00`00Ool00002000/Ool00`00Oomoo`04Ool5000XOol00`00
Oomoo`02000]Ool00`00Ool00007Ool00`00Oomoo`0MOol0025oo`03001oogoo03Yoo`03001oogoo
029oo`03001oogoo03]oo`03001oogoo02=oo`<00003Ool0000003Aoo`03001oogoo02Qoo`03001o
ogoo03Qoo`03001oogoo029oo`03001oo`00008002aoo`03001oogoo00Eoo`D002Ioo`04001oogoo
Ool2000]Ool30007Ool00`00Oomoo`0MOol0025oo`03001oogoo03]oo`03001oogoo021oo`03001o
ogoo03eoo`03001oogoo025oo`03001oogoo008003Moo`03001oogoo02Ioo`03001oogoo03Yoo`03
001oogoo021oo`03001oogoo031oo`03001oogoo00Eoo`D002Eoo`04001oo`00000jOol00`00Oomo
o`0LOol0021oo`03001oogoo03aoo`03001oogoo01moo`03001oogoo03ioo`03001oogoo025oo`H0
03Moo`03001oogoo02Aoo`03001oogoo03aoo`03001oogoo01ioo`03001oogoo039oo`X00003Ool0
000002=oo`03001oogoo008003Qoo`800003Ool007oo01aoo`007goo00<007ooOol0?Woo00<007oo
Ool07Goo00<007ooOol0@7oo00<007ooOol07Woo0`000Woo0P00>Goo00<007ooOol08Woo00<007oo
Ool0?Woo00<007ooOol077oo00<007ooOol0>Woo0`000Woo0P008Goo00<007ooOol0>goo0P000Woo
00<007ooOol06Woo000NOol00`00Oomoo`10Ool00`00Oomoo`0LOol00`00Oomoo`11Ool00`00Oomo
o`0LOol00`00Ool00003Ool00`00Oomoo`0iOol00`00Oomoo`0QOol00`00Oomoo`0kOol20002Ool0
0`00Oomoo`0JOol00`00Oomoo`0hOol200000goo001oo`0400000goo001oo`0NOol00`00Oomoo`11
Ool00`00Oomoo`0IOol001eoo`03001oogoo049oo`03001oogoo01Yoo`03001oogoo04=oo`03001o
ogoo01]oo`06001oogoo001oo`00?Goo00<007ooOol07goo00<007ooOol0?7oo0P000Woo00<007oo
Ool06Woo00<007ooOol0>7oo0P0000Aoo`00001oo`<0009oo`03001oogoo01]oo`03001oogoo049o
o`03001oogoo01Uoo`007Goo00<007ooOol0@goo00<007ooOol067oo00<007ooOol0AGoo00<007oo
Ool06Goo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol07goo00<007ooOol0@Goo00<007oo
Ool067oo00<007ooOol0?Woo00<007oo00000P0000=oo`00Ool077oo00<007ooOol03Woo00<007oo
Ool0<Woo00<007ooOol067oo000LOol00`00Oomoo`14Ool00`00Oomoo`0GOol00`00Oomoo`16Ool0
0`00Oomoo`0IOol01000Ool00000@Goo00<007ooOol07Goo00<007ooOol0@Woo00<007ooOol067oo
00<007ooOol0@Goo0P000Woo00<007ooOol06Goo00<007ooOol03Woo00<007oo0000;goo0`0000=o
o`00Ool06Goo000LOol00`00Oomoo`15Ool00`00Oomoo`0FOol00`00Oomoo`17Ool00`00Oomoo`0G
Ool00`00Oomoo`020012Ool00`00Oomoo`0LOol00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomo
o`13Ool200000goo001oo`0JOol00`00Oomoo`0=Ool01@00Oomoogoo0000;Goo0P0000Eoo`00001o
o`0001Uoo`006goo00<007ooOol0AWoo00<007ooOol05Goo00<007ooOol0B7oo00<007ooOol05Woo
00<007ooOol0AWoo00<007ooOol06Woo00<007ooOol0A7oo00<007ooOol05Goo00<007ooOol0A7oo
0`0000=oo`00Ool067oo00<007ooOol03goo00@007ooOol0009oo`<002Uoo`@00003Ool007oo01Qo
o`006goo00<007ooOol0Agoo00<007ooOol057oo00<007ooOol00P00Agoo00<007ooOol057oo00<0
07ooOol0B7oo00<007ooOol06Goo00<007ooOol0@Woo10005Woo00<007ooOol0AGoo1@005goo00<0
07ooOol047oo0`000Woo00D007ooOomoo`0002Qoo`D00003Ool007oo01Moo`006Woo00<007ooOol0
B7oo00<007ooOol04goo00@007ooOomoo`8004Moo`03001oogoo01=oo`03001oogoo04Uoo`03001o
ogoo01Moo`@0049oo`D001Eoo`03001oogoo01moo`8002Eoo`800003Ool0000001Moo`03001oogoo
01Eoo`05001oogooOol0000ZOol400000goo001oo`0FOol001Yoo`03001oogoo04Uoo`03001oogoo
019oo`03001oogoo04]oo`03001oogoo019oo`04001oogoo0019Ool00`00Oomoo`0DOol200000goo
001oo`04000oOol6000DOol00`00Oomoo`0OOol2000UOol00`00Ool00003000FOol00`00Oomoo`0D
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol300000goo001oo`0FOol001Uoo`03001oogoo04Yoo`03
001oogoo019oo`03001oogoo04]oo`03001oogoo019oo`05001oo`00Ool00018Ool00`00Oomoo`0C
Ool01000Oomoo`001Woo00<007ooOol0?Goo1@004goo00@007ooOol0021oo`03001oogoo02=oo`80
0004Ool00000000FOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0ZOol01@00Oomoogoo
00005Woo000IOol00`00Oomoo`1:Ool00`00Oomoo`0BOol4001:Ool00`00Oomoo`0BOol300000goo
001oo`18Ool00`00Oomoo`0@Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`0lOol30002Ool00`00
Oomoo`0@Ool01000Oomoo`00AWoo10000Woo00<007ooOol04Woo00<007ooOol05Goo0P000Woo0P00
<7oo00<007ooOol057oo000IOol00`00Oomoo`1:Ool00`00Oomoo`0AOol70018Ool00`00Oomoo`0A
Ool60019Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0lOol20002
Ool00`00Oomoo`0?Ool00`00Oomoo`1:Ool20002Ool00`00Oomoo`0BOol00`00Oomoo`0GOol2000c
Ool00`00Oomoo`0COol001Uoo`03001oogoo04]oo`03001oogoo00ioo`@000=oo`<004Qoo`03001o
ogoo011oo`06001oogoo001oo`00BGoo00<007ooOol03goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol0>goo0P000Woo00<007ooOol03goo00<007ooOol0BWoo0P000Woo00<007ooOol04Goo
00<007ooOol0CGoo00<007ooOol04goo000HOol00`00Oomoo`1<Ool00`00Oomoo`0>Ool20007Ool2
0017Ool00`00Oomoo`0?Ool00`00Ool00003Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomo
o`03Ool00`00Oomoo`09Ool00`00Oomoo`0nOol00`00Oomoo`0>Ool00`00Oomoo`1?Ool00`00Oomo
o`0AOol00`00Oomoo`1=Ool00`00Oomoo`0COol001Qoo`03001oogoo04eoo`03001oogoo00aoo`<0
0003Ool00000008000=oo`8004Moo`03001oogoo00ioo`03001oo`0000<004]oo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo03moo`03001oogoo00eoo`03001oogoo051o
o`03001oogoo011oo`03001oogoo04eoo`03001oogoo01=oo`005goo00<007ooOol00`00Bgoo00<0
07ooOol037oo00@007oo001oo`D0009oo`8004Moo`03001oogoo00eoo`P004Yoo`03001oogoo00eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo03moo`03001oogoo00eoo`03001oogoo01Io
o`8003Qoo`03001oogoo011oo`03001oogoo04ioo`03001oogoo019oo`005goo2`00AWoo00<007oo
Ool02goo0P0000=oo`0000001@000Woo0P00Agoo00<007ooOol03Goo1P0000=oo`000000BWoo00<0
07ooOol037oo00<007ooOol00Woo00D007ooOomoo`0000Qoo`03001oogoo03moo`03001oogoo00eo
o`03001oogoo00<001=oo`8003Qoo`03001oogoo00moo`04001oogooOol2001<Ool00`00Oomoo`0B
Ool001Ioo`8000=oo`D0009oo`03001oogoo04=oo`03001oogoo00]oo`<00003Ool0000000D0009o
o`03001oogoo04Eoo`03001oogoo00eoo`800003Ool0000000<00003Ool007oo04Qoo`03001oogoo
00]oo`03001oogoo009oo`03001oogoo009oo`8000Moo`03001oogoo03moo`03001oogoo00aoo`03
001oogoo00D004aoo`03001oogoo00moo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo019o
o`005Goo0`0017oo0P000Woo00<007oo0000AGoo00<007ooOol037oo0`0000=oo`00Ool00`0000Ao
o`00Ool004Moo`03001oogoo00eoo`03001oo`0000=oo`800003Ool007oo04Qoo`03001oogoo00ao
o`05001oogooOol00003Ool30007Ool00`00Oomoo`10Ool00`00Oomoo`0;Ool01`00Oomoogoo001o
o`0004ioo`03001oogoo00ioo`03001oogoo04moo`03001oogoo019oo`005Goo00@007oo001oo`H0
009oo`03001oo`0004Aoo`03001oogoo00aoo`<00004Ool00000Ool300000goo00000017Ool00`00
Oomoo`0<Ool2000017oo000007oo1@00BGoo00<007ooOol037oo00D007ooOomoo`00009oo`03001o
ogoo008000Ioo`03001oogoo041oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo04eoo`03
001oogoo00ioo`03001oogoo04moo`03001oogoo019oo`0057oo0P0000=oo`0000000Woo1@0000Ao
o`00Ool004Eoo`03001oogoo00]oo`8000Aoo`H004Uoo`03001oogoo00]oo`L00003Ool0000004]o
o`03001oogoo00]oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0kOol20003Ool00`00Oomoo`0;Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool01000Oomoogoo0P00
C7oo00<007ooOol04Woo000DOol01P00Ool007oo001oo`D0009oo`<004Eoo`03001oogoo00Yoo`<0
00Aoo`<00003Ool0000004Uoo`03001oogoo00]oo`05001oo`00001oo`05001;Ool00`00Oomoo`0;
Ool01P00Oomoogoo001oo`@000=oo`03001oogoo009oo`03001oogoo03]oo`03001oo`00009oo`03
001oogoo00]oo`03001oogoo00Qoo`8004Qoo`03001oogoo00eoo`04001oogooOol40017Ool01@00
Oomoogoo000057oo000COol200001Woo000007oo001oo`<00005Ool007ooOol00016Ool00`00Oomo
o`0:Ool40005Ool40019Ool00`00Oomoo`0;Ool00`00Ool00006001<Ool00`00Oomoo`0<Ool01`00
Oomoo`00Ool007oo00<0009oo`03001oogoo009oo`03001oogoo03aoo`05001oogooOol0000=Ool0
0`00Oomoo`07Ool30018Ool00`00Oomoo`0=Ool00`00Ool000050016Ool20003Ool00`00Oomoo`0B
Ool001=oo`800004Ool007ooOol300000goo000000040016Ool00`00Oomoo`0;Ool200000goo0000
00070019Ool00`00Oomoo`0:Ool01000Oomoogoo1@00CGoo00<007ooOol03Goo00H007oo001oo`00
Ool30002Ool00`00Oomoo`020013Ool00`00Oomoo`0;Ool00`00Oomoo`1BOol00`00Oomoo`0=Ool2
000017oo000007oo0`00BWoo00<007ooOol04Woo000COol00`00Ool0000200000goo000000030000
0goo001oo`020016Ool00`00Oomoo`0;Ool20007Ool30019Ool00`00Oomoo`0:Ool00`00Ool00005
001>Ool00`00Oomoo`0=Ool01000Ool007oo0`0000Aoo`00Ool0009oo`03001oogoo04=oo`03001o
ogoo00]oo`03001oogoo011oo`80041oo`03001oogoo00eoo`03001oo`00009oo`05001oo`00Ool0
0019Ool00`00Oomoo`0BOol001=oo`03001oo`0000800004Ool000000003Ool01000Ool00000AWoo
00<007ooOol02goo0`001Woo0`00BGoo00<007ooOol02Woo00<007oo00001@00CWoo00<007ooOol0
3Woo0P0000=oo`0000000P0000=oo`0000000Woo00<007ooOol0@goo00<007ooOol02goo00<007oo
Ool03goo0P0000=oo`00Ool0?Woo00<007ooOol037oo0P000Woo0`0000Eoo`00Oomoo`0004Qoo`03
001oogoo019oo`004goo00<007ooOol00P000Woo0P000goo00<007oo0000Agoo00<007ooOol02goo
0P0000=oo`00Ool00goo0`00BWoo00<007ooOol02Woo0P000Woo0`0000=oo`00Ool0C7oo00<007oo
Ool03goo0`0000Eoo`00000007oo00<004Ioo`03001oogoo00]oo`03001oogoo00moo`04001oo`00
000oOol00`00Oomoo`0;Ool00`00Ool00002Ool200000goo00000002Ool30016Ool00`00Oomoo`0B
Ool001Aoo`03001oo`00008000Aoo`800003Ool0000004Moo`03001oogoo00]oo`03001oo`0000D0
0003Ool0000004Yoo`03001oogoo00Yoo`8000Ioo`03001oogoo04]oo`03001oogoo00moo`03001o
ogoo00D004Uoo`03001oogoo00]oo`03001oogoo008000ioo`03001oogoo03moo`03001oogoo00]o
o`04001oo`00Ool2000017oo000000000Woo0`00AWoo00<007ooOol04Woo000EOol300000goo0000
0002000017oo00000000B7oo00<007ooOol02goo00<007ooOol01P00C7oo00<007ooOol02Woo00<0
07oo000017oo00<007ooOol0C7oo00<007ooOol03goo00<007ooOol0CWoo00<007ooOol02goo00<0
07ooOol00P00D7oo00<007ooOol02goo00<007oo00000Woo0P000Woo00D007ooOomoo`0004=oo`80
009oo`03001oogoo019oo`005Woo00<007oo00001@0000=oo`000000B7oo00<007ooOol02goo00<0
07ooOol027oo0P00B7oo00<007ooOol02Woo00@007oo0000009oo`8004ioo`03001oogoo00moo`03
001oogoo04ioo`03001oogoo00]oo`03001oogoo04eoo`8000=oo`03001oogoo00]oo`03001oo`00
009oo`@000Aoo`03001oogoo045oo`80009oo`03001oogoo019oo`005Woo0`000goo0`00BWoo00<0
07ooOol02goo00<007ooOol027oo0P00B7oo00<007ooOol02Woo00@007ooOomoo`80051oo`03001o
ogoo00moo`03001oogoo04Yoo`80009oo`03001oogoo00]oo`03001oogoo04eoo`06001oo`00001o
o`003Goo00D007ooOol007oo00800003Ool007oo00=oo`03001oogoo049oo`04001oogoo000DOol0
01Moo`03001oo`00008004aoo`03001oogoo00eoo`03001oogoo051oo`03001oogoo00]oo`04001o
ogooOol2001@Ool00`00Oomoo`0?Ool00`00Oomoo`1:Ool20002Ool00`00Oomoo`0;Ool00`00Oomo
o`1=Ool400000goo001oo`0<Ool01000Oomoo`000Woo00<007oo000017oo00<007ooOol0AGoo00<0
07ooOol04Woo000GOol00`00Oomoo`1>Ool00`00Oomoo`0=Ool00`00Oomoo`1@Ool00`00Oomoo`0<
Ool00`00Oomoo`03001?Ool00`00Oomoo`0?Ool00`00Oomoo`1>Ool00`00Oomoo`0;Ool00`00Oomo
o`1=Ool30002Ool00`00Oomoo`0;Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0?Woo
0P001Goo00<007ooOol04Woo000GOol00`00Oomoo`1>Ool00`00Oomoo`0=Ool00`00Oomoo`1@Ool0
0`00Oomoo`0<Ool01@00Oomoogoo0000D7oo00<007ooOol03goo00<007ooOol0CWoo00<007ooOol0
2goo00<007ooOol0DWoo00<007ooOol037oo00<007oo00000goo0P000goo00<007ooOol05Woo0`00
;Goo00<007ooOol04Woo000GOol00`00Oomoo`1>Ool00`00Oomoo`0=Ool00`00Oomoo`1@Ool00`00
Oomoo`0<Ool01000Oomoogoo0P00Cgoo00<007ooOol03goo00<007ooOol0CGoo00<007ooOol037oo
00@007ooOomoo`8004ioo`03001oogoo00eoo`800006Ool007oo001oo`000Woo00<007ooOol05goo
00<007oo00009Goo00<007ooOol01Goo00<007ooOol04Woo000GOol00`00Oomoo`1>Ool00`00Oomo
o`0>Ool00`00Oomoo`1?Ool00`00Oomoo`0<Ool00`00Oomoo`04001=Ool00`00Oomoo`0AOol00`00
Oomoo`1<Ool00`00Oomoo`0=Ool01000Oomoo`00Cgoo00<007ooOol03goo1P0000=oo`00Ool06Woo
00<007ooOol08goo0P001Woo00<007ooOol04goo000GOol00`00Oomoo`1>Ool00`00Oomoo`0>Ool0
0`00Oomoo`1?Ool00`00Oomoo`0=Ool00`00Ool00003001=Ool00`00Oomoo`0AOol00`00Oomoo`1<
Ool00`00Oomoo`0=Ool00`00Oomoo`1@Ool00`00Oomoo`0@Ool00`00Ool000030011Ool40005Ool0
0`00Oomoo`0COol001Qoo`03001oogoo04eoo`03001oogoo00ioo`03001oogoo04moo`03001oogoo
00eoo`03001oo`00008004ioo`03001oogoo015oo`03001oogoo04aoo`03001oogoo00eoo`03001o
ogoo051oo`03001oogoo011oo`03001oogoo03Yoo`8000Uoo`03001oogoo00Eoo`03001oogoo01=o
o`0067oo00<007ooOol0C7oo00<007ooOol03goo00<007ooOol0CWoo00<007ooOol03Woo00<007oo
Ool00`00CGoo00<007ooOol04Goo00<007ooOol0Bgoo00<007ooOol03Woo00<007ooOol047oo0`00
?7oo00<007ooOol04Woo00<007ooOol0>Goo0P004Goo00<007ooOol04goo000IOol00`00Oomoo`1;
Ool00`00Oomoo`0@Ool00`00Oomoo`1=Ool00`00Oomoo`0>Ool00`00Oomoo`1?Ool00`00Oomoo`0C
Ool00`00Oomoo`1:Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Ool0000lOol00`00Oomoo`0B
Ool01000Oomoo`00BWoo00<007ooOol057oo000IOol00`00Oomoo`1:Ool00`00Oomoo`0AOol00`00
Oomoo`1<Ool00`00Oomoo`0@Ool01000Oomoo`00CGoo00<007ooOol04goo00<007ooOol0BWoo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol0>goo00<007ooOol04goo1P00Agoo00<007ooOol0
57oo000IOol00`00Oomoo`1:Ool00`00Oomoo`0BOol00`00Oomoo`1;Ool00`00Oomoo`0@Ool00`00
Oomoo`1=Ool00`00Oomoo`0EOol00`00Oomoo`19Ool00`00Oomoo`0@Ool00`00Oomoo`1=Ool00`00
Oomoo`0COol01P00Oomoo`00Ool004Ioo`03001oogoo01Eoo`006Goo00<007ooOol0BWoo00<007oo
Ool04Woo00<007ooOol0Bgoo00<007ooOol04Goo00<007ooOol0C7oo00<007ooOol05Goo00<007oo
Ool0A7oo0P000Woo00<007ooOol04Goo00@007ooOol004Eoo`<000=oo`03001oogoo01Aoo`03001o
o`0000<0015oo`03001oogoo039oo`03001oogoo01Eoo`006Woo00<007ooOol0BGoo00<007ooOol0
4Woo00<007ooOol0Bgoo00<007ooOol04Goo00<007ooOol0C7oo00<007ooOol05Woo0`00@goo00D0
07ooOomoo`0001Aoo`@004Aoo`@00003Ool007oo01Ioo`H0011oo`03001oo`00039oo`03001oogoo
01Ioo`006Woo00<007ooOol0B7oo00<007ooOol04goo00<007ooOol0BWoo00<007ooOol04goo00<0
07ooOol0Bgoo00<007ooOol05Woo00<007ooOol0@Goo0`000Woo00<007ooOol057oo0P00AGoo0`00
0Woo00<007ooOol05Woo1P003goo0P00<goo00<007ooOol05Woo000KOol00`00Oomoo`17Ool00`00
Oomoo`0DOol00`00Oomoo`19Ool00`00Oomoo`0COol01000Ool00000BGoo00<007ooOol067oo00<0
07oo0000@Goo00D007ooOomoo`0001Ioo`04001oo`000014Ool01000Oomoo`006Goo100000=oo`00
0000@Woo00<007ooOol05goo000KOol00`00Oomoo`16Ool00`00Oomoo`0EOol00`00Oomoo`18Ool0
0`00Oomoo`0DOol50018Ool00`00Oomoo`0HOol200000goo001oo`12Ool00`00Oomoo`0FOol30017
Ool00`00Oomoo`0GOol3000017oo00000000?goo0P0000=oo`00Ool067oo000LOol00`00Oomoo`15
Ool00`00Oomoo`0FOol00`00Oomoo`17Ool00`00Oomoo`0DOol400000goo001oo`15Ool00`00Oomo
o`0IOol200000goo001oo`0kOol200001Goo000007oo00006Goo0`00AWoo00<007ooOol067oo1P00
?Woo1@006Woo000LOol00`00Oomoo`14Ool00`00Oomoo`0GOol20017Ool00`00Oomoo`0EOol01P00
Ool00000Ool004Eoo`03001oogoo01Yoo`<003eoo`800003Ool00000008001Uoo`8004Moo`03001o
ogoo01Qoo`H003eoo`06001oo`00001oo`006Woo000MOol00`00Oomoo`12Ool00`00Oomoo`0JOol0
0`00Oomoo`13Ool00`00Oomoo`0FOol2000017oo00000000AGoo00<007ooOol077oo00<007ooOol0
?Woo0`006goo00<007ooOol0@Goo0P0000=oo`00Ool077oo00<007oo00001000>goo10006goo000N
Ool00`00Oomoo`10Ool00`00Oomoo`0LOol00`00Oomoo`11Ool00`00Oomoo`0IOol50013Ool00`00
Oomoo`0NOol00`00Oomoo`0lOol200000goo001oo`0KOol00`00Oomoo`0?Ool2000^Ool300000goo
001oo`0MOol00`00Ool00003Ool00`00Oomoo`0gOol300000goo001oo`0JOol001moo`03001oogoo
03ioo`03001oogoo01eoo`03001oogoo041oo`03001oogoo01aoo`<0049oo`03001oogoo01moo`03
001oogoo03]oo`@001eoo`80011oo`8001=oo`<00003Ool007oo01Aoo`03001oo`000080021oo`80
00=oo`03001oogoo03Moo`@001aoo`0087oo00<007ooOol0?Goo00<007ooOol07Woo00<007ooOol0
?goo00<007ooOol077oo00@007ooOol0041oo`03001oogoo025oo`03001oogoo03Moo`03001oo`00
00@001moo`03001oogoo025oo`04001oogoo0002Ool3000BOol3000SOol4000jOol01000Ool00000
77oo000POol00`00Oomoo`0lOol00`00Oomoo`0OOol2000oOol00`00Oomoo`0NOol01000Ool00000
?Woo00<007ooOol08Woo0P00=goo1`008Goo00@007oo0000021oo`<000=oo`8001Aoo`03001oogoo
029oo`@003Uoo`<001eoo`008Goo00<007ooOol0>Woo00<007ooOol08Woo00<007ooOol0>goo00<0
07ooOol087oo0P00?Woo00<007ooOol09Goo00<007ooOol0=7oo1@008goo00<007oo00000`009goo
0P0037oo1@009Goo00<007oo0000>Woo00<007ooOol07Goo000ROol00`00Oomoo`0hOol00`00Oomo
o`0TOol00`00Oomoo`0iOol00`00Oomoo`0ROol00`00Oomoo`0kOol00`00Oomoo`0WOol00`00Oomo
o`0cOol300000goo001oo`0SOol01@00Ool007oo00009Goo100027oo00<007ooOol00Woo0P00:7oo
00<007ooOol0>7oo00<007ooOol07Woo000SOol00`00Oomoo`0fOol00`00Oomoo`0VOol00`00Oomo
o`0gOol00`00Oomoo`0TOol00`00Oomoo`0iOol00`00Oomoo`0XOol00`00Oomoo`0aOol6000VOol4
000UOol200000goo001oo`04Ool01000Oomoo`001Goo00<007ooOol09goo00<007ooOol0=Woo00<0
07ooOol07goo000TOol00`00Oomoo`0dOol00`00Oomoo`0XOol00`00Oomoo`0eOol00`00Oomoo`0V
Ool00`00Oomoo`0hOol00`00Oomoo`0YOol00`00Oomoo`0`Ool200000goo001oo`0XOol2000VOol0
1000Oomoo`001Goo0P001Goo0P00:goo0P00=Goo00<007ooOol087oo000UOol00`00Oomoo`0bOol0
0`00Oomoo`0ZOol00`00Oomoo`0cOol00`00Oomoo`0XOol00`00Oomoo`02000cOol2000]Ool00`00
Oomoo`0bOol00`00Oomoo`0YOol00`00Oomoo`0TOol3000:Ool2000_Ool00`00Oomoo`0aOol00`00
Oomoo`0QOol002Ioo`03001oogoo031oo`03001oogoo02]oo`80039oo`8002aoo`@0035oo`80031o
o`80031oo`8002eoo`8002Eoo`<000Qoo`03001oogoo031oo`05001oogooOol0000XOol20003Ool0
0`00Oomoo`0ROol002Moo`8002ioo`80031oo`8002moo`03001oogoo02ioo`@002eoo`8003Aoo`03
001oo`00008002Yoo`03001oogoo02moo`03001oogoo00moo`<0011oo`<000Moo`03001oogoo039o
o`03001oo`00008002Ioo`<00003Ool0000002Eoo`00:Goo0P00:Woo0P00=7oo00<007ooOol0:Woo
0P00<goo0`0097oo0`0017oo00<007ooOol0=Goo10008Goo0`0017oo0P00<goo00<007ooOol03goo
0P004Woo00<007ooOol017oo00<007ooOol0=7oo0`00:7oo0`009goo000[Ool2000VOol2000gOol2
000XOol2000gOol2000ROol01P00Oomoogoo001oo`8003Yoo`80021oo`06001oogooOol007oo0P00
=Woo0P000goo0`0077oo10000Woo0P00>Goo0P005Woo0P003goo0P00:7oo000]Ool00`00Oomoo`0Q
Ool2000kOol2000TOol2000kOol2000MOol600000goo0000000nOol2000MOol20003Ool2000jOol6
0002Ool3000AOol30002Ool7000mOol20005Ool3000;Ool00`00Ool0000=Ool2000ZOol002ioo`80
021oo`03001oogoo03eoo`80021oo`8003moo`03001oogoo01Yoo`P0045oo`8000Ioo`04001oo`00
000@Ool200000goo00000002000oOol200001Goo001oogoo00004Goo00<007oo00000Woo1000@Woo
0P000goo00@007ooOol000]oo`8000]oo`8002aoo`00<7oo0P0077oo0P00@Woo0P0077oo0P00@Woo
0P003Goo0`002Woo1@0000=oo`000000@goo00@007ooOomoo`@0009oo`03001oogoo00eoo`D00003
Ool007oo041oo`D000Aoo`D000Qoo`04001oo`00Ool20017Ool400000goo001oo`06Ool2000<Ool4
000^Ool0039oo`@001Ioo`8004Ioo`@001Ioo`8004Ioo`D000Ioo`D000Uoo`L004Ioo`L0009oo`04
001oogooOol20008Ool600000goo001oo`13Ool40003Ool200000goo00000008Ool4001=Ool40004
Ool00`00Oomoo`030005Ool4000bOol003Ioo`@000aoo`H004aoo`@000aoo`H004eoo`@0009oo`03
001oo`0000<000Aoo`@000=oo`03001oogoo04]oo`@00003Ool007oo009oo`8000Eoo`<000Ioo`03
001oogoo04Mooa0005Eoo`H00003Ool0000000H003Ioo`00>Woo3000EWoo3000Egoo3000F7oo3@00
EWoo1000Hgoo1000?7oo003oOoooOom_Ool00?mooomoofmoo`00ogooogooKgoo003oOoooOom_Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 620.5}, {94.625, 0}} -> {-0.177959, -0.0230818, \
0.0102432, 0.0102432}, {{17.375, 107.438}, {92.3125, 2.25}} -> {-263.056, \
-187.668, 4.11288, 3.96395}, {{116.5, 206.563}, {92.3125, 2.25}} -> \
{-651.137, -187.668, 4.01696, 3.96395}, {{215.625, 305.688}, {92.3125, 2.25}} -> \
{-1033.23, -202.348, 3.96395, 4.13305}, {{314.75, 404.813}, {92.3125, 2.25}} -> \
{-1510.26, -188.08, 4.17282, 3.97554}, {{413.875, 504}, {92.3125, 2.25}} -> \
{-1819.21, -193.064, 3.96395, 4.06722}, {{513, 603.125}, {92.3125, 2.25}} -> \
{-2286.26, -187.789, 4.0873, 3.99097}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["This highlights the initial priority of the home base and the \
subsequent explosive increase in the spatial scatter (spread of bubbles in \
the arena) and temporal scatter (more evenly spread diameters of bubbles) of \
lingering.  A numerical expression of this scatter is obtained by a measure \
of diversity developed in our lab: it represents the average distance between \
every two episodes within a given interval, weighted by the durations' \
distribution  (for principles of measurement of diversity see Patil &Taillie \
1982). Diversity is defined as:\n",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["\n",
    PageWidth->WindowWidth,
    FontSize->14],
  "\n",
  Cell[BoxData[
      \(\[Sum]\+\(i, j = 1\)\%n\( p\_i\) \(p\_j\) d\_\(i, j\)\)], "Input",
    FontSize->20],
  "\n",
  StyleBox["\n",
    PageWidth->WindowWidth,
    FontSize->14],
  StyleBox["\n\n\nWhere p",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["i",
    PageWidth->WindowWidth,
    FontSize->12,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the proportion of time spent at stopping place i, and  d",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["ij",
    PageWidth->WindowWidth,
    FontSize->12,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the distance between the location of the i-th and j-th \
episodes. The summation is thus over every possible pair of stops within an \
interval (Tchernichovski et al., 1996). This measure is designed to increase \
as a greater distance is \"covered\", and as the duration of stopping is \
distributed more evenly within that distance (the product of the time \
proportions is obviously the largest when p",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["i",
    PageWidth->WindowWidth,
    FontSize->12,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" and p",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["j",
    PageWidth->WindowWidth,
    FontSize->12,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" are equal).\nOne can easily implement this measure as a \
Mathematica function and add it to the set of tools (see Appendix, 2.4.)\nThe \
diversity numbers corresponding to the bubble graphs displayed in figure 6 \
would be produced by evaluating\nMap[Diversity, TimeSlice[lingering, 300]]\n",
    
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["{94.0723, 131.645, 193.754, 339.331, 375.662, 273.02}\n",
    PageWidth->WindowWidth,
    FontSize->12,
    FontVariations->{"Underline"->True}],
  StyleBox["As expected upon viewing the dynamic visualizations in fig. 6, \
the fourth and fifth slabs show an abrupt rise in diversity. \nThis measure \
has been originally devised to capture the developmental transition from \
restrained to relatively free behavior. It is an instructive measure as it \
reflects the animal's freedom of movement in the arena (Tchernichovski et \
al., 1996).\nThe visualization suggests the hypothesis that periods of \
intense exploration could be better characterized by an increase in diversity \
rather than by a mere increase in mileage. To examine this hypothesis all one \
has to do is apply the same function to a set of sessions of all the animals \
in the experimental population.",
    PageWidth->WindowWidth,
    FontSize->12],
  "\nThis  dynamics is interesting in many respects, firstly because the unit \
of the dynamics are not arbitrary slices of equal times (say 5mn) but a \
certain number of performances of a rat defined pattern (lingering behavior), \
secondly because it clearly shows the initial priority of the home base and \
the sudden \"explosion\" of spatial diversity of the lingering episodes. \
Actually this  series of graphs brings to mind the diversity measure defined \
in the paper [Tchernichovski et al.,1995]. One would really like to compute \
the dynamics of this measure, but, alas!, the diversity function was not \
provided in the original SEE package. Well, this is the occasion to \
illustrate the advantage of working in an integrated environment; we can \
simply define and program diversity and see the results it gives when \
analysing the data from this session. If we like it, we shall see later how \
to incorporate it in the SEE package, so that it becomes a standard tool in \
future sessions (without need for further programming).\nIn [Tchernichovski \
et al.,1995], diversity was defined thus:\n\n\"The spatial and temporal \
scatter of stops within a given time interval is thus captured by a measure \
of diversity developed by us. It represents the average distance between \
every two stops within the interval, weighted by the time distribution (for \
principles of measurement of diversity see Patil &Taillie 1982). the \
diversity is defined as \nD(t)=",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Sum]\+\(i = 1\)\%n\),
            ScriptLevel->0], 
          StyleBox[" ",
            ScriptLevel->0], 
          RowBox[{
            StyleBox[\(\[Sum]\+\(j = 1\)\%n\),
              ScriptLevel->0], 
            StyleBox[" ",
              ScriptLevel->0], \((Pi\ Pj\ \(distance(i, j)\)\)}]}], 
        TraditionalForm]]],
  ")\nWhere Pi  is the proportion of time spent at stopping place i. i and j \
are two indexes indicating every pair of stopping places. The summation is, \
therefore, over every possible pair of stops within an interval (...) This \
diversity measure is designed to increase as a greater distance is \
\"covered\", and as the duration of stopping is distributed more \
homogeneously within that distance (the product of the time proportions is \
obviously the largest when Pi and Pj are equal).\"\nTranslating this to a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function is almost immediate, even with the extra complication of not \
being totally careless with the performance of the resulting function ( an \
inefficient version would be much simpler to write, but from our experience \
the extra complication is worthwhile)"
}], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[BoxData[
    \(Diversity[listofstops_] := 
      Module[{totaltime, localdata, place, time}, \n\t\tlocaldata = 
          Partition[data[\([Flatten[listofstops]]\)], 2]; \n\t\ttotaltime = 
          N[Apply[Plus, 
              Map[#[\([2, 1]\)] - #[\([1, 1]\)] &, localdata]]]; \n\t\tplace[
            k_] := {0.5 \((localdata[\([k, 1, 2]\)] + 
                  localdata[\([k, 2, 2]\)])\), 
            0.5 \((localdata[\([k, 1, 3]\)] + 
                  localdata[\([k, 2, 3]\)])\)}; \n\t\ttime[
            k_] := \((localdata[\([k, 2, 1]\)] - localdata[\([k, 1, 1]\)])\)/
            totaltime; \n
        Return[Apply[Plus, 
            Flatten[Table[
                Distance[place[i], place[j]] time[i]\ time[j], {i, 1, 
                  Length[listofstops]}, {j, 1, 
                  Length[listofstops]}]]]];]\)], "Input",
  PageWidth->WindowWidth],

Cell["\<\
Once this function is written we can apply it on any list of lingerings and \
get the diversity within this list: for instance the numbers corresponding to \
the  bubble graphs displayed earlier would be produced by evaluating\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Script[{"\<Timing[Map[Diversity,Partition[lingering,40]]]\>"}, 
      twofiles]\)], "Input"],

Cell[BoxData[
    \({{{0.828000000000003`\ Second, {142.70794307718958`, 
            180.17808682682315`, 167.392618884174`, 121.77812620622619`, 
            123.22986685736723`, 
            111.3404353260329`}}}, {{1.218999999999994`\ Second, \
{10.831949345104665`, 84.72926923786572`, 57.38162578099431`, 
            149.35305338304002`, 143.85571920332958`, 189.31797415108113`, 
            92.13599163036733`, 122.43762407195194`, 
            181.3388356508355`}}}}\)], "Output"]
}, Open  ]],

Cell["\<\
What we see above is the result of the calculation, preceded by the time the \
calculation took, which can be seen to be 5.22 seconds. As expected the \
fourth and fifth slab show an abrupt rise in diversity. It is interesting to \
note that the increase in diversity is much sharper than the corresponding \
increase in activity we computed at the begining of the SEE  session. \
Rigorously speaking this is not yet clear since in the slabbing of activity \
we used time units and here we used behavior units, we should therefore \
recompute our \"dynamics of activity through the same units:\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Script[{"\<Map[Activity,Map[{First[First[#]],Last[Last[#]]}&,Partition[\
lingering,40]]]\>"}, twofiles]\)], "Input"],

Cell[BoxData[
    \({{{3420.025697925733`, 2498.3093389605597`, 2845.642313675514`, 
          2860.800568428276`, 2278.0235533362734`, 
          2200.484479072218`}}, {{1063.9103114031063`, 880.0563636070868`, 
          1435.6157041896022`, 1217.625600452242`, 1329.0353174821573`, 
          1693.38751561861`, 1388.3762061531695`, 2327.345778680067`, 
          2887.8262970729156`}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Script[{"\<Map[Activity,Map[{First[First[#]],Last[Last[#]]}&,Partition[\
lingering,40]]]*0.01 meters\>"}, twofiles]\)], "Input"],

Cell[BoxData[
    \({{{34.20025697925733`\ meters, 24.983093389605596`\ meters, 
          28.456423136755138`\ meters, 28.608005684282762`\ meters, 
          22.780235533362735`\ meters, 
          22.00484479072218`\ meters}}, {{10.639103114031064`\ meters, 
          8.80056363607087`\ meters, 14.356157041896022`\ meters, 
          12.17625600452242`\ meters, 13.290353174821574`\ meters, 
          16.9338751561861`\ meters, 13.883762061531696`\ meters, 
          23.27345778680067`\ meters, 
          28.878262970729157`\ meters}}}\)], "Output"]
}, Open  ]],

Cell["\<\
  So it seems that periods of intense exploration  are better characterised \
by an increase in diversity than by a mere increase in mileage. As any \
perceptive reader will be prompt to notice, there would be absolutely no \
problem in automatically carrying out such a calculation on a set of files \
rather than on a single session  and then submit the resulting numbers to a \
statistical enquiry which in principle could show an interesting \
differentiation between, say, two strains of animals, equivalent in terms of \
activity or even of the dynamics of the activity. 
So far we have used only the categorization of  movement to build our \
illustrations and guide our computations, but what about the home base, and \
more generally about the role of places in the structure of exploratory \
behavior?\
\>", "Text",
  PageWidth->WindowWidth,
  FontSize->14],

Cell["\<\
The function PairPlot connects every two successive locations of stopping in \
the arena by a straight line. This helps  highlight the connectivity between \
places in the arena. In what follows we present several graphs generated by  \
SpeedPairPlot,   a variant of PairPlot distinguishing between high and low \
speed  movement segments by coloring them differently. Preliminary analysis \
of the frequency distribution of maximal velocities of movement segments \
suggested that in hooded rats segments belonging to the upper 1/8 quantile of \
the population of segments constitute a distinct population. The cutoff point \
between this population and the rest of the population is 187.75cm/sec. We \
therefore color lines designating proression segments that have  maximal \
velocities above this cutoff value in red,and segments  below this cutoff in \
black. In the following graph all the segments of movement are confounded:\
\>", "Text",
  TextJustification->1,
  FontSize->14],

Cell[BoxData[
    \(Load[ratfiles[\([1]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(graph1 = 
        See[SpeedPairPlot2[movesegments], 
          PlotLabel -> StyleForm["\<All\>", FontSize -> 14], 
          DisplayFunction -> $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -14.5625 0 ]
[.5 1.0125 14.5625 13.3125 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.3125 translate 1 -1 scale
63.000 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(All) show
88.125 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.56845 .94841 m
.6369 .9246 L
s
.6369 .9246 m
.55804 .94841 L
s
.55357 .95106 m
.3497 .93386 L
s
.3497 .93254 m
.52083 .95503 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.5744 .94577 m
.73363 .88228 L
s
.73363 .88095 m
.79315 .83995 L
s
.78423 .83995 m
.64435 .92328 L
s
.62202 .93386 m
.55952 .94841 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.4628 .95635 m
.51786 .95503 L
s
.52679 .9537 m
.66964 .87698 L
s
.67113 .87037 m
.72768 .88757 L
s
.72768 .87566 m
.55952 .94841 L
s
.5506 .94577 m
.55952 .89021 L
s
.55952 .89021 m
.46875 .95635 L
s
.4375 .94974 m
.48958 .95767 L
s
.52679 .95635 m
.70685 .90344 L
s
.71429 .89815 m
.82143 .81349 L
s
.82143 .80952 m
.8378 .77778 L
s
.88244 .74868 m
.8006 .8373 L
s
.79762 .83862 m
.55952 .94444 L
s
.54315 .93386 m
.3244 .92063 L
s
1 0 0 r
.3244 .92063 m
.52083 .94974 L
s
0 0 0 r
.5253 .94709 m
.61161 .93783 L
s
.62202 .93915 m
.64732 .9246 L
s
.65179 .92328 m
.76339 .86243 L
s
.76935 .85847 m
.82143 .76058 L
s
1 0 0 r
.81994 .75794 m
.56845 .94841 L
s
0 0 0 r
.55804 .94841 m
.70685 .90344 L
s
.70685 .89947 m
.85565 .77513 L
s
.84524 .77381 m
.80655 .79233 L
s
1 0 0 r
.79911 .75926 m
.55952 .94444 L
s
.55506 .94709 m
.11012 .73413 L
s
.11012 .73413 m
.50149 .95635 L
s
0 0 0 r
.55506 .9537 m
.74554 .87566 L
s
.75 .87302 m
.83482 .80291 L
s
.84077 .79101 m
.92857 .67328 L
s
.93601 .6627 m
.94643 .59788 L
s
1 0 0 r
.94643 .59656 m
.59673 .94048 L
s
0 0 0 r
.61905 .93783 m
.6875 .89947 L
s
.66964 .87302 m
.55804 .9418 L
s
.55506 .93783 m
.55952 .89153 L
s
.55952 .89153 m
.45982 .95635 L
s
.47619 .95899 m
.52083 .95503 L
s
.54464 .95767 m
.80952 .77646 L
s
.81101 .7619 m
.83185 .64418 L
s
.83185 .64153 m
.7872 .55159 L
s
1 0 0 r
.7872 .55159 m
.61012 .93783 L
s
0 0 0 r
.60119 .93915 m
.52679 .93915 L
s
.5253 .93915 m
.3869 .93386 L
s
.38244 .9246 m
.22768 .82011 L
s
1 0 0 r
.22768 .82011 m
.51637 .95503 L
s
0 0 0 r
.53274 .96032 m
.57589 .9418 L
s
1 0 0 r
.56994 .94312 m
.76935 .86111 L
s
0 0 0 r
.77083 .86111 m
.8378 .79101 L
s
.84226 .78836 m
.88542 .74735 L
s
.88542 .74603 m
.81399 .7672 L
s
1 0 0 r
.81548 .7619 m
.55952 .9418 L
s
0 0 0 r
.58631 .92196 m
.66071 .87169 L
s
.66667 .86508 m
.44196 .90476 L
s
.44345 .89815 m
.52083 .94444 L
s
1 0 0 r
.54018 .96164 m
.73661 .88228 L
s
0 0 0 r
.73661 .87963 m
.80804 .78042 L
s
.79762 .75926 m
.58482 .73942 L
s
1 0 0 r
.58482 .73942 m
.49107 .95635 L
s
0 0 0 r
.48363 .95635 m
.44643 .9537 L
s
.44048 .9418 m
.47024 .95899 L
s
.54911 .94841 m
.70982 .89947 L
s
.71726 .8955 m
.79464 .83862 L
s
.80208 .83598 m
.81845 .78968 L
s
.80208 .76323 m
.96429 .43254 L
s
.88839 .42196 m
.82738 .7619 L
s
.82589 .7672 m
.68155 .91402 L
s
.66071 .91799 m
.6756 .87302 L
s
.6756 .87169 m
.70238 .8955 L
s
.73512 .88624 m
.78571 .84921 L
s
.79464 .84392 m
.55655 .94841 L
s
.54315 .96429 m
.1131 .71296 L
s
.11161 .71164 m
.05506 .52249 L
s
.05804 .52249 m
.08036 .6627 L
s
.08333 .67196 m
.21875 .82143 L
s
.22173 .81217 m
.5119 .95503 L
s
.52381 .96032 m
.77827 .85317 L
s
.78423 .85053 m
.81994 .7672 L
s
.81696 .76323 m
.96429 .3955 L
s
.96131 .39153 m
.87202 .26323 L
s
1 0 0 r
.86756 .26323 m
.60565 .94048 L
s
0 0 0 r
.64881 .91667 m
.66815 .87566 L
s
.66815 .87434 m
.22917 .87698 L
s
1 0 0 r
.24256 .88757 m
.5 .95767 L
s
0 0 0 r
.54167 .96164 m
.69792 .90873 L
s
.70238 .90608 m
.80952 .82937 L
s
.8125 .83069 m
.96875 .53571 L
s
1 0 0 r
.97024 .53968 m
.56101 .94841 L
s
0 0 0 r
.59375 .9418 m
.69643 .90344 L
s
.70089 .89947 m
.75446 .84921 L
s
.75595 .85053 m
.79315 .76984 L
s
.8006 .76852 m
.89732 .72884 L
s
.89732 .7381 m
.95685 .42725 L
s
.96726 .41931 m
.92262 .33862 L
s
.93006 .33201 m
.70685 .12169 L
s
.6994 .12566 m
.65774 .09788 L
s
.66369 .10053 m
.62054 .14286 L
s
.62202 .14683 m
.67113 .14021 L
s
1 0 0 r
.6756 .13757 m
.82292 .79762 L
s
0 0 0 r
.81548 .76323 m
.5744 .94048 L
s
.61161 .93783 m
.65476 .91005 L
s
.65774 .90476 m
.67262 .87302 L
s
.65327 .85847 m
.35417 .92063 L
s
.35714 .91005 m
.50149 .95635 L
s
.55506 .94974 m
.95685 .51587 L
s
.96875 .51852 m
.95536 .3664 L
s
.95685 .37302 m
.87054 .26323 L
s
.86607 .26323 m
.85863 .21296 L
s
.85714 .19974 m
.73214 .12566 L
s
.72917 .12302 m
.69792 .11772 L
s
.69196 .1164 m
.20089 .20899 L
s
.19643 .21164 m
.0506 .44048 L
s
.0506 .44709 m
.05357 .48545 L
s
.04911 .53836 m
.09226 .63228 L
s
.12946 .62698 m
.21429 .66005 L
s
1 0 0 r
.21875 .66138 m
.74256 .8664 L
s
0 0 0 r
.74851 .86772 m
.79167 .76587 L
s
.78423 .75397 m
.66667 .63228 L
s
1 0 0 r
.65923 .64286 m
.79464 .80159 L
s
0 0 0 r
.79018 .80026 m
.79464 .77646 L
s
.78423 .74603 m
.51786 .71693 L
s
.51339 .71296 m
.10417 .38757 L
s
.10417 .38889 m
.2753 .18254 L
s
.28869 .1918 m
.56399 .17593 L
s
1 0 0 r
.55655 .18122 m
.6131 .92328 L
s
0 0 0 r
.58185 .90476 m
.49256 .93783 L
s
.47768 .90344 m
.24554 .81481 L
s
.24256 .80556 m
.22768 .7619 L
s
.2247 .75661 m
.09375 .62037 L
s
1 0 0 r
.13244 .62963 m
.1994 .36772 L
s
0 0 0 r
.20089 .37037 m
.05506 .41667 L
s
.05506 .41931 m
.20387 .20503 L
s
.20685 .2037 m
.60119 .14683 L
s
1 0 0 r
.60714 .14815 m
.56696 .93783 L
s
0 0 0 r
.5506 .94974 m
.56696 .84656 L
s
1 0 0 r
.56845 .83995 m
.10119 .7209 L
s
0 0 0 r
.0744 .66402 m
.04911 .57804 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.14583 .61111 m
.5997 .17063 L
s
.60268 .16799 m
.85714 .20503 L
s
.85863 .21032 m
.85417 .25132 L
s
1 0 0 r
.85417 .25265 m
.60268 .92196 L
s
0 0 0 r
.59673 .92328 m
.48065 .94974 L
s
.53274 .96032 m
.70238 .90344 L
s
.70685 .90212 m
.78274 .85185 L
s
.79315 .84127 m
.82292 .76984 L
s
.82887 .7619 m
.94048 .40344 L
s
1 0 0 r
.95685 .38228 m
.46875 .0873 L
s
0 0 0 r
.45833 .08862 m
.37202 .11111 L
s
.36756 .11243 m
.2753 .17593 L
s
.28571 .1918 m
.05506 .47751 L
s
.04464 .50661 m
.07143 .46429 L
s
.07589 .46164 m
.3869 .4418 L
s
.38542 .44048 m
.07143 .54101 L
s
.05506 .55556 m
.09077 .57804 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.54315 .95635 m
.73661 .88095 L
s
.7381 .88889 m
.90923 .6918 L
s
.91369 .69312 m
.95982 .5582 L
s
.95833 .55556 m
.95238 .4246 L
s
.96875 .40873 m
.8869 .23148 L
s
.88988 .23016 m
.79911 .15079 L
s
.79464 .14947 m
.69494 .11243 L
s
.68155 .10582 m
.59524 .09524 L
s
.62798 .09392 m
.6131 .1455 L
s
.6131 .15212 m
.56994 .08333 L
s
.55804 .08201 m
.49256 .08069 L
s
.46875 .08069 m
.37946 .10185 L
s
.37649 .10185 m
.17113 .23016 L
s
.14435 .25265 m
.22619 .24735 L
s
.2247 .25 m
.09226 .41534 L
s
1 0 0 r
.0997 .41402 m
.77381 .84656 L
s
0 0 0 r
.77083 .84921 m
.72321 .89021 L
s
.71875 .89418 m
.61756 .93783 L
s
.5997 .94974 m
.56101 .94841 L
s
.55804 .95503 m
.67708 .88757 L
s
.67113 .85979 m
.56399 .94048 L
s
.55506 .95106 m
.30655 .91667 L
s
.30506 .91402 m
.1503 .80423 L
s
.14137 .79101 m
.0506 .57011 L
s
.04613 .57275 m
.10863 .34127 L
s
.10119 .3254 m
.3631 .1045 L
s
.36607 .10582 m
.76488 .13624 L
s
1 0 0 r
.76488 .13624 m
.75149 .87302 L
s
0 0 0 r
.73363 .83995 m
.55952 .7963 L
s
.58185 .80423 m
.7872 .75794 L
s
.78869 .75661 m
.83482 .7963 L
s
.83185 .7791 m
.82143 .75132 L
s
.81101 .74735 m
.74107 .53042 L
s
1 0 0 r
.73661 .5291 m
.15923 .8082 L
s
0 0 0 r
.18304 .78571 m
.15774 .26455 L
s
.15179 .26587 m
.10268 .3254 L
s
.10268 .32804 m
.05208 .44709 L
s
.05208 .44974 m
.0625 .51058 L
s
1 0 0 r
.10565 .50529 m
.58036 .93254 L
s
0 0 0 r
.57887 .93915 m
.44345 .95503 L
s
.44196 .95503 m
.52679 .95503 L
s
.54167 .96032 m
.7753 .85582 L
s
.77679 .85317 m
.79762 .7619 L
s
.79464 .75926 m
.68155 .85714 L
s
.6756 .85582 m
.29464 .90476 L
s
.29762 .8955 m
.5997 .93651 L
s
.54167 .94048 m
.47321 .95899 L
s
.46429 .95503 m
.06101 .6164 L
s
.0625 .61508 m
.09077 .61905 L
s
.13839 .63624 m
.17411 .59259 L
s
.17262 .60847 m
.08036 .64153 L
s
.07143 .66138 m
.12946 .65608 L
s
.13542 .64815 m
.28125 .15212 L
s
.28125 .1746 m
.16071 .24603 L
s
.16071 .25265 m
.12798 .2791 L
s
.08631 .35582 m
.10119 .38228 L
s
.10565 .39153 m
.04911 .5119 L
s
.0506 .53571 m
.0625 .55556 L
s
.06845 .56349 m
.14435 .55423 L
s
.125 .56746 m
.08631 .57937 L
s
.08185 .58201 m
.09226 .67989 L
s
.08333 .69312 m
.11012 .72619 L
s
.11607 .72619 m
.20833 .84392 L
s
1 0 0 r
.23214 .82407 m
.66369 .92063 L
s
0 0 0 r
.66518 .91799 m
.78571 .74603 L
s
.78125 .75529 m
.6503 .90741 L
s
.67708 .8545 m
.5372 .83995 L
s
.5372 .8373 m
.77827 .83862 L
s
.77976 .84259 m
.74256 .87566 L
s
.7381 .87566 m
.55655 .95238 L
s
.54911 .95635 m
.45833 .95503 L
s
.35565 .92857 m
.38542 .8664 L
s
.38839 .86376 m
.50446 .95635 L
s
.54167 .96164 m
.80804 .76587 L
s
.81101 .76058 m
.83333 .56349 L
s
1 0 0 r
.83482 .56614 m
.54911 .93915 L
s
0 0 0 r
.54167 .93783 m
.4747 .95899 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0023OolI0024Ool007]oo`P0
01Uoo`P007aoo`00MGoo1P00:Goo1P00MWoo001bOol3000eOol3001cOol006eoo`D003]oo`D006io
o`00JWoo0`00AGoo0`00Jgoo001WOol3001;Ool2001YOol006Eoo`80051oo`@006Eoo`00HWoo0`00
EWoo0P00Hgoo001OOol3001KOol3001POol005aoo`<0065oo`<005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Ioo`8006moo`8005Moo`00E7oo0P00Lgoo0P00EGoo001BOol2000a
Ool30005Ool:000dOol2001COol0051oo`8002moo`@0019oo`T0009oo`03001oogoo02Qoo`80055o
o`00Cgoo00<007ooOol0:goo10000Woo0P000Woo00=l07ooOol06Goo00<007ooOol0:Goo00<007oo
Ool0CWoo001=Ool2000ZOol40002Ool40005Ool2O00IOol00`00Oomoo`0ZOol2001>Ool004aoo`03
001oogoo02Ioo`@000=oo`<000]oo`9l01Qoo`03001oogoo009oo`@000Eoo`03001oogoo01eoo`03
001oogoo04]oo`00BWoo0P009Goo10000goo100047oo00=l07ooOol05Woo00<007ooOol01Goo2000
1Goo00<007ooOol05Woo0P00Bgoo0018Ool2000TOol30004Ool3000EOol2O00FOol00`00Oomoo`09
Ool01000Oomoogoo200067oo0P00BGoo0017Ool00`00Oomoo`0POol;000JOol2O00EOol00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`04000FOol20017Ool004Eoo`80029oo`<0009ooa80015o
o`03O01oogoo019oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`8001Uoo`03001o
ogoo04Aoo`00A7oo00<007ooOol087oo0`0000Aoo`000000019oo`d000Eoo`9l01=oo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Eoo`80009oo`8001Aoo`03001oogoo04=oo`00@Woo0P00
8Woo1@008Woo3P003Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo0`0000=oo`00
00000P004Woo0P00@goo0011Ool00`00Oomoo`0QOol200000goo001oo`0[Ool2O004Ool>0007Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool50002Ool20002Ool5000AOol00`00Oomoo`10Ool0041oo`03
001oogoo025oo`@002moo`9l00mooa@000Uoo`04001oogoo0002Ool4000?Ool00`00Oomoo`0oOol0
03moo`03001oogoo021oo`800003Ool007oo039oo`03O01oogoo00ioo`03001oogoo009oo`03001o
o`00014000Ioo`03001oogoo009oo`<000ioo`03001oogoo03ioo`00?Goo0P008Woo1000=Goo0W`0
3Woo00<007oo000010000Woo00<007ooOol03Goo40003Goo0P00?Woo000lOol00`00Oomoo`0POol2
00000goo001oo`0hOol2O008Ool60003Ool01000Oomoo`0067oo00<007ooOol00goo1P0000=l07oo
Ool027oo00<007ooOol0>goo000kOol00`00Oomoo`0POol4000lOol00g`0Oomoo`050005Ool01`00
Oomoogoo001oo`0000Qoo`@00003O01oogoo00]oo`03001oogoo00Eoo`<00003O00007oo00Uoo`03
001oogoo03Yoo`00>Woo00<007ooOol07goo1000?7oo0`000W`02goo00D007oo001oo`0000=oo`H0
00Aoo`03O01oogoo00aoo`03001oogoo00Ioo`03001l07oo008000Uoo`03001oogoo03Uoo`00>7oo
0P0087oo0P0000=oo`000000=goo1P001Goo0W`017oo10000Woo0P0000=oo`0000000P002Woo00=l
07ooOol03Goo00<007ooOol01Woo00Al0000001oo`<000Moo`8003Uoo`00=goo00<007ooOol07goo
00<007oo00000P00<goo1@002goo0P0000Al0000000000Eoo`03O00007oo011oo`03O01oogoo00eo
o`03001oogoo00Eoo`04O01oogoo0003Ool30006Ool00`00Oomoo`0fOol003Ioo`03001oogoo01]o
o`03001oogoo00800003Ool00000031oo`D000Uoo`L000=oo`9l00Ioo`03O01oo`00011oo`03O01o
ogoo00ioo`8000Eoo`04O01oogooOol20004Ool00`00Oomoo`04Ool00`00Oomoo`0eOol003Eoo`03
001oogoo01aoo`03001oo`00009oo`8002]oo`H000Moo`L000aoo`03O01oogoo00=oo`03O01oogoo
011oo`03O01oogoo011oo`03001oogoo009oo`03O01oogoo00=oo`8000=oo`03001oogoo00=oo`03
001oogoo03Eoo`00=7oo00<007ooOol077oo0`000Woo00<007ooOol09Woo1@001goo1P0057oo0W`0
0goo00=l07ooOol047oo00=l07ooOol04Goo00D007ooOomoog`000Moo`05001oogooOol00005Ool0
0`00Oomoo`0dOol003Aoo`03001oogoo01]oo`80009oo`8002Aoo`D000Eoo`L001aoo`9l0003Ooml
07oo019oo`03O01oogoo015oo`04001oogooO008Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`0c
Ool003=oo`03001oogoo01]oo`04001oo`00Ool2000OOol60003Ool7000UOol017`0000000004Goo
00=l07ooOol04Woo00<007ooO0002Woo0P0000=oo`00000017oo00<007ooOol0<Woo000bOol00`00
Oomoo`0JOol20002Ool2000LOol50003Ool6000[Ool01@00Ooml07`0Ool01`002Woo00=l07ooOol0
4goo00<007`0Ool02goo00@007ooOol000Aoo`03001oogoo035oo`00<Goo00<007ooOol06Woo00@0
07ooOomoo`<001Moo`D00003Ool0000000D001ioo`X000Qoo`05001oogooO01oo`02O006Ool70003
Ool00g`0Oomoo`0DOol00g`0Oomoo`0;Ool200000goo001oo`03Ool00`00Oomoo`0`Ool0031oo`03
001oogoo01Uoo`8000Aoo`80019oo``001=ooa8000Moo`03O01oogoo00Moo`05001oogooOoml0003
Ool00g`0Oomoo`0:Ool7000COol00g`0001oo`0=Ool30004Ool00`00Oomoo`0_Ool002moo`03001o
ogoo01Qoo`8000Aoo`<000ioo`/000Iooa<001Uoo`03O01oogoo00Ioo`03001oogoo009oo`03O01o
ogoo009oo`9l00ioo`03O01oogoo00L000aoo`03O01oo`0000moo`8000Aoo`03001oogoo02ioo`00
;Woo00<007ooOol067oo00<007ooOol00Woo10002Woo5P00;7oo00=l07ooOol01Goo00<007ooOol0
0Woo00=l07ooOol01Goo0W`037oo00=l07ooOol01goo1P001Woo00Al07ooOol0011oo`03001oogoo
009oo`03001oogoo02eoo`00;Goo00<007ooOol05goo0P0017oo0P0000=oo`0000000goo2`00?Woo
00=l07ooOol017oo00<007ooOol00goo00=l07ooOol01goo00=l07ooOol02Goo00=l07ooOol03Goo
1P0000El07ooOomoo`00011oo`8000=oo`03001oogoo02aoo`00;7oo00<007ooOol05goo00<007oo
Ool00Woo0`000Woo2000AWoo00=l07ooOol00goo00<007ooOol017oo00=l07ooOol027oo0W`02Goo
00=l07ooOol04goo00=l000000001@003Woo0`000Woo00<007ooOol0:goo000[Ool00`00Oomoo`0F
Ool20003Ool80002Ool00`00Oomoo`18Ool00g`0Oomoo`02Ool00`00Oomoo`05Ool00g`0Oomoo`0:
Ool00g`0Oomoo`07Ool00g`0Oomoo`0BOol00g`0Oomoo`03Ool00`00Ool000060008Ool00`00Ool0
0002Ool00`00Oomoo`0ZOol002Yoo`03001oogoo01Eoo`X0009oo`03001oo`00009oo`03001oogoo
04Qoo`05O01oogooOol00008Ool00g`0Oomoo`0;Ool2O007Ool00g`0Oomoo`0BOol00g`0Oomoo`04
Ool00`00Oomoo`05Ool70002Ool00`00Oomoo`02Ool00`00Oomoo`0YOol002Uoo`03001oogoo01=o
o`P0009oo`80009oo`06001oogoo001oo`00C7oo00=l07oo00002Goo00=l07ooOol03Goo0W`01Goo
00=l07ooOol04Woo00=l07ooOol01Goo00<007ooOol02goo100017oo00<007ooOol0:7oo000YOol0
0`00Oomoo`0BOol30003Ool20002Ool01@00Oomoogoo00000goo0P00CGoo00=l0000Ool02Goo00=l
07ooOol03goo00=l07ooOol00Woo00=l07ooOol04Woo00=l07ooOol01Woo00<007ooOol03Goo0`00
0Woo00<007ooOol0:7oo000XOol00`00Oomoo`0BOol20003Ool20003Ool01@00Oomoogoo00000goo
0P00CWoo00<007ooOol02Goo00=l07ooOol047oo0W`00Woo00=l07ooOol04Woo00=l07ooOol01goo
00<007ooOol037oo00@007ooOol0009oo`03001oogoo02Moo`00:7oo00<007ooOol04Goo0P000goo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0004ioo`03001l07oo00Yoo`03O01oogoo
019oo`9l0003Ooml07oo019oo`03O01oogoo00Qoo`03001oogoo00]oo`05001oogooOol00002Ool0
0`00Oomoo`0VOol002Moo`03001oogoo011oo`<0009oo`8000Aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo04]oo`03001oog`000]oo`03O01oogoo01Aoo`9l01=oo`03O01oogoo00Uoo`03
001oogoo00Yoo`03001oogoo009oo`03001oo`0002Qoo`009Woo00<007ooOol047oo00<007oo0000
0`0017oo0P0017oo00<007ooOol00Woo00<007ooOol0Bgoo00@007ooOoml00]oo`03O01oogoo01Eo
o`9l019oo`03O01oogoo00Yoo`8000Yoo`03001oogoo00=oo`03001oo`0002Moo`009Woo00<007oo
Ool03Woo0P0000Aoo`00000000Eoo`03001oogoo00=oo`03001oogoo009oo`8004]oo`8000=oo`03
O01oogoo00Uoo`03O01oogoo01Eoo`04O01oog`0O00?Ool00g`0Oomoo`0=Ool00`00Oomoo`07Ool2
0005Ool00`00Ool0000VOol002Eoo`03001oogoo00ioo`05001oogooOol00006Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Ool0001:Ool00`00Oomoo`03Ool00g`0Oomoo`09Ool00g`0Oomoo`0F
Ool017`0Oomoog`03Woo00=l07ooOol03Woo00<007ooOol01Goo00<007oo00001Woo0P009Woo000T
Ool00`00Oomoo`0AOol20006Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0004Yoo`03001oogoo
00Aoo`03O01oogoo00Uoo`03O01oogoo01Ioo`04O01oogooOol2O00<Ool00g`0Oomoo`0?Ool00`00
Oomoo`04Ool00`00Ool00006Ool00`00Ool0000UOol002Aoo`03001oogoo00moo`800003Ool007oo
00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`0004Uoo`03001oogoo00Eoo`03O01oogoo
00Uoo`03O01oogoo01Ioo`03O01oogoo00=oo`03O01oogoo00Uoo`03O01oogoo011oo`03001oogoo
00=oo`03001oo`0000Moo`8002Eoo`008goo00<007ooOol03Woo0P000Woo00<007ooOol00Woo0P00
1Woo00<007ooOol00Woo00@007ooOol004Qoo`03001oogoo00Ioo`03O01oogoo00Uoo`03O01oogoo
01Ioo`03O01oogoo00Aoo`9l00Uoo`03O01oogoo015oo`03001oogoo009oo`03001oo`0000Moo`03
001oo`0002Aoo`008Woo00<007ooOol03Woo00D007ooOomoo`0000Aoo`04001oogooOol60003Ool0
1@00Oomoogoo0000Agoo00<007ooOol01goo00=l07ooOol02Goo00=l07ooOol05goo00=l07ooOol0
1Goo0W`01goo00=l07ooOol04Woo00L007ooOomoo`00Ool00008Ool00`00Ool0000SOol0029oo`03
001oogoo011oo`/000=oo`03001oo`00009oo`05001oogooOol00017Ool00`00Oomoo`09Ool00g`0
Oomoo`08Ool00g`0Oomoo`0GOol00g`0Oomoo`07Ool00g`0Oomoo`04Ool00g`0Oomoo`0COol01P00
Oomoo`00Ool000Qoo`03001oo`0002=oo`008Goo00<007ooOol02goo1P0000=oo`00Ool00Woo00<0
07ooOol01Goo00<007oo00000Woo00<007ooOol00Woo00<007ooOol0A7oo00<007ooOol02Woo00=l
07ooOol027oo00=l07ooOol05goo00=l07ooOol027oo0W`017oo00=l07ooOol057oo00<007ooO000
0Woo00<007ooOol01Woo00<007oo00008Woo000QOol00`00Oomoo`0>Ool01000Oomoo`000goo00<0
07ooOol01Woo0P000goo00<007ooOol00Woo00<007ooOol0@goo00<007ooOol02goo00=l07ooOol0
27oo00=l07ooOol05goo00=l07ooOol02Woo0W`00Woo00=l07ooOol05Goo00D007`0Oomoo`0000Qo
o`04001oogoo000QOol0021oo`03001oogoo00eoo`8000=oo`04001oo`000008Ool00`00Ool00002
Ool00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0<Ool00g`0Oomoo`07Ool00g`0Oomoo`0H
Ool00g`0Oomoo`0<Ool00g`0Ooml000GOol01G`0001oogoo00002Goo00<007oo00008Goo000OOol0
0`00Oomoo`0=Ool02000Ool00000Ool007oo0009Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00
Oomoo`12Ool00`00Oomoo`0=Ool00g`0Oomoo`07Ool00g`0Oomoo`0IOol00g`0Oomoo`0<Ool2O00G
Ool017`0Ool007oo0`001goo00@007ooOol0021oo`007goo00<007ooOol037oo00@007oo001oo`@0
00Uoo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo045oo`03001oogoo00ioo`03O01oogoo
00Moo`03O01oogoo01Uoo`03O01oogoo00eoo`=l01Aoo`07O01oogooOol007`0Ool00P001goo00<0
07oo000087oo000NOol00`00Oomoo`0;Ool2000017oo001oogoo0`002Goo00<007oo00000goo00<0
07ooOol00goo00<007ooOol0@Goo00<007ooOol03goo00=l07ooOol01goo00=l07ooOol06Goo00=l
07ooOol03Goo00Al07ooOoml01=oo`06O01oogooOoml00000Woo00<007ooOol01Goo00@007ooOol0
01moo`007Goo00<007ooOol02goo00D007ooOomoo`00009oo`8000Uoo`03001oo`0000=oo`03001o
ogoo00Aoo`03001oogoo041oo`03001oogoo011oo`03O01oogoo00Moo`03O01oogoo01Uoo`03O01o
ogoo00eoo`04O01oogooOol2O00AOol027`0OomoogooO01oo`00Ool20007Ool01000Oomoo`007Woo
000MOol00`00Oomoo`0:Ool01@00Oomoogoo00000Woo0P002Woo00<007oo00000Woo00<007ooOol0
1Goo00<007ooOol0?goo00<007ooOol04Goo00=l07ooOol01goo00=l07ooOol06Woo00=l07ooOol0
37oo00=l07ooOol00goo00=l07ooOol03Goo00El07ooOomoog`000=oo`04001oo`000006Ool01000
Oomoo`007Woo000LOol00`00Oomoo`0>Ool00`00Oomoo`030009Ool00`00Ool00002Ool00`00Oomo
o`06Ool00`00Oomoo`0nOol00`00Oomoo`0BOol00g`0Oomoo`07Ool00g`0Oomoo`0JOol00g`0Oomo
o`0<Ool00g`0Oomoo`04Ool2O00=Ool01G`0OomoogooO00017oo00@007oo000000Eoo`05001oogoo
Ool0000MOol001aoo`03001oogoo00eoo`03001oogoo00800003Ool007oo00Moo`03001oo`00009o
o`03001oogoo00Ioo`03001oogoo03ioo`03001oogoo01=oo`03O01oogoo00Moo`03O01oogoo01Yo
o`03O01oogoo00aoo`03O01oogoo00Ioo`9l00]oo`05O01oogooOoml0005Ool00`00Ool00006Ool0
1000Oomoo`007Goo000KOol00`00Oomoo`0=Ool00`00Oomoo`0300000goo001oo`06Ool00`00Ool0
0003Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0DOol00g`0Oomoo`07Ool00g`0Oomo
o`0JOol00g`0Oomoo`0<Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool01G`0OomoogooO0001goo00<0
07oo00001Goo00D007ooOomoo`0001aoo`006goo00<007ooOol03Goo00<007oo00000P000Woo00<0
07ooOol017oo00<007oo00000goo00<007ooOol01goo00<007ooOol0?7oo00<007ooOol05Goo00=l
07ooOol01goo00=l07ooOol06Woo00=l07ooOol037oo00=l07ooOol02Goo0W`01goo00El07ooOomo
og`000Qoo`<000Eoo`04001oogoo000LOol001]oo`03001oogoo00aoo`<00003Ool00000009oo`03
001oogoo00Aoo`03001oo`00009oo`03001oogoo00Moo`03001oogoo03aoo`03001oogoo01Moo`03
O01oogoo00Ioo`03O01oogoo01]oo`03O01oogoo00]oo`03O01oogoo00]oo`9l00Aoo`03O01oogoo
009oo`03O01oogoo00Qoo`03001oogoo00=oo`04001oogoo000LOol001Yoo`03001oogoo00aoo`80
009oo`8000=oo`03001oogoo00=oo`03001oo`00009oo`03001oogoo00Qoo`03001oogoo03]oo`03
001oogoo01Qoo`03O01oogoo00Ioo`03O01oogoo01]oo`03O01oogoo00]oo`03O01oogoo00eoo`05
O01oogooOoml0003Ool00g`0Oomoo`0:Ool00`00Oomoo`03Ool01000Oomoo`006goo000JOol00`00
Oomoo`0;Ool20002Ool20005Ool01`00Oomoogoo001oo`00009oo`03001oogoo00Uoo`03001oogoo
03Yoo`03001oogoo01Uoo`03O01oogoo00Ioo`03O01oogoo01]oo`03O01oogoo00]oo`03O01oogoo
00ioo`9l0003Ooml07oo009oo`03O01oogoo00]oo`03001oogoo009oo`04001oogoo000KOol001Uo
o`03001oogoo00]oo`8000=oo`8000Eoo`06001oogoo001oo`000goo00<007ooOol027oo00<007oo
Ool0>Woo00<007ooOol06Woo00=l07ooOol01Woo00=l07ooOol06goo00=l07ooOol02goo00=l07oo
Ool047oo0W`00Woo00=l07ooOol037oo0P0017oo00@007ooOol001Yoo`006Goo00<007ooOol02Woo
0P000goo0P001Woo00D007oo001oo`0000=oo`03001oogoo00Uoo`03001oogoo03Uoo`03001oogoo
01]oo`03O01oogoo00Ioo`03O01oogoo01aoo`03O01oogoo00Yoo`03O01oogoo011oo`05O01oog`0
Ooml000?Ool20003Ool01000Oomoo`006Woo000HOol00`00Oomoo`0:Ool20003Ool20007Ool20002
Ool01000Oomoo`0037oo00<007ooOol0>7oo00<007ooOol077oo00=l07ooOol01Woo00=l07ooOol0
77oo00=l07ooOol02Woo00=l07ooOol047oo00=l07ooOol00W`047oo0P000goo00@007ooOol001Uo
o`0067oo00<007ooOol02Goo0P0017oo0P001goo0P0000Eoo`00Oomoo`0000eoo`03001oogoo03Mo
o`03001oogoo01eoo`03O01oogoo00Ioo`03O01oogoo01aoo`03O01oogoo00Yoo`03O01oogoo00mo
o`07O01oogooOoml07ooO00047oo0P000Woo00@007ooOol001Uoo`005goo00<007ooOol02Goo0P00
17oo0P0027oo00<007oo00000Woo00<007ooOol02goo00<007ooOol0=goo00<007ooOol07Woo00=l
07ooOol01Woo00=l07ooOol077oo00=l07ooOol02Woo00=l07ooOol03goo00El07ooOomoog`0009o
o`9l00ioo`<00003Ool007oo009oo`03001oogoo01Ioo`005goo00<007ooOol02Woo00L007ooOomo
o`00Ool00007Ool30003Ool00`00Oomoo`0;Ool00`00Oomoo`0fOol00`00Oomoo`0OOol00g`0Oomo
o`06Ool00g`0Oomoo`0LOol00g`0Oomoo`0:Ool00g`0Oomoo`0>Ool01G`0OomoogooO0001Goo0W`0
3Goo00D007oo001oo`00009oo`03001oogoo01Ioo`005goo00<007ooOol02Woo00@007ooOomoo`80
00Moo`03001oo`0000=oo`03001oogoo00aoo`03001oogoo03Eoo`03001oogoo021oo`03O01oogoo
00Eoo`03O01oogoo01ioo`03O01oogoo00Uoo`03O01oogoo00ioo`05O01oogooOoml0007Ool00g`0
Oomoo`0;Ool01000Ool000000Woo00<007ooOol05Woo000FOol00`00Oomoo`0:Ool01000Oomoogoo
0P001goo00@007ooOol0009oo`03001oogoo00aoo`03001oogoo03Eoo`03001oogoo025oo`03O01o
ogoo00Eoo`03O01oogoo01ioo`03O01oogoo00Uoo`03O01oogoo00ioo`05O01oogooOoml0008Ool2
O00;Ool20002Ool01000Oomoo`005goo000FOol00`00Oomoo`0:Ool01P00Oomoo`00Ool000Moo`06
001oo`00001oo`003goo00<007ooOol0<goo0P0097oo00=l07ooOol01Goo00=l07ooOol07Woo00=l
07ooOol02Goo00=l07ooOol03Goo00El07ooOomoog`000]oo`9l00Uoo`<00005Ool007ooOol0000G
Ool001Ioo`03001oogoo00Uoo`06001oogoo001oo`001goo00@007oo001oo`80011oo`03001oogoo
039oo`03001oogoo02Eoo`03O01oogoo00Aoo`03O01oogoo01ioo`03O01oogoo00Uoo`03O01oogoo
00eoo`05O01oogooOoml000=Ool00g`0Oomoo`07Ool3000017oo001oo`005goo000EOol00`00Oomo
o`0:Ool00`00Oomoo`020007Ool00`00Ool00002Ool2000?Ool00`00Oomoo`0bOol00`00Oomoo`0V
Ool00g`0Oomoo`04Ool00g`0Oomoo`0OOol00g`0Oomoo`08Ool00g`0Oomoo`0=Ool01G`0Oomoogoo
O0003Woo0W`01goo00D007oo001oo`00009oo`03001oogoo01Aoo`005Goo00<007ooOol02Goo00H0
07ooOol007oo0006Ool00`00Ool00003Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol00`00Oomoo`0W
Ool00g`0Oomoo`04Ool00g`0Oomoo`0OOol00g`0Oomoo`08Ool00g`0Oomoo`0<Ool01G`0Oomoogoo
O0004Goo0W`01Woo0`0000Aoo`00Ool001Ioo`0057oo00<007ooOol02Woo00<007oo00000P001Woo
00@007ooOol0009oo`80011oo`03001oogoo031oo`03001oogoo02Qoo`03O01oogoo00Aoo`03O01o
ogoo01moo`03O01oogoo00Qoo`03O01oogoo00aoo`05O01oogooOoml000COol00g`0Oomoo`03Ool0
0`00Ool000020002Ool00`00Oomoo`0COol001Aoo`03001oogoo00Qoo`04001oo`00Ool20006Ool0
1000Oomoo`000Woo00<007oo000047oo00<007ooOol0;goo00<007ooOol0:Goo00=l07ooOol017oo
00=l07ooOol07goo00=l07ooOol027oo00=l07ooOol02goo00El07ooOomoog`001Eoo`9l00Aoo`03
001oo`0000800003Ool007oo01Aoo`0057oo00<007ooOol02Goo00D007oo001oo`0000Ioo`03001o
o`00009oo`04001oogoo000?Ool00`00Oomoo`0_Ool00`00Oomoo`0ZOol00g`0Oomoo`04Ool00g`0
Oomoo`0OOol00g`0Oomoo`08Ool00g`0Oomoo`0;Ool01G`0OomoogooO0005goo00]l07ooOomoo`00
Ool007oo001oo`0001Eoo`0057oo00<007ooOol02Goo0P0000=oo`00Ool01Goo00<007oo00000goo
00@007ooOol000moo`03001oogoo02ioo`03001oogoo02]oo`03O01oogoo00Aoo`03O01oogoo021o
o`03O01oogoo00Moo`03O01oogoo00]oo`05O01oogooOoml000HOol2O002Ool00`00Ool00003000E
Ool001Aoo`03001oogoo00Qoo`05001oo`00Ool00005Ool00`00Ool00003Ool01@00Oomoogoo0000
2Woo00=l07ooOol00Woo00<007ooOol0;Goo00<007ooOol0;7oo00=l07ooOol017oo00=l07ooOol0
87oo00=l07ooOol01goo00=l07ooOol02Woo00El07ooOomoog`001]oo`9l0003001oogoo00@001Ao
o`004goo00<007ooOol02Goo1@0017oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00Mo
o`8000=oo`03001oogoo02eoo`03001oogoo02eoo`03O01oogoo00Aoo`03O01oogoo021oo`03O01o
ogoo00Moo`03O01oogoo00Yoo`05O01oogooOoml000MOol00g`0001oo`04000DOol001=oo`03001o
ogoo00Qoo`800004Ool000000003Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo
0`0000=l07ooOol00Woo00<007ooOol0;7oo00<007ooOol0;Woo00=l07ooOol017oo00=l07ooOol0
87oo00=l07ooOol01goo00=l07ooOol02Woo00El07ooOomoog`001ioo`9l0004Ool00000000DOol0
01=oo`03001oogoo00Qoo`800003Ool0000000=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Ool000030003Ool00g`0Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomoo`0_Ool00g`0Oomoo`04Ool0
0g`0Oomoo`0QOol00g`0Oomoo`06Ool00g`0Oomoo`09Ool01G`0OomoogooO00087oo00H007`0O000
07oo000COol0019oo`03001oogoo00Qoo`800003Ool007oo0080009oo`03001oo`0000=oo`03001o
ogoo00Aoo`<000Moo`05O01oogooOol0000]Ool00`00Oomoo`0`Ool00g`0Oomoo`04Ool00g`0Oomo
o`0QOol00g`0Oomoo`06Ool00g`0Oomoo`09Ool01G`0OomoogooO0008Goo00<007ooO0000P004goo
000BOol00`00Oomoo`08Ool00`00Ool00002Ool01P00Ool00000Ool000=oo`03001oogoo009oo`<0
0003Ool007oo00Moo`05O01oogooOol0000/Ool00`00Oomoo`0aOol00g`0Oomoo`04Ool00g`0Oomo
o`0QOol00g`0Oomoo`06Ool00g`0Oomoo`08Ool01G`0OomoogooO0008Woo00<007oo00000P004goo
000BOol00`00Oomoo`08Ool01@00Ool007oo00000Woo0P0000Eoo`00Oomoo`00009oo`<000Aoo`03
001oogoo00Eoo`03O01oogoo009oo`03001oogoo02Uoo`03001oogoo03=oo`03O01oogoo00=oo`03
O01oogoo025oo`03O01oogoo00Ioo`03O01oogoo00Qoo`05O01oogooOoml000SOol01000Ool00000
4goo000BOol00`00Oomoo`07Ool00`00Ool00002Ool01@00Oomoo`00Ool00P0000=oo`0000000P00
1goo00<007ooOol01Goo00=l07ooOol00Woo00<007ooOol0:7oo00<007ooOol0=7oo00=l07ooOol0
0goo00=l07ooOol08Woo00=l07ooOol01Goo00=l07ooOol027oo00El07ooOomoog`002=oo`03001o
o`000080019oo`004Woo00<007ooOol01Woo0P0000Qoo`00Oomoo`00Ool007oo10002goo00<007oo
Ool01Goo00El07ooOomoo`0002Yoo`03001oogoo03Eoo`03O01oogoo00=oo`03O01oogoo029oo`03
O01oogoo00Eoo`03O01oogoo00Moo`05O01oogooOoml000UOol200000goo001oo`0AOol0015oo`03
001oogoo00Ioo`800003Ool007oo009oo`03001oo`000080009oo`8000Yoo`03001oogoo00Eoo`05
O01oogooOol0000YOol00`00Oomoo`0fOol00g`0Oomoo`02Ool00g`0Oomoo`0SOol00g`0Oomoo`05
Ool00g`0Oomoo`07Ool01G`0OomoogooO0009Goo10004Woo000AOol00`00Oomoo`06Ool30003Ool4
0003Ool01000Oomoo`002Goo00<007ooOol017oo00=l07ooOol00Woo00<007ooOol09Woo00<007oo
Ool0=goo00=l07ooOol00Woo00=l07ooOol08goo00=l07ooOol01Goo00=l07ooOol01goo00Al07oo
Ooml029oo`03001oogoo009oo`@0015oo`004Goo00<007ooOol01Goo0P0000=oo`0000000`0000=o
o`0000000Woo00<007ooOol00Woo0P001goo00<007ooOol017oo00El07ooOomoo`0002Qoo`03001o
ogoo03Qoo`03O01oogoo009oo`03O01oogoo02=oo`03O01oogoo00Eoo`03O01oogoo00Ioo`05O01o
ogooOoml000ROol00`00Oomoo`02Ool01000Ool000004Goo000AOol00`00Oomoo`04Ool40004Ool3
00000g`0Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01G`0Oomoogoo00009goo00<007oo
Ool0>Goo00=l07ooOol00Woo00=l07ooOol097oo00=l07ooOol00goo00=l07ooOol01goo00El07oo
Oomoog`0025oo`03001oogoo00=oo`<0019oo`0047oo00<007ooOol017oo0P0000=oo`00Ool017oo
0P000Woo0W`027oo00<007ooOol00goo00<007ooOol017oo00El07ooOomoo`0002Ioo`03001oogoo
03Yoo`03O01oogoo009oo`03O01oogoo02Aoo`03O01oogoo00=oo`03O01oogoo00Ioo`05O01oogoo
Ooml000ROol00`00Oomoo`03Ool200000goo001oo`0@Ool0011oo`03001oogoo00Aoo`04001oo`00
0004Ool20003Ool00`00Ooml0008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00g`0Oomoo`02Ool0
0`00Oomoo`0SOol00`00Oomoo`0kOol00g`0Oomoo`02Ool00g`0Oomoo`0TOol00g`0Oomoo`03Ool0
0g`0Oomoo`06Ool01G`0OomoogooO0008Woo00<007ooOol00Woo0P0000=oo`0000004Goo000@Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool20002Ool01000Oomoogoo0W`01goo0P000Woo00<007ooOol0
0goo00El07ooOomoo`0002Eoo`03001oogoo03aoo`03O01oogoo009oo`03O01oogoo02Aoo`03O01o
ogoo00=oo`03O01oogoo00Ioo`05O01oogooOoml000EOol00`00Oomoo`09Ool00`00Oomoo`02Ool3
0002Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Eoo`8000Eoo`04001oogoo0006Ool2O007Ool0
0`00Ool00005Ool01G`0Oomoogoo000097oo00<007ooOol0?Goo00=l07ooOol00Woo00=l07ooOol0
9Goo00=l07ooOol00Woo00=l07ooOol01Goo00El07ooOomoog`001Ioo`03001oogoo00Uoo`03001o
ogoo009oo`800004Ool007oo000AOol0011oo`03001oogoo00Eoo`03001oogoo00=oo`800003Ool0
07oo00Qoo`03O01oogoo00Eoo`8000Eoo`05O01oogooOol0000SOol00`00Oomoo`0nOol00g`0Oomo
o`02Ool00g`0Oomoo`0UOol00g`0Oomoo`02Ool00g`0Oomoo`05Ool01G`0OomoogooO0005Woo00<0
07ooOol02Goo00<007ooOol00Woo0P0000Aoo`000000015oo`003goo00<007ooOol01Goo00<007oo
Ool017oo0P0000=oo`00Ool02Goo0W`01Woo0P000goo00El07ooOomoo`0002=oo`03001oogoo03mo
o`03O01oogoo009oo`03O01oogoo02Eoo`03O01oogoo009oo`03O01oogoo00Eoo`04O01oogooO00F
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool200001Goo000007oo000047oo000?Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Ool0000=Ool00g`0Oomoo`03Ool00`00Ool00002Ool01G`0Oomoogoo
00008Woo00<007ooOol0@Goo00El07ooOomoog`002Moo`03O01oogoo009oo`03O01oogoo00Aoo`05
O01oogooOoml000FOol00`00Oomoo`09Ool00`00Oomoo`02Ool20002Ool01000Oomoo`0047oo000?
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool2000?Ool2O003Ool01P00Oomoo`00Ooml00=oo`03001o
ogoo01moo`03001oogoo00Ioo`T003=oo`05O01oogooOoml000WOol00g`0Oomoo`02Ool00g`0Oomo
o`04Ool01G`0OomoogooO0005Woo00<007ooOol02Goo00<007ooOol00Woo0P000Woo00@007ooOol0
011oo`003goo00<007ooOol017oo00<007ooOol017oo0P004Woo00Al07ooOol000=oo`05001l07oo
Ool0000JOolA0004Ool3000eOol01G`0OomoogooO000:7oo00El07ooOomoog`000Eoo`05O01oogoo
Ooml000GOol00`00Oomoo`09Ool02000Oomoogoo001oo`00Ool20002Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo019oo`9l0005001oogooOoml000200000goo
001oo`08OolA0005Ool00`00Oomoo`0:Ool3000hOol01G`0OomoogooO000:7oo00El07ooOomoog`0
00Eoo`05O01oogooOoml000GOol00`00Oomoo`08Ool00`00Oomoo`02Ool01000Ool007oo0P000Woo
00<007ooOol03Woo000?Ool00`00Oomoo`04Ool00`00Oomoo`03Ool2000FOol00g`00000000?000E
Ool00`00Oomoo`07Ool4000kOol01G`0OomoogooO000:7oo00El07ooOomoog`000Eoo`04O01oogoo
O00HOol00`00Oomoo`08Ool00`00Oomoo`02Ool01P00Ool00000Ool0009oo`03001oogoo00ioo`00
3goo00<007ooOol017oo00<007ooOol00goo0P001goo4@0000=l07ooO0000goo00<007ooOol06goo
00<007ooOol01Goo0`00?goo00El07ooOomoog`002Qoo`05O01oogooOoml0004Ool01G`0Oomoogoo
O0005goo00<007ooOol02Goo00/007ooOomoo`00Ool007oo001oo`00009oo`03001oogoo00ioo`00
3goo00<007ooOol017oo0P000goo2P0047oo00@007ooO01l009oo`03001oo`0001]oo`03001oogoo
00=oo`<0049oo`05O01oogooOoml000YOol017`0Oomoog`017oo00El07ooOomoog`001Moo`03001o
ogoo00Qoo`03001oogoo009oo`03001oo`0000800005Ool007ooOol0000@Ool000moo`03001oogoo
00Aoo`80009oo`<001Qoo`07001oog`0Ooml07oo00000Woo0P0067oo00@007ooOomoo`<004Eoo`05
O01oogooOoml000YOol017`0Oomoog`017oo00Al07ooOoml01Qoo`03001oogoo00Qoo`05001oogoo
Ool00002Ool30002Ool00`00Ool0000@Ool000moo`03001oogoo00Aoo`800005Ool00000Ool0000H
Ool00`00Ooml0002Ool00g`0001oo`03Ool00`00Oomoo`0DOol00`00Ool000020018Ool01G`0Oomo
ogooO000:Goo00Al07ooOoml00=oo`05O01oogooOoml000HOol00`00Oomoo`08Ool01@00Oomoogoo
00000Woo00<007oo00000Woo00<007oo000047oo000?Ool00`00Oomoo`04Ool2000017oo00000000
6Goo00<007ooO0000Woo00<007ooO00017oo00<007ooOol04Woo0`00Bgoo00El07ooOomoog`002Uo
o`04O01oogooO003Ool01G`0OomoogooO00067oo00<007ooOol01goo00<007ooOol00Woo00H007oo
Ool007oo0002Ool00`00Ool0000@Ool000ioo`03001oogoo00Eoo`H001Uoo`03001oog`0009oo`03
001oogoo009l00=oo`03001oogoo00ioo`<004ioo`04O01oogooO00ZOol017`0Oomoog`00Woo00El
07ooOomoog`001Qoo`03001oogoo00Qoo`05001oogooOol00002Ool200001Goo001oogoo00000Woo
00<007ooOol03Goo000>Ool00`00Oomoo`05Ool400000goo001oo`0HOol00`00O01oo`02Ool00`00
Oomoo`02Ool017`0Oomoogoo0P002Woo100000=oo`00Ool0CWoo00Al07ooOoml02]oo`03O01oog`0
009oo`05O01oogooOoml000HOol00`00Oomoo`08Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo000?Ool000ioo`03001oogoo00Eoo`06001oo`00001oo`006Goo00D007`0Oomoo`00
00Ioo`9l00=oo`03001oogoo00Aoo`<000Aoo`03001oogoo04moo`03O01oog`002]oo`03O01oog`0
009oo`04O01oogooO00IOol00`00Oomoo`07Ool01@00Oomoogoo00000Woo0P000Woo00@007ooOol0
009oo`03001oogoo00eoo`003Woo00<007ooOol01Goo0`0000=oo`00Ool06Goo00D007`0Oomoo`00
00Qoo`05O01oogooOol00002Ool30006Ool00`00Oomoo`1@Ool00g`0Ooml000[Ool01G`0Ooml07oo
O0000goo00=l07ooOol05goo00<007ooOol01goo00D007ooOomoo`00009oo`80009oo`04001oogoo
0002Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Ioo`800003Ool007oo01Uoo`05001l07ooOol0
0009Ool2O00017oo0000000027oo00<007ooOol0DGoo00=l07ooO000:goo00El07ooO01oog`000=o
o`03O01oogoo01Moo`03001oogoo00Moo`09001oogooOol007oo001oo`00009oo`04001oogoo0002
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Eoo`<00003Ool007oo01Uoo`05001oogooOol00009
Ool20002O0000goo00000006Ool00`00Oomoo`1BOol00g`0Ooml000/Ool2O0001GooO01oogooO000
6Goo00<007ooOol027oo00@007ooOol0009oo`03001oo`00009oo`04001oogoo0002Ool00`00Oomo
o`0=Ool000ioo`03001oogoo00Aoo`03001oo`00008001]oo`04001oogoo0007Ool30004Ool017`0
Oomoo`0017oo00<007ooOol0Dgoo00=l07ooO000;7oo0g`00goo00=l07ooOol05goo00<007ooOol0
1goo00T007ooOomoo`00Ool007oo00000goo00@007ooOol0009oo`03001oogoo00eoo`003Woo00<0
07ooOol017oo0P0000=oo`0000006goo00@007ooOol000Aoo`<000Qoo`9l0005Ool007ooOol0001F
Ool00g`0Ooml000/Ool3O003Ool00g`0Oomoo`0GOol00`00Oomoo`07Ool01000Oomoo`000Woo00<0
07oo00000goo00L007ooOomoo`00Ool0000?Ool000ioo`03001oogoo00=oo`03001oo`00009oo`03
001oogoo00Qoo`03O01oogoo00ioo`03001oogoo00D000eoo`04O01oo`00001GOol00g`0Ooml000/
Ool2O003Ool00g`0Oomoo`0HOol00`00Oomoo`07Ool01P00Oomoo`00Ool0009oo`05001oogooOol0
0003Ool00`00Ool0000?Ool000ioo`03001oogoo00Aoo`05001oogooOol0000;Ool00g`0Oomoo`0<
Ool00g`000000002000BOol2O002001FOol00g`0Ooml000/Ool2O003Ool00g`0Oomoo`0HOol00`00
Oomoo`06Ool01`00Oomoogoo001oo`00009oo`05001oogooOol00003Ool00`00Ool0000?Ool000io
o`03001oogoo00Aoo`03001oogoo008000aoo`03O01oogoo00Yoo`<00003Ool007oo019oo`05001o
og`0Ool0001EOol00g`0Ooml000]Ool017`0Oomoog`06goo00<007ooOol01Woo00H007ooOol007oo
0003Ool01@00Oomoogoo00000goo00<007oo00003goo000>Ool00`00Oomoo`07Ool00`00Oomoo`0<
Ool00g`0Oomoo`06Ool300001GooO00007oo00004Woo00@007ooOomoo`9l0003001oogoo059oo`03
O01oog`002aoo`9l009oo`03O01oogoo01Qoo`03001oogoo00Moo`06001oogoo001oo`000Woo00<0
07ooOol00Woo00L007ooOomoo`00Ool0000?Ool000ioo`03001oogoo00Moo`03001oogoo00eoo`9l
00=oo`<000Aoo`03O0000000019oo`03001oogoo00Aoo`03O0000000059oo`03O01oog`002aoo`9l
009oo`03O01oogoo01Qoo`03001oogoo00Ioo`06001oogoo001oo`000goo00@007ooOomoo`8000=o
o`03001oo`0000moo`003Woo00<007ooOol01Woo0P004Goo00=l000000001Woo00Al07oo0000015o
o`03001oogoo00Ioo`9l0003001oogoo04moo`03O01oog`002aoo`9l0003Ooml07oo01Yoo`03001o
ogoo00Ioo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00eo
o`003goo00<007ooOol01Goo0P003Woo0`0000=oog`0Ool01Woo00Al07ooOol0011oo`03001oogoo
00Uoo`9l051oo`03O01oog`002]oo`03O01oog`0009l01]oo`03001oogoo00Ioo`03001oogoo0080
00Aoo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00eoo`003goo00<007ooOol01Goo0P00
2Woo10001Goo00=l07ooOol017oo00Al07ooOol000moo`03001oogoo00aoo`03O01oogoo04ioo`9l
02Ioo`9l0005001oogooO01oo`02O00LOol00`00Oomoo`05Ool01P00Oomoo`00Ool000Aoo`8000Ao
o`05001oogooOol0000@Ool000moo`03001oogoo00Aoo`<000Moo`<000Yoo`03O01oogoo00=oo`04
O01oo`00000>Ool00`00Oomoo`0>Ool2O01>Ool2O00TOol2O002Ool00`00Ooml0002Ool2O00KOol0
0`00Oomoo`06Ool00`00Oomoo`020004Ool20005Ool00`00Oomoo`02000@Ool000moo`03001oogoo
00=oo`D000=oo`<000ioo`05O01oogooOoml0002Ool2000=Ool00`00Oomoo`0AOol00g`0Oomoo`1;
Ool2O00ROol2O005Ool01000O01oogoo0W`06goo00<007ooOol01Woo00D007oo001oo`0000Aoo`03
001oogoo00Aoo`05001oo`00O000000@Ool000moo`03001oogoo00=oo`D00003Ool00000019oo`04
O01oogooO002Ool2000<Ool00`00Oomoo`0COol2O01;Ool2O00POol2O007Ool01000O01oogoo0W`0
6goo00<007ooOol01Goo00<007ooOol00P001Goo00<007ooOol017oo00D007ooO01oo`00011oo`00
3goo00<007ooOol017oo00@007oo000001Ioo`07O01oog`0Ool007oo00002goo00<007ooOol05Goo
00<007`0Ool0BGoo00=l07ooOol07Goo0W`02Goo00L007ooOomoog`0Ooml000JOol00`00Oomoo`05
Ool00`00Oomoo`020004Ool20006Ool01@00O01oogoo000047oo000?Ool00`00Oomoo`04Ool01000
Ool0000017oo00=l07ooOol047oo0W`000Aoo`00Ool000Yoo`03001oogoo01Moo`03001l07`004Qo
o`03O01oogoo01]oo`9l00]oo`07O00007ooOoml07ooO0006Woo00<007ooOol01Goo00@007oo0000
00Aoo`03001oo`0000Ioo`80009oo`03001oogoo00ioo`003goo00<007ooOol00goo00D007oo001o
o`0000Eoo`03O01oogoo00Yoo`@00007Ooml07`0O00007oo00002Goo00<007ooOol06Woo00<007`0
Ool0AWoo00=l07ooOol06Goo0W`03Goo00=l0000Ool00W`000=oog`0Ool017oo00=l07ooOol04Goo
00<007ooOol01Woo00@007oo000000=oo`04001oogoo0005Ool00g`0001oo`02Ool00`00Oomoo`0>
Ool000moo`03001oogoo00=oo`04001oo`00Ool20005Ool00g`0Oomoo`02Ool70005Ool01W`0Ool0
07`0Ool000Moo`8001ioo`03001l07`004Eoo`03O01oogoo01Moo`9l00ioo`04O01oo`00Ool2O000
0gooO01oo`04Ool00g`0001oo`0AOol00`00Oomoo`05Ool01000Ool000000goo00@007ooOol000Eo
o`03O01oo`0000=oo`03001oogoo00ioo`003goo00<007ooOol00goo00<007ooOol00`000goo1`00
37oo00Il07oo001oog`00006Ool00`00Oomoo`0OOol01000Ooml07`0@goo00=l07ooOol05Goo0W`0
47oo00Il07ooOol007ooO002Ool01g`0OomoogooO01oo`00019oo`03001oogoo00Eoo`04001oo`00
0002Ool01@00Oomoogoo000017oo00Al07oo000000=oo`03001oogoo00ioo`003goo00<007ooOol0
0goo00D007ooOol007oo00@000Aoo`03O01oogoo00aoo`03O01oo`00009oo`03O01oogoo00=oo`03
001oogoo025oo`800003Ooml07oo045oo`03O01oogoo01=oo`9l015oo`07O01oogooOol007ooO000
0Woo00El07ooOomoog`0009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
o`00009oo`03001oogoo009oo`05001oogooOoml0002Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool0
011oo`05001oogooOol00004Ool40006Ool00g`0Oomoo`03Ool20005Ool017`0Oomoo`000Woo00<0
07`0Ool00Woo00<007ooOol097oo00@007ooO01l041oo`03O01oogoo015oo`9l01=oo`07O01oogoo
Ool007ooO0000Woo00Al07ooOoml00=oo`03001oogoo00Moo`03001l07oo00Eoo`03001oogoo00Ao
o`06001oo`00001oo`001Goo00@007ooOoml009oo`8000Aoo`03001oogoo00ioo`0047oo00L007oo
Oomoo`00Ool00002Ool300000goo001oo`05Ool00g`0000000020007Ool00g`0Ool00003Ool01@00
Ooml07oo0000:7oo00@007ooOoml03moo`03O01oogoo00moo`9l01Eoo`07O01oogooO01oo`00O000
0Woo00Al07ooOoml00Aoo`03001oogoo00Ioo`03O01oogoo00Eoo`03001oogoo00Aoo`05001oo`00
Ool00006Ool00`00Ooml0003Ool20003Ool00`00Oomoo`0?Ool0011oo`03001oogoo00=oo`04001o
ogooOol20002Ool200000goo0000000200000g`0Oomoo`08Ool00g`0Ool00003Ool01000Oomoog`0
:Woo00<007ooOol00W`0?Goo0W`03Goo0g`05Woo00Ql07ooOomoog`0Ool007`00goo0W`01Goo00<0
07ooOol01Goo00=l0000Ool01Goo00<007ooOol01Goo10001Woo00<007ooO0000goo0P0017oo00<0
07ooOol03goo000@Ool00`00Oomoo`02Ool00`00Ool00002Ool30002Ool20005Ool00g`0Oomoo`07
Ool00g`0Ool00003Ool01@00Ool007ooO000:Woo0P000Woo00=l07ooOol0>Woo0W`02goo0W`06Goo
00Al07ooOoml009oo`03001l07oo009oo`9l00Ioo`03001oogoo00Aoo`03O00007oo00Eoo`03001o
ogoo00Aoo`04001oo`000007Ool00`00O01oo`03Ool20004Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo009oo`03001oo`0000=oo`@000Qoo`03O01oogoo00Eoo`03O01oo`0000Aoo`8000=oo`03O01o
ogoo02Uoo`03001oogoo009l03Yoo`9l00Uoo`9l01]oo`04O01oogooO003Ool01@00OomoogooO000
1goo00<007ooOol00goo00=l0000Ool01Woo00<007ooOol017oo00<007oo000027oo00<007ooOol0
0Woo00<007oo000017oo00<007ooOol03goo000AOol00`00Oomoo`02Ool00`00Ool00002Ool20000
17oo000000001goo00=l07ooOol017oo00=l07oo000017oo00<007ooOol00goo0W`0:Woo00D007oo
Oomoog`003Uoo`9l00Moo`9l01aoo`05O01oogooOoml0003Ool01@00OomoogooO00027oo00L007oo
Oomoog`0Ool00007Ool00`00Oomoo`04Ool20008Ool00g`0001oo`02Ool00`00Ool00005Ool00`00
Oomoo`0?Ool0015oo`03001oogoo009oo`03001oo`00009oo`800004Ool007ooOol20006Ool00g`0
Oomoo`03Ool00g`0Ool00003Ool20007Ool00g`0Oomoo`0XOol20002Ool2O00gOol2O005Ool2O00N
Ool017`0Oomoog`017oo00<007ooOol00W`027oo00@007ooOoml009oo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oo`0000Moo`03O01oo`0000=oo`03001oo`0000Aoo`03001oogoo011oo`004Goo
00<007ooOol00Woo00<007oo00000Woo100017oo0P001Goo00=l07ooOol00Woo00=l0000Ool00Woo
00@007oo000000Moo`03O01oogoo02Uoo`04001oogooOol2O00eOol2O003Ool2O00OOol01G`0Oomo
ogooO00017oo00H007ooOoml07ooO008Ool00`00Ooml0002Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool20007Ool00g`0Ool00003Ool01000Oomoo`0017oo00<007ooOol047oo000AOol00`00Oomoo`03
Ool01P00Ool007oo001oo`8000Ioo`03001oogoo00=oo`06O01oogooO01oo`000Woo00@007ooOol0
00Uoo`03O01oogoo02Uoo`03001oogoo009oo`03O01oogoo039oo`9l0003Ooml07`0025oo`05O01o
ogooOoml0003Ool017`0Ool007`00Woo00=l07ooOol01Woo00<007`0Ool00Woo00<007ooOol017oo
00<007ooOol017oo0P001Woo00Al07ooOol000=oo`04001oo`00O004Ool00`00Oomoo`0@Ool0015o
o`03001oogoo00=oo`09001oo`00Ool007oo001oo`0000aoo`07O01oog`0Ool007oo00000Woo00<0
07oo00002Goo00=l07ooOol0:Goo00<007ooOol00Woo0W`0<Woo0g`08goo00Al07ooOoml00Aoo`04
O01oo`00O002Ool00g`0Oomoo`06Ool00g`0001oo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Ool00005Ool01G`0Oomoogoo00000Woo00<007ooOol00P0017oo00<007ooOol047oo000BOol0
0`00Oomoo`02Ool00`00Oomoo`02000017oo000000001goo0`000goo0W`000=oo`0000000Woo00@0
07ooOol000Yoo`03O01oogoo02Uoo`8000Aoo`03O01oogoo02ioo`=l02=oo`05O01oogooOoml0004
Ool017`0Ool007`00Woo00=l07ooOol01Goo00=l07oo00000goo00<007ooOol017oo00<007ooOol0
0Woo0`001Goo00=l07ooOol00Woo00H007ooOol007ooO0020003Ool00`00Oomoo`0AOol0019oo`03
001oogoo009oo`07001oogoo001oo`00Ool00P002Woo100000=l000000000Woo00<007ooOol00P00
2goo00=l07ooOol0:Woo00<007ooOol00Woo0W`0;7oo0W`000=oog`0O0008goo00Al07ooOoml00Eo
o`04O01oog`00003Ool00g`0Oomoo`03Ool01G`0Oomoogoo00000Woo00<007ooOol017oo00H007oo
Oomoo`00Ool20004Ool00g`0Oomoo`03Ool02000Ool007ooO00007oo0003Ool00`00Oomoo`0AOol0
019oo`03001oogoo00=oo`06001oo`00Ool007oo0P003Goo00El0000000007oo00@00003Ool007oo
00]oo`03O01oogoo02Yoo`03001oogoo00=oo`03O01oogoo02Moo`9l00=oo`9l02=oo`04O01oogoo
O005Ool017`0Ooml00000goo00=l07ooOol00goo00El07ooOomoo`00009oo`03001oogoo00=oo`05
001oogooOol00002Ool00`00Oomoo`02Ool00g`0Oomoo`03Ool01P00Oomoo`00O01oo`8000Aoo`03
001oogoo015oo`004Woo00<007ooOol00goo1@0000=oo`0000003Goo00Al07oo001l008000Aoo`03
001oogoo00]oo`03O01oogoo02Yoo`03001oogoo00=oo`9l02Eoo`9l00Aoo`03O01oog`0029oo`05
O01oogooOoml0005Ool2O0000goo001oo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool20006Ool0
1000Oomoo`000Woo0P000goo00=l07ooOol017oo00@007oo001l009oo`8000Aoo`03001oogoo015o
o`004goo00<007ooOol00Woo0P0000=oo`0000001@002goo00=l000000000P0000=l07ooOol00Woo
00<007ooOol037oo0W`0:goo0P001Goo00=l07ooOol087oo0W`01Woo00=l07ooO0008Woo00Al07oo
Ooml00Ioo`9l009oo`04001oogooO003Ool00g`0Oomoo`04Ool20006Ool00`00Ool00003Ool20002
Ool00g`0Oomoo`05Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0AOol001=oo`03001o
ogoo00=oo`800004Ool007ooOol200000goo001oo`07Ool400001Goo001oogooO0000goo00<007oo
Ool03Woo00=l07ooOol0:Woo00<007ooOol00goo0W`07Goo0g`027oo00Al07ooOoml021oo`05O01o
ogooOoml0006Ool01G`0Oomoogoo00000Woo00Al07ooOoml00Qoo`03001oogoo00Aoo`8000Aoo`04
001oogooO008Ool20003Ool00`00Ool00003Ool00`00Oomoo`0BOol001=oo`03001oogoo00=oo`04
001oo`000002Ool01@00Ool007oo000017oo100000Al07oo000000Aoo`04O01oogoo000AOol00g`0
Oomoo`0ZOol00`00Oomoo`04Ool2O00IOol2O00;Ool017`0Oomoog`087oo00El07ooOomoog`000Io
o`05O01oogooOol00003Ool00g`0Ooml0008Ool00`00Oomoo`04Ool00`00Oomoo`02Ool200000goo
O01oo`08Ool20003Ool00`00Ool00003Ool00`00Oomoo`0BOol001Aoo`03001oogoo009oo`05001o
ogooOol00002Ool20002Ool40004Ool00g`000000006Ool00g`0Ool0000BOol00g`0Oomoo`0ZOol0
0`00Oomoo`05Ool00g`0Oomoo`0DOol2O00=Ool017`0Oomoog`04goo00<007ooOol02Woo00Al07oo
Ooml00Ioo`9l00Aoo`03001oogoo009l00Uoo`8000Aoo`8000Aoo`03001oog`000Uoo`03O00007oo
00=oo`03001oo`0000=oo`03001oogoo019oo`0057oo00<007ooOol00goo00<007ooOol00P0000Ao
o`00Oomoo`<000Moo`03001oo`00008000Aoo`03O00007oo019oo`03O01oogoo02Yoo`8000Ioo`9l
019oo`9l00moo`04O01oogooO00DOol00`00Oomoo`08Ool01G`0OomoogooO0001Woo0W`017oo00@0
07ooOoml00Yoo`8000=oo`8000Aoo`800003O01oogoo00Moo`03O00007oo00=oo`03001oo`0000=o
o`03001oogoo01=oo`0057oo00<007ooOol00goo00D007ooOol007oo00@000=oo`03001oogoo00Ao
o`03001oogoo009oo`8000=oo`03001oogoo019oo`03O01oogoo02]oo`03001oogoo00Eoo`03O01o
ogoo00eoo`9l015oo`04O01oogooO00EOol00`00Oomoo`07Ool017`0Oomoog`01Woo00=l07ooO000
17oo00@007ooO01l00Yoo`03001oo`00009oo`8000Aoo`03001l07oo00Qoo`03O01oo`0000Aoo`03
001oo`0000=oo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol010001Woo00<007oo
Ool00goo00<007ooOol017oo100000=l07ooOol04Woo00=l07ooOol0:goo00<007ooOol01Goo0W`0
2goo0W`04goo00Al07ooOoml015oo`03O01oogoo009oo`03001oogoo00Ioo`04O01oogooO006Ool0
0g`0Ooml0005Ool017`0Oomoog`02Goo00L007oo001oo`00Ool00003Ool20009Ool017`0Ool00000
17oo00<007oo00000goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`02000017oo
000000001Goo00D007ooOomoo`0000Yoo`800003O01oogoo019oo`03O01oogoo02]oo`03001oogoo
00Ioo`03O01oogoo00Ioo`9l01Eoo`04O01oogooO00BOol00g`0Oomoo`02Ool00`00Oomoo`04Ool0
1G`0OomoogooO0001Goo00Al07ooOoml00Eoo`04O01oogooO009Ool01000Ool000000Woo00H007oo
Oomoog`00008Ool00g`0Oomoo`020003Ool01000Oomoo`000goo00<007ooOol04goo000EOol00`00
Oomoo`03Ool01000Ool007oo0`0000=oo`00Ool017oo00@007ooOol000Yoo`05001oogooO000000C
Ool00g`0Oomoo`0[Ool20007Ool2O004Ool2O00GOol017`0Oomoog`04goo00=l07ooOol00Woo00<0
07ooOol00goo00Al07ooOoml00Ioo`04O01oogooO004Ool01G`0001oogooO00027oo00@007ooOol0
00=oo`05001oogooO0000008Ool01W`0Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`0D
Ool001Eoo`03001oogoo00=oo`03001oogoo00@0009oo`03001oogoo00=oo`03001oogoo00Yoo`05
001oogooOoml0003000AOol2O00]Ool00`00Oomoo`06Ool017`0Ooml07`06Goo00Al07ooOoml01Ao
o`03O01oogoo009oo`05001oogooOoml0003Ool00g`0Oomoo`04Ool017`0Oomoog`00goo00Il07oo
Ool007ooO008Ool01000Ool000000Woo00@007ooOoml008000Moo`04O01oogooOol20004Ool01000
Oomoo`000Woo00<007ooOol057oo000FOol00`00Oomoo`02Ool00`00Oomoo`0300000goo00000008
000;Ool00`00Oomoo`02Ool00g`0Oomoo`02000AOol00g`0Oomoo`0[Ool00`00Oomoo`05Ool3O00J
Ool017`0Oomoog`057oo00=l07ooOol00goo00@007ooOoml009oo`03O01oogoo00Aoo`05O01oogoo
Ooml0002Ool01g`0Oomoogoo001oog`000Qoo`<000=oo`06001oog`0001oo`001Woo00Ml07ooOomo
o`00Ool00003Ool01000Oomoo`000Woo00<007ooOol05Goo000FOol00`00Oomoo`02Ool80003Ool0
0`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool017`0Oomoogoo0P000W`03Woo00=l07oo
Ool0:goo00<007ooOol00Woo0W`00goo0W`067oo00Al07ooOoml01Eoo`03O01oogoo00=oo`03001o
og`0009oo`03O01oogoo00Aoo`05O01oogooOoml0002Ool01G`0Oomoogoo00000Woo00=l07ooOol0
1Goo00<007oo00000goo00<007`0Ool00P001Woo00=l07ooOol00Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo01Eoo`005Woo00<007ooOol00goo00@007oo001oo`<000Aoo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Aoo`03O01oogoo00Aoo`9l00eoo`03O01oogoo02]oo`80
009l00Moo`03O01oogoo01Eoo`04O01oogooO00FOol00g`0Oomoo`03Ool01G`0OomoogooO0001Goo
00=l07ooOol00Woo00=l07ooO0001Goo00<007ooO0001Woo0P0000=oo`00Ool00Woo00El07oo001o
o`0000Eoo`03O01oogoo009oo`04001oogoo0003Ool01000Oomoo`000Woo00<007ooOol05Goo000F
Ool00`00Oomoo`08Ool20005Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00g`0Oomoo`05
Ool3O00;Ool00g`0Oomoo`0YOol3O0000`00Oomoo`07Ool2O00EOol01G`0OomoogooO0005Woo00=l
07ooOol00Woo00Al0000Ooml00Ioo`03O01oogoo009oo`9l00Ioo`03001oog`000Eoo`05001oo`00
Ool00002Ool00g`0001oo`030004Ool00g`0Oomoo`03Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol05Goo000GOol00`00Oomoo`04Ool01P00Oomoo`00Ool000Ioo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo00Ioo`03O01oogoo00Moo`9l00Yoo`03O01oogoo02Ioo`9l00Aoo`03
001oogoo00Qoo`03O01oogoo019oo`05O01oogooOoml000GOol027`0OomoogooO01oo`00O005Ool0
0g`0Oomoo`03Ool00g`0Oomoo`05Ool00`00Ooml0004Ool03000Oomoo`00Ool007ooO00007oo001o
o`8000=oo`03O01oogoo00=oo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0FOol001Mo
o`03001oogoo00Eoo`05001oo`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00g`0Oomoo`08Ool3O008Ool00g`0Oomoo`0SOol2O007Ool20009Ool2O00BOol01G`0Oomo
ogooO00067oo00=l07ooO0000goo00<007ooOol00goo00=l07ooOol00Woo0W`027oo00<007ooO000
0Woo00@007ooOomoo`800008Ooml07oo001oo`00Ool000=oo`03O01oogoo00Aoo`04001oogoo0003
Ool20004Ool00`00Oomoo`0FOol001Moo`03001oogoo00Ioo`@000Qoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo00Moo`03O01oogoo00Yoo`9l00Moo`03O01oogoo021oo`9l00]oo`03001o
ogoo00Qoo`03O01oogoo00moo`05O01oogooOoml000IOol2O002Ool00g`0Ool00003Ool00g`0Oomo
o`03Ool2O008Ool01@00Ooml07oo00000goo00@007oo001l009oo`800003Ool00000009oo`03O01o
ogoo00Aoo`05001oogooOol00002Ool00`00Ool00004Ool00`00Oomoo`0FOol001Qoo`03001oogoo
00Ioo`800003Ool007oo00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qoo`03O01o
ogoo00]oo`=l00Eoo`03O01oogoo01eoo`9l00ioo`03001oogoo00Qoo`9l00moo`05O01oogooOoml
000IOol01G`0OomoogooO0000Woo00@007ooOoml00Aoo`03O01oog`000Qoo`04001oog`00004Ool0
0`00Ooml0003Ool200000goo00000002O007Ool01@00Oomoogoo00000Woo0P0017oo00<007ooOol0
5goo000HOol00`00Oomoo`07Ool30009Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00g`0
Oomoo`0=Ool3O003Ool2O00KOol2O00AOol00`00Oomoo`09Ool00g`0Oomoo`0<Ool01G`0Oomoogoo
O0006Goo0W`000=oog`0Ool00goo00<007`0Ool00goo00Al07ooOoml00Uoo`03001l000000Aoo`03
001l000000=oo`05001oo`00001l0008Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0
5goo000IOol00`00Oomoo`07Ool2000;Ool01000Oomoo`0017oo00<007ooOol02Woo00=l07ooOol0
3goo0W`00goo00=l07ooOol05Woo0W`057oo0P002Woo0W`02goo00=l07ooOol00Woo00=l07ooOol0
5goo00Al07ooO01l00Eoo`05001oogooOoml0003Ool00g`0Oomoo`07Ool20005Ool00`00Ool00003
Ool01000Ool0000027oo00<007ooOol00Woo00@007oo000000Eoo`03001oogoo01Qoo`006Goo00<0
07ooOol00Woo00<007ooOol00Woo00<007oo00002goo00@007ooOol000=oo`03001oogoo00]oo`03
O01oogoo011oo`=l0003Ooml07oo01Aoo`9l01Qoo`03001oogoo00Uoo`9l00Uoo`03O01oogoo009o
o`03O01oogoo01Ioo`05O01oogooOoml0004Ool01G`0001oogooO00017oo00=l07ooOol01goo00<0
07ooO0000goo00=l000000000goo00<007ooOol00P0027oo00<007ooOol00Woo0P0000=oo`00Ool0
17oo00<007ooOol067oo000JOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000<Ool01000Oomoo`00
0Woo00<007ooOol037oo00=l07ooOol04Woo0g`04Woo0W`06goo00<007ooOol02Woo00=l07ooOol0
1Woo00=l07ooOol00Woo00=l07ooOol05Woo00Il07ooOoml07ooO003Ool01G`0Ool007ooO00017oo
00=l07ooOol01Woo0P0000Ioog`0Oomoog`0Ool20003Ool01000Ool0000027oo00<007ooOol00goo
00<007oo00001Goo00<007ooOol06Goo000KOol00`00Oomoo`02Ool01000Oomoogoo0P003Goo00H0
07ooOol007oo000?Ool00g`0Oomoo`0COol3O00>Ool2O00NOol00`00Oomoo`0:Ool2O006Ool00g`0
Oomoo`02Ool00g`0Oomoo`0FOol017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo00=oo`03
O01oogoo00Eoo`07001oogoo001l07ooO0000Woo0P000Woo0P0000=l0000000027oo00<007ooOol0
0Woo0`001Woo00<007ooOol06Goo000KOol00`00Oomoo`03Ool01000Oomoogoo0P003Goo0P0000=o
o`00000047oo00=l07ooOol057oo0g`02Woo0W`08Goo0P0037oo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol05Goo00Al07ooOoml00Aoo`9l009oo`03O01oo`0000Aoo`03O01oogoo00Aoo`05
001oogooOol00002O003Ool20002Ool300000goo001oo`06Ool00`00Oomoo`03Ool20006Ool00`00
Oomoo`0JOol001]oo`03001oogoo00Aoo`03001oogoo00<000ioo`03001oo`00015oo`03O01oogoo
01Aoo`03O01oog`0009l00Eoo`9l02Eoo`03001oogoo00Yoo`9l00=oo`03O01oogoo009oo`03O01o
ogoo01Eoo`04O01oogooO004Ool2O0000gooO01oo`02Ool01@00OomoogooO0001Goo00<007ooOol0
0Woo00<007`0O0000goo0P0000=oo`00O0000`0027oo00<007ooOol00Woo00<007oo00001Woo00<0
07ooOol06Woo000LOol00`00Oomoo`03Ool00`00Oomoo`0200000goo001oo`0=Ool3000AOol00g`0
Oomoo`0DOol017`0Oomoogoo0W`000=oog`0O000:7oo00<007ooOol02goo00Al07ooOoml00Aoo`03
O01oogoo01Aoo`05O01oogooOoml0004Ool2O0000gooO01oo`03Ool01000Oomoog`017oo00<007oo
Ool00goo00=l0000O0000Woo00@007oo001oo`800003Ool0000000Moo`03001oogoo009oo`03001o
o`0000Moo`03001oogoo01Yoo`0077oo00<007ooOol017oo00<007ooOol010003Woo00<007oo0000
4Goo00=l07ooOol057oo00=l07ooOol01G`0:Goo1@002Goo0g`01Goo00=l07ooOol04goo00Al07oo
Ooml00Eoo`03O01oog`000Ioo`03001oog`000=oo`03001oogoo00=oo`04O01oo`00O002Ool20000
0goo001oo`0200000goo001oo`06Ool01P00Oomoogoo001oo`8000Ioo`03001oogoo01]oo`007Goo
00<007ooOol00goo00Al0000Ool0009oo`8000eoo`800003Ool007oo011oo`03O01oogoo01Aoo`9l
00Eoo`9l02aoo`T0009oo`03O01oogoo00=oo`03O01oogoo01=oo`04O01oogooO004Ool01G`0Ooml
07ooO0001Woo00D007`0Oomoo`0000Eoo`05O01oogoo001l0002Ool200000g`0001oo`030007Ool0
2@00Oomoogoo001oo`00Ool00005Ool00`00Oomoo`0LOol001eoo`03001oogoo00Eoo`04001l0000
O002Ool2000;Ool01@00Ool007oo00004Goo00=l07ooOol04Goo0W`00Woo00=l07ooOol017oo0g`0
<Woo0P000g`00`0000=l07ooOol04Woo00El07ooOomoog`000Aoo`9l00=oo`03O01oogoo00Aoo`03
O01oo`0000Eoo`03O01oogoo009oo`03001l07oo00<0009oo`03001oo`0000Moo`04001oogoo0002
Ool00`00Ool00005Ool00`00Oomoo`0LOol001ioo`03001oogoo00Eoo`800003Ooml07`0009l0003
001oogoo00Qoo`03001oogoo00<0015oo`03O01oogoo00ioo`9l00Eoo`03O01oogoo00Ioo`9l039o
o`03O01oogoo009l0003Ooml000000P000]oo`04O01oogooO004Ool2O005Ool00g`0Oomoo`03Ool0
0g`0001oo`04Ool00g`0Oomoo`03Ool00`00O01oo`030002Ool00`00Ool00006Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo01eoo`007goo00<007ooOol01Goo0P000goo00<007`0O000
0W`01goo00<007ooOol00Woo0P004Goo00=l07ooOol02goo0W`027oo00=l07ooOol01goo0g`0;goo
00=l07ooOol00Woo0W`02Goo2@000Woo00Al07ooOoml00Aoo`9l00Ioo`03O01oogoo009oo`03O01o
o`0000=oo`03O01oogoo00Aoo`03001l07`00080009oo`800003Ool007oo00Eoo`03001oo`00009o
o`04001oo`000004Ool00`00Oomoo`0NOol001moo`03001oogoo00Aoo`9l008000=oo`04001oogoo
0004O003Ool00`00Oomoo`03Ool2000AOol00g`0Oomoo`08Ool2O00;Ool00g`0Oomoo`09Ool2O00]
Ool00g`0Oomoo`03Ool2O00AOol00`00O00000060002O008Ool01G`0OomoogooO0000Woo00<007oo
O00027oo00@007oo0000009oo`03001oo`0000Ioo`05001oogoo001oo`0300000goo001oo`03Ool0
0`00Oomoo`0NOol0021oo`03001oogoo00Aoo`03O000000000Aoo`05001oogooOol00002Ool3O000
0`00Oomoo`04Ool2000AOol00g`0Oomoo`05Ool2O00>Ool00g`0Oomoo`0:Ool3O00ZOol00g`0Ooml
000300000g`0Ooml000AOol017`0Oomoog`017oo00=l000000001P0000Ioog`0Oomoo`00O003Ool0
0`00Oomoo`06Ool017`0001oo`000goo00<007oo00001Goo00<007ooOol010000goo00D007ooOomo
o`00025oo`0087oo00<007ooOol01Woo0P0000El07ooOomoo`0000=oo`8000=oo`03001l07`0009l
00=oo`80015oo`03O01oogoo009oo`9l015oo`03O01oogoo00aoo`=l02Moo`03O01oog`000=oo`03
O0000000009l00H000Qoo`05O01oogooOoml0003Ool00g`0Oomoo`07Ool500001W`000000000Ool0
00Ioo`05O01oo`00O0000002Ool200000goo001oo`04Ool400000goo001oo`07Ool00`00Oomoo`0O
Ool0025oo`03001oogoo00Eoo`03001oo`00009l009oo`03001oogoo009oo`800003Ool007oo00=o
o`=l0003Ool00000015oo`04O01oog`0O00DOol00g`0Oomoo`0>Ool2O00UOol2O004Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool8000017`0Oomoog`017oo00=l07ooOol02Goo00L007`0Ooml07ooO01o
o`050002Ool017`0Oomoogoo0P000Woo0`001Goo0`000Woo00@007oo000000Eoo`03001oogoo021o
o`008Goo00<007ooOol01Woo00<007oo00000g`000=oo`00Ool017oo0`001Woo0g`000<007ooOol0
3Woo0W`05goo00=l07ooOol03goo0g`08Woo0W`017oo00=l07ooOol00goo0W`02goo00Al0000001l
00<00004O00000000008Ool00`00Oomoo`03O005Ool01000Oomoog`017oo0P000Woo0`000Woo1@00
0Woo1@001Goo00<007ooOol087oo000ROol00`00Oomoo`05Ool01000Ool007oo17`000<007ooOol0
17oo00<007ooOol027oo00@007`0O01l00Yoo`9l009oo`9l01Ioo`9l019oo`9l021oo`03O01oogoo
00=oo`03O01oogoo00Eoo`03O01oogoo00Moo`05O01oogooOoml0002Ool2O003Ool90003Ool00g`0
Oomoo`04Ool200000g`0Oomoo`02Ool20002Ool2000017oo000000000Woo1P0000=oo`0000001Goo
00<007ooOol08Goo000SOol00`00Oomoo`04Ool01000Oomoo`000Woo0g`000<007ooOol00goo0`00
2Goo00<007ooOol017`017oo0W`01Woo00=l07ooOol05Goo00=l07ooOol04Goo0g`07Goo00=l07oo
Ool00goo00=l07ooOol01Woo0W`01goo00Al07ooOoml009oo`03O01oog`000Uoo`03001oogoo0080
00=l00P000Aoo`80009l00@0009oo`@0009oo`04001oo`000005Ool00`00Oomoo`0ROol002Aoo`03
001oogoo00Aoo`04001oogoo0003Ool2O0000`00O01oo`02Ool00`00Oomoo`020007Ool20005Ool4
O009Ool00g`0Oomoo`0EOol00g`0Oomoo`0COol2O00JOol00g`0Oomoo`04Ool00g`0Oomoo`08Ool2
O005Ool027`0Oomoog`0Ooml07ooO009Ool00`00Oomoo`02Ool01G`0Ooml07ooO0002@0000El0000
Ool007`000L00003Ool007oo009oo`04001oo`000005Ool00`00Oomoo`0SOol002Aoo`03001oogoo
00Aoo`05001oogooOol00004Ool01W`0001l07`0Ool000Aoo`03001oogoo00Aoo`03001oo`0000=o
o`9l00=oo`Al00Ioo`03O01oogoo01Eoo`03O01oogoo01Aoo`=l01Moo`03O01oogoo00Eoo`03O01o
ogoo00Uoo`05O01oogooOoml0002Ool01W`0Oomoog`0Ooml00Qoo`03001oogoo009oo`03O01oo`00
00<0009oo`03001l07oo009oo`800003Ool0000000H000Aoo`05001oogoo001oo`020006Ool00`00
Oomoo`0SOol002Eoo`03001oogoo00Aoo`05001oogooOol00004Ool01@00O01oog`000001Goo0P00
1Goo00D007oo000007`000Uoo`=l00Aoo`03O01oogoo01Eoo`03O01oogoo01Ioo`9l01Eoo`03O01o
ogoo00Eoo`03O01oogoo00Yoo`9l0009Ooml07ooOoml07ooO01oog`000Qoo`03001oogoo00D00007
Ooml07ooOoml0000O0000goo1`0000=l0000Ool00P000goo00@007ooOomoo`<000Ioo`03001oogoo
02Aoo`009Goo00<007ooOol017oo00D007ooOomoo`0000Eoo`04001l07`00002O005Ool20003Ool0
1@00O01l07oo000037oo17`000=oog`0Ool05Woo00=l07ooOol05goo0g`04Goo0W`01goo00=l07oo
Ool037oo00Al07ooOomoo`9l009oo`03O01oogoo00Eoo`@00003Ooml07oo00=oo`03O01oogoo0080
009oo`800003Ool007oo00<00006Ooml0000001oo`000Woo0P000Woo00<007oo00001goo00<007oo
Ool097oo000VOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Ool007`0Ool0
0W`01Goo0P000W`017oo00<007ooOol03Goo17`05Woo00=l07ooOol06Goo0W`03goo0W`01goo00=l
07ooOol037oo1G`00Woo00=l07ooOol00Woo100017oo00=l07ooOol00goo00Ul07ooOol007ooO000
07`0Ool010000Woo0P0000Al0000Oomoo`@00004Ool000000007Ool00`00Oomoo`0UOol002Ioo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`800004Ooml07ooOol2O003Ool2O0000`00
Ool00004Ool00`00Oomoo`0?Ool5O00COol00g`0Oomoo`0JOol3O00;Ool00g`0Ooml0007Ool00g`0
Oomoo`0<Ool00g`0Oomoo`02O002Ool50002Ool00`00Oomoo`02Ool00g`0Oomoo`04Ool00g`0Ool0
0002Ool01000O01oogoo0`0000=oo`0000000`000goo0`0000Aoo`00000000Qoo`03001oogoo02Eo
o`009goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00W`00Woo0g`0
0goo0P001Goo00<007ooOol03goo00Al07ooOomoo`Al011oo`03O01oogoo01aoo`9l00Uoo`03O01o
og`000Moo`03O01oogoo00]oo`03O01oogoo009l00<000Moo`05001oogooOoml0006Ool00g`0Ool0
0002Ool01000Oomoog`00`0000Qoo`00001oo`00Ool007oo0P0000Aoo`00Oomoo`8000Qoo`03001o
ogoo02Ioo`00:7oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo0P000goo0g`000Ao
og`0O01l009oo`<000Aoo`80011oo`03O01oogoo00Aoo`Al00eoo`9l01ioo`=l00Eoo`04O01oogoo
O007Ool00g`0Oomoo`0;Ool300001G`0OomoogooO0001Woo00D007ooOomoog`000Moo`05O0000000
Ool00002Ool017`0001l07oo0P0000=oo`0000000P0000Il0000001oo`00Ool30008Ool00`00Oomo
o`0WOol002Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`05001oog`0O01oo`02
O003Ool2O00017oo001oo`001Goo00<007ooOol03Woo00=l07ooOol01goo17`02goo00=l07ooOol0
7Woo0g`00Woo00Al07ooOoml00Moo`03O01oogoo00Moo`@00004O01oog`0O002Ool017`0Ooml07`0
0goo00D007ooOomoog`000Qoo`@0009oo`<00004O0000000Ool600000g`0000000040008Ool00`00
Oomoo`0XOol002Uoo`03001oogoo00Uoo`03001oogoo00=oo`9l00Eoo`03O01oogoo009oo`04O000
07ooOol20004Ool00`00Oomoo`0>Ool00g`0Oomoo`0:Ool3O009Ool00g`0Oomoo`0POol3O002Ool0
0g`0Oomoo`05Ool00g`0Oomoo`02Ool50003Ool017`0Ooml07`00goo00Al07ooOomoo`9l0005001o
ogooOoml0008Ool30002Ool017`0000007oo2@0000Aoo`00001oo`800003Ool007oo00Qoo`03001o
ogoo02Qoo`00:Woo00<007ooOol02Goo00<007ooOol00W`00Woo00<007ooOol00goo0W`00goo00<0
07`0O0000Woo0P000goo00<007ooOol03Woo00=l07ooOol037oo17`01Woo00=l07ooOol087oo0P00
0g`01goo00=l000000000P0027oo00Al07ooO01l00=oo`03O01oogoo009oo`05001l07ooOoml0008
Ool00g`000000002Ool017`0000007oo0P0000Eoo`00O00007oo00D00005O01oo`00Ool00009Ool0
0`00Oomoo`0YOol002]oo`03001oogoo00Uoo`03001l07oo00Aoo`03001oogoo00Aoo`9l009oo`04
001oog`0O002Ool20002Ool00`00Oomoo`0>Ool00g`0Oomoo`0?Ool4O003Ool00g`0Oomoo`0OOol0
0g`0Ool000030003Ool4000;Ool01G`0Ooml07ooO0000Woo00=l07ooOol00Woo00<007ooOol00W`0
27oo00=l000000000W`01P000Woo0P0000Al0000001oo`80009oo`03001oo`0000Uoo`03001oogoo
02Yoo`00;7oo00D007ooOomoo`0000Aoo`9l0003001oogoo00Aoo`03001oogoo00Ioo`9l0004001o
ogooOol2O002Ool00`00Oomoo`02000?Ool00g`0Oomoo`0BOol5O00OOol00g`0Oomoo`02Ool00g`0
Ool000030002Ool00g`0Oomoo`09Ool2O0000gooO01oo`02Ool01G`0Oomoogoo00000goo00=l07oo
O0001Woo00El0000001oog`000800005Ool007ooOol00002Ool00`00Oomoo`0900000goo001oo`06
Ool00`00Oomoo`0[Ool002eoo`04001oogooOol20002O003Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00g`0Oomoo`03Ool2O0000goo00000002Ool00`00Oomoo`0=Ool00g`0Oomoo`0EOol4O00LOol0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`000000002000:Ool017`0Oomoog`00Woo00El07ooOomo
o`0000=oo`04O01oogooOol2O003Ool00g`000000002O00200001Goo001oogoo00000Woo00D007oo
Ool007oo00L00003Ool007oo00Ioo`03001oogoo02aoo`00;Goo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol017oo00@007ooOomoo`8000Aoo`9l00Eoo`9l0005Ool00000Ool0000?Ool00g`0
Oomoo`0FOol00g`0Ooml0003O00HOol00g`0Oomoo`02Ool00g`0Oomoo`04Ool3O0040005Ool2O000
0gooO01oo`02Ool017`0Oomoo`000goo00=l07ooOol017oo00El07ooO00007oo00<00003O0000000
00=oo`04001oo`000002Ool3000017oo000007oo0`0027oo00<007ooOol0;7oo000^Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool20002Ool20002O005Ool2O000
17oo000000003goo00=l07ooOol05Woo00=l07ooOol00Woo0g`057oo00=l07ooOol00goo00=l07oo
Ool01Woo0g`00Woo100000Eoog`0Oomoog`0009oo`04O01oogoo0003Ool00g`0Oomoo`06Ool00g`0
001oo`0300000gooO01oo`03Ool00`00Ool0000200000goo001oo`0400000goo00000009Ool00`00
Oomoo`0]Ool002moo`8000Aoo`8000Aoo`03001oogoo00Aoo`03001oogoo009l0003Ool00000009o
o`80009l00Eoo`9l0003Ool0000000moo`03O01oogoo01Ioo`9l00Eoo`Al011oo`03O01oogoo00=o
o`03O01oogoo00Ioo`03O01oogoo00=l00=oo`05O0000000001l0002Ool00g`0Ool00003Ool00g`0
Oomoo`06Ool00g`0001l000500000g`0Oomoo`02Ool300000goo001oo`080008Ool2000`Ool0035o
o`03001oogoo00=oo`05001oogooOol00007Ool01000Oomoo`000g`00P000Woo0`001Woo0W`00P00
3goo00=l07ooOol05goo00=l07ooOol01Woo17`02goo00=l07ooOol017oo00=l07ooOol01Woo00=l
07ooOol00goo17`00Woo00=l000000000`000goo00=l07ooOol01Woo00=l000000000P000W`00Woo
00Al07ooOomoo`800003Ool007oo00800003Ool0000000@000Qoo`03001oogoo031oo`00<Woo00<0
07ooOol00goo0P000Woo00<007ooOol02Goo00<007`0O0000g`00goo0`001Goo0W`00P003Woo00=l
07ooOol05goo00=l07ooOol02Goo17`01goo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol0
17oo17`000Eoog`0Oomoog`000D000Moo`03O000000000D00004Ooml07`0O003Ool01P00Ool007oo
001oo`P000Moo`03001oogoo035oo`00<Woo00<007ooOol01Goo00@007ooOol000]oo`80009l0003
Ooml07`000Al008000Eoo`9l0003001oogoo00aoo`03O01oogoo01Moo`03O01oogoo00aoo`Al009o
o`03O01oogoo00Aoo`03O01oogoo00Moo`03O01oogoo00Aoo`9l009oo`9l0004Ooml07oo0002Ool0
0g`0Ool000030002Ool00g`0001l00040005Ool01W`0Oomoo`00Ool0009oo`T000Qoo`03001oogoo
035oo`00<goo00<007ooOol01Goo00@007ooOol000aoo`05001oog`0O01oo`0200000gooO01l0002
O0020004Ool00g`00000000=Ool00g`0Oomoo`0GOol00g`0Oomoo`0?Ool4O005Ool00g`0Oomoo`07
Ool00g`0Oomoo`03Ool00g`0Ooml0002Ool00g`0Ooml0002O002Ool00g`0Oomoo`04Ool80006Ool3
O0020003Ool200000goo000000030008Ool00`00Oomoo`0bOol003Aoo`03001oogoo00Eoo`<000eo
o`800004Ooml07`0Ool20003Ool5O003Ool3000<Ool00g`0Oomoo`0GOol00g`0Oomoo`0>OolH0000
0g`00000000X00000goo000000020009Ool00`00Oomoo`0cOol003Eoo`03001oogoo00Ioo`8000io
o`03001oogoo009l0003Ool00000009oo`9l009oo`Al0004001l0000000;Ool00g`0Oomoo`0GOol0
0g`0Oomoo`0=Ool700000gooO01l0009Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`05001o
ogooO01oo`03O002Ool2O0060002Ool20004Ool017`0000000000W`000=oo`00000010002Goo00<0
07ooOol0=7oo000fOol00`00Oomoo`06Ool2000>Ool20002Ool2O0000goo00000002Ool2O002Ool2
0006O00:Ool00g`0Oomoo`0GOol00g`0Oomoo`0=Ool00g`0Oomoo`03Ool=0003Ool017`0Oomoog`0
0Woo00Il07oo001l07ooO005Ool2O0050002Ool00`00Oomoo`06Ool00g`000000003Ool00g`00000
00040008Ool00`00Oomoo`0eOol003Moo`03001oogoo00Moo`03001oogoo00eoo`04001oogooOol2
O0000goo00000002Ool2O003Ool300000gooO01l0002O008Ool00g`0Oomoo`0GOol00g`0Oomoo`0;
Ool00g`0Oomoo`05Ool00`00O01oo`08Ool017`0000007`02@0000=oog`0Ool01Goo00Il00000000
07`00002Ool00`00Oomoo`06Ool01@00O0000000Ool01`002Goo00<007ooOol0=Woo000hOol20008
Ool00`00Oomoo`0=Ool20003Ool3O0020002Ool00g`0Oomoo`02Ool300000goo00000004O005Ool0
0g`0Oomoo`0GOol2O00;Ool00g`0Oomoo`05Ool00`00O01oo`08Ool00g`0Ooml0003Ool01g`0Oomo
og`0001oog`000L00003O000000000<0009l0003001oogoo00Ioo`05001oog`0001oo`060009Ool2
000iOol003Yoo`03001oogoo00Ioo`8000moo`03001oogoo00=oo`9l00800003Ooml07`000Aoo`D0
009l0003Ooml07`000=l0003Ooml07oo01Uoo`03O01oogoo00Moo`03O01oogoo00Ioo`03001l07oo
00Uoo`03O01oogoo009oo`05O01oogoo001oo`02O002Ool400000g`0000000030003Ool00`00O01l
0005Ool01000Ool007`01`002Goo00<007ooOol0>Goo000kOol00`00Oomoo`07Ool00`00Oomoo`0=
Ool20005Ool2O00200000gooO01l0003Ool00`00Oomoo`030002O004Ool4O00IOol00g`0Oomoo`06
Ool00g`0Oomoo`05Ool00`00Ooml0009Ool2O003Ool00g`0Ool000070002Ool00`00O00000020000
0goo001oo`02Ool01000Oomoogoo0g`000=oo`00Ool00P0000=l000000000`002Woo00<007ooOol0
>Woo000lOol00`00Oomoo`07Ool2000?Ool00`00Oomoo`04Ool2O00200000gooO01l0002Ool01000
Oomoogoo0`000W`000=oo`00Ool00Woo1W`05Goo00=l07ooOol01Goo00=l07ooOol01Goo00<007oo
O00027oo00<007`00000200000Al07ooOomoo`<00006O0000000001oo`000goo00<007ooOol01Goo
0W`00`0000=l000000000P002Woo00<007ooOol0>goo000mOol20009Ool00`00Oomoo`0=Ool20006
Ool2O002000017ooO01oogoo0P0017oo0`0000=l0000Ool00Woo00=l07ooOol00Woo17`04Woo00=l
07ooOol00goo00=l07ooOol01Woo00<007ooO000200000=l0000O0000`0000=l0000Ool00W`02@00
0Woo00<007ooOol00Woo00<007ooOol017oo0`000W`01@002Goo0P00?Woo000oOol00`00Oomoo`07
Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool2O0020002O002Ool00`00Oomoo`03Ool50002Ool00g`0
Oomoo`05Ool5O00>Ool00g`0Oomoo`02Ool017`0Oomoogoo200017oo0`0000Ml0000Ooml07oo001l
00020003O003Ool300001W`000000000Ool000=oo`03001oogoo00=oo`P00003O00007oo00Uoo`03
001oogoo03ioo`00@7oo00<007ooOol01goo0P003goo0P001goo0W`00P000W`000=oo`00Ool00Woo
00<007oo000010000Woo00=l07ooOol01Woo0`0017`06P0000=l00000000100000El0000000007`0
00800004O0000000O00900000goo000000050003Ool<000:Ool00`00Oomoo`0oOol0045oo`03001o
ogoo009ooc<00003O000000000D000Moo`El00H00004Ooml07ooO006Ool500000g`0Ool000030000
0g`0Oomoo`02Ool01G`0Oomoog`0Ool00g`000=oo`0000000`0000Al0000001oo`80009oo`D00003
Ool0000000P000Yoo`03001oogoo041oo`00@Woo0P002Goo0P003goo0P0027oo0W`00P0000=l0000
00001Woo1@0000=l07ooOol01Woo20000Woo17`017oo00=l07ooOol01@0000=oo`0000000P0000=l
0000Ool00goo00=l07ooOol00Woo00Al07ooO01oo`9l0003Ooml000000@00003Ool000000080009o
oa4000Uoo`8004=oo`00A7oo00<007ooOol00Woo0W`017oo00<007ooOol03Woo00<007ooOol01goo
0W`010001goo0`0000=l000000001P003Woo1g`01P0000Eoo`00Oomoog`000Aoo`03O01oogoo00=o
o`05O00007`0O01oo`02O00400000g`000000003000017oo001oogoo3`002Goo00<007ooOol0@goo
0015Ool00`00Oomoo`03Ool4O0000goo001oo`0?Ool2000:Ool40002Ool800000gooO01l0002000>
Ool70005O005Ool01000Oomoog`00goo00=l07ooOol017oo0g`000=oog`00000100000El0000Ool0
07oo01800003Ool007oo00Qoo`03001oogoo04Aoo`00AWoo00<007ooOol01Woo0W`00P0047oo00<0
07ooOol01Goo20001goo0P000Woo0W`00`001Woo2P0000=oog`0Ool00goo1W`000@007ooOoml009o
o`03O01oogoo00Aoo`03001l07`0009oo`D00004O01oogooOolB000<Ool00`00Oomoo`15Ool004Mo
o`8000Yoo`03001l07`0009oo`@000Moo`P00003Ool007oo00=oo`03O000000000Qoo`05001oogoo
O0000002O00:0007Ool00g`0Oomoo`03Ool00g`0Ool00002Ool4O002Ool00g`0Oomoo`03Ool01@00
Ooml07`0Ool010000W`00goo4P002goo0P00B7oo0019Ool20009Ool20004O0000goo000000070002
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool30007Ool300000g`000000005000;Ool00g`0Oomoo`04
Ool00`00O01oo`02Ool00`00Oomoo`05O003Ool01000Ooml07`01@000W`00goo4@002goo0P00BWoo
001;Ool20009Ool50003O006Ool80008Ool40002Ool7000017`0Ool000000W`000=oo`0000002Goo
00=l07ooOol00goo0P0000=oog`0Ool00P0000Aoog`0Ooml00800003Ooml07`000=l0003Ool007`0
00<0009l009oo`/00003O000000000@000Yoo`8004aoo`00CGoo0P0027oo00<007ooOol017oo0g`0
1goo0P0000=oo`0000001P000Woo1@001Woo0P0000El07ooOol007oo009l00Yoo`04O01oogooOol2
0004Ool017`0000007oo0W`000<007ooOol00Woo00D007ooO00007`0008000Al0003Ool000000100
00Yoo`8004ioo`00Cgoo00<007ooOol01Woo0P001goo17`01Goo0`000goo30001Goo00<007ooO000
0Woo0P0000=oog`0O0001goo00Al07ooOomoo`8000Ioo`04O0000000O005Ool00`00Ooml00040007
O00700000g`000000005000;Ool00`00Oomoo`1>Ool0051oo`03001oogoo00Moo`D000Ioo`Al0003
Ool0000000@000Qoo`03001oo`0000P00003Ooml0000009oo`03001oogoo009l00Eoo`03O01oo`00
008000Eoo`<00003O01oog`000Aoo`03001oog`000<00003O00007`0009l00H0009l00P000eoo`03
001oogoo04moo`00DGoo0P0037oo30000W`00P0000Aoo`00000000Ioo`05001oogooOoml00020002
Ool90002Ool2O002Ool017`0Ool0000017oo0`000Woo00@007ooO01l00=oo`03001oog`000<0009l
0003Ooml000000T000=l008000ioo`80059oo`00Dgoo0P003goo0W`01`000g`01`000goo00<007oo
Ool00Woo00=l000000000goo00<007`0Ool020000W`00P000goo0P001Goo00<007`0Ool00W`000=o
o`0000001@0000=l000000003@003goo0P00E7oo001EOol2000AOol01000Ooml07`01`0000=l07oo
Ool02`0000Ql0000000007oo001l07oo0P000Woo00<007ooOol020001Woo00Il07ooOoml07ooO00D
000@Ool2001FOol005Moo`8001Qoo`9l00T00003Ool007oo00=oo`9l00@00003O000000000D00005
O0000000001l0003Ool600000g`00000000300000g`00000000>000AOol2001HOol005Uoo`<000Yo
o`H000Aoo`P0009l00X0009l00@000=oo`@000=oo`03001l07`000H00003O000000001<0011oo`<0
05Yoo`00G7oo0`002goo3@0017oo17`07@0000El0000000007`000d00003Ool0000000moo`<005eo
o`00Ggoo0P004Goo3@0000=l0000O0000`000W`01`0000=oog`000006P0000=oog`0Ool047oo0P00
H7oo001QOol2000GOol90002O00500000g`00000000>0002O00;000DOol2001ROol006=oo`<001Qo
o`P0009l02<000moo`8006Aoo`00IWoo0`0067oo4@0000=oo`0000003@0057oo1000IWoo001YOol3
000COolQ000COol3001ZOol006aoo`D001Ioo`P000Ioo`800003Ool000000080019oo`D006eoo`00
LGoo10009Woo00<007ooOol02goo1@00LWoo001eOol5000[Ool4001gOol007Yoo`L001eoo`L007]o
o`00PGoo7@00PWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00PWoo0`000Woo0`0000=oo`0000001@0000=oo`0000001@00QWoo0023Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`27Ool008Aoo`@000Ioo`03001oogoo00Eo
o`03001oogoo08Moo`00Q7oo00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo08Moo`00Q7oo
00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo08Moo`00QGoo0P001goo00<007ooOol01Goo
00<007ooOol0Qgoo0025Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`27Ool008Aoo`<000Moo`03
001oogoo00Eoo`03001oogoo08Moo`00SGoo0P001Woo0P00RGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-376.75, -363.004, 2.48606, \
2.79683}}]
}, Open  ]],

Cell["\<\
 
As illustrated, the long-distance,faster progression segments tend to \
converge (and diverge) to particular neighborhoods. To examine the \
connectivity of these neighborhoods in relative isolation, we use the SEE \
operators that characterize segments by their ending or starting \
neighborhood:
From[{x,y}, epsilon] : selects the progression segments whose starting point \
is at a
distance less than epsilon from {x,y} (which will typically be the center of \
one of the 
preferred places). 
To[{x,y}, epsilon] :  selects the progression segments whose endpoint is at a \
distance 
less than epsilon from {x,y}. 
This allows us to form a preliminary opinion as to whether specific locations \
constitute operational places in the behavioral space of the animal. 
Since the rat's home base stands out as a relatively stable structure (see \
background section), it is only reasonable to examine the departures from and \
arrivals to the presumed home base's neighborhood. In this particular rat \
session examination of the cumulative time spent in, and number of visits \
payed to, all locations around the periphery suggested that the home base was \
located at about 12 o\"clock. The following commands cull, therefore,  out \
all the segments starting or ending at that neighborhood, here designated by \
the coordinates {10,350}. 
See[SpeedPairPlot[From[{10,350}, 50]]]  generates the departures from from \
that neighborhood, and See[SpeedPairPlot[To[{10,350}, 50]]] generates the \
arrivals to that neighborhood (c). Note the asymmetry:\
\>", "Text",
  TextJustification->1,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"graph2", 
          StyleBox["=",
            FontColor->GrayLevel[0]], \(See[
            SpeedPairPlot2[From[{10, 350}, 50]], 
            PlotLabel -> 
              StyleForm["\<From home base (departures)\>", 
                FontSize -> 14]]\)}], " ", ";"}], 
      StyleBox[" ",
        FontColor->GrayLevel[0]]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -115.156 0 ]
[.5 1.0125 115.156 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -176.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(From) show
105.063 13.750 moveto
(home) show
146.938 13.750 moveto
(base) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
188.813 13.750 moveto
(H) show
197.188 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(departures) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.938 13.750 moveto
(L) show
289.313 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.56845 .94841 m
.6369 .9246 L
s
.55357 .95106 m
.3497 .93386 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.5744 .94577 m
.73363 .88228 L
s
.54762 .94577 m
.53869 .94048 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.48958 .95899 m
.46726 .95503 L
s
.52679 .9537 m
.66964 .87698 L
s
.5506 .94577 m
.55952 .89021 L
s
.55952 .89021 m
.46875 .95635 L
s
.48512 .96032 m
.50595 .95503 L
s
.52679 .95635 m
.70685 .90344 L
s
.55208 .94048 m
.54613 .93915 L
s
.54315 .93386 m
.3244 .92063 L
s
.5253 .94709 m
.61161 .93783 L
s
.55804 .94841 m
.70685 .90344 L
s
1 0 0 r
.55506 .94709 m
.11012 .73413 L
s
0 0 0 r
.50744 .95503 m
.51637 .95503 L
s
.53423 .96032 m
.54167 .96693 L
s
.54315 .95767 m
.5506 .95503 L
s
.55506 .9537 m
.74554 .87566 L
s
.58929 .94577 m
.59077 .94841 L
s
.59077 .9537 m
.58631 .94312 L
s
.58482 .94841 m
.58482 .94577 L
s
.55506 .93783 m
.55952 .89153 L
s
.55952 .89153 m
.45982 .95635 L
s
.47619 .95899 m
.52083 .95503 L
s
.52679 .95635 m
.53571 .96296 L
s
.54464 .95767 m
.80952 .77646 L
s
.60119 .93915 m
.52679 .93915 L
s
.5253 .93915 m
.3869 .93386 L
s
.50893 .95635 m
.49554 .95503 L
s
.5 .95503 m
.52381 .95767 L
s
.53274 .96032 m
.57589 .9418 L
s
.56994 .94841 m
.56845 .94841 L
s
1 0 0 r
.56994 .94312 m
.76935 .86111 L
s
0 0 0 r
.55655 .94444 m
.58333 .92725 L
s
.58631 .92196 m
.66071 .87169 L
s
.52827 .95635 m
.5372 .96429 L
s
1 0 0 r
.54018 .96164 m
.73661 .88228 L
s
0 0 0 r
.48363 .95635 m
.44643 .9537 L
s
.49256 .95899 m
.52083 .95106 L
s
.5253 .94841 m
.54167 .94048 L
s
.54911 .94841 m
.70982 .89947 L
s
.54911 .95635 m
.54613 .96164 L
s
.54315 .96429 m
.1131 .71296 L
s
.52381 .96032 m
.77827 .85317 L
s
.59375 .94048 m
.58482 .94312 L
s
.5878 .94444 m
.5878 .94841 L
s
.5878 .94974 m
.59524 .9418 L
s
.60565 .93915 m
.63988 .92593 L
s
.49256 .95635 m
.51935 .95106 L
s
.52679 .95635 m
.5372 .96561 L
s
.54167 .96164 m
.69792 .90873 L
s
.59375 .9418 m
.69643 .90344 L
s
.57292 .94048 m
.59821 .94048 L
s
.61161 .93783 m
.65476 .91005 L
s
.52827 .95635 m
.5372 .96429 L
s
.54464 .95635 m
.54911 .9537 L
s
.55506 .94974 m
.95685 .51587 L
s
.61012 .91667 m
.61012 .91138 L
s
.59673 .90741 m
.5878 .90741 L
s
.58185 .90476 m
.49256 .93783 L
s
.55506 .9418 m
.54762 .95503 L
s
.5506 .94974 m
.56696 .84656 L
s
.59673 .92328 m
.48065 .94974 L
s
.47768 .95899 m
.49702 .95767 L
s
.53274 .96032 m
.70238 .90344 L
s
.50893 .94974 m
.52381 .95503 L
s
.52827 .95238 m
.53274 .95635 L
s
.54315 .95635 m
.73661 .88095 L
s
.5997 .94312 m
.60119 .9537 L
s
.5997 .94974 m
.56101 .94841 L
s
.55804 .95503 m
.67708 .88757 L
s
.55506 .95106 m
.30655 .91667 L
s
.57887 .93915 m
.44345 .95503 L
s
.52976 .95767 m
.5372 .96429 L
s
.54167 .96032 m
.7753 .85582 L
s
.59673 .94048 m
.5878 .94048 L
s
.58185 .9418 m
.57143 .94709 L
s
.54167 .94048 m
.47321 .95899 L
s
.54911 .95635 m
.45833 .95503 L
s
.51042 .95503 m
.52976 .95503 L
s
.53571 .95767 m
.53869 .96296 L
s
.54167 .96164 m
.80804 .76587 L
s
.54167 .93783 m
.4747 .95899 L
s
.47619 .95238 m
.47768 .94841 L
s
.48065 .94841 m
.47917 .9537 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0023OolI0024Ool007]oo`P0
01Uoo`P007aoo`00MGoo1P00:Goo1P00MWoo001bOol3000eOol3001cOol006eoo`D003]oo`D006io
o`00JWoo0`00AGoo0`00Jgoo001WOol3001;Ool2001YOol006Eoo`80051oo`@006Eoo`00HWoo0`00
EWoo0P00Hgoo001OOol3001KOol3001POol005aoo`<0065oo`<005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Ioo`8006moo`8005Moo`00E7oo0P00Lgoo0P00EGoo001COol00`00
Oomoo`1eOol2001COol0055oo`8007Yoo`80055oo`00Cgoo0P00OWoo00<007ooOol0CWoo001=Ool2
0021Ool2001>Ool004]oo`8008Eoo`03001oogoo04]oo`00BGoo0P00R7oo0P00Bgoo0018Ool00`00
Oomoo`2:Ool20019Ool004Moo`03001oogoo08eoo`03001oogoo04Ioo`00AGoo0P00TGoo0P00AWoo
0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0049oo`8009Moo`8004=oo`00@Goo00<007ooOol0
VGoo00<007ooOol0@7oo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003moo`03001oogoo09eo
o`03001oogoo03ioo`00?Goo0P00XGoo0P00?Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol0
03]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo00<007ooOol0>Goo000i
Ool00`00Oomoo`2YOol2000iOol003Qoo`03001oogoo0:aoo`03001oogoo03Ioo`00=Woo0P00/7oo
00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03001oogoo0;=oo`03
001oogoo03=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000cOol00`00Oomoo`2eOol00`00
Oomoo`0bOol0039oo`03001oogoo0;Moo`03001oogoo035oo`00<Goo00<007ooOol0^Goo00<007oo
Ool0<7oo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool002moo`03001oogoo0;eoo`03001oogoo
02ioo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/
Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo
000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00
:Goo00<007ooOol0bGoo00<007ooOol0:7oo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Qo
o`03001oogoo0<aoo`03001oogoo02Ioo`009goo00<007ooOol0cGoo00<007ooOol09Woo000VOol0
0`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Goo00<0
07ooOol0dGoo00<007ooOol097oo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000ROol00`00Oomo
o`3GOol00`00Oomoo`0QOol0025oo`03001oogoo0=Qoo`03001oogoo025oo`008Goo00<007ooOol0
fGoo00<007ooOol087oo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]o
o`03001oogoo01moo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol0
0`00Oomoo`0NOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<0
07ooOol07Goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001o
ogoo01aoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomo
o`0KOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol0
6Woo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uo
o`006Goo00<007ooOol0jGoo00<007ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol0
01Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000G
Ool00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03
001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00
Oomoo`3`Ool00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Aoo`03001oogoo
0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3d
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo
00<007ooOol04Woo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03
001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00
Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo
011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@
Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo
000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo0?aoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool0
0`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomo
o`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0
oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol0
0`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<0
07ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001o
ogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?Uoo`03001oogoo00=oo`03001oogoo00eoo`003goo00<007ooOol0
mgoo00<007ooOol017oo00<007ooOol03Goo000?Ool00`00Oomoo`3fOol00`00Oomoo`04Ool00`00
Oomoo`0>Ool000moo`03001oogoo0?Eoo`03001oogoo00Eoo`03001oogoo00ioo`003goo00<007oo
Ool0m7oo00<007ooOol01Woo00<007ooOol03Woo000?Ool00`00Oomoo`3cOol00`00Oomoo`07Ool0
0`00Oomoo`0>Ool000moo`03001oogoo0?9oo`03001oogoo00Qoo`03001oogoo00ioo`003goo00<0
07ooOol0lWoo00<007ooOol027oo00<007ooOol03Woo000?Ool00`00Oomoo`3aOol00`00Oomoo`09
Ool00`00Oomoo`0>Ool000moo`03001oogoo0?1oo`03001oogoo00Yoo`03001oogoo00ioo`003goo
00<007ooOol0kgoo00<007ooOol02goo00<007ooOol03Woo000?Ool00`00Oomoo`3^Ool00`00Oomo
o`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo0>eoo`03001oogoo00eoo`03001oogoo00ioo`00
47oo00<007ooOol0jgoo00<007ooOol03Goo00<007ooOol03goo000@Ool00`00Oomoo`3ZOol00`00
Oomoo`0>Ool00`00Oomoo`0?Ool0011oo`03001oogoo0>Uoo`03001oogoo00moo`03001oogoo00mo
o`0047oo00<007ooOol0j7oo00<007ooOol047oo00<007ooOol03goo000@Ool00`00Oomoo`3WOol0
0`00Oomoo`0AOol00`00Oomoo`0?Ool0011oo`03001oogoo0>Ioo`03001oogoo019oo`03001oogoo
00moo`004Goo00<007ooOol0i7oo00<007ooOol04Woo00<007ooOol047oo000AOol00`00Oomoo`3T
Ool00`00Oomoo`0BOol00`00Oomoo`0@Ool0015oo`03001oogoo0>=oo`03001oogoo01=oo`03001o
ogoo011oo`004Goo00<007ooOol0hWoo00<007ooOol057oo00<007ooOol047oo000AOol00`00Oomo
o`3QOol00`00Oomoo`0EOol00`00Oomoo`0@Ool0019oo`03001oogoo0=moo`03001oogoo01Eoo`03
001oogoo015oo`004Woo00<007ooOol0gWoo00<007ooOol05Woo00<007ooOol04Goo000BOol00`00
Oomoo`3MOol00`00Oomoo`0GOol00`00Oomoo`0AOol0019oo`03001oogoo0=aoo`03001oogoo01Qo
o`03001oogoo015oo`004goo00<007ooOol0fWoo00<007ooOol06Goo00<007ooOol04Goo000COol0
0`00Oomoo`3IOol00`00Oomoo`0IOol00`00Oomoo`0BOol001=oo`03001oogoo0=Qoo`03001oogoo
01Yoo`03001oogoo019oo`0057oo00<007ooOol0eWoo00<007ooOol06goo00<007ooOol04Woo000D
Ool00`00Oomoo`3EOol00`00Oomoo`0KOol00`00Oomoo`0COol001Aoo`03001oogoo0=Eoo`03001o
ogoo01]oo`03001oogoo01=oo`005Goo00<007ooOol0dgoo00<007ooOol077oo00<007ooOol04goo
000EOol00`00Oomoo`3BOol00`00Oomoo`0LOol00`00Oomoo`0DOol001Eoo`03001oogoo0=5oo`03
001oogoo01eoo`03001oogoo01Aoo`005Goo00<007ooOol0d7oo00<007ooOol07Woo00<007ooOol0
57oo000EOol00`00Oomoo`3?Ool00`00Oomoo`0OOol00`00Oomoo`0DOol001Ioo`03001oogoo0<eo
o`03001oogoo01moo`03001oogoo01Eoo`005Woo00<007ooOol0c7oo00<007ooOol087oo00<007oo
Ool05Goo000FOol00`00Oomoo`3;Ool00`00Oomoo`0QOol00`00Oomoo`0EOol001Moo`03001oogoo
0<Uoo`03001oogoo025oo`03001oogoo01Ioo`005goo00<007ooOol0b7oo00<007ooOol08Woo00<0
07ooOol05Woo000GOol00`00Oomoo`37Ool00`00Oomoo`0SOol00`00Oomoo`0FOol001Qoo`03001o
ogoo0<Eoo`03001oogoo02=oo`03001oogoo01Moo`0067oo00<007ooOol0aGoo00<007ooOol08goo
00<007ooOol05goo000IOol00`00Oomoo`33Ool00`00Oomoo`0SOol00`00Oomoo`0HOol001Yoo`03
001oogoo0<5oo`03001oogoo02=oo`03001oogoo01Uoo`006Woo00<007ooOol0`7oo00<007ooOol0
97oo00<007ooOol06Goo000KOol00`00Oomoo`2nOol00`00Oomoo`0TOol00`00Oomoo`0JOol001]o
o`03001oogoo0;eoo`03001oogoo02Eoo`03001oogoo01Yoo`0077oo00<007ooOol0^goo00<007oo
Ool09Goo00<007ooOol06goo000LOol00`00Oomoo`07Ool00`00Oomoo`2`Ool00`00Oomoo`0VOol0
0`00Oomoo`0KOol001eoo`03001oogoo00Moo`800:moo`03001oogoo02Ioo`03001oogoo01aoo`00
7Goo00<007ooOol02Goo0P00[7oo00<007ooOol09goo00<007ooOol077oo000NOol00`00Oomoo`0:
Ool2002YOol00`00Oomoo`0WOol00`00Oomoo`0MOol001ioo`03001oogoo00aoo`03001oogoo0:Eo
o`03001oogoo02Qoo`03001oogoo01eoo`007goo00<007ooOol037oo0P00Y7oo00<007ooOol0:7oo
00<007ooOol07Woo000OOol00`00Oomoo`04Ool2O008Ool2002ROol00`00Oomoo`0XOol00`00Oomo
o`0NOol0021oo`03001oogoo00Eoo`9l00Qoo`03001oogoo09ioo`03001oogoo02Qoo`03001oogoo
01moo`0087oo00<007ooOol01goo0W`01goo0P00WGoo00<007ooOol0:Goo00<007ooOol07goo000Q
Ool00`00Oomoo`08Ool2O007Ool2002JOol00`00Oomoo`0YOol00`00Oomoo`0POol0025oo`03001o
ogoo00Yoo`9l00Moo`8009Moo`03001oogoo02Yoo`03001oogoo021oo`008Woo00<007ooOol02goo
0W`01goo00<007ooOol0Tgoo00<007ooOol0:Woo00<007ooOol08Goo000SOol00`00Oomoo`0<Ool2
O006Ool2002BOol00`00Oomoo`0ZOol00`00Oomoo`0ROol002Aoo`03001oogoo00eoo`9l00Ioo`80
08moo`03001oogoo02Yoo`03001oogoo02=oo`0097oo00<007ooOol03goo0W`01Woo00<007ooOol0
Rgoo00<007ooOol04goo00<007ooOol05Goo00<007ooOol08goo000UOol00`00Oomoo`0@Ool3O004
Ool2002:Ool00`00Oomoo`0BOol2000GOol00`00Oomoo`0TOol002Ioo`03001oogoo019oo`9l00Ao
o`8008Moo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo02Eoo`009Woo00<007ooOol057oo
0W`017oo0P00Q7oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol09Goo
000WOol00`00Oomoo`0EOol2O004Ool00`00Oomoo`20Ool00`00Oomoo`0AOol20003Ool2000DOol0
0`00Oomoo`0VOol002Qoo`03001oogoo01Ioo`9l00=oo`80081oo`03001oogoo011oo`03001oogoo
009oo`03001oogoo01Aoo`03001oogoo02Ioo`00:7oo00<007ooOol067oo0W`00goo0P00OGoo00<0
07ooOol047oo00@007ooOomoo`8001Ioo`03001oogoo02Moo`00:Goo00<007ooOol06Goo0W`00goo
00<007ooOol0NGoo00<007ooOol03goo0P000goo00<007ooOol05Goo00<007ooOol0:7oo000YOol0
0`00Oomoo`0KOol2O002Ool2001hOol00`00Oomoo`0?Ool01000Oomoogoo0P0067oo00<007ooOol0
:7oo000ZOol00`00Oomoo`0LOol2O002Ool2001eOol00`00Oomoo`0?Ool01@00Oomoogoo00006Goo
00<007ooOol0:Goo000[Ool00`00Oomoo`0MOol2O002Ool2001bOol00`00Oomoo`0>Ool20002Ool2
000IOol00`00Oomoo`0ZOol002aoo`03001oogoo01ioo`=l0003Ool007oo06moo`03001oogoo00io
o`05001oogooOol0000JOol00`00Oomoo`0[Ool002eoo`03001oogoo021oo`9l008006eoo`03001o
ogoo00ioo`05001oogooOol0000JOol00`00Oomoo`0/Ool002ioo`03001oogoo025oo`9l008006Yo
o`03001oogoo00eoo`80009oo`8001Yoo`03001oogoo02eoo`00;goo00<007ooOol08Woo0W`00P00
Igoo00<007ooOol03Goo00D007ooOomoo`0001]oo`03001oogoo02ioo`00<7oo00<007ooOol08goo
0W`000<007ooOol0Hgoo00<007ooOol037oo0P000Woo0P006goo00<007ooOol0;goo000aOol00`00
Oomoo`0TOol00g`00000001ROol00`00Oomoo`0<Ool01@00Oomoogoo000077oo00<007ooOol0<7oo
000bOol00`00Oomoo`0UOol00g`00000001OOol00`00Oomoo`0<Ool00`00Oomoo`02000LOol00`00
Oomoo`0aOol003=oo`03001oogoo02Ioo`03O00007oo05eoo`03001oogoo00Yoo`80009oo`03001o
ogoo01]oo`03001oogoo039oo`00=7oo00<007ooOol09goo0P00Fgoo00<007ooOol02Woo00<007oo
Ool00P007Goo00<007ooOol0<goo000dOol00`00Oomoo`0YOol200000g`0Oomoo`1EOol00`00Oomo
o`0:Ool01000Oomoo`007goo00<007ooOol0<goo000eOol00`00Oomoo`0ZOol200000g`0Oomoo`1B
Ool00`00Oomoo`09Ool200000goo0000000OOol00`00Oomoo`0dOol003Ioo`8002aoo`03001l07`0
03Yoo`03001oogoo01Aoo`03001oogoo00Uoo`04001oogoo000OOol2000gOol003Qoo`03001oogoo
02Yoo`80009l03Qoo`03001oogoo01=oo`03001oogoo00Uoo`04001oo`00000OOol00`00Oomoo`0g
Ool003Uoo`03001oogoo02]oo`80009l03Ioo`03001oogoo019oo`03001oogoo00Qoo`800003Ool0
07oo01=oo`8000Yoo`03001oogoo03Qoo`00>Woo00<007ooOol0;7oo00@007ooO01l03Aoo`03001o
ogoo015oo`03001oogoo00Qoo`04001oo`00000COol3000:Ool00`00Oomoo`0iOol003]oo`03001o
ogoo02aoo`800003Ooml07`0035oo`03001oogoo015oo`03001oogoo00Moo`800003Ool007oo019o
o`<00003O01oogoo00Qoo`03001oogoo03Yoo`00?7oo00<007ooOol0;Goo0P0000=oog`0O000;goo
00<007ooOol047oo00<007ooOol01goo00@007oo0000015oo`@00003O01oogoo00Uoo`03001oogoo
03]oo`00?Goo0P00;goo0P0000=oog`0O000;Goo00<007ooOol03goo00<007ooOol01goo00<007oo
00004Goo100000=l07ooOol02Goo0P00?Woo000oOol00`00Oomoo`0^Ool00`00Oomoo`02O00[Ool0
0`00Oomoo`0>Ool00`00Oomoo`06Ool200000goo001oo`0>Ool5000=Ool00`00Oomoo`0nOol0041o
o`03001oogoo02ioo`80009oo`=l02Qoo`03001oogoo00eoo`03001oogoo00Eoo`800004Ool00000
000=Ool400000g`00000000<Ool00`00Oomoo`0oOol0045oo`03001oogoo02moo`8000=oo`9l02Io
o`03001oogoo00eoo`03001oogoo00Aoo`800004Ool00000000<Ool400000goo0000000=Ool00`00
Oomoo`10Ool0049oo`80035oo`8000=oo`9l02Aoo`03001oogoo00aoo`03001oogoo00=oo`H000]o
o`P0009l00]oo`8004=oo`00A7oo00<007ooOol0<7oo00<007ooOol00Woo0W`08Goo00<007ooOol0
37oo00<007ooOol00goo0P0000=oo`0000001Woo00<007ooOol00Woo20000W`037oo00<007ooOol0
@goo0015Ool2000aOol20004Ool2O00OOol00`00Oomoo`0;Ool00`00Oomoo`03Ool40006Ool20003
Ool400000goo00000003O00<Ool20016Ool004Moo`03001oogoo031oo`8000Aoo`9l01]oo`<000ao
o`03001oogoo009oo`@000Ioo`80009oo`P0009l00ioo`03001oogoo04Ioo`00B7oo00<007ooOol0
<Goo00<007ooOol00goo0W`067oo00@007ooOol000]oo`03001oogoo009oo`@000Eoo`80009oo`80
0003O0000000008000=l008000eoo`03001oogoo04Moo`00BGoo0P00<Woo0P001Goo0W`057oo0P00
0goo00<007ooOol027oo00@007ooOomoo`@000Eoo`800003Ool0000000H0009l00<000eoo`8004Yo
o`00Bgoo0P00<Woo0P001Goo0W`04Goo0P000goo0P0017oo0P000goo00@007ooOomoo`@000Eoo`05
001oo`00001l00040002O007000:Ool2001<Ool004eoo`80039oo`8000Eoo`=l00aoo`8000Eoo`80
0004Ool000000003Ool300000goo000000020005Ool400000g`00000000;000:Ool2001>Ool004mo
o`03001oogoo035oo`03001oogoo00Eoo`9l00Uoo`8000Ioo`<000Ioo`03001oogoo00@000Aoo`@0
0003O000000000X000aoo`03001oogoo04ioo`00D7oo00<007ooOol027oo10009Goo0P001goo0W`0
1Goo0`001Goo0`001goo00<007oo00000`0000Aoo`00Oomoo`<00003O000000000@00003Ool00000
00<000ioo`03001oogoo04moo`00DGoo0P0037oo2@007Woo0P001goo0W`00Woo0P0017oo0`000Woo
00<007ooOol017oo1P000goo0`0000=l000000000`0000=l000000000`003goo0P00DWoo001COol3
000AOol@000AOol00`00Oomoo`06Ool30003Ool20005Ool00`00Oomoo`03Ool60002Ool300000g`0
0000000200000g`000000003000?Ool3001DOol005Ioo`8001Ioo`P00003Ool0000000`000Aoo`80
00Eoo`<00004O00000000007Ool00`00Oomoo`02Ool50002Ool300000g`000000007000@Ool2001G
Ool005Qoo`8001aoo`L000Qoo`l00003Ooml07`000Mooa000003O000000000<0015oo`8005Uoo`00
FWoo0P002Woo1`000goo50002Goo10000goo0`000W`0200000=oo`0000003@004Woo0P00Fgoo001L
Ool3000>Ool>0009OolZ000BOol3001MOol005moo`<001Uoo`h00003Ool007oo01l0019oo`<0061o
o`00HWoo0`008goo8@0000=oo`00Ool03Woo0`00Hgoo001UOol3000MOol90002OolK000<Ool3001V
Ool006Qoo`<001Eoob8000Ioo`03001oo`0000Uoo`<006Uoo`00Jgoo0`005Woo00<007ooOol06000
4Woo0`00K7oo001^Ool3000GOol70006Ool7000BOol3001_Ool0075oo`D002=oo`03001oo`0000eo
o`D0079oo`00MWoo100087oo00<007ooOol027oo1000Mgoo001jOol8000KOol8001kOol0089ooa/0
08=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00:9oo`03001oogoo011oo`<0045oo`03001o
ogoo02Aoo`00XGoo00<007ooOol04Woo00<007ooOol0@Goo00<007ooOol08goo002QOol00`00Oomo
o`0BOol00`00Oomoo`11Ool00`00Oomoo`0SOol001moo`@000Aoo`D000Aoo`@0009oo`<00005Ool0
0000Ool0000;Ool3000017oo000000000Woo10000Woo0`0000Eoo`00001oo`00009oo`D000]oo`80
0004Ool000000004Ool3000017oo000007oo1@0017oo1@003goo00<007ooOol00goo1P000Woo1@00
0goo100017oo0`0000Aoo`00001oo`D000Eoo`<000Eoo`800004Ool00000Ool50004Ool50002Ool5
0009Ool00`00Oomoo`0ROol0021oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`0037oo00D007ooOomoo`00009oo`03001oogoo009oo`04001oogoo
0002Ool01P00Oomoo`00Ool0015oo`8000=oo`04001oogoo0003Ool20002Ool00`00Oomoo`02Ool0
1000Oomoo`0057oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Qoo`05001oogooOol0
0002Ool01000Oomoogoo0P000goo00<007ooOol01Goo00D007ooOomoo`0000=oo`03001oogoo0080
00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
029oo`0087oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo000<Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo
001oo`004Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo000DOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0027oo00D007ooOomoo`00009oo`03001oogoo
009oo`05001oogooOol00007Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol01Woo00<007ooOol08Woo000POol00`00Ool00005Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000aoo`05001oogooOol00002Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00D007ooOol007oo00H000aoo`03001oogoo009oo`04001o
ogooOol50003Ool40003Ool6000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`060003
Ool01@00Oomoogoo00000goo1@000goo00<007ooOol01Goo00<007ooOol01Goo00D007ooOomoo`00
00=oo`03001oogoo00Aoo`H000=oo`@000Uoo`03001oogoo029oo`0087oo0`001Goo0P001Goo00<0
07ooOol00Woo00<007ooOol00P0000Eoo`00001oo`0000aoo`80009oo`04001oogoo0004Ool00`00
Oomoo`0200001goo000007oo001oo`0000Aoo`03001oogoo00Yoo`8000=oo`04001oogoo0004Ool0
1000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00eoo`03001oogoo009oo`04001oogooOol2
0002Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOol000Aoo`04001oogooOol20006
Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo0P001Goo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00Ioo`03001oogoo029oo`0087oo00D007oo001oo`00009oo`800004Ool000000003
Ool40002Ool200001Goo001oogoo00003Goo00@007oo000000Aoo`@0009oo`800005Ool007ooOol0
0003Ool4000=Ool00`00Ool000020004Ool40004Ool50003Ool4000@Ool00`00Oomoo`03Ool30000
0goo001oo`02Ool40003Ool200000goo00000004Ool40003Ool2000017oo000000000Woo1P000Woo
0P000Woo0P000Woo0P0000Aoo`00000000=oo`@000Aoo`D000Qoo`03001oogoo029oo`0087oo00D0
07ooOomoo`0002Eoo`03001oogoo02Ioo`03001oogoo02]oo`03001oogoo00Ioo`03001oogoo025o
o`03001oogoo02Uoo`03001oogoo02=oo`007goo1P009Goo00<007ooOol09Woo00<007ooOol0:goo
00<007ooOol01Woo00<007ooOol08Goo00<007ooOol0:Goo00<007ooOol08goo0019Ool2000WOol2
000^Ool00`00Oomoo`04Ool2001>Ool00`00Oomoo`0TOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-376.995, -363.004, 2.48777, \
2.79875}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[" ",
        FontColor->GrayLevel[0]], 
      StyleBox[\(graph3 = \ 
            See[SpeedPairPlot2[To[{10, 350}, 50]], 
              PlotLabel -> 
                StyleForm["\<To home base (arrivals)\>", FontSize -> 14]];\),
        FontColor->GrayLevel[0]], 
      StyleBox["\n",
        FontColor->RGBColor[0.996109, 0, 0]], 
      StyleBox["\n",
        FontColor->RGBColor[0.996109, 0, 0]]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -98.3125 0 ]
[.5 1.0125 98.3125 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -159.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(To) show
88.125 13.750 moveto
(home) show
130.000 13.750 moveto
(base) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.875 13.750 moveto
(H) show
180.250 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arrivals) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
247.250 13.750 moveto
(L) show
255.625 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.6369 .9246 m
.55804 .94841 L
s
.3497 .93254 m
.52083 .95503 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.62202 .93386 m
.55952 .94841 L
s
.54762 .94577 m
.53869 .94048 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.4628 .95635 m
.51786 .95503 L
s
.72768 .87566 m
.55952 .94841 L
s
.5506 .94577 m
.55952 .89021 L
s
.4375 .94974 m
.48958 .95767 L
s
.48512 .96032 m
.50595 .95503 L
s
.79762 .83862 m
.55952 .94444 L
s
.55208 .94048 m
.54613 .93915 L
s
1 0 0 r
.3244 .92063 m
.52083 .94974 L
s
0 0 0 r
.5253 .94709 m
.61161 .93783 L
s
1 0 0 r
.81994 .75794 m
.56845 .94841 L
s
.79911 .75926 m
.55952 .94444 L
s
.11012 .73413 m
.50149 .95635 L
s
0 0 0 r
.50744 .95503 m
.51637 .95503 L
s
.53423 .96032 m
.54167 .96693 L
s
.54315 .95767 m
.5506 .95503 L
s
1 0 0 r
.94643 .59656 m
.59673 .94048 L
s
0 0 0 r
.58929 .94577 m
.59077 .94841 L
s
.59077 .9537 m
.58631 .94312 L
s
.58482 .94841 m
.58482 .94577 L
s
.66964 .87302 m
.55804 .9418 L
s
.55506 .93783 m
.55952 .89153 L
s
.47619 .95899 m
.52083 .95503 L
s
.52679 .95635 m
.53571 .96296 L
s
1 0 0 r
.7872 .55159 m
.61012 .93783 L
s
0 0 0 r
.60119 .93915 m
.52679 .93915 L
s
1 0 0 r
.22768 .82011 m
.51637 .95503 L
s
0 0 0 r
.50893 .95635 m
.49554 .95503 L
s
.5 .95503 m
.52381 .95767 L
s
.53274 .96032 m
.57589 .9418 L
s
.56994 .94841 m
.56845 .94841 L
s
1 0 0 r
.81548 .7619 m
.55952 .9418 L
s
0 0 0 r
.55655 .94444 m
.58333 .92725 L
s
.44345 .89815 m
.52083 .94444 L
s
.52827 .95635 m
.5372 .96429 L
s
1 0 0 r
.58482 .73942 m
.49107 .95635 L
s
0 0 0 r
.49256 .95899 m
.52083 .95106 L
s
.5253 .94841 m
.54167 .94048 L
s
.79464 .84392 m
.55655 .94841 L
s
.54911 .95635 m
.54613 .96164 L
s
.22173 .81217 m
.5119 .95503 L
s
1 0 0 r
.86756 .26323 m
.60565 .94048 L
s
0 0 0 r
.59375 .94048 m
.58482 .94312 L
s
.5878 .94444 m
.5878 .94841 L
s
.5878 .94974 m
.59524 .9418 L
s
1 0 0 r
.24256 .88757 m
.5 .95767 L
s
0 0 0 r
.49256 .95635 m
.51935 .95106 L
s
.52679 .95635 m
.5372 .96561 L
s
1 0 0 r
.97024 .53968 m
.56101 .94841 L
s
0 0 0 r
.81548 .76323 m
.5744 .94048 L
s
.57292 .94048 m
.59821 .94048 L
s
.35714 .91005 m
.50149 .95635 L
s
.52827 .95635 m
.5372 .96429 L
s
.54464 .95635 m
.54911 .9537 L
s
1 0 0 r
.55655 .18122 m
.6131 .92328 L
s
0 0 0 r
.59673 .90741 m
.5878 .90741 L
s
.58185 .90476 m
.49256 .93783 L
s
1 0 0 r
.60714 .14815 m
.56696 .93783 L
s
0 0 0 r
.55506 .9418 m
.54762 .95503 L
s
1 0 0 r
.85417 .25265 m
.60268 .92196 L
s
0 0 0 r
.59673 .92328 m
.48065 .94974 L
s
.47768 .95899 m
.49702 .95767 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.50893 .94974 m
.52381 .95503 L
s
.52827 .95238 m
.53274 .95635 L
s
.71875 .89418 m
.61756 .93783 L
s
.5997 .94312 m
.60119 .9537 L
s
.5997 .94974 m
.56101 .94841 L
s
.67113 .85979 m
.56399 .94048 L
s
1 0 0 r
.10565 .50529 m
.58036 .93254 L
s
0 0 0 r
.44196 .95503 m
.52679 .95503 L
s
.52976 .95767 m
.5372 .96429 L
s
.29762 .8955 m
.5997 .93651 L
s
.59673 .94048 m
.5878 .94048 L
s
.58185 .9418 m
.57143 .94709 L
s
.54167 .94048 m
.47321 .95899 L
s
.7381 .87566 m
.55655 .95238 L
s
.38839 .86376 m
.50446 .95635 L
s
.51042 .95503 m
.52976 .95503 L
s
.53571 .95767 m
.53869 .96296 L
s
1 0 0 r
.83482 .56614 m
.54911 .93915 L
s
0 0 0 r
.54167 .93783 m
.4747 .95899 L
s
.47619 .95238 m
.47768 .94841 L
s
.48065 .94841 m
.47917 .9537 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0023OolI0024Ool007]oo`P0
01Uoo`P007aoo`00MGoo1P00:Goo1P00MWoo001bOol3000eOol3001cOol006eoo`D003]oo`D006io
o`00JWoo0`00AGoo0`00Jgoo001WOol3001;Ool2001YOol006Eoo`80051oo`@006Eoo`00HWoo0`00
EWoo0P00Hgoo001OOol3001KOol3001POol005aoo`<0065oo`<005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Ioo`8006moo`8005Moo`00E7oo0P00Lgoo0P00EGoo001COol00`00
Oomoo`1eOol2001COol0055oo`8007Yoo`80055oo`00Cgoo0P00OWoo00<007ooOol0CWoo001=Ool2
0021Ool2001>Ool004]oo`8008Eoo`03001oogoo04]oo`00BGoo0P00R7oo0P00Bgoo0018Ool00`00
Oomoo`2:Ool20019Ool004Moo`03001oogoo08eoo`03001oogoo04Ioo`00AGoo0P00TGoo0P00AWoo
0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0049oo`8009Moo`8004=oo`00@Goo00<007ooOol0
VGoo00<007ooOol0@7oo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003moo`03001oogoo09eo
o`03001oogoo03ioo`00?Goo0P00XGoo0P00?Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol0
03]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo00<007ooOol0>Goo000i
Ool00`00Oomoo`2YOol2000iOol003Qoo`03001oogoo075oo`03O01oogoo03Qoo`03001oogoo03Io
o`00=Woo0P00M7oo00=l07ooOol0>Goo00<007ooOol0=Goo000eOol00`00Oomoo`1dOol00g`0Oomo
o`0jOol00`00Oomoo`0dOol003Aoo`03001oogoo07Eoo`03O01oogoo03]oo`03001oogoo03=oo`00
=7oo00<007ooOol0MGoo00=l07ooOol0>goo00<007ooOol0<goo000cOol00`00Oomoo`1fOol00g`0
Oomoo`0lOol00`00Oomoo`0bOol0039oo`03001oogoo07Moo`03O01oogoo03eoo`03001oogoo035o
o`00<Goo00<007ooOol0N7oo00=l07ooOol0?Woo00<007ooOol0<7oo000`Ool00`00Oomoo`1[Ool0
0g`0Oomoo`0;Ool00g`0Oomoo`0oOol00`00Oomoo`0_Ool002moo`03001oogoo06aoo`03O01oogoo
00]oo`03O01oogoo041oo`03001oogoo02ioo`00;Woo00<007ooOol0KGoo00=l07ooOol02Woo00=l
07ooOol0@Woo00<007ooOol0;Goo000]Ool00`00Oomoo`1^Ool00g`0Oomoo`0:Ool00g`0Oomoo`13
Ool00`00Oomoo`0/Ool002aoo`03001oogoo06moo`03O01oogoo00Yoo`03O01oogoo04Aoo`03001o
ogoo02]oo`00:goo00<007ooOol0L7oo00=l07ooOol02Woo00=l07ooOol0AGoo00<007ooOol0:Woo
000ZOol00`00Oomoo`1aOol00g`0Oomoo`0:Ool00g`0Oomoo`16Ool00`00Oomoo`0YOol002Uoo`03
001oogoo07=oo`03O01oogoo00Uoo`03O01oogoo04Moo`03001oogoo02Qoo`00:Goo00<007ooOol0
Lgoo00=l07ooOol02Goo00=l07ooOol0Agoo00<007ooOol0:7oo000XOol00`00Oomoo`1dOol00g`0
Oomoo`09Ool00g`0Oomoo`18Ool00`00Oomoo`0WOol002Qoo`03001oogoo07Aoo`03O01oogoo00Uo
o`03O01oogoo04Uoo`03001oogoo02Ioo`009goo00<007ooOol0MGoo00=l07ooOol02Goo00=l07oo
Ool0BGoo00<007ooOol09Woo000VOol00`00Oomoo`1fOol00g`0Oomoo`09Ool00g`0Oomoo`1:Ool0
0`00Oomoo`0UOol002Ioo`03001oogoo07Ioo`03O01oogoo00Uoo`03O01oogoo04Yoo`03001oogoo
02Eoo`009Goo00<007ooOol0Mgoo00=l07ooOol02Goo00=l07ooOol0Bgoo00<007ooOol097oo000T
Ool00`00Oomoo`1hOol00g`0Oomoo`09Ool00g`0Oomoo`1<Ool00`00Oomoo`0SOol002Aoo`03001o
ogoo07Qoo`03O01oogoo00Uoo`03O01oogoo04aoo`03001oogoo02=oo`008goo00<007ooOol0NGoo
00=l07ooOol02Goo00=l07ooOol0CGoo00<007ooOol08Woo000ROol00`00Oomoo`1jOol00g`0Oomo
o`09Ool00g`0Oomoo`1>Ool00`00Oomoo`0QOol0025oo`03001oogoo07aoo`03O01oogoo00Qoo`03
O01oogoo04ioo`03001oogoo025oo`008Goo00<007ooOol0O7oo00=l07ooOol027oo00=l07ooOol0
@Goo00=l07ooOol02goo00<007ooOol087oo000POol00`00Oomoo`1mOol00g`0Oomoo`08Ool00g`0
Oomoo`11Ool00g`0Oomoo`0<Ool00`00Oomoo`0OOol0021oo`03001oogoo07eoo`03O01oogoo00Mo
o`03O01oogoo045oo`03O01oogoo00eoo`03001oogoo01moo`007goo00<007ooOol0OWoo00=l07oo
Ool01goo00=l07ooOol0@Goo00El07ooOomoog`000aoo`03001oogoo01ioo`007goo00<007ooOol0
OWoo00=l07ooOol01goo00=l07ooOol0@7oo00=l07ooOol00Woo00=l07ooOol02Woo00<007ooOol0
7Woo000NOol00`00Oomoo`1oOol00g`0Oomoo`07Ool00g`0Oomoo`10Ool01G`0OomoogooO0003Woo
00<007ooOol07Goo000NOol00`00Oomoo`1oOol00g`0Oomoo`07Ool00g`0Oomoo`10Ool01G`0Oomo
ogooO0003Woo00<007ooOol07Goo000MOol00`00Oomoo`20Ool00g`0Oomoo`07Ool00g`0Oomoo`0o
Ool01G`0OomoogooO00047oo00<007ooOol077oo000MOol00`00Oomoo`20Ool00g`0Oomoo`07Ool0
0g`0Oomoo`0oOol01G`0OomoogooO00047oo00<007ooOol077oo000LOol00`00Oomoo`21Ool00g`0
Oomoo`07Ool00g`0Oomoo`0oOol01G`0OomoogooO0004Goo00<007ooOol06goo000LOol00`00Oomo
o`21Ool00g`0Oomoo`07Ool00g`0Oomoo`0nOol01G`0OomoogooO0004Woo00<007ooOol06goo000K
Ool00`00Oomoo`22Ool00g`0Oomoo`07Ool00g`0Oomoo`0nOol01G`0OomoogooO0004goo00<007oo
Ool06Woo000KOol00`00Oomoo`23Ool00g`0Oomoo`06Ool00g`0Oomoo`0mOol00g`0Oomoo`02Ool0
0g`0Oomoo`0AOol00`00Oomoo`0JOol001Yoo`03001oogoo08Aoo`03O01oogoo00Ioo`03O01oogoo
03eoo`05O01oogooOoml000EOol00`00Oomoo`0IOol001Yoo`03001oogoo08Aoo`03O01oogoo00Io
o`03O01oogoo03eoo`05O01oogooOoml000EOol00`00Oomoo`0IOol001Uoo`03001oogoo08Eoo`03
O01oogoo00Ioo`03O01oogoo03aoo`05O01oogooOoml000GOol00`00Oomoo`0HOol001Uoo`03001o
ogoo08Eoo`03O01oogoo00Ioo`03O01oogoo03aoo`05O01oogooOoml000GOol00`00Oomoo`0HOol0
01Qoo`03001oogoo08Ioo`03O01oogoo00Ioo`03O01oogoo03aoo`05O01oogooOoml000HOol00`00
Oomoo`0GOol001Qoo`03001oogoo08Ioo`03O01oogoo00Ioo`03O01oogoo03]oo`05O01oogooOoml
000IOol00`00Oomoo`0GOol001Moo`03001oogoo08Moo`03O01oogoo00Ioo`03O01oogoo03]oo`05
O01oogooOoml000JOol00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03O01oogoo00Ioo`03O01o
ogoo03Yoo`05O01oogooOoml000KOol00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03O01oogoo
00Eoo`03O01oogoo03]oo`05O01oogooOoml000KOol00`00Oomoo`0FOol001Ioo`03001oogoo08Qo
o`03O01oogoo00Eoo`03O01oogoo03]oo`05O01oogooOoml000LOol00`00Oomoo`0EOol001Ioo`03
001oogoo08Qoo`03O01oogoo00Eoo`03O01oogoo03Yoo`05O01oogooOoml000MOol00`00Oomoo`0E
Ool001Ioo`03001oogoo08Uoo`03O01oogoo00Aoo`03O01oogoo03Yoo`05O01oogooOoml000MOol0
0`00Oomoo`0EOol001Ioo`03001oogoo08Uoo`03O01oogoo00Aoo`03O01oogoo03Yoo`05O01oogoo
Ooml000NOol00`00Oomoo`0DOol001Eoo`03001oogoo08Yoo`03O01oogoo00Aoo`03O01oogoo03Uo
o`05O01oogooOoml000OOol00`00Oomoo`0DOol001Eoo`03001oogoo08Yoo`03O01oogoo00Aoo`03
O01oogoo03Uoo`05O01oogooOoml000OOol00`00Oomoo`0DOol001Eoo`03001oogoo08Yoo`03O01o
ogoo00Aoo`03O01oogoo03Qoo`05O01oogooOoml000QOol00`00Oomoo`0COol001Aoo`03001oogoo
08]oo`03O01oogoo00Aoo`03O01oogoo03Qoo`05O01oogooOoml000QOol00`00Oomoo`0COol001Ao
o`03001oogoo08]oo`03O01oogoo00Aoo`03O01oogoo03Qoo`05O01oogooOoml000QOol00`00Oomo
o`0COol001Aoo`03001oogoo08]oo`03O01oogoo00Aoo`03O01oogoo03Moo`05O01oogooOoml000S
Ool00`00Oomoo`0BOol001=oo`03001oogoo08aoo`03O01oogoo00Aoo`03O01oogoo03Moo`05O01o
ogooOoml000SOol00`00Oomoo`0BOol001=oo`03001oogoo08aoo`03O01oogoo00Aoo`03O01oogoo
03Moo`05O01oogooOoml000SOol00`00Oomoo`0BOol001=oo`03001oogoo08aoo`03O01oogoo00Ao
o`03O01oogoo03Ioo`05O01oogooOoml000UOol00`00Oomoo`0AOol0019oo`03001oogoo08eoo`03
O01oogoo00Aoo`03O01oogoo03Ioo`05O01oogooOoml000UOol00`00Oomoo`0AOol0019oo`03001o
ogoo08eoo`03O01oogoo00Aoo`03O01oogoo03Eoo`05O01oogooOoml000VOol00`00Oomoo`0AOol0
019oo`03001oogoo08ioo`03O01oogoo00=oo`03O01oogoo03Eoo`05O01oogooOoml000VOol00`00
Oomoo`0AOol0019oo`03001oogoo08ioo`03O01oogoo00=oo`03O01oogoo03Eoo`05O01oogooOoml
000VOol00`00Oomoo`0AOol0015oo`03001oogoo08moo`03O01oogoo00=oo`03O01oogoo03Aoo`05
O01oogooOoml000XOol00`00Oomoo`0@Ool0015oo`03001oogoo08moo`03O01oogoo009oo`03O01o
ogoo03Eoo`05O01oogooOoml000XOol00`00Oomoo`0@Ool0015oo`03001oogoo08moo`03O01oogoo
009oo`03O01oogoo03Eoo`04O01oogooO00YOol00`00Oomoo`0@Ool0015oo`03001oogoo08moo`03
O01oogoo009oo`03O01oogoo03Aoo`05O01oogooOoml000YOol00`00Oomoo`0@Ool0015oo`03001o
ogoo08moo`03O01oogoo009oo`03O01oogoo03Aoo`05O01oogooOoml000YOol00`00Oomoo`0@Ool0
011oo`03001oogoo091oo`03O01oogoo009oo`03O01oogoo03=oo`05O01oogooOoml000[Ool00`00
Oomoo`0?Ool0011oo`03001oogoo091oo`03O01oogoo009oo`03O01oogoo03=oo`05O01oogooOoml
000[Ool00`00Oomoo`0?Ool0011oo`03001oogoo091oo`03O01oogoo009oo`03O01oogoo03=oo`05
O01oogooOoml000[Ool00`00Oomoo`0?Ool0011oo`03001oogoo091oo`03O01oogoo009oo`03O01o
ogoo039oo`05O01oogooOoml000/Ool00`00Oomoo`0?Ool0011oo`03001oogoo091oo`03O01oogoo
009oo`03O01oogoo039oo`05O01oogooOoml000/Ool00`00Oomoo`0?Ool0011oo`03001oogoo091o
o`03O01oogoo009oo`03O01oogoo039oo`04O01oogooO00]Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo095oo`05O01oogooOoml000cOol01G`0OomoogooO000;Woo00<007ooOol03Woo000?Ool00`00
Oomoo`2BOol01G`0OomoogooO000<goo00El07ooOomoog`002ioo`03001oogoo00ioo`003goo00<0
07ooOol0TWoo00El07ooOomoog`0039oo`05O01oogooOoml000_Ool00`00Oomoo`0>Ool000moo`03
001oogoo099oo`05O01oogooOoml000bOol01G`0OomoogooO000;goo00<007ooOol03Woo000?Ool0
0`00Oomoo`2BOol01G`0OomoogooO000<Woo00Al07ooOoml031oo`03001oogoo00ioo`003goo00<0
07ooOol0TWoo00El07ooOomoog`0035oo`05O01oogooOoml000`Ool00`00Oomoo`0>Ool000moo`03
001oogoo099oo`05O01oogooOoml000aOol01G`0OomoogooO000<7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`2BOol01G`0OomoogooO000<Goo00Al07ooOoml035oo`03001oogoo00ioo`003goo00<0
07ooOol0TWoo00El07ooOomoog`0031oo`05O01oogooOoml000aOol00`00Oomoo`0>Ool000moo`03
001oogoo099oo`05O01oogooOoml000`Ool01G`0OomoogooO000<Goo00<007ooOol03Woo000?Ool0
0`00Oomoo`2BOol017`0Oomoog`0<7oo00El07ooOomoog`0039oo`03001oogoo00ioo`003goo00<0
07ooOol0TWoo00Al07ooOoml031oo`05O01oogooOoml000cOol00`00Oomoo`0=Ool000ioo`03001o
ogoo09Aoo`03O01oog`0031oo`04O01oogooO00dOol00`00Oomoo`0=Ool000ioo`03001oogoo09Ao
o`03O01oog`002moo`05O01oogooOoml000dOol00`00Oomoo`0=Ool000ioo`03001oogoo09Aoo`03
O01oog`002moo`05O01oogooOoml000dOol00`00Oomoo`0=Ool000ioo`03001oogoo09Aoo`03O01o
og`002moo`04O01oogooO00eOol00`00Oomoo`0=Ool000ioo`03001oogoo09Aoo`03O01oog`002io
o`05O01oogooOoml000eOol00`00Oomoo`0=Ool000ioo`03001oogoo09Aoo`03O01oog`002ioo`05
O01oogooOoml000eOol00`00Oomoo`0=Ool000ioo`03001oogoo01=oo`03O01oogoo07ioo`03O01o
og`002eoo`05O01oogooOoml000fOol00`00Oomoo`0=Ool000ioo`03001oogoo01Aoo`03O01oogoo
07eoo`03O01oog`002eoo`05O01oogooOoml000fOol00`00Oomoo`0=Ool000ioo`03001oogoo01Eo
o`03O01oogoo07aoo`03O01oog`002eoo`04O01oogooO00gOol00`00Oomoo`0=Ool000ioo`03001o
ogoo01Ioo`03O01oogoo07]oo`03O01oog`002aoo`05O01oogooOoml000gOol00`00Oomoo`0=Ool0
00moo`03001oogoo01Ioo`9l07]oo`03O01oog`002aoo`05O01oogooOoml000gOol00`00Oomoo`0=
Ool000moo`03001oogoo01Qoo`03O01oogoo07Qoo`03O01oog`002aoo`04O01oogooO00gOol00`00
Oomoo`0>Ool000moo`03001oogoo01Uoo`03O01oogoo07Moo`03O01oog`002]oo`05O01oogooOoml
000gOol00`00Oomoo`0>Ool000moo`03001oogoo01Yoo`03O01oogoo07Moo`9l02]oo`04O01oogoo
O00hOol00`00Oomoo`0>Ool000moo`03001oogoo01]oo`03O01oogoo07Ioo`9l02Yoo`05O01oogoo
Ooml000hOol00`00Oomoo`0>Ool000moo`03001oogoo01aoo`03O01oogoo07Eoo`9l02Yoo`05O01o
ogooOoml000gOol00g`0001oo`0?Ool000moo`03001oogoo01eoo`03O01oogoo07Aoo`9l02Yoo`04
O01oogooO00gOol00g`0Ool0000@Ool000moo`03001oogoo01ioo`03O01oogoo07=oo`03O01oogoo
02Qoo`05O01oogooOoml000fOol017`0Oomoo`0047oo000?Ool00`00Oomoo`0<Ool00g`0Oomoo`0@
Ool2O01cOol00g`0Oomoo`0XOol01G`0OomoogooO0001goo00=l07ooOol0:goo00El07ooOomoo`00
011oo`003goo00<007ooOol03Goo00=l07ooOol04Goo00=l07ooOol0L7oo00=l07ooOol0:7oo00Al
07ooOoml00Qoo`03O01oogoo02Yoo`03O01oogoo009oo`03001oogoo00ioo`003goo00<007ooOol0
3Woo00=l07ooOol04Goo00=l07ooOol0Kgoo00=l07ooOol09goo00El07ooOomoog`000Moo`03O01o
ogoo02Yoo`03O01oogoo00=oo`03001oogoo00ioo`003goo00<007ooOol03goo00=l07ooOol04Goo
00=l07ooOol0KWoo00=l07ooOol09goo00Al07ooOoml00Qoo`03O01oogoo02Uoo`03O01oogoo00Ao
o`03001oogoo00ioo`0047oo00<007ooOol03goo00=l07ooOol04Goo00=l07ooOol0KGoo00=l07oo
Ool09Woo00El07ooOomoog`000Moo`03O01oogoo00]oo`03O01oogoo01]oo`03O01oogoo00Aoo`03
001oogoo00moo`0047oo00<007ooOol047oo00=l07ooOol04Goo00=l07ooOol0K7oo00=l07ooOol0
9Woo00El07ooOomoog`000Moo`03O01oogoo00Yoo`03O01oogoo01]oo`03O01oogoo00Eoo`03001o
ogoo00moo`0047oo00<007ooOol04Goo00=l07ooOol04Goo00=l07ooOol0Jgoo00=l07ooOol09Woo
00Al07ooOoml00Moo`03O01oogoo00Yoo`03O01oogoo01]oo`03O01oogoo00Ioo`03001oogoo00mo
o`0047oo00<007ooOol04Woo00=l07ooOol04Goo00=l07ooOol0JWoo0W`09Woo00El07ooOomoog`0
00Moo`03O01oogoo00Yoo`03O01oogoo01Yoo`03O01oogoo00Moo`03001oogoo00moo`0047oo00<0
07ooOol04goo00=l07ooOol04Goo00=l07ooOol0JGoo0W`09Woo00Al07ooOoml00Moo`03O01oogoo
00Yoo`03O01oogoo01Yoo`03O01oogoo00Qoo`03001oogoo00moo`0047oo00<007ooOol057oo00=l
07ooOol04Goo0W`0JGoo0W`09Woo00Al07ooOoml00Moo`03O01oogoo00Uoo`03O01oogoo01Yoo`03
O01oogoo00Uoo`03001oogoo00moo`004Goo00<007ooOol057oo00=l07ooOol04Woo00=l07ooOol0
IWoo0W`09Goo00El07ooOomoog`000Ioo`03O01oogoo00Uoo`03O01oogoo01Yoo`03O01oogoo00Uo
o`03001oogoo011oo`004Goo00<007ooOol05Goo00=l07ooOol04Woo00=l07ooOol0IGoo0W`09Goo
00Al07ooOoml00Moo`03O01oogoo00Uoo`03O01oogoo01Uoo`03O01oogoo00Yoo`03001oogoo011o
o`004Goo00<007ooOol05Woo00=l07ooOol04Woo00=l07ooOol0I7oo0W`097oo00El07ooOomoog`0
00Moo`03O01oogoo00Qoo`03O01oogoo01Uoo`03O01oogoo00]oo`03001oogoo011oo`004Goo00<0
07ooOol05goo00=l07ooOol04Woo00=l07ooOol0Hgoo0W`097oo00El07ooOomoog`000Ioo`03O01o
ogoo00Qoo`03O01oogoo01Uoo`03O01oogoo00Moo`03O01oogoo009oo`03001oogoo011oo`004Goo
00<007ooOol067oo0W`04goo00=l07ooOol0HWoo0W`097oo00Al07ooOoml00Moo`03O01oogoo00Mo
o`03O01oogoo01Uoo`03O01oogoo00Moo`03O01oogoo00=oo`03001oogoo011oo`004Woo00<007oo
Ool06Goo00=l07ooOol04Goo00=l07ooOol0HGoo0W`08goo00El07ooOomoog`000Ioo`03O01oogoo
00Qoo`03O01oogoo01Qoo`03O01oogoo00Moo`03O01oogoo00=oo`03001oogoo015oo`004Woo00<0
07ooOol06Woo00=l07ooOol04Goo00=l07ooOol0H7oo0W`08goo00Al07ooOoml00Moo`03O01oogoo
00Moo`03O01oogoo01Qoo`03O01oogoo00Moo`03O01oogoo00Aoo`03001oogoo015oo`004Woo00<0
07ooOol06goo00=l07ooOol04Goo0W`0H7oo0W`08goo00Al07ooOoml00Ioo`03O01oogoo00Moo`03
O01oogoo01Qoo`03O01oogoo00Moo`03O01oogoo00Eoo`03001oogoo015oo`004Woo00<007ooOol0
77oo00=l07ooOol04Woo00=l07ooOol0G7oo00=l07ooO0008Woo00El07ooOomoog`000Ioo`03O01o
ogoo00Ioo`03O01oogoo01Qoo`03O01oogoo00Moo`03O01oogoo00Ioo`03001oogoo015oo`004goo
00<007ooOol077oo00=l07ooOol04Woo00=l07ooOol0Fgoo00=l07ooO0008Woo00Al07ooOoml00Io
o`03O01oogoo00Moo`03O01oogoo01Moo`03O01oogoo00Moo`03O01oogoo00Moo`03001oogoo015o
o`004goo00<007ooOol07Goo00=l07ooOol04Woo00=l07ooOol0FWoo00Al07ooOoml021oo`05O01o
ogooOoml0006Ool00g`0Oomoo`06Ool00g`0Oomoo`0GOol00g`0Oomoo`07Ool00g`0Oomoo`07Ool0
0`00Oomoo`0BOol001=oo`03001oogoo01ioo`03O01oogoo019oo`03O01oogoo05Uoo`04O01oogoo
O00POol01G`0OomoogooO0001Goo00=l07ooOol01Woo00=l07ooOol05goo00=l07ooOol01goo00=l
07ooOol027oo00<007ooOol04Woo000DOol00`00Oomoo`0NOol00g`0Oomoo`0BOol00g`0Oomoo`1H
Ool017`0Oomoog`087oo00Al07ooOoml00Ioo`03O01oogoo00Eoo`03O01oogoo01Moo`03O01oogoo
00Moo`03O01oogoo00Uoo`03001oogoo019oo`0057oo00<007ooOol07goo00=l07ooOol04Woo00=l
07ooOol0Egoo00Al07ooOoml01moo`05O01oogooOoml0005Ool00g`0Oomoo`06Ool00g`0Oomoo`0F
Ool00g`0Oomoo`07Ool00g`0Oomoo`09Ool00`00Oomoo`0COol001Aoo`03001oogoo021oo`03O01o
ogoo019oo`03O01oogoo05Ioo`04O01oogooO00OOol017`0Oomoog`01Woo00=l07ooOol01Goo00=l
07ooOol05Woo00=l07ooOol01goo00=l07ooOol02Woo00<007ooOol04goo000EOol00`00Oomoo`0P
Ool00g`0Oomoo`0BOol2O01FOol017`0Oomoog`07goo00Al07ooOoml00Ioo`03O01oogoo00Aoo`03
O01oogoo01Ioo`03O01oogoo00Moo`03O01oogoo00]oo`03001oogoo01=oo`005Goo00<007ooOol0
8Goo00=l07ooOol04goo00=l07ooOol0Dgoo00Al07ooOoml01ioo`05O01oogooOoml0005Ool00g`0
Oomoo`04Ool00g`0Oomoo`0FOol00g`0Oomoo`07Ool00g`0Oomoo`0;Ool00`00Oomoo`0DOol001Eo
o`03001oogoo029oo`03O01oogoo01=oo`03O01oogoo059oo`04O01oogooO00NOol017`0Oomoog`0
1Woo00=l07ooOol00goo00=l07ooOol05Woo00=l07ooOol01goo00=l07ooOol037oo00<007ooOol0
57oo000EOol00`00Oomoo`0SOol00g`0Oomoo`0COol00g`0Oomoo`1AOol017`0Oomoog`07Goo00El
07ooOomoog`000Eoo`03O01oogoo00Aoo`03O01oogoo01Eoo`03O01oogoo00Moo`03O01oogoo00eo
o`03001oogoo01Aoo`005Goo00<007ooOol097oo00=l07ooOol04goo00=l07ooOol0D7oo00Al07oo
Ooml01eoo`04O01oogooO006Ool00g`0Oomoo`03Ool00g`0Oomoo`0EOol00g`0Oomoo`07Ool00g`0
Oomoo`0>Ool00`00Oomoo`0DOol001Ioo`03001oogoo02Aoo`03O01oogoo01=oo`03O01oogoo04mo
o`04O01oogooO00MOol017`0Oomoog`01Goo00=l07ooOol00goo00=l07ooOol05Goo00=l07ooOol0
1goo00=l07ooOol03Woo00<007ooOol05Goo000FOol00`00Oomoo`0UOol00g`0Oomoo`0COol00g`0
Oomoo`1>Ool017`0Oomoog`077oo00El07ooOomoog`000Eoo`03O01oogoo009oo`03O01oogoo01Eo
o`03O01oogoo00Moo`03O01oogoo00moo`03001oogoo01Eoo`005Woo00<007ooOol09Woo00=l07oo
Ool04goo00=l07ooOol0CGoo00El07ooOomoog`001]oo`04O01oogooO005Ool00g`0Oomoo`03Ool0
0g`0Oomoo`0DOol00g`0Oomoo`07Ool00g`0Oomoo`0@Ool00`00Oomoo`0EOol001Moo`03001oogoo
02Ioo`03O01oogoo01=oo`9l04eoo`05O01oogooOoml000KOol017`0Oomoog`01Goo00=l07ooOol0
0Woo00=l07ooOol057oo00=l07ooOol01goo00=l07ooOol047oo00<007ooOol05Woo000GOol00`00
Oomoo`0WOol00g`0Oomoo`0DOol00g`0Oomoo`1:Ool01G`0OomoogooO0006Woo00El07ooOomoog`0
00Aoo`03O01oogoo009oo`03O01oogoo01Aoo`03O01oogoo00Moo`03O01oogoo015oo`03001oogoo
01Ioo`005goo00<007ooOol0:7oo00=l07ooOol057oo00=l07ooOol0BGoo00El07ooOomoog`001Yo
o`04O01oogooO005Ool01G`0OomoogooO0005Woo00=l07ooOol01goo00=l07ooOol04Woo00<007oo
Ool05Woo000HOol00`00Oomoo`0XOol00g`0Oomoo`0DOol00g`0Oomoo`18Ool01G`0OomoogooO000
6Goo00El07ooOomoog`000Eoo`05O01oogooOoml000EOol00g`0Oomoo`06Ool2O00DOol00`00Oomo
o`0GOol001Qoo`03001oogoo02Uoo`03O01oogoo01Aoo`03O01oogoo04Moo`05O01oogooOoml000I
Ool017`0Oomoog`01Goo00El07ooOomoog`001Eoo`03O01oogoo00Ioo`03O01oogoo01Aoo`03001o
ogoo01Moo`006Goo00<007ooOol0:Goo00=l07ooOol057oo00=l07ooOol0AGoo00=l07ooOol00Woo
00=l07ooOol05goo00Al07ooOoml00Eoo`04O01oogooO00EOol00g`0Oomoo`06Ool00g`0Oomoo`0D
Ool00`00Oomoo`0HOol001Yoo`03001oogoo02Uoo`03O01oogoo01Aoo`03O01oogoo04Aoo`03O01o
ogoo009oo`03O01oogoo01Ioo`05O01oogooOoml0004Ool017`0Oomoog`05Goo00=l07ooOol01Woo
00=l07ooOol057oo00<007ooOol06Goo000JOol00`00Oomoo`0ZOol00g`0Oomoo`0DOol00g`0Oomo
o`13Ool00g`0Oomoo`02Ool00g`0Oomoo`0FOol017`0Oomoog`01Goo00Al07ooOoml01Aoo`03O01o
ogoo00Ioo`03O01oogoo01Eoo`03001oogoo01Uoo`006goo00<007ooOol0:Woo0W`05Goo0W`0@goo
00=l07ooOol00Woo00=l07ooOol05Woo00Al07ooOoml00Aoo`04O01oogooO00DOol00g`0Oomoo`06
Ool00g`0Oomoo`0EOol00`00Oomoo`0JOol001]oo`03001oogoo02aoo`03O01oogoo01Aoo`03O01o
ogoo041oo`03O01oogoo009oo`03O01oogoo01Eoo`04O01oogooO005Ool00g`0Ooml000DOol00g`0
Oomoo`06Ool00g`0Oomoo`0FOol00`00Oomoo`0JOol001aoo`03001oogoo02aoo`03O01oogoo01Ao
o`03O01oogoo03moo`03O01oogoo009oo`03O01oogoo01Eoo`04O01oogooO004Ool00g`0Ooml000D
Ool00g`0Oomoo`06Ool00g`0Oomoo`0FOol00`00Oomoo`0KOol001aoo`03001oogoo02eoo`03O01o
ogoo01Aoo`03O01oogoo03ioo`03O01oogoo009oo`03O01oogoo01Aoo`05O01oogooOoml0004Ool0
0g`0Ooml000COol00g`0Oomoo`06Ool00g`0Oomoo`0GOol00`00Oomoo`0KOol001eoo`03001oogoo
02eoo`03O01oogoo01Aoo`03O01oogoo03eoo`03O01oogoo00=oo`03O01oogoo01=oo`04O01oogoo
O004Ool00g`0Ooml000COol00g`0Oomoo`06Ool00g`0Oomoo`0GOol00`00Oomoo`0LOol001eoo`03
001oogoo02ioo`03O01oogoo01Aoo`03O01oogoo03aoo`03O01oogoo00=oo`03O01oogoo01=oo`04
O01oogooO004Ool2O00COol00g`0Oomoo`06Ool00g`0Oomoo`0HOol00`00Oomoo`0LOol001ioo`03
001oogoo02ioo`03O01oogoo01Aoo`03O01oogoo03]oo`03O01oogoo00=oo`03O01oogoo019oo`05
O01oogooOoml0004Ool00g`0Oomoo`0AOol00g`0Oomoo`06Ool00g`0Oomoo`0HOol00`00Oomoo`0M
Ool001ioo`03001oogoo02moo`03O01oogoo01Aoo`03O01oogoo03Yoo`03O01oogoo00=oo`03O01o
ogoo019oo`04O01oogooO004Ool00g`0Oomoo`0AOol00g`0Oomoo`06Ool00g`0Oomoo`0IOol00`00
Oomoo`0MOol001moo`03001oogoo02moo`03O01oogoo01Aoo`03O01oogoo03Uoo`03O01oogoo00=o
o`03O01oogoo019oo`04O01oogooO004Ool00g`0Oomoo`0@Ool00g`0Oomoo`06Ool00g`0Oomoo`0I
Ool00`00Oomoo`0NOol001moo`03001oogoo00Aoo`03O01oogoo02Uoo`03O01oogoo01Aoo`9l03Uo
o`03O01oogoo00=oo`03O01oogoo015oo`04O01oogooO004Ool00g`0Oomoo`0@Ool00g`0Oomoo`06
Ool00g`0Oomoo`0JOol00`00Oomoo`0NOol0021oo`03001oogoo00Aoo`9l02Yoo`03O01oogoo01Eo
o`03O01oogoo03Ioo`03O01oog`000=oo`03O01oogoo015oo`04O01oogooO003Ool2O00AOol00g`0
Oomoo`06Ool00g`0Oomoo`0JOol00`00Oomoo`0OOol0021oo`03001oogoo00Ioo`9l02Uoo`03O01o
ogoo01Eoo`03O01oogoo03Eoo`03O01oog`000=oo`03O01oogoo011oo`05O01oogooOoml0002Ool2
O00AOol00g`0Oomoo`06Ool00g`0Oomoo`0KOol00`00Oomoo`0OOol0025oo`03001oogoo00Moo`9l
02Qoo`03O01oogoo01Eoo`03O01oogoo03Aoo`9l00Aoo`03O01oogoo011oo`04O01oogooO003Ool2
O00@Ool00g`0Oomoo`06Ool00g`0Oomoo`0KOol00`00Oomoo`0POol0025oo`03001oogoo00Uoo`03
O01oogoo02Ioo`03O01oogoo01Eoo`03O01oogoo03=oo`9l00Aoo`03O01oogoo011oo`04O01oogoo
O002Ool2O00@Ool00g`0Oomoo`06Ool00g`0Oomoo`0LOol00`00Oomoo`0POol0029oo`03001oogoo
00Uoo`9l02Moo`03O01oogoo01Eoo`03O01oogoo039oo`03O01oogoo00=oo`03O01oogoo00moo`09
O01oogooOoml07ooO01oog`000moo`03O01oogoo00Ioo`03O01oogoo01aoo`03001oogoo025oo`00
8goo00<007ooOol02Woo0W`09Woo00=l07ooOol05Goo00=l07ooOol0<Goo00=l07ooOol00goo00=l
07ooOol03goo00Ql07ooOoml07ooO01oog`03goo00=l07ooOol01Woo00=l07ooOol01Woo00=l07oo
Ool04goo00<007ooOol08Woo000TOol00`00Oomoo`0;Ool2O00UOol00g`0Oomoo`0EOol00g`0Oomo
o`0_Ool00g`0Oomoo`04Ool00g`0Oomoo`0?Ool027`0Oomoog`0Ooml07ooO00>Ool00g`0Oomoo`06
Ool00g`0Oomoo`02Ool01G`0OomoogooO0005Goo00<007ooOol08goo000TOol00`00Oomoo`0=Ool0
0g`0Oomoo`0SOol00g`0Oomoo`0EOol2O00_Ool00g`0Oomoo`05Ool00g`0Oomoo`0=Ool027`0Oomo
og`0Ooml07ooO00>Ool00g`0Oomoo`06Ool00g`0Oomoo`02Ool00g`0Oomoo`02O0000`00Oomoo`0C
Ool00`00Oomoo`0SOol002Eoo`03001oogoo00eoo`9l02Aoo`03O01oogoo01Ioo`03O01oogoo02ao
o`03O01oogoo00Eoo`03O01oogoo00eoo`03O01oogoo009l009oo`03O01oogoo00]oo`03O01oogoo
00Ioo`04O01oogooOol2O002Ool00g`00000000EOol00`00Oomoo`0TOol002Ioo`03001oogoo00io
o`9l02=oo`03O01oogoo01Ioo`03O01oogoo02Yoo`9l00Moo`03O01oogoo00aoo`05O01oogooOoml
0003Ool00g`0Oomoo`0:Ool00g`0Oomoo`06Ool01G`0OomoogooO0000goo00=l0000Ool05Goo00<0
07ooOol09Goo000VOol00`00Oomoo`0@Ool2O00ROol00g`0Oomoo`0FOol00g`0Oomoo`0YOol2O007
Ool00g`0Oomoo`0<Ool00g`0Oomoo`02O002Ool00g`0Oomoo`0:Ool00g`0Oomoo`06Ool01G`0Oomo
ogooO0000Woo0W`000<007ooOol05Goo00<007ooOol09Goo000WOol00`00Oomoo`0AOol00g`0Oomo
o`0POol00g`0Oomoo`0FOol00g`0Oomoo`0WOol00g`0Ooml0007Ool00g`0Oomoo`0<Ool017`0Oomo
og`00goo00=l07ooOol02Goo00=l07ooOol01Woo00=l07ooOol00W`00Woo00=l000000005goo00<0
07ooOol09Woo000XOol00`00Oomoo`0AOol2O00QOol00g`0Oomoo`0FOol00g`0Oomoo`0VOol00g`0
Ooml0007Ool00g`0Oomoo`0;Ool017`0Oomoog`00goo00=l07ooOol02Goo00=l07ooOol01Woo00Al
07ooOoml009oo`9l0003001oogoo01Moo`03001oogoo02Ioo`00:7oo00<007ooOol04goo0W`087oo
00=l07ooOol05Woo00=l07ooOol097oo00Al07ooOoml00Moo`03O01oogoo00]oo`04O01oog`0O003
Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool017`0Oomoog`00Woo0W`000<007ooOol05goo00<007oo
Ool09goo000YOol00`00Oomoo`0DOol2O00OOol00g`0Oomoo`0FOol00g`0Oomoo`0SOol017`0Oomo
og`01goo00=l07ooOol02goo0W`000Eoog`0Oomoog`000Yoo`03O01oogoo00Ioo`04O01oog`0O002
Ool00g`00000000IOol00`00Oomoo`0XOol002Uoo`03001oogoo01Ioo`03O01oogoo01eoo`03O01o
ogoo01Ioo`9l02=oo`04O01oogooO007Ool00g`0Oomoo`0:Ool017`0Ooml07`00goo00=l07ooOol0
1goo00=l07ooOol01Woo00=l07ooO0000Woo0W`000<007ooOol06Goo00<007ooOol0:7oo000ZOol0
0`00Oomoo`0FOol2O00NOol00g`0Oomoo`0GOol00g`0Oomoo`0OOol01G`0OomoogooO0001goo00=l
07ooOol02Woo0W`000Eoog`0Oomoog`000Uoo`03O01oogoo00Ioo`03O01oog`0009oo`9l0003001o
ogoo01Uoo`03001oogoo02Uoo`00:goo00<007ooOol05goo0W`07Goo0W`067oo00=l07ooOol07Woo
00El07ooOomoog`000Moo`03O01oogoo00Uoo`9l009oo`04O01oogooO008Ool00g`0Oomoo`06Ool0
17`0Ooml07oo0W`00P006goo00<007ooOol0:Woo000/Ool00`00Oomoo`0HOol2O00MOol00g`0Oomo
o`0FOol00g`0Oomoo`0LOol00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`09Ool017`0Oomo
og`00Woo00=l07ooOol01Woo00=l07ooOol01Woo0g`000Aoog`0O00001aoo`03001oogoo02]oo`00
;Goo00<007ooOol06Goo00=l07ooOol06goo00=l07ooOol05Woo00=l07ooOol06goo00=l07ooOol0
0Woo00=l07ooOol01Woo00=l07ooOol027oo00Al07ooOoml009oo`03O01oogoo00Eoo`03O01oogoo
00Ioo`9l0005Ooml07`0O000000LOol00`00Oomoo`0/Ool002ioo`03001oogoo01=oo`8000Aoo`9l
01aoo`03O01oogoo01Ioo`03O01oogoo01Yoo`03O01oogoo009oo`03O01oogoo00Ioo`03O01oogoo
00Moo`04O01oogooO003Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool2O0000gooO01l0002000LOol0
0`00Oomoo`0]Ool002moo`03001oogoo01Aoo`8000Aoo`9l01]oo`03O01oogoo01Ioo`03O01oogoo
01Qoo`03O01oogoo00=oo`03O01oogoo00Ioo`03O01oogoo00Ioo`9l009oo`04O01oogooO006Ool0
0g`0Oomoo`06Ool2O00017ooO01l00007Goo00<007ooOol0;Woo000`Ool00`00Oomoo`0BOol2O000
0goo00000004Ool2O00JOol00g`0Oomoo`0FOol00g`0Oomoo`0GOol00g`0Oomoo`03Ool00g`0Oomo
o`06Ool00g`0Oomoo`05Ool00g`0Ooml0002Ool017`0Oomoog`01Goo00=l07ooOol01Woo00=l07oo
O0000W`000<007ooOol06goo00<007ooOol0;goo000aOol00`00Oomoo`0COol2O0000goo00000004
Ool00g`0Oomoo`0HOol00g`0Oomoo`0FOol2O00FOol00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0
Oomoo`05Ool2O002Ool017`0Oomoog`01Goo00=l07ooOol01Woo00Al07ooO01l008001eoo`03001o
ogoo031oo`00<Woo00<007ooOol057oo0W`000=oo`0000000goo0W`06Goo00=l07ooOol05goo00=l
07ooOol04goo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol017oo00=l07ooO0000Woo00Al
07ooOoml00Aoo`03O01oogoo00Eoo`El0003001oogoo01aoo`03001oogoo035oo`00<goo00<007oo
Ool05Goo0W`000=oo`0000000goo0W`067oo00=l07ooOol05goo00=l07ooOol04Goo00=l07ooOol0
17oo00=l07ooOol01goo00=l07ooOol00goo00=l07ooO0000Woo00Al07ooOoml00Aoo`03O01oogoo
00Eoo`=l0003Ool0000001ioo`03001oogoo039oo`00=7oo00<007ooOol05Woo0W`000=oo`000000
0goo0W`05goo00=l07ooOol05goo00=l07ooOol047oo00=l07ooOol017oo00=l07ooOol01goo00=l
07ooOol00Woo00Al07ooOoml009oo`04O01oogooO003Ool00g`0Oomoo`05Ool4O0000`00Oomoo`0M
Ool00`00Oomoo`0cOol003Aoo`03001oogoo01Qoo`9l0003Ool0000000=oo`03O01oogoo01Eoo`03
O01oogoo01Moo`03O01oogoo00moo`03O01oogoo00Aoo`03O01oogoo00Moo`03O01oogoo009oo`04
O01oogooO002Ool00g`0Ooml0003Ool00g`0Oomoo`05Ool4O0000`00Oomoo`0BOol2000:Ool00`00
Oomoo`0cOol003Eoo`03001oogoo01Uoo`=l0080009oo`9l01Ioo`03O01oogoo01Moo`03O01oogoo
00eoo`03O01oogoo00Eoo`03O01oogoo00Moo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Al
07ooOoml00Ioo`=l0003Ool0000001=oo`@000Uoo`03001oogoo03Aoo`00=Woo0P0077oo0W`00P00
0Woo0W`05Goo00=l07ooOol05goo00=l07ooOol037oo00=l07ooOol01Goo00=l07ooOol01goo00Al
07ooOoml00=oo`06O01oogooO01oog`00Woo00=l07ooOol017oo17`000<007ooOol04Goo10002Goo
0P00=goo000hOol00`00Oomoo`0KOol2O0020002Ool2O00DOol00g`0Oomoo`0GOol00g`0Oomoo`0:
Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Ooml0004Ool027`0Oomoog`0Ooml07ooO006Ool4
O0000`00Oomoo`0@Ool4000:Ool00`00Oomoo`0gOol003Uoo`03001oogoo01aoo`9l0080009oo`03
O01oogoo019oo`03O01oogoo01Moo`9l00Yoo`03O01oogoo00Ioo`03O01oogoo00Moo`03O01oog`0
00=oo`04O01oogooO002Ool2O005Ool4O002000AOol4000;Ool00`00Oomoo`0hOol003Yoo`03001o
ogoo01eoo`9l00800003Ooml07`001=oo`03O01oogoo01Qoo`03O01oogoo00Ioo`03O01oogoo00Mo
o`03O01oogoo00Qoo`03O01oogoo009oo`05O01oogooO01oo`02O005Ool4O0000`00Oomoo`0>Ool5
000<Ool00`00Oomoo`0iOol003]oo`03001oogoo01ioo`9l00800003Ooml07`0019oo`03O01oogoo
01Qoo`03O01oogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Moo`9l00=oo`04O01oogooO002Ool0
0g`0Oomoo`03Ool01@00O01l07`000003goo10003Woo00<007ooOol0>Woo000lOol00`00Oomoo`0O
Ool2O00200000gooO01l000<Ool00`00Oomoo`02Ool00g`0Oomoo`0HOol00g`0Oomoo`04Ool00g`0
Oomoo`07Ool00g`0Oomoo`06Ool00g`0Ooml0003Ool01W`0Oomoog`0Ooml00Aoo`04O00007`0O002
000>Ool4000?Ool00`00Oomoo`0kOol003eoo`80029oo`05O0000000Ooml000<Ool00`00Oomoo`02
Ool00g`0Oomoo`0HOol00g`0Oomoo`02Ool00g`0Oomoo`08Ool00g`0Oomoo`05Ool017`0Oomoog`0
0goo00=l07ooOol00g`00goo0P0000=oog`000003Woo10003goo0P00?Woo000oOol00`00Oomoo`0Q
Ool00g`000000002O00;Ool20003Ool00g`0Oomoo`0HOol01G`0OomoogooO0002Woo00=l07ooOol0
1Goo00Al07ooOoml009oo`03O01oogoo00=l00=oo`05001l07ooO000000=Ool4000@Ool00`00Oomo
o`0nOol0041oo`03001oogoo029oo`03O0000000009l00]oo`05001oogooOoml000JOol00g`0Ooml
000;Ool00g`0Oomoo`04Ool01G`0OomoogooO0000Woo00Il07ooOoml07ooO002Ool00`00O01oo`02
000;Ool8000>Ool00`00Oomoo`0oOol0045oo`03001oogoo02=oo`03O0000000009l00Yoo`05001o
ogooOoml000JOol2O00;Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0Oomoog`0Ool00g`000=o
o`0000000Woo00<007ooOol02Goo20003goo00<007ooOol0@7oo0012Ool2000UOol017`000000000
2Woo00D007ooOomoog`001Uoo`9l00]oo`03O01oogoo009oo`03O01oogoo00=oo`04O01oog`0Ool2
O0001GooO00007`0Ool00P002Woo20003goo0P00@goo0014Ool00`00Oomoo`02Ool2O00POol2O002
0009Ool20002Ool00g`0Oomoo`0FOol017`0Ooml07`02Goo00=l07ooOol00Woo00=l07ooOol00goo
00El07ooO01l07oo009l0005001oo`00001l0009Ool8000@Ool00`00Oomoo`13Ool004Eoo`8000Ao
o`Al01moo`03O000000000Uoo`04001oogooO00GOol01G`0OomoogooO0001Goo00@007ooOoml00=o
o`03O01oogoo00Aoo`=l0005Ooml0000001oo`0200000g`0Oomoo`05Ool8000AOol20016Ool004Mo
o`03001oogoo00Eoo`Al00Eoo`@001Aoo`03O000000000Qoo`04001oogooO00EOol00g`0Oomoo`03
Ool00g`0Oomoo`02Ool01000Oomoog`00Woo00=l07ooOol01Goo0W`00Woo00<007`000000P0000=l
07ooOol017oo200017oo0P0037oo00<007ooOol0AWoo0018Ool00`00Oomoo`08Ool3O006Ool8000>
Ool00g`000000007Ool01@00Oomoog`000004goo00=l07ooOol017oo00El07ooOomoo`00009oo`03
O01oog`000Qoo`9l0007Ool007`0O00007ooO0001Goo200017oo0P003Goo00<007ooOol0Agoo0019
Ool2000;Ool4O00:Ool70009Ool00g`000000006Ool2000017ooO01l000047oo00=l07ooOol01Woo
00Al07ooOol0009oo`03O01oog`000Moo`9l00800005O0000000Ooml0004Ool70005Ool2000=Ool2
001:Ool004]oo`8000eoo`Al00eoo`P000=oo`03O000000000Ioo`04001oogooO002000>Ool00g`0
Oomoo`07Ool01g`0000007ooO01oog`0008000Eoo`04O01oo`00O00300000gooO01oo`02Ool70005
Ool2000=Ool2001<Ool004eoo`8000moo`=l00Moo`8000Uoo`P000Eoo`06001oogooO01oo`003Goo
00=l07ooOol027oo00=l0000Ool00W`000@007ooOomoo`<0009l0004001l07`00003O0000goo0000
00060004Ool3000=Ool2001>Ool004moo`03001oogoo00moo`Al00Eoo`<000eoo`P0009oo`04O01o
o`00000:Ool00g`0Oomoo`09Ool01000O00007`01goo00El0000001l07oo00Al00L000Eoo`8000mo
o`03001oogoo04ioo`00D7oo00<007ooOol04Woo17`017oo0`002goo0W`00P000goo1`002Goo00=l
07ooOol01goo0`0000=oog`0O0001Woo00Il0000001oog`00003O0060005Ool2000@Ool00`00Oomo
o`1?Ool0055oo`8000eoo`Al00Eoo`Al00=oo`<000Yoo`9l0080009oo`800004Ooml07ooOol70000
0gooO01oo`06Ool30002Ool00`00Ooml0002O004Ool017`0000007oo0W`000=oog`000001@001Goo
0P0047oo0P00DWoo001COol3000>Ool6O003Ool3O003Ool30009Ool2O0020002Ool00`00Ooml0003
Ool20003Ool90005Ool01P00O01oog`0Ooml009oo`D00003O0000000009l00800003Ool00000009o
o`<000moo`<005Aoo`00EWoo0P004Woo2W`00Woo0`0027oo00Ql07oo000007oo001oog`017oo00@0
07ooOoml00=oo`<00003Ool0000000@00007O01oogooO01oo`00O0000P0000=oo`0000000`0000=l
000000000`000Woo0P0047oo0P00Egoo001HOol2000<Ool40007Ool7O00017oo000000001Woo0W`0
00Ioo`00000007ooO004Ool2000017`0000000002Woo00=l000000001`0000=l000000000`0000=l
0000Ool00Woo0P0047oo0P00FGoo001JOol2000>Ool80006Ool4O0030005Ool2O0001Goo00000000
O00017oo0P002Goo0`0000El0000Oomoog`000800003Ool0000000@00003O00007`000D0011oo`80
05]oo`00G7oo0`004goo200000=oog`0O0000W`00`000g`000Aoog`0O01oo`800006O01oo`00001l
07oo0P000goo1P0000Ml0000000007`0001l00090002O0000goo0000000?Ool3001MOol005moo`<0
01Qoo`D000=l00<000Il0006001l07`0Ooml07oo2P0000=oo`0000000`0000=l000000001`0000=o
og`0Ool03goo0`00H7oo001ROol3000MOol00`00O01l00040002O0000goo001l000300000g`0Ool0
000;0002O00800000goo001oo`0>Ool3001SOol006Eoo`<001Ioo`@000Aoo`9l02<000aoo`<006Io
o`00J7oo0`0057oo8@0027oo00<007oo00002Goo0`00JGoo001[Ool3000GOol=00000goo00000008
000DOol3001/Ool006ioo`<001Moo`L000Qoo`<00003Ool007oo015oo`<006moo`00LGoo1@008goo
00<007ooOol03Goo1@00LWoo001fOol4000POol00`00Oomoo`08Ool4001gOol007Yoo`P001]oo`P0
07]oo`00PWoo6`00Pgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00XWoo00<007ooOol0@goo
00<007ooOol0=Goo002QOol00`00Oomoo`15Ool00`00Oomoo`0dOol00:5oo`03001oogoo04Eoo`03
001oogoo03Aoo`00<Goo1@000goo100037oo0`0000Aoo`000000009oo`@0009oo`<00005Ool00000
Ool00002Ool5000;Ool2000017oo0000000017oo0`0000Aoo`00001oo`D000Aoo`D000moo`03001o
ogoo00=oo`<00004Ool00000Ool50003Ool50003Ool70003Ool20005Ool3000017oo000007oo1`00
00=oo`0000000`0027oo00<007ooOol0<goo000cOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001o
o`004Goo0P000goo00@007ooOol000=oo`80009oo`03001oogoo009oo`04001oogoo000DOol00`00
Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo
0P0017oo00@007ooOomoo`8000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo03=oo`00<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomo
o`00009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool0015oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`0057oo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Moo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0cOol003=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol00002Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00D007ooOol007oo00H000aoo`03001oogoo009oo`04001oogooOol5
0003Ool40003Ool6000?Ool00`00Oomoo`03Ool50003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo1@001Goo00<007ooOol00goo100027oo00<007ooOol0<goo
000cOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool20002Ool01000Oomoo`0017oo
00<007ooOol00P0000Moo`00001oo`00Ool00004Ool00`00Oomoo`0:Ool20003Ool01000Oomoo`00
17oo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoogoo0P001Woo0P0027oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
03=oo`00<7oo00@007ooOol0009oo`03001oogoo00@000eoo`04001oo`000004Ool40002Ool20000
1Goo001oogoo00000goo10003Goo00<007oo00000P0017oo100017oo1@000goo100047oo00<007oo
Ool00goo10000goo0P0000Aoo`000000009oo`800004Ool000000003Ool30003Ool30002Ool30002
Ool40006Ool00`00Oomoo`03Ool50007Ool00`00Oomoo`0cOol0031oo`04001oogoo0002Ool00`00
Oomoo`0AOol00`00Oomoo`0VOol00`00Oomoo`0[Ool00`00Oomoo`0dOol00`00Oomoo`0>Ool00`00
Oomoo`0dOol0031oo`L001=oo`03001oogoo02Ioo`03001oogoo02]oo`03001oogoo01aoo`03001o
ogoo01Eoo`03001oogoo00ioo`03001oogoo03Aoo`00BGoo0P009goo0P00;Woo00<007ooOol0<Woo
0P003goo00<007ooOol0=Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-376.995, -363.004, 2.48777, \
2.79875}}]
}, Open  ]],

Cell["\<\
   The arrivals segments reach higher maxima of distance and velocity  than \
the departures segments . In other words, the rat returned to the home base \
non-stop from further away and at higher maximal velocities than when leaving \
the home base. A similar examination of the next most preferred place  shows \
that the arrivals/departures asymmetry does not hold for this place. \
\>", "Text",
  TextJustification->1,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(graph4\)\(=\)\(See[SpeedPairPlot2[From[{\(-300\), 95}, 50]], 
        PlotLabel -> 
          StyleForm["\<From place1\>", FontSize -> 14]]\)\(\n\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -48.1563 0 ]
[.5 1.0125 48.1563 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -109.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(From) show
105.063 13.750 moveto
(place1) show
155.313 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.12946 .62698 m
.21429 .66005 L
s
1 0 0 r
.13244 .62963 m
.1994 .36772 L
s
0 0 0 r
.0744 .66402 m
.04911 .57804 L
s
.06101 .57011 m
.05804 .57407 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.14583 .61111 m
.5997 .17063 L
s
.05506 .55556 m
.09077 .57804 L
s
.08036 .57804 m
.08631 .56746 L
s
.0878 .56085 m
.07887 .54365 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.04613 .57275 m
.10863 .34127 L
s
.0625 .61508 m
.09077 .61905 L
s
.10417 .62169 m
.09375 .62963 L
s
.07143 .64021 m
.0997 .66005 L
s
.0997 .66005 m
.11161 .64683 L
s
.13839 .63624 m
.17411 .59259 L
s
.07738 .64683 m
.07292 .65344 L
s
.07143 .66138 m
.12946 .65608 L
s
.13244 .65476 m
.1369 .64153 L
s
.13542 .64815 m
.28125 .15212 L
s
.06845 .56349 m
.14435 .55423 L
s
.125 .56746 m
.08631 .57937 L
s
.08185 .58201 m
.09226 .67989 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0023OolI0024Ool007]oo`P0
01Uoo`P007aoo`00MGoo1P00:Goo1P00MWoo001bOol3000eOol3001cOol006eoo`D003]oo`D006io
o`00JWoo0`00AGoo0`00Jgoo001WOol3001;Ool2001YOol006Eoo`80051oo`@006Eoo`00HWoo0`00
EWoo0P00Hgoo001OOol3001KOol3001POol005aoo`<0065oo`<005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Ioo`8006moo`8005Moo`00E7oo0P00Lgoo0P00EGoo001COol00`00
Oomoo`1eOol2001COol0055oo`8007Yoo`80055oo`00Cgoo0P00OWoo00<007ooOol0CWoo001=Ool2
0021Ool2001>Ool004]oo`8008Eoo`03001oogoo04]oo`00BGoo0P00R7oo0P00Bgoo0018Ool00`00
Oomoo`2:Ool20019Ool004Moo`03001oogoo08eoo`03001oogoo04Ioo`00AGoo0P00TGoo0P00AWoo
0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0049oo`8009Moo`8004=oo`00@Goo00<007ooOol0
VGoo00<007ooOol0@7oo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003moo`03001oogoo09eo
o`03001oogoo03ioo`00?Goo0P00XGoo0P00?Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol0
03]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo00<007ooOol0>Goo000i
Ool00`00Oomoo`2YOol2000iOol003Qoo`03001oogoo0:aoo`03001oogoo03Ioo`00=Woo0P0077oo
00<007ooOol0TGoo00<007ooOol0=Goo000eOol00`00Oomoo`0LOol00`00Oomoo`2BOol00`00Oomo
o`0dOol003Aoo`03001oogoo01aoo`03001oogoo09Aoo`03001oogoo03=oo`00=7oo00<007ooOol0
77oo00<007ooOol0U7oo00<007ooOol0<goo000cOol00`00Oomoo`0MOol00`00Oomoo`2EOol00`00
Oomoo`0bOol0039oo`03001oogoo01ioo`03001oogoo05Aoo`03001oogoo03moo`03001oogoo035o
o`00<Goo00<007ooOol07Woo00<007ooOol0E7oo00<007ooOol0@Goo00<007ooOol0<7oo000`Ool0
0`00Oomoo`0OOol00`00Oomoo`1COol00`00Oomoo`13Ool00`00Oomoo`0_Ool002moo`03001oogoo
021oo`03001oogoo059oo`03001oogoo04Eoo`03001oogoo02ioo`00;Woo00<007ooOol087oo00<0
07ooOol0DWoo00<007ooOol0Agoo00<007ooOol0;Goo000]Ool00`00Oomoo`0QOol00`00Oomoo`1A
Ool00`00Oomoo`19Ool00`00Oomoo`0/Ool002aoo`03001oogoo029oo`03001oogoo051oo`03001o
ogoo04]oo`03001oogoo02]oo`00:goo00<007ooOol08goo00<007ooOol0Cgoo00<007ooOol0CGoo
00<007ooOol0:Woo000ZOol00`00Oomoo`0SOol00`00Oomoo`1?Ool00`00Oomoo`1?Ool00`00Oomo
o`0YOol002Uoo`03001oogoo02Aoo`03001oogoo04ioo`03001oogoo055oo`03001oogoo02Qoo`00
:Goo00<007ooOol097oo00<007ooOol0CGoo00<007ooOol0DWoo00<007ooOol0:7oo000XOol00`00
Oomoo`0TOol00`00Oomoo`1=Ool00`00Oomoo`1DOol00`00Oomoo`0WOol002Qoo`03001oogoo02Ao
o`03001oogoo04aoo`03001oogoo05Ioo`03001oogoo02Ioo`009goo00<007ooOol09Goo00<007oo
Ool0Bgoo00<007ooOol0Egoo00<007ooOol09Woo000VOol00`00Oomoo`0UOol00`00Oomoo`1;Ool0
0`00Oomoo`1IOol00`00Oomoo`0UOol002Ioo`03001oogoo02Eoo`03001oogoo04Uoo`8005aoo`03
001oogoo02Eoo`009Goo00<007ooOol09Woo00<007ooOol0B7oo00<007ooOol0GGoo00<007ooOol0
97oo000TOol00`00Oomoo`0WOol00`00Oomoo`17Ool00`00Oomoo`1OOol00`00Oomoo`0SOol002Ao
o`03001oogoo02Ioo`03001oogoo04Moo`03001oogoo061oo`03001oogoo02=oo`008goo00<007oo
Ool09goo00<007ooOol0AWoo00<007ooOol0HWoo00<007ooOol08Woo000ROol00`00Oomoo`0XOol0
0`00Oomoo`15Ool00`00Oomoo`1TOol00`00Oomoo`0QOol0025oo`03001oogoo02Qoo`03001oogoo
04Eoo`03001oogoo06Eoo`03001oogoo025oo`008Goo00<007ooOol0:7oo00<007ooOol0A7oo00<0
07ooOol0Igoo00<007ooOol087oo000POol00`00Oomoo`0YOol00`00Oomoo`13Ool00`00Oomoo`1Y
Ool00`00Oomoo`0OOol0021oo`03001oogoo02Uoo`03001oogoo049oo`03001oogoo06Yoo`03001o
ogoo01moo`007goo00<007ooOol0:Goo00<007ooOol0@Woo00<007ooOol0K7oo00<007ooOol07Woo
000OOol00`00Oomoo`0YOol00`00Oomoo`11Ool00`00Oomoo`1]Ool00`00Oomoo`0NOol001ioo`03
001oogoo02Yoo`03001oogoo041oo`03001oogoo06moo`03001oogoo01eoo`007Woo00<007ooOol0
:Goo00<007ooOol0@7oo00<007ooOol0L7oo00<007ooOol07Goo000MOol00`00Oomoo`0ZOol00`00
Oomoo`0oOol00`00Oomoo`1bOol00`00Oomoo`0LOol001eoo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo07=oo`03001oogoo01aoo`0077oo00<007ooOol0:goo00<007ooOol0?Goo00<007oo
Ool0MGoo00<007ooOol06goo000LOol00`00Oomoo`0ZOol00`00Oomoo`0mOol00`00Oomoo`1fOol0
0`00Oomoo`0KOol001]oo`03001oogoo02]oo`03001oogoo03aoo`03001oogoo07Qoo`03001oogoo
01Yoo`006goo00<007ooOol0:goo00<007ooOol0>goo00<007ooOol0NGoo00<007ooOol06Woo000J
Ool00`00Oomoo`0[Ool00`00Oomoo`0kOol00`00Oomoo`1kOol00`00Oomoo`0IOol001Yoo`03001o
ogoo02]oo`03001oogoo03Yoo`03001oogoo07aoo`03001oogoo01Uoo`006Goo00<007ooOol0;7oo
00<007ooOol0>Goo00<007ooOol0OWoo00<007ooOol067oo000IOol00`00Oomoo`0[Ool00`00Oomo
o`0iOol00`00Oomoo`1oOol00`00Oomoo`0HOol001Qoo`03001oogoo02aoo`03001oogoo03Qoo`03
001oogoo085oo`03001oogoo01Moo`0067oo00<007ooOol0;7oo00<007ooOol0=goo00<007ooOol0
PWoo00<007ooOol05goo000GOol00`00Oomoo`0]Ool00`00Oomoo`0fOol00`00Oomoo`24Ool00`00
Oomoo`0FOol001Moo`03001oogoo02aoo`03001oogoo03Ioo`03001oogoo08Eoo`03001oogoo01Io
o`005goo00<007ooOol0;7oo00<007ooOol0=Goo00<007ooOol0QWoo00<007ooOol05Woo000FOol0
0`00Oomoo`0]Ool00`00Oomoo`0dOol00`00Oomoo`28Ool00`00Oomoo`0EOol001Ioo`03001oogoo
02aoo`03001oogoo03=oo`8008]oo`03001oogoo01Eoo`005Woo00<007ooOol037oo00<007ooOol0
7Goo00<007ooOol0<Woo00<007ooOol0Rgoo00<007ooOol05Goo000FOol00`00Oomoo`0<Ool00`00
Oomoo`0MOol00`00Oomoo`0aOol00`00Oomoo`2=Ool00`00Oomoo`0DOol001Eoo`03001oogoo00ao
o`03001oogoo01ioo`03001oogoo031oo`03001oogoo08ioo`03001oogoo01Aoo`005Goo00<007oo
Ool037oo00<007ooOol07Goo00<007ooOol0<7oo00<007ooOol0Sgoo00<007ooOol057oo000EOol0
0`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`0_Ool00`00Oomoo`2AOol00`00Oomoo`0COol0
01Aoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo02ioo`03001oogoo099oo`03001oogoo
01=oo`0057oo00<007ooOol037oo00<007ooOol07Goo00<007ooOol0;Woo00<007ooOol0Tgoo00<0
07ooOol04goo000DOol00`00Oomoo`0<Ool00`00Oomoo`0HOol00g`0Oomoo`02Ool00`00Oomoo`0]
Ool00`00Oomoo`2EOol00`00Oomoo`0BOol001=oo`03001oogoo00eoo`03001oogoo01Qoo`03O01o
ogoo009oo`03001oogoo02aoo`03001oogoo09Ioo`03001oogoo019oo`004goo00<007ooOol03Goo
00<007ooOol05goo00=l07ooOol00goo00<007ooOol0:goo00<007ooOol0Ugoo00<007ooOol04Woo
000COol00`00Oomoo`0<Ool00`00Oomoo`0HOol00g`0Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomo
o`2IOol00`00Oomoo`0AOol0019oo`03001oogoo00eoo`03001oogoo01Qoo`03O01oogoo009oo`03
001oogoo02Yoo`03001oogoo09Yoo`03001oogoo015oo`004Woo00<007ooOol03Goo00<007ooOol0
67oo00=l07ooOol00Woo00<007ooOol0:Goo00<007ooOol0Vgoo00<007ooOol04Goo000BOol00`00
Oomoo`0<Ool00`00Oomoo`0HOol00g`0Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`2LOol00`00
Oomoo`0AOol0019oo`03001oogoo00aoo`03001oogoo01Qoo`03O01oogoo009oo`03001oogoo02Qo
o`03001oogoo09eoo`03001oogoo015oo`004Goo00<007ooOol03Goo00<007ooOol067oo00=l07oo
Ool00Woo00<007ooOol09goo00<007ooOol0Wgoo00<007ooOol047oo000AOol00`00Oomoo`0=Ool0
0`00Oomoo`0HOol00g`0Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`2POol00`00Oomoo`0@Ool0
015oo`03001oogoo00aoo`03001oogoo01Qoo`03O01oogoo009oo`03001oogoo02Ioo`03001oogoo
0:5oo`03001oogoo011oo`004Goo00<007ooOol037oo00<007ooOol067oo00=l07ooOol00Woo00<0
07ooOol09Goo00<007ooOol0XWoo00<007ooOol047oo000AOol00`00Oomoo`0<Ool00`00Oomoo`0H
Ool00g`0Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`2SOol00`00Oomoo`0@Ool0011oo`03001o
ogoo00eoo`03001oogoo01Qoo`05O01oogooOol0000VOol00`00Oomoo`2UOol00`00Oomoo`0?Ool0
011oo`03001oogoo00aoo`03001oogoo01Qoo`03O01oogoo009oo`03001oogoo02=oo`03001oogoo
0:Ioo`03001oogoo00moo`0047oo00<007ooOol037oo00<007ooOol067oo00=l07ooOol00Woo00<0
07ooOol08Woo00<007ooOol0Ygoo00<007ooOol03goo000@Ool00`00Oomoo`0<Ool00`00Oomoo`0H
Ool01G`0Oomoogoo000097oo00<007ooOol0Z7oo00<007ooOol03goo000@Ool00`00Oomoo`0;Ool0
0`00Oomoo`0IOol01G`0Oomoogoo00008goo00<007ooOol0ZGoo00<007ooOol03goo000@Ool00`00
Oomoo`0;Ool00`00Oomoo`0HOol00g`0Oomoo`02Ool00`00Oomoo`0POol00`00Oomoo`2ZOol00`00
Oomoo`0?Ool0011oo`03001oogoo00]oo`03001oogoo01Qoo`03O01oogoo009oo`03001oogoo01mo
o`03001oogoo0:aoo`03001oogoo00ioo`003goo00<007ooOol037oo00<007ooOol067oo00El07oo
Oomoo`00025oo`03001oogoo0:eoo`03001oogoo00ioo`003goo00<007ooOol02goo00<007ooOol0
6Goo00El07ooOomoo`0001moo`800;1oo`03001oogoo00ioo`003goo00<007ooOol02goo00<007oo
Ool067oo00=l07ooOol00Woo00<007ooOol077oo00<007ooOol0/7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`0;Ool00`00Oomoo`0HOol01G`0Oomoogoo00007Woo00<007ooOol0/Goo00<007ooOol0
3Woo000?Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol01G`0Oomoogoo00007Goo00<007ooOol0/Woo
00<007ooOol03Woo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0IOol01G`0Oomoogoo000077oo00<0
07ooOol0/goo00<007ooOol03Woo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol00g`0Oomoo`02
Ool00`00Oomoo`0IOol00`00Oomoo`2dOol00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`03001o
ogoo01Qoo`05O01oogooOol0000KOol00`00Oomoo`2eOol00`00Oomoo`0>Ool000moo`03001oogoo
00Uoo`03001oogoo01Uoo`05O01oogooOol0000JOol00`00Oomoo`2fOol00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`03001oogoo01Uoo`05O01oogooOol0000IOol00`00Oomoo`2gOol00`00Oomo
o`0>Ool000moo`03001oogoo00Uoo`03001oogoo01Qoo`05O01oogooOol0000IOol00`00Oomoo`2i
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo`03001oogoo01Qoo`05O01oogooOol0000HOol0
0`00Oomoo`2jOol00`00Oomoo`0=Ool000ioo`03001oogoo00Uoo`03001oogoo01Uoo`05O01oogoo
Ool0000GOol00`00Oomoo`2kOol00`00Oomoo`0=Ool000ioo`03001oogoo00Uoo`03001oogoo01Uo
o`05O01oogooOol0000FOol00`00Oomoo`2lOol00`00Oomoo`0=Ool000ioo`03001oogoo00Uoo`03
001oogoo01Qoo`05O01oogooOol0000FOol00`00Oomoo`2mOol00`00Oomoo`0=Ool000ioo`03001o
ogoo00Qoo`03001oogoo01Uoo`05O01oogooOol0000EOol00`00Oomoo`2nOol00`00Oomoo`0=Ool0
00ioo`03001oogoo00Qoo`03001oogoo01Uoo`05O01oogooOol0000DOol00`00Oomoo`2oOol00`00
Oomoo`0=Ool000ioo`03001oogoo00Qoo`03001oogoo01Uoo`04O01oogoo000DOol00`00Oomoo`30
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Qoo`03001oogoo01Qoo`05O01oogooOol0000COol0
0`00Oomoo`31Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`03001oogoo01Uoo`05O01oogoo
Ool0000BOol00`00Oomoo`32Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`03001oogoo01Uo
o`04O01oogoo000BOol00`00Oomoo`33Ool00`00Oomoo`0=Ool000moo`03001oogoo00Ioo`03001o
ogoo01Uoo`04O01oogoo000AOol00`00Oomoo`34Ool00`00Oomoo`0=Ool000moo`03001oogoo00Io
o`03001oogoo01Qoo`05O01oogooOol0000@Ool00`00Oomoo`34Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Eoo`03001oogoo01Uoo`05O01oogooOol0000?Ool00`00Oomoo`35Ool00`00Oomoo`0>
Ool000moo`03001oogoo00Eoo`03001oogoo01Uoo`04O01oogoo000?Ool00`00Oomoo`36Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Eoo`03001oogoo01Uoo`04O01oogoo000>Ool00`00Oomoo`37
Ool00`00Oomoo`0>Ool000moo`03001oogoo00Aoo`03001oogoo01Uoo`05O01oogooOol0000=Ool0
0`00Oomoo`38Ool00`00Oomoo`0>Ool000moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
019oo`04O01oogoo000=Ool00`00Oomoo`39Ool00`00Oomoo`0>Ool000moo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo015oo`04O01oogoo000<Ool00`00Oomoo`3:Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Aoo`03001oogoo00Eoo`03O01oogoo015oo`04O01oogoo000;Ool00`00Oomo
o`3;Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`03001oogoo00Moo`03O01oogoo00Yoo`@0
0003Ooml07oo009oo`03001oogoo00Qoo`03001oogoo0<aoo`03001oogoo00ioo`003goo00<007oo
Ool00goo00<007oo00001goo00<007`0Ool00goo1`001Goo00Al07ooOol000Uoo`800<moo`03001o
ogoo00ioo`003goo00<007ooOol00goo00<007ooOol00P0017oo1`0037oo00Al07ooOol000Qoo`03
001oogoo0<moo`03001oogoo00ioo`0047oo00<007ooOol00Woo00<007ooOol00Woo100017oo00=l
07ooOol037oo00Al07ooOol000Moo`03001oogoo0<moo`03001oogoo00moo`0047oo00D007ooOomo
o`0000=oo`03001oogoo0080009oo`05001oogooOoml0005Ool20005Ool017`0Oomoo`001goo00<0
07ooOol0d7oo00<007ooOol03goo000@Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
000017oo00=l000000000P001goo00Al07ooOol000Ioo`03001oogoo0=5oo`03001oogoo00moo`00
47oo00<007ooOol01Goo00<007oo00000goo0P0000=oo`0000000P0000=l07ooOol027oo00Al07oo
Ool000Eoo`03001oogoo0=9oo`03001oogoo00moo`0047oo00<007ooOol00Woo00<007ooOol00goo
0P0000Aoo`00000000Eoo`03O01oogoo00Moo`04O01oogoo0004Ool00`00Oomoo`3COol00`00Oomo
o`0?Ool0011oo`03001oogoo009oo`03001oogoo00Eoo`8000Qoo`03O01oogoo00Eoo`04O01oogoo
0004Ool00`00Oomoo`3DOol00`00Oomoo`0?Ool0015oo`03001oogoo009oo`03001oogoo00Eoo`<0
00Moo`03O01oogoo00Aoo`04O01oogoo0003Ool00`00Oomoo`3DOol00`00Oomoo`0@Ool0015oo`03
001oogoo009oo`03001oogoo00Eoo`03001oogoo008000Ioo`03O01oogoo00=oo`04O01oogoo0002
Ool00`00Oomoo`3EOol00`00Oomoo`0@Ool0015oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo009oo`8000Eoo`03O01oogoo009oo`03O01oo`00009oo`04001oogoo003EOol00`00Oomoo`0@
Ool0015oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`04O01o
ogooO002Ool00`00Ool00002Ool00`00Oomoo`3DOol00`00Oomoo`0@Ool0015oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00Yoo`=l009oo`80009oo`03001oogoo0=Eoo`03001oogoo011o
o`004Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Goo0`0017oo00Al07oo0000009o
o`03001oogoo0=Eoo`03001oogoo015oo`004Woo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool027oo1@0000El0000Oomoo`000=Qoo`03001oogoo015oo`004Woo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol02goo00=l07oo00000`00fGoo00<007ooOol04Goo000BOol00`00Oomoo`03
Ool50002Ool00`00Oomoo`0;Ool01W`0Oomoo`00O0000=Uoo`03001oogoo015oo`004goo00<007oo
Ool00Woo00<007ooOol00Woo10000goo00<007ooOol01Woo00Il07oo001oo`00O03IOol00`00Oomo
o`0AOol001=oo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00009Ool017`0Ool00000
0Woo00=l07ooOol0eGoo00<007ooOol04Woo000COol00`00Oomoo`03Ool00`00Oomoo`03Ool01000
Oomoo`0027oo00D007`0Oomoo`0000Aoo`03O01oogoo0=Aoo`03001oogoo019oo`0057oo00<007oo
Ool00Woo00<007ooOol017oo0P002Woo00=l000000001Woo00=l07ooOol0dgoo00<007ooOol04Woo
000DOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool50004Ool00g`0Oomoo`3AOol0
0`00Oomoo`0COol001Aoo`03001oogoo00=oo`8000Aoo`03001oogoo00]oo`04001oogooOol20003
Ool00g`0Oomoo`3@Ool00`00Oomoo`0COol001Eoo`03001oogoo009oo`04001oo`000002Ool00`00
Oomoo`0:Ool20005Ool300000gooO01oo`3@Ool00`00Oomoo`0COol001Eoo`03001oogoo009oo`03
001oogoo00800003Ool007oo00Aoo`03001oogoo00Aoo`03001oogoo00Moo`800003O01oogoo0<eo
o`03001oogoo01Aoo`005Goo00<007ooOol00goo00@007oo001oo`8000Aoo`03001oogoo00Aoo`80
00aoo`03O00007oo0<aoo`03001oogoo01Aoo`005Goo00<007ooOol00goo0P000goo0P000goo00<0
07ooOol017oo00<007ooOol037oo00Al000000000<Yoo`03001oogoo01Aoo`005Goo00<007ooOol0
0goo00<007ooOol00Woo00<007oo00002@0047oo00=l07ooOol00P00b7oo00<007ooOol057oo000F
Ool00`00Oomoo`02Ool9000IOol017`0Oomoogoo0P00aGoo00<007ooOol05Goo000FOol00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00g`0Oomoo`37Ool00`00Oomoo`0EOol001Ioo`03
001oogoo00Qoo`03001oogoo01]oo`03O01oogoo0<Ioo`03001oogoo01Eoo`005goo00<007ooOol0
1goo00<007ooOol077oo00=l07ooOol0a7oo00<007ooOol05Woo000GOol00`00Oomoo`07Ool00`00
Oomoo`0MOol00g`0Oomoo`33Ool00`00Oomoo`0FOol001Moo`03001oogoo00Moo`03001oogoo01io
o`03O01oogoo0<9oo`03001oogoo01Ioo`0067oo00<007ooOol0:7oo00=l07ooOol0`7oo00<007oo
Ool05goo000HOol00`00Oomoo`0YOol00g`0Oomoo`2oOol00`00Oomoo`0GOol001Uoo`03001oogoo
02Uoo`03O01oogoo0;eoo`03001oogoo01Qoo`006Woo00<007ooOol0:Goo00=l07ooOol0^goo00<0
07ooOol06Goo000JOol00`00Oomoo`0ZOol00g`0Oomoo`2jOol00`00Oomoo`0IOol001]oo`03001o
ogoo02Yoo`9l0;Uoo`03001oogoo01Yoo`006goo00<007ooOol0;7oo00=l07ooOol0]Woo00<007oo
Ool06Woo000LOol00`00Oomoo`0/Ool00g`0Oomoo`2dOol00`00Oomoo`0KOol001aoo`03001oogoo
02eoo`03O01oogoo0;=oo`03001oogoo01]oo`007Goo00<007ooOol0;Goo00=l07ooOol0/Goo00<0
07ooOol077oo000MOol00`00Oomoo`0^Ool00g`0Oomoo`2`Ool00`00Oomoo`0LOol001ioo`03001o
ogoo02ioo`03O01oogoo0:ioo`03001oogoo01eoo`007Woo00<007ooOol0;goo00=l07ooOol0[Goo
00<007ooOol07Goo000OOol00`00Oomoo`0_Ool00g`0Oomoo`2[Ool00`00Oomoo`0NOol001moo`03
001oogoo031oo`03O01oogoo0:Yoo`03001oogoo01ioo`0087oo00<007ooOol0<7oo00=l07ooOol0
Z7oo00<007ooOol07goo000POol00`00Oomoo`0aOol00g`0Oomoo`2WOol00`00Oomoo`0OOol0025o
o`03001oogoo035oo`03O01oogoo0:Eoo`03001oogoo021oo`008Goo00<007ooOol0<Woo00=l07oo
Ool0Y7oo00<007ooOol087oo000ROol00`00Oomoo`0bOol00g`0Oomoo`2ROol00`00Oomoo`0QOol0
02=oo`03001oogoo039oo`03O01oogoo0:1oo`03001oogoo029oo`0097oo00<007ooOol0<Woo00=l
07ooOol0WWoo00<007ooOol08goo000TOol00`00Oomoo`0cOol00g`0Oomoo`2MOol00`00Oomoo`0S
Ool002Eoo`03001oogoo03=oo`03O01oogoo09]oo`03001oogoo02Aoo`009Woo00<007ooOol0<goo
00=l07ooOol0VGoo00<007ooOol09Goo000VOol00`00Oomoo`0dOol00g`0Oomoo`2HOol00`00Oomo
o`0UOol002Moo`03001oogoo03Aoo`03O01oogoo09Ioo`03001oogoo02Ioo`00:7oo00<007ooOol0
=7oo00=l07ooOol0UGoo00<007ooOol09Woo000XOol00`00Oomoo`0eOol00g`0Oomoo`2COol00`00
Oomoo`0WOol002Uoo`03001oogoo03Eoo`03O01oogoo095oo`03001oogoo02Qoo`00:Goo00<007oo
Ool0=Woo00=l07ooOol0T7oo00<007ooOol0:7oo000ZOol00`00Oomoo`0fOol00g`0Oomoo`2>Ool0
0`00Oomoo`0YOol002]oo`03001oogoo03Ioo`9l08eoo`03001oogoo02Yoo`00;7oo00<007ooOol0
=goo00=l07ooOol0RGoo00<007ooOol0:goo000]Ool00`00Oomoo`0gOol00g`0Oomoo`27Ool00`00
Oomoo`0/Ool002ioo`03001oogoo03Moo`03O01oogoo08Eoo`03001oogoo02eoo`00;goo00<007oo
Ool0=goo00=l07ooOol0Pgoo00<007ooOol0;Woo000`Ool00`00Oomoo`0gOol00g`0Oomoo`21Ool0
0`00Oomoo`0_Ool0035oo`03001oogoo03Moo`03O01oogoo07moo`03001oogoo031oo`00<Woo00<0
07ooOol0=goo00=l07ooOol0OGoo00<007ooOol0<Goo000cOol00`00Oomoo`0gOol00g`0Oomoo`1k
Ool00`00Oomoo`0bOol003Aoo`03001oogoo03Moo`03O01oogoo07Uoo`03001oogoo03=oo`00=7oo
00<007ooOol0>7oo00=l07ooOol0N7oo00<007ooOol0<goo000eOol00`00Oomoo`0hOol00g`0Oomo
o`1fOol00`00Oomoo`0dOol003Ioo`8003Uoo`03O01oogoo07=oo`8003Moo`00>7oo00<007ooOol0
=goo00=l07ooOol0LGoo00<007ooOol0=goo000iOol00`00Oomoo`0gOol00g`0Oomoo`1_Ool00`00
Oomoo`0hOol003Yoo`03001oogoo03Moo`03O01oogoo06eoo`03001oogoo03Uoo`00>goo00<007oo
Ool0=goo00=l07ooOol0Jgoo00<007ooOol0>Woo000lOol00`00Oomoo`0gOol00g`0Oomoo`1YOol0
0`00Oomoo`0kOol003eoo`8003Qoo`03O01oogoo06Ioo`8003ioo`00?goo00<007ooOol0=Woo00=l
07ooOol0I7oo00<007ooOol0?Woo0010Ool00`00Oomoo`0fOol00g`0Oomoo`1ROol00`00Oomoo`0o
Ool0045oo`03001oogoo03Ioo`03O01oogoo061oo`03001oogoo041oo`00@Woo0P00=goo00=l07oo
Ool0GGoo0P00@goo0014Ool00`00Oomoo`0eOol00g`0Oomoo`1KOol00`00Oomoo`13Ool004Eoo`80
03Ioo`03O01oogoo05Qoo`8004Ioo`00Agoo00<007ooOol0=7oo00=l07ooOol0EWoo00<007ooOol0
AWoo0018Ool00`00Oomoo`0dOol00g`0Oomoo`1DOol00`00Oomoo`17Ool004Uoo`8003Eoo`9l059o
o`8004Yoo`00Bgoo0P00=Goo00=l07ooOol0CGoo0P00C7oo001=Ool2000dOol00g`0Oomoo`1:Ool2
001>Ool004moo`03001oogoo039oo`03O01oogoo04Qoo`03001oogoo04ioo`00D7oo00<007ooOol0
<Woo00=l07ooOol0AWoo00<007ooOol0Cgoo001AOol2000cOol00g`0Oomoo`13Ool2001BOol005=o
o`<0035oo`03O01oogoo03moo`<005Aoo`00EWoo0P00<7oo00=l07ooOol0?7oo0P00Egoo001HOol2
000_Ool00g`0Oomoo`0iOol2001IOol005Yoo`8002ioo`03O01oogoo03Ioo`8005]oo`00G7oo0`00
;7oo00=l07ooOol0<Woo0`00GGoo001OOol3000ZOol00g`0Oomoo`0^Ool3001POol0069oo`<002Qo
o`03O01oogoo02Yoo`<006=oo`00IGoo0`009Woo00=l07ooOol09Woo0`00IWoo001XOol3000TOol0
0g`0Oomoo`0ROol3001YOol006]oo`<004=oo`<006aoo`00KWoo0`00?Goo0`00Kgoo001aOol5000c
Ool5001bOol007Ioo`@002]oo`@007Moo`00NWoo20006goo2000Ngoo0022OolK0023Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002<Ool3002AOol008eoo`03001oogoo091oo`00SGoo00<007oo
Ool0T7oo001ROol40004Ool50004Ool40002Ool300001Goo000007oo000037oo10000goo1`000Woo
0`0000=oo`0000000Woo100017oo1@000goo1@00IWoo001SOol00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000aoo`05001oogooOol00005Ool00`00
Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol00Woo00@007ooOol000Yoo`03001oogoo06Io
o`00Hgoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo000<Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Mo
o`03001oogoo00Qoo`03001oogoo06Ioo`00Hgoo00<007oo00001Goo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo000<Ool01@00Oomoogoo00001Goo00<007ooOol00goo
1@000Woo00<007ooOol01Goo1P001Goo00<007ooOol0IWoo001SOol30005Ool20005Ool00`00Oomo
o`02Ool00`00Oomoo`0200001Goo000007oo000037oo0P000Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000=oo`80009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo06Ioo`00Hgoo00D007oo001oo`00009oo`800004Ool000000003Ool40002Ool200001Goo
001oogoo000037oo0P0000=oo`0000001Woo00<007ooOol00goo100017oo0`0000=oo`00Ool00Woo
10001Woo00<007ooOol0IWoo001SOol01@00Oomoogoo0000;goo00<007ooOol07Goo00<007ooOol0
IWoo001ROol6000_Ool00`00Oomoo`0KOol3001XOol009Ioo`8001moo`03001oogoo06Ioo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-376.995, -363.004, 2.48777, \
2.79875}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(graph5\)\(=\)\(See[SpeedPairPlot2[To[{\(-300\), 95}, 50]], 
        PlotLabel -> 
          StyleForm["\<To place 1\>", FontSize -> 14]]\)\(\n\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -43.875 0 ]
[.5 1.0125 43.875 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -104.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(To) show
88.125 13.750 moveto
(place) show
138.375 13.750 moveto
(1) show
146.750 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.05804 .52249 m
.08036 .6627 L
s
.04911 .53836 m
.09226 .63228 L
s
.2247 .75661 m
.09375 .62037 L
s
.0744 .66402 m
.04911 .57804 L
s
.06101 .57011 m
.05804 .57407 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.38542 .44048 m
.07143 .54101 L
s
.06696 .54101 m
.06101 .5463 L
s
.05506 .55556 m
.09077 .57804 L
s
.08036 .57804 m
.08631 .56746 L
s
.0878 .56085 m
.07887 .54365 L
s
.14137 .79101 m
.0506 .57011 L
s
.46429 .95503 m
.06101 .6164 L
s
.0625 .61508 m
.09077 .61905 L
s
.10417 .62169 m
.09375 .62963 L
s
.07143 .64021 m
.0997 .66005 L
s
.0997 .66005 m
.11161 .64683 L
s
.17262 .60847 m
.08036 .64153 L
s
.07738 .64683 m
.07292 .65344 L
s
.07143 .66138 m
.12946 .65608 L
s
.13244 .65476 m
.1369 .64153 L
s
.0506 .53571 m
.0625 .55556 L
s
.1369 .5582 m
.12946 .56481 L
s
.125 .56746 m
.08631 .57937 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0023OolI0024Ool007]oo`P0
01Uoo`P007aoo`00MGoo1P00:Goo1P00MWoo001bOol3000eOol3001cOol006eoo`D003]oo`D006io
o`00JWoo0`00AGoo0`00Jgoo001WOol3001;Ool2001YOol006Eoo`80051oo`@006Eoo`00HWoo0`00
EWoo0P00Hgoo001OOol3001KOol3001POol005aoo`<0065oo`<005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Ioo`8006moo`8005Moo`00E7oo0P00Lgoo0P00EGoo001COol00`00
Oomoo`1eOol2001COol0055oo`8007Yoo`80055oo`00Cgoo0P00OWoo00<007ooOol0CWoo001=Ool2
0021Ool2001>Ool004]oo`8008Eoo`03001oogoo04]oo`00BGoo0P00R7oo0P00Bgoo0018Ool00`00
Oomoo`2:Ool20019Ool004Moo`03001oogoo08eoo`03001oogoo04Ioo`00AGoo0P00TGoo0P00AWoo
0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0049oo`8009Moo`8004=oo`00@Goo00<007ooOol0
VGoo00<007ooOol0@7oo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003moo`03001oogoo09eo
o`03001oogoo03ioo`00?Goo0P00XGoo0P00?Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol0
03]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo00<007ooOol0>Goo000i
Ool00`00Oomoo`2YOol2000iOol003Qoo`03001oogoo0:aoo`03001oogoo03Ioo`00=Woo0P00/7oo
00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03001oogoo0;=oo`03
001oogoo03=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000cOol00`00Oomoo`2eOol00`00
Oomoo`0bOol0039oo`03001oogoo0;Moo`03001oogoo035oo`00<Goo00<007ooOol0^Goo00<007oo
Ool0<7oo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool002moo`03001oogoo0;eoo`03001oogoo
02ioo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/
Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo
000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00
:Goo00<007ooOol0bGoo00<007ooOol0:7oo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Qo
o`03001oogoo0<aoo`03001oogoo02Ioo`009goo00<007ooOol0cGoo00<007ooOol09Woo000VOol0
0`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Goo00<0
07ooOol0dGoo00<007ooOol097oo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000ROol00`00Oomo
o`3GOol00`00Oomoo`0QOol0025oo`03001oogoo0=Qoo`03001oogoo025oo`008Goo00<007ooOol0
fGoo00<007ooOol087oo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]o
o`03001oogoo01moo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol0
0`00Oomoo`0NOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<0
07ooOol07Goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001o
ogoo01aoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomo
o`0KOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol0
6Woo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uo
o`006Goo00<007ooOol0jGoo00<007ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol0
01Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000G
Ool00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03
001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00
Oomoo`3`Ool00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Aoo`03001oogoo
0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3d
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo
00<007ooOol04Woo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03
001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00
Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo
011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@
Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo
000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo05aoo`8009ioo`03001oogoo00ioo`003goo00<007ooOol0FWoo0`00X7oo00<007oo
Ool03Woo000?Ool00`00Oomoo`1GOol3002SOol00`00Oomoo`0>Ool000moo`03001oogoo05Aoo`<0
0:Ioo`03001oogoo00ioo`003goo00<007ooOol0DGoo0`00ZGoo00<007ooOol03Woo000?Ool00`00
Oomoo`1>Ool3002/Ool00`00Oomoo`0>Ool000moo`03001oogoo04]oo`<00:moo`03001oogoo00io
o`003goo00<007ooOol0B7oo0`00/Woo00<007ooOol03Woo000?Ool00`00Oomoo`15Ool3002eOol0
0`00Oomoo`0>Ool000moo`03001oogoo049oo`<00;Qoo`03001oogoo00ioo`003goo00<007ooOol0
?goo0`00^goo00<007ooOol03Woo000?Ool00`00Oomoo`0lOol3002oOol00`00Oomoo`0=Ool000io
o`03001oogoo03Yoo`<00<9oo`03001oogoo00eoo`003Woo00<007ooOol0=goo0`00aGoo00<007oo
Ool03Goo000>Ool00`00Oomoo`0cOol40038Ool00`00Oomoo`0=Ool000ioo`03001oogoo031oo`<0
0<aoo`03001oogoo00eoo`003Woo00<007ooOol0;Goo0`00cgoo00<007ooOol03Goo000>Ool00`00
Oomoo`0ZOol3003BOol00`00Oomoo`0=Ool000ioo`03001oogoo02Moo`<00=Eoo`03001oogoo00eo
o`003Woo00<007ooOol097oo0`00f7oo00<007ooOol03Goo000>Ool00`00Oomoo`0QOol3003KOol0
0`00Oomoo`0=Ool000ioo`03001oogoo01ioo`<00=ioo`03001oogoo00eoo`003goo00<007ooOol0
6Woo0`00hGoo00<007ooOol03Goo000?Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool3003SOol00`00
Oomoo`0>Ool000moo`03001oogoo00Ioo`03001oogoo00]oo`<00>Ioo`03001oogoo00ioo`003goo
00<007ooOol01Woo00<007ooOol027oo0`00jGoo00<007ooOol03Woo000?Ool00`00Oomoo`04Ool0
0`00Ool00007Ool3003/Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`05001oo`00Ool00003
Ool3003_Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`04001oo`00Ool5003aOol00`00Oomo
o`0>Ool000moo`03001oogoo00Aoo`04001oo`000004Ool00`00Oomoo`3^Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Aoo`04001oo`000004Ool00`00Oomoo`3^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Eoo`03001oo`0000Eoo`03001oogoo0>eoo`03001oogoo00ioo`003goo00<007ooOol0
1Goo00<007oo00001Goo00<007ooOol02goo00<007ooOol0ggoo00<007ooOol03Woo000?Ool00`00
Oomoo`06Ool30005Ool00`00Oomoo`09Ool00`00Oomoo`3POol00`00Oomoo`0>Ool0011oo`03001o
ogoo00Eoo`03001oo`00011oo`03001oogoo0>1oo`03001oogoo00moo`0047oo00<007ooOol00goo
00<007oo000010000Woo00<007ooOol01goo0P00hgoo00<007ooOol03goo000@Ool00`00Oomoo`03
Ool00`00Ool000020002Ool00`00Ool00005Ool4003UOol00`00Oomoo`0?Ool0011oo`03001oogoo
00Aoo`800003Ool007oo009oo`800003Ool0000000800>Uoo`03001oogoo00moo`0047oo00<007oo
Ool00Woo00<007oo00000Woo0`0000Aoo`0000000>eoo`03001oogoo00moo`0047oo00<007ooOol0
0Woo00@007ooOol0009oo`04001oo`00003_Ool00`00Oomoo`0?Ool0015oo`03001oogoo009oo`03
001oo`00009oo`04001oogooOol2003/Ool00`00Oomoo`0@Ool0015oo`03001oogoo009oo`03001o
o`00009oo`8000Aoo`800>Yoo`03001oogoo011oo`004Goo00<007ooOol00Woo00D007ooOol007oo
008000Ioo`800>Qoo`03001oogoo011oo`004Goo00<007ooOol00goo00L007oo001oo`00Ool00007
Ool00`00Oomoo`3UOol00`00Oomoo`0@Ool0015oo`03001oogoo00=oo`03001oogoo00800003Ool0
07oo0>ioo`03001oogoo011oo`004Woo00<007ooOol00Woo00<007ooOol00P000Woo00<007ooOol0
1Woo0`00hWoo00<007ooOol04Goo000BOol00`00Oomoo`02Ool02000Oomoo`00Ool007oo000;Ool5
0007Ool2003DOol00`00Oomoo`0AOol0019oo`03001oogoo00=oo`03001oogoo0080009oo`03001o
ogoo00eoo`<00004Ool00000003FOol00`00Oomoo`0AOol0019oo`03001oogoo00=oo`D0009oo`03
001oogoo00moo`800=Uoo`03001oogoo015oo`004goo00<007ooOol00Woo0P000Woo1P000Woo00<0
07ooOol01goo0`00fgoo00<007ooOol04Goo000COol00`00Oomoo`03Ool200000goo001oo`02Ool0
1000Ool000001goo0`00gGoo00<007ooOol04Woo000COol00`00Oomoo`03Ool01000Ool0000017oo
0`0017oo0`00h7oo00<007ooOol04Woo000DOol00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07ooOol01000hgoo00<007ooOol04Woo000DOol00`00Oomoo`03Ool00`00Oomoo`020004Ool3003T
Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`800003Ool0000000@000=oo`03001oogoo0>5o
o`03001oogoo01=oo`005Goo00<007ooOol00Woo00<007oo000010001Woo00<007ooOol00goo00<0
07ooOol0fWoo00<007ooOol04goo000EOol00`00Oomoo`02Ool00`00Oomoo`020002Ool20003Ool0
0`00Ool00004Ool00`00Oomoo`3IOol00`00Oomoo`0DOol001Eoo`03001oogoo00=oo`05001oo`00
Ool00003Ool00`00Ool00003Ool01000Oomoo`00g7oo00<007ooOol057oo000EOol00`00Oomoo`03
Ool200000goo000000020002Ool20004Ool00`00Ool0003LOol00`00Oomoo`0DOol001Eoo`03001o
ogoo00=oo`07001oogoo001oo`00Ool02P00gGoo00<007ooOol057oo000FOol00`00Oomoo`02Ool9
0002Ool00`00Oomoo`03Ool00`00Oomoo`3IOol00`00Oomoo`0EOol001Ioo`03001oogoo00=oo`05
001oo`00Ool00006Ool20004Ool00`00Oomoo`3HOol00`00Oomoo`0EOol001Ioo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo0=Moo`03001oogoo01Eoo`005goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0eGoo00<007ooOol05Woo000GOol0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`3DOol00`00Oomoo`0FOol0
01Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0==oo`03001oogoo
01Ioo`0067oo00<007ooOol01goo00<007ooOol027oo0P000goo00<007ooOol0dGoo00<007ooOol0
5goo000HOol00`00Oomoo`08Ool00`00Oomoo`09Ool01@00Oomoogoo0000dWoo00<007ooOol05goo
000IOol00`00Oomoo`07Ool00`00Oomoo`0:Ool01000Oomoo`00dGoo00<007ooOol067oo000JOol0
0`00Oomoo`07Ool00`00Oomoo`0:Ool01000Oomoo`00cgoo00<007ooOol06Goo000JOol00`00Oomo
o`07Ool00`00Oomoo`0;Ool01000Oomoo`00cWoo00<007ooOol06Goo000KOol00`00Oomoo`06Ool0
0`00Oomoo`0<Ool200000goo001oo`3;Ool00`00Oomoo`0JOol001]oo`03001oogoo00Moo`03001o
ogoo00eoo`03001oo`000<]oo`03001oogoo01Yoo`0077oo00<007ooOol01Woo00<007ooOol03Woo
00<007oo0000bGoo00<007ooOol06goo000LOol00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Ool0
0038Ool00`00Oomoo`0KOol001eoo`03001oogoo00Ioo`03001oogoo00moo`03001oo`000<Ioo`03
001oogoo01aoo`007Goo00<007ooOol01Woo00<007ooOol047oo0`00aGoo00<007ooOol077oo000N
Ool00`00Oomoo`06Ool00`00Oomoo`0AOol20033Ool00`00Oomoo`0MOol001ioo`03001oogoo00Io
o`03001oogoo019oo`800<9oo`03001oogoo01eoo`007goo00<007ooOol01Woo00<007ooOol04Woo
0P00`7oo00<007ooOol07Woo000OOol00`00Oomoo`06Ool00`00Oomoo`0COol2002oOol00`00Oomo
o`0NOol0021oo`03001oogoo00Eoo`03001oogoo01Aoo`800;eoo`03001oogoo01moo`0087oo00<0
07ooOol01Woo00<007ooOol05Goo00<007ooOol0^Woo00<007ooOol07goo000QOol00`00Oomoo`05
Ool00`00Oomoo`0FOol00`00Oomoo`2hOol00`00Oomoo`0POol0025oo`03001oogoo00Ioo`03001o
ogoo01Ioo`03001oogoo0;Moo`03001oogoo021oo`008Woo00<007ooOol01Goo00<007ooOol05goo
00<007ooOol0]Goo00<007ooOol08Goo000SOol00`00Oomoo`04Ool00`00Oomoo`0HOol2002dOol0
0`00Oomoo`0ROol002Aoo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo0;1oo`03001oogoo
02=oo`0097oo00<007ooOol017oo00<007ooOol06Woo00<007ooOol0[goo00<007ooOol08goo000U
Ool00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`2]Ool00`00Oomoo`0TOol002Ioo`03001o
ogoo00=oo`03001oogoo01]oo`03001oogoo0:]oo`03001oogoo02Eoo`009Woo00<007ooOol00goo
00<007ooOol077oo0P00Zgoo00<007ooOol09Goo000WOol00`00Oomoo`03Ool00`00Oomoo`0MOol0
0`00Oomoo`2WOol00`00Oomoo`0VOol002Qoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo
0:Ioo`03001oogoo02Ioo`00:7oo00<007ooOol00goo00<007ooOol07Woo00<007ooOol0Y7oo00<0
07ooOol09goo000YOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`2ROol00`00Oomoo`0X
Ool002Uoo`03001oogoo02Eoo`800:9oo`03001oogoo02Qoo`00:Woo00<007ooOol09Woo00<007oo
Ool0WWoo00<007ooOol0:Goo000[Ool00`00Oomoo`0VOol00`00Oomoo`2LOol00`00Oomoo`0ZOol0
02aoo`03001oogoo02Ioo`03001oogoo09Yoo`03001oogoo02]oo`00;Goo00<007ooOol09Woo00<0
07ooOol0V7oo00<007ooOol0;7oo000^Ool00`00Oomoo`0VOol2002GOol00`00Oomoo`0]Ool002mo
o`03001oogoo02Moo`03001oogoo09=oo`03001oogoo02ioo`00<7oo00<007ooOol09goo00<007oo
Ool0TGoo00<007ooOol0;goo000aOol00`00Oomoo`0WOol00`00Oomoo`2?Ool00`00Oomoo`0`Ool0
039oo`03001oogoo02Moo`03001oogoo08eoo`03001oogoo035oo`00<goo00<007ooOol09goo0P00
S7oo00<007ooOol0<Woo000dOol00`00Oomoo`0XOol00`00Oomoo`28Ool00`00Oomoo`0cOol003Ao
o`03001oogoo02Uoo`03001oogoo08Moo`03001oogoo03=oo`00=Goo00<007ooOol0:Goo00<007oo
Ool0QGoo00<007ooOol0=7oo000fOol2000ZOol00`00Oomoo`22Ool2000gOol003Qoo`03001oogoo
02Qoo`80085oo`03001oogoo03Moo`00>Goo00<007ooOol0:Goo00<007ooOol0OGoo00<007ooOol0
>7oo000jOol00`00Oomoo`0YOol00`00Oomoo`1kOol00`00Oomoo`0iOol003]oo`03001oogoo02Uo
o`03001oogoo07Uoo`03001oogoo03Yoo`00?7oo00<007ooOol0:Goo00<007ooOol0Mgoo00<007oo
Ool0>goo000mOol2000ZOol2001eOol2000nOol003moo`03001oogoo02Uoo`03001oogoo075oo`03
001oogoo03ioo`00@7oo00<007ooOol0:Goo00<007ooOol0Kgoo00<007ooOol0?goo0011Ool00`00
Oomoo`0YOol00`00Oomoo`1]Ool00`00Oomoo`10Ool0049oo`8002Yoo`03001oogoo06Yoo`8004=o
o`00A7oo00<007ooOol0:7oo0P00JGoo00<007ooOol0@goo0015Ool2000ZOol00`00Oomoo`1TOol2
0016Ool004Moo`03001oogoo02Qoo`03001oogoo069oo`03001oogoo04Ioo`00B7oo00<007ooOol0
:7oo00<007ooOol0H7oo00<007ooOol0Agoo0019Ool2000YOol00`00Oomoo`1MOol2001:Ool004]o
o`8002Qoo`8005]oo`8004aoo`00CGoo0P00:7oo00<007ooOol0EWoo0P00CWoo001?Ool00`00Oomo
o`0VOol00`00Oomoo`1DOol00`00Oomoo`1>Ool0051oo`03001oogoo02Ioo`03001oogoo059oo`03
001oogoo04moo`00DGoo0P009goo00<007ooOol0Cgoo0P00DWoo001COol3000UOol2001<Ool3001D
Ool005Ioo`8002Eoo`03001oogoo04Moo`8005Moo`00F7oo0P0097oo00<007ooOol0A7oo0P00FGoo
001JOol2000SOol00`00Oomoo`11Ool2001KOol005aoo`<0025oo`03001oogoo03eoo`<005eoo`00
Ggoo0`007goo0P00>Woo0`00H7oo001ROol3000NOol00`00Oomoo`0dOol3001SOol006Eoo`<001ao
o`03001oogoo031oo`<006Ioo`00J7oo0`006Woo00<007ooOol0;7oo0`00JGoo001[Ool30013Ool3
001/Ool006ioo`<003eoo`<006moo`00LGoo1@00<goo1@00LWoo001fOol4000[Ool4001gOol007Yo
o`P001]oo`P007]oo`00PWoo6`00Pgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ogoo0`00
WWoo0020Ool00`00Oomoo`2MOol0081oo`03001oogoo09eoo`00Igoo1@000goo10003Goo10000goo
1`000Woo0`0000=oo`0000000Woo100017oo1@003Woo1@00J7oo001YOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00@007ooOomoo`80
009oo`03001oogoo009oo`04001oogoo000EOol00`00Oomoo`1XOol006Uoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Yoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`001goo00<007ooOol04goo00<007ooOol0J7oo001YOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<007ooOol00goo1@000Woo00<007oo
Ool01Goo1P0047oo00<007ooOol0J7oo001YOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo
0P000Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0J7oo001VOol01000Oomoo`000Woo
00<007ooOol0100037oo0P0000=oo`0000001Woo00<007ooOol00goo100017oo0`0000=oo`00Ool0
0Woo10004Goo00<007ooOol0J7oo001VOol01000Oomoo`000Woo00<007ooOol06goo00<007ooOol0
:7oo00<007ooOol0J7oo001VOol7000MOol00`00Oomoo`0VOol3001ZOol008Uoo`8002Yoo`03001o
ogoo06Qoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-376.995, -363.004, 2.48777, \
2.79875}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The built in Mathematics function Show allows us to see all the figures \
within one figure:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{graph1, graph2, graph3, graph4, 
            graph5}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .18519 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00440917 0.190476 [
[ 0 0 0 0 ]
[ 1 .18519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .18519 L
0 .18519 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00440917 0.200176 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -14.5625 0 ]
[.5 1.0125 14.5625 13.3125 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.3125 translate 1 -1 scale
63.000 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(All) show
88.125 13.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.56845 .94841 m
.6369 .9246 L
s
.6369 .9246 m
.55804 .94841 L
s
.55357 .95106 m
.3497 .93386 L
s
.3497 .93254 m
.52083 .95503 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.5744 .94577 m
.73363 .88228 L
s
.73363 .88095 m
.79315 .83995 L
s
.78423 .83995 m
.64435 .92328 L
s
.62202 .93386 m
.55952 .94841 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.4628 .95635 m
.51786 .95503 L
s
.52679 .9537 m
.66964 .87698 L
s
.67113 .87037 m
.72768 .88757 L
s
.72768 .87566 m
.55952 .94841 L
s
.5506 .94577 m
.55952 .89021 L
s
.55952 .89021 m
.46875 .95635 L
s
.4375 .94974 m
.48958 .95767 L
s
.52679 .95635 m
.70685 .90344 L
s
.71429 .89815 m
.82143 .81349 L
s
.82143 .80952 m
.8378 .77778 L
s
.88244 .74868 m
.8006 .8373 L
s
.79762 .83862 m
.55952 .94444 L
s
.54315 .93386 m
.3244 .92063 L
s
1 0 0 r
.3244 .92063 m
.52083 .94974 L
s
0 0 0 r
.5253 .94709 m
.61161 .93783 L
s
.62202 .93915 m
.64732 .9246 L
s
.65179 .92328 m
.76339 .86243 L
s
.76935 .85847 m
.82143 .76058 L
s
1 0 0 r
.81994 .75794 m
.56845 .94841 L
s
0 0 0 r
.55804 .94841 m
.70685 .90344 L
s
.70685 .89947 m
.85565 .77513 L
s
.84524 .77381 m
.80655 .79233 L
s
1 0 0 r
.79911 .75926 m
.55952 .94444 L
s
.55506 .94709 m
.11012 .73413 L
s
.11012 .73413 m
.50149 .95635 L
s
0 0 0 r
.55506 .9537 m
.74554 .87566 L
s
.75 .87302 m
.83482 .80291 L
s
.84077 .79101 m
.92857 .67328 L
s
.93601 .6627 m
.94643 .59788 L
s
1 0 0 r
.94643 .59656 m
.59673 .94048 L
s
0 0 0 r
.61905 .93783 m
.6875 .89947 L
s
.66964 .87302 m
.55804 .9418 L
s
.55506 .93783 m
.55952 .89153 L
s
.55952 .89153 m
.45982 .95635 L
s
.47619 .95899 m
.52083 .95503 L
s
.54464 .95767 m
.80952 .77646 L
s
.81101 .7619 m
.83185 .64418 L
s
.83185 .64153 m
.7872 .55159 L
s
1 0 0 r
.7872 .55159 m
.61012 .93783 L
s
0 0 0 r
.60119 .93915 m
.52679 .93915 L
s
.5253 .93915 m
.3869 .93386 L
s
.38244 .9246 m
.22768 .82011 L
s
1 0 0 r
.22768 .82011 m
.51637 .95503 L
s
0 0 0 r
.53274 .96032 m
.57589 .9418 L
s
1 0 0 r
.56994 .94312 m
.76935 .86111 L
s
0 0 0 r
.77083 .86111 m
.8378 .79101 L
s
.84226 .78836 m
.88542 .74735 L
s
.88542 .74603 m
.81399 .7672 L
s
1 0 0 r
.81548 .7619 m
.55952 .9418 L
s
0 0 0 r
.58631 .92196 m
.66071 .87169 L
s
.66667 .86508 m
.44196 .90476 L
s
.44345 .89815 m
.52083 .94444 L
s
1 0 0 r
.54018 .96164 m
.73661 .88228 L
s
0 0 0 r
.73661 .87963 m
.80804 .78042 L
s
.79762 .75926 m
.58482 .73942 L
s
1 0 0 r
.58482 .73942 m
.49107 .95635 L
s
0 0 0 r
.48363 .95635 m
.44643 .9537 L
s
.44048 .9418 m
.47024 .95899 L
s
.54911 .94841 m
.70982 .89947 L
s
.71726 .8955 m
.79464 .83862 L
s
.80208 .83598 m
.81845 .78968 L
s
.80208 .76323 m
.96429 .43254 L
s
.88839 .42196 m
.82738 .7619 L
s
.82589 .7672 m
.68155 .91402 L
s
.66071 .91799 m
.6756 .87302 L
s
.6756 .87169 m
.70238 .8955 L
s
.73512 .88624 m
.78571 .84921 L
s
.79464 .84392 m
.55655 .94841 L
s
.54315 .96429 m
.1131 .71296 L
s
.11161 .71164 m
.05506 .52249 L
s
.05804 .52249 m
.08036 .6627 L
s
.08333 .67196 m
.21875 .82143 L
s
.22173 .81217 m
.5119 .95503 L
s
.52381 .96032 m
.77827 .85317 L
s
.78423 .85053 m
.81994 .7672 L
s
.81696 .76323 m
.96429 .3955 L
s
.96131 .39153 m
.87202 .26323 L
s
1 0 0 r
.86756 .26323 m
.60565 .94048 L
s
0 0 0 r
.64881 .91667 m
.66815 .87566 L
s
.66815 .87434 m
.22917 .87698 L
s
1 0 0 r
.24256 .88757 m
.5 .95767 L
s
0 0 0 r
.54167 .96164 m
.69792 .90873 L
s
.70238 .90608 m
.80952 .82937 L
s
.8125 .83069 m
.96875 .53571 L
s
1 0 0 r
.97024 .53968 m
.56101 .94841 L
s
0 0 0 r
.59375 .9418 m
.69643 .90344 L
s
.70089 .89947 m
.75446 .84921 L
s
.75595 .85053 m
.79315 .76984 L
s
.8006 .76852 m
.89732 .72884 L
s
.89732 .7381 m
.95685 .42725 L
s
.96726 .41931 m
.92262 .33862 L
s
.93006 .33201 m
.70685 .12169 L
s
.6994 .12566 m
.65774 .09788 L
s
.66369 .10053 m
.62054 .14286 L
s
.62202 .14683 m
.67113 .14021 L
s
1 0 0 r
.6756 .13757 m
.82292 .79762 L
s
0 0 0 r
.81548 .76323 m
.5744 .94048 L
s
.61161 .93783 m
.65476 .91005 L
s
.65774 .90476 m
.67262 .87302 L
s
.65327 .85847 m
.35417 .92063 L
s
.35714 .91005 m
.50149 .95635 L
s
.55506 .94974 m
.95685 .51587 L
s
.96875 .51852 m
.95536 .3664 L
s
.95685 .37302 m
.87054 .26323 L
s
.86607 .26323 m
.85863 .21296 L
s
.85714 .19974 m
.73214 .12566 L
s
.72917 .12302 m
.69792 .11772 L
s
.69196 .1164 m
.20089 .20899 L
s
.19643 .21164 m
.0506 .44048 L
s
.0506 .44709 m
.05357 .48545 L
s
.04911 .53836 m
.09226 .63228 L
s
.12946 .62698 m
.21429 .66005 L
s
1 0 0 r
.21875 .66138 m
.74256 .8664 L
s
0 0 0 r
.74851 .86772 m
.79167 .76587 L
s
.78423 .75397 m
.66667 .63228 L
s
1 0 0 r
.65923 .64286 m
.79464 .80159 L
s
0 0 0 r
.79018 .80026 m
.79464 .77646 L
s
.78423 .74603 m
.51786 .71693 L
s
.51339 .71296 m
.10417 .38757 L
s
.10417 .38889 m
.2753 .18254 L
s
.28869 .1918 m
.56399 .17593 L
s
1 0 0 r
.55655 .18122 m
.6131 .92328 L
s
0 0 0 r
.58185 .90476 m
.49256 .93783 L
s
.47768 .90344 m
.24554 .81481 L
s
.24256 .80556 m
.22768 .7619 L
s
.2247 .75661 m
.09375 .62037 L
s
1 0 0 r
.13244 .62963 m
.1994 .36772 L
s
0 0 0 r
.20089 .37037 m
.05506 .41667 L
s
.05506 .41931 m
.20387 .20503 L
s
.20685 .2037 m
.60119 .14683 L
s
1 0 0 r
.60714 .14815 m
.56696 .93783 L
s
0 0 0 r
.5506 .94974 m
.56696 .84656 L
s
1 0 0 r
.56845 .83995 m
.10119 .7209 L
s
0 0 0 r
.0744 .66402 m
.04911 .57804 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.14583 .61111 m
.5997 .17063 L
s
.60268 .16799 m
.85714 .20503 L
s
.85863 .21032 m
.85417 .25132 L
s
1 0 0 r
.85417 .25265 m
.60268 .92196 L
s
0 0 0 r
.59673 .92328 m
.48065 .94974 L
s
.53274 .96032 m
.70238 .90344 L
s
.70685 .90212 m
.78274 .85185 L
s
.79315 .84127 m
.82292 .76984 L
s
.82887 .7619 m
.94048 .40344 L
s
1 0 0 r
.95685 .38228 m
.46875 .0873 L
s
0 0 0 r
.45833 .08862 m
.37202 .11111 L
s
.36756 .11243 m
.2753 .17593 L
s
.28571 .1918 m
.05506 .47751 L
s
.04464 .50661 m
.07143 .46429 L
s
.07589 .46164 m
.3869 .4418 L
s
.38542 .44048 m
.07143 .54101 L
s
.05506 .55556 m
.09077 .57804 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.54315 .95635 m
.73661 .88095 L
s
.7381 .88889 m
.90923 .6918 L
s
.91369 .69312 m
.95982 .5582 L
s
.95833 .55556 m
.95238 .4246 L
s
.96875 .40873 m
.8869 .23148 L
s
.88988 .23016 m
.79911 .15079 L
s
.79464 .14947 m
.69494 .11243 L
s
.68155 .10582 m
.59524 .09524 L
s
.62798 .09392 m
.6131 .1455 L
s
.6131 .15212 m
.56994 .08333 L
s
.55804 .08201 m
.49256 .08069 L
s
.46875 .08069 m
.37946 .10185 L
s
.37649 .10185 m
.17113 .23016 L
s
.14435 .25265 m
.22619 .24735 L
s
.2247 .25 m
.09226 .41534 L
s
1 0 0 r
.0997 .41402 m
.77381 .84656 L
s
0 0 0 r
.77083 .84921 m
.72321 .89021 L
s
.71875 .89418 m
.61756 .93783 L
s
.5997 .94974 m
.56101 .94841 L
s
.55804 .95503 m
.67708 .88757 L
s
.67113 .85979 m
.56399 .94048 L
s
.55506 .95106 m
.30655 .91667 L
s
.30506 .91402 m
.1503 .80423 L
s
.14137 .79101 m
.0506 .57011 L
s
.04613 .57275 m
.10863 .34127 L
s
.10119 .3254 m
.3631 .1045 L
s
.36607 .10582 m
.76488 .13624 L
s
1 0 0 r
.76488 .13624 m
.75149 .87302 L
s
0 0 0 r
.73363 .83995 m
.55952 .7963 L
s
.58185 .80423 m
.7872 .75794 L
s
.78869 .75661 m
.83482 .7963 L
s
.83185 .7791 m
.82143 .75132 L
s
.81101 .74735 m
.74107 .53042 L
s
1 0 0 r
.73661 .5291 m
.15923 .8082 L
s
0 0 0 r
.18304 .78571 m
.15774 .26455 L
s
.15179 .26587 m
.10268 .3254 L
s
.10268 .32804 m
.05208 .44709 L
s
.05208 .44974 m
.0625 .51058 L
s
1 0 0 r
.10565 .50529 m
.58036 .93254 L
s
0 0 0 r
.57887 .93915 m
.44345 .95503 L
s
.44196 .95503 m
.52679 .95503 L
s
.54167 .96032 m
.7753 .85582 L
s
.77679 .85317 m
.79762 .7619 L
s
.79464 .75926 m
.68155 .85714 L
s
.6756 .85582 m
.29464 .90476 L
s
.29762 .8955 m
.5997 .93651 L
s
.54167 .94048 m
.47321 .95899 L
s
.46429 .95503 m
.06101 .6164 L
s
.0625 .61508 m
.09077 .61905 L
s
.13839 .63624 m
.17411 .59259 L
s
.17262 .60847 m
.08036 .64153 L
s
.07143 .66138 m
.12946 .65608 L
s
.13542 .64815 m
.28125 .15212 L
s
.28125 .1746 m
.16071 .24603 L
s
.16071 .25265 m
.12798 .2791 L
s
.08631 .35582 m
.10119 .38228 L
s
.10565 .39153 m
.04911 .5119 L
s
.0506 .53571 m
.0625 .55556 L
s
.06845 .56349 m
.14435 .55423 L
s
.125 .56746 m
.08631 .57937 L
s
.08185 .58201 m
.09226 .67989 L
s
.08333 .69312 m
.11012 .72619 L
s
.11607 .72619 m
.20833 .84392 L
s
1 0 0 r
.23214 .82407 m
.66369 .92063 L
s
0 0 0 r
.66518 .91799 m
.78571 .74603 L
s
.78125 .75529 m
.6503 .90741 L
s
.67708 .8545 m
.5372 .83995 L
s
.5372 .8373 m
.77827 .83862 L
s
.77976 .84259 m
.74256 .87566 L
s
.7381 .87566 m
.55655 .95238 L
s
.54911 .95635 m
.45833 .95503 L
s
.35565 .92857 m
.38542 .8664 L
s
.38839 .86376 m
.50446 .95635 L
s
.54167 .96164 m
.80804 .76587 L
s
.81101 .76058 m
.83333 .56349 L
s
1 0 0 r
.83482 .56614 m
.54911 .93915 L
s
0 0 0 r
.54167 .93783 m
.4747 .95899 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.00440917 0.39418 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -115.156 0 ]
[.5 1.0125 115.156 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -176.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(From) show
105.063 13.750 moveto
(home) show
146.938 13.750 moveto
(base) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
188.813 13.750 moveto
(H) show
197.188 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(departures) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.938 13.750 moveto
(L) show
289.313 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.56845 .94841 m
.6369 .9246 L
s
.55357 .95106 m
.3497 .93386 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.5744 .94577 m
.73363 .88228 L
s
.54762 .94577 m
.53869 .94048 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.48958 .95899 m
.46726 .95503 L
s
.52679 .9537 m
.66964 .87698 L
s
.5506 .94577 m
.55952 .89021 L
s
.55952 .89021 m
.46875 .95635 L
s
.48512 .96032 m
.50595 .95503 L
s
.52679 .95635 m
.70685 .90344 L
s
.55208 .94048 m
.54613 .93915 L
s
.54315 .93386 m
.3244 .92063 L
s
.5253 .94709 m
.61161 .93783 L
s
.55804 .94841 m
.70685 .90344 L
s
1 0 0 r
.55506 .94709 m
.11012 .73413 L
s
0 0 0 r
.50744 .95503 m
.51637 .95503 L
s
.53423 .96032 m
.54167 .96693 L
s
.54315 .95767 m
.5506 .95503 L
s
.55506 .9537 m
.74554 .87566 L
s
.58929 .94577 m
.59077 .94841 L
s
.59077 .9537 m
.58631 .94312 L
s
.58482 .94841 m
.58482 .94577 L
s
.55506 .93783 m
.55952 .89153 L
s
.55952 .89153 m
.45982 .95635 L
s
.47619 .95899 m
.52083 .95503 L
s
.52679 .95635 m
.53571 .96296 L
s
.54464 .95767 m
.80952 .77646 L
s
.60119 .93915 m
.52679 .93915 L
s
.5253 .93915 m
.3869 .93386 L
s
.50893 .95635 m
.49554 .95503 L
s
.5 .95503 m
.52381 .95767 L
s
.53274 .96032 m
.57589 .9418 L
s
.56994 .94841 m
.56845 .94841 L
s
1 0 0 r
.56994 .94312 m
.76935 .86111 L
s
0 0 0 r
.55655 .94444 m
.58333 .92725 L
s
.58631 .92196 m
.66071 .87169 L
s
.52827 .95635 m
.5372 .96429 L
s
1 0 0 r
.54018 .96164 m
.73661 .88228 L
s
0 0 0 r
.48363 .95635 m
.44643 .9537 L
s
.49256 .95899 m
.52083 .95106 L
s
.5253 .94841 m
.54167 .94048 L
s
.54911 .94841 m
.70982 .89947 L
s
.54911 .95635 m
.54613 .96164 L
s
.54315 .96429 m
.1131 .71296 L
s
.52381 .96032 m
.77827 .85317 L
s
.59375 .94048 m
.58482 .94312 L
s
.5878 .94444 m
.5878 .94841 L
s
.5878 .94974 m
.59524 .9418 L
s
.60565 .93915 m
.63988 .92593 L
s
.49256 .95635 m
.51935 .95106 L
s
.52679 .95635 m
.5372 .96561 L
s
.54167 .96164 m
.69792 .90873 L
s
.59375 .9418 m
.69643 .90344 L
s
.57292 .94048 m
.59821 .94048 L
s
.61161 .93783 m
.65476 .91005 L
s
.52827 .95635 m
.5372 .96429 L
s
.54464 .95635 m
.54911 .9537 L
s
.55506 .94974 m
.95685 .51587 L
s
.61012 .91667 m
.61012 .91138 L
s
.59673 .90741 m
.5878 .90741 L
s
.58185 .90476 m
.49256 .93783 L
s
.55506 .9418 m
.54762 .95503 L
s
.5506 .94974 m
.56696 .84656 L
s
.59673 .92328 m
.48065 .94974 L
s
.47768 .95899 m
.49702 .95767 L
s
.53274 .96032 m
.70238 .90344 L
s
.50893 .94974 m
.52381 .95503 L
s
.52827 .95238 m
.53274 .95635 L
s
.54315 .95635 m
.73661 .88095 L
s
.5997 .94312 m
.60119 .9537 L
s
.5997 .94974 m
.56101 .94841 L
s
.55804 .95503 m
.67708 .88757 L
s
.55506 .95106 m
.30655 .91667 L
s
.57887 .93915 m
.44345 .95503 L
s
.52976 .95767 m
.5372 .96429 L
s
.54167 .96032 m
.7753 .85582 L
s
.59673 .94048 m
.5878 .94048 L
s
.58185 .9418 m
.57143 .94709 L
s
.54167 .94048 m
.47321 .95899 L
s
.54911 .95635 m
.45833 .95503 L
s
.51042 .95503 m
.52976 .95503 L
s
.53571 .95767 m
.53869 .96296 L
s
.54167 .96164 m
.80804 .76587 L
s
.54167 .93783 m
.4747 .95899 L
s
.47619 .95238 m
.47768 .94841 L
s
.48065 .94841 m
.47917 .9537 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.00440917 0.588183 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -98.3125 0 ]
[.5 1.0125 98.3125 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -159.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(To) show
88.125 13.750 moveto
(home) show
130.000 13.750 moveto
(base) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.875 13.750 moveto
(H) show
180.250 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arrivals) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
247.250 13.750 moveto
(L) show
255.625 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.6369 .9246 m
.55804 .94841 L
s
.3497 .93254 m
.52083 .95503 L
s
.52679 .95635 m
.56101 .94974 L
s
.55357 .95106 m
.51935 .95503 L
s
.52381 .95106 m
.56994 .94841 L
s
.62202 .93386 m
.55952 .94841 L
s
.54762 .94577 m
.53869 .94048 L
s
.53423 .93915 m
.51786 .95503 L
s
.52083 .95106 m
.49107 .95899 L
s
.4628 .95635 m
.51786 .95503 L
s
.72768 .87566 m
.55952 .94841 L
s
.5506 .94577 m
.55952 .89021 L
s
.4375 .94974 m
.48958 .95767 L
s
.48512 .96032 m
.50595 .95503 L
s
.79762 .83862 m
.55952 .94444 L
s
.55208 .94048 m
.54613 .93915 L
s
1 0 0 r
.3244 .92063 m
.52083 .94974 L
s
0 0 0 r
.5253 .94709 m
.61161 .93783 L
s
1 0 0 r
.81994 .75794 m
.56845 .94841 L
s
.79911 .75926 m
.55952 .94444 L
s
.11012 .73413 m
.50149 .95635 L
s
0 0 0 r
.50744 .95503 m
.51637 .95503 L
s
.53423 .96032 m
.54167 .96693 L
s
.54315 .95767 m
.5506 .95503 L
s
1 0 0 r
.94643 .59656 m
.59673 .94048 L
s
0 0 0 r
.58929 .94577 m
.59077 .94841 L
s
.59077 .9537 m
.58631 .94312 L
s
.58482 .94841 m
.58482 .94577 L
s
.66964 .87302 m
.55804 .9418 L
s
.55506 .93783 m
.55952 .89153 L
s
.47619 .95899 m
.52083 .95503 L
s
.52679 .95635 m
.53571 .96296 L
s
1 0 0 r
.7872 .55159 m
.61012 .93783 L
s
0 0 0 r
.60119 .93915 m
.52679 .93915 L
s
1 0 0 r
.22768 .82011 m
.51637 .95503 L
s
0 0 0 r
.50893 .95635 m
.49554 .95503 L
s
.5 .95503 m
.52381 .95767 L
s
.53274 .96032 m
.57589 .9418 L
s
.56994 .94841 m
.56845 .94841 L
s
1 0 0 r
.81548 .7619 m
.55952 .9418 L
s
0 0 0 r
.55655 .94444 m
.58333 .92725 L
s
.44345 .89815 m
.52083 .94444 L
s
.52827 .95635 m
.5372 .96429 L
s
1 0 0 r
.58482 .73942 m
.49107 .95635 L
s
0 0 0 r
.49256 .95899 m
.52083 .95106 L
s
.5253 .94841 m
.54167 .94048 L
s
.79464 .84392 m
.55655 .94841 L
s
.54911 .95635 m
.54613 .96164 L
s
.22173 .81217 m
.5119 .95503 L
s
1 0 0 r
.86756 .26323 m
.60565 .94048 L
s
0 0 0 r
.59375 .94048 m
.58482 .94312 L
s
.5878 .94444 m
.5878 .94841 L
s
.5878 .94974 m
.59524 .9418 L
s
1 0 0 r
.24256 .88757 m
.5 .95767 L
s
0 0 0 r
.49256 .95635 m
.51935 .95106 L
s
.52679 .95635 m
.5372 .96561 L
s
1 0 0 r
.97024 .53968 m
.56101 .94841 L
s
0 0 0 r
.81548 .76323 m
.5744 .94048 L
s
.57292 .94048 m
.59821 .94048 L
s
.35714 .91005 m
.50149 .95635 L
s
.52827 .95635 m
.5372 .96429 L
s
.54464 .95635 m
.54911 .9537 L
s
1 0 0 r
.55655 .18122 m
.6131 .92328 L
s
0 0 0 r
.59673 .90741 m
.5878 .90741 L
s
.58185 .90476 m
.49256 .93783 L
s
1 0 0 r
.60714 .14815 m
.56696 .93783 L
s
0 0 0 r
.55506 .9418 m
.54762 .95503 L
s
1 0 0 r
.85417 .25265 m
.60268 .92196 L
s
0 0 0 r
.59673 .92328 m
.48065 .94974 L
s
.47768 .95899 m
.49702 .95767 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.50893 .94974 m
.52381 .95503 L
s
.52827 .95238 m
.53274 .95635 L
s
.71875 .89418 m
.61756 .93783 L
s
.5997 .94312 m
.60119 .9537 L
s
.5997 .94974 m
.56101 .94841 L
s
.67113 .85979 m
.56399 .94048 L
s
1 0 0 r
.10565 .50529 m
.58036 .93254 L
s
0 0 0 r
.44196 .95503 m
.52679 .95503 L
s
.52976 .95767 m
.5372 .96429 L
s
.29762 .8955 m
.5997 .93651 L
s
.59673 .94048 m
.5878 .94048 L
s
.58185 .9418 m
.57143 .94709 L
s
.54167 .94048 m
.47321 .95899 L
s
.7381 .87566 m
.55655 .95238 L
s
.38839 .86376 m
.50446 .95635 L
s
.51042 .95503 m
.52976 .95503 L
s
.53571 .95767 m
.53869 .96296 L
s
1 0 0 r
.83482 .56614 m
.54911 .93915 L
s
0 0 0 r
.54167 .93783 m
.4747 .95899 L
s
.47619 .95238 m
.47768 .94841 L
s
.48065 .94841 m
.47917 .9537 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.00440917 0.782187 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -48.1563 0 ]
[.5 1.0125 48.1563 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -109.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(From) show
105.063 13.750 moveto
(place1) show
155.313 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.12946 .62698 m
.21429 .66005 L
s
1 0 0 r
.13244 .62963 m
.1994 .36772 L
s
0 0 0 r
.0744 .66402 m
.04911 .57804 L
s
.06101 .57011 m
.05804 .57407 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.14583 .61111 m
.5997 .17063 L
s
.05506 .55556 m
.09077 .57804 L
s
.08036 .57804 m
.08631 .56746 L
s
.0878 .56085 m
.07887 .54365 L
s
1 0 0 r
.08036 .54894 m
.50149 .95503 L
s
0 0 0 r
.04613 .57275 m
.10863 .34127 L
s
.0625 .61508 m
.09077 .61905 L
s
.10417 .62169 m
.09375 .62963 L
s
.07143 .64021 m
.0997 .66005 L
s
.0997 .66005 m
.11161 .64683 L
s
.13839 .63624 m
.17411 .59259 L
s
.07738 .64683 m
.07292 .65344 L
s
.07143 .66138 m
.12946 .65608 L
s
.13244 .65476 m
.1369 .64153 L
s
.13542 .64815 m
.28125 .15212 L
s
.06845 .56349 m
.14435 .55423 L
s
.125 .56746 m
.08631 .57937 L
s
.08185 .58201 m
.09226 .67989 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.00440917 0.97619 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.529762 0.0014881 0.480159 0.00132275 [
[.5 1.0125 -43.875 0 ]
[.5 1.0125 43.875 13.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -104.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(To) show
88.125 13.750 moveto
(place) show
138.375 13.750 moveto
(1) show
146.750 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 0 r
.05804 .52249 m
.08036 .6627 L
s
.04911 .53836 m
.09226 .63228 L
s
.2247 .75661 m
.09375 .62037 L
s
.0744 .66402 m
.04911 .57804 L
s
.06101 .57011 m
.05804 .57407 L
s
.06696 .5754 m
.10863 .59921 L
s
.11458 .60582 m
.1503 .61376 L
s
.38542 .44048 m
.07143 .54101 L
s
.06696 .54101 m
.06101 .5463 L
s
.05506 .55556 m
.09077 .57804 L
s
.08036 .57804 m
.08631 .56746 L
s
.0878 .56085 m
.07887 .54365 L
s
.14137 .79101 m
.0506 .57011 L
s
.46429 .95503 m
.06101 .6164 L
s
.0625 .61508 m
.09077 .61905 L
s
.10417 .62169 m
.09375 .62963 L
s
.07143 .64021 m
.0997 .66005 L
s
.0997 .66005 m
.11161 .64683 L
s
.17262 .60847 m
.08036 .64153 L
s
.07738 .64683 m
.07292 .65344 L
s
.07143 .66138 m
.12946 .65608 L
s
.13244 .65476 m
.1369 .64153 L
s
.0506 .53571 m
.0625 .55556 L
s
.1369 .5582 m
.12946 .56481 L
s
.125 .56746 m
.08631 .57937 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1104.56, 204.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000A@0000c1000`40O003h00Oogooogooogooogoo
E7oo003oOoooOoooOoooOomDOol00?mooomooomooomooeAoo`00ogooogooogooogooE7oo003oOooo
OoooOoooOomDOol00?mooomooomooomooeAoo`00ogooogooogooogooE7oo003oOoooOoooOoooOomD
Ool00?mooomooomooomooeAoo`00M7oo4P00`goo4`00`goo4P00`goo4P00`goo4P00MGoo001^Ool6
000BOol7002fOol6000COol6002fOol7000BOol6002gOol6000BOol6002gOol6000BOol7001^Ool0
06Yoo`@001moo`@00:ioo`@001moo`@00:ioo`@001moo`@00:moo`@001ioo`@00:moo`@001moo`@0
06Yoo`00IWoo10009goo1000YWoo10009goo1000YWoo10009goo1000Ygoo10009Woo1@00YWoo1000
9goo1000IWoo001ROol4000_Ool4002NOol4000_Ool4002NOol4000_Ool4002NOol5000_Ool4002N
Ool4000_Ool4001ROol0061oo`8003Moo`8009Yoo`8003Moo`8009Yoo`8003Moo`8009]oo`03001o
ogoo03Ioo`8009Yoo`8003Moo`80061oo`00GWoo0P00>goo0P00UWoo0P00>goo0P00UWoo0P00>goo
0P00Ugoo0P00>goo0P00UWoo0P00>goo0P00GWoo001LOol2000oOol2002BOol2000oOol2002BOol2
000oOol2002COol2000oOol00`00Oomoo`2AOol2000oOol2001LOol005Qoo`@004=oo`@008Yoo`@0
04=oo`@008Yoo`@004=oo`@008]oo`@0049oo`@008]oo`@004=oo`@005Qoo`00EWoo0P00Bgoo0P00
QWoo0P00Bgoo0P00Qgoo00<007ooOol0BGoo0P00Qgoo0P00BWoo0P00Qgoo0P00Bgoo00<007ooOol0
EGoo001DOol2000POol20003Ool=000MOol00`00Oomoo`21Ool2001?Ool20023Ool2001>Ool20023
Ool2001>Ool20023Ool2001>Ool2001EOol0059oo`8001ioo`@00003Ooml07oo011oo`03001oogoo
01Yoo`80081oo`03001oogoo055oo`03001oogoo07ioo`80059oo`8007moo`80059oo`8007moo`80
059oo`8005=oo`00DGoo00<007ooOol06Woo10000Woo0P000Woo0W`047oo00<007ooOol06goo00<0
07ooOol0Ngoo0P00EGoo00<007ooOol0Ngoo0P00EWoo00<007ooOol0NWoo0P00EWoo00<007ooOol0
Ngoo00<007ooOol0E7oo00<007ooOol0D7oo001@Ool00`00Oomoo`0GOol40002Ool40006Ool2O00>
Ool01000Oomoogoo10000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0NGoo00<007oo
Ool0EWoo00<007ooOol0NGoo00<007ooOol0Egoo00<007ooOol0N7oo00<007ooOol0Egoo00<007oo
Ool0NGoo00<007ooOol0EWoo00<007ooOol0Cgoo001?Ool00`00Oomoo`0BOol00`00Oomoo`030002
Ool4000<Ool00g`0Oomoo`0<Ool00`00Oomoo`04Ool:000>Ool2001hOol00`00Oomoo`1HOol2001h
Ool00`00Oomoo`1IOol00`00Oomoo`1fOol00`00Oomoo`1IOol2001hOol00`00Oomoo`1HOol2001?
Ool004eoo`8001Aoo`03001oo`0000L0011oo`9l00eoo`03001oogoo00Aoo`03001oogoo00=oo`D0
00ioo`8007Aoo`8005eoo`8007Aoo`8005eoo`8007Eoo`03001oogoo05aoo`03001oogoo07=oo`80
05eoo`8004eoo`00Bgoo0P005Goo1P001Goo3P0017oo0W`02goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00P0037oo00<007ooOol0Kgoo0P00HGoo0P00LGoo00<007oo
Ool0Ggoo0P00LGoo0P00H7oo0P00LGoo0P00HGoo00<007ooOol0BWoo0019Ool2000EOol5000FOol>
0004Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo20002Woo0P00KWoo00<007ooOol0Hgoo00<0
07ooOol0K7oo0P00I7oo00<007ooOol0K7oo0P00I7oo0P00KWoo00<007ooOol0HWoo0P00BWoo0018
Ool00`00Oomoo`0DOol4000OOol2O005OolD0003Ool00`00Ool000050009Ool00`00Oomoo`1ZOol0
0`00Oomoo`1UOol00`00Oomoo`1ZOol00`00Oomoo`1UOol00`00Oomoo`1ZOol00`00Oomoo`1UOol0
0`00Oomoo`1[Ool00`00Oomoo`1UOol00`00Oomoo`17Ool004Qoo`03001oogoo01=oo`@0029oo`03
O01oogoo00Moo`04001oogooOolC0002Ool30008Ool00`00Oomoo`1XOol00`00Oomoo`1WOol00`00
Oomoo`1XOol00`00Oomoo`1WOol00`00Oomoo`1YOol00`00Oomoo`1VOol00`00Oomoo`1YOol00`00
Oomoo`1WOol00`00Oomoo`16Ool004Ioo`8001Eoo`<002Eoo`9l00Eoo`P000Qoo`03O01oogoo00Eo
o`P00003O01oogoo00Aoo`03001oogoo06Eoo`8006]oo`8006Moo`03001oogoo06Uoo`8006Moo`80
06Yoo`8006Moo`8006]oo`03001oogoo04Eoo`00AGoo00<007ooOol04goo0P0000=oo`00Ool09goo
0W`00`0017oo0`001Goo100000=l07ooOol01Woo00<007ooOol00goo00<007`000000P0017oo0P00
I7oo00<007ooOol0KGoo00<007ooOol0HWoo0P00KWoo00<007ooOol0HWoo0P00KWoo0P00I7oo00<0
07ooOol0K7oo0P00AGoo0014Ool00`00Oomoo`0COol4000SOol60002Ool00g`0Oomoo`0600000goo
000000030004Ool00g`0Oomoo`07Ool00`00Oomoo`03Ool017`0001oogoo0P0017oo00<007ooOol0
H7oo00<007ooOol0Kgoo00<007ooOol0H7oo00<007ooOol0BGoo00=l07ooOol08goo00<007ooOol0
H7oo00<007ooOol0Kgoo00<007ooOol0HGoo00<007ooOol0KWoo00<007ooOol0@goo0013Ool00`00
Oomoo`0@Ool00`00Ool00003000POol50004Ool50002O004Ool00g`0001oo`0:Ool00g`0Oomoo`07
Ool00`00Oomoo`02Ool017`0Ool000000Woo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0
LGoo00<007ooOol0Ggoo00<007ooOol0BGoo00=l07ooOol097oo00<007ooOol0Ggoo00<007ooOol0
47oo00<007ooOol0GGoo00<007ooOol0Ggoo00<007ooOol0L7oo00<007ooOol0@Woo0011Ool2000C
Ool5000KOol60002Ool70007Ool2O002Ool00g`0Oomoo`0:Ool00g`0Oomoo`08Ool01@00Oomoogoo
O0000goo00@007ooOol000Aoo`03001oogoo05aoo`03001oogoo07=oo`03001oogoo05aoo`8004ao
o`03O01oogoo02Eoo`03001oogoo05aoo`8001=oo`03001oogoo05ioo`8005ioo`03001oogoo079o
o`80049oo`00@7oo00<007ooOol04Woo100067oo1@0000=oo`0000001@0047oo00=l07ooO00037oo
00=l07ooOol02Goo00@007ooOoml00Aoo`800003Ool007oo00=oo`03001oogoo05Yoo`03001oogoo
07Eoo`03001oogoo05Yoo`03001oogoo04aoo`03O01oogoo02Ioo`03001oogoo05Yoo`03001oogoo
019oo`03001oogoo061oo`03001oogoo05]oo`03001oogoo07Aoo`03001oogoo041oo`00@7oo00<0
07ooOol047oo1@004goo300067oo0W`00P002Woo00=l07ooOol02Woo00<007ooO0001Woo0`0017oo
00<007ooOol0F7oo00<007ooOol0Mgoo00<007ooOol0F7oo00<007ooOol0CGoo00=l07ooOol09goo
00<007ooOol0F7oo00<007ooOol04goo00<007ooOol0=Woo00<007ooOol0:7oo00<007ooOol0FGoo
00<007ooOol0MWoo00<007ooOol0?goo000oOol00`00Oomoo`0@Ool00`00Oomoo`02000?Ool:000@
Ool90005Ool00`00Ooml0002O0080003Ool00g`0Oomoo`0:Ool00`00O01oo`07Ool30003Ool00`00
Oomoo`1FOol00`00Oomoo`1iOol00`00Oomoo`1FOol00`00Oomoo`1>Ool00g`0Oomoo`0XOol00`00
Oomoo`1FOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`0ZOol2001HOol00`00Oomoo`1h
Ool2000oOol003ioo`03001oogoo00moo`80009oo`8000Yoo`P000Qooa0000Moo`03O01oogoo00=o
o`04001oogooO002Ool00g`0Oomoo`05Ool7000:Ool00g`0001oo`08Ool20002Ool00`00Oomoo`1E
Ool00`00Oomoo`1kOol00`00Oomoo`1DOol00`00Oomoo`16Ool00g`0Oomoo`06Ool00g`0Oomoo`0Y
Ool00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomoo`0dOol00`00Oomoo`0/Ool00`00Oomoo`1E
Ool00`00Oomoo`1jOol00`00Oomoo`0mOol003eoo`03001oogoo00moo`03001oogoo00<000EooaH0
01Moo`03O01oogoo009oo`05001oogooOoml0003Ool2O008Ool017`0Oomoogoo20000Woo00=l07oo
00002Goo0P000Woo00<007ooOol0Dgoo00<007ooOol0OGoo00<007ooOol0Dgoo00<007ooOol0AWoo
00=l07ooOol01Woo00=l07ooOol0:Woo00<007ooOol0Dgoo00<007ooOol057oo00<007ooOol0=7oo
00<007ooOol0;Woo00<007ooOol0Dgoo00<007ooOol0O7oo00<007ooOol0?7oo000lOol00`00Oomo
o`0>Ool20002Ool?000WOol01G`0Oomoogoo000017oo00=l07ooOol00goo0W`01Woo00=l07ooOol0
2Goo0P0000=l000000000P002Goo0P0000=oo`000000DWoo00<007ooOol0Ogoo00<007ooOol0D7oo
0P00BGoo00=l07ooOol01Woo00=l07ooOol0:goo00<007ooOol0DGoo00<007ooOol05Goo00<007oo
Ool0<goo00<007ooOol0<7oo00<007ooOol0DGoo00<007ooOol0OWoo0P00?7oo000kOol00`00Oomo
o`0=Ool:00000goo001oo`0_Ool017`0Oomoo`001Goo00=l07ooOol01Goo00=l07ooOol00goo00=l
07ooOol02goo00Al07ooOomoo`T0009oo`800003Ool007oo051oo`03001oogoo081oo`03001oogoo
04moo`03001oogoo04Uoo`03O01oogoo00Ioo`03O01oogoo02aoo`03001oogoo04moo`03001oogoo
01Ioo`03001oogoo039oo`03001oogoo039oo`03001oogoo04moo`03001oogoo081oo`03001oogoo
03Yoo`00>Woo00<007ooOol02goo20000Woo0P0000=oo`00Ool0<7oo00=l07oo00001Woo00=l07oo
Ool01Woo0W`017oo00=l07ooOol02Woo00=l07ooOol00Woo00<007ooOol01Goo10000Woo00<007oo
Ool0CWoo00<007ooOol0PGoo00<007ooOol0CWoo00<007ooOol0BGoo00=l07ooOol01Woo00=l07oo
Ool0;Goo00<007ooOol0CGoo00<007ooOol05Woo00<007ooOol0<Woo00<007ooOol0=7oo00<007oo
Ool0CGoo00<007ooOol0PWoo00<007ooOol0>Goo000iOol00`00Oomoo`0;Ool30002Ool00`00Ool0
0002Ool01@00Ool007oo0000<Goo00=l0000Ool01Goo00=l07ooOol02Goo00El07ooOomoog`000ao
o`03O01oogoo00=oo`03001oogoo00Qoo`03001oo`0004moo`03001oogoo08=oo`03001oogoo04ao
o`03001oogoo04Yoo`03O01oogoo00Eoo`03O01oogoo02ioo`03001oogoo04aoo`03001oogoo01Mo
o`03001oogoo035oo`03001oogoo03Eoo`03001oogoo04aoo`03001oogoo08=oo`03001oogoo03Uo
o`00>Goo00<007ooOol02goo00<007ooOol00P0000Eoo`00Oomoo`00009oo`80039oo`03001oogoo
00Eoo`03O01oogoo00Yoo`9l0003Ooml07oo00]oo`03O01oogoo00Aoo`03001oogoo00Moo`@004eo
o`03001oogoo08Eoo`03001oogoo04]oo`03001oogoo04Yoo`03O01oogoo00Eoo`03O01oogoo02mo
o`03001oogoo04]oo`03001oogoo01Moo`03001oogoo031oo`03001oogoo03Moo`03001oogoo04]o
o`03001oogoo08Aoo`03001oogoo03Qoo`00>7oo00<007ooOol02Woo0P0000=oo`0000000Woo00@0
07ooOol0009oo`80039oo`03001oog`000Ioo`03O01oogoo00aoo`9l00aoo`03O01oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00<004Yoo`03001oogoo08Moo`03001oogoo04Qoo`8004ioo`03O01o
ogoo00Aoo`03O01oogoo031oo`03001oogoo04Uoo`03001oogoo01Moo`03001oogoo031oo`03001o
ogoo03Uoo`03001oogoo04Uoo`03001oogoo08Ioo`8003Qoo`00=goo00<007ooOol02Goo1@000goo
00@007ooOol000=oo`03001oogoo031oo`04001oogooO006Ool00g`0Oomoo`0>Ool00g`0Oomoo`09
Ool00g`0Oomoo`06Ool00`00Oomoo`05Ool01000Oomoogoo0P00BGoo00<007ooOol0R7oo00<007oo
Ool0Agoo00<007ooOol0CWoo00=l07ooOol017oo00=l07ooOol0<7oo00<007ooOol0B7oo00<007oo
Ool067oo00<007ooOol0;goo00<007ooOol0>goo00<007ooOol0Agoo00<007ooOol0R7oo00<007oo
Ool0=Woo000gOol00`00Oomoo`08Ool01000Oomoo`000goo0P000Woo00@007ooOomoo`80035oo`05
001oogooOoml0006Ool00g`0Oomoo`0>Ool3O009Ool00g`0Oomoo`07Ool00`00Oomoo`03Ool20004
Ool20018Ool00`00Oomoo`29Ool00`00Oomoo`16Ool00`00Oomoo`1>Ool00g`0Oomoo`04Ool00g`0
Oomoo`0aOol00`00Oomoo`16Ool00`00Oomoo`0IOol00`00Oomoo`0^Ool00`00Oomoo`0mOol00`00
Oomoo`16Ool00`00Oomoo`29Ool00`00Oomoo`0eOol003Ioo`03001oogoo00Yoo`8000=oo`03001o
ogoo009oo`06001oogoo001oo`00<7oo00<007ooOol00Woo00=l07ooOol017oo00=l07ooOol03Woo
00=l07ooOol00W`01goo00=l07ooOol027oo00<007ooOol00Woo0P0017oo0P00Agoo00<007ooOol0
RWoo00<007ooOol0AGoo00<007ooOol0Cgoo00=l07ooOol017oo00=l07ooOol0<Woo00<007ooOol0
A7oo00<007ooOol06Woo00<007ooOol0;Goo00<007ooOol0?Woo00<007ooOol0AGoo00<007ooOol0
RWoo00<007ooOol0=Goo000eOol00`00Oomoo`09Ool40002Ool00`00Oomoo`02Ool01000Oomoogoo
0P00<7oo00<007ooOol00goo00=l07ooOol017oo00=l07ooOol03Woo00=l07ooOol00Woo00=l07oo
Ool017oo00=l07ooOol02Goo00L007ooOomoo`00Ool00004Ool20016Ool00`00Oomoo`2;Ool00`00
Oomoo`14Ool00`00Oomoo`1?Ool00g`0Oomoo`04Ool00g`0Oomoo`0cOol00`00Oomoo`13Ool00`00
Oomoo`0IOol00`00Oomoo`0]Ool00`00Oomoo`10Ool00`00Oomoo`13Ool00`00Oomoo`2<Ool00`00
Oomoo`0dOol003Aoo`03001oogoo00Uoo`05001oo`00001oo`080002Ool00`00Ool0000_Ool00`00
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0>Ool00g`0Oomoo`03Ool2O004Ool00g`0Oomoo`0:
Ool01P00Oomoo`00Ool000Aoo`8004Eoo`03001oogoo08aoo`03001oogoo04=oo`03001oogoo051o
o`03O01oogoo00Aoo`03O01oogoo03=oo`03001oogoo049oo`03001oogoo01Yoo`03001oogoo02ao
o`03001oogoo045oo`03001oogoo049oo`03001oogoo08eoo`03001oogoo03Aoo`00=7oo00<007oo
Ool01Woo2@0017oo0P000Woo00@007ooOol002ioo`03001oogoo00Eoo`03O01oogoo00Aoo`03O01o
ogoo00moo`03O01oogoo00Aoo`9l009oo`03O01oogoo00]oo`05001oog`0Ool00005Ool20014Ool0
0`00Oomoo`2=Ool00`00Oomoo`12Ool00`00Oomoo`1@Ool00g`0Oomoo`04Ool00g`0Oomoo`0ZOol0
0g`0Oomoo`07Ool00`00Oomoo`11Ool00`00Oomoo`0JOol00`00Oomoo`0[Ool00`00Oomoo`13Ool0
0`00Oomoo`11Ool00`00Oomoo`2>Ool00`00Oomoo`0cOol003=oo`03001oogoo00Uoo`06001oo`00
001oo`0017oo0P000Woo00@007ooOol002ioo`03001oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo
00moo`03O01oogoo00Ioo`03O01oog`000ioo`04001l07oo0005Ool20013Ool00`00Oomoo`2?Ool0
0`00Oomoo`10Ool00`00Oomoo`1AOol00g`0Oomoo`04Ool00g`0Oomoo`0ZOol00g`0Oomoo`08Ool0
0`00Oomoo`0oOol00`00Oomoo`0JOol00`00Oomoo`0[Ool00`00Oomoo`15Ool00`00Oomoo`0oOol0
0`00Oomoo`2@Ool00`00Oomoo`0bOol003=oo`03001oogoo00Qoo`@00003Ool007oo00=oo`05001o
o`00Ool00003Ool00`00Oomoo`0[Ool00`00Oomoo`07Ool00g`0Oomoo`04Ool00g`0Oomoo`0?Ool0
0g`0Oomoo`07Ool2O00>Ool00g`0001oo`020005Ool20011Ool00`00Oomoo`2AOol00`00Oomoo`0n
Ool00`00Oomoo`1BOol00g`0Oomoo`04Ool00g`0Oomoo`0YOol01G`0OomoogooO0001goo00<007oo
Ool0?Woo00<007ooOol06goo00<007ooOol0:Woo00<007ooOol0AWoo00<007ooOol0?Woo00<007oo
Ool0TGoo00<007ooOol0<Woo000bOol00`00Oomoo`07Ool3000017oo000000001Goo0P0000=oo`00
Ool00goo00<007ooOol0:Woo00<007ooOol027oo00=l07ooOol017oo00=l07ooOol03goo00=l07oo
Ool027oo0W`03Goo00Il07oo001l07oo0004Ool00`00Ool00010Ool00`00Oomoo`2BOol00`00Oomo
o`0mOol00`00Oomoo`1BOol00g`0Oomoo`04Ool00g`0Oomoo`0YOol01G`0OomoogooO00027oo00<0
07ooOol0?Goo00<007ooOol06goo00<007ooOol0:Goo00<007ooOol0B7oo00<007ooOol0?Goo00<0
07ooOol0TWoo00<007ooOol0<Goo000aOol00`00Oomoo`07Ool01000Ool007oo0P001Woo0P000Woo
00D007ooOomoo`0002aoo`03001oogoo00Uoo`03O01oogoo00Aoo`03O01oogoo011oo`03O01oogoo
00Moo`04O01oog`0O00:Ool01W`0Oomoog`0001oo`8000=oo`03001oo`0003moo`03001oogoo09=o
o`03001oogoo03aoo`03001oogoo05=oo`03O01oogoo00Aoo`03O01oogoo02Uoo`04O01oogooO009
Ool00`00Oomoo`0lOol00`00Oomoo`0KOol00`00Oomoo`0YOol00`00Oomoo`19Ool00`00Oomoo`0l
Ool00`00Oomoo`2COol00`00Oomoo`0aOol0035oo`03001oogoo00Ioo`03001oogoo00@000Eoo`80
009oo`03001oogoo009oo`03001oogoo02Qoo`8000aoo`03O01oogoo00Aoo`03O01oogoo011oo`03
O01oogoo00Moo`04O01oogooOol2O008Ool01G`0Oomoog`0Ool00`0017oo00<007oo0000?Woo00<0
07ooOol0U7oo00<007ooOol0>goo00<007ooOol0Dgoo00=l07ooOol017oo00=l07ooOol0:7oo00El
07ooOomoog`000Yoo`03001oogoo03]oo`03001oogoo01]oo`03001oogoo02Moo`8004eoo`03001o
ogoo03]oo`03001oogoo09Aoo`03001oogoo031oo`00<7oo00<007ooOol02Goo00<007oo00000P00
17oo0P000Woo00<007ooOol00goo00<007ooOol09goo00<007ooOol037oo00=l07ooOol017oo00=l
07ooOol047oo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooO00017oo0P00
0goo00<007oo0000?Goo00<007ooOol0UGoo00<007ooOol0>Woo00<007ooOol0E7oo00=l07ooOol0
17oo00=l07ooOol0:7oo00Al07ooOoml00]oo`03001oogoo03Yoo`03001oogoo01aoo`03001oogoo
02Ioo`03001oogoo04eoo`03001oogoo03Yoo`03001oogoo09Eoo`03001oogoo031oo`00<7oo00<0
07ooOol027oo00H007oo000007oo0003Ool01@00Ool007oo00001Woo00<007ooOol09Woo00<007oo
Ool03Woo00=l07ooOol00goo00=l07ooOol047oo00=l07ooOol01goo00=l07ooOol017oo0W`017oo
00Al07ooOoml00Eoo`8000=oo`03001oo`0003aoo`03001oogoo09Eoo`03001oogoo03Yoo`03001o
ogoo05Eoo`03O01oogoo00=oo`03O01oogoo02Moo`05O01oogooOoml000<Ool00`00Oomoo`0iOol0
0`00Oomoo`0LOol00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`0iOol00`00Oomoo`2FOol0
0`00Oomoo`0_Ool002moo`03001oogoo00Qoo`04001oo`000002Ool02000Oomoo`00Ool007oo0006
Ool00`00Oomoo`0VOol00`00Oomoo`0?Ool00g`0Oomoo`03Ool00g`0Oomoo`0@Ool00g`0Oomoo`07
Ool00g`0Oomoo`06Ool2O002Ool017`0Oomoog`01Woo0P000Woo00<007oo0000>goo00<007ooOol0
UWoo00<007ooOol0>Goo00<007ooOol0EWoo00=l07ooOol00goo00=l07ooOol09goo00El07ooOomo
og`000aoo`03001oogoo03Qoo`03001oogoo01aoo`03001oogoo02Eoo`03001oogoo051oo`03001o
ogoo03Qoo`03001oogoo09Moo`03001oogoo02moo`00;goo00<007ooOol01goo00<007oo00000P00
0Woo00<007ooOol00P000Woo00<007ooOol017oo00<007ooOol09Goo00<007ooOol047oo00=l07oo
Ool00goo00=l07ooOol04Goo00=l07ooOol01Woo00=l07ooOol027oo00El07ooO01oog`000Qoo`80
009oo`03001oo`0003Yoo`03001oogoo09Moo`03001oogoo03Qoo`03001oogoo05Ioo`03O01oogoo
00=oo`03O01oogoo02Moo`04O01oogooO00>Ool00`00Oomoo`0gOol00`00Oomoo`0LOol00`00Oomo
o`0TOol00`00Oomoo`1BOol00`00Oomoo`0gOol00`00Oomoo`2HOol00`00Oomoo`0^Ool002moo`03
001oogoo00Ioo`D000=oo`04001oo`000002Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomo
o`0AOol00g`0Oomoo`03Ool00g`0Oomoo`0AOol00g`0Oomoo`06Ool00g`0Oomoo`09Ool2O0000goo
O01oo`08Ool01P00Oomoo`00Ool003Uoo`03001oogoo09Qoo`03001oogoo03Moo`03001oogoo05Mo
o`03O01oogoo00=oo`03O01oogoo02Ioo`05O01oogooOoml000>Ool00`00Oomoo`0fOol00`00Oomo
o`0MOol00`00Oomoo`0SOol00`00Oomoo`1COol00`00Oomoo`0gOol00`00Oomoo`2HOol00`00Oomo
o`0^Ool002moo`03001oogoo00Ioo`04001oo`000004Ool30002Ool00`00Oomoo`05Ool00`00Oomo
o`0TOol00`00Oomoo`0BOol00g`0Oomoo`03Ool00g`0Oomoo`0AOol00g`0Oomoo`06Ool00g`0Oomo
o`09Ool017`0Ooml07`02Goo0P000Woo00<007oo0000>7oo00<007ooOol0VGoo00<007ooOol0=Woo
00<007ooOol0Egoo00=l07ooOol00goo00=l07ooOol09Woo00Al07ooOoml00moo`03001oogoo03Io
o`03001oogoo01aoo`03001oogoo02=oo`03001oogoo05Eoo`03001oogoo03Ioo`03001oogoo09Uo
o`03001oogoo02eoo`00;Woo00<007ooOol01Woo00D007oo001oo`0000Aoo`05001oo`00Ool00008
Ool00`00Oomoo`0SOol00`00Oomoo`0COol00g`0Oomoo`02Ool00g`0Oomoo`0BOol00g`0Oomoo`05
Ool00g`0Oomoo`09Ool01W`0Oomoog`0Ooml00Uoo`800004Ool007oo000gOol00`00Oomoo`2JOol0
0`00Oomoo`0eOol00`00Oomoo`1HOol00g`0Oomoo`02Ool00g`0Oomoo`0WOol017`0Oomoog`03goo
00<007ooOol0=Woo00<007ooOol077oo00<007ooOol08Woo00<007ooOol0EWoo00<007ooOol0=Goo
00<007ooOol0VWoo00<007ooOol0;Goo000^Ool00`00Oomoo`05Ool00`00Oomoo`020004Ool30000
0goo001oo`08Ool00`00Oomoo`0ROol00`00Oomoo`0DOol00g`0Oomoo`02Ool00g`0Oomoo`0BOol0
0g`0Oomoo`05Ool00g`0Oomoo`09Ool017`0Oomoog`00Woo0W`027oo0`000Woo00<007ooOol0=7oo
00<007ooOol0Vgoo00<007ooOol0=7oo00<007ooOol0F7oo00=l07ooOol00Woo00=l07ooOol09Woo
00El07ooOomoog`0011oo`03001oogoo03Eoo`03001oogoo01aoo`03001oogoo025oo`03001oogoo
05Moo`03001oogoo03Eoo`03001oogoo09]oo`03001oogoo02aoo`00;Goo00<007ooOol01Woo00@0
07oo000000Aoo`03001oo`00008000Yoo`03001oogoo025oo`03001oogoo01Eoo`03O01oogoo009o
o`03O01oogoo01=oo`03O01oogoo00Aoo`03O01oogoo00Uoo`03O01oog`000Eoo`9l00Ioo`@00003
Ool007oo03Aoo`03001oogoo09aoo`03001oogoo03Aoo`03001oogoo05Qoo`03O01oogoo009oo`03
O01oogoo02Ioo`04O01oogooO00AOol00`00Oomoo`0dOol00`00Oomoo`0MOol00`00Oomoo`0POol0
0`00Oomoo`1HOol00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`0/Ool002eoo`03001oogoo
00Eoo`05001oo`00Ool00004Ool200000goo00000009Ool00`00Oomoo`0QOol00`00Oomoo`0FOol0
0g`0Oomoo`02Ool00g`0Oomoo`0COol00g`0Oomoo`04Ool00g`0Oomoo`08Ool017`0Oomoog`01goo
00=l07ooOol017oo0`000Woo00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0<goo00<007oo
Ool0F7oo00=l07ooOol00Woo00=l07ooOol09Goo00El07ooOomoog`0019oo`03001oogoo03=oo`03
001oogoo01aoo`03001oogoo021oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo09aoo`03
001oogoo02aoo`00;7oo00<007ooOol01Woo00@007oo000000Aoo`80009oo`03001oogoo00Qoo`03
001oogoo021oo`03001oogoo01Moo`03O01oogoo009oo`03O01oogoo01=oo`03O01oogoo00Aoo`03
O01oogoo00Qoo`04O01oogooO008Ool2O005Ool300000goo001oo`0cOol00`00Oomoo`2MOol00`00
Oomoo`0bOol00`00Oomoo`1IOol00g`0Oomoo`02Ool00g`0Oomoo`0UOol01G`0OomoogooO0004Woo
00<007ooOol0<Woo00<007ooOol027oo00<007ooOol04Woo00<007ooOol07goo00<007ooOol0Fgoo
00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0;7oo000/Ool00`00Oomoo`05Ool01000Ool0
000017oo00@007oo001oo`8000Yoo`03001oogoo01moo`03001oogoo01Qoo`03O01oogoo009oo`03
O01oogoo01=oo`03O01oogoo00Aoo`03O01oogoo00Qoo`03O01oog`000]oo`03O01oogoo009oo`05
001oo`00Ool0000dOol00`00Oomoo`2MOol00`00Oomoo`0bOol00`00Oomoo`1IOol00g`0Oomoo`02
Ool00g`0Oomoo`0UOol017`0Oomoog`057oo00<007ooOol0<Goo00<007ooOol027oo00<007ooOol0
4Woo00<007ooOol07Woo00<007ooOol0GGoo00<007ooOol0<Goo00<007ooOol0WWoo00<007ooOol0
:goo000/Ool00`00Oomoo`04Ool50003Ool01`00Ool007oo001oo`0000Uoo`03001oogoo01moo`03
001oogoo01Uoo`03O01oogoo009oo`03O01oogoo01Aoo`03O01oogoo00=oo`03O01oogoo00Moo`04
O01oogooO00<Ool2O003Ool01000Ool00000<goo00<007ooOol0WWoo00<007ooOol0<Goo00<007oo
Ool0FWoo00=l07ooOol00Woo00=l07ooOol097oo00El07ooOomoog`001Aoo`03001oogoo031oo`03
001oogoo00Qoo`03001oogoo019oo`03001oogoo01ioo`03001oogoo05ioo`03001oogoo035oo`03
001oogoo09ioo`03001oogoo02]oo`00;7oo00<007ooOol01Goo0`000goo00D007oo001oo`00009o
o`03001oogoo00Moo`03001oogoo01ioo`03001oogoo01Yoo`03O01oogoo009oo`03O01oogoo01Ao
o`03O01oogoo00=oo`03O01oogoo00Moo`04O01oogooO00>Ool2O0001Woo00000000Ool0039oo`03
001oogoo09moo`03001oogoo031oo`03001oogoo05Yoo`03O01oogoo009oo`03O01oogoo02Aoo`04
O01oogooO00EOol00`00Oomoo`0`Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0MOol0
0`00Oomoo`1POol00`00Oomoo`0`Ool00`00Oomoo`2OOol00`00Oomoo`0ZOol002]oo`03001oogoo
00Eoo`@0009oo`05001oo`00Ool00003Ool00`00Oomoo`03Ool01G`0Oomoogoo00007goo00<007oo
Ool06goo00=l07ooOol00Woo00=l07ooOol057oo00=l07ooOol00goo00=l07ooOol01Woo00Al07oo
Ooml015oo`03O01oo`0000<0035oo`03001oogoo0:1oo`03001oogoo031oo`03001oogoo05Yoo`03
O01oogoo009oo`03O01oogoo02Aoo`04O01oogooO00EOol00`00Oomoo`0`Ool00`00Oomoo`08Ool0
0`00Oomoo`0>Ool01G`0Oomoogoo00007Woo00<007ooOol0HGoo00<007ooOol0;goo00<007ooOol0
X7oo00<007ooOol0:Woo000[Ool00`00Oomoo`05Ool01000Ool000000Woo0P000Woo00D007ooOomo
o`0000Aoo`80009oo`03001oogoo01eoo`03001oogoo01eoo`05O01oogooOoml000FOol00g`0Oomo
o`03Ool00g`0Oomoo`06Ool017`0Oomoog`04Woo0W`01000<7oo00<007ooOol0XGoo00<007ooOol0
;goo00<007ooOol0Fgoo00El07ooOomoog`002Eoo`05O01oogooOoml000FOol00`00Oomoo`0_Ool0
0`00Oomoo`08Ool00`00Oomoo`0>Ool017`0Oomoo`007Woo00<007ooOol0HWoo00<007ooOol0;goo
00<007ooOol0X7oo00<007ooOol0:Woo000ZOol00`00Oomoo`05Ool40002Ool01@00Ool007oo0000
17oo00<007oo00000P0000El07ooOomoo`0001ioo`03001oogoo01ioo`05O01oogooOoml000FOol0
0g`0Oomoo`03Ool00g`0Oomoo`06Ool00g`0Ooml000EOol017`000000000<7oo00<007ooOol0XGoo
00<007ooOol0;Woo00<007ooOol0G7oo00El07ooOomoog`002Eoo`04O01oogooO00GOol00`00Oomo
o`0^Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool01G`0Oomoogoo00007Goo00<007ooOol0Hgoo00<0
07ooOol0;goo00<007ooOol0X7oo00<007ooOol0:Woo000ZOol00`00Oomoo`05Ool2000027oo0000
0000Ool007oo0003Ool40003Ool01G`0Oomoogoo00007Goo00<007ooOol07goo00El07ooOomoog`0
01Moo`03O01oogoo009oo`03O01oogoo00Eoo`04O01oogooO00EOol01000Ool00000<7oo00<007oo
Ool0XGoo00<007ooOol0;Woo00<007ooOol0G7oo00El07ooOomoog`002Aoo`05O01oogooOoml000G
Ool00`00Oomoo`0^Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool01G`0Oomoogoo000077oo00<007oo
Ool0IGoo00<007ooOol0;Woo00<007ooOol0XGoo00<007ooOol0:Goo000ZOol00`00Oomoo`04Ool0
1000Ool007oo0P0000Eoo`00Ool007oo00<0009oo`03001oogoo009oo`05O01oogooOol0000LOol0
0`00Oomoo`0POol01G`0OomoogooO0005goo00=l07ooOol00Woo00=l07ooOol01Goo00Al07ooOoml
01Ioo`<002moo`03001oogoo0:9oo`03001oogoo02ioo`03001oogoo05aoo`05O01oogooOoml000T
Ool017`0Oomoog`067oo00<007ooOol0;Woo00<007ooOol027oo00<007ooOol03Woo00El07ooOomo
o`0001]oo`03001oogoo06Ioo`03001oogoo02eoo`03001oogoo0:9oo`03001oogoo02Uoo`00:Woo
00<007ooOol00goo0`000Woo0`0000Aoo`00000000Eoo`03001oogoo009oo`04O01oogoo000LOol0
0`00Oomoo`0QOol01G`0OomoogooO0005goo00=l07ooOol00Woo00=l07ooOol01Goo00=l07ooO000
5goo1000;Woo00<007ooOol0Xgoo00<007ooOol0;Goo00<007ooOol0G7oo00El07ooOomoog`002Ao
o`04O01oogooO00IOol00`00Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool017`0Oomoo`00
6goo00<007ooOol0Igoo00<007ooOol0;Goo00<007ooOol0XWoo00<007ooOol0:Goo000ZOol00`00
Oomoo`03Ool300000goo001oo`040007Ool01@00OomoogooO0000goo00<007ooOol06Goo00<007oo
Ool08Woo00El07ooOomoog`001Moo`03O01oogoo009oo`03O01oogoo00Aoo`04O01oogooO00HOol3
000^Ool00`00Oomoo`2SOol00`00Oomoo`0/Ool00`00Oomoo`1MOol01G`0OomoogooO0008goo00El
07ooOomoog`001Uoo`03001oogoo02aoo`03001oogoo00Qoo`03001oogoo00ioo`05O01oogooOol0
000JOol00`00Oomoo`1XOol00`00Oomoo`0]Ool00`00Oomoo`2ROol00`00Oomoo`0YOol002Yoo`03
001oogoo009oo`P00004Ool007oo0006Ool01@00OomoogooO0000goo00<007ooOol067oo00<007oo
Ool08goo00El07ooOomoog`001Qoo`05O01oogooOoml0006Ool00g`0Ooml000FOol00`00Oomoo`03
000^Ool00`00Oomoo`2SOol00`00Oomoo`0/Ool00`00Oomoo`1MOol01G`0OomoogooO0008goo00Al
07ooOoml01Yoo`03001oogoo02aoo`03001oogoo00Qoo`03001oogoo00ioo`05O01oogooOol0000I
Ool00`00Oomoo`1ZOol00`00Oomoo`0/Ool00`00Oomoo`2SOol00`00Oomoo`0XOol002Uoo`03001o
ogoo009oo`@0009oo`800003Ool007oo009oo`03001oogoo00=oo`05001oogooOoml0002Ool00`00
Oomoo`0HOol00`00Oomoo`0TOol01G`0OomoogooO00067oo00El07ooOomoog`000Eoo`04O01oogoo
O00FOol01000Oomoogoo0P00;Goo00<007ooOol0Y7oo00<007ooOol0;7oo00<007ooOol0GGoo00El
07ooOomoog`002=oo`04O01oogooO00JOol00`00Oomoo`0/Ool00`00Oomoo`08Ool00`00Oomoo`0>
Ool017`0Oomoo`006Goo00<007ooOol0Jgoo00<007ooOol0:goo00<007ooOol0Y7oo00<007ooOol0
:7oo000YOol01000Oomoogoo10000goo00<007`000001Goo00<007ooOol00Woo00D007ooOomoog`0
009oo`03001oogoo01Moo`03001oogoo02Eoo`05O01oogooOoml000HOol01G`0OomoogooO0001Goo
00Al07ooOoml01Eoo`04001oogooOol3000]Ool00`00Oomoo`2UOol00`00Oomoo`0[Ool00`00Oomo
o`1MOol01G`0OomoogooO0008Woo00Al07ooOoml01aoo`03001oogoo02]oo`03001oogoo00Qoo`03
001oogoo00ioo`04O01oogoo000HOol00`00Oomoo`1/Ool00`00Oomoo`0[Ool00`00Oomoo`2TOol0
0`00Oomoo`0XOol002Uoo`07001oogooOol007oo00000goo0`000W`01Goo0P000Woo00@007ooOoml
00=oo`03001oogoo01Ioo`03001oogoo02Ioo`05O01oogooOoml000HOol01G`0OomoogooO0001Goo
00=l07ooO0003Woo00<007ooOol01Goo00@007ooOomoo`<002eoo`03001oogoo0:Eoo`03001oogoo
02Yoo`03001oogoo05ioo`05O01oogooOoml000ROol017`0Oomoog`077oo00<007ooOol0:goo00<0
07ooOol01goo00<007ooOol03Woo00El07ooOomoo`0001Moo`03001oogoo06eoo`03001oogoo02]o
o`03001oogoo0:Aoo`03001oogoo02Qoo`00:Goo00<007ooOol00Woo0P000goo0P000goo00=l07oo
Ool017oo00<007oo00000Woo00El07ooOomoo`0001Moo`03001oogoo02Moo`05O01oogooOoml000H
Ool01G`0OomoogooO00017oo00Al07ooOoml00ioo`03001oogoo00Eoo`03001oogoo00<00003Ool0
07oo02]oo`03001oogoo0:Eoo`03001oogoo02Yoo`03001oogoo05ioo`05O01oogooOoml000ROol0
17`0Oomoog`077oo00<007ooOol0:goo00<007ooOol01goo00<007ooOol03Woo00El07ooOomoo`00
01Ioo`03001oogoo06ioo`03001oogoo02]oo`03001oogoo0:Eoo`03001oogoo02Moo`00:7oo00<0
07ooOol00goo00<007ooOol00Woo0P0017oo0W`01Goo0P000Woo00Al07ooOol001Moo`03001oogoo
02Qoo`04O01oogooO00JOol017`0Oomoog`017oo00Al07ooOoml00ioo`03001oogoo00Aoo`04001o
ogooOol5000/Ool00`00Oomoo`2UOol00`00Oomoo`0ZOol00`00Oomoo`1NOol017`0Oomoog`08Woo
00Al07ooOoml01eoo`03001oogoo02Yoo`03001oogoo00Qoo`03001oogoo00ioo`04O01oogoo000F
Ool00`00Oomoo`1_Ool00`00Oomoo`0[Ool00`00Oomoo`2UOol00`00Oomoo`0WOol002Qoo`03001o
ogoo009oo`8000=oo`8000Moo`9l00Aoo`04001oogooO002Ool00`00Oomoo`0DOol00`00Oomoo`06
Ool2000QOol017`0Oomoog`06Woo00Al07ooOoml00Aoo`03O01oog`000ioo`03001oogoo00Eoo`04
001oogooOol5000/Ool00`00Oomoo`2UOol00`00Oomoo`0ZOol00`00Oomoo`1NOol017`0Oomoog`0
8Woo00Al07ooOoml01eoo`03001oogoo02Yoo`03001oogoo00Moo`03001oogoo00moo`04O01oogoo
000EOol00`00Oomoo`1aOol00`00Oomoo`0ZOol00`00Oomoo`0kOol2001XOol00`00Oomoo`0WOol0
02Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`04O01oogooOol200001G`0Oomo
ogoo00005Goo00<007ooOol02P008Goo00=l07ooO0006Woo00Al07ooOoml00=oo`04O01oogooO00>
Ool00`00Oomoo`05Ool00`00Oomoo`02000017oo001oo`00;7oo00<007ooOol0YGoo00<007ooOol0
:Woo00<007ooOol0Ggoo00=l07ooO0008Goo00Al07ooOoml01ioo`03001oogoo02Yoo`03001oogoo
00Moo`03001oogoo00ioo`05O01oogooOol0000DOol00`00Oomoo`1bOol00`00Oomoo`0YOol00`00
Oomoo`0iOol3001ZOol00`00Oomoo`0WOol002Qoo`03001oogoo009oo`04001oogooOol2000;Ool2
O0001goo001oog`0001oo`0000Mooa800004Ool00000000WOol00g`0Ooml000JOol017`0Oomoog`0
0goo00=l07ooO0003goo00<007ooOol017oo00@007ooOomoo`800004Ool007oo000/Ool00`00Oomo
o`2UOol00`00Oomoo`0ZOol00`00Oomoo`1OOol00g`0Ooml000QOol017`0Oomoog`07goo00<007oo
Ool0:Goo00<007ooOol01goo00<007ooOol03Woo00Al07ooOol001Aoo`03001oogoo07=oo`03001o
ogoo02Uoo`03001oogoo03Ioo`<006eoo`03001oogoo02Moo`00:7oo00<007ooOol00Woo00<007oo
Ool00`0027oo1@0000=l000000002`003Goo00<007ooOol00`00:Woo00=l07ooO0006goo00=l07oo
O0000Woo00Al07ooOoml00moo`03001oogoo00Aoo`05001oogoo001oo`0300000goo001oo`0[Ool0
0`00Oomoo`2UOol00`00Oomoo`0ZOol00`00Oomoo`1OOol00g`0Ooml000QOol017`0Oomoog`07goo
00<007ooOol0:Goo00<007ooOol01goo00<007ooOol03Woo00Al07ooOol001=oo`03001oogoo07Ao
o`03001oogoo02Uoo`03001oogoo03=oo`<0071oo`03001oogoo02Moo`00:7oo00<007ooOol00Woo
00<007oo00002`001Woo00=l0000O0000Woo00<007ooOol04Goo1000;Goo00=l07ooO0006goo00=l
07ooO0000Woo00Al07ooOoml00moo`03001oogoo00Aoo`05001oogoo001oo`0300000goo001oo`0Z
Ool00`00Oomoo`2WOol00`00Oomoo`0YOol00`00Oomoo`1OOol00g`0Ooml000POol017`0Oomoog`0
87oo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol03goo00Al07ooOol0019oo`03001oogoo
07Eoo`03001oogoo02Uoo`03001oogoo031oo`<007=oo`03001oogoo02Moo`00:7oo00<007ooOol0
0Woo1@0047oo00D007`0Ool007oo008000ioo`@0031oo`03O01oog`001]oo`03O01oog`0009oo`03
O01oog`0011oo`03001oogoo00Aoo`0:001oogoo001oo`00Ool007oo000[Ool00`00Oomoo`2WOol0
0`00Oomoo`0YOol00`00Oomoo`1OOol00g`0Ooml000POol017`0Oomoog`087oo00<007ooOol0:Goo
00<007ooOol01Woo00<007ooOol03Woo00Al07ooOol0019oo`03001oogoo07Ioo`03001oogoo02Uo
o`03001oogoo02aoo`@007Ioo`03001oogoo02Moo`00:7oo00<007ooOol00Woo0`0000=oo`00Ool0
3goo00@007ooO00000=oo`03001oogoo00Qoo`<00003Ool007oo035oo`03O01oog`001]oo`05O01o
og`0Ooml0002Ool00g`0Oomoo`0=Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007oo001oo`00
02]oo`03001oogoo0:Moo`03001oogoo02Uoo`03001oogoo05moo`03O01oog`0021oo`04O01oogoo
O00POol00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0>Ool017`0Oomoo`004Goo00<007oo
Ool0Mgoo00<007ooOol0:Goo00<007ooOol0:Goo0`00NWoo00<007ooOol09goo000XOol00`00Oomo
o`02Ool300000goo001oo`0?Ool01000Oomoo`000W`00Woo00<007ooOol017oo0`000goo00<007oo
Ool0<Goo00=l07ooO0006goo00El07ooO01oog`0009oo`03O01oogoo00eoo`03001oogoo00Aoo`05
001oogoo001oo`0200001Goo001oogoo0000:Woo00<007ooOol0Ygoo00<007ooOol0:Goo00<007oo
Ool0Ggoo00=l07ooO0007goo00Al07ooOoml025oo`03001oogoo02Uoo`03001oogoo00Ioo`03001o
ogoo00ioo`04O01oogoo000@Ool00`00Oomoo`1hOol00`00Oomoo`0YOol00`00Oomoo`0VOol3001m
Ool00`00Oomoo`0WOol002Qoo`03001oogoo009oo`800003Ool007oo011oo`04001oogoo0002Ool0
0g`0Oomoo`02000017oo000000001Goo00<007ooOol0<Woo00=l07ooO00077oo0g`00Woo00=l07oo
Ool03Woo00<007ooOol017oo00<007oo00000Woo0P000Woo00<007oo0000:Woo00<007ooOol0Ygoo
00<007ooOol0:7oo00<007ooOol0H7oo00=l07ooO0007goo00Al07ooOoml025oo`03001oogoo02Uo
o`03001oogoo00Eoo`03001oogoo00moo`04O01oogoo000?Ool00`00Oomoo`1iOol00`00Oomoo`0Y
Ool00`00Oomoo`0SOol30020Ool00`00Oomoo`0WOol002Qoo`03001oogoo00=oo`03001oo`00011o
o`04O00007oo0004Ool2O0030007Ool00`00Oomoo`0cOol00g`0Ooml000LOol3O002Ool00g`0Oomo
o`0>Ool00`00Oomoo`03Ool01@00Oomoo`00Ool00`000Woo00<007oo0000:Woo00<007ooOol0Ygoo
00<007ooOol0:7oo00<007ooOol0H7oo00=l07ooO0007Woo00Al07ooOoml029oo`03001oogoo02Uo
o`03001oogoo00Eoo`03001oogoo00ioo`04O01oogoo000?Ool00`00Oomoo`1jOol00`00Oomoo`0Y
Ool00`00Oomoo`0POol30024Ool00`00Oomoo`0VOol002Qoo`03001oogoo009oo`800003Ool007oo
00moo`04O00007oo0003Ool3000017`0Oomoo`001Goo00<007ooOol0=7oo00=l07ooO00077oo0g`0
00=oog`0Ool047oo00<007ooOol00goo00D007ooOol007oo00800006Ool007oo001oo`00:Woo00<0
07ooOol0Ygoo00<007ooOol0:7oo00<007ooOol0H7oo00=l07ooO0007Woo00Al07ooOoml029oo`03
001oogoo02Uoo`03001oogoo00Eoo`03001oogoo00ioo`04O01oogoo000>Ool00`00Oomoo`1kOol0
0`00Oomoo`0YOol00`00Oomoo`0MOol30027Ool00`00Oomoo`0VOol002Qoo`03001oogoo009oo`03
001oo`00015oo`03O00007oo00@000Aoo`9l0004Ool007ooOol2000gOol00g`0Ooml000LOol2O002
Ool00g`0Oomoo`0>Ool00`00Oomoo`04Ool03@00Ool007oo001oo`00Ool007oo001oo`0002Yoo`03
001oogoo0:Moo`03001oogoo02Qoo`03001oogoo061oo`03O01oog`001ioo`04O01oogooO00ROol0
0`00Oomoo`0YOol00`00Oomoo`04Ool00`00Oomoo`0?Ool017`0Oomoo`0037oo0P00OWoo00<007oo
Ool0:Goo00<007ooOol06Woo0`00RWoo00<007ooOol09Woo000XOol01@00Oomoogoo00000Woo00<0
07ooOol017oo00=l07ooOol027oo00Al0000000000Uoo`04O01oo`00000iOol00g`0Ooml000MOol0
17`0Oomoog`047oo00<007ooOol00goo00D007ooOol007oo0080009oo`05001oo`00Ool0000ZOol0
0`00Oomoo`2WOol00`00Oomoo`0XOol00`00Oomoo`0<Ool00g`0Oomoo`1AOol00g`0Ooml000MOol0
17`0Oomoog`08goo00<007ooOol0:Goo00<007ooOol017oo00<007ooOol03goo00=l07oo000037oo
00<007ooOol0OWoo00<007ooOol0:Goo00<007ooOol05goo0`00SGoo00<007ooOol09Woo000XOol0
1@00Oomoogoo00000Woo00<007ooOol01Goo00=l07ooOol01Goo1@002goo0W`000=oo`00Ool0=goo
00=l07ooO0007Goo00=l07ooO0004Goo00<007ooOol00goo00L007oo001oo`00Ool00002Ool01@00
Ool007oo0000:Woo00<007ooOol0Ygoo00<007ooOol0:7oo00<007ooOol03Goo00=l07ooOol0D7oo
00=l07ooO0007Goo00Al07ooOoml02=oo`03001oogoo02Uoo`03001oogoo00Aoo`03001oogoo00io
o`04O01oogoo000;Ool00`00Oomoo`1oOol00`00Oomoo`0YOol00`00Oomoo`0DOol3002@Ool00`00
Oomoo`0VOol002Qoo`03001oogoo00Aoo`03001oogoo00Ioo`03O01oogoo00@00003Ooml07oo0080
00]oo`05001oog`0O000000hOol2O00LOol2O0000gooO01oo`0@Ool00`00Oomoo`03Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool0000ZOol00`00Oomoo`2SOol01@00Oomoogoo0000:Woo00<0
07ooOol03Woo00=l07ooOol0D7oo0W`07Goo00=l07ooO00097oo00<007ooOol0:Goo00<007ooOol0
17oo00<007ooOol03Woo00Al07ooOol000Yoo`03001oogoo081oo`03001oogoo02Uoo`03001oogoo
011oo`@0099oo`03001oogoo02Moo`00:7oo00<007ooOol00Woo0P002Goo00<007`000001Goo00=l
07oo00002goo00<007ooOol00Woo00=l0000Ool0=Woo0W`077oo0W`000=oog`0Ool047oo00<007oo
Ool00Woo00<007ooOol00P000Woo00@007oo000000=oo`03001oogoo02Qoo`03001oogoo0:9oo`03
001oogoo009oo`03001oogoo02Uoo`03001oogoo00ioo`03O01oogoo04moo`9l01aoo`04O01oogoo
O00TOol00`00Oomoo`0YOol00`00Oomoo`03Ool00`00Oomoo`0?Ool00g`0Ool0000:Ool00`00Oomo
o`21Ool00`00Oomoo`0YOol00`00Oomoo`03Ool00`00Oomoo`07Ool3002FOol00`00Oomoo`0WOol0
02Qoo`03001oogoo009oo`8000Ioo`<0009oo`9l00Aoo`03O01oo`0000Yoo`03001oogoo00Aoo`9l
0003001oogoo03=oo`9l01Qoo`9l0003001l07oo009l019oo`03001oogoo009oo`05001oo`00Ool0
0002Ool200001Goo001oogoo0000:goo00<007ooOol0XGoo00<007ooOol00goo00<007ooOol0:Goo
00<007ooOol03goo0W`0Cgoo0W`077oo00Al07ooOoml02Aoo`03001oogoo02Uoo`03001oogoo00=o
o`03001oogoo00moo`03O01oo`0000Uoo`03001oogoo089oo`03001oogoo02Uoo`03001oogoo00=o
o`03001oogoo00Aoo`<009Uoo`03001oogoo02Moo`00:7oo00<007ooOol00Woo0P000goo0`001goo
00Al07ooOoml009oo`03001oogoo00Moo`03001oogoo00Moo`03O00007oo03=oo`9l01Ioo`9l009o
o`03001l07oo009l015oo`03001oogoo00=oo`04001oo`000003Ool01@00Oomoo`00Ool00P00:goo
00<007ooOol0X7oo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol04Goo00=l07ooOol0C7oo
0W`077oo00=l07ooO0009Goo00<007ooOol0:Goo00<007ooOol00goo00<007ooOol03Woo00Al07oo
Ool000Qoo`03001oogoo08=oo`03001oogoo02Uoo`03001oogoo009oo`8000=oo`<009aoo`03001o
ogoo02Moo`00:7oo00@007ooOomoo`<00003Ool0000000]oo`03O01oog`0009oo`03001oogoo00Io
o`03001oogoo00Uoo`9l03=oo`9l01Aoo`9l00Eoo`04001oog`0O00AOol00`00Oomoo`02Ool01@00
Ool007oo00000Woo00@007ooOomoo`800003Ooml07oo02Yoo`03001oogoo09moo`03001oogoo00Ao
o`03001oogoo02Yoo`03001oogoo019oo`03O01oogoo04]oo`9l01]oo`04O01oogooO00TOol00g`0
001oo`0ZOol00`00Oomoo`03Ool00`00Oomoo`0>Ool017`0Oomoo`001goo00<007ooOol0Q7oo00<0
07ooOol0:Goo00@007ooOomoo`<00003Ool0000009moo`03001oogoo02Moo`00:7oo00@007ooOomo
o`@000ioo`9l0003Ool0000000Moo`03001oogoo00aoo`03O01oogoo031oo`03O01oogoo015oo`9l
00Ioo`03O00007oo009l015oo`03001oogoo009oo`04001oo`000002Ool20003Ool200000g`0001o
o`0[Ool00`00Oomoo`2MOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`0COol00g`0Oomo
o`1:Ool00g`0Oomoo`0JOol00g`0Ooml000TOol00g`0Ool0000[Ool00`00Oomoo`02Ool01@00Oomo
ogoo00003Goo00=l07oo00001goo00<007ooOol0QGoo00<007ooOol0:Goo00H007ooOomoo`00Ool2
0002Ool00`00Oomoo`2LOol00`00Oomoo`0WOol002Qoo`03001oogoo009oo`<0009oo`03O01oogoo
00Yoo`04O01oo`000006Ool00`00Oomoo`0>Ool2O00`Ool00g`0Oomoo`0?Ool2O008Ool00g`0001o
o`02O003Ool00g`0Oomoo`0;Ool00`00Oomoo`02Ool02000Ool00000Ool007oo0003Ool01000O01o
o`00;7oo00<007ooOol0W7oo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Woo00=l07oo
Ool02goo00=l07ooOol0BGoo00=l07ooOol06Goo00Al07ooOoml00Aoo`03O01oogoo01aoo`03O01o
o`0002aoo`03001oogoo009oo`03001oogoo009oo`03O01oogoo00Yoo`03O01oo`0000Ioo`03001o
ogoo08Ioo`03001oogoo02Uoo`03001oogoo009oo`<0009oo`03001oogoo09aoo`03001oogoo02Mo
o`00:7oo00<007ooOol00Woo00<007oo00000goo00Al07ooOomoo`L00003O01oog`0008000Eoo`03
001oogoo015oo`9l02ioo`03O01oogoo00eoo`9l00Yoo`06O01oo`00O01oog`00Woo00=l07ooOol0
2goo00<007ooOol00Woo0`000Woo00<007oo00000goo0P0000=oo`00Ool0:goo00<007ooOol0W7oo
00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01goo00=l07ooOol02goo00=l07ooOol0B7oo
00=l07ooOol06Goo00Al07ooOoml00Aoo`03O01oogoo01]oo`04O01oogoo000/Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00O01oo`02Ool7000017`0Oomoo`001Goo00<007ooOol0Qgoo00<007oo
Ool0:Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`2BOol00`00Oomoo`0W
Ool002Qoo`03001oogoo009oo`X000Moo`05O01oo`00O0000004Ool00`00Oomoo`0COol00`00O01o
o`0/Ool00g`0Oomoo`0;Ool2O00;Ool02g`0Oomoo`00O01oog`0Ooml07oo00001Woo00<007ooOol0
0Woo00<007ooOol00Woo00H007oo000007oo0002Ool02000Oomoog`0Ool007oo000/Ool00`00Oomo
o`2KOol00`00Oomoo`07Ool00`00Oomoo`0ZOol00`00Oomoo`08Ool00g`0Oomoo`0;Ool00g`0Oomo
o`17Ool00g`0Oomoo`0IOol00g`0Ooml0004Ool00g`0Oomoo`0KOol01G`0Oomoogoo0000;7oo00<0
07ooOol00Woo2P001goo00=l07oo00001Goo00<007ooOol0R7oo00<007ooOol0:Woo00<007ooOol0
0Woo0P000goo00<007ooOol01Goo00<007ooOol0Tgoo00<007ooOol09goo000XOol01000Oomoogoo
1P000goo00Al07ooOomoo`8000=oo`05O01oo`00Ooml0003Ool00`00Oomoo`0EOol00`00O01l000[
Ool00g`0Oomoo`09Ool2O00=Ool02g`0Ooml0000O01oog`0Ooml07oo00001Woo00=l07ooOol00Woo
00<007ooOol00Woo0`0000Eoo`00Oomoo`00009oo`03O0000000009oo`03001oogoo02Yoo`03001o
ogoo09Yoo`03001oogoo00Qoo`03001oogoo02Yoo`03001oogoo00Uoo`03O01oogoo00]oo`03O01o
ogoo04Ioo`03O01oogoo01Qoo`04O01oogooO004Ool00g`0Oomoo`07Ool00g`0Oomoo`0@Ool00g`0
Oomoo`02Ool00`00Oomoo`0[Ool01`00Oomoo`00Ool007oo00800004Ool007ooO003Ool20003Ool0
0g`0Ool00004Ool00`00Oomoo`28Ool00`00Oomoo`0[Ool01000Oomoogoo1@0000=oo`00Ool017oo
0P00UWoo00<007ooOol09goo000YOol00`00Oomoo`02000017oo000007oo0P0000=oo`0000000P00
1Goo00Ql07oo001oo`00O01oo`006Goo0P0000=l07ooOol0:7oo00=l07ooOol01goo0W`03Woo00Ml
07ooOoml0000O01oo`02O003Ool00`00Oomoo`02Ool00g`0001oo`03Ool00`00Oomoo`02Ool40003
Ool01P00Ooml0000Ool0009oo`03001oogoo02Yoo`03001oogoo09Uoo`03001oogoo00Uoo`03001o
ogoo02Yoo`03001oogoo00Yoo`03O01oogoo00]oo`03O01oogoo04Eoo`03O01oogoo01Qoo`03O01o
og`000Aoo`03O01oogoo00Moo`03O01oogoo011oo`03O01oogoo00=oo`03001oogoo02]oo`05001o
ogoo001oo`020002Ool200000goo000000020005Ool00g`0Ool00003Ool00`00Oomoo`29Ool00`00
Oomoo`0[Ool01000Oomoogoo100000Aoo`00001oo`@009Qoo`03001oogoo02Moo`00:Goo00D007oo
Ool007oo00L0009oo`03O01oogoo00=oo`07O01oogoo001oo`00Ool00W`06goo00<007`0O000:7oo
00=l07ooOol01Goo0W`047oo00Ml07ooOoml07oo001oo`02O003Ool01`00OomoogooO01oo`0000Ao
o`04001oogooOol40004Ool02000O01oo`00Ool007oo000]Ool00`00Oomoo`2HOol00`00Oomoo`0:
Ool00`00Oomoo`0ZOol00`00Oomoo`0;Ool00g`0Oomoo`0;Ool2O015Ool00g`0Oomoo`0HOol00g`0
Ooml0004Ool00g`0Oomoo`06Ool00g`0Oomoo`0@Ool00g`0Oomoo`04Ool00`00Oomoo`0[Ool01000
Oomoo`000goo1@000Woo00=l07ooOol00goo00Al07ooOol0009oo`03001oogoo08Yoo`03001oogoo
02]oo`05001oogoo001oo`07002KOol00`00Oomoo`0XOol002Uoo`09001oogoo001oo`00Ool007oo
008000Aoo`03O01oogoo009oo`03O01oo`00009oo`80009oo`03O01oogoo01Uoo`03001oog`002Mo
o`03O01oogoo00=oo`9l019oo`03O01oog`0009oo`04001oog`0O004Ool01P00Oomoog`0Ool000Ao
o`04001oogooOol30005Ool01@00Ool007oo00000Woo00<007ooOol0:goo00<007ooOol0Ugoo00<0
07ooOol02goo00<007ooOol0:goo00<007ooOol02goo00=l07ooOol037oo00=l07ooOol0@Woo00=l
07ooOol05goo00Al07ooOoml00=oo`03O01oogoo00Moo`03O01oogoo00moo`03O01oogoo00Eoo`03
001oogoo02]oo`04001oogoo0005Ool00`00Oomoo`03Ool00g`0Oomoo`02Ool00g`0Ool00002Ool0
0`00Oomoo`2;Ool00`00Oomoo`0[Ool02000Oomoo`00Ool007oo0002Ool00`00Oomoo`2JOol00`00
Oomoo`0XOol002Uoo`06001oogooOol007oo100000=oo`00Ool00goo00Ml07ooOomoog`0Ool00002
Ool20003Ool00g`0Oomoo`0IOol01000Ooml07`09Goo0W`00Woo0W`04goo00Al07ooOoml009oo`04
001oog`0O004Ool01@00Ooml07oo00001Goo00@007ooOomoo`8000Eoo`06O00007oo001oo`000Woo
00<007ooOol0:goo00<007ooOol0UWoo00<007ooOol02goo00<007ooOol0;7oo00<007ooOol037oo
00=l07ooOol037oo00=l07ooOol0@Goo0W`067oo00=l07ooO00017oo00=l07ooOol01Woo00=l07oo
Ool03goo00=l07ooOol01Goo00<007ooOol0;7oo00D007ooOomoo`0000Aoo`<000Aoo`08O01oogoo
Ooml07oo001oo`8008eoo`03001oogoo02]oo`06001oogooOol007oo0P000goo00<007ooOol0VGoo
00<007ooOol0:7oo000ZOol01@00Oomoo`00Ool010000Woo0P000goo00Ml07ooOoml07oo001oo`03
0004Ool00g`0Oomoo`0IOol200000gooO01l000SOol4O00EOol017`0Oomoog`00Woo00Al0000Ooml
00Eoo`04O01oogoo0004Ool01000Oomoogoo0`0017oo00Ml07oo000007ooO0000002Ool00`00Oomo
o`0/Ool00`00Oomoo`2DOol00`00Oomoo`0<Ool00`00Oomoo`0/Ool00`00Oomoo`0=Ool00g`0Oomo
o`0<Ool00g`0Oomoo`10Ool2O00GOol017`0Oomoog`00goo00=l07ooOol01Woo00=l07ooOol03goo
00=l07ooOol00goo00Al07ooOol002ioo`05001oogooOol00004Ool00`00Oomoo`020003Ool01G`0
Oomoog`0Ool00`00SWoo00<007ooOol0;7oo00D007ooOol007oo00<000=oo`8009Uoo`03001oogoo
02Qoo`00:Woo00D007ooOol007oo00@000Aoo`04001oogooOol2O0000goo001oo`0200000goo001o
o`04Ool00g`0Oomoo`0JOol01000Oomoog`08Woo0W`05goo00=l07ooO0000goo00Al0000Ooml00Ao
o`05O00007ooOol00004Ool01000Oomoogoo0P0017oo00Ml07oo001oo`00O0000003Ool00`00Oomo
o`0/Ool00`00Oomoo`2COol00`00Oomoo`0=Ool00`00Oomoo`0/Ool00`00Oomoo`0>Ool2O00=Ool0
0g`0Oomoo`0oOol2O00GOol00g`0Ooml0004Ool00g`0Oomoo`05Ool00g`0Oomoo`0?Ool00g`0Oomo
o`03Ool01G`0Oomoogoo0000;Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogooOol2
O00017oo00000000SWoo00<007ooOol0;Goo00D007ooOol007oo00<000Eoo`03001oogoo09Eoo`03
001oogoo02Uoo`00:Woo00H007ooOomoo`00Ool30005Ool300000gooO01oo`060006Ool00g`0Oomo
o`0JOol00`00Oomoo`02O00NOol4O00FOol017`0Oomoog`00goo00El0000Oomoog`000=oo`05O01o
o`00Ool00004Ool00`00Oomoo`030003Ool00g`0Oomoo`0200000g`0Ool00003Ool00`00Oomoo`0/
Ool00`00Oomoo`2BOol00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0?Ool00g`0Oomoo`0;
Ool00g`0Oomoo`0nOol2O00GOol00g`0Ooml0004Ool00g`0Oomoo`05Ool00g`0Oomoo`0>Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00`00Oomoo`0]Ool01@00Oomoogoo000017oo00<007ooOol00Woo
0`0000Ioog`0Ool007oo002>Ool00`00Oomoo`0]Ool02@00Oomoogoo001oo`00Ool00005Ool30006
Ool2002<Ool00`00Oomoo`0YOol002Yoo`04001oogooOol60007Ool2000017`0000000000Woo00<0
07ooOol01Goo00=l07ooOol06Woo00D007ooOomoog`001]oo`9l009oo`9l01Ioo`03O01oog`000Ao
o`05O01oo`00Ooml0002Ool01W`0Oomoo`00Ool000Aoo`03001oo`00008000=oo`04O01oogooOol2
0002Ool01000Oomoo`00;goo00<007ooOol0TGoo00<007ooOol03Woo00<007ooOol0;Woo00<007oo
Ool047oo00=l07ooOol02goo00=l07ooOol0?Goo0W`05Woo00Al07ooOoml00=oo`03O01oogoo00Eo
o`03O01oogoo00ioo`03O01oogoo00=oo`03O01oogoo009oo`03001oogoo02ioo`04001oogooOol4
00000goo001oo`06Ool200000g`00000002?Ool00`00Oomoo`0]Ool01000Oomoogoo1@0027oo1P00
SWoo00<007ooOol0:Goo000ZOol01@00Oomoogoo00000Woo10001goo10000goo00<007ooOol01Woo
00=l07ooOol06Woo0P000Woo0W`05goo0W`017oo0W`05Goo00Al07ooOoml00=oo`9l0006Ool007oo
O01oog`017oo0P0017oo0P0000=oo`0000000Woo00=l07ooOol00Woo00<007ooOol00P000Woo00<0
07ooOol0;Woo00<007ooOol0Sgoo00<007ooOol03goo00<007ooOol0;Woo00<007ooOol04Goo00=l
07ooOol02goo00=l07ooOol0?7oo0W`05Woo00=l07ooO00017oo00=l07ooOol017oo00=l07ooOol0
3Woo00=l07ooOol00goo00=l07ooOol00goo00<007ooOol0;Woo00D007ooOomoo`0000=oo`<000Mo
o`04O0000000O02?Ool00`00Oomoo`0^Ool00`00Oomoo`0200000goo000000020007Ool3002@Ool0
0`00Oomoo`0YOol002Yoo`03001oogoo009oo`03001oo`0000800003Ool007oo009oo`<00005Ool0
0000Ooml0002Ool00`00Oomoo`07Ool2O00LOol01@00OomoogooO0004goo0g`01Woo0W`05Goo00Al
07ooOoml00=oo`9l0003Ool007oo009l00Eoo`8000Aoo`04001oogoo0002Ool00g`0Oomoo`02Ool0
17`0001oogoo0P0000=oo`00Ool0<7oo00<007ooOol0SWoo00<007ooOol047oo00<007ooOol0;Woo
00<007ooOol04Woo00=l07ooOol02goo0W`0?7oo0W`05Woo00=l07ooO0000goo00=l07ooOol017oo
00=l07ooOol03Woo00=l07ooOol00goo00=l07ooOol017oo00<007ooOol0;Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo009oo`03O01oo`00009oo`03O01oogoo08]oo`03001oogoo
02moo`04001oogooOol300000goo001oo`020002Ool3002BOol00`00Oomoo`0ZOol002]oo`04001o
ogooOol3000017oo000007oo0`000Woo00=l000000000goo00=l07oo00002goo00=l07ooOol06Woo
00@007ooOomoo`9l00moo`9l00Uoo`9l01Eoo`03O01oog`000Aoo`9l009oo`03001l07`000Ioo`04
001oogooOol200001Goo000007ooO00017oo00=l0000Ool00Woo00@007ooOol0035oo`03001oogoo
08ioo`03001oogoo011oo`03001oogoo02moo`03001oogoo019oo`03O01oogoo00aoo`03O01oogoo
03Uoo`9l01Eoo`04O01oogooO003Ool00g`0Oomoo`03Ool00g`0Oomoo`0>Ool00g`0Oomoo`03Ool0
0g`0Oomoo`05Ool00`00Oomoo`0_Ool01@00Oomoogoo00000goo0`0017oo00@007`0Ool000=oo`03
O01oogoo08Yoo`03001oogoo02moo`07001oogooOol007oo00000Woo1@00UGoo00<007ooOol0:Woo
000[Ool01P00Oomoogoo001oo`L000Aoo`<000=oo`03O00007oo00]oo`03O01oogoo01Yoo`8000=o
o`9l00]oo`9l00]oo`9l00aoo`03001oogoo00Eoo`04O01oogooO003Ool00g`0Ooml0002Ool00`00
O01l0006Ool01@00Oomoogoo00000Woo00<007ooO00017oo00=l000000000Woo0P000Woo00<007oo
Ool0;goo00<007ooOol0SGoo00<007ooOol047oo00<007ooOol0<7oo00<007ooOol04goo00=l07oo
Ool037oo00=l07ooOol0>7oo0W`05Goo00=l07ooO0000goo00=l07ooOol017oo00=l07ooOol03Goo
00=l07ooOol00goo00=l07ooOol01Goo00<007ooOol0<7oo00D007ooOomoo`0000=oo`03001oogoo
00Ioo`<000=oo`03O01oogoo08Uoo`03001oogoo02moo`06001oogooOol007oo1`00UWoo00<007oo
Ool0:Woo000/Ool01000Oomoogoo100017oo00D007ooOomoo`00009oo`<00003Ool007oo00aoo`03
O01oogoo01]oo`03001oogoo009oo`03O01oogoo00Ioo`9l00eoo`9l00]oo`03O01oo`0000Ioo`04
O01oogooO003Ool00g`0Ooml0002Ool00g`0Ooml0005Ool01000Ool007oo0P000Woo00<007`0Ool0
0goo00Al07oo0000009oo`80009oo`03001oogoo031oo`03001oogoo08]oo`03001oogoo015oo`03
001oogoo031oo`03001oogoo01Aoo`03O01oogoo00aoo`03O01oogoo03Moo`9l01Aoo`04O01oogoo
O003Ool00g`0Oomoo`03Ool00g`0Oomoo`0=Ool00g`0Oomoo`03Ool00g`0Oomoo`06Ool00`00Oomo
o`0`Ool00`00Oomoo`02Ool01000Oomoo`0027oo00<007ooOol00`0000=oog`0Ool0RGoo00<007oo
Ool0<7oo00@007ooOomoo`D000=oo`05001oogooOol0002AOol00`00Oomoo`0ZOol002aoo`06001o
ogooOol007oo0`0017oo00@007ooOol000Eoo`800003O01oogoo00]oo`03O01oogoo01]oo`03001o
ogoo009oo`9l00Aoo`9l00moo`9l00aoo`03O01oo`0000Eoo`03O01oog`000=oo`09O01oogooO01o
og`0001oog`000Eoo`07001oo`00001oo`00Ool00P0017oo00El07oo001oo`00009oo`800003Ool0
07oo039oo`03001oogoo08Yoo`03001oogoo015oo`03001oogoo035oo`03001oogoo01Eoo`03O01o
ogoo00aoo`03O01oogoo03Ioo`9l01Aoo`03O01oog`000=oo`03O01oogoo00=oo`03O01oogoo00eo
o`03O01oogoo00=oo`03O01oogoo00Moo`03001oogoo031oo`03001oogoo009oo`@000=oo`04001o
ogooOol20005Ool200000g`0001oo`26Ool00`00Oomoo`0aOol01000Oomoogoo100000Aoo`00Oomo
o`800003Ool007oo091oo`03001oogoo02]oo`00;7oo00H007ooOomoo`00Ool40004Ool00`00Oomo
o`06Ool200000g`0001oo`0;Ool00g`0Oomoo`0KOol00`00Oomoo`03Ool017`0Ooml07`04Goo0W`0
3Goo00=l07oo00000goo00Al07ooOoml00=oo`09O01oogooO01oog`0Ool007`000Eoo`03001oo`00
009oo`03001oo`0000Aoo`0<O01oogoo001oo`00Ool007oo001oo`00=7oo00<007ooOol0R7oo00<0
07ooOol04Woo00<007ooOol0<Woo00<007ooOol05Goo00=l07ooOol037oo00=l07ooOol0=Goo0W`0
57oo00=l07ooO0000goo00=l07ooOol00Woo00=l07ooOol03Goo00=l07ooOol00goo00=l07ooOol0
27oo00<007ooOol0<Goo00D007ooOomoo`00009oo`800003Ool007oo00=oo`03001oogoo00Moo`04
O00000000024Ool00`00Oomoo`0aOol01000Oomoogoo1@0000=oo`0000000Woo0P00TGoo00<007oo
Ool0:goo000/Ool00`00Oomoo`02Ool400000goo000000040007Ool01000Oomoog`00P002goo00=l
07ooOol06goo0P000goo0g`04Goo00=l07ooO0003Goo00Al07ooOol0009oo`03O01oog`000=oo`04
O01oogooOol2O002Ool00`00O01oo`04Ool300001Goo001oog`000000goo00Al07ooOol0009oo`07
001oo`00Ool007oo0000=7oo00<007ooOol0Qgoo00<007ooOol04goo00<007ooOol0<Woo00<007oo
Ool05Woo00=l07ooOol037oo00=l07ooOol0<goo00=l07ooO0004goo00Al07ooOoml009oo`03O01o
ogoo00=oo`03O01oogoo00aoo`03O01oogoo00=oo`03O01oogoo00Qoo`03001oogoo039oo`03001o
ogoo009oo`03001oogoo00L000]oo`03O01oogoo0080085oo`03001oogoo039oo`03001oogoo009o
o`<00003Ool0000000D0091oo`03001oogoo02aoo`00;Goo00<007ooOol01P0000=oo`0000000goo
00<007ooOol017oo00H007ooOomoog`0Ool20002O008Ool00g`0Oomoo`0LOol00`00O01l0003Ool0
0g`0Oomoo`0>Ool017`0Oomoog`03Goo00El07ooOol007`0009oo`05O01oogooOoml0003Ool01g`0
Oomoogoo001oog`000Aoo`80009oo`04001l00000002Ool01g`0Oomoogoo001oo`00009oo`05001o
o`00Ool0000dOol00`00Oomoo`26Ool00`00Oomoo`0DOol00`00Oomoo`0cOol00`00Oomoo`0FOol0
0g`0Oomoo`0<Ool00g`0Oomoo`0bOol017`0Oomoog`04Woo00=l07ooO0000goo00=l07ooOol00Woo
00=l07ooOol037oo00=l07ooOol00goo00=l07ooOol02Goo00<007ooOol0<goo00<007ooOol01P00
4Goo00=l07ooOol0PWoo00<007ooOol0<goo00<007ooOol01P000Woo0P000Woo00<007ooOol0SGoo
00<007ooOol0;7oo000]Ool00`00Oomoo`04Ool20003Ool01@00Oomoogoo00001Goo00<007ooOol0
0Woo00=l07ooOol00Woo0W`01goo00=l07ooOol06Woo0W`000<007ooOol00goo0W`03Woo00Al07oo
Ooml00ioo`04O01oogooO002Ool017`0Oomoog`00goo0W`017oo00<007`0Ool00Woo0`000Woo00=l
000000000Woo00El07ooOomoo`00009oo`03001oo`0000=oo`03001oogoo03=oo`03001oogoo08Eo
o`03001oogoo01Aoo`03001oogoo03Aoo`03001oogoo01Moo`03O01oogoo00aoo`03O01oogoo035o
o`04O01oogooO00BOol00g`0Ooml0003Ool01G`0OomoogooO0003Woo00=l07ooOol00goo00=l07oo
Ool02Goo00<007ooOol0=7oo00<007ooOol017oo00<007ooOol04Goo00=l07ooOol0P7oo00<007oo
Ool0=7oo00<007ooOol017oo00<007ooOol00goo00@007ooOol008ioo`03001oogoo02aoo`00;Woo
00H007ooOomoo`00Ool20004Ool01@00Oomoogoo000017oo00<007ooOol00goo00=l07ooOol00goo
0g`01Goo0W`067oo0W`00goo00<007ooOol017oo0W`037oo00Al07ooOoml00moo`05O01oog`0001l
0003Ool017`0Oomoogoo0W`017oo00H007`0Oomoo`00Ool200000gooO000000200000gooO01oo`03
Ool01@00Oomoo`00Ool00P000Woo00<007ooOol0=7oo00<007ooOol0Pgoo00<007ooOol05Goo00<0
07ooOol0=7oo00<007ooOol067oo00=l07ooOol037oo0W`0<Goo00Al07ooOoml015oo`03O01oog`0
00=oo`05O01oogooOoml000>Ool00g`0Oomoo`03Ool00g`0Oomoo`0:Ool00`00Oomoo`0eOol00`00
Oomoo`03Ool00`00Oomoo`0BOol00g`0Oomoo`1oOol00`00Oomoo`0eOol00`00Oomoo`04Ool00`00
Oomoo`03Ool01000Oomoo`00SGoo00<007ooOol0;7oo000^Ool00`00Oomoo`02Ool30005Ool01@00
Oomoogoo00000goo00<007ooOol017oo00=l07ooOol01Goo0g`017oo00=l07ooOol04goo0W`01Woo
0P001Woo00=l07ooOol02Goo00Al07ooOoml011oo`04O01oogoo0002Ool01g`0OomoogooO01oog`0
00Aoo`04001l07oo0002Ool200000g`0Ool0000200000g`0Oomoo`02Ool01`00Oomoogoo001oo`00
009oo`03001oogoo03Eoo`03001oogoo089oo`03001oogoo01Eoo`03001oogoo03Eoo`03001oogoo
01Uoo`03O01oogoo00eoo`03O01oogoo02ioo`04O01oogooO00AOol00g`0Ooml0003Ool01G`0Oomo
ogooO0003Goo00=l07ooOol00Woo0W`037oo00<007ooOol0=Woo00<007ooOol00goo00<007ooOol0
4goo00=l07ooOol0OWoo00<007ooOol0=Goo00<007ooOol017oo00<007ooOol017oo00@007ooOol0
08]oo`03001oogoo02eoo`00;Woo00<007ooOol00goo0`001Goo00D007ooOomoo`00009oo`03001o
ogoo00Eoo`03O01oogoo00Moo`9l00=oo`03O01oogoo011oo`9l00Yoo`03001oogoo00Aoo`9l00Uo
o`04O01oogooO00@Ool3O00017oo001oog`00Woo00Al07ooOoml00Eoo`80009oo`03001oog`0009o
o`800003O01oogoo00=oo`04001oogooOol30002Ool00`00Oomoo`0fOol00`00Oomoo`20Ool00`00
Oomoo`0FOol00`00Oomoo`0fOol00`00Oomoo`0IOol00g`0Oomoo`0=Ool00g`0Oomoo`0]Ool017`0
Oomoog`04Goo00=l07ooO0000Woo00El07ooOomoog`000eoo`03O01oogoo009oo`03O01oogoo00ao
o`03001oogoo03Ioo`03001oogoo01Yoo`03O01oogoo07eoo`03001oogoo03Ioo`03001oogoo00=o
o`03001oogoo00Eoo`04001oogoo002:Ool00`00Oomoo`0]Ool002ioo`05001oogooOol00002Ool2
0006Ool200001Goo001oogoo000027oo00=l07ooOol027oo0g`000=oog`0Ool03Woo0W`03Goo00<0
07ooOol01Goo00=l07ooOol01Woo00Al07ooOoml011oo`=l009oo`04001oogooO002Ool00g`0Oomo
o`04Ool01P00O01oogoo001l009oo`<000Eoo`04001oogooOol30002Ool00`00Oomoo`0gOol00`00
Oomoo`1oOol00`00Oomoo`0FOol00`00Oomoo`0gOol00`00Oomoo`0JOol00g`0Oomoo`0=Ool00g`0
Oomoo`0/Ool017`0Oomoog`047oo00=l07ooO0000goo00Al07ooOoml00eoo`03O01oogoo009oo`03
O01oogoo00eoo`03001oogoo03Ioo`03001oogoo01]oo`03O01oogoo07]oo`03001oogoo03Moo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oo`0008Uoo`03001oogoo02ioo`00;goo00D007ooOomo
o`00009oo`03001oogoo00Ioo`05001oo`00Ool00009Ool00g`0Oomoo`0:Ool3O00<Ool2O00@Ool0
0`00Oomoo`05Ool2O006Ool017`0Oomoog`03goo00Al07ooOoml009oo`04O00007ooO002Ool00g`0
Oomoo`03Ool200000g`0Oomoo`020002Ool30005Ool01000Oomoogoo0P000goo00<007ooOol0>7oo
00<007ooOol0OGoo00<007ooOol05goo00<007ooOol0>7oo00<007ooOol06Woo00=l07ooOol03Goo
00=l07ooOol0:goo00Al07ooOoml011oo`03O01oog`0009oo`04O01oogooO00=Ool00g`0Oomoo`02
Ool00g`0Oomoo`0>Ool00`00Oomoo`0gOol00`00Oomoo`0KOol00g`0Oomoo`1jOol00`00Oomoo`0g
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool30028Ool00`00Oomoo`0^Ool002moo`03001oogoo009o
o`04001oo`000008Ool01000Ool000002Woo00=l07ooOol02goo0g`027oo0W`04goo0P001goo00=l
07ooOol00goo00Al07ooOoml00moo`04O01oog`0Ool2O002Ool01G`0OomoogooO0001Goo00D007oo
001oog`000800004Ool000000005Ool01000Oomoogoo0P000goo00<007ooOol0>Goo00<007ooOol0
OGoo00<007ooOol05Woo00<007ooOol0>Goo00<007ooOol06goo0W`03Woo00=l07ooOol0:Woo00Al
07ooOoml00moo`03O01oog`000=oo`03O01oog`000eoo`03O01oogoo009oo`03O01oogoo00ioo`03
001oogoo03Qoo`03001oogoo01aoo`03O01oogoo07Qoo`03001oogoo03Qoo`03001oogoo00Eoo`03
001oogoo00Moo`8008Ioo`03001oogoo02moo`00<7oo00D007ooOomoo`00009oo`8000Qoo`03001o
o`0000]oo`03O01oogoo00aoo`=l00Aoo`9l01Moo`03001oogoo00Eoo`9l00=oo`04O01oogooO00>
Ool017`0Oomoog`00Woo00El07ooO01oo`00009oo`03O01oogoo009oo`06001oogoo001l07oo0P00
00Aoo`00000000Eoo`06001oogoo001oo`000goo00<007ooOol0>Woo00<007ooOol0Ngoo00<007oo
Ool05goo00<007ooOol0>Woo00<007ooOol077oo00=l07ooOol037oo00=l07ooOol0:Goo00Al07oo
Ooml00moo`03O01oog`0009oo`04O01oogooO00<Ool00g`0Oomoo`02Ool00g`0Oomoo`0?Ool00`00
Oomoo`0iOol00`00Oomoo`0LOol00g`0Oomoo`1gOol00`00Oomoo`0iOol00`00Oomoo`04Ool00`00
Oomoo`08Ool20025Ool00`00Oomoo`0_Ool0031oo`03001oogoo009oo`03001oo`00008000Qoo`<0
00]oo`03O01oogoo00aoo`03O01oog`000=l01Yoo`03001oogoo00Ioo`9l0005Ooml07ooOoml000>
Ool017`0Oomoog`00Woo0W`00goo00<007ooO0000goo00L007ooOomoo`00O01oo`0300000goo0000
0004Ool01@00Oomoo`00Ool00P000Woo00<007ooOol0>goo00<007ooOol017oo00<007ooOol0Lgoo
00<007ooOol05goo00<007ooOol0>goo00<007ooOol07Goo00=l07ooOol037oo00=l07ooOol0:7oo
00Al07ooOoml00moo`03O01oog`0009oo`03O01oog`000aoo`03O01oogoo009oo`03O01oogoo00mo
o`03001oogoo03Yoo`03001oogoo01eoo`03O01oogoo07Eoo`03001oogoo03Yoo`03001oogoo00Ao
o`03001oogoo00Uoo`8008=oo`03001oogoo031oo`00<Goo00<007ooOol00Woo00<007`000000P00
27oo0`002goo00=l07ooOol037oo0W`00Woo0g`06Goo1@001Goo0W`00Woo00=l07ooOol037oo00=l
07ooO0000Woo00Al07ooO01l00=oo`05001l07ooOol00003Ool017`0001l07oo1@001Goo00<007oo
Ool00P0000Eoo`00Oomoo`0003ioo`03001oogoo00Aoo`80079oo`03001oogoo01Qoo`03001oogoo
03aoo`03001oogoo01eoo`03O01oogoo00aoo`9l02Qoo`04O01oogooO00>Ool00g`0Ooml0003Ool2
O00<Ool00g`0Oomoo`02Ool00g`0Oomoo`0@Ool00`00Oomoo`0kOol00`00Oomoo`0MOol00g`0Oomo
o`1dOol00`00Oomoo`0kOol00`00Oomoo`04Ool00`00Oomoo`09Ool20022Ool00`00Oomoo`0`Ool0
035oo`03001oogoo00=oo`8000=l0003001oogoo00Eoo`<000]oo`03O01oogoo00Uoo`9l009oo`03
O01oogoo009oo`9l01aoo`H0009l0003001l07oo00aoo`04O01oogooO002Ool2O0000gooO01oo`03
Ool00g`0Ool00003Ool01G`0Oomoo`00Ool00P0000=oo`00000017oo00D007ooOol007oo0080009o
o`03001oogoo03eoo`03001oogoo00Ioo`8006moo`03001oogoo01Uoo`03001oogoo03eoo`03001o
ogoo01eoo`03O01oogoo00eoo`03O01oogoo02Eoo`04O01oogooO00>Ool00g`0Ooml0002Ool2O00<
Ool00g`0Oomoo`02Ool00g`0Oomoo`0@Ool00`00Oomoo`0mOol00`00Oomoo`0MOol00g`0Oomoo`1b
Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0:Ool20020Ool00`00Oomoo`0aOol0039o
o`03001oogoo00Aoo`03001oogoo00Al00Aoo`04001oo`00000;Ool00g`0Oomoo`06Ool2O005Ool0
0g`0Oomoo`03Ool3O00OOol017`0Ooml07`02@0017oo00=l07ooO0000Woo0W`00goo00Il07ooOomo
og`00003Ool01W`0Oomoogoo001l00D000Aoo`04001oo`00Ool30002Ool00`00Oomoo`0nOol00`00
Oomoo`07Ool00`00Oomoo`1[Ool00`00Oomoo`0IOol00`00Oomoo`0nOol00`00Oomoo`0NOol00g`0
Oomoo`0=Ool00g`0Oomoo`0TOol017`0Oomoog`03Woo0W`00goo0W`02goo00=l07ooOol00Woo00=l
07ooOol047oo00<007ooOol0?Woo00<007ooOol07Woo00=l07ooOol0L7oo00<007ooOol0?Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol0O7oo00<007ooOol0<Woo000cOol01000Oomoogoo
0W`00P000Woo0`0017`000<007ooOol00P002goo00=l07ooOol00goo0W`027oo00=l07ooOol01Goo
0W`07Goo00=l07ooOol00W`027oo0`0000=l000000000`0000=l07ooOol00goo00Ql07ooOoml07oo
001oog`017oo0`0000Aoo`00000000=oo`04001oo`00Ool2000017oo001oo`00@Woo00@007ooOomo
o`9l00Aoo`8006Yoo`03001oogoo01Uoo`03001oogoo041oo`05001oogooOoml000LOol00g`0Oomo
o`0=Ool00g`0Oomoo`0SOol017`0Oomoog`03Goo00=l07ooO0000Woo0W`02goo00=l07ooOol00Woo
00=l07ooOol04Goo00<007ooOol0?goo00<007ooOol07Woo00=l07ooOol0Kgoo00<007ooOol0?goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol0Ngoo00<007ooOol0<Woo000cOol00`00Oomo
o`02Ool00g`000000003Ool01000Ool000000Woo00@007`0O01oo`8000]oo`03O01oogoo009l00]o
o`03O01oogoo00Ioo`=l01Yoo`9l0080009l008000Qoo`05O01oogooO01oo`02O008000017`0Oomo
o`0017oo00El07oo000007oo008000=oo`03001oo`00008000Aoo`03001oogoo045oo`03001oogoo
00=oo`9l00Aoo`8006Moo`03001oogoo01Uoo`03001oogoo045oo`03001oogoo009oo`9l01]oo`03
O01oogoo00eoo`03O01oogoo029oo`9l009oo`03O01oogoo00Yoo`03O01oog`0009oo`03O01oogoo
00Uoo`03O01oogoo009oo`03O01oogoo015oo`03001oogoo041oo`03001oogoo01moo`03O01oogoo
06eoo`03001oogoo041oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo07Uoo`03001oogoo
03=oo`00=7oo00<007ooOol00goo0P0000=l07oo00000goo00<007oo00000Woo0W`00P002goo0W`0
3Woo00=l07ooOol027oo0g`05goo0W`00Woo00Al07ooO01l00P00006O00007`0001oog`01goo00<0
07`0O0001P0000=l07ooOol00`0000=oo`00Ool00Woo0P000Woo0P000goo00<007ooOol0@Woo00<0
07ooOol017oo0W`017oo0P00I7oo00<007ooOol06Woo00<007ooOol0@Woo00<007ooOol00goo0W`0
6Woo00=l07ooOol03Goo00=l07ooOol08Goo0W`00Woo00=l07ooOol02Goo00=l07ooO0000Woo00=l
07ooOol02Goo00=l07ooOol00Woo00=l07ooOol04Woo00<007ooOol0@Goo00<007ooOol07goo00=l
07ooOol0K7oo00<007ooOol0@Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0N7oo00<0
07ooOol0<goo000dOol00`00Oomoo`03Ool00`00Ool00002O0001000Oomoogoo0P001Woo00@007`0
O01l00Eoo`9l0003Ooml07`000ioo`03O01oogoo00Yoo`9l01Eoo`05O01oogooOoml0003Ool2O005
Ool01W`0Oomoog`0Ooml00X0009l00=oo`03001l07oo009oo`03001oo`0000X000=oo`03001oogoo
04=oo`03001oogoo00Ioo`9l00Aoo`03001oogoo061oo`03001oogoo01Yoo`03001oogoo04=oo`03
001oogoo00Eoo`9l01Uoo`03O01oogoo00eoo`03O01oogoo021oo`05O01oogooOoml000;Ool017`0
Ooml07oo0W`02Woo00=l07ooOol00Woo00=l07ooOol04Woo00<007ooOol0@Woo00<007ooOol087oo
0W`0Jgoo00<007ooOol0@Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0MWoo00<007oo
Ool0=7oo000eOol00`00Oomoo`03Ool00`00Ool00002O0001000Oomoogoo0`001Goo00<007ooOol0
1G`01Goo00=l07ooOol037oo00=l07ooOol02goo0g`04Woo00El07ooOomoog`000Eoo`03O01oogoo
009oo`03O01oogoo00=l00Ioo`06001oogooOoml07oo3@0000Eoo`00000007oo008000Aoo`03001o
ogoo04Aoo`03001oogoo00Moo`9l00=oo`8005moo`03001oogoo01]oo`03001oogoo04Aoo`03001o
ogoo00Ioo`9l01Qoo`03O01oogoo00eoo`03O01oogoo01moo`05O01oogooOoml000;Ool01G`0Ooml
07ooO0002Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`03O01oogoo00aoo`03001oogoo04=o
o`03001oogoo025oo`03O01oogoo06Qoo`03001oogoo04=oo`03001oogoo00=oo`03001oogoo00io
o`8007Ioo`03001oogoo03Aoo`00=Woo00<007ooOol00Woo00X007ooOol007ooO00007`0Ool0009o
o`8000=oo`80009oo`9l0003Ooml07`0009l00=oo`03O01oogoo00aoo`9l00ioo`9l00moo`9l00=o
o`03O01oogoo00Aoo`9l009oo`03O01oog`0009l00Ioo`05001oogooOoml000500000goo00000004
00000goo000000020003Ool00`00Oomoo`02Ool00`00Oomoo`15Ool00`00Oomoo`09Ool2O003Ool2
001LOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`15Ool00`00Oomoo`08Ool00g`0Oomo
o`0FOol00g`0Oomoo`0=Ool2O00NOol2O003Ool00g`0Oomoo`08Ool017`0Ooml07oo0W`02Goo00=l
07ooOol00Woo00El07ooOomoog`0009oo`03001oogoo00aoo`03001oogoo04Aoo`03001oogoo029o
o`03O01oogoo06Ioo`03001oogoo04Eoo`03001oogoo009oo`03001oogoo011oo`03001oogoo079o
o`03001oogoo03Eoo`00=goo00D007ooOomoo`00009oo`07001oogooO00007`0000017oo00L007oo
Ool007oo001l0007Ool3O0000gooO01oo`0>Ool00g`0Oomoo`0=Ool3O00<Ool00g`0Oomoo`02Ool0
0g`0Oomoo`06Ool2O002Ool3O006Ool500001g`0Ooml0000Ool007`000@00003O0000000009oo`04
001oogoo0005Ool00`00Oomoo`16Ool00`00Oomoo`0:Ool2O003Ool00`00Oomoo`1IOol00`00Oomo
o`0:Ool2000?Ool00`00Oomoo`16Ool00`00Oomoo`08Ool2O00GOol00g`0Oomoo`0>Ool00g`0Oomo
o`0KOol00g`0Oomoo`02Ool00g`0Oomoo`08Ool00g`0Ooml0002O009Ool00g`0Oomoo`02Ool00g`0
Oomoo`02O0000goo0000000>Ool00`00Oomoo`16Ool00`00Oomoo`0ROol00g`0Oomoo`1UOol00`00
Oomoo`16Ool01@00Oomoogoo00004goo00<007ooOol0LGoo00<007ooOol0=Goo000gOol00`00Oomo
o`02Ool01000Oomoo`000goo0P000W`00goo0P000W`000=oo`0000002Goo17`03Woo00=l07ooOol0
3goo0W`02Goo0W`017oo00=l07ooOol01goo1G`00Woo1@000Woo00Ul07ooOoml07oo001l0000Ool0
1@0000=l0000Ool00`0000=oo`00Ool017oo00<007ooOol0B7oo00<007ooOol02goo0W`00Woo0P00
F7oo00<007ooOol02Woo00@007ooOol000eoo`03001oogoo04Qoo`03001oogoo00Uoo`9l01Ioo`03
O01oogoo00ioo`03O01oogoo01Uoo`9l00Aoo`03O01oogoo00Qoo`=l0003Ooml07oo00Moo`03O01o
ogoo009oo`04O01oogooO002Ool00`00Oomoo`0=Ool00`00Oomoo`18Ool2000SOol00g`0Oomoo`1R
Ool2001:Ool01@00Oomoogoo00004goo00<007ooOol0Kgoo00<007ooOol0=Woo000hOol01@00Oomo
ogoo00000goo00D007ooOomoo`0000Al0003Ooml07`0008000=oo`03001oogoo00Uoo`El00]oo`03
O01oogoo011oo`=l00Ioo`9l00Aoo`03O01oogoo00Ioo`04O01oogooO0040003Ool01000Oomoog`0
0goo0W`00P0000=l07oo00001@0000Ioo`00000007oo0006Ool00`00Oomoo`18Ool00`00Oomoo`0=
Ool2O002Ool2001EOol00`00Oomoo`0:Ool01000Ool000003Goo00<007ooOol0BWoo00<007ooOol0
2Woo0W`05Goo00=l07ooOol03Woo00=l07ooOol067oo0W`017oo00=l07ooOol01goo00Il07ooO01l
07ooO007Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00<007ooOol03Goo00<007ooOol0BWoo00<0
07ooOol08Woo00=l07ooOol0H7oo00<007ooOol0BWoo00D007ooOomoo`0001Aoo`03001oogoo06eo
o`03001oogoo03Moo`00>Goo00D007ooOomoo`0000=oo`03001oogoo00800003Ooml07`0009l00=o
o`05001oogooOol0000;Ool017`0Oomoogoo17`027oo00=l07ooOol04Woo0g`00Woo00=l07ooO000
17oo00=l07ooOol01Goo0`0000Al0000O01l00Aoo`04001oogooO004Ool017`0000007oo100000=o
o`000000100000=oo`00000017oo0P00C7oo00<007ooOol03Woo0W`00Woo0P00DWoo00<007ooOol0
2Goo0P0000=oo`00Ool03Woo00<007ooOol0Bgoo00<007ooOol02goo0W`057oo00=l07ooOol03Woo
00=l07ooOol05goo0W`017oo00=l07ooOol01goo00El07ooO01oog`000Moo`03O01oogoo009oo`05
O01oog`0O01oo`02000@Ool00`00Oomoo`1;Ool00`00Oomoo`0ROol00g`0Oomoo`1OOol00`00Oomo
o`1;Ool01@00Oomoogoo000057oo0P00K7oo00<007ooOol0>7oo000iOol01@00Oomoogoo000017oo
00@007ooOomoo`9l0003Ooml07oo00=l00<0009oo`03001oogoo00Uoo`03O01oogoo00Aoo`=l00Io
o`03O01oogoo01Aoo`=l0003Ooml07oo00=oo`03O01oogoo00D00007Ooml07ooO01oog`0Ool00W`0
00Eoo`00Oomoog`000Aoo`04O00007ooOol2000017`0000007oo0P0000=oo`0000000`0017oo00<0
07ooOol0CGoo00<007ooOol03goo0W`00Woo00<007ooOol0CWoo00<007ooOol02Goo00@007oo0000
00moo`03001oogoo04aoo`03001oogoo00eoo`03O01oogoo019oo`03O01oogoo00ioo`03O01oogoo
01Eoo`03O01oog`000Aoo`03O01oogoo00Moo`9l009oo`03O01oogoo00Aoo`03O01oogoo009oo`03
O01oog`0009oo`03001oogoo00moo`03001oogoo04aoo`03001oogoo02=oo`03O01oogoo05eoo`03
001oogoo04aoo`05001oogooOol0000FOol00`00Oomoo`1XOol00`00Oomoo`0iOol003Yoo`03001o
ogoo00Ioo`05001l07`0Ool00002Ool2O002Ool00g`0001oo`0200000goo001oo`0:Ool00g`0Oomo
o`06Ool4O003Ool00g`0Oomoo`0DOol20002O003Ool40005Ool01W`0Ooml07`0Ooml00=oo`04O01o
ogooO004Ool017`0000007oo2P0000Al0000000000Eoo`03001oogoo04ioo`03001oogoo011oo`9l
0003Ool0000004eoo`03001oogoo00Uoo`03001oo`00011oo`03001oogoo04ioo`03001oogoo00eo
o`9l01=oo`03O01oogoo00ioo`03O01oogoo01Aoo`03O01oog`000Aoo`03O01oogoo00Ioo`=l0003
Ooml07oo00Eoo`03O01oogoo009oo`06O01oog`0Ooml00004Woo00<007ooOol0CGoo00<007ooOol0
8goo00=l07ooOol0G7oo00<007ooOol0CGoo00<007ooOol067oo00<007ooOol0Igoo00<007ooOol0
>Goo000kOol01000Oomoo`000goo00=l0000Ool00goo00@007ooOomoo`9l0007Ool007`0O01oo`00
Ool00P002Woo00=l07ooOol02Goo1G`05Goo00=l07oo0000100000=oog`0Ool01Woo0W`000=oog`0
O0000goo00@007ooO01l00Aoo`03O000000000D00003Ool0000000L000Eoo`03001oogoo051oo`03
001oogoo015oo`9l0003Ool0000004Yoo`03001oogoo00Qoo`@0011oo`03001oogoo051oo`03001o
ogoo00ioo`9l019oo`9l00moo`03O01oogoo019oo`04O01oogooO004Ool00g`0Oomoo`06Ool2O002
Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool3O0000goo0000000AOol2001AOol2000TOol00g`0Oomo
o`1IOol2001AOol2000IOol00`00Oomoo`1UOol00`00Oomoo`0jOol003aoo`04001oogoo0002O002
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2O002Ool2O00200000goo001oo`09Ool00g`0Oomoo`0<
Ool4O00BOol017`0Oomoog`00Woo10001Woo00El07ooO01oog`0009oo`06001oogooO01oog`00Woo
00El0000000007`000@00003Ool0000000800004Ool000000006Ool00`00Oomoo`1@Ool00`00Oomo
o`0COol3O0000`00Oomoo`16Ool00`00Oomoo`08Ool00`00Ool0000AOol00`00Oomoo`1BOol00`00
Oomoo`0<Ool00`00Oomoo`02O00BOol00g`0Oomoo`0=Ool00g`0Oomoo`0AOol017`0Oomoog`017oo
00=l07ooOol01Goo0g`000=oog`0Ool017oo00=l07ooOol00Woo0W`00Woo00<007ooOol047oo00<0
07ooOol0DWoo00<007ooOol08goo00=l07ooOol0Egoo00<007ooOol0DWoo00<007ooOol067oo00<0
07ooOol0Hgoo00<007ooOol0>goo000mOol01@00Oomoogoo00000goo00<007ooOol00Woo0`000Woo
0P0000=l07ooOol00W`00`002Woo00=l07ooOol03Goo1W`03Goo00El07ooOomoog`000Eoo`03O000
000000800004Ooml07`0Ool2O002Ool01000Oomoog`00goo0W`0100000El07ooOol007oo00P000Eo
o`8005Aoo`03001oogoo01Eoo`03O000000004Eoo`03001oogoo00Moo`@0019oo`03001oogoo05=o
o`03001oogoo00aoo`80009oo`9l015oo`03O01oogoo00eoo`9l015oo`04O01oogooO005Ool00g`0
Oomoo`04Ool01G`0Ooml07ooO00017oo00=l07ooOol00Woo0W`000=oog`000004goo00<007ooOol0
Dgoo00<007ooOol08goo00=l07ooOol0EWoo00<007ooOol0Dgoo00<007ooOol067oo0P00HWoo00<0
07ooOol0?7oo000mOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00@007`00000009oo`8000=o
o`9l008000Yoo`03O01oogoo00ioo`04O01oogooOol3O00:Ool01G`0OomoogooO0001Goo00=l07oo
Ool00W`000P007`0000007ooO01oo`000Woo00=l07ooOol00Woo00=l000000000`0000=l07oo0000
2@001Goo00<007ooOol0EGoo00<007ooOol05Woo00=l00000000@Woo00<007ooOol01goo00<007oo
00004goo00<007ooOol0E7oo00<007ooOol037oo0W`00P000Woo00=l07ooOol03goo00=l07ooOol0
3Woo00=l07ooOol03Goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`=l0003Ooml07oo00=oo`03
O01oogoo009oo`9l0003Ool0000001=oo`03001oogoo05Aoo`03001oogoo02Aoo`03O01oogoo05Ao
o`03001oogoo05Eoo`03001oogoo01Uoo`03001oogoo05ioo`03001oogoo03eoo`00?Woo00<007oo
Ool00Woo0P000Woo00<007ooOol00goo0g`000<007ooOol00`000Woo00=l000000002Woo00=l07oo
Ool03Woo00=l07ooOol00goo17`01Goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00Woo
17`0100000=oog`0Ool00Woo0W`00`000W`000=oog`0Ool02P001Goo00<007ooOol0EWoo00<007oo
Ool05goo00=l00000000?goo00<007ooOol01goo00<007oo00004goo00<007ooOol0EWoo00<007oo
Ool03Goo0W`00P0000=oog`0O00047oo00=l07ooOol03Woo00=l07ooOol037oo00El07ooOomoog`0
00Eoo`03O01oogoo009oo`9l0004Ooml07ooO003Ool00g`0Oomoo`02Ool3O0000`00Oomoo`0BOol0
0`00Oomoo`1FOol00`00Oomoo`0TOol00g`0Oomoo`1COol00`00Oomoo`1FOol00`00Oomoo`0IOol0
0`00Oomoo`1MOol00`00Oomoo`0mOol003moo`03001oogoo00=oo`03001oo`0000Moo`03001l07`0
009l0003Ooml000000800004Ooml00000009Ool00g`0Oomoo`0>Ool00g`0Oomoo`06Ool4O0000goo
O01oo`03Ool00g`0Oomoo`03Ool017`0Oomoogoo0W`00Woo0W`000<007ooOol010000W`010000Woo
0W`00`0000Aoo`00001oo`<000Eoo`03001oogoo05Qoo`03001oogoo01Qoo`03O00007oo03aoo`03
001oogoo00Ioo`@001=oo`03001oogoo05Qoo`03001oogoo00ioo`9l00800003Ooml07`000moo`03
O01oogoo00ioo`03O01oogoo00Yoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`=l
009oo`04O01oogooO004Ool017`0Ooml000057oo00<007ooOol0F7oo00<007ooOol097oo00=l07oo
Ool0DGoo00<007ooOol0F7oo00<007ooOol06Goo00<007ooOol0Fgoo00<007ooOol0?Woo0010Ool0
0`00Oomoo`03Ool30007Ool200000g`0001l0004O00200000gooO0000009Ool00g`0Oomoo`0>Ool0
0g`0Oomoo`08OolA00000g`00000000M0005Ool00`00Oomoo`1JOol00`00Oomoo`0IOol2000jOol0
0`00Oomoo`06Ool00`00Ool0000DOol00`00Oomoo`1JOol00`00Oomoo`0?Ool2O00200000gooO01l
000>Ool00g`0Oomoo`0>Ool00g`0Oomoo`09Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01W`0Oomo
ogooO01oo`9l0005Ooml07ooOoml0004Ool017`0Ool0000037oo0P001Woo00<007ooOol0FWoo00<0
07ooOol097oo00=l07ooOol0Cgoo00<007ooOol0FWoo00<007ooOol06Goo00<007ooOol0FGoo00<0
07ooOol0?goo0011Ool00`00Oomoo`04Ool20008Ool00`00Ooml00020002Ool4O00300000g`0Oomo
o`05Ool00g`0Oomoo`0>Ool00g`0Oomoo`07Ool700000g`0Oomoo`03Ool00g`0Oomoo`02O002Ool2
O0001000Ooml07oo0g`01`000goo00Al0000O01l00@000Ioo`03001oogoo05aoo`03001oogoo01Yo
o`8003Qoo`03001oogoo00Eoo`<001Aoo`03001oogoo05aoo`03001oogoo011oo`9l00800003Ooml
07oo00eoo`03O01oogoo00ioo`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo00=oo`0<O01o
ogooO01oog`0Ooml07ooO01oog`00goo0g`000<007ooOol02Woo10001Goo00<007ooOol0G7oo00<0
07ooOol097oo00=l07ooOol0CGoo00<007ooOol0G7oo00<007ooOol06Goo00<007ooOol0Egoo00<0
07ooOol0@7oo0012Ool20005Ool00`00Oomoo`07Ool200001GooO0000000Ool00W`000=oog`0O000
17`01Woo00=l07ooOol03Woo00=l07ooOol01Woo00=l07ooOol00goo2@0000Al00000000009l0003
001oog`0009oo`03O01oo`0000@000Eoo`04001l0000Ool40006Ool00`00Oomoo`1NOol00`00Oomo
o`0KOol00`00O01oo`0UOol00`00Oomoo`0<Ool00`00Oomoo`04Ool3000EOol00`00Oomoo`1NOol2
000BOol2O0020002O00=Ool00g`0Oomoo`0>Ool00g`0Oomoo`06Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Ooml0002Ool2O00017ooO01oog`00goo0g`000<007ooOol02Goo10001Woo00<007oo
Ool0GWoo0P009Goo00=l07ooOol0BWoo0P00H7oo00<007ooOol06Goo0P00EGoo0P00@goo0014Ool0
0`00Oomoo`03Ool20009Ool01000Oomoog`00P0000=oog`0O0000Woo0P0017`017oo00=l07ooOol0
3Woo00=l07ooOol01Goo00=l07ooOol00goo00<007`0Ool017oo0W`00Woo00=l07oo00001P0000=o
o`0000000P0000=l0000O0000goo0P0000=l000000000`001Woo00<007ooOol0H7oo0P0077oo0P00
00=l07ooOol08Woo00<007ooOol02goo00<007ooOol017oo0`0037oo0`001Goo0P00Hgoo00<007oo
Ool04Goo0W`00P000W`037oo00=l07ooOol03Woo00=l07ooOol01Goo00=l07ooOol00goo00=l07oo
Ool00goo00Ql07ooO01oog`0Ooml07oo0W`00goo0W`00P002Woo10001Woo0P00Hgoo00<007ooOol0
8goo00=l07ooOol0B7oo00<007ooOol0HGoo0P006goo00<007ooOol0DGoo00<007ooOol0@goo0015
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool20003Ool2000017ooO01l07oo1@001W`047oo0W`01Goo
00=l07ooOol00goo00<007`0Ool017oo0W`01`0000Aoog`0001l00@00004Ool007ooOol2O0030000
0g`0000000020006Ool00`00Oomoo`1ROol00`00Oomoo`0LOol200000g`0Oomoo`0POol00`00Oomo
o`0:Ool00`00Oomoo`04Ool2000<Ool30006Ool00`00Oomoo`1TOol00`00Oomoo`0BOol2O0020002
O00;Ool00g`0Oomoo`0>Ool2O004Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool2O002Ool2O0000goo
O01l0002Ool017`0001l00002Woo10001goo00<007ooOol0I7oo00<007ooOol08goo00=l07ooOol0
AWoo00<007ooOol0Hgoo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol0A7oo0016Ool00`00
Oomoo`04Ool20009Ool00`00Oomoo`02Ool200001WooO01l07oo001oo`D00003Ooml07`0009l00mo
o`05O01oogooOoml0005Ool00`00Ool00005000017`0000007`00P000W`01P0000Aoo`00Ool000Ao
o`03001l07`000@000Ioo`8006Ioo`03001oogoo01eoo`800003O01oogoo01eoo`03001oogoo00Yo
o`03001oogoo00=oo`<000]oo`<000Qoo`03001oogoo06Eoo`03001oogoo01=oo`9l0080009l00Io
o`05001oogooOoml000AOol01G`0OomoogooO0001Woo00=l07ooOol00goo00Al07ooOomoo`9l0004
Ooml07ooOol40008Ool50009Ool00`00Oomoo`1UOol00`00Oomoo`0SOol00g`0Oomoo`14Ool00`00
Oomoo`1UOol00`00Oomoo`0JOol00`00Oomoo`1=Ool00`00Oomoo`15Ool004Moo`8000Ioo`03001o
ogoo00Moo`03001oogoo00=oo`800004Ooml07oo0002Ool40002Ool00g`0Ooml0004O00;Ool00g`0
Oomoo`0800000g`0Ool000020002O00017ooO00000000W`01P0000Aoo`00Ool000=oo`H00003O000
07oo00Eoo`03001oogoo06Moo`8001moo`03001l07`001eoo`03001oogoo00Uoo`03001oogoo00=o
o`8000]oo`800003O01oogoo00Ioo`8006Uoo`03001oogoo01Eoo`04O0000000O006Ool01@00Oomo
ogooO0004Goo00=l07ooO0001goo00=l07ooOol00Woo0W`00Woo00Al07ooO01l009oo`04001l0000
O007Ool4000:Ool2001YOol2000TOol00g`0Oomoo`11Ool2001YOol2000KOol00`00Oomoo`1;Ool0
0`00Oomoo`16Ool004Qoo`04001oogooOolR00000g`0000000030005O00A00002G`000000000O000
07`0001l000200000g`00000000900000goo000000070006Ool00`00Oomoo`1ZOol00`00Oomoo`0M
Ool20003O00JOol00`00Oomoo`08Ool00`00Oomoo`02Ool40009Ool200000g`000000007Ool00`00
Oomoo`1ZOol00`00Oomoo`0FOol017`0000007`01Goo0P000Woo00=l07ooOol03goo0W`01goo00Ml
07ooOomoog`0Ooml0002Ool5O0000`00O0000007Ool70008Ool00`00Oomoo`1ZOol00`00Oomoo`0S
Ool00g`0Oomoo`0oOol00`00Oomoo`1[Ool00`00Oomoo`0IOol2001:Ool00`00Oomoo`17Ool004Uo
o`03001oogoo00Eoo`8000Uoo`03001oogoo00Aoo`800003O0000000009oo`800004Ool00000O003
Ool60004O004Ool00g`0Ool0000500000g`000000002Ool01W`0Ooml07ooO01oo`9l00L00003Ool0
000000T000Moo`03001oogoo06aoo`03001oogoo01ioo`800003Ooml07`001Qoo`03001oogoo00Mo
o`03001oogoo009oo`@000Moo`<00003Ool0000000Qoo`03001oogoo06aoo`03001oogoo01Moo`04
O0000000O005Ool01000Oomoog`047oo0W`01Woo00=l07ooOol00Woo00=l07ooO0000Woo0g`01000
1Woo1`002Goo00<007ooOol0K7oo00<007ooOol08goo00=l07ooOol0?Woo00<007ooOol0K7oo00<0
07ooOol06Woo00<007ooOol0AWoo00<007ooOol0B7oo001:Ool20003Ool2O002Ool00`00Oomoo`07
Ool20006Ool40002Ool8000:Ool6O00400000goo001l0003Ool01W`0OomoogooO01oo`9l00@00003
Ool0000000`000Ioo`80071oo`03001oogoo01moo`03001oogoo009l01Ioo`03001oogoo00Ioo`04
001oogooOol40004Ool00`00Oomoo`02000017`0000000002Goo00<007ooOol0KWoo0P000Woo0W`0
5Goo00Al0000001l00Aoo`04001oogooO00?Ool00g`0Ooml0004Ool00`00O01oo`02Ool017`0Oomo
ogoo17`000@007`0001l00Eoo`L000Yoo`03001oogoo06ioo`8002Aoo`9l03aoo`80071oo`03001o
ogoo01Yoo`03001oogoo04=oo`8004]oo`00C7oo0P000goo0g`00P002Goo00<007ooOol00Woo1`00
0goo0`000W`00`000goo1`0000=l07ooO0000g`000Aoo`00001l009oo`05O01oogooOol00002O004
00000g`0Ool0000<0007Ool00`00Oomoo`1aOol2000POol20002Ool2O00BOol30007Ool01000Oomo
ogoo0`0017oo1@0000Aoo`00000000Uoo`8007=oo`04001oogooOol4O004Ool4000;Ool017`00000
07`00goo0P0000=oog`0Ool03Goo00Al07ooOoml00=oo`05001l07ooOoml0004Ool3O0000`00O000
0004Ool700000goo00000008Ool2001cOol2000TOol00g`0Oomoo`0gOol2001cOol2000KOol00`00
Oomoo`11Ool00`00Oomoo`1;Ool004ioo`8000Eoo`04O00007`0Ool;00000goo001oo`03Ool20003
Ool300000gooO00000060004Ool00g`0Oomoo`02Ool00g`0001l0005O003Ool00`00Ooml00040000
0g`0Ool0000<0006Ool2001fOol2000POol20002Ool2O00?Ool40006Ool00`00Oomoo`030004Ool:
0008Ool2001fOol20005Ool4O004Ool70006Ool00g`000000004Ool00`00Ooml000<Ool00g`0Oomo
o`02Ool01g`0Oomoo`00O01oog`000Eoo`03O0000000008000=oo`L00003Ool0000000Qoo`8007Mo
o`03001oogoo029oo`03O01oogoo03Eoo`03001oogoo07Eoo`8001Yoo`03001oogoo03ioo`8004io
o`00D7oo00<007ooOol017oo1@0000=oo`0000001`001Goo0`000Woo100000Al0000O01l008000Eo
o`03O01oogoo009oo`07001l07oo001oog`0000017`000=oog`000000`0000=l000000002`001Woo
0P00NWoo0P0087oo0P000Woo0W`037oo0P0000=oo`0000000Woo100000Aoo`00000000Aoo``000Io
o`8007Yoo`8000Moo`Al00Moo`H0009oo`03O000000000=oo`04001oog`0O00:Ool00g`0Oomoo`03
Ool01W`0000007`0Ooml00<00006Ooml0000O00007`00Woo1P000Woo0P0027oo0P00NWoo0P008goo
00=l07ooOol0<Woo0P00NWoo0P006Goo00<007ooOol0>goo0P00D7oo001AOol00`00Oomoo`04Ool2
0002Ool3O004Ool=0003Ool200000g`000000002O005Ool00g`0Oomoo`020002Ool2O0000`00O01l
0002Ool00`00Ooml00020003O00<0007Ool00`00Oomoo`1lOol2000POol01000Oomoogoo0W`027oo
0P000goo10000Woo00<007oo00000P000goo30001Woo0P00OWoo0P002Goo17`00goo0P0017oo1`00
0Woo0P0000=oog`000001goo00=l07ooOol01Goo17`017oo00Il0000O00007`0Ool60002Ool20009
Ool00`00Oomoo`1lOol2000ROol00g`0Oomoo`0_Ool2001nOol00`00Oomoo`0GOol2000iOol2001B
Ool0059oo`03001oogoo00Eoo`@00003Ooml07`0009l0003Ool0000000D0009oo`T00004O01oo`00
Ool2O002Ool017`0Oomoo`000goo0`000W`00goo10000W`000<007`0O0002@0027oo00<007ooOol0
Ogoo00<007ooOol017oo10005Woo0P000goo0W`01Goo0P000goo0`0017oo1@0000=oo`0000002P00
1goo00<007ooOol0P7oo0P002goo17`000Aoo`00000000Qoo`T000Eoo`03O01oogoo00Aoo`<00003
O01oogoo009oo`8000Al00@0009oo`<000Uoo`80085oo`80025oo`03O01oogoo02aoo`80085oo`80
01Uoo`03001oogoo03Aoo`8005Aoo`00Dgoo0P0027oo00=l0000000030000goo00<007ooOol02P00
0g`00P0000Eoo`00000007oo0080009l009oo`<00003O000000000H0009l008000Uoo`8008=oo`80
00Moo`X000moo`8000=oo`9l0003Ool00000009oo`<00003Ool007oo00=oo`<0009oo`/000Qoo`80
08Eoo`8000Ioo`Al00=oo`=l0003Ool00000008000Ioo`800003Ool007oo00L00004O01oogooOol3
00000goo001l0002O002Ool30002O0030003Ool2000:Ool20025Ool2000POol00g`0Oomoo`0YOol2
0025Ool2000HOol00`00Oomoo`0aOol2001FOol005Eoo`@000Qoo`9l0003001l07`001000003O000
000000/0009oo`800003O00007`000h000Uoo`<008Moo`8000eooaH0009oo`800003Ool0000000Ao
o`03001oo`0000@00003Ool0000000P000Uoo`8008Uoo`03001oogoo00Moo`Yl0004Ool000000005
Ool400001W`0Ool00000Ooml00H0009oo`05001l0000001l00070002Ool3000:Ool20029Ool2000O
Ool00g`0Oomoo`0VOol20029Ool2000GOol00`00Oomoo`0_Ool00`00Oomoo`1FOol005Uoo`8000Mo
o`H00003O00007`0009l00P00004O0000000O0070002O00500000g`00000000=0009Ool2002<Ool2
0007OolD0004Ool700000g`00000000B000:Ool2002<Ool20007Ool40003Ool7O0030003Ool01G`0
00000000O0000Woo100017oo0P0000=l000000000P0000Al00000000009l00@000Yoo`8008eoo`80
01ioo`03O01oogoo02=oo`8008eoo`8001Ioo`03001oogoo02aoo`8005Uoo`00Fgoo0P002Goo2000
17`0500000=l0000000030002Goo0P00T7oo0P0037oo:P002goo0P00T7oo0P002Goo20000Woo0g`0
0`0000=l07ooO0000P0000Al0000001oo`L00003O000000000L0009l008000Yoo`80095oo`8001eo
o`03O01oogoo021oo`80095oo`8001Eoo`8002Yoo`8005]oo`00GGoo0P003goo0`000W`0700000=o
og`0Ool02Woo0P00U7oo0P005Woo6`0037oo0P00U7oo0P003goo1P000W`0100000=l000000002`00
00=l000000001@0037oo0P00UGoo0P0077oo00=l07ooOol07Goo0P00UGoo0P005Goo00<007ooOol0
9Goo0P00GGoo001OOol4000?Ool40002O00H0008Ool4002HOol4000DOolI0008Ool4002HOol4000?
Ool600000g`00000000E0008Ool4002IOol3000JOol00g`0Oomoo`0IOol3002IOol4000BOol00`00
Oomoo`0POol4001OOol006=oo`8000eooaL000eoo`800:1oo`8000iooaH000Aoo`03001oo`0000Io
o`800:1oo`8000iooaD000Eoo`03001oo`0000Ioo`800:1oo`<001Qoo`03O01oogoo01Eoo`<00:1o
o`80015oo`03001oogoo01eoo`8006=oo`00IGoo10003Woo1@000W`00goo1@0037oo1000Y7oo1000
3goo1P000goo1@0037oo1000Y7oo10003goo1P001Goo0`0037oo1000YGoo1000:7oo1000YGoo1000
:Goo1000IGoo001YOol4000GOol00`00Oomoo`06Ool5002/Ool6000EOol20006Ool6002/Ool7000D
Ool20006Ool6002]Ool6000LOol6002]Ool6000LOol7001YOol006eoo`P0011oo`P00;Moo`T000]o
o`T00;Uoo`P000]oo`T00;Uoo`P000aoo`P00;Uoo`T000]oo`P0071oo`00MGoo4000b7oo2`00bWoo
2`00bWoo3000bWoo2`00N7oo003oOoooOoooOoooOomDOol00?mooomooomooomooeAoo`00ogooogoo
ogooogooE7oo003oOoooOoooOoooOomDOol00?mooomooomooomooeAoo`00ogooogooogooogooE7oo
003oOoooOoooOoooOomDOol00?moofIoo`03001oogoo011oo`<0045oo`03001oogoo07]oo`03001o
ogoo04=oo`03001oogoo07Ioo`<00<Ioo`<008]oo`00ogooIGoo00<007ooOol04Woo00<007ooOol0
@Goo00<007ooOol0NGoo00<007ooOol0AGoo00<007ooOol0MWoo00<007ooOol0aWoo00<007ooOol0
RWoo003oOomUOol00`00Oomoo`0BOol00`00Oomoo`11Ool00`00Oomoo`1iOol00`00Oomoo`15Ool0
0`00Oomoo`1fOol00`00Oomoo`36Ool00`00Oomoo`2:Ool0071oo`<0009oo`<00003Ool0000000D0
0003Ool0000000D005Yoo`@000Aoo`D000Aoo`@0009oo`<00005Ool00000Ool0000;Ool3000017oo
000000000Woo10000Woo0`0000Eoo`00001oo`00009oo`D000]oo`800004Ool000000004Ool30000
17oo000007oo1@0017oo1@003goo00<007ooOol00goo1P000Woo1@000goo100017oo0`0000Aoo`00
001oo`D000Eoo`<000Eoo`800004Ool00000Ool50004Ool50002Ool50009Ool00`00Oomoo`08Ool5
0003Ool4000<Ool3000017oo000000000Woo10000Woo0`0000Eoo`00001oo`00009oo`D000]oo`80
0004Ool000000004Ool3000017oo000007oo1@0017oo1@003goo00<007ooOol00goo0`0000Aoo`00
001oo`D000=oo`D000=oo`L000=oo`8000Eoo`<00004Ool00000Ool700000goo000000030008Ool0
0`00Oomoo`1:Ool40004Ool50004Ool40002Ool300001Goo000007oo000037oo10000goo1`000Woo
0`0000=oo`0000000Woo100017oo1@000goo1@00Pgoo1@000goo10003Goo10000goo1`000Woo0`00
00=oo`0000000Woo100017oo1@003Goo1@00EWoo001aOol00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00H007ooOol007oo000AOol20003Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo
00@007ooOol001Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0008Ool01@00Oomoogoo
00000Woo00@007ooOomoo`8000=oo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`02
0003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`004Goo0P000goo00@007ooOol000=oo`80
009oo`03001oogoo009oo`04001oogoo000DOol00`00Oomoo`02Ool01000Oomoogoo0P000goo00<0
07ooOol01Goo00<007ooOol01goo00<007ooOol017oo0P0017oo00@007ooOomoo`8000Eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo04]oo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0037oo00D007ooOomoo`0000Eo
o`03001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`02Ool01000Oomoo`002Woo00<007oo
Ool0QGoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Eoo`03
001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`02Ool01000Oomoo`0057oo00<007ooOol0
EWoo001bOol40006Ool00`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000aoo`05001oogooOol00002Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo000AOol00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol001Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0008Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo00Eo
o`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`004Goo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`04001oogoo000DOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00001goo00<007ooOol01goo00<007ooOol00goo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo04]oo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0037oo00D007ooOomoo`00
00Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`08Ool00`00Oomo
o`25Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Moo`03001oogoo019oo`03001oogoo05Ioo`00
LWoo00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo05aoo`03001oo`0000Eoo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0037oo00D007ooOomoo`00009oo`03
001oogoo009oo`04001oogoo0002Ool01@00Oomoo`00Ool01P0037oo00<007ooOol00Woo00@007oo
Oomoo`D000=oo`@000=oo`H000moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00H000=o
o`05001oogooOol00003Ool50003Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0goo00<007ooOol017oo1P000goo10002Goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol02Woo00D007ooOomoo`00009oo`03001oogoo009oo`04001oogoo0002Ool01@00
Oomoo`00Ool01P0037oo00<007ooOol00Woo00@007ooOomoo`D000=oo`@000=oo`H000moo`03001o
ogoo00=oo`D000=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo0004
Ool50005Ool00`00Oomoo`03Ool40008Ool00`00Oomoo`1;Ool00`00Ool00005Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000aoo`05001oogooOol00005Ool00`00
Oomoo`03Ool50002Ool00`00Oomoo`05Ool60005Ool00`00Oomoo`25Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<007ooOol00goo1@000Woo00<007oo
Ool01Goo1P003goo00<007ooOol0EWoo001bOol01000Oomoo`001Woo00<007ooOol01Goo00<007oo
Ool0G7oo0`001Goo0P001Goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00001oo`0000aoo`80
009oo`04001oogoo0004Ool00`00Oomoo`0200001goo000007oo001oo`0000Aoo`03001oogoo00Yo
o`8000=oo`04001oogoo0004Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00eoo`03
001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@007oo
Ool000Aoo`04001oogooOol20006Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo0P001Goo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Yoo`80009oo`04001oogoo0004Ool00`00Oomoo`0200001goo0000
07oo001oo`0000Aoo`03001oogoo00Yoo`8000=oo`04001oogoo0004Ool01000Oomoo`0017oo00@0
07ooOol000Aoo`03001oogoo00eoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20006
Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0Bgoo0`001Goo0P001Goo00<0
07ooOol00Woo00<007ooOol00P0000Eoo`00001oo`0000aoo`80009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`25Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool20002Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo0P000Woo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol0EWoo001cOol20007Ool00`00Oomoo`05Ool00`00Oomoo`1L
Ool01@00Ool007oo00000Woo0P0000Aoo`00000000=oo`@0009oo`800005Ool007ooOol0000=Ool0
1000Ool0000017oo10000Woo0P0000Eoo`00Oomoo`0000=oo`@000eoo`03001oo`00008000Aoo`@0
00Aoo`D000=oo`@0011oo`03001oogoo00=oo`<00003Ool007oo009oo`@000=oo`800003Ool00000
00Aoo`@000=oo`800004Ool000000002Ool60002Ool20002Ool20002Ool2000017oo000000000goo
100017oo1@0027oo00<007ooOol01goo00@007ooOol0009oo`03001oogoo00@000eoo`04001oo`00
0004Ool40002Ool200001Goo001oogoo00000goo10003Goo00<007oo00000P0017oo100017oo1@00
0goo100047oo00<007ooOol00goo10000goo0P0000Aoo`000000009oo`800004Ool000000003Ool3
0003Ool30002Ool30002Ool40006Ool00`00Oomoo`03Ool50007Ool00`00Oomoo`1;Ool01@00Ool0
07oo00000Woo0P0000Aoo`00000000=oo`@0009oo`800005Ool007ooOol0000<Ool200000goo0000
0006Ool00`00Oomoo`03Ool40004Ool300000goo001oo`02Ool40006Ool00`00Oomoo`22Ool01000
Oomoo`000Woo00<007ooOol0100037oo0P0000=oo`0000001Woo00<007ooOol00goo100017oo0`00
00=oo`00Ool00Woo100047oo00<007ooOol0EWoo001cOol20007Ool00`00Oomoo`05Ool00`00Oomo
o`1LOol01@00Oomoogoo00009Goo00<007ooOol09Woo00<007ooOol0:goo00<007ooOol01Woo00<0
07ooOol08Goo00<007ooOol0:Goo00<007ooOol027oo00@007ooOol0009oo`03001oogoo015oo`03
001oogoo02Ioo`03001oogoo02]oo`03001oogoo03Aoo`03001oogoo00ioo`03001oogoo04aoo`05
001oogooOol0000_Ool00`00Oomoo`0MOol00`00Oomoo`22Ool01000Oomoo`000Woo00<007ooOol0
6goo00<007ooOol09goo00<007ooOol0EWoo001bOol30007Ool00`00Oomoo`05Ool00`00Oomoo`1K
Ool6000UOol00`00Oomoo`0VOol00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomoo`0QOol00`00
Oomoo`0YOol00`00Oomoo`08Ool7000COol00`00Oomoo`0VOol00`00Oomoo`0[Ool00`00Oomoo`0L
Ool00`00Oomoo`0EOol00`00Oomoo`0>Ool00`00Oomoo`1;Ool6000_Ool00`00Oomoo`0KOol30024
Ool7000MOol00`00Oomoo`0UOol3001HOol007]oo`8000Ioo`8008Moo`8002Moo`8002ioo`03001o
ogoo00Aoo`8004ioo`03001oogoo029oo`8002Moo`8002ioo`03001oogoo039oo`8000moo`03001o
ogoo081oo`8001moo`03001oogoo0:Eoo`8002Uoo`03001oogoo05Ioo`00ogooogooogooogooE7oo
003oOoooOoooOoooOomDOol00?mooomooomooomooeAoo`00ogooogooogooogooE7oo003oOoooOooo
OoooOomDOol00001\
\>"],
  ImageRangeCache->{{{0, 1103.56}, {203.563, 0}} -> {-0.135423, -0.023153, \
0.00477621, 0.00477621}, {{28.3125, 222.188}, {198.688, 4.8125}} -> \
{-491.973, -383.671, 3.76825, 4.2393}, {{241.563, 435.438}, {198.688, \
4.8125}} -> {-1296.88, -383.692, 3.77217, 4.24371}, {{454.813, 648.688}, \
{198.688, 4.8125}} -> {-2101.29, -383.692, 3.77217, 4.24371}, {{668.063, \
861.938}, {198.688, 4.8125}} -> {-2905.71, -383.692, 3.77217, 4.24371}, \
{{881.313, 1075.19}, {198.688, 4.8125}} -> {-3710.12, -383.692, 3.77217, \
4.24371}}]
}, Open  ]],

Cell["\<\
 Having used lingering episodes to highlight the animal's freedom of movement \
in the arena (reflected by connectivity and diversity) we can now return to \
progression episodes. The gradual occupancy of the arena, movement segment by \
movement segment, can be visualized with AnimSeg, a graphic function \
generating an animation of the animal's path in terms of the \"current\" \
movement segment, colored from yellow to red, on the background of the whole \
previously traced sequence in gray. The AnimSeg function can be used to \
animate any sequence of segments, be it of lingering segments or of movement \
segments, or even of larget slices of the path including several segments.\
\>", "Text",
  TextJustification->1,
  FontSize->14],

Cell["We UnLoad the ratfile and load a balb mouse file:", "Text",
  FontSize->13],

Cell[BoxData[
    \(UnLoad[ratfiles[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(Load[twofiles[\([2]\)]]\)], "Input"],

Cell["\<\
Because in mice there are, in addition to the  stops that also appear in \
rats,very short stops of extremely short durations of 0.2s and less, and \
because these stops constitute a distinct population represented by a \
distinct Gaussian,  we present in the following visualizations only stops \
whose duration is longer than 0.2s (reallingering). These longer stops also \
define longer movement segments (realmovesegments). 
\
\>", "Text",
  PageWidth->WindowWidth,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[reallingering]\)], "Input"],

Cell[BoxData[
    \(246\)], "Output"]
}, Open  ]],

Cell["\<\
Specify the segments to be animated in the command below and then, to animate \
the sequence of graphs mark the cell brackets on the right, and click Cell\
\[Rule]Animate selected graphics. To change animation parameters mark the \
bracket cells and then click Format\[Rule]Graphic Options\[Rule]Animation\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[See[AnimSeg[i, reallingering], PlotLabel \[Rule] i], {i, 236, 
        246}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(236)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
1 .977 0 r
.008 w
.07438 .55838 Mdot
.016 w
.07438 .55838 m
.07447 .55834 L
s
1 .953 0 r
.008 w
.07447 .55834 Mdot
.016 w
.07447 .55834 m
.07448 .5582 L
s
1 .93 0 r
.008 w
.07448 .5582 Mdot
.016 w
.07448 .5582 m
.07443 .55801 L
s
1 .907 0 r
.008 w
.07443 .55801 Mdot
.016 w
.07443 .55801 m
.07436 .55779 L
s
1 .884 0 r
.008 w
.07436 .55779 Mdot
.016 w
.07436 .55779 m
.07429 .55759 L
s
1 .86 0 r
.008 w
.07429 .55759 Mdot
.016 w
.07429 .55759 m
.07424 .55746 L
s
1 .837 0 r
.008 w
.07424 .55746 Mdot
.016 w
.07424 .55746 m
.07421 .55741 L
s
1 .814 0 r
.008 w
.07421 .55741 Mdot
.016 w
.07421 .55741 m
.07421 .5574 L
s
1 .791 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .767 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .744 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .721 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .698 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .674 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .651 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .628 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .605 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .581 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .558 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .535 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .512 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .488 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .465 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .442 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .419 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .395 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .372 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .349 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .326 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .302 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .279 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .256 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .233 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .209 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .5574 L
s
1 .186 0 r
.008 w
.07421 .5574 Mdot
.016 w
.07421 .5574 m
.07421 .55739 L
s
1 .163 0 r
.008 w
.07421 .55739 Mdot
.016 w
.07421 .55739 m
.07421 .55731 L
s
1 .14 0 r
.008 w
.07421 .55731 Mdot
.016 w
.07421 .55731 m
.07422 .55715 L
s
1 .116 0 r
.008 w
.07422 .55715 Mdot
.016 w
.07422 .55715 m
.07422 .55693 L
s
1 .093 0 r
.008 w
.07422 .55693 Mdot
.016 w
.07422 .55693 m
.07421 .55668 L
s
1 .07 0 r
.008 w
.07421 .55668 Mdot
.016 w
.07421 .55668 m
.07418 .55643 L
s
1 .047 0 r
.008 w
.07418 .55643 Mdot
.016 w
.07418 .55643 m
.07412 .55624 L
s
1 .023 0 r
.008 w
.07412 .55624 Mdot
.016 w
.07412 .55624 m
.07405 .5562 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo00<mkgb0O8000Wb047oo1Cg_dWoo1Cg_
2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool2O8000g`0O80mk`0?Ool4?NoCOol5?Nl9Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`9lP003O01lP3g_00moo`@mkm=oo`Dmk`Uoo`03001o
ogoo00aoo`003Goo00<007ooOol027oo17b0iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomo
o`08Ool4O83VOol5?Nl:Ool00`00Oomoo`0<Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo
00eoo`003Woo00<007ooOol0lGoo13g_2Woo00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007oo
Ool027oo13g_lWoo00<007ooOol03Goo000?Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Uoo`@mkeeoo`8mki5oo`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_
G7oo13g_T7oo00<007ooOol03Woo000?Ool00`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>
Ool0011oo`03001oogoo00Moo`Dmkeeoo`8mki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo
1Cg_kgoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03
001oogoo0>1oo`DmkaIoo`03001oogoo00moo`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol0
3goo000AOol00`00Oomoo`08Ool3?NoDOol6?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Mo
o`Dmkm=oo`DmkaEoo`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007oo
Ool047oo000BOol00`00Oomoo`07Ool3?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8m
kcMoo`03001oogoo015oo`004Woo00<007ooOol0_Goo13g_=Woo00<007ooOol04Goo000COol00`00
Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol001=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001o
ogoo019oo`004goo00<007ooOol0=Woo13g_^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4
?NnkOol00`00Oomoo`0BOol001Aoo`03001oogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`00
57oo00<007ooOol01Goo1Cg_jGoo00<007ooOol04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00
Oomoo`0COol001Eoo`03001oogoo00Aoo`@mknUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo
13g_17oo0Sg_hgoo00<007ooOol057oo000EOol00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol0
01Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]oo`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_
dgoo13g_2Woo00<007ooOol05Goo000GOol00`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0F
Ool001Moo`03001oogoo0>1oo`@mk`Uoo`03001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo
0Sg_2Goo00<007ooOol05goo000HOol00`00Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomo
o`0GOol001Uoo`03001oogoo009oo`HmkcYoo`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<0
07ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo
0cg_U7oo1Cg_2Woo00<007ooOol067oo000JOol00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomo
o`0IOol001]oo`04001oogooOol5?NoBOol5?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol5
?NoCOol2?Nl:Ool00`00Oomoo`0JOol001aoo`03001oogoo00Dmkmioo`03001oogoo01]oo`0077oo
00<007ooOol01Sg_gGoo00<007ooOol06goo000MOol00`00Oolmk`05?NoLOol00`00Oomoo`0LOol0
01eoo`03001oocg_00Dmkmaoo`03001oogoo01aoo`007Woo00<007oo?Nl013g_0goo0Sg_eWoo00<0
07ooOol07Goo000NOol00`00Oolmk`05?Nl00goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol0
01moo`03000mkcg_00@mk`03Oolmkcg_008mkl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo
00<003g_?Nl02Cg_`Goo13g_17oo1Cg_1Woo00<007ooOol07Woo000POol;?No2Ool2?Nl3Ool7?Nl5
Ool00`00Oomoo`0OOol0021oo`03000mkcg_00Tmkl=oo`Xmk`Eoo`03001oogoo01moo`008Goo00<0
03g_?Nl00cg_00=oocg_?Nl00Sg_`goo2Sg_17oo00<007ooOol087oo000ROol00`00Oomoo`03Ool3
?No4Ool:?Nl3Ool00`00Oomoo`0QOol002=oo`04001oogooOol5?No3Ool9?Nl3Ool00`00Oomoo`0R
Ool002Aoo`03001oogoo00DmklMoo`@mk`=oo`03001oogoo02=oo`0097oo00@007ooOomoo`<mklUo
o`<mk`=oo`03001oogoo02=oo`009Goo00<007ooOol027oo0Sg_`7oo1Cg_0Woo00<007ooOol097oo
000VOol00`00Oomoo`05Ool5?NnnOol4?Nl3Ool00`00Oomoo`0UOol002Ioo`03001oogoo00Eoo`Dm
kkioo`@mk`=oo`03001oogoo02Eoo`009goo00<007ooOol017oo1Cg_^goo1Sg_0goo00<007ooOol0
9Woo000XOol00`00Oomoo`03Ool5?NnkOol7?Nl00goo001oo`0XOol002Uoo`03001oogoo00Aoo`8m
k`03Oolmkgoo0;Uoo`Lmk`03001oogoo02Qoo`00:Woo00@007ooOomoo`LmkfYoo`8mkdeoo`Hmk`03
001oogoo02Uoo`00:Woo00@007ooOomoo`PmkfQoo`@mk`aoo`@mkcaoo`Hmk`03001oogoo02Uoo`00
:goo00<007ooOol023g_J7oo13g_37oo1Cg_>goo1Cg_00<007ooOol0:Woo000/Ool00`00Oolmk`07
?NmYOol2?Nl=Ool5?Nl`Ool4?Nl4Ool2?Nl5Ool00`00Oomoo`0[Ool002eoo`03001oogoo009oo`@m
kgQoo`@mkc5oo`Dmk`9oo`@mk`=oo`03001oogoo02aoo`00;Woo00@007ooOomoo`@mkjeoo`Dmk`9o
o`@mk`9oo`03001oogoo02eoo`00;Woo00<007ooOol0/Woo13g_17oo0Sg_0goo00<007ooOol0;Goo
000_Ool00`00Oomoo`28Ool2?NlZOol2?Nl7Ool00`00Oomoo`0^Ool0031oo`03001oogoo08Ioo`@m
kbIoo`Hmk`Eoo`03001oogoo02moo`00<Goo00<007ooOol01Goo13g_O7oo13g_9Goo1cg_17oo00<0
07ooOol0<7oo000bOol20005Ool5?NmlOol2?NlVOol6?Nl3Ool2000cOol003Aoo`03001oogoo009o
o`DmkgIoo`@mkb]oo`<mk`Aoo`03001oogoo03=oo`00=Goo00@007ooOomoo`@mkgMoo`DmkbYoo`<m
k`=oo`03001oogoo03Aoo`00=Goo00@007ooOomoo`@mkgMoo`Dmkc1oo`03001oogoo03Aoo`00=Woo
00<007ooOol0Ngoo1Cg_;goo00<007ooOol0=Goo000gOol00`00Oomoo`1jOol5?Nl^Ool00`00Oomo
o`0fOol003Qoo`03001oogoo07Uoo`Dmkbeoo`03001oogoo03Moo`00>Goo0P00NWoo13g_:goo0P00
>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]o
o`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001oogoo
09]oo`03001oogoo03moo`00@Goo0P002Woo0Sg_Jgoo0Sg_87oo0P00@Woo0013Ool00`00Oomoo`04
Ool6?NmYOol4?NlNOol00`00Oomoo`12Ool004Aoo`03001oogoo009oo`Lmkc5oo`8mkcIoo`@mka5o
o`8mk`Yoo`03001oogoo04=oo`00AGoo00@007ooOomoo`Hmkc5oo`@mkcIoo`8mka5oo`@mk`Qoo`03
001oogoo04Aoo`00AWoo0P000Woo1Cg_<Goo13g_BGoo13g_1Woo0P00Agoo0018Ool200000goo?Nlm
k`02?NlbOol2?Nm;Ool2?Nl5Ool20019Ool004Yoo`03000mkcg_008mkhAoo`8004]oo`00C7oo0P00
Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo00aoo`8mkeio
o`8mk`moo`03001oogoo04ioo`00D7oo0P002goo13g_=goo13g_8Goo1cg_2Goo0P00DGoo001BOol2
0009Ool4?NlgOol4?NlPOol9?Nl6Ool2001COol005Aoo`8000Qoo`8mkcQoo`@mkaUoo`<mk`9oo`/m
k`Aoo`8005Eoo`00EWoo0P00@7oo13g_67oo43g_0goo0P00Egoo001HOol3000AOol5?NlWOol4?NlH
Ool@?Nl3001IOol005]oo`<000ioo`DmkcUoo`Hmk`Aoo`hmk`8005aoo`00GWoo0P0037oo1cg_=goo
1Sg_1Goo3Cg_GWoo001POol2000:Ool8?Nl4Ool5?Nl]Ool6?Nl6Ool7?Nl00`00Oomoo`1POol0069o
o`<000Moo`Tmk`=oo`Hmk`moo`<mkaYoo`Hmk`Ioo`Dmk`8006=oo`00IGoo0`0027oo1Cg_0goo1Sg_
3Woo1Sg_6Woo13g_1goo0`00IWoo001XOol40004Ool4?Nl4Ool5?Nl8Ool3?Nl4Ool6?Nl00goo?Nlm
k`0NOol4001YOol006aoo`@000Qoo`Dmk`Mooa8mkaUoo`@006eoo`00L7oo0`001Woo13g_1goo4Sg_
5Goo1000LGoo001cOol5000<Ool:?Nl01Goo?Nlmkcg_Ool00Sg_4Woo1000MGoo001hOol70005Ool:
?Nl017oo?Nlmkcg_3Woo1`00NGoo001oOol5000:?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Qgoo10000goo0P000goo0`00RWoo0027Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol008Uoo`00R7oo00<007ooOol017oo00D007ooOomo
o`00009oo`03001oogoo08Moo`00RGoo00<007ooOol017oo00<007ooOol00`00RWoo0027Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo08Uoo`00R7oo0P0017oo0P0017oo0`00RGoo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(237)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
1 .998 0 r
.008 w
.11352 .72801 Mdot
.016 w
.11352 .72801 m
.11342 .72821 L
s
1 .996 0 r
.008 w
.11342 .72821 Mdot
.016 w
.11342 .72821 m
.11316 .72847 L
s
1 .994 0 r
.008 w
.11316 .72847 Mdot
.016 w
.11316 .72847 m
.11279 .72877 L
s
1 .992 0 r
.008 w
.11279 .72877 Mdot
.016 w
.11279 .72877 m
.11235 .72906 L
s
1 .99 0 r
.008 w
.11235 .72906 Mdot
.016 w
.11235 .72906 m
.1119 .72927 L
s
1 .988 0 r
.008 w
.1119 .72927 Mdot
.016 w
.1119 .72927 m
.11144 .72939 L
s
1 .986 0 r
.008 w
.11144 .72939 Mdot
.016 w
.11144 .72939 m
.11107 .7294 L
s
1 .984 0 r
.008 w
.11107 .7294 Mdot
.016 w
.11107 .7294 m
.11076 .72933 L
s
1 .982 0 r
.008 w
.11076 .72933 Mdot
.016 w
.11076 .72933 m
.11045 .72916 L
s
1 .98 0 r
.008 w
.11045 .72916 Mdot
.016 w
.11045 .72916 m
.11021 .72888 L
s
1 .978 0 r
.008 w
.11021 .72888 Mdot
.016 w
.11021 .72888 m
.11003 .72853 L
s
1 .976 0 r
.008 w
.11003 .72853 Mdot
.016 w
.11003 .72853 m
.10993 .72816 L
s
1 .974 0 r
.008 w
.10993 .72816 Mdot
.016 w
.10993 .72816 m
.10991 .72769 L
s
1 .972 0 r
.008 w
.10991 .72769 Mdot
.016 w
.10991 .72769 m
.10999 .72718 L
s
1 .97 0 r
.008 w
.10999 .72718 Mdot
.016 w
.10999 .72718 m
.11012 .72667 L
s
1 .968 0 r
.008 w
.11012 .72667 Mdot
.016 w
.11012 .72667 m
.1103 .72619 L
s
1 .966 0 r
.008 w
.1103 .72619 Mdot
.016 w
.1103 .72619 m
.1105 .72578 L
s
1 .964 0 r
.008 w
.1105 .72578 Mdot
.016 w
.1105 .72578 m
.11069 .72546 L
s
1 .962 0 r
.008 w
.11069 .72546 Mdot
.016 w
.11069 .72546 m
.11084 .72526 L
s
1 .96 0 r
.008 w
.11084 .72526 Mdot
.016 w
.11084 .72526 m
.11096 .72515 L
s
1 .958 0 r
.008 w
.11096 .72515 Mdot
.016 w
.11096 .72515 m
.11104 .72511 L
s
1 .956 0 r
.008 w
.11104 .72511 Mdot
.016 w
.11104 .72511 m
.11109 .72514 L
s
1 .954 0 r
.008 w
.11109 .72514 Mdot
.016 w
.11109 .72514 m
.11107 .72524 L
s
1 .952 0 r
.008 w
.11107 .72524 Mdot
.016 w
.11107 .72524 m
.11098 .72536 L
s
1 .95 0 r
.008 w
.11098 .72536 Mdot
.016 w
.11098 .72536 m
.11084 .72547 L
s
1 .948 0 r
.008 w
.11084 .72547 Mdot
.016 w
.11084 .72547 m
.11067 .72554 L
s
1 .946 0 r
.008 w
.11067 .72554 Mdot
.016 w
.11067 .72554 m
.11044 .72562 L
s
1 .944 0 r
.008 w
.11044 .72562 Mdot
.016 w
.11044 .72562 m
.11015 .72571 L
s
1 .942 0 r
.008 w
.11015 .72571 Mdot
.016 w
.11015 .72571 m
.1098 .72583 L
s
1 .94 0 r
.008 w
.1098 .72583 Mdot
.016 w
.1098 .72583 m
.10941 .72597 L
s
1 .938 0 r
.008 w
.10941 .72597 Mdot
.016 w
.10941 .72597 m
.10902 .72612 L
s
1 .936 0 r
.008 w
.10902 .72612 Mdot
.016 w
.10902 .72612 m
.10864 .72627 L
s
1 .934 0 r
.008 w
.10864 .72627 Mdot
.016 w
.10864 .72627 m
.10828 .72639 L
s
1 .932 0 r
.008 w
.10828 .72639 Mdot
.016 w
.10828 .72639 m
.10795 .72648 L
s
1 .93 0 r
.008 w
.10795 .72648 Mdot
.016 w
.10795 .72648 m
.10773 .72652 L
s
1 .928 0 r
.008 w
.10773 .72652 Mdot
.016 w
.10773 .72652 m
.10756 .72654 L
s
1 .926 0 r
.008 w
.10756 .72654 Mdot
.016 w
.10756 .72654 m
.10742 .72653 L
s
1 .924 0 r
.008 w
.10742 .72653 Mdot
.016 w
.10742 .72653 m
.10733 .72647 L
s
1 .922 0 r
.008 w
.10733 .72647 Mdot
.016 w
.10733 .72647 m
.10728 .72642 L
s
1 .92 0 r
.008 w
.10728 .72642 Mdot
.016 w
.10728 .72642 m
.10726 .72635 L
s
1 .918 0 r
.008 w
.10726 .72635 Mdot
.016 w
.10726 .72635 m
.1073 .72625 L
s
1 .915 0 r
.008 w
.1073 .72625 Mdot
.016 w
.1073 .72625 m
.10736 .72615 L
s
1 .913 0 r
.008 w
.10736 .72615 Mdot
.016 w
.10736 .72615 m
.10743 .72605 L
s
1 .911 0 r
.008 w
.10743 .72605 Mdot
.016 w
.10743 .72605 m
.10749 .72596 L
s
1 .909 0 r
.008 w
.10749 .72596 Mdot
.016 w
.10749 .72596 m
.10756 .72586 L
s
1 .907 0 r
.008 w
.10756 .72586 Mdot
.016 w
.10756 .72586 m
.10763 .72576 L
s
1 .905 0 r
.008 w
.10763 .72576 Mdot
.016 w
.10763 .72576 m
.10774 .72558 L
s
1 .903 0 r
.008 w
.10774 .72558 Mdot
.016 w
.10774 .72558 m
.10778 .72553 L
s
1 .901 0 r
.008 w
.10778 .72553 Mdot
.016 w
.10778 .72553 m
.1078 .7255 L
s
1 .899 0 r
.008 w
.1078 .7255 Mdot
.016 w
.1078 .7255 m
.10784 .7255 L
s
1 .897 0 r
.008 w
.10784 .7255 Mdot
.016 w
.10784 .7255 m
.10789 .72551 L
s
1 .895 0 r
.008 w
.10789 .72551 Mdot
.016 w
.10789 .72551 m
.10795 .72553 L
s
1 .893 0 r
.008 w
.10795 .72553 Mdot
.016 w
.10795 .72553 m
.10802 .72555 L
s
1 .891 0 r
.008 w
.10802 .72555 Mdot
.016 w
.10802 .72555 m
.10809 .72556 L
s
1 .889 0 r
.008 w
.10809 .72556 Mdot
.016 w
.10809 .72556 m
.10814 .72557 L
s
1 .887 0 r
.008 w
.10814 .72557 Mdot
.016 w
.10814 .72557 m
.10816 .72558 L
s
1 .885 0 r
.008 w
.10816 .72558 Mdot
.016 w
.10816 .72558 m
.10815 .7256 L
s
1 .883 0 r
.008 w
.10815 .7256 Mdot
.016 w
.10815 .7256 m
.10809 .7256 L
s
1 .881 0 r
.008 w
.10809 .7256 Mdot
.016 w
.10809 .7256 m
.108 .7256 L
s
1 .879 0 r
.008 w
.108 .7256 Mdot
.016 w
.108 .7256 m
.10789 .72561 L
s
1 .877 0 r
.008 w
.10789 .72561 Mdot
.016 w
.10789 .72561 m
.10781 .72562 L
s
1 .875 0 r
.008 w
.10781 .72562 Mdot
.016 w
.10781 .72562 m
.10777 .72565 L
s
1 .873 0 r
.008 w
.10777 .72565 Mdot
.016 w
.10777 .72565 m
.10779 .72568 L
s
1 .871 0 r
.008 w
.10779 .72568 Mdot
.016 w
.10779 .72568 m
.10784 .72571 L
s
1 .869 0 r
.008 w
.10784 .72571 Mdot
.016 w
.10784 .72571 m
.10795 .72574 L
s
1 .867 0 r
.008 w
.10795 .72574 Mdot
.016 w
.10795 .72574 m
.10812 .72576 L
s
1 .865 0 r
.008 w
.10812 .72576 Mdot
.016 w
.10812 .72576 m
.10835 .72577 L
s
1 .863 0 r
.008 w
.10835 .72577 Mdot
.016 w
.10835 .72577 m
.10863 .72578 L
s
1 .861 0 r
.008 w
.10863 .72578 Mdot
.016 w
.10863 .72578 m
.10894 .72576 L
s
1 .859 0 r
.008 w
.10894 .72576 Mdot
.016 w
.10894 .72576 m
.10927 .72574 L
s
1 .857 0 r
.008 w
.10927 .72574 Mdot
.016 w
.10927 .72574 m
.10959 .72571 L
s
1 .855 0 r
.008 w
.10959 .72571 Mdot
.016 w
.10959 .72571 m
.1099 .72569 L
s
1 .853 0 r
.008 w
.1099 .72569 Mdot
.016 w
.1099 .72569 m
.11018 .72567 L
s
1 .851 0 r
.008 w
.11018 .72567 Mdot
.016 w
.11018 .72567 m
.11043 .72565 L
s
1 .849 0 r
.008 w
.11043 .72565 Mdot
.016 w
.11043 .72565 m
.11063 .72562 L
s
1 .847 0 r
.008 w
.11063 .72562 Mdot
.016 w
.11063 .72562 m
.11077 .72558 L
s
1 .845 0 r
.008 w
.11077 .72558 Mdot
.016 w
.11077 .72558 m
.11088 .72553 L
s
1 .843 0 r
.008 w
.11088 .72553 Mdot
.016 w
.11088 .72553 m
.11094 .72549 L
s
1 .841 0 r
.008 w
.11094 .72549 Mdot
.016 w
.11094 .72549 m
.11096 .72545 L
s
1 .839 0 r
.008 w
.11096 .72545 Mdot
.016 w
.11096 .72545 m
.11095 .72542 L
s
1 .837 0 r
.008 w
.11095 .72542 Mdot
.016 w
.11095 .72542 m
.11091 .72541 L
s
1 .835 0 r
.008 w
.11091 .72541 Mdot
.016 w
.11091 .72541 m
.11087 .7254 L
s
1 .833 0 r
.008 w
.11087 .7254 Mdot
.016 w
.11087 .7254 m
.11083 .72541 L
s
1 .831 0 r
.008 w
.11083 .72541 Mdot
.016 w
.11083 .72541 m
.11082 .72543 L
s
1 .829 0 r
.008 w
.11082 .72543 Mdot
.016 w
.11082 .72543 m
.11081 .72544 L
s
1 .827 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .825 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .823 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .821 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .819 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .817 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .815 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .813 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .811 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .809 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .807 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .805 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .803 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .801 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .799 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .797 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .795 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .793 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .791 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .789 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .787 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .785 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .783 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .781 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .779 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11083 .72544 L
s
1 .777 0 r
.008 w
.11083 .72544 Mdot
.016 w
.11083 .72544 m
.11086 .72544 L
s
1 .775 0 r
.008 w
.11086 .72544 Mdot
.016 w
.11086 .72544 m
.1109 .72544 L
s
1 .773 0 r
.008 w
.1109 .72544 Mdot
.016 w
.1109 .72544 m
.11094 .72544 L
s
1 .771 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11096 .72544 L
s
1 .769 0 r
.008 w
.11096 .72544 Mdot
.016 w
.11096 .72544 m
.11094 .72544 L
s
1 .767 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11088 .72544 L
s
1 .765 0 r
.008 w
.11088 .72544 Mdot
.016 w
.11088 .72544 m
.11078 .72544 L
s
1 .763 0 r
.008 w
.11078 .72544 Mdot
.016 w
.11078 .72544 m
.11062 .72545 L
s
1 .761 0 r
.008 w
.11062 .72545 Mdot
.016 w
.11062 .72545 m
.1104 .72546 L
s
1 .759 0 r
.008 w
.1104 .72546 Mdot
.016 w
.1104 .72546 m
.11013 .72547 L
s
1 .757 0 r
.008 w
.11013 .72547 Mdot
.016 w
.11013 .72547 m
.10983 .72548 L
s
1 .755 0 r
.008 w
.10983 .72548 Mdot
.016 w
.10983 .72548 m
.10951 .7255 L
s
1 .753 0 r
.008 w
.10951 .7255 Mdot
.016 w
.10951 .7255 m
.10923 .72551 L
s
1 .751 0 r
.008 w
.10923 .72551 Mdot
.016 w
.10923 .72551 m
.10898 .72552 L
s
1 .748 0 r
.008 w
.10898 .72552 Mdot
.016 w
.10898 .72552 m
.10877 .72553 L
s
1 .746 0 r
.008 w
.10877 .72553 Mdot
.016 w
.10877 .72553 m
.10862 .72553 L
s
1 .744 0 r
.008 w
.10862 .72553 Mdot
.016 w
.10862 .72553 m
.10856 .72554 L
s
1 .742 0 r
.008 w
.10856 .72554 Mdot
.016 w
.10856 .72554 m
.10859 .72553 L
s
1 .74 0 r
.008 w
.10859 .72553 Mdot
.016 w
.10859 .72553 m
.10871 .72553 L
s
1 .738 0 r
.008 w
.10871 .72553 Mdot
.016 w
.10871 .72553 m
.1089 .72552 L
s
1 .736 0 r
.008 w
.1089 .72552 Mdot
.016 w
.1089 .72552 m
.10915 .72551 L
s
1 .734 0 r
.008 w
.10915 .72551 Mdot
.016 w
.10915 .72551 m
.10944 .7255 L
s
1 .732 0 r
.008 w
.10944 .7255 Mdot
.016 w
.10944 .7255 m
.10975 .72549 L
s
1 .73 0 r
.008 w
.10975 .72549 Mdot
.016 w
.10975 .72549 m
.11006 .72547 L
s
1 .728 0 r
.008 w
.11006 .72547 Mdot
.016 w
.11006 .72547 m
.11034 .72546 L
s
1 .726 0 r
.008 w
.11034 .72546 Mdot
.016 w
.11034 .72546 m
.11057 .72545 L
s
1 .724 0 r
.008 w
.11057 .72545 Mdot
.016 w
.11057 .72545 m
.11075 .72545 L
s
1 .722 0 r
.008 w
.11075 .72545 Mdot
.016 w
.11075 .72545 m
.11087 .72544 L
s
1 .72 0 r
.008 w
.11087 .72544 Mdot
.016 w
.11087 .72544 m
.11094 .72544 L
s
1 .718 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11096 .72544 L
s
1 .716 0 r
.008 w
.11096 .72544 Mdot
.016 w
.11096 .72544 m
.11095 .72544 L
s
1 .714 0 r
.008 w
.11095 .72544 Mdot
.016 w
.11095 .72544 m
.11091 .72544 L
s
1 .712 0 r
.008 w
.11091 .72544 Mdot
.016 w
.11091 .72544 m
.11087 .72544 L
s
1 .71 0 r
.008 w
.11087 .72544 Mdot
.016 w
.11087 .72544 m
.11083 .72544 L
s
1 .708 0 r
.008 w
.11083 .72544 Mdot
.016 w
.11083 .72544 m
.11082 .72544 L
s
1 .706 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72544 L
s
1 .704 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .702 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .7 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .698 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .696 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .694 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .692 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .69 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .688 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .686 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .684 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .682 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .68 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .678 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .676 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .674 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .672 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .67 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .668 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .666 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11083 .72544 L
s
1 .664 0 r
.008 w
.11083 .72544 Mdot
.016 w
.11083 .72544 m
.11086 .72544 L
s
1 .662 0 r
.008 w
.11086 .72544 Mdot
.016 w
.11086 .72544 m
.1109 .72544 L
s
1 .66 0 r
.008 w
.1109 .72544 Mdot
.016 w
.1109 .72544 m
.11094 .72544 L
s
1 .658 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11096 .72544 L
s
1 .656 0 r
.008 w
.11096 .72544 Mdot
.016 w
.11096 .72544 m
.11094 .72544 L
s
1 .654 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11088 .72544 L
s
1 .652 0 r
.008 w
.11088 .72544 Mdot
.016 w
.11088 .72544 m
.11074 .72545 L
s
1 .65 0 r
.008 w
.11074 .72545 Mdot
.016 w
.11074 .72545 m
.11055 .72545 L
s
1 .648 0 r
.008 w
.11055 .72545 Mdot
.016 w
.11055 .72545 m
.11031 .72546 L
s
1 .646 0 r
.008 w
.11031 .72546 Mdot
.016 w
.11031 .72546 m
.11005 .72547 L
s
1 .644 0 r
.008 w
.11005 .72547 Mdot
.016 w
.11005 .72547 m
.10982 .72548 L
s
1 .642 0 r
.008 w
.10982 .72548 Mdot
.016 w
.10982 .72548 m
.10961 .72549 L
s
1 .64 0 r
.008 w
.10961 .72549 Mdot
.016 w
.10961 .72549 m
.10946 .7255 L
s
1 .638 0 r
.008 w
.10946 .7255 Mdot
.016 w
.10946 .7255 m
.10935 .72551 L
s
1 .636 0 r
.008 w
.10935 .72551 Mdot
.016 w
.10935 .72551 m
.10929 .72551 L
s
1 .634 0 r
.008 w
.10929 .72551 Mdot
.016 w
.10929 .72551 m
.10928 .72551 L
s
1 .632 0 r
.008 w
.10928 .72551 Mdot
.016 w
.10928 .72551 m
.10932 .72551 L
s
1 .63 0 r
.008 w
.10932 .72551 Mdot
.016 w
.10932 .72551 m
.10941 .7255 L
s
1 .628 0 r
.008 w
.10941 .7255 Mdot
.016 w
.10941 .7255 m
.10955 .7255 L
s
1 .626 0 r
.008 w
.10955 .7255 Mdot
.016 w
.10955 .7255 m
.10975 .72549 L
s
1 .624 0 r
.008 w
.10975 .72549 Mdot
.016 w
.10975 .72549 m
.10998 .72548 L
s
1 .622 0 r
.008 w
.10998 .72548 Mdot
.016 w
.10998 .72548 m
.11024 .72547 L
s
1 .62 0 r
.008 w
.11024 .72547 Mdot
.016 w
.11024 .72547 m
.11049 .72546 L
s
1 .618 0 r
.008 w
.11049 .72546 Mdot
.016 w
.11049 .72546 m
.11071 .72545 L
s
1 .616 0 r
.008 w
.11071 .72545 Mdot
.016 w
.11071 .72545 m
.11086 .72544 L
s
1 .614 0 r
.008 w
.11086 .72544 Mdot
.016 w
.11086 .72544 m
.11094 .72544 L
s
1 .612 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11096 .72544 L
s
1 .61 0 r
.008 w
.11096 .72544 Mdot
.016 w
.11096 .72544 m
.11094 .72544 L
s
1 .608 0 r
.008 w
.11094 .72544 Mdot
.016 w
.11094 .72544 m
.11091 .72544 L
s
1 .606 0 r
.008 w
.11091 .72544 Mdot
.016 w
.11091 .72544 m
.11086 .72544 L
s
1 .604 0 r
.008 w
.11086 .72544 Mdot
.016 w
.11086 .72544 m
.11083 .72544 L
s
1 .602 0 r
.008 w
.11083 .72544 Mdot
.016 w
.11083 .72544 m
.11082 .72544 L
s
1 .6 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72544 L
s
1 .598 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .596 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .594 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .592 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .59 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .588 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .586 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .584 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .581 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .579 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .577 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .575 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .573 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .571 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .569 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .567 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .565 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .563 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .561 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .559 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .557 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .555 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .553 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .551 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .549 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .547 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .545 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .543 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .541 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .539 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .537 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .535 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .533 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .531 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .529 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .527 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .525 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .523 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .521 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .519 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .517 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .515 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .513 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .511 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .509 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .507 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .505 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .503 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .501 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .499 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .497 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .495 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .493 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .491 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .489 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .487 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .485 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .483 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .481 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .479 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .477 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .475 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .473 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .471 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .469 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .467 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .465 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .463 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .461 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .459 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .457 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .455 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .453 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .451 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .449 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .447 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .445 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .443 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .441 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .439 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .437 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .435 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .433 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11082 .72544 L
s
1 .431 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .429 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .427 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .425 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .423 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72544 L
s
1 .421 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.1108 .72544 L
s
1 .419 0 r
.008 w
.1108 .72544 Mdot
.016 w
.1108 .72544 m
.11079 .72544 L
s
1 .416 0 r
.008 w
.11079 .72544 Mdot
.016 w
.11079 .72544 m
.11078 .72544 L
s
1 .414 0 r
.008 w
.11078 .72544 Mdot
.016 w
.11078 .72544 m
.11077 .72544 L
s
1 .412 0 r
.008 w
.11077 .72544 Mdot
.016 w
.11077 .72544 m
.11076 .72544 L
s
1 .41 0 r
.008 w
.11076 .72544 Mdot
.016 w
.11076 .72544 m
.11076 .72544 L
s
1 .408 0 r
.008 w
.11076 .72544 Mdot
.016 w
.11076 .72544 m
.11075 .72544 L
s
1 .406 0 r
.008 w
.11075 .72544 Mdot
.016 w
.11075 .72544 m
.11075 .72544 L
s
1 .404 0 r
.008 w
.11075 .72544 Mdot
.016 w
.11075 .72544 m
.11075 .72544 L
s
1 .402 0 r
.008 w
.11075 .72544 Mdot
.016 w
.11075 .72544 m
.11075 .72544 L
s
1 .4 0 r
.008 w
.11075 .72544 Mdot
.016 w
.11075 .72544 m
.11076 .72544 L
s
1 .398 0 r
.008 w
.11076 .72544 Mdot
.016 w
.11076 .72544 m
.11076 .72544 L
s
1 .396 0 r
.008 w
.11076 .72544 Mdot
.016 w
.11076 .72544 m
.11077 .72544 L
s
1 .394 0 r
.008 w
.11077 .72544 Mdot
.016 w
.11077 .72544 m
.11079 .72544 L
s
1 .392 0 r
.008 w
.11079 .72544 Mdot
.016 w
.11079 .72544 m
.1108 .72544 L
s
1 .39 0 r
.008 w
.1108 .72544 Mdot
.016 w
.1108 .72544 m
.11081 .72544 L
s
1 .388 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11082 .72544 L
s
1 .386 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .384 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .382 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .38 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .378 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72544 L
s
1 .376 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .374 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .372 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .37 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .368 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .366 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .364 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .362 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .36 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .358 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .356 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .354 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .352 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .35 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .348 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .346 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .344 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .342 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .34 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .338 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .336 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .334 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .332 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .33 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .328 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .326 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .324 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .322 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .32 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .318 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .316 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .314 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .312 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .31 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .308 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .306 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .304 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .302 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .3 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .298 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .296 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .294 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .292 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .29 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .288 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .286 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .284 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .282 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .28 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .278 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .276 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .274 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .272 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .27 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .268 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .266 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .264 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11082 .72543 L
s
1 .262 0 r
.008 w
.11082 .72543 Mdot
.016 w
.11082 .72543 m
.11082 .72542 L
s
1 .26 0 r
.008 w
.11082 .72542 Mdot
.016 w
.11082 .72542 m
.11083 .72542 L
s
1 .258 0 r
.008 w
.11083 .72542 Mdot
.016 w
.11083 .72542 m
.11083 .72542 L
s
1 .256 0 r
.008 w
.11083 .72542 Mdot
.016 w
.11083 .72542 m
.11082 .72544 L
s
1 .254 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72546 L
s
1 .252 0 r
.008 w
.11081 .72546 Mdot
.016 w
.11081 .72546 m
.1108 .72549 L
s
1 .249 0 r
.008 w
.1108 .72549 Mdot
.016 w
.1108 .72549 m
.11078 .72551 L
s
1 .247 0 r
.008 w
.11078 .72551 Mdot
.016 w
.11078 .72551 m
.11076 .72554 L
s
1 .245 0 r
.008 w
.11076 .72554 Mdot
.016 w
.11076 .72554 m
.11074 .72556 L
s
1 .243 0 r
.008 w
.11074 .72556 Mdot
.016 w
.11074 .72556 m
.11073 .72557 L
s
1 .241 0 r
.008 w
.11073 .72557 Mdot
.016 w
.11073 .72557 m
.11072 .72558 L
s
1 .239 0 r
.008 w
.11072 .72558 Mdot
.016 w
.11072 .72558 m
.11071 .72558 L
s
1 .237 0 r
.008 w
.11071 .72558 Mdot
.016 w
.11071 .72558 m
.11071 .72558 L
s
1 .235 0 r
.008 w
.11071 .72558 Mdot
.016 w
.11071 .72558 m
.11071 .72558 L
s
1 .233 0 r
.008 w
.11071 .72558 Mdot
.016 w
.11071 .72558 m
.11071 .72558 L
s
1 .231 0 r
.008 w
.11071 .72558 Mdot
.016 w
.11071 .72558 m
.11071 .72557 L
s
1 .229 0 r
.008 w
.11071 .72557 Mdot
.016 w
.11071 .72557 m
.11072 .72555 L
s
1 .227 0 r
.008 w
.11072 .72555 Mdot
.016 w
.11072 .72555 m
.11074 .72553 L
s
1 .225 0 r
.008 w
.11074 .72553 Mdot
.016 w
.11074 .72553 m
.11075 .7255 L
s
1 .223 0 r
.008 w
.11075 .7255 Mdot
.016 w
.11075 .7255 m
.11077 .72547 L
s
1 .221 0 r
.008 w
.11077 .72547 Mdot
.016 w
.11077 .72547 m
.11079 .72545 L
s
1 .219 0 r
.008 w
.11079 .72545 Mdot
.016 w
.11079 .72545 m
.11081 .72543 L
s
1 .217 0 r
.008 w
.11081 .72543 Mdot
.016 w
.11081 .72543 m
.11082 .72542 L
s
1 .215 0 r
.008 w
.11082 .72542 Mdot
.016 w
.11082 .72542 m
.11083 .72542 L
s
1 .213 0 r
.008 w
.11083 .72542 Mdot
.016 w
.11083 .72542 m
.11083 .72543 L
s
1 .211 0 r
.008 w
.11083 .72543 Mdot
.016 w
.11083 .72543 m
.11082 .72544 L
s
1 .209 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11082 .72544 L
s
1 .207 0 r
.008 w
.11082 .72544 Mdot
.016 w
.11082 .72544 m
.11081 .72544 L
s
1 .205 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .203 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .201 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .199 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .197 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .195 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .193 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .191 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .189 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .187 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .185 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .183 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .181 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .179 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .177 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .175 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .173 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .171 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72544 L
s
1 .169 0 r
.008 w
.11081 .72544 Mdot
.016 w
.11081 .72544 m
.11081 .72543 L
s
1 .167 0 r
.008 w
.11081 .72543 Mdot
.016 w
.11081 .72543 m
.11081 .7254 L
s
1 .165 0 r
.008 w
.11081 .7254 Mdot
.016 w
.11081 .7254 m
.11082 .72536 L
s
1 .163 0 r
.008 w
.11082 .72536 Mdot
.016 w
.11082 .72536 m
.11082 .72534 L
s
1 .161 0 r
.008 w
.11082 .72534 Mdot
.016 w
.11082 .72534 m
.11082 .72533 L
s
1 .159 0 r
.008 w
.11082 .72533 Mdot
.016 w
.11082 .72533 m
.11082 .72534 L
s
1 .157 0 r
.008 w
.11082 .72534 Mdot
.016 w
.11082 .72534 m
.11081 .72539 L
s
1 .155 0 r
.008 w
.11081 .72539 Mdot
.016 w
.11081 .72539 m
.11081 .72549 L
s
1 .153 0 r
.008 w
.11081 .72549 Mdot
.016 w
.11081 .72549 m
.1108 .72565 L
s
1 .151 0 r
.008 w
.1108 .72565 Mdot
.016 w
.1108 .72565 m
.11079 .72585 L
s
1 .149 0 r
.008 w
.11079 .72585 Mdot
.016 w
.11079 .72585 m
.11079 .72607 L
s
1 .147 0 r
.008 w
.11079 .72607 Mdot
.016 w
.11079 .72607 m
.11078 .72628 L
s
1 .145 0 r
.008 w
.11078 .72628 Mdot
.016 w
.11078 .72628 m
.11077 .72646 L
s
1 .143 0 r
.008 w
.11077 .72646 Mdot
.016 w
.11077 .72646 m
.11076 .72663 L
s
1 .141 0 r
.008 w
.11076 .72663 Mdot
.016 w
.11076 .72663 m
.11075 .72671 L
s
1 .139 0 r
.008 w
.11075 .72671 Mdot
.016 w
.11075 .72671 m
.11071 .72672 L
s
1 .137 0 r
.008 w
.11071 .72672 Mdot
.016 w
.11071 .72672 m
.11067 .72671 L
s
1 .135 0 r
.008 w
.11067 .72671 Mdot
.016 w
.11067 .72671 m
.11064 .72666 L
s
1 .133 0 r
.008 w
.11064 .72666 Mdot
.016 w
.11064 .72666 m
.11062 .72659 L
s
1 .131 0 r
.008 w
.11062 .72659 Mdot
.016 w
.11062 .72659 m
.11064 .72652 L
s
1 .129 0 r
.008 w
.11064 .72652 Mdot
.016 w
.11064 .72652 m
.1107 .72635 L
s
1 .127 0 r
.008 w
.1107 .72635 Mdot
.016 w
.1107 .72635 m
.11081 .72615 L
s
1 .125 0 r
.008 w
.11081 .72615 Mdot
.016 w
.11081 .72615 m
.11097 .72595 L
s
1 .123 0 r
.008 w
.11097 .72595 Mdot
.016 w
.11097 .72595 m
.11117 .72577 L
s
1 .121 0 r
.008 w
.11117 .72577 Mdot
.016 w
.11117 .72577 m
.11141 .72562 L
s
1 .119 0 r
.008 w
.11141 .72562 Mdot
.016 w
.11141 .72562 m
.11167 .72551 L
s
1 .117 0 r
.008 w
.11167 .72551 Mdot
.016 w
.11167 .72551 m
.11194 .72547 L
s
1 .115 0 r
.008 w
.11194 .72547 Mdot
.016 w
.11194 .72547 m
.11221 .72546 L
s
1 .113 0 r
.008 w
.11221 .72546 Mdot
.016 w
.11221 .72546 m
.11247 .72548 L
s
1 .111 0 r
.008 w
.11247 .72548 Mdot
.016 w
.11247 .72548 m
.11273 .7255 L
s
1 .109 0 r
.008 w
.11273 .7255 Mdot
.016 w
.11273 .7255 m
.11297 .72553 L
s
1 .107 0 r
.008 w
.11297 .72553 Mdot
.016 w
.11297 .72553 m
.11318 .72558 L
s
1 .105 0 r
.008 w
.11318 .72558 Mdot
.016 w
.11318 .72558 m
.11335 .72557 L
s
1 .103 0 r
.008 w
.11335 .72557 Mdot
.016 w
.11335 .72557 m
.11347 .72555 L
s
1 .101 0 r
.008 w
.11347 .72555 Mdot
.016 w
.11347 .72555 m
.11354 .72551 L
s
1 .099 0 r
.008 w
.11354 .72551 Mdot
.016 w
.11354 .72551 m
.11356 .72547 L
s
1 .097 0 r
.008 w
.11356 .72547 Mdot
.016 w
.11356 .72547 m
.11355 .72543 L
s
1 .095 0 r
.008 w
.11355 .72543 Mdot
.016 w
.11355 .72543 m
.11351 .72538 L
s
1 .093 0 r
.008 w
.11351 .72538 Mdot
.016 w
.11351 .72538 m
.11347 .72534 L
s
1 .091 0 r
.008 w
.11347 .72534 Mdot
.016 w
.11347 .72534 m
.11344 .72531 L
s
1 .089 0 r
.008 w
.11344 .72531 Mdot
.016 w
.11344 .72531 m
.11342 .7253 L
s
1 .087 0 r
.008 w
.11342 .7253 Mdot
.016 w
.11342 .7253 m
.11342 .7253 L
s
1 .085 0 r
.008 w
.11342 .7253 Mdot
.016 w
.11342 .7253 m
.11342 .72531 L
s
1 .082 0 r
.008 w
.11342 .72531 Mdot
.016 w
.11342 .72531 m
.11342 .72532 L
s
1 .08 0 r
.008 w
.11342 .72532 Mdot
.016 w
.11342 .72532 m
.11342 .72533 L
s
1 .078 0 r
.008 w
.11342 .72533 Mdot
.016 w
.11342 .72533 m
.11342 .72534 L
s
1 .076 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .074 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .072 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .07 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .068 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .066 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72534 L
s
1 .064 0 r
.008 w
.11342 .72534 Mdot
.016 w
.11342 .72534 m
.11342 .72533 L
s
1 .062 0 r
.008 w
.11342 .72533 Mdot
.016 w
.11342 .72533 m
.11343 .72533 L
s
1 .06 0 r
.008 w
.11343 .72533 Mdot
.016 w
.11343 .72533 m
.11347 .72533 L
s
1 .058 0 r
.008 w
.11347 .72533 Mdot
.016 w
.11347 .72533 m
.11355 .72533 L
s
1 .056 0 r
.008 w
.11355 .72533 Mdot
.016 w
.11355 .72533 m
.11363 .72532 L
s
1 .054 0 r
.008 w
.11363 .72532 Mdot
.016 w
.11363 .72532 m
.11366 .72532 L
s
1 .052 0 r
.008 w
.11366 .72532 Mdot
.016 w
.11366 .72532 m
.11363 .72532 L
s
1 .05 0 r
.008 w
.11363 .72532 Mdot
.016 w
.11363 .72532 m
.11353 .72533 L
s
1 .048 0 r
.008 w
.11353 .72533 Mdot
.016 w
.11353 .72533 m
.11334 .72534 L
s
1 .046 0 r
.008 w
.11334 .72534 Mdot
.016 w
.11334 .72534 m
.11304 .72536 L
s
1 .044 0 r
.008 w
.11304 .72536 Mdot
.016 w
.11304 .72536 m
.11263 .72537 L
s
1 .042 0 r
.008 w
.11263 .72537 Mdot
.016 w
.11263 .72537 m
.11213 .72539 L
s
1 .04 0 r
.008 w
.11213 .72539 Mdot
.016 w
.11213 .72539 m
.1116 .72542 L
s
1 .038 0 r
.008 w
.1116 .72542 Mdot
.016 w
.1116 .72542 m
.11106 .72544 L
s
1 .036 0 r
.008 w
.11106 .72544 Mdot
.016 w
.11106 .72544 m
.11052 .72546 L
s
1 .034 0 r
.008 w
.11052 .72546 Mdot
.016 w
.11052 .72546 m
.11006 .72549 L
s
1 .032 0 r
.008 w
.11006 .72549 Mdot
.016 w
.11006 .72549 m
.10954 .72551 L
s
1 .03 0 r
.008 w
.10954 .72551 Mdot
.016 w
.10954 .72551 m
.10902 .72553 L
s
1 .028 0 r
.008 w
.10902 .72553 Mdot
.016 w
.10902 .72553 m
.10856 .72554 L
s
1 .026 0 r
.008 w
.10856 .72554 Mdot
.016 w
.10856 .72554 m
.10821 .72556 L
s
1 .024 0 r
.008 w
.10821 .72556 Mdot
.016 w
.10821 .72556 m
.10798 .72556 L
s
1 .022 0 r
.008 w
.10798 .72556 Mdot
.016 w
.10798 .72556 m
.10786 .72557 L
s
1 .02 0 r
.008 w
.10786 .72557 Mdot
.016 w
.10786 .72557 m
.10783 .72557 L
s
1 .018 0 r
.008 w
.10783 .72557 Mdot
.016 w
.10783 .72557 m
.10785 .72556 L
s
1 .016 0 r
.008 w
.10785 .72556 Mdot
.016 w
.10785 .72556 m
.10795 .72554 L
s
1 .014 0 r
.008 w
.10795 .72554 Mdot
.016 w
.10795 .72554 m
.10807 .72551 L
s
1 .012 0 r
.008 w
.10807 .72551 Mdot
.016 w
.10807 .72551 m
.10818 .72546 L
s
1 .01 0 r
.008 w
.10818 .72546 Mdot
.016 w
.10818 .72546 m
.10827 .72541 L
s
1 .008 0 r
.008 w
.10827 .72541 Mdot
.016 w
.10827 .72541 m
.10833 .72537 L
s
1 .006 0 r
.008 w
.10833 .72537 Mdot
.016 w
.10833 .72537 m
.10836 .72533 L
s
1 .004 0 r
.008 w
.10836 .72533 Mdot
.016 w
.10836 .72533 m
.10833 .72532 L
s
1 .002 0 r
.008 w
.10833 .72532 Mdot
.016 w
.10833 .72532 m
.10824 .72536 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol4?Nl2O0000g`POomoo`3?Ool2?Nl:Ool00`00
Oomoo`0JOol001aoo`03001oogoo008mk`El0003O21oogoo0=Uoo`03001oogoo01]oo`0077oo00<0
07ooOol00Sg_1G`000=l87ooOol0fGoo00<007ooOol06goo000MOol01000Oolmkcg_1G`000=l87oo
Ool0f7oo00<007ooOol077oo000MOol01000Oolmkcg_1G`000=l87ooOol0f7oo00<007ooOol077oo
000NOol01000Oolmkcg_1GoP00=oocg_?Nl0eWoo00<007ooOol07Goo000NOol00`00Oolmk`05?Nl0
0goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol001moo`03000mkcg_00@mk`03Oolmkcg_008m
kl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo00<003g_?Nl02Cg_`Goo13g_17oo1Cg_1Woo
00<007ooOol07Woo000POol;?No2Ool2?Nl3Ool7?Nl5Ool00`00Oomoo`0OOol0021oo`03000mkcg_
00Tmkl=oo`Xmk`Eoo`03001oogoo01moo`008Goo00<003g_?Nl00cg_00=oocg_?Nl00Sg_`goo2Sg_
17oo00<007ooOol087oo000ROol00`00Oomoo`03Ool3?No4Ool:?Nl3Ool00`00Oomoo`0QOol002=o
o`04001oogooOol5?No3Ool9?Nl3Ool00`00Oomoo`0ROol002Aoo`03001oogoo00DmklMoo`@mk`=o
o`03001oogoo02=oo`0097oo00@007ooOomoo`<mklUoo`<mk`=oo`03001oogoo02=oo`009Goo00<0
07ooOol027oo0Sg_`7oo1Cg_0Woo00<007ooOol097oo000VOol00`00Oomoo`05Ool5?NnnOol4?Nl3
Ool00`00Oomoo`0UOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001oogoo02Eoo`009goo
00<007ooOol017oo1Cg_^goo1Sg_0goo00<007ooOol09Woo000XOol00`00Oomoo`03Ool5?NnkOol7
?Nl00goo001oo`0XOol002Uoo`03001oogoo00Aoo`8mk`03Oolmkgoo0;Uoo`Lmk`03001oogoo02Qo
o`00:Woo00@007ooOomoo`LmkfYoo`8mkdeoo`Hmk`03001oogoo02Uoo`00:Woo00@007ooOomoo`Pm
kfQoo`@mk`aoo`@mkcaoo`Hmk`03001oogoo02Uoo`00:goo00<007ooOol023g_J7oo13g_37oo1Cg_
>goo1Cg_00<007ooOol0:Woo000/Ool00`00Oolmk`07?NmYOol2?Nl=Ool5?Nl`Ool4?Nl4Ool2?Nl5
Ool00`00Oomoo`0[Ool002eoo`03001oogoo009oo`@mkgQoo`@mkc5oo`Dmk`9oo`@mk`=oo`03001o
ogoo02aoo`00;Woo00@007ooOomoo`@mkjeoo`Dmk`9oo`@mk`9oo`03001oogoo02eoo`00;Woo00<0
07ooOol0/Woo13g_17oo0Sg_0goo00<007ooOol0;Goo000_Ool00`00Oomoo`28Ool2?NlZOol2?Nl7
Ool00`00Oomoo`0^Ool0031oo`03001oogoo08Ioo`@mkbIoo`Hmk`Eoo`03001oogoo02moo`00<Goo
00<007ooOol01Goo13g_O7oo13g_9Goo1cg_17oo00<007ooOol0<7oo000bOol20005Ool5?NmlOol2
?NlVOol6?Nl3Ool2000cOol003Aoo`03001oogoo009oo`DmkgIoo`@mkb]oo`<mk`Aoo`03001oogoo
03=oo`00=Goo00@007ooOomoo`@mkgMoo`DmkbYoo`<mk`=oo`03001oogoo03Aoo`00=Goo00@007oo
Oomoo`@mkgMoo`Dmkc1oo`03001oogoo03Aoo`00=Woo00<007ooOol0Ngoo1Cg_;goo00<007ooOol0
=Goo000gOol00`00Oomoo`1jOol5?Nl^Ool00`00Oomoo`0fOol003Qoo`03001oogoo07Uoo`Dmkbeo
o`03001oogoo03Moo`00>Goo0P00NWoo13g_:goo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomo
o`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0
?7oo000nOol2002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P002Woo
0Sg_Jgoo0Sg_87oo0P00@Woo0013Ool00`00Oomoo`04Ool6?NmYOol4?NlNOol00`00Oomoo`12Ool0
04Aoo`03001oogoo009oo`Lmkc5oo`8mkcIoo`@mka5oo`8mk`Yoo`03001oogoo04=oo`00AGoo00@0
07ooOomoo`Hmkc5oo`@mkcIoo`8mka5oo`@mk`Qoo`03001oogoo04Aoo`00AWoo0P000Woo1Cg_<Goo
13g_BGoo13g_1Woo0P00Agoo0018Ool200000goo?Nlmk`02?NlbOol2?Nm;Ool2?Nl5Ool20019Ool0
04Yoo`03000mkcg_008mkhAoo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol0
0`00Oomoo`1=Ool004moo`03001oogoo00aoo`8mkeioo`8mk`moo`03001oogoo04ioo`00D7oo0P00
2goo13g_=goo13g_8Goo1cg_2Goo0P00DGoo001BOol20009Ool4?NlgOol4?NlPOol9?Nl6Ool2001C
Ool005Aoo`8000Qoo`8mkcQoo`@mkaUoo`<mk`9oo`/mk`Aoo`8005Eoo`00EWoo0P00@7oo13g_67oo
43g_0goo0P00Egoo001HOol3000AOol5?NlWOol4?NlHOol@?Nl3001IOol005]oo`<000ioo`DmkcUo
o`Hmk`Aoo`hmk`8005aoo`00GWoo0P0037oo1cg_=goo1Sg_1Goo3Cg_GWoo001POol2000:Ool8?Nl4
Ool5?Nl]Ool6?Nl6Ool7?Nl00`00Oomoo`1POol0069oo`<000Moo`Tmk`=oo`Hmk`moo`<mkaYoo`Hm
k`Ioo`Dmk`8006=oo`00IGoo0`0027oo1Cg_0goo1Sg_3Woo1Sg_6Woo13g_1goo0`00IWoo001XOol4
0004Ool4?Nl4Ool5?Nl8Ool3?Nl4Ool6?Nl00goo?Nlmk`0NOol4001YOol006aoo`@000Qoo`Dmk`Mo
oa8mkaUoo`@006eoo`00L7oo0`001Woo13g_1goo4Sg_5Goo1000LGoo001cOol5000<Ool:?Nl01Goo
?Nlmkcg_Ool00Sg_4Woo1000MGoo001hOol70005Ool:?Nl017oo?Nlmkcg_3Woo1`00NGoo001oOol5
000:?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00Qgoo10000goo0P001Goo00<007ooOol0R7oo0027Ool00`00Oomoo`03Ool01000Oomoo`0017oo
00<007ooOol0R7oo0028Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`28Ool008Uoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo08Moo`00Qgoo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`00RGoo0028Ool20004Ool20003Ool40029Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(238)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
1 .982 0 r
.008 w
.1036 .73252 Mdot
.016 w
.1036 .73252 m
.10345 .7326 L
s
1 .964 0 r
.008 w
.10345 .7326 Mdot
.016 w
.10345 .7326 m
.10337 .73258 L
s
1 .945 0 r
.008 w
.10337 .73258 Mdot
.016 w
.10337 .73258 m
.10336 .73247 L
s
1 .927 0 r
.008 w
.10336 .73247 Mdot
.016 w
.10336 .73247 m
.10335 .73234 L
s
1 .909 0 r
.008 w
.10335 .73234 Mdot
.016 w
.10335 .73234 m
.10335 .7322 L
s
1 .891 0 r
.008 w
.10335 .7322 Mdot
.016 w
.10335 .7322 m
.10336 .73209 L
s
1 .873 0 r
.008 w
.10336 .73209 Mdot
.016 w
.10336 .73209 m
.10343 .732 L
s
1 .855 0 r
.008 w
.10343 .732 Mdot
.016 w
.10343 .732 m
.10355 .73193 L
s
1 .836 0 r
.008 w
.10355 .73193 Mdot
.016 w
.10355 .73193 m
.1037 .73194 L
s
1 .818 0 r
.008 w
.1037 .73194 Mdot
.016 w
.1037 .73194 m
.10389 .73205 L
s
1 .8 0 r
.008 w
.10389 .73205 Mdot
.016 w
.10389 .73205 m
.10412 .73217 L
s
1 .782 0 r
.008 w
.10412 .73217 Mdot
.016 w
.10412 .73217 m
.10438 .73233 L
s
1 .764 0 r
.008 w
.10438 .73233 Mdot
.016 w
.10438 .73233 m
.10468 .73252 L
s
1 .745 0 r
.008 w
.10468 .73252 Mdot
.016 w
.10468 .73252 m
.10496 .73269 L
s
1 .727 0 r
.008 w
.10496 .73269 Mdot
.016 w
.10496 .73269 m
.10519 .73283 L
s
1 .709 0 r
.008 w
.10519 .73283 Mdot
.016 w
.10519 .73283 m
.10536 .73294 L
s
1 .691 0 r
.008 w
.10536 .73294 Mdot
.016 w
.10536 .73294 m
.10548 .73302 L
s
1 .673 0 r
.008 w
.10548 .73302 Mdot
.016 w
.10548 .73302 m
.10555 .73304 L
s
1 .655 0 r
.008 w
.10555 .73304 Mdot
.016 w
.10555 .73304 m
.10558 .73301 L
s
1 .636 0 r
.008 w
.10558 .73301 Mdot
.016 w
.10558 .73301 m
.10558 .73295 L
s
1 .618 0 r
.008 w
.10558 .73295 Mdot
.016 w
.10558 .73295 m
.10556 .7329 L
s
1 .6 0 r
.008 w
.10556 .7329 Mdot
.016 w
.10556 .7329 m
.10553 .73284 L
s
1 .582 0 r
.008 w
.10553 .73284 Mdot
.016 w
.10553 .73284 m
.1055 .73277 L
s
1 .564 0 r
.008 w
.1055 .73277 Mdot
.016 w
.1055 .73277 m
.10548 .73272 L
s
1 .545 0 r
.008 w
.10548 .73272 Mdot
.016 w
.10548 .73272 m
.10547 .73268 L
s
1 .527 0 r
.008 w
.10547 .73268 Mdot
.016 w
.10547 .73268 m
.10548 .73265 L
s
1 .509 0 r
.008 w
.10548 .73265 Mdot
.016 w
.10548 .73265 m
.10548 .73259 L
s
1 .491 0 r
.008 w
.10548 .73259 Mdot
.016 w
.10548 .73259 m
.10549 .73249 L
s
1 .473 0 r
.008 w
.10549 .73249 Mdot
.016 w
.10549 .73249 m
.10549 .73238 L
s
1 .455 0 r
.008 w
.10549 .73238 Mdot
.016 w
.10549 .73238 m
.10549 .73226 L
s
1 .436 0 r
.008 w
.10549 .73226 Mdot
.016 w
.10549 .73226 m
.10548 .73216 L
s
1 .418 0 r
.008 w
.10548 .73216 Mdot
.016 w
.10548 .73216 m
.10547 .73209 L
s
1 .4 0 r
.008 w
.10547 .73209 Mdot
.016 w
.10547 .73209 m
.10546 .73206 L
s
1 .382 0 r
.008 w
.10546 .73206 Mdot
.016 w
.10546 .73206 m
.10538 .73192 L
s
1 .364 0 r
.008 w
.10538 .73192 Mdot
.016 w
.10538 .73192 m
.10536 .73195 L
s
1 .345 0 r
.008 w
.10536 .73195 Mdot
.016 w
.10536 .73195 m
.10533 .73201 L
s
1 .327 0 r
.008 w
.10533 .73201 Mdot
.016 w
.10533 .73201 m
.10532 .73209 L
s
1 .309 0 r
.008 w
.10532 .73209 Mdot
.016 w
.10532 .73209 m
.1053 .73218 L
s
1 .291 0 r
.008 w
.1053 .73218 Mdot
.016 w
.1053 .73218 m
.1053 .73227 L
s
1 .273 0 r
.008 w
.1053 .73227 Mdot
.016 w
.1053 .73227 m
.1053 .73239 L
s
1 .255 0 r
.008 w
.1053 .73239 Mdot
.016 w
.1053 .73239 m
.1053 .73252 L
s
1 .236 0 r
.008 w
.1053 .73252 Mdot
.016 w
.1053 .73252 m
.10531 .73266 L
s
1 .218 0 r
.008 w
.10531 .73266 Mdot
.016 w
.10531 .73266 m
.10533 .73281 L
s
1 .2 0 r
.008 w
.10533 .73281 Mdot
.016 w
.10533 .73281 m
.10535 .73295 L
s
1 .182 0 r
.008 w
.10535 .73295 Mdot
.016 w
.10535 .73295 m
.10538 .73307 L
s
1 .164 0 r
.008 w
.10538 .73307 Mdot
.016 w
.10538 .73307 m
.10541 .73315 L
s
1 .145 0 r
.008 w
.10541 .73315 Mdot
.016 w
.10541 .73315 m
.10544 .7332 L
s
1 .127 0 r
.008 w
.10544 .7332 Mdot
.016 w
.10544 .7332 m
.10548 .73319 L
s
1 .109 0 r
.008 w
.10548 .73319 Mdot
.016 w
.10548 .73319 m
.10553 .73309 L
s
1 .091 0 r
.008 w
.10553 .73309 Mdot
.016 w
.10553 .73309 m
.10558 .73293 L
s
1 .073 0 r
.008 w
.10558 .73293 Mdot
.016 w
.10558 .73293 m
.10561 .73277 L
s
1 .055 0 r
.008 w
.10561 .73277 Mdot
.016 w
.10561 .73277 m
.10562 .73267 L
s
1 .036 0 r
.008 w
.10562 .73267 Mdot
.016 w
.10562 .73267 m
.1056 .73266 L
s
1 .018 0 r
.008 w
.1056 .73266 Mdot
.016 w
.1056 .73266 m
.10554 .73276 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol7?NoAOol2?Nl:Ool00`00Oomoo`0JOol001ao
o`03001oogoo00Pmkm]oo`03001oogoo01]oo`0077oo00H007ooOolmkglPOD02O2000ge0?Nlmk`3K
Ool00`00Oomoo`0KOol001eoo`06001oocg_O^1l87`00W`P0Sg_fWoo00<007ooOol077oo000MOol0
1P00OolmkgkPO21l009l808mkmYoo`03001oogoo01aoo`007Woo00@007ooO^1m@09l8004OD0mkcg_
Ool2?NoFOol00`00Oomoo`0MOol001ioo`03001oogkP00Am@003?Nmoocg_00<mkl9oo`8mka5oo`03
001oogoo01eoo`007goo00<003g_?Nl013g_00=oocg_?Nl00Sg_`Goo13g_1Goo0cg_1goo00<007oo
Ool07Woo000OOol00`00?Nlmk`09?No1Ool4?Nl4Ool5?Nl6Ool00`00Oomoo`0NOol0021oo`/mkl9o
o`8mk`=oo`Lmk`Eoo`03001oogoo01moo`0087oo00<003g_?Nl02Cg_`goo2Sg_1Goo00<007ooOol0
7goo000QOol00`00?Nlmk`03?Nl00goo?Nlmk`02?No3Ool:?Nl4Ool00`00Oomoo`0POol0029oo`03
001oogoo00=oo`<mklAoo`Xmk`=oo`03001oogoo025oo`008goo00@007ooOomoo`Dmkl=oo`Tmk`=o
o`03001oogoo029oo`0097oo00<007ooOol01Cg_agoo13g_0goo00<007ooOol08goo000TOol01000
Oomoogoo0cg_bGoo0cg_0goo00<007ooOol08goo000UOol00`00Oomoo`08Ool2?No0Ool5?Nl2Ool0
0`00Oomoo`0TOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001oogoo02Eoo`009Woo00<0
07ooOol01Goo1Cg__Woo13g_0goo00<007ooOol09Goo000WOol00`00Oomoo`04Ool5?NnkOol6?Nl3
Ool00`00Oomoo`0VOol002Qoo`03001oogoo00=oo`Dmkk]oo`Lmk`03Ool007oo02Qoo`00:Goo00<0
07ooOol017oo0Sg_00=oocg_Ool0^Goo1cg_00<007ooOol0:7oo000ZOol01000Oomoogoo1cg_JWoo
0Sg_CGoo1Sg_00<007ooOol0:Goo000ZOol01000Oomoogoo23g_J7oo13g_37oo13g_?7oo1Sg_00<0
07ooOol0:Goo000[Ool00`00Oomoo`08?NmXOol4?Nl<Ool5?NlkOol5?Nl00`00Oomoo`0ZOol002ao
o`03001oocg_00LmkfUoo`8mk`eoo`Dmkc1oo`@mk`Aoo`8mk`Eoo`03001oogoo02]oo`00;Goo00<0
07ooOol00Woo13g_N7oo13g_<Goo1Cg_0Woo13g_0goo00<007ooOol0;7oo000^Ool01000Oomoogoo
13g_[Goo1Cg_0Woo13g_0Woo00<007ooOol0;Goo000^Ool00`00Oomoo`2bOol4?Nl4Ool2?Nl3Ool0
0`00Oomoo`0]Ool002moo`03001oogoo08Qoo`8mkbYoo`8mk`Moo`03001oogoo02ioo`00<7oo00<0
07ooOol0QWoo13g_9Woo1Sg_1Goo00<007ooOol0;goo000aOol00`00Oomoo`05Ool4?NmlOol4?NlU
Ool7?Nl4Ool00`00Oomoo`0`Ool0039oo`8000Eoo`Dmkgaoo`8mkbIoo`Hmk`=oo`8003=oo`00=7oo
00<007ooOol00Woo1Cg_MWoo13g_:goo0cg_17oo00<007ooOol0<goo000eOol01000Oomoogoo13g_
Mgoo1Cg_:Woo0cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo13g_Mgoo1Cg_<7oo00<007oo
Ool0=7oo000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol003Moo`03001oogoo07Yoo`Dm
kbioo`03001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<007ooOol0=goo000iOol2001j
Ool4?Nl[Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo
00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00
@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2000:Ool2?Nm[Ool2?NlPOol20012Ool004=o
o`03001oogoo00Aoo`HmkfUoo`@mkaioo`03001oogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo
0Sg_=Woo13g_4Goo0Sg_2Woo00<007ooOol0@goo0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_
4Goo13g_27oo00<007ooOol0A7oo0016Ool20002Ool5?NlaOol4?Nm9Ool4?Nl6Ool20017Ool004Qo
o`800003Oolmkcg_008mkc9oo`8mkd]oo`8mk`Eoo`8004Uoo`00BWoo00<003g_?Nl00Sg_Q7oo0P00
Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007oo
Ool037oo0Sg_GWoo0Sg_3goo00<007ooOol0CWoo001@Ool2000;Ool4?NlgOol4?NlQOol7?Nl9Ool2
001AOol0059oo`8000Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`8005=oo`00E7oo0P0027oo0Sg_>7oo13g_
6Goo0cg_0Woo2cg_17oo0P00EGoo001FOol20010Ool4?NlHOol@?Nl3Ool2001GOol005Qoo`<0015o
o`DmkbMoo`@mkaQooa0mk`<005Uoo`00Fgoo0`003Woo1Cg_>Goo1Sg_17oo3Sg_0P00G7oo001NOol2
000<Ool7?NlgOol6?Nl5Ool=?NmNOol0061oo`8000Yoo`Pmk`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001o
ogoo061oo`00HWoo0`001goo2Cg_0goo1Sg_3goo0cg_6Woo1Sg_1Woo1Cg_0P00Hgoo001UOol30008
Ool5?Nl3Ool6?Nl>Ool6?NlJOol4?Nl7Ool3001VOol006Qoo`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Ao
o`Hmk`03Oolmkcg_01ioo`@006Uoo`00K7oo100027oo1Cg_1goo4Sg_6Goo1000KGoo001`Ool30006
Ool4?Nl7OolB?NlEOol4001aOol007=oo`D000aoo`Xmk`05Oolmkcg_?Nmoo`02?NlBOol4001eOol0
07Qoo`L000Eoo`Xmk`04Oolmkcg_?Nl>Ool7001iOol007moo`D000Xmk`Aoo`h0081oo`00SGoo1@00
SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0027Ool40003Ool20004Ool2002:
Ool008Moo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00RGoo0028Ool00`00Oomoo`04
Ool01@00Oomoogoo00000Woo00<007ooOol0Qgoo0029Ool00`00Oomoo`04Ool01000Oomoogoo0P00
RWoo0027Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0029Ool008Qoo`8000Aoo`80
00Aoo`8008Yoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(239)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
1 .98 0 r
.008 w
.11532 .75601 Mdot
.016 w
.11532 .75601 m
.11541 .75604 L
s
1 .959 0 r
.008 w
.11541 .75604 Mdot
.016 w
.11541 .75604 m
.11538 .75601 L
s
1 .939 0 r
.008 w
.11538 .75601 Mdot
.016 w
.11538 .75601 m
.11526 .75592 L
s
1 .918 0 r
.008 w
.11526 .75592 Mdot
.016 w
.11526 .75592 m
.1151 .75582 L
s
1 .898 0 r
.008 w
.1151 .75582 Mdot
.016 w
.1151 .75582 m
.11492 .75574 L
s
1 .878 0 r
.008 w
.11492 .75574 Mdot
.016 w
.11492 .75574 m
.11476 .7557 L
s
1 .857 0 r
.008 w
.11476 .7557 Mdot
.016 w
.11476 .7557 m
.11465 .7557 L
s
1 .837 0 r
.008 w
.11465 .7557 Mdot
.016 w
.11465 .7557 m
.1146 .75579 L
s
1 .816 0 r
.008 w
.1146 .75579 Mdot
.016 w
.1146 .75579 m
.11457 .75591 L
s
1 .796 0 r
.008 w
.11457 .75591 Mdot
.016 w
.11457 .75591 m
.11455 .75603 L
s
1 .776 0 r
.008 w
.11455 .75603 Mdot
.016 w
.11455 .75603 m
.1145 .75608 L
s
1 .755 0 r
.008 w
.1145 .75608 Mdot
.016 w
.1145 .75608 m
.1144 .7561 L
s
1 .735 0 r
.008 w
.1144 .7561 Mdot
.016 w
.1144 .7561 m
.11425 .75606 L
s
1 .714 0 r
.008 w
.11425 .75606 Mdot
.016 w
.11425 .75606 m
.11406 .75593 L
s
1 .694 0 r
.008 w
.11406 .75593 Mdot
.016 w
.11406 .75593 m
.11387 .7557 L
s
1 .673 0 r
.008 w
.11387 .7557 Mdot
.016 w
.11387 .7557 m
.1137 .75539 L
s
1 .653 0 r
.008 w
.1137 .75539 Mdot
.016 w
.1137 .75539 m
.1136 .75505 L
s
1 .633 0 r
.008 w
.1136 .75505 Mdot
.016 w
.1136 .75505 m
.11358 .75467 L
s
1 .612 0 r
.008 w
.11358 .75467 Mdot
.016 w
.11358 .75467 m
.11364 .75432 L
s
1 .592 0 r
.008 w
.11364 .75432 Mdot
.016 w
.11364 .75432 m
.11374 .75401 L
s
1 .571 0 r
.008 w
.11374 .75401 Mdot
.016 w
.11374 .75401 m
.11386 .75379 L
s
1 .551 0 r
.008 w
.11386 .75379 Mdot
.016 w
.11386 .75379 m
.11396 .75359 L
s
1 .531 0 r
.008 w
.11396 .75359 Mdot
.016 w
.11396 .75359 m
.11403 .7534 L
s
1 .51 0 r
.008 w
.11403 .7534 Mdot
.016 w
.11403 .7534 m
.11405 .75325 L
s
1 .49 0 r
.008 w
.11405 .75325 Mdot
.016 w
.11405 .75325 m
.11403 .75319 L
s
1 .469 0 r
.008 w
.11403 .75319 Mdot
.016 w
.11403 .75319 m
.114 .75319 L
s
1 .449 0 r
.008 w
.114 .75319 Mdot
.016 w
.114 .75319 m
.11397 .75326 L
s
1 .429 0 r
.008 w
.11397 .75326 Mdot
.016 w
.11397 .75326 m
.11394 .75342 L
s
1 .408 0 r
.008 w
.11394 .75342 Mdot
.016 w
.11394 .75342 m
.11388 .75365 L
s
1 .388 0 r
.008 w
.11388 .75365 Mdot
.016 w
.11388 .75365 m
.1138 .75393 L
s
1 .367 0 r
.008 w
.1138 .75393 Mdot
.016 w
.1138 .75393 m
.11371 .75425 L
s
1 .347 0 r
.008 w
.11371 .75425 Mdot
.016 w
.11371 .75425 m
.11364 .75462 L
s
1 .327 0 r
.008 w
.11364 .75462 Mdot
.016 w
.11364 .75462 m
.11361 .75502 L
s
1 .306 0 r
.008 w
.11361 .75502 Mdot
.016 w
.11361 .75502 m
.11364 .75543 L
s
1 .286 0 r
.008 w
.11364 .75543 Mdot
.016 w
.11364 .75543 m
.11374 .75581 L
s
1 .265 0 r
.008 w
.11374 .75581 Mdot
.016 w
.11374 .75581 m
.11391 .7562 L
s
1 .245 0 r
.008 w
.11391 .7562 Mdot
.016 w
.11391 .7562 m
.11414 .75654 L
s
1 .224 0 r
.008 w
.11414 .75654 Mdot
.016 w
.11414 .75654 m
.11443 .75678 L
s
1 .204 0 r
.008 w
.11443 .75678 Mdot
.016 w
.11443 .75678 m
.11473 .75691 L
s
1 .184 0 r
.008 w
.11473 .75691 Mdot
.016 w
.11473 .75691 m
.115 .75691 L
s
1 .163 0 r
.008 w
.115 .75691 Mdot
.016 w
.115 .75691 m
.11522 .75679 L
s
1 .143 0 r
.008 w
.11522 .75679 Mdot
.016 w
.11522 .75679 m
.11535 .75656 L
s
1 .122 0 r
.008 w
.11535 .75656 Mdot
.016 w
.11535 .75656 m
.1154 .75628 L
s
1 .102 0 r
.008 w
.1154 .75628 Mdot
.016 w
.1154 .75628 m
.11537 .75597 L
s
1 .082 0 r
.008 w
.11537 .75597 Mdot
.016 w
.11537 .75597 m
.11527 .75566 L
s
1 .061 0 r
.008 w
.11527 .75566 Mdot
.016 w
.11527 .75566 m
.11515 .7554 L
s
1 .041 0 r
.008 w
.11515 .7554 Mdot
.016 w
.11515 .7554 m
.11503 .75524 L
s
1 .02 0 r
.008 w
.11503 .75524 Mdot
.016 w
.11503 .75524 m
.11497 .75529 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol7?NoAOol2?Nl:Ool00`00Oomoo`0JOol001ao
o`03001oogoo00Pmkm]oo`03001oogoo01]oo`0077oo00<007ooOol023g_fgoo00<007ooOol06goo
000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001eoo`03001oocg_00LmkmYoo`03001oogoo
01aoo`007Woo00<007oo?Nl01Sg_00=oocg_?Nl0eWoo00<007ooOol07Goo000NOol00`00Oolmk`05
?Nl00goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol001moo`03000mkcg_00@mk`03Oolmkcg_
008mkl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo00@003g_?Nlmk`AmP0@mkl5oo`@mk`Ao
o`Dmk`Ioo`03001oogoo01ioo`0087oo0cg_00AmP7dPO01mP0@mkl9oo`8mk`=oo`Lmk`Eoo`03001o
ogoo01moo`0087oo00P003g_?NmmP7cPO01mP7mP13g_`goo2Sg_1Goo00<007ooOol07goo000QOol0
1`00?NmmP7cPO21mP7mP00@mkl=oo`Xmk`Aoo`03001oogoo021oo`008Woo00<007f0OH000Wf000Ao
ocg_?NlmklAoo`Xmk`=oo`03001oogoo025oo`008goo00@007ooOomoo`Dmkl=oo`Tmk`=oo`03001o
ogoo029oo`0097oo00<007ooOol01Cg_agoo13g_0goo00<007ooOol08goo000TOol01000Oomoogoo
0cg_bGoo0cg_0goo00<007ooOol08goo000UOol00`00Oomoo`08Ool2?No0Ool5?Nl2Ool00`00Oomo
o`0TOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001oogoo02Eoo`009Woo00<007ooOol0
1Goo1Cg__Woo13g_0goo00<007ooOol09Goo000WOol00`00Oomoo`04Ool5?NnkOol6?Nl3Ool00`00
Oomoo`0VOol002Qoo`03001oogoo00=oo`Dmkk]oo`Lmk`03Ool007oo02Qoo`00:Goo00<007ooOol0
17oo0Sg_00=oocg_Ool0^Goo1cg_00<007ooOol0:7oo000ZOol01000Oomoogoo1cg_JWoo0Sg_CGoo
1Sg_00<007ooOol0:Goo000ZOol01000Oomoogoo23g_J7oo13g_37oo13g_?7oo1Sg_00<007ooOol0
:Goo000[Ool00`00Oomoo`08?NmXOol4?Nl<Ool5?NlkOol5?Nl00`00Oomoo`0ZOol002aoo`03001o
ocg_00LmkfUoo`8mk`eoo`Dmkc1oo`@mk`Aoo`8mk`Eoo`03001oogoo02]oo`00;Goo00<007ooOol0
0Woo13g_N7oo13g_<Goo1Cg_0Woo13g_0goo00<007ooOol0;7oo000^Ool01000Oomoogoo13g_[Goo
1Cg_0Woo13g_0Woo00<007ooOol0;Goo000^Ool00`00Oomoo`2bOol4?Nl4Ool2?Nl3Ool00`00Oomo
o`0]Ool002moo`03001oogoo08Qoo`8mkbYoo`8mk`Moo`03001oogoo02ioo`00<7oo00<007ooOol0
QWoo13g_9Woo1Sg_1Goo00<007ooOol0;goo000aOol00`00Oomoo`05Ool4?NmlOol4?NlUOol7?Nl4
Ool00`00Oomoo`0`Ool0039oo`8000Eoo`Dmkgaoo`8mkbIoo`Hmk`=oo`8003=oo`00=7oo00<007oo
Ool00Woo1Cg_MWoo13g_:goo0cg_17oo00<007ooOol0<goo000eOol01000Oomoogoo13g_Mgoo1Cg_
:Woo0cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo13g_Mgoo1Cg_<7oo00<007ooOol0=7oo
000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol003Moo`03001oogoo07Yoo`Dmkbioo`03
001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<007ooOol0=goo000iOol2001jOol4?Nl[
Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007oo
Ool0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<0
07ooOol0Vgoo00<007ooOol0?goo0011Ool2000:Ool2?Nm[Ool2?NlPOol20012Ool004=oo`03001o
ogoo00Aoo`HmkfUoo`@mkaioo`03001oogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo
13g_4Goo0Sg_2Woo00<007ooOol0@goo0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo13g_
27oo00<007ooOol0A7oo0016Ool20002Ool5?NlaOol4?Nm9Ool4?Nl6Ool20017Ool004Qoo`800003
Oolmkcg_008mkc9oo`8mkd]oo`8mk`Eoo`8004Uoo`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<
Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol037oo
0Sg_GWoo0Sg_3goo00<007ooOol0CWoo001@Ool2000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0
059oo`8000Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`8005=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_
0Woo2cg_17oo0P00EGoo001FOol20010Ool4?NlHOol@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMo
o`@mkaQooa0mk`<005Uoo`00Fgoo0`003Woo1Cg_>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7
?NlgOol6?Nl5Ool=?NmNOol0061oo`8000Yoo`Pmk`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061o
o`00HWoo0`001goo2Cg_0goo1Sg_3goo0cg_6Woo1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3
Ool6?Nl>Ool6?NlJOol4?Nl7Ool3001VOol006Qoo`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03
Oolmkcg_01ioo`@006Uoo`00K7oo100027oo1Cg_1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7
OolB?NlEOol4001aOol007=oo`D000aoo`Xmk`05Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L0
00Eoo`Xmk`04Oolmkcg_?Nl>Ool7001iOol007moo`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0027Ool40003Ool20003Ool3002:Ool008Mo
o`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`28Ool008Qoo`03001oogoo00Aoo`03001o
ogoo009oo`<008Uoo`00RGoo00<007ooOol017oo00@007ooOol0009oo`03001oogoo08Moo`00Qgoo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00RGoo0028Ool20004Ool20004Ool30029
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(240)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
1 .974 0 r
.008 w
.73856 .89181 Mdot
.016 w
.73856 .89181 m
.73859 .89166 L
s
1 .947 0 r
.008 w
.73859 .89166 Mdot
.016 w
.73859 .89166 m
.73847 .89167 L
s
1 .921 0 r
.008 w
.73847 .89167 Mdot
.016 w
.73847 .89167 m
.73824 .8918 L
s
1 .895 0 r
.008 w
.73824 .8918 Mdot
.016 w
.73824 .8918 m
.73798 .892 L
s
1 .868 0 r
.008 w
.73798 .892 Mdot
.016 w
.73798 .892 m
.73772 .89221 L
s
1 .842 0 r
.008 w
.73772 .89221 Mdot
.016 w
.73772 .89221 m
.7375 .89238 L
s
1 .816 0 r
.008 w
.7375 .89238 Mdot
.016 w
.7375 .89238 m
.73753 .89248 L
s
1 .789 0 r
.008 w
.73753 .89248 Mdot
.016 w
.73753 .89248 m
.73739 .8925 L
s
1 .763 0 r
.008 w
.73739 .8925 Mdot
.016 w
.73739 .8925 m
.73731 .89249 L
s
1 .737 0 r
.008 w
.73731 .89249 Mdot
.016 w
.73731 .89249 m
.73727 .89247 L
s
1 .711 0 r
.008 w
.73727 .89247 Mdot
.016 w
.73727 .89247 m
.73725 .89244 L
s
1 .684 0 r
.008 w
.73725 .89244 Mdot
.016 w
.73725 .89244 m
.73721 .89241 L
s
1 .658 0 r
.008 w
.73721 .89241 Mdot
.016 w
.73721 .89241 m
.73716 .89239 L
s
1 .632 0 r
.008 w
.73716 .89239 Mdot
.016 w
.73716 .89239 m
.73709 .89238 L
s
1 .605 0 r
.008 w
.73709 .89238 Mdot
.016 w
.73709 .89238 m
.73696 .89239 L
s
1 .579 0 r
.008 w
.73696 .89239 Mdot
.016 w
.73696 .89239 m
.73678 .89242 L
s
1 .553 0 r
.008 w
.73678 .89242 Mdot
.016 w
.73678 .89242 m
.73652 .89246 L
s
1 .526 0 r
.008 w
.73652 .89246 Mdot
.016 w
.73652 .89246 m
.73627 .89249 L
s
1 .5 0 r
.008 w
.73627 .89249 Mdot
.016 w
.73627 .89249 m
.73607 .89251 L
s
1 .474 0 r
.008 w
.73607 .89251 Mdot
.016 w
.73607 .89251 m
.73594 .89252 L
s
1 .447 0 r
.008 w
.73594 .89252 Mdot
.016 w
.73594 .89252 m
.73588 .89251 L
s
1 .421 0 r
.008 w
.73588 .89251 Mdot
.016 w
.73588 .89251 m
.73591 .89248 L
s
1 .395 0 r
.008 w
.73591 .89248 Mdot
.016 w
.73591 .89248 m
.73598 .89244 L
s
1 .368 0 r
.008 w
.73598 .89244 Mdot
.016 w
.73598 .89244 m
.73606 .89242 L
s
1 .342 0 r
.008 w
.73606 .89242 Mdot
.016 w
.73606 .89242 m
.7361 .89243 L
s
1 .316 0 r
.008 w
.7361 .89243 Mdot
.016 w
.7361 .89243 m
.73606 .89248 L
s
1 .289 0 r
.008 w
.73606 .89248 Mdot
.016 w
.73606 .89248 m
.73594 .89255 L
s
1 .263 0 r
.008 w
.73594 .89255 Mdot
.016 w
.73594 .89255 m
.73574 .89264 L
s
1 .237 0 r
.008 w
.73574 .89264 Mdot
.016 w
.73574 .89264 m
.73547 .89272 L
s
1 .211 0 r
.008 w
.73547 .89272 Mdot
.016 w
.73547 .89272 m
.7352 .8928 L
s
1 .184 0 r
.008 w
.7352 .8928 Mdot
.016 w
.7352 .8928 m
.73493 .89289 L
s
1 .158 0 r
.008 w
.73493 .89289 Mdot
.016 w
.73493 .89289 m
.73467 .89298 L
s
1 .132 0 r
.008 w
.73467 .89298 Mdot
.016 w
.73467 .89298 m
.73444 .89309 L
s
1 .105 0 r
.008 w
.73444 .89309 Mdot
.016 w
.73444 .89309 m
.73423 .8932 L
s
1 .079 0 r
.008 w
.73423 .8932 Mdot
.016 w
.73423 .8932 m
.73409 .89332 L
s
1 .053 0 r
.008 w
.73409 .89332 Mdot
.016 w
.73409 .89332 m
.73402 .89345 L
s
1 .026 0 r
.008 w
.73402 .89345 Mdot
.016 w
.73402 .89345 m
.73402 .89357 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol7?NoAOol2?Nl:Ool00`00Oomoo`0JOol001ao
o`03001oogoo00Pmkm]oo`03001oogoo01]oo`0077oo00<007ooOol023g_fgoo00<007ooOol06goo
000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001eoo`03001oocg_00LmkmYoo`03001oogoo
01aoo`007Woo00<007oo?Nl01Sg_00=oocg_?Nl0eWoo00<007ooOol07Goo000NOol00`00Oolmk`05
?Nl00goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol001moo`03000mkcg_00@mk`03Oolmkcg_
008mkl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo00<003g_?Nl02Cg_`Goo13g_17oo1Cg_
1Woo00<007ooOol07Woo000POol;?No2Ool2?Nl3Ool7?Nl5Ool00`00Oomoo`0OOol0021oo`03000m
kcg_00Tmkl=oo`Xmk`Eoo`03001oogoo01moo`008Goo00<003g_?Nl023g_`goo2Sg_17oo00<007oo
Ool087oo000ROol00`00?Nlmk`02?Nl017oo?Nlmkcg_a7oo2Sg_0goo00<007ooOol08Goo000SOol0
1000Oomoogoo1Cg_`goo2Cg_0goo00<007ooOol08Woo000TOol00`00Oomoo`05?No7Ool4?Nl3Ool0
0`00Oomoo`0SOol002Aoo`04001oogooOol3?No9Ool3?Nl3Ool00`00Oomoo`0SOol002Eoo`03001o
ogoo00Qoo`8mkl1oo`Dmk`9oo`03001oogoo02Aoo`009Woo00<007ooOol01Goo1Cg__Woo13g_0goo
00<007ooOol09Goo000VOol00`00Oomoo`05Ool5?NnnOol4?Nl3Ool00`00Oomoo`0UOol002Moo`03
001oogoo00Aoo`Dmkk]oo`Hmk`=oo`03001oogoo02Ioo`00:7oo00<007ooOol00goo1Cg_^goo1cg_
00=oo`00Ool0:7oo000YOol00`00Oomoo`04Ool2?Nl00goo?Nmoo`2iOol7?Nl00`00Oomoo`0XOol0
02Yoo`04001oogooOol7?NmZOol2?Nm=Ool6?Nl00`00Oomoo`0YOol002Yoo`04001oogooOol8?NmX
Ool4?Nl<Ool4?NllOol6?Nl00`00Oomoo`0YOol002]oo`03001oogoo00PmkfQoo`@mk`aoo`Dmkc]o
o`Dmk`03001oogoo02Yoo`00;7oo00<007oo?Nl01cg_JGoo0Sg_3Goo1Cg_<7oo13g_17oo0Sg_1Goo
00<007ooOol0:goo000]Ool00`00Oomoo`02Ool4?NmhOol4?NlaOol5?Nl2Ool4?Nl3Ool00`00Oomo
o`0/Ool002ioo`04001oogooOol4?Nn]Ool5?Nl2Ool4?Nl2Ool00`00Oomoo`0]Ool002ioo`03001o
ogoo0;9oo`@mk`Aoo`8mk`=oo`03001oogoo02eoo`00;goo00<007ooOol0R7oo0Sg_:Woo0Sg_1goo
00<007ooOol0;Woo000`Ool00`00Oomoo`26Ool4?NlVOol6?Nl5Ool00`00Oomoo`0_Ool0035oo`03
001oogoo00Eoo`@mkgaoo`@mkbEoo`Lmk`Aoo`03001oogoo031oo`00<Woo0P001Goo1Cg_O7oo0Sg_
9Woo1Sg_0goo0P00<goo000dOol00`00Oomoo`02Ool5?NmfOol4?Nl[Ool3?Nl4Ool00`00Oomoo`0c
Ool003Eoo`04001oogooOol4?NmgOol5?NlZOol3?Nl3Ool00`00Oomoo`0dOol003Eoo`04001oogoo
Ool4?NmgOol5?Nl`Ool00`00Oomoo`0dOol003Ioo`03001oogoo07]oo`Dmkbmoo`03001oogoo03Eo
o`00=goo00<007ooOol0NWoo1Cg_;Woo00<007ooOol0=Woo000hOol00`00Oomoo`1iOol5?Nl]Ool0
0`00Oomoo`0gOol003Uoo`8007Yoo`@mkb]oo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0
>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03ao
o`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8000Yoo`8m
kf]oo`8mkb1oo`80049oo`00@goo00<007ooOol017oo1Sg_JGoo13g_4Goo00Eo@7`PO21o@7o000Qo
o`03001oogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo13g_47oo00=lX7`PO0000W`P
00=o@7ooOol01Goo00<007ooOol0@goo0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo00=l
X7`PO0000W`P00=o@7ooOol017oo00<007ooOol0A7oo0016Ool20002Ool5?NlaOol4?Nm9Ool2O:02
O2000gbPOl1oo`03Ool20017Ool004Qoo`800003Oolmkcg_008mkc9oo`8mkdYoo`ElX0=oo`8004Uo
o`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07mo
o`03001oogoo04eoo`00Cgoo00<007ooOol037oo0Sg_GWoo0Sg_3goo00<007ooOol0CWoo001@Ool2
000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0059oo`8000Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`80
05=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_0Woo2cg_17oo0P00EGoo001FOol20010Ool4?NlH
Ool@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMoo`@mkaQooa0mk`<005Uoo`00Fgoo0`003Woo1Cg_
>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7?NlgOol6?Nl5Ool=?NmNOol0061oo`8000Yoo`Pm
k`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061oo`00HWoo0`001goo2Cg_0goo1Sg_3goo0cg_6Woo
1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3Ool6?Nl>Ool6?NlJOol4?Nl7Ool3001VOol006Qo
o`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03Oolmkcg_01ioo`@006Uoo`00K7oo100027oo1Cg_
1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7OolB?NlEOol4001aOol007=oo`D000aoo`Xmk`05
Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L000Eoo`Xmk`04Oolmkcg_?Nl>Ool7001iOol007mo
o`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo0027Ool40004Ool30002Ool2002:Ool008Moo`03001oogoo00Ioo`04001oogoo0002Ool00`00
Oomoo`27Ool008Qoo`03001oogoo009oo`D00005Ool007ooOol00029Ool008Uoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol0Qgoo0027Ool01000Oomoo`000goo00<007oo00000Woo
00@007ooOol008Uoo`00R7oo0P001Goo0P000goo0P00RWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(241)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
1 .992 0 r
.008 w
.81264 .83023 Mdot
.016 w
.81264 .83023 m
.81264 .83037 L
s
1 .984 0 r
.008 w
.81264 .83037 Mdot
.016 w
.81264 .83037 m
.81268 .83044 L
s
1 .977 0 r
.008 w
.81268 .83044 Mdot
.016 w
.81268 .83044 m
.81273 .83048 L
s
1 .969 0 r
.008 w
.81273 .83048 Mdot
.016 w
.81273 .83048 m
.81278 .83048 L
s
1 .961 0 r
.008 w
.81278 .83048 Mdot
.016 w
.81278 .83048 m
.81281 .83046 L
s
1 .953 0 r
.008 w
.81281 .83046 Mdot
.016 w
.81281 .83046 m
.81282 .83041 L
s
1 .945 0 r
.008 w
.81282 .83041 Mdot
.016 w
.81282 .83041 m
.81282 .83036 L
s
1 .938 0 r
.008 w
.81282 .83036 Mdot
.016 w
.81282 .83036 m
.81282 .83033 L
s
1 .93 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .922 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .914 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .906 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .898 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .891 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81282 .83033 L
s
1 .883 0 r
.008 w
.81282 .83033 Mdot
.016 w
.81282 .83033 m
.81283 .83033 L
s
1 .875 0 r
.008 w
.81283 .83033 Mdot
.016 w
.81283 .83033 m
.81285 .83032 L
s
1 .867 0 r
.008 w
.81285 .83032 Mdot
.016 w
.81285 .83032 m
.81291 .83031 L
s
1 .859 0 r
.008 w
.81291 .83031 Mdot
.016 w
.81291 .83031 m
.81299 .83028 L
s
1 .852 0 r
.008 w
.81299 .83028 Mdot
.016 w
.81299 .83028 m
.81306 .83023 L
s
1 .844 0 r
.008 w
.81306 .83023 Mdot
.016 w
.81306 .83023 m
.81308 .83018 L
s
1 .836 0 r
.008 w
.81308 .83018 Mdot
.016 w
.81308 .83018 m
.81306 .83016 L
s
1 .828 0 r
.008 w
.81306 .83016 Mdot
.016 w
.81306 .83016 m
.81296 .83018 L
s
1 .82 0 r
.008 w
.81296 .83018 Mdot
.016 w
.81296 .83018 m
.81276 .83023 L
s
1 .813 0 r
.008 w
.81276 .83023 Mdot
.016 w
.81276 .83023 m
.81245 .83032 L
s
1 .805 0 r
.008 w
.81245 .83032 Mdot
.016 w
.81245 .83032 m
.81206 .83044 L
s
1 .797 0 r
.008 w
.81206 .83044 Mdot
.016 w
.81206 .83044 m
.8116 .83062 L
s
1 .789 0 r
.008 w
.8116 .83062 Mdot
.016 w
.8116 .83062 m
.81111 .83085 L
s
1 .781 0 r
.008 w
.81111 .83085 Mdot
.016 w
.81111 .83085 m
.81062 .83113 L
s
1 .773 0 r
.008 w
.81062 .83113 Mdot
.016 w
.81062 .83113 m
.81014 .83149 L
s
1 .766 0 r
.008 w
.81014 .83149 Mdot
.016 w
.81014 .83149 m
.8097 .8319 L
s
1 .758 0 r
.008 w
.8097 .8319 Mdot
.016 w
.8097 .8319 m
.80929 .83233 L
s
1 .75 0 r
.008 w
.80929 .83233 Mdot
.016 w
.80929 .83233 m
.80891 .83277 L
s
1 .742 0 r
.008 w
.80891 .83277 Mdot
.016 w
.80891 .83277 m
.80859 .8332 L
s
1 .734 0 r
.008 w
.80859 .8332 Mdot
.016 w
.80859 .8332 m
.80835 .8336 L
s
1 .727 0 r
.008 w
.80835 .8336 Mdot
.016 w
.80835 .8336 m
.80819 .83396 L
s
1 .719 0 r
.008 w
.80819 .83396 Mdot
.016 w
.80819 .83396 m
.80814 .8343 L
s
1 .711 0 r
.008 w
.80814 .8343 Mdot
.016 w
.80814 .8343 m
.80817 .83461 L
s
1 .703 0 r
.008 w
.80817 .83461 Mdot
.016 w
.80817 .83461 m
.80826 .83485 L
s
1 .695 0 r
.008 w
.80826 .83485 Mdot
.016 w
.80826 .83485 m
.80838 .83502 L
s
1 .688 0 r
.008 w
.80838 .83502 Mdot
.016 w
.80838 .83502 m
.80848 .83509 L
s
1 .68 0 r
.008 w
.80848 .83509 Mdot
.016 w
.80848 .83509 m
.80856 .83503 L
s
1 .672 0 r
.008 w
.80856 .83503 Mdot
.016 w
.80856 .83503 m
.80861 .83484 L
s
1 .664 0 r
.008 w
.80861 .83484 Mdot
.016 w
.80861 .83484 m
.80865 .83454 L
s
1 .656 0 r
.008 w
.80865 .83454 Mdot
.016 w
.80865 .83454 m
.80872 .83418 L
s
1 .648 0 r
.008 w
.80872 .83418 Mdot
.016 w
.80872 .83418 m
.80881 .83376 L
s
1 .641 0 r
.008 w
.80881 .83376 Mdot
.016 w
.80881 .83376 m
.80892 .83333 L
s
1 .633 0 r
.008 w
.80892 .83333 Mdot
.016 w
.80892 .83333 m
.80907 .83293 L
s
1 .625 0 r
.008 w
.80907 .83293 Mdot
.016 w
.80907 .83293 m
.80926 .83263 L
s
1 .617 0 r
.008 w
.80926 .83263 Mdot
.016 w
.80926 .83263 m
.80948 .83244 L
s
1 .609 0 r
.008 w
.80948 .83244 Mdot
.016 w
.80948 .83244 m
.80971 .83234 L
s
1 .602 0 r
.008 w
.80971 .83234 Mdot
.016 w
.80971 .83234 m
.80992 .83231 L
s
1 .594 0 r
.008 w
.80992 .83231 Mdot
.016 w
.80992 .83231 m
.81013 .83236 L
s
1 .586 0 r
.008 w
.81013 .83236 Mdot
.016 w
.81013 .83236 m
.8103 .83249 L
s
1 .578 0 r
.008 w
.8103 .83249 Mdot
.016 w
.8103 .83249 m
.81044 .83269 L
s
1 .57 0 r
.008 w
.81044 .83269 Mdot
.016 w
.81044 .83269 m
.81055 .83295 L
s
1 .563 0 r
.008 w
.81055 .83295 Mdot
.016 w
.81055 .83295 m
.81066 .83328 L
s
1 .555 0 r
.008 w
.81066 .83328 Mdot
.016 w
.81066 .83328 m
.81076 .83359 L
s
1 .547 0 r
.008 w
.81076 .83359 Mdot
.016 w
.81076 .83359 m
.81086 .83382 L
s
1 .539 0 r
.008 w
.81086 .83382 Mdot
.016 w
.81086 .83382 m
.81096 .8339 L
s
1 .531 0 r
.008 w
.81096 .8339 Mdot
.016 w
.81096 .8339 m
.81108 .83384 L
s
1 .523 0 r
.008 w
.81108 .83384 Mdot
.016 w
.81108 .83384 m
.81122 .83362 L
s
1 .516 0 r
.008 w
.81122 .83362 Mdot
.016 w
.81122 .83362 m
.81137 .83337 L
s
1 .508 0 r
.008 w
.81137 .83337 Mdot
.016 w
.81137 .83337 m
.81155 .83298 L
s
1 .5 0 r
.008 w
.81155 .83298 Mdot
.016 w
.81155 .83298 m
.81175 .83258 L
s
1 .492 0 r
.008 w
.81175 .83258 Mdot
.016 w
.81175 .83258 m
.81195 .83224 L
s
1 .484 0 r
.008 w
.81195 .83224 Mdot
.016 w
.81195 .83224 m
.81214 .83192 L
s
1 .477 0 r
.008 w
.81214 .83192 Mdot
.016 w
.81214 .83192 m
.81231 .83171 L
s
1 .469 0 r
.008 w
.81231 .83171 Mdot
.016 w
.81231 .83171 m
.81245 .83161 L
s
1 .461 0 r
.008 w
.81245 .83161 Mdot
.016 w
.81245 .83161 m
.81257 .83168 L
s
1 .453 0 r
.008 w
.81257 .83168 Mdot
.016 w
.81257 .83168 m
.81265 .83178 L
s
1 .445 0 r
.008 w
.81265 .83178 Mdot
.016 w
.81265 .83178 m
.81266 .83193 L
s
1 .438 0 r
.008 w
.81266 .83193 Mdot
.016 w
.81266 .83193 m
.81259 .8321 L
s
1 .43 0 r
.008 w
.81259 .8321 Mdot
.016 w
.81259 .8321 m
.81245 .83229 L
s
1 .422 0 r
.008 w
.81245 .83229 Mdot
.016 w
.81245 .83229 m
.81226 .83248 L
s
1 .414 0 r
.008 w
.81226 .83248 Mdot
.016 w
.81226 .83248 m
.81205 .8326 L
s
1 .406 0 r
.008 w
.81205 .8326 Mdot
.016 w
.81205 .8326 m
.81183 .8326 L
s
1 .398 0 r
.008 w
.81183 .8326 Mdot
.016 w
.81183 .8326 m
.81169 .83243 L
s
1 .391 0 r
.008 w
.81169 .83243 Mdot
.016 w
.81169 .83243 m
.81154 .83216 L
s
1 .383 0 r
.008 w
.81154 .83216 Mdot
.016 w
.81154 .83216 m
.81139 .83187 L
s
1 .375 0 r
.008 w
.81139 .83187 Mdot
.016 w
.81139 .83187 m
.81124 .83164 L
s
1 .367 0 r
.008 w
.81124 .83164 Mdot
.016 w
.81124 .83164 m
.8111 .8314 L
s
1 .359 0 r
.008 w
.8111 .8314 Mdot
.016 w
.8111 .8314 m
.81093 .83118 L
s
1 .352 0 r
.008 w
.81093 .83118 Mdot
.016 w
.81093 .83118 m
.81075 .83099 L
s
1 .344 0 r
.008 w
.81075 .83099 Mdot
.016 w
.81075 .83099 m
.8106 .83086 L
s
1 .336 0 r
.008 w
.8106 .83086 Mdot
.016 w
.8106 .83086 m
.8105 .83079 L
s
1 .328 0 r
.008 w
.8105 .83079 Mdot
.016 w
.8105 .83079 m
.81043 .83072 L
s
1 .32 0 r
.008 w
.81043 .83072 Mdot
.016 w
.81043 .83072 m
.81039 .83065 L
s
1 .313 0 r
.008 w
.81039 .83065 Mdot
.016 w
.81039 .83065 m
.81041 .83056 L
s
1 .305 0 r
.008 w
.81041 .83056 Mdot
.016 w
.81041 .83056 m
.81046 .83058 L
s
1 .297 0 r
.008 w
.81046 .83058 Mdot
.016 w
.81046 .83058 m
.81054 .83063 L
s
1 .289 0 r
.008 w
.81054 .83063 Mdot
.016 w
.81054 .83063 m
.81063 .83068 L
s
1 .281 0 r
.008 w
.81063 .83068 Mdot
.016 w
.81063 .83068 m
.81071 .83067 L
s
1 .273 0 r
.008 w
.81071 .83067 Mdot
.016 w
.81071 .83067 m
.81078 .83067 L
s
1 .266 0 r
.008 w
.81078 .83067 Mdot
.016 w
.81078 .83067 m
.81083 .83073 L
s
1 .258 0 r
.008 w
.81083 .83073 Mdot
.016 w
.81083 .83073 m
.81088 .83085 L
s
1 .25 0 r
.008 w
.81088 .83085 Mdot
.016 w
.81088 .83085 m
.81093 .831 L
s
1 .242 0 r
.008 w
.81093 .831 Mdot
.016 w
.81093 .831 m
.81098 .83115 L
s
1 .234 0 r
.008 w
.81098 .83115 Mdot
.016 w
.81098 .83115 m
.81101 .83125 L
s
1 .227 0 r
.008 w
.81101 .83125 Mdot
.016 w
.81101 .83125 m
.811 .83132 L
s
1 .219 0 r
.008 w
.811 .83132 Mdot
.016 w
.811 .83132 m
.81097 .83147 L
s
1 .211 0 r
.008 w
.81097 .83147 Mdot
.016 w
.81097 .83147 m
.81095 .83169 L
s
1 .203 0 r
.008 w
.81095 .83169 Mdot
.016 w
.81095 .83169 m
.81093 .83192 L
s
1 .195 0 r
.008 w
.81093 .83192 Mdot
.016 w
.81093 .83192 m
.81089 .83216 L
s
1 .188 0 r
.008 w
.81089 .83216 Mdot
.016 w
.81089 .83216 m
.81087 .83242 L
s
1 .18 0 r
.008 w
.81087 .83242 Mdot
.016 w
.81087 .83242 m
.81084 .83272 L
s
1 .172 0 r
.008 w
.81084 .83272 Mdot
.016 w
.81084 .83272 m
.81078 .83302 L
s
1 .164 0 r
.008 w
.81078 .83302 Mdot
.016 w
.81078 .83302 m
.81067 .83327 L
s
1 .156 0 r
.008 w
.81067 .83327 Mdot
.016 w
.81067 .83327 m
.81051 .83348 L
s
1 .148 0 r
.008 w
.81051 .83348 Mdot
.016 w
.81051 .83348 m
.81027 .83364 L
s
1 .141 0 r
.008 w
.81027 .83364 Mdot
.016 w
.81027 .83364 m
.80999 .83375 L
s
1 .133 0 r
.008 w
.80999 .83375 Mdot
.016 w
.80999 .83375 m
.80973 .83383 L
s
1 .125 0 r
.008 w
.80973 .83383 Mdot
.016 w
.80973 .83383 m
.8095 .83389 L
s
1 .117 0 r
.008 w
.8095 .83389 Mdot
.016 w
.8095 .83389 m
.80933 .83396 L
s
1 .109 0 r
.008 w
.80933 .83396 Mdot
.016 w
.80933 .83396 m
.80919 .83397 L
s
1 .102 0 r
.008 w
.80919 .83397 Mdot
.016 w
.80919 .83397 m
.80913 .83392 L
s
1 .094 0 r
.008 w
.80913 .83392 Mdot
.016 w
.80913 .83392 m
.80917 .83377 L
s
1 .086 0 r
.008 w
.80917 .83377 Mdot
.016 w
.80917 .83377 m
.80933 .8335 L
s
1 .078 0 r
.008 w
.80933 .8335 Mdot
.016 w
.80933 .8335 m
.80957 .83306 L
s
1 .07 0 r
.008 w
.80957 .83306 Mdot
.016 w
.80957 .83306 m
.80991 .83254 L
s
1 .063 0 r
.008 w
.80991 .83254 Mdot
.016 w
.80991 .83254 m
.81033 .83196 L
s
1 .055 0 r
.008 w
.81033 .83196 Mdot
.016 w
.81033 .83196 m
.81086 .83145 L
s
1 .047 0 r
.008 w
.81086 .83145 Mdot
.016 w
.81086 .83145 m
.81145 .831 L
s
1 .039 0 r
.008 w
.81145 .831 Mdot
.016 w
.81145 .831 m
.81208 .83065 L
s
1 .031 0 r
.008 w
.81208 .83065 Mdot
.016 w
.81208 .83065 m
.81265 .8304 L
s
1 .023 0 r
.008 w
.81265 .8304 Mdot
.016 w
.81265 .8304 m
.81309 .83025 L
s
1 .016 0 r
.008 w
.81309 .83025 Mdot
.016 w
.81309 .83025 m
.81331 .8302 L
s
1 .008 0 r
.008 w
.81331 .8302 Mdot
.016 w
.81331 .8302 m
.81328 .83024 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol7?NoAOol2?Nl:Ool00`00Oomoo`0JOol001ao
o`03001oogoo00Pmkm]oo`03001oogoo01]oo`0077oo00<007ooOol023g_fgoo00<007ooOol06goo
000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001eoo`03001oocg_00LmkmYoo`03001oogoo
01aoo`007Woo00<007oo?Nl01Sg_00=oocg_?Nl0eWoo00<007ooOol07Goo000NOol00`00Oolmk`05
?Nl00goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol001moo`03000mkcg_00@mk`03Oolmkcg_
008mkl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo00<003g_?Nl02Cg_`Goo13g_17oo1Cg_
1Woo00<007ooOol07Woo000POol;?No2Ool2?Nl3Ool7?Nl5Ool00`00Oomoo`0OOol0021oo`03000m
kcg_00Tmkl=oo`Xmk`Eoo`03001oogoo01moo`008Goo00<003g_?Nl023g_`goo2Sg_17oo00<007oo
Ool087oo000ROol00`00?Nlmk`02?Nl017oo?Nlmkcg_a7oo2Sg_0goo00<007ooOol08Goo000SOol0
1000Oomoogoo1Cg_`goo2Cg_0goo00<007ooOol08Woo000TOol00`00Oomoo`05?No7Ool4?Nl3Ool0
0`00Oomoo`0SOol002Aoo`04001oogooOol3?No9Ool3?Nl3Ool00`00Oomoo`0SOol002Eoo`03001o
ogoo00Qoo`8mkl1oo`Dmk`9oo`03001oogoo02Aoo`009Woo00<007ooOol01Goo1Cg__Woo13g_0goo
00<007ooOol09Goo000VOol00`00Oomoo`05Ool5?NnnOol4?Nl3Ool00`00Oomoo`0UOol002Moo`03
001oogoo00Aoo`Dmkk]oo`Hmk`=oo`03001oogoo02Ioo`00:7oo00<007ooOol00goo1Cg_^goo1cg_
00=oo`00Ool0:7oo000YOol00`00Oomoo`04Ool2?Nl00goo?Nmoo`2iOol7?Nl00`00Oomoo`0XOol0
02Yoo`04001oogooOol7?NmZOol2?Nm=Ool6?Nl00`00Oomoo`0YOol002Yoo`04001oogooOol8?NmX
Ool4?Nl<Ool4?NllOol6?Nl00`00Oomoo`0YOol002]oo`03001oogoo00PmkfQoo`@mk`aoo`Dmkc]o
o`Dmk`03001oogoo02Yoo`00;7oo00<007oo?Nl01cg_JGoo0Sg_3Goo1Cg_<7oo13g_17oo0Sg_1Goo
00<007ooOol0:goo000]Ool00`00Oomoo`02Ool4?NmhOol4?NlaOol5?Nl2Ool4?Nl3Ool00`00Oomo
o`0/Ool002ioo`04001oogooOol4?Nn]Ool5?Nl2Ool4?Nl2Ool00`00Oomoo`0]Ool002ioo`03001o
ogoo0;9oo`@mk`Aoo`8mk`=oo`03001oogoo02eoo`00;goo00<007ooOol0R7oo0Sg_9goo17`000<m
kgooOol01Goo00<007ooOol0;Woo000`Ool00`00Oomoo`26Ool4?NlUOol00g`PO01l0002O002?Nl5
Ool00`00Oomoo`0_Ool0035oo`03001oogoo00Eoo`@mkgaoo`@mkbEoo`03O21l07`0009l008mk`Ao
o`03001oogoo031oo`00<Woo0P001Goo1Cg_O7oo0Sg_9Woo00=l87`0O0000W`000@mkgooOomoo`80
03=oo`00=7oo00<007ooOol00Woo1Cg_MWoo13g_:Woo00=l87`0O0000W`00goo00<007ooOol0<goo
000eOol01000Oomoogoo13g_Mgoo1Cg_:Goo17j00goo00<007ooOol0=7oo000eOol01000Oomoogoo
13g_Mgoo1Cg_<7oo00<007ooOol0=7oo000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol0
03Moo`03001oogoo07Yoo`Dmkbioo`03001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<0
07ooOol0=goo000iOol2001jOol4?Nl[Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yo
o`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol0
03ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2000:Ool2?Nm[
Ool2?NlPOol20012Ool004=oo`03001oogoo00Aoo`HmkfUoo`@mka5oo`Dmk`Qoo`03001oogoo049o
o`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo13g_47oo1Sg_1goo00<007ooOol0@goo0015Ool0
1000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo1Sg_1Woo00<007ooOol0A7oo0016Ool20002Ool5?Nla
Ool4?Nm9Ool6?Nl4Ool20017Ool004Qoo`800003Oolmkcg_008mkc9oo`8mkdYoo`Dmk`=oo`8004Uo
o`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07mo
o`03001oogoo04eoo`00Cgoo00<007ooOol037oo0Sg_GWoo0Sg_3goo00<007ooOol0CWoo001@Ool2
000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0059oo`8000Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`80
05=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_0Woo2cg_17oo0P00EGoo001FOol20010Ool4?NlH
Ool@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMoo`@mkaQooa0mk`<005Uoo`00Fgoo0`003Woo1Cg_
>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7?NlgOol6?Nl5Ool=?NmNOol0061oo`8000Yoo`Pm
k`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061oo`00HWoo0`001goo2Cg_0goo1Sg_3goo0cg_6Woo
1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3Ool6?Nl>Ool6?NlJOol4?Nl7Ool3001VOol006Qo
o`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03Oolmkcg_01ioo`@006Uoo`00K7oo100027oo1Cg_
1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7OolB?NlEOol4001aOol007=oo`D000aoo`Xmk`05
Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L000Eoo`Xmk`04Oolmkcg_?Nl>Ool7001iOol007mo
o`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo0027Ool40004Ool300000goo000000030028Ool008Moo`03001oogoo00Ioo`03001oogoo009o
o`03001oogoo08Qoo`00R7oo00<007ooOol00Woo1@000goo00<007ooOol0R7oo0029Ool01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007ooOol0R7oo0027Ool01000Oomoo`000goo00<007oo0000
17oo00<007ooOol0R7oo0028Ool20005Ool20003Ool2002:Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(242)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
1 .977 0 r
.008 w
.23882 .87478 Mdot
.016 w
.23882 .87478 m
.23876 .87471 L
s
1 .953 0 r
.008 w
.23876 .87471 Mdot
.016 w
.23876 .87471 m
.2388 .87473 L
s
1 .93 0 r
.008 w
.2388 .87473 Mdot
.016 w
.2388 .87473 m
.23888 .8748 L
s
1 .907 0 r
.008 w
.23888 .8748 Mdot
.016 w
.23888 .8748 m
.23888 .87469 L
s
1 .884 0 r
.008 w
.23888 .87469 Mdot
.016 w
.23888 .87469 m
.23895 .87474 L
s
1 .86 0 r
.008 w
.23895 .87474 Mdot
.016 w
.23895 .87474 m
.23902 .87478 L
s
1 .837 0 r
.008 w
.23902 .87478 Mdot
.016 w
.23902 .87478 m
.23905 .87478 L
s
1 .814 0 r
.008 w
.23905 .87478 Mdot
.016 w
.23905 .87478 m
.23901 .87474 L
s
1 .791 0 r
.008 w
.23901 .87474 Mdot
.016 w
.23901 .87474 m
.23894 .87469 L
s
1 .767 0 r
.008 w
.23894 .87469 Mdot
.016 w
.23894 .87469 m
.23887 .87466 L
s
1 .744 0 r
.008 w
.23887 .87466 Mdot
.016 w
.23887 .87466 m
.23882 .87468 L
s
1 .721 0 r
.008 w
.23882 .87468 Mdot
.016 w
.23882 .87468 m
.23878 .87472 L
s
1 .698 0 r
.008 w
.23878 .87472 Mdot
.016 w
.23878 .87472 m
.23876 .87475 L
s
1 .674 0 r
.008 w
.23876 .87475 Mdot
.016 w
.23876 .87475 m
.23878 .87478 L
s
1 .651 0 r
.008 w
.23878 .87478 Mdot
.016 w
.23878 .87478 m
.23883 .87483 L
s
1 .628 0 r
.008 w
.23883 .87483 Mdot
.016 w
.23883 .87483 m
.2389 .87489 L
s
1 .605 0 r
.008 w
.2389 .87489 Mdot
.016 w
.2389 .87489 m
.23897 .87493 L
s
1 .581 0 r
.008 w
.23897 .87493 Mdot
.016 w
.23897 .87493 m
.23905 .87495 L
s
1 .558 0 r
.008 w
.23905 .87495 Mdot
.016 w
.23905 .87495 m
.23914 .87495 L
s
1 .535 0 r
.008 w
.23914 .87495 Mdot
.016 w
.23914 .87495 m
.23919 .87492 L
s
1 .512 0 r
.008 w
.23919 .87492 Mdot
.016 w
.23919 .87492 m
.23921 .87487 L
s
1 .488 0 r
.008 w
.23921 .87487 Mdot
.016 w
.23921 .87487 m
.2392 .87479 L
s
1 .465 0 r
.008 w
.2392 .87479 Mdot
.016 w
.2392 .87479 m
.23915 .87469 L
s
1 .442 0 r
.008 w
.23915 .87469 Mdot
.016 w
.23915 .87469 m
.23906 .87458 L
s
1 .419 0 r
.008 w
.23906 .87458 Mdot
.016 w
.23906 .87458 m
.23895 .87446 L
s
1 .395 0 r
.008 w
.23895 .87446 Mdot
.016 w
.23895 .87446 m
.23888 .87435 L
s
1 .372 0 r
.008 w
.23888 .87435 Mdot
.016 w
.23888 .87435 m
.23884 .87427 L
s
1 .349 0 r
.008 w
.23884 .87427 Mdot
.016 w
.23884 .87427 m
.23882 .87419 L
s
1 .326 0 r
.008 w
.23882 .87419 Mdot
.016 w
.23882 .87419 m
.23883 .87413 L
s
1 .302 0 r
.008 w
.23883 .87413 Mdot
.016 w
.23883 .87413 m
.23886 .8741 L
s
1 .279 0 r
.008 w
.23886 .8741 Mdot
.016 w
.23886 .8741 m
.23889 .87409 L
s
1 .256 0 r
.008 w
.23889 .87409 Mdot
.016 w
.23889 .87409 m
.23891 .87404 L
s
1 .233 0 r
.008 w
.23891 .87404 Mdot
.016 w
.23891 .87404 m
.23893 .87398 L
s
1 .209 0 r
.008 w
.23893 .87398 Mdot
.016 w
.23893 .87398 m
.23899 .87392 L
s
1 .186 0 r
.008 w
.23899 .87392 Mdot
.016 w
.23899 .87392 m
.23909 .87388 L
s
1 .163 0 r
.008 w
.23909 .87388 Mdot
.016 w
.23909 .87388 m
.23923 .87384 L
s
1 .14 0 r
.008 w
.23923 .87384 Mdot
.016 w
.23923 .87384 m
.2394 .8738 L
s
1 .116 0 r
.008 w
.2394 .8738 Mdot
.016 w
.2394 .8738 m
.2396 .87376 L
s
1 .093 0 r
.008 w
.2396 .87376 Mdot
.016 w
.2396 .87376 m
.23978 .87373 L
s
1 .07 0 r
.008 w
.23978 .87373 Mdot
.016 w
.23978 .87373 m
.23993 .8737 L
s
1 .047 0 r
.008 w
.23993 .8737 Mdot
.016 w
.23993 .8737 m
.24001 .8737 L
s
1 .023 0 r
.008 w
.24001 .8737 Mdot
.016 w
.24001 .8737 m
.24006 .87376 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`Dmk`Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo1Cg_1goo00<007ooOol05Goo
000EOol00`00Oomoo`05Ool6?NoVOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`DmknMoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1Cg_igoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool5?NoXOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007oo
Ool0igoo13g_27oo00<007ooOol04goo000COol00`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol0
01=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019oo`004goo00<007ooOol0j7oo13g_2Goo00<0
07ooOol04Woo000BOol00`00Oomoo`3YOol4?Nl:Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol02Goo0Sg_
kWoo00<007ooOol047oo000AOol00`00Oomoo`08Ool4?NlnOol2?Nn^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_?Goo
13g_[Goo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?NlmOol2?Nn^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`Hmkneoo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Tmknaoo`03001oogoo
00eoo`003Woo00<007ooOol02Woo2Sg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool8?No[
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknIoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00ioo`dmkmQoo`8mk`aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoFOol5?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`dmkmMoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol037oo
3Sg_1Goo0Sg_d7oo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool@?Nl4Ool4?No?Ool4
?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Xmk`=oo`Dmk`Aoo`@mkmmoo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_17oo0Sg_27oo0Sg_h7oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool9?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Xmk`=oo`@mknUo
o`03001oogoo00aoo`0037oo00<007ooOol01goo2Sg_1Goo0Sg_jgoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo
00]oo`0037oo00<007ooOol01goo23g_m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:
Ool4?NoWOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaeoo`8mklQoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_77oo13g_agoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl;Ool2?NlMOol4?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
kb]oo`8mklQoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmka1oo`8mkn=oo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl?Ool4?NoROol00`00Oomoo`0;Ool000eoo`03001oogoo00Moo`Dmka5oo`8mkn=o
o`03001oogoo00]oo`003Goo00<007ooOol01goo1Cg_mGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool4?NofOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mknYoo`8mk`Yoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_j7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool6?Nl?Ool4?NoDOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Dmkm=o
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo1Cg_dWoo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Dmk`moo`@mkm=oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_
iWoo1Sg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NoVOol5?Nl:Ool00`00Oomoo`0<
Ool000ioo`03001oogoo0?5oo`Dmk`Uoo`03001oogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo
00<007ooOol03Goo000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Uoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo13g_lWoo00<007ooOol03Goo000?
Ool00`00Oomoo`08Ool5?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@mkeeoo`8mki5o
o`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000?Ool0
0`00Oomoo`08Ool5?NmLOol4?Nn@Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmkeeoo`8m
ki5oo`03001oogoo00ioo`0047oo00<007ooOol01goo1Cg_kgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool2?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`DmkaIoo`03001oogoo00mo
o`0047oo00<007ooOol0h7oo1Sg_5Goo00<007ooOol03goo000AOol00`00Oomoo`08Ool3?NoDOol6
?NlEOol00`00Oomoo`0?Ool0015oo`03001oogoo00Moo`Dmkm=oo`DmkaEoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Cg_dgoo13g_5Woo00<007ooOol047oo000BOol00`00Oomoo`07Ool3?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0;ioo`8mkcMoo`03001oogoo015oo`004Woo00<007oo
Ool0_Goo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`2lOol4?NlfOol00`00Oomoo`0AOol0
01=oo`03001oogoo03Moo`8mkhAoo`8mkcIoo`03001oogoo019oo`004goo00<007ooOol0=Woo13g_
^goo00<007ooOol04Woo000DOol00`00Oomoo`0eOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00Eoo`@mkbeoo`8mkk]oo`03001oogoo01=oo`0057oo00<007ooOol01Goo1Cg_jGoo00<007oo
Ool04goo000EOol00`00Oomoo`04Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`@m
knUoo`03001oogoo01Aoo`005Goo00<007ooOol017oo13g_17oo0Sg_hgoo00<007ooOol057oo000E
Ool00`00Oomoo`0:Ool5?NoROol00`00Oomoo`0DOol001Ioo`03001oogoo00Uoo`DmkmAoo`8mk`]o
o`03001oogoo01Eoo`005Woo00<007ooOol02Goo1Cg_dgoo13g_2Woo00<007ooOol05Goo000GOol0
0`00Oomoo`08Ool5?NoCOol4?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo0>1oo`@mk`Uoo`03
001oogoo01Ioo`0067oo00<007ooOol017oo0Sg_fWoo0Sg_2Goo00<007ooOol05goo000HOol00`00
Oomoo`03Ool5?NllOol3?NnEOol7?Nl8Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYo
o`DmkiAoo`Hmk`Uoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_Tgoo1Sg_2Goo
00<007ooOol067oo000JOol01000Oomoogoo1Cg_?7oo0cg_U7oo1Cg_2Woo00<007ooOol067oo000J
Ool00`00Oomoo`02Ool5?NoBOol5?Nl9Ool00`00Oomoo`0IOol001]oo`04001oogooOol5?NoBOol5
?Nl8Ool00`00Oomoo`0JOol001]oo`04001oogooOol7?NoAOol2?Nl:Ool00`00Oomoo`0JOol001ao
o`03001oogoo00Pmkm]oo`03001oogoo01]oo`0077oo00<007ooOol023g_fgoo00<007ooOol06goo
000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001eoo`03001oocg_00LmkmYoo`03001oogoo
01aoo`007Woo00<007oo?Nl01Sg_00=oocg_?Nl0eWoo00<007ooOol07Goo000NOol00`00Oolmk`05
?Nl00goo?Nlmk`02?No2Ool2?NlAOol00`00Oomoo`0MOol001moo`03000mkcg_00@mk`03Oolmkcg_
008mkl5oo`@mk`Eoo`<mk`Moo`03001oogoo01ioo`007goo00<003g_?Nl02Cg_`Goo13g_17oo1Cg_
1Woo00<007ooOol07Woo000POol;?No2Ool2?Nl3Ool7?Nl5Ool00`00Oomoo`0OOol0021oo`03000m
kcg_00Tmkl=oo`Xmk`Eoo`03001oogoo01moo`008Goo00<003g_?Nl023g_`goo2Sg_17oo00<007oo
Ool087oo000ROol00`00?Nlmk`02?Nl017oo?Nlmkcg_a7oo2Sg_0goo00<007ooOol08Goo000SOol0
1000Oomoogoo1Cg_`goo2Cg_0goo00<007ooOol08Woo000TOol00`00Oomoo`05?No7Ool4?Nl3Ool0
0`00Oomoo`0SOol002Aoo`04001oogooOol3?No9Ool3?Nl3Ool00`00Oomoo`0SOol002Eoo`03001o
ogoo00Qoo`8mkl1oo`Dmk`9oo`03001oogoo02Aoo`009Woo00<007ooOol01Goo1Cg__Woo13g_0goo
00<007ooOol09Goo000VOol00`00Oomoo`05Ool5?NnnOol4?Nl3Ool00`00Oomoo`0UOol002Moo`03
001oogoo00Aoo`Dmkk]oo`Hmk`=oo`03001oogoo02Ioo`00:7oo00<007ooOol00goo1Cg_^goo1cg_
00=oo`00Ool0:7oo000YOol00`00Oomoo`04Ool2?Nl00goo?Nmoo`2iOol7?Nl00`00Oomoo`0XOol0
02Yoo`04001oogooOol7?NmZOol2?Nm=Ool6?Nl00`00Oomoo`0YOol002Yoo`04001oogooOol8?NmX
Ool4?Nl<Ool4?NllOol6?Nl00`00Oomoo`0YOol002]oo`03001oogoo00PmkfQoo`@mk`aoo`Dmkc]o
o`Dmk`03001oogoo02Yoo`00;7oo00<007oo?Nl01cg_JGoo0Sg_3Goo1Cg_<7oo13g_17oo0Sg_1Goo
00<007ooOol0:goo000]Ool00`00Oomoo`02Ool4?NmhOol4?NlaOol5?Nl2Ool4?Nl3Ool00`00Oomo
o`0/Ool002ioo`04001oogooOol4?Nn]Ool5?Nl2Ool4?Nl2Ool00`00Oomoo`0]Ool002ioo`03001o
ogoo0;9oo`@mk`Aoo`8mk`=oo`03001oogoo02eoo`00;goo00<007ooOol0R7oo0Sg_9goo1Cg_1goo
00<007ooOol0;Woo000`Ool00`00Oomoo`26Ool4?NlUOol7?Nl5Ool00`00Oomoo`0_Ool0035oo`03
001oogoo00Eoo`@mkgaoo`@mkbEoo`Lmk`Aoo`03001oogoo031oo`00<Woo0P001Goo1Cg_O7oo0Sg_
9Woo1Sg_0goo0P00<goo000dOol00`00Oomoo`02Ool5?NmfOol4?NlZOol5?Nl3Ool00`00Oomoo`0c
Ool003Eoo`04001oogooOol4?NmgOol5?NlZOol3?Nl3Ool00`00Oomoo`0dOol003Eoo`04001oogoo
Ool4?NmgOol5?Nl`Ool00`00Oomoo`0dOol003Ioo`03001oogoo07]oo`Dmkbmoo`03001oogoo03Eo
o`00=goo00<007ooOol0NWoo1Cg_;Woo00<007ooOol0=Woo000hOol00`00Oomoo`1iOol5?Nl]Ool0
0`00Oomoo`0gOol003Uoo`8007Yoo`@mkb]oo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0
>Woo000lOol00`00Oomoo`06Ool2O602O2000gaPOomoo`2FOol00`00Oomoo`0kOol003eoo`03001o
ogoo00Eoo`03O61l87`0009l89Moo`03001oogoo03aoo`00?Woo0P001Goo00=lH7`PO0000W`PUGoo
0P00?goo0010Ool00`00Oomoo`02Ool2O602O2000gaPOomoo`2BOol00`00Oomoo`0oOol0045oo`80
009oo`Am80Aoo`8mkf]oo`8mkb1oo`80049oo`00@goo00<007ooOol017oo1Sg_JGoo13g_4Goo1Cg_
27oo00<007ooOol0@Woo0014Ool00`00Oomoo`02Ool7?NlaOol2?NlfOol4?Nl@Ool6?Nl7Ool00`00
Oomoo`13Ool004Eoo`04001oogooOol6?NlaOol4?NlfOol2?NlAOol6?Nl6Ool00`00Oomoo`14Ool0
04Ioo`80009oo`Dmkc5oo`@mkdUoo`Hmk`Aoo`8004Moo`00B7oo0P0000=oocg_?Nl00Sg_<Woo0Sg_
BWoo1Cg_0goo0P00BGoo001:Ool00`00?Nlmk`02?Nn4Ool2001;Ool004aoo`8008=oo`8004eoo`00
CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`0<Ool2?NmNOol2?Nl?Ool00`00
Oomoo`1>Ool0051oo`8000]oo`@mkcMoo`@mkb5oo`Lmk`Uoo`80055oo`00DWoo0P002Goo13g_=goo
13g_87oo2Cg_1Woo0P00Dgoo001DOol20008Ool2?NlhOol4?NlIOol3?Nl2Ool;?Nl4Ool2001EOol0
05Ioo`80041oo`@mkaQooa0mk`=oo`8005Moo`00F7oo0`004Goo1Cg_9goo13g_67oo43g_0`00FGoo
001KOol3000>Ool5?NliOol6?Nl4Ool>?Nl2001LOol005ioo`8000aoo`LmkcMoo`Hmk`Eoo`dmkeio
o`00H7oo0P002Woo23g_17oo1Cg_;Goo1Sg_1Woo1cg_00<007ooOol0H7oo001ROol30007Ool9?Nl3
Ool6?Nl?Ool3?NlJOol6?Nl6Ool5?Nl2001SOol006Eoo`<000Qoo`Dmk`=oo`Hmk`ioo`HmkaYoo`@m
k`Moo`<006Ioo`00J7oo100017oo13g_17oo1Cg_27oo0cg_17oo1Sg_00=oocg_?Nl07Woo1000JGoo
001/Ool40008Ool5?Nl7OolB?NlIOol4001]Ool0071oo`<000Ioo`@mk`Mooa8mkaEoo`@0075oo`00
Lgoo1@0037oo2Sg_00Eoocg_?Nlmkgoo008mka9oo`@007Eoo`00N7oo1`001Goo2Sg_00Aoocg_?Nlm
k`ioo`L007Uoo`00Ogoo1@002Sg_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol008Moo`@000Aoo`<00003Ool00000008008Uoo`00Qgoo00<007ooOol0
1Woo00@007ooOol008aoo`00R7oo00<007ooOol00Woo1@000Woo00<007ooOol0RGoo0029Ool01@00
Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0R7oo0027Ool01000Oomoo`000goo00<007oo
00000Woo00@007ooOol008Uoo`00R7oo0P001Goo0P000goo0P00RWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(243)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
.23882 .87478 m
.23876 .87471 L
.2388 .87473 L
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
s
1 .909 0 r
.008 w
.90793 .32161 Mdot
.016 w
.90793 .32161 m
.908 .32184 L
s
1 .818 0 r
.008 w
.908 .32184 Mdot
.016 w
.908 .32184 m
.90807 .32232 L
s
1 .727 0 r
.008 w
.90807 .32232 Mdot
.016 w
.90807 .32232 m
.90814 .32296 L
s
1 .636 0 r
.008 w
.90814 .32296 Mdot
.016 w
.90814 .32296 m
.90822 .32368 L
s
1 .545 0 r
.008 w
.90822 .32368 Mdot
.016 w
.90822 .32368 m
.90833 .32442 L
s
1 .455 0 r
.008 w
.90833 .32442 Mdot
.016 w
.90833 .32442 m
.90845 .32507 L
s
1 .364 0 r
.008 w
.90845 .32507 Mdot
.016 w
.90845 .32507 m
.90856 .32563 L
s
1 .273 0 r
.008 w
.90856 .32563 Mdot
.016 w
.90856 .32563 m
.90867 .32605 L
s
1 .182 0 r
.008 w
.90867 .32605 Mdot
.016 w
.90867 .32605 m
.90875 .32633 L
s
1 .091 0 r
.008 w
.90875 .32633 Mdot
.016 w
.90875 .32633 m
.90877 .32643 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000Qoo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo00<007oo
Ool01Woo1Cg_HGoo0Sg_47oo13g_1Goo13g_00<007ooOol0Agoo0016Ool20009Ool5?NmPOol4?Nl?
Ool4?Nl5Ool5?Nl20017Ool004Eoo`03001oogoo00Uoo`Dmkf1oo`@mkaQoo`PmkdIoo`00A7oo00<0
07ooOol00Sg_27oo1Cg_HGoo1Sg_5Goo2Cg_AGoo0013Ool00`00Oomoo`04?Nm^Ool5?NlEOol:?Nm4
Ool0045oo`80009oo`Hmkfeoo`DmkaEoo`dmkd5oo`00@7oo00<007ooOol023g_KGoo1Cg_5Goo3Sg_
@7oo000oOol00`00Oomoo`08?Nl4Ool2?NmXOol5?NlKOol8?Nl00`00Oomoo`0mOol003ioo`04001o
ogooOol7?Nl4Ool4?NmVOol6?NlKOol8?Nl00goo001oo`0mOol003aoo`8000Aoo`Dmk`Ioo`@mkfIo
o`Dmkb5oo`Dmk`03001oogoo03]oo`00>goo00<007ooOol017oo1Cg_1Woo13g_IWoo1Cg_8Goo1Cg_
00=oo`00Ool0>goo000jOol00`00Oomoo`05Ool4?Nl8Ool2?NmWOol5?NlQOol5?Nl2Ool2000jOol0
03Uoo`04001oocg_?Nl5Ool4?NmaOol4?NlROol5?Nl4Ool00`00Oomoo`0gOol003Moo`800003Oolm
kcg_008mkgUoo`@mkb9oo`Pmk`9oo`03001oogoo03Ioo`00=Woo00@007ooOomoo`@mkimoo`Tmk`9o
o`03001oogoo03Eoo`00=Goo00<007ooOol00Woo13g_TGoo13g_3Woo1Cg_0goo00<007ooOol0=7oo
000dOol00`00Oomoo`04Ool6?Nn>Ool5?Nl=Ool4?Nl5Ool00`00Oomoo`0cOol0039oo`8000Qoo`Dm
khioo`Dmk`eoo`@mk`Ioo`03001oogoo039oo`00<Goo00<007ooOol027oo1Cg_SWoo1Cg_67oo00<0
07ooOol0<Goo000`Ool00`00Oomoo`08Ool6?Nn>Ool5?Nl@Ool5?Nl4Ool00`00Oomoo`0`Ool0031o
o`03001oogoo00Moo`DmkjEoo`Dmk`Eoo`03001oogoo02moo`00;goo00<007ooOol027oo1Cg_YGoo
1Cg_1Woo00<007ooOol0;Woo000^Ool00`00Oomoo`04Ool:?NnUOol5?Nl7Ool00`00Oomoo`0]Ool0
02eoo`03001oogoo00Eoo`XmkjIoo`Dmk`Moo`03001oogoo02aoo`00;7oo00<007ooOol01Woo1cg_
ZWoo1Cg_1goo00<007ooOol0:goo000/Ool00`00Oomoo`06Ool7?NnZOol6?Nl6Ool00`00Oomoo`0[
Ool002]oo`03001oogoo00Moo`Lmkj]oo`Dmk`Moo`03001oogoo02Yoo`00:Woo00<007ooOol02Goo
0Sg_/7oo1Cg_1goo00<007ooOol0:Goo000YOol00`00Oomoo`2lOol5?Nl8Ool00`00Oomoo`0XOol0
02Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`00:7oo00<007ooOol0_Goo1Cg_2Goo00<0
07ooOol09goo000WOol00`00Oomoo`2`Ool2?NlKOol00`00Oomoo`0VOol002Ioo`03001oogoo0;1o
o`@mka]oo`03001oogoo02Eoo`009Goo00<007ooOol0/Goo13g_4Woo0Sg_27oo00<007ooOol097oo
000TOol00`00Oomoo`2cOol2?NlBOol4?Nl8Ool00`00Oomoo`0SOol002Aoo`03001oogoo0<Moo`@m
k`Qoo`03001oogoo02=oo`008goo00<007ooOol0bGoo0Sg_00Aoocg_?Nlmk`Ioo`03001oogoo029o
o`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000ROol00`00Oomoo`3<Ool5?Nl6Ool0
0`00Oomoo`0QOol0025oo`03001oogoo0<ioo`<mk`Qoo`03001oogoo021oo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gWoo00<007ooOol07Goo000NOol00`00Oomoo`3DOol4
?Nl7Ool00`00Oomoo`0MOol001eoo`03001oogoo03Eoo`@mki]oo`Hmk`Moo`03001oogoo01aoo`00
7Goo00<007ooOol0=Goo1Cg_Ugoo2Cg_1goo00<007ooOol077oo000LOol00`00Oomoo`0fOol5?NnG
Ool9?Nl8Ool00`00Oomoo`0KOol001aoo`03001oogoo03Ioo`DmkiMoo`Tmk`Qoo`03001oogoo01]o
o`006goo00<007ooOol0=goo1Cg_Ugoo13g_0Woo1Cg_1goo00<007ooOol06Woo000KOol00`00Oomo
o`3IOol5?Nl7Ool00`00Oomoo`0JOol001Yoo`03001oogoo00Moo`8mkm5oo`Lmk`Ioo`03001oogoo
01Uoo`006Woo00<007ooOol01Woo13g_d7oo23g_1Goo00<007ooOol06Goo000IOol00`00Oomoo`07
Ool4?No@Ool8?Nl6Ool00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`@mkeaoo`@mkg=oo`Hmk`Io
o`03001oogoo01Qoo`0067oo00<007ooOol01Woo13g_@goo0Sg_67oo13g_Lgoo1cg_1Woo00<007oo
Ool05goo000HOol00`00Oomoo`06Ool4?Nm2Ool4?NlGOol4?NmdOol6?Nl6Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo00Eoo`@mkd9oo`DmkaMoo`@mkgAoo`Lmk`Eoo`03001oogoo01Moo`005goo00<0
07ooOol01Goo13g_@goo1Sg_5Woo13g_M7oo1cg_1Woo00<007ooOol05Woo000GOol00`00Oomoo`04
Ool5?Nm4Ool5?Nn>Ool7?Nl6Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`DmkdAoo`@mki5o
o`03?Nmn87hP009n80Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo1Sg_fGoo00DmkghPOR1m
07hP00Moo`03001oogoo01Eoo`005Goo00<007ooOol01Goo1Sg_fWoo0WhP00=l@7hPOol01goo00<0
07ooOol057oo000EOol00`00Oomoo`05Ool5?NoKOol2OR000ga0OR1oo`07Ool00`00Oomoo`0DOol0
01Eoo`03001oogoo00Eoo`Dmkm]oo`An80Qoo`03001oogoo01Aoo`0057oo00<007ooOol01Woo1Cg_
j7oo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0>Mo
o`@mk`Qoo`03001oogoo01=oo`004goo00<007ooOol0j7oo13g_2Goo00<007ooOol04Woo000COol0
0`00Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol001=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo
019oo`004Woo00<007ooOol0jGoo13g_2Woo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00
Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo00Uoo`8mknioo`03
001oogoo011oo`004Goo00<007ooOol027oo13g_?Woo0Sg_[Woo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5?NlmOol4?Nn]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmkceoo`@mkjeo
o`03001oogoo00moo`0047oo00<007ooOol027oo1Sg_?Goo0Sg_[Woo00<007ooOol03goo000@Ool0
0`00Oomoo`08Ool6?No]Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo
00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool8?No/
Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003goo00<007oo
Ool02Goo1cg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool9?No/Ool00`00Oomoo`0=Ool0
00ioo`03001oogoo00Yoo`Xmkn]oo`03001oogoo00eoo`003Woo00<007ooOol037oo23g_jgoo00<0
07ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoVOol00`00Oomoo`0=Ool000ioo`03001oogoo00eo
o`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0>Ool=?NoHOol2?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmkmIoo`Dm
k`]oo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_eWoo1Cg_2goo00<007ooOol037oo000=
Ool00`00Oomoo`0=Ool=?NoGOol5?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`hmk`Eo
o`8mkm1oo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol02Woo43g_17oo13g_cgoo13g_37oo
00<007ooOol037oo000=Ool00`00Oomoo`08Ool:?Nl3Ool5?Nl4Ool4?NoOOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qoo`Tmk`Aoo`8mk`Qoo`8mkn1oo`03001oogoo00aoo`003Goo00<007ooOol0
27oo2Cg_0goo13g_jGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool:?Nl3Ool4?NoYOol00`00
Oomoo`0<Ool000aoo`03001oogoo00Moo`Xmk`Eoo`8mkn]oo`03001oogoo00]oo`0037oo00<007oo
Ool027oo23g_lgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Moo`PmkoAoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_
igoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:Ool4?NlMOol2?No8Ool00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaaoo`@mklMoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Sg_2goo0Sg_7Goo13g_agoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl[Ool2
?No8Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl@Ool2?NoSOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`Hmk`moo`@mkn9oo`03001oogoo00]oo`0037oo00<007ooOol0
27oo1Sg_3goo13g_hWoo00<007ooOol02goo000=Ool00`00Oomoo`07Ool5?NlAOol2?NoSOol00`00
Oomoo`0;Ool000eoo`03001oogoo00Moo`DmkoEoo`03001oogoo00aoo`003Goo00<007ooOol01goo
13g_mWoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool4?NoZOol2?Nl:Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Moo`DmknQoo`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Sg_
3goo13g_e7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07Ool6?Nl?Ool5?NoCOol4?Nl9
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Dmkm9oo`Dmk`Uoo`03001oogoo00ao
o`003Goo00<007ooOol027oo1Cg_3goo13g_dgoo1Cg_2Goo00<007ooOol037oo000=Ool00`00Oomo
o`08Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mknIoo`Hm
k`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_iWoo1Cg_2Woo00<007ooOol037oo000>
Ool00`00Oomoo`3aOol5?Nl9Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?5oo`@mk`Yoo`03001o
ogoo00eoo`003Woo00<007ooOol0lGoo13g_2Woo00<007ooOol03Goo000>Ool00`00Oomoo`09Ool4
?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Qoo`@mko9oo`03001oogoo00eoo`003goo00<0
07ooOol027oo1Cg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4?NmMOol2?NnAOol00`00
Oomoo`0>Ool000moo`03001oogoo00Qoo`Dmkeaoo`@mki1oo`03001oogoo00ioo`003goo00<007oo
Ool027oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000@Ool00`00Oomoo`07Ool5?NmMOol2?NnAOol0
0`00Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmknmoo`03001oogoo00moo`0047oo00<007ooOol0
27oo0Sg_lGoo00<007ooOol03goo000@Ool00`00Oomoo`3POol5?NlFOol00`00Oomoo`0?Ool0011o
o`03001oogoo0>1oo`HmkaEoo`03001oogoo00moo`004Goo00<007ooOol027oo0cg_e7oo1Sg_5Goo
00<007ooOol03goo000AOol00`00Oomoo`07Ool5?NoCOol5?NlEOol00`00Oomoo`0@Ool0015oo`03
001oogoo00Moo`Dmkm=oo`@mkaIoo`03001oogoo011oo`004Woo00<007ooOol01goo0cg_kWoo00<0
07ooOol047oo000BOol00`00Oomoo`2nOol2?NlgOol00`00Oomoo`0AOol0019oo`03001oogoo0;eo
o`@mkcIoo`03001oogoo015oo`004goo00<007ooOol0_7oo13g_=Woo00<007ooOol04Goo000COol0
0`00Oomoo`0gOol2?Nn4Ool2?NlfOol00`00Oomoo`0BOol001=oo`03001oogoo03Ioo`@mkk]oo`03
001oogoo019oo`0057oo00<007ooOol0=Goo13g_^goo00<007ooOol04Woo000DOol00`00Oomoo`05
Ool4?Nl]Ool2?NnkOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`DmknUoo`03001oogoo01=o
o`005Goo00<007ooOol017oo1Cg_jGoo00<007ooOol04goo000EOol00`00Oomoo`04Ool4?NoYOol0
0`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`@mk`Aoo`8mkn=oo`03001oogoo01Aoo`005Goo00<0
07ooOol02Woo1Cg_hWoo00<007ooOol057oo000FOol00`00Oomoo`09Ool5?NoDOol2?Nl;Ool00`00
Oomoo`0EOol001Ioo`03001oogoo00Uoo`Dmkm=oo`@mk`Yoo`03001oogoo01Eoo`005goo00<007oo
Ool027oo1Cg_dgoo13g_2Goo00<007ooOol05Woo000GOol00`00Oomoo`3POol4?Nl9Ool00`00Oomo
o`0FOol001Qoo`03001oogoo00Aoo`8mkmYoo`8mk`Uoo`03001oogoo01Moo`0067oo00<007ooOol0
0goo1Cg_?7oo0cg_UGoo1cg_27oo00<007ooOol05goo000IOol00`00Oomoo`02Ool6?NljOol5?NnD
Ool6?Nl9Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYoo`Dmki=oo`Hmk`Uoo`03001o
ogoo01Qoo`006Woo00@007ooOomoo`Dmkcaoo`<mkiAoo`Dmk`Yoo`03001oogoo01Qoo`006Woo00<0
07ooOol00Woo1Cg_dWoo1Cg_2Goo00<007ooOol06Goo000KOol01000Oomoogoo1Cg_dWoo1Cg_27oo
00<007ooOol06Woo000KOol01000Oomoogoo1cg_dGoo0Sg_2Woo00<007ooOol06Woo000LOol00`00
Oomoo`08?NoKOol00`00Oomoo`0KOol001aoo`03001oogoo00Pmkm]oo`03001oogoo01]oo`007Goo
00<007oo?Nl01cg_fWoo00<007ooOol077oo000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol0
01ioo`03001oocg_00Hmk`03Oolmkcg_0=Ioo`03001oogoo01eoo`007Woo00<007oo?Nl01Cg_00=o
ocg_?Nl00Sg_`Woo0Sg_4Goo00<007ooOol07Goo000OOol00`00?Nlmk`04?Nl00goo?Nlmk`02?No1
Ool4?Nl5Ool3?Nl7Ool00`00Oomoo`0NOol001moo`03000mkcg_00Tmkl5oo`@mk`Aoo`Dmk`Ioo`03
001oogoo01ioo`0087oo2cg_`Woo0Sg_0goo1cg_1Goo00<007ooOol07goo000POol00`00?Nlmk`09
?No3Ool:?Nl5Ool00`00Oomoo`0OOol0025oo`03000mkcg_00Pmkl=oo`Xmk`Aoo`03001oogoo021o
o`008Woo00<003g_?Nl00Sg_00Aoocg_?NlmklAoo`Xmk`=oo`03001oogoo025oo`008goo00@007oo
Oomoo`Dmkl=oo`Tmk`=oo`03001oogoo029oo`0097oo00<007ooOol01Cg_agoo13g_0goo00<007oo
Ool08goo000TOol01000Oomoogoo0cg_bGoo0cg_0goo00<007ooOol08goo000UOol00`00Oomoo`08
Ool2?No0Ool5?Nl2Ool00`00Oomoo`0TOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001o
ogoo02Eoo`009Woo00<007ooOol01Goo1Cg__Woo13g_0goo00<007ooOol09Goo000WOol00`00Oomo
o`04Ool5?NnkOol6?Nl3Ool00`00Oomoo`0VOol002Qoo`03001oogoo00=oo`Dmkk]oo`Lmk`03Ool0
07oo02Qoo`00:Goo00<007ooOol017oo0Sg_00=oocg_Ool0^Goo1cg_00<007ooOol0:7oo000ZOol0
1000Oomoogoo1cg_JWoo0Sg_CGoo1Sg_00<007ooOol0:Goo000ZOol01000Oomoogoo23g_J7oo13g_
37oo13g_?7oo1Sg_00<007ooOol0:Goo000[Ool00`00Oomoo`08?NmXOol4?Nl<Ool5?NlkOol5?Nl0
0`00Oomoo`0ZOol002aoo`03001oocg_00LmkfUoo`8mk`eoo`Dmkc1oo`@mk`Aoo`8mk`Eoo`03001o
ogoo02]oo`00;Goo00<007ooOol00Woo13g_N7oo13g_<Goo1Cg_0Woo13g_0goo00<007ooOol0;7oo
000^Ool01000Oomoogoo13g_[Goo1Cg_0Woo13g_0Woo00<007ooOol0;Goo000^Ool00`00Oomoo`2b
Ool4?Nl4Ool2?Nl3Ool00`00Oomoo`0]Ool002moo`03001oogoo08Qoo`8mkbMoo`Dmk`Moo`03001o
ogoo02ioo`00<7oo00<007ooOol0QWoo13g_9Goo1cg_1Goo00<007ooOol0;goo000aOol00`00Oomo
o`05Ool4?NmlOol4?NlUOol7?Nl4Ool00`00Oomoo`0`Ool0039oo`8000Eoo`Dmkgaoo`8mkbIoo`Hm
k`=oo`8003=oo`00=7oo00<007ooOol00Woo1Cg_MWoo13g_:Woo1Cg_0goo00<007ooOol0<goo000e
Ool01000Oomoogoo13g_Mgoo1Cg_:Woo0cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo13g_
Mgoo1Cg_<7oo00<007ooOol0=7oo000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol003Mo
o`03001oogoo07Yoo`Dmkbioo`03001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<007oo
Ool0=goo000iOol2001jOol4?Nl[Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00
?7oo00<007ooOol01Woo1Cg_V7oo00<007ooOol0>goo000mOol00`00Oomoo`05Ool5?NnGOol00`00
Oomoo`0lOol003ioo`8000Eoo`DmkiEoo`8003moo`00@7oo00<007ooOol00Woo1Cg_U7oo00<007oo
Ool0?goo0011Ool20002Ool4?Nl4Ool2?Nm[Ool2?NlPOol20012Ool004=oo`03001oogoo00Aoo`Hm
kfUoo`@mka5oo`Dmk`Qoo`03001oogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo13g_
47oo1Sg_1goo00<007ooOol0@goo0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo1Sg_1Woo
00<007ooOol0A7oo0016Ool20002Ool5?NlaOol4?Nm9Ool6?Nl4Ool20017Ool004Qoo`800003Oolm
kcg_008mkc9oo`8mkdYoo`Dmk`=oo`8004Uoo`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<Ool2
0023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol037oo0Sg_
GWoo0Sg_3goo00<007ooOol0CWoo001@Ool2000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0059o
o`8000Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`8005=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_0Woo
2cg_17oo0P00EGoo001FOol20010Ool4?NlHOol@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMoo`@m
kaQooa0mk`<005Uoo`00Fgoo0`003Woo1Cg_>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7?Nlg
Ool6?Nl5Ool=?NmNOol0061oo`8000Yoo`Pmk`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061oo`00
HWoo0`001goo2Cg_0goo1Sg_3goo0cg_6Woo1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3Ool6
?Nl>Ool6?NlJOol4?Nl7Ool3001VOol006Qoo`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03Oolm
kcg_01ioo`@006Uoo`00K7oo100027oo1Cg_1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7OolB
?NlEOol4001aOol007=oo`D000aoo`Xmk`05Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L000Eo
o`Xmk`04Oolmkcg_?Nl>Ool7001iOol007moo`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0027Ool40004Ool30002Ool2002:Ool008Moo`03
001oogoo00Ioo`04001oogoo0002Ool00`00Oomoo`27Ool008Qoo`03001oogoo009oo`D000=oo`03
001oogoo08Qoo`00RGoo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo08Moo`00Qgoo
00@007ooOol000=oo`03001oo`00009oo`04001oogoo0029Ool008Qoo`8000Eoo`8000=oo`8008Yo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(244)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
.23882 .87478 m
.23876 .87471 L
.2388 .87473 L
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
s
.90793 .32161 m
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
s
1 .964 0 r
.008 w
.26343 .10379 Mdot
.016 w
.26343 .10379 m
.26345 .10379 L
s
1 .929 0 r
.008 w
.26345 .10379 Mdot
.016 w
.26345 .10379 m
.2636 .10369 L
s
1 .893 0 r
.008 w
.2636 .10369 Mdot
.016 w
.2636 .10369 m
.26382 .10356 L
s
1 .857 0 r
.008 w
.26382 .10356 Mdot
.016 w
.26382 .10356 m
.26404 .1034 L
s
1 .821 0 r
.008 w
.26404 .1034 Mdot
.016 w
.26404 .1034 m
.26423 .10327 L
s
1 .786 0 r
.008 w
.26423 .10327 Mdot
.016 w
.26423 .10327 m
.26435 .10317 L
s
1 .75 0 r
.008 w
.26435 .10317 Mdot
.016 w
.26435 .10317 m
.26439 .10313 L
s
1 .714 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .679 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .643 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .607 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .571 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .536 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .5 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .464 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .429 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .393 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .357 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .321 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.26439 .10313 L
s
1 .286 0 r
.008 w
.26439 .10313 Mdot
.016 w
.26439 .10313 m
.2644 .10313 L
s
1 .25 0 r
.008 w
.2644 .10313 Mdot
.016 w
.2644 .10313 m
.26446 .10311 L
s
1 .214 0 r
.008 w
.26446 .10311 Mdot
.016 w
.26446 .10311 m
.26458 .10306 L
s
1 .179 0 r
.008 w
.26458 .10306 Mdot
.016 w
.26458 .10306 m
.26477 .10296 L
s
1 .143 0 r
.008 w
.26477 .10296 Mdot
.016 w
.26477 .10296 m
.26499 .10283 L
s
1 .107 0 r
.008 w
.26499 .10283 Mdot
.016 w
.26499 .10283 m
.26522 .10267 L
s
1 .071 0 r
.008 w
.26522 .10267 Mdot
.016 w
.26522 .10267 m
.26541 .10251 L
s
1 .036 0 r
.008 w
.26541 .10251 Mdot
.016 w
.26541 .10251 m
.26549 .10241 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000=oo`9l`0=oo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo
00@007ooOomoo`9lH003O21lH7aP00Dmkf5oo`8mka1oo`@mk`Eoo`@mk`03001oogoo04Moo`00AWoo
0P0017oo0WaP00=l87aPO6001Cg_H7oo13g_3goo13g_1Goo1Cg_0P00Agoo0015Ool00`00Oomoo`04
Ool5O605?NmPOol4?NlHOol8?Nm6Ool004Aoo`03001oogoo008mk`=oo`ElH0Dmkf5oo`HmkaEoo`Tm
kdEoo`00@goo00<007ooOol013g_KWoo1Cg_5Goo2Sg_A7oo0011Ool20002Ool6?Nm]Ool5?NlEOol=
?Nm1Ool0041oo`03001oogoo00Pmkfeoo`DmkaEoo`hmkd1oo`00?goo00<007ooOol023g_17oo0Sg_
J7oo1Cg_6goo23g_00<007ooOol0?Goo000nOol01000Oomoogoo1cg_17oo13g_IWoo1Sg_6goo23g_
00=oo`00Ool0?Goo000lOol20004Ool5?Nl6Ool4?NmVOol5?NlQOol5?Nl00`00Oomoo`0kOol003]o
o`03001oogoo00Aoo`Dmk`Ioo`@mkfIoo`Dmkb5oo`Dmk`03Ool007oo03]oo`00>Woo00<007ooOol0
1Goo13g_27oo0Sg_Igoo1Cg_8Goo1Cg_0Woo0P00>Woo000iOol01000Oolmkcg_1Goo13g_LGoo13g_
8Woo1Cg_17oo00<007ooOol0=goo000gOol200000goo?Nlmk`02?NmiOol4?NlROol8?Nl2Ool00`00
Oomoo`0fOol003Ioo`04001oogooOol4?NnOOol9?Nl2Ool00`00Oomoo`0eOol003Eoo`03001oogoo
009oo`@mki5oo`@mk`ioo`Dmk`=oo`03001oogoo03Aoo`00=7oo00<007ooOol017oo1Sg_SWoo1Cg_
3Goo13g_1Goo00<007ooOol0<goo000bOol20008Ool5?Nn>Ool5?Nl=Ool4?Nl6Ool00`00Oomoo`0b
Ool0035oo`03001oogoo00Qoo`Dmkhioo`DmkaQoo`03001oogoo035oo`00<7oo00<007ooOol027oo
1Sg_SWoo1Cg_47oo1Cg_17oo00<007ooOol0<7oo000`Ool00`00Oomoo`07Ool5?NnUOol5?Nl5Ool0
0`00Oomoo`0_Ool002moo`03001oogoo00Qoo`DmkjEoo`Dmk`Ioo`03001oogoo02ioo`00;Woo00<0
07ooOol017oo2Sg_YGoo1Cg_1goo00<007ooOol0;Goo000]Ool00`00Oomoo`05Ool:?NnVOol5?Nl7
Ool00`00Oomoo`0/Ool002aoo`03001oogoo00Ioo`LmkjYoo`Dmk`Moo`03001oogoo02]oo`00;7oo
00<007ooOol01Woo1cg_ZWoo1Sg_1Woo00<007ooOol0:goo000[Ool00`00Oomoo`07Ool7?Nn[Ool5
?Nl7Ool00`00Oomoo`0ZOol002Yoo`03001oogoo00Uoo`8mkk1oo`Dmk`Moo`03001oogoo02Uoo`00
:Goo00<007ooOol0_7oo1Cg_27oo00<007ooOol0:7oo000XOol00`00Oomoo`2mOol5?Nl9Ool00`00
Oomoo`0WOol002Qoo`03001oogoo0;eoo`Dmk`Uoo`03001oogoo02Moo`009goo00<007ooOol0/7oo
0Sg_6goo00<007ooOol09Woo000VOol00`00Oomoo`2`Ool4?NlKOol00`00Oomoo`0UOol002Eoo`03
001oogoo0;5oo`@mka9oo`8mk`Qoo`03001oogoo02Aoo`0097oo00<007ooOol0/goo0Sg_4Woo13g_
27oo00<007ooOol08goo000TOol00`00Oomoo`37Ool4?Nl8Ool00`00Oomoo`0SOol002=oo`03001o
ogoo0<Uoo`8mk`04Oolmkcg_?Nl6Ool00`00Oomoo`0ROol0029oo`03001oogoo0<aoo`Dmk`Ioo`03
001oogoo025oo`008Woo00<007ooOol0c7oo1Cg_1Woo00<007ooOol08Goo000QOol00`00Oomoo`3>
Ool3?Nl8Ool00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007oo
Ool0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo
0=ioo`03001oogoo01eoo`007Woo00<007ooOol0e7oo13g_1goo00<007ooOol07Goo000MOol00`00
Oomoo`0eOol4?NnKOol6?Nl7Ool00`00Oomoo`0LOol001eoo`03001oogoo03Eoo`DmkiMoo`Tmk`Mo
o`03001oogoo01aoo`0077oo00<007ooOol0=Woo1Cg_Ugoo2Cg_27oo00<007ooOol06goo000LOol0
0`00Oomoo`0fOol5?NnGOol9?Nl8Ool00`00Oomoo`0KOol001]oo`03001oogoo03Moo`DmkiMoo`@m
k`9oo`Dmk`Moo`03001oogoo01Yoo`006goo00<007ooOol0fGoo1Cg_1goo00<007ooOol06Woo000J
Ool00`00Oomoo`07Ool2?NoAOol7?Nl6Ool00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`@mkm1o
o`Pmk`Eoo`03001oogoo01Uoo`006Goo00<007ooOol01goo13g_d7oo23g_1Woo00<007ooOol067oo
000IOol00`00Oomoo`06Ool4?NmLOol4?NmcOol6?Nl6Ool00`00Oomoo`0HOol001Qoo`03001oogoo
00Ioo`@mkd=oo`8mkaQoo`@mkg=oo`Lmk`Ioo`03001oogoo01Moo`0067oo00<007ooOol01Woo13g_
@Woo13g_5goo13g_M7oo1Sg_1Woo00<007ooOol05goo000HOol00`00Oomoo`05Ool4?Nm2Ool5?NlG
Ool4?NmdOol7?Nl5Ool00`00Oomoo`0GOol001Moo`03001oogoo00Eoo`@mkd=oo`HmkaIoo`@mkgAo
o`Lmk`Ioo`03001oogoo01Ioo`005goo00<007ooOol017oo1Cg_A7oo1Cg_SWoo1cg_1Woo00<007oo
Ool05Woo000FOol00`00Oomoo`05Ool5?Nm4Ool4?NnAOol5?Nl7Ool00`00Oomoo`0EOol001Ioo`03
001oogoo00Aoo`HmkmUoo`Dmk`Moo`03001oogoo01Eoo`005Goo00<007ooOol01Goo1Sg_fWoo13g_
27oo00<007ooOol057oo000EOol00`00Oomoo`05Ool5?NoKOol4?Nl8Ool00`00Oomoo`0DOol001Eo
o`03001oogoo00Eoo`Dmkm]oo`@mk`Qoo`03001oogoo01Aoo`0057oo00<007ooOol01Woo1Cg_j7oo
00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0>Moo`@m
k`Qoo`03001oogoo01=oo`004goo00<007ooOol0j7oo13g_2Goo00<007ooOol04Woo000COol00`00
Oomoo`3XOol4?Nl9Ool00`00Oomoo`0BOol001=oo`03001oogoo0>Qoo`@mk`Uoo`03001oogoo019o
o`004Woo00<007ooOol0jGoo13g_2Woo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomo
o`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007ooOol0
47oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo00Uoo`8mknioo`03001o
ogoo011oo`004Goo00<007ooOol027oo13g_?Woo0Sg_[Woo00<007ooOol03goo000@Ool00`00Oomo
o`08Ool5?NlmOol4?Nn]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03
001oogoo00moo`0047oo00<007ooOol027oo1Sg_?Goo0Sg_[Woo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool6?No]Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo00io
o`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool8?No/Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol0
2Goo1cg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool9?No/Ool00`00Oomoo`0=Ool000io
o`03001oogoo00Yoo`Xmkn]oo`03001oogoo00eoo`003Woo00<007ooOol037oo23g_jgoo00<007oo
Ool03Goo000>Ool00`00Oomoo`0=Ool<?NoVOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`dm
knIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00
Oomoo`0>Ool=?NoHOol2?Nl<Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmkmIoo`Dmk`]o
o`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_eWoo1Cg_2goo00<007ooOol037oo000=Ool0
0`00Oomoo`0=Ool=?NoGOol5?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`hmk`Eoo`8m
km1oo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol02Woo43g_17oo13g_cgoo13g_37oo00<0
07ooOol037oo000=Ool00`00Oomoo`08Ool:?Nl3Ool5?Nl4Ool4?NoOOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Qoo`Tmk`Aoo`8mk`Qoo`8mkn1oo`03001oogoo00aoo`003Goo00<007ooOol027oo
2Cg_0goo13g_jGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool:?Nl3Ool4?NoYOol00`00Oomo
o`0<Ool000aoo`03001oogoo00Moo`Xmk`Eoo`8mkn]oo`03001oogoo00]oo`0037oo00<007ooOol0
27oo23g_lgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000ao
o`03001oogoo00Moo`PmkoAoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_igoo
00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:Ool4?NlMOol2?No8Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo00Qoo`Hmk`Yoo`@mkaaoo`@mklMoo`03001oogoo00]oo`0037oo00<007ooOol0
27oo1Sg_2goo0Sg_7Goo13g_agoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl[Ool2?No8
Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0
27oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl@Ool2?NoSOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Hmk`moo`@mkn9oo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Sg_3goo13g_hWoo00<007ooOol02goo000=Ool00`00Oomoo`07Ool5?NlAOol2?NoSOol00`00Oomo
o`0;Ool000eoo`03001oogoo00Moo`DmkoEoo`03001oogoo00aoo`003Goo00<007ooOol01goo13g_
mWoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool4?NoZOol2?Nl:Ool00`00Oomoo`0<Ool000eo
o`03001oogoo00Moo`DmknQoo`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Sg_3goo
13g_e7oo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07Ool6?Nl?Ool5?NoCOol4?Nl9Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Dmkm9oo`Dmk`Uoo`03001oogoo00aoo`00
3Goo00<007ooOol027oo1Cg_3goo13g_dgoo1Cg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08
Ool5?Nl?Ool4?NoCOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mknIoo`Hmk`Uo
o`03001oogoo00aoo`003Goo00<007ooOol027oo13g_iWoo1Cg_2Woo00<007ooOol037oo000>Ool0
0`00Oomoo`3aOol5?Nl9Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?5oo`@mk`Yoo`03001oogoo
00eoo`003Woo00<007ooOol0lGoo13g_2Woo00<007ooOol03Goo000>Ool00`00Oomoo`09Ool4?Nob
Ool00`00Oomoo`0=Ool000moo`03001oogoo00Qoo`@mko9oo`03001oogoo00eoo`003goo00<007oo
Ool027oo1Cg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4?NmMOol2?NnAOol00`00Oomo
o`0>Ool000moo`03001oogoo00Qoo`Dmkeaoo`@mki1oo`03001oogoo00ioo`003goo00<007ooOol0
27oo1Cg_G7oo13g_T7oo00<007ooOol03Woo000@Ool00`00Oomoo`07Ool5?NmMOol2?NnAOol00`00
Oomoo`0>Ool0011oo`03001oogoo00Moo`Dmknmoo`03001oogoo00moo`0047oo00<007ooOol027oo
0Sg_lGoo00<007ooOol03goo000@Ool00`00Oomoo`3POol5?NlFOol00`00Oomoo`0?Ool0011oo`03
001oogoo0>1oo`HmkaEoo`03001oogoo00moo`004Goo00<007ooOol027oo0cg_e7oo1Sg_5Goo00<0
07ooOol03goo000AOol00`00Oomoo`07Ool5?NoCOol5?NlEOol00`00Oomoo`0@Ool0015oo`03001o
ogoo00Moo`Dmkm=oo`@mkaIoo`03001oogoo011oo`004Woo00<007ooOol01goo0cg_kWoo00<007oo
Ool047oo000BOol00`00Oomoo`2nOol2?NlgOol00`00Oomoo`0AOol0019oo`03001oogoo0;eoo`@m
kcIoo`03001oogoo015oo`004goo00<007ooOol0_7oo13g_=Woo00<007ooOol04Goo000COol00`00
Oomoo`0gOol2?Nn4Ool2?NlfOol00`00Oomoo`0BOol001=oo`03001oogoo03Ioo`@mkk]oo`03001o
ogoo019oo`0057oo00<007ooOol0=Goo13g_^goo00<007ooOol04Woo000DOol00`00Oomoo`05Ool4
?Nl]Ool2?NnkOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`DmknUoo`03001oogoo01=oo`00
5Goo00<007ooOol017oo1Cg_jGoo00<007ooOol04goo000EOol00`00Oomoo`04Ool4?NoYOol00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`@mk`Aoo`8mkn=oo`03001oogoo01Aoo`005Goo00<007oo
Ool02Woo1Cg_hWoo00<007ooOol057oo000FOol00`00Oomoo`09Ool5?NoDOol2?Nl;Ool00`00Oomo
o`0EOol001Ioo`03001oogoo00Uoo`Dmkm=oo`@mk`Yoo`03001oogoo01Eoo`005goo00<007ooOol0
27oo1Cg_dgoo13g_2Goo00<007ooOol05Woo000GOol00`00Oomoo`3POol4?Nl9Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo00Aoo`8mkmYoo`8mk`Uoo`03001oogoo01Moo`0067oo00<007ooOol00goo
1Cg_?7oo0cg_UGoo1cg_27oo00<007ooOol05goo000IOol00`00Oomoo`02Ool6?NljOol5?NnDOol6
?Nl9Ool00`00Oomoo`0GOol001Uoo`03001oogoo009oo`HmkcYoo`Dmki=oo`Hmk`Uoo`03001oogoo
01Qoo`006Woo00@007ooOomoo`Dmkcaoo`<mkiAoo`Dmk`Yoo`03001oogoo01Qoo`006Woo00<007oo
Ool00Woo1Cg_dWoo1Cg_2Goo00<007ooOol06Goo000KOol01000Oomoogoo1Cg_dWoo1Cg_27oo00<0
07ooOol06Woo000KOol01000Oomoogoo1cg_dGoo0Sg_2Woo00<007ooOol06Woo000LOol00`00Oomo
o`08?NoKOol00`00Oomoo`0KOol001aoo`03001oogoo00Pmkm]oo`03001oogoo01]oo`007Goo00<0
07oo?Nl01cg_fWoo00<007ooOol077oo000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001io
o`03001oocg_00Hmk`03Oolmkcg_0=Ioo`03001oogoo01eoo`007Woo00<007oo?Nl01Cg_00=oocg_
?Nl00Sg_`Woo0Sg_4Goo00<007ooOol07Goo000OOol00`00?Nlmk`04?Nl00goo?Nlmk`02?No1Ool4
?Nl5Ool3?Nl7Ool00`00Oomoo`0NOol001moo`03000mkcg_00Tmkl5oo`@mk`Aoo`Dmk`Ioo`03001o
ogoo01ioo`0087oo2cg_`Woo0Sg_0goo1cg_1Goo00<007ooOol07goo000POol00`00?Nlmk`09?No3
Ool:?Nl5Ool00`00Oomoo`0OOol0025oo`03000mkcg_00Pmkl=oo`Xmk`Aoo`03001oogoo021oo`00
8Woo00<003g_?Nl00Sg_00Aoocg_?NlmklAoo`Xmk`=oo`03001oogoo025oo`008goo00@007ooOomo
o`Dmkl=oo`Tmk`=oo`03001oogoo029oo`0097oo00<007ooOol01Cg_agoo13g_0goo00<007ooOol0
8goo000TOol01000Oomoogoo0cg_bGoo0cg_0goo00<007ooOol08goo000UOol00`00Oomoo`08Ool2
?No0Ool5?Nl2Ool00`00Oomoo`0TOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001oogoo
02Eoo`009Woo00<007ooOol01Goo1Cg__Woo13g_0goo00<007ooOol09Goo000WOol00`00Oomoo`04
Ool5?NnkOol6?Nl3Ool00`00Oomoo`0VOol002Qoo`03001oogoo00=oo`Dmkk]oo`Lmk`03Ool007oo
02Qoo`00:Goo00<007ooOol017oo0Sg_00=oocg_Ool0^Goo1cg_00<007ooOol0:7oo000ZOol01000
Oomoogoo1cg_JWoo0Sg_CGoo1Sg_00<007ooOol0:Goo000ZOol01000Oomoogoo23g_J7oo13g_37oo
13g_?7oo1Sg_00<007ooOol0:Goo000[Ool00`00Oomoo`08?NmXOol4?Nl<Ool5?NlkOol5?Nl00`00
Oomoo`0ZOol002aoo`03001oocg_00LmkfUoo`8mk`eoo`Dmkc1oo`@mk`Aoo`8mk`Eoo`03001oogoo
02]oo`00;Goo00<007ooOol00Woo13g_N7oo13g_<Goo1Cg_0Woo13g_0goo00<007ooOol0;7oo000^
Ool01000Oomoogoo13g_[Goo1Cg_0Woo13g_0Woo00<007ooOol0;Goo000^Ool00`00Oomoo`2bOol4
?Nl4Ool2?Nl3Ool00`00Oomoo`0]Ool002moo`03001oogoo08Qoo`8mkbMoo`Dmk`Moo`03001oogoo
02ioo`00<7oo00<007ooOol0QWoo13g_9Goo1cg_1Goo00<007ooOol0;goo000aOol00`00Oomoo`05
Ool4?NmlOol4?NlUOol7?Nl4Ool00`00Oomoo`0`Ool0039oo`8000Eoo`Dmkgaoo`8mkbIoo`Hmk`=o
o`8003=oo`00=7oo00<007ooOol00Woo1Cg_MWoo13g_:Woo1Cg_0goo00<007ooOol0<goo000eOol0
1000Oomoogoo13g_Mgoo1Cg_:Woo0cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo13g_Mgoo
1Cg_<7oo00<007ooOol0=7oo000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol003Moo`03
001oogoo07Yoo`Dmkbioo`03001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<007ooOol0
=goo000iOol2001jOol4?Nl[Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo
00<007ooOol01Woo1Cg_V7oo00<007ooOol0>goo000mOol00`00Oomoo`05Ool5?NnGOol00`00Oomo
o`0lOol003ioo`8000Eoo`DmkiEoo`8003moo`00@7oo00<007ooOol00Woo1Cg_U7oo00<007ooOol0
?goo0011Ool20002Ool4?Nl4Ool2?Nm[Ool2?NlPOol20012Ool004=oo`03001oogoo00Aoo`HmkfUo
o`@mka5oo`Dmk`Qoo`03001oogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo13g_47oo
1Sg_1goo00<007ooOol0@goo0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo1Sg_1Woo00<0
07ooOol0A7oo0016Ool20002Ool5?NlaOol4?Nm9Ool6?Nl4Ool20017Ool004Qoo`800003Oolmkcg_
008mkc9oo`8mkdYoo`Dmk`=oo`8004Uoo`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<Ool20023
Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol037oo0Sg_GWoo
0Sg_3goo00<007ooOol0CWoo001@Ool2000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0059oo`80
00Uoo`@mkcMoo`@mkb1oo`Tmk`Ioo`8005=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_0Woo2cg_
17oo0P00EGoo001FOol20010Ool4?NlHOol@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMoo`@mkaQo
oa0mk`<005Uoo`00Fgoo0`003Woo1Cg_>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7?NlgOol6
?Nl5Ool=?NmNOol0061oo`8000Yoo`Pmk`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061oo`00HWoo
0`001goo2Cg_0goo1Sg_3goo0cg_6Woo1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3Ool6?Nl>
Ool6?NlJOol4?Nl7Ool3001VOol006Qoo`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03Oolmkcg_
01ioo`@006Uoo`00K7oo100027oo1Cg_1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7OolB?NlE
Ool4001aOol007=oo`D000aoo`Xmk`05Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L000Eoo`Xm
k`04Oolmkcg_?Nl>Ool7001iOol007moo`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0027Ool40004Ool30003Ool30028Ool008Moo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo08Moo`00R7oo00<007ooOol00Woo1@0000=oo`000000
0`00R7oo0029Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo08Moo`00Qgoo00@0
07ooOol000=oo`03001oo`0000=oo`03001oo`0008Uoo`00R7oo0P001Goo0P0017oo0P00RGoo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(245)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
.23882 .87478 m
.23876 .87471 L
.2388 .87473 L
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
s
.90793 .32161 m
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
s
.26343 .10379 m
.26345 .10379 L
.2636 .10369 L
.26382 .10356 L
.26404 .1034 L
.26423 .10327 L
.26435 .10317 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.2644 .10313 L
.26446 .10311 L
.26458 .10306 L
.26477 .10296 L
.26499 .10283 L
.26522 .10267 L
.26541 .10251 L
.26549 .10241 L
s
1 .95 0 r
.008 w
.08992 .34962 Mdot
.016 w
.08992 .34962 m
.09 .34966 L
s
1 .9 0 r
.008 w
.09 .34966 Mdot
.016 w
.09 .34966 m
.09008 .34958 L
s
1 .85 0 r
.008 w
.09008 .34958 Mdot
.016 w
.09008 .34958 m
.09013 .34947 L
s
1 .8 0 r
.008 w
.09013 .34947 Mdot
.016 w
.09013 .34947 m
.09015 .34936 L
s
1 .75 0 r
.008 w
.09015 .34936 Mdot
.016 w
.09015 .34936 m
.09016 .34926 L
s
1 .7 0 r
.008 w
.09016 .34926 Mdot
.016 w
.09016 .34926 m
.09016 .34917 L
s
1 .65 0 r
.008 w
.09016 .34917 Mdot
.016 w
.09016 .34917 m
.09016 .3491 L
s
1 .6 0 r
.008 w
.09016 .3491 Mdot
.016 w
.09016 .3491 m
.09016 .34906 L
s
1 .55 0 r
.008 w
.09016 .34906 Mdot
.016 w
.09016 .34906 m
.09016 .34903 L
s
1 .5 0 r
.008 w
.09016 .34903 Mdot
.016 w
.09016 .34903 m
.09016 .34903 L
s
1 .45 0 r
.008 w
.09016 .34903 Mdot
.016 w
.09016 .34903 m
.09016 .34902 L
s
1 .4 0 r
.008 w
.09016 .34902 Mdot
.016 w
.09016 .34902 m
.09016 .34898 L
s
1 .35 0 r
.008 w
.09016 .34898 Mdot
.016 w
.09016 .34898 m
.09016 .3489 L
s
1 .3 0 r
.008 w
.09016 .3489 Mdot
.016 w
.09016 .3489 m
.09018 .34878 L
s
1 .25 0 r
.008 w
.09018 .34878 Mdot
.016 w
.09018 .34878 m
.09022 .34857 L
s
1 .2 0 r
.008 w
.09022 .34857 Mdot
.016 w
.09022 .34857 m
.09028 .34823 L
s
1 .15 0 r
.008 w
.09028 .34823 Mdot
.016 w
.09028 .34823 m
.09035 .34786 L
s
1 .1 0 r
.008 w
.09035 .34786 Mdot
.016 w
.09035 .34786 m
.09041 .34765 L
s
1 .05 0 r
.008 w
.09041 .34765 Mdot
.016 w
.09041 .34765 m
.09043 .34768 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000=oo`8mk`=oo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo
00@007ooOomoo`Xmkf5oo`8mka1oo`@mk`Eoo`@mk`03001oogoo04Moo`00AWoo0P0017oo2Sg_H7oo
13g_3goo13g_1Goo1Cg_0P00Agoo0015Ool00`00Oomoo`04Ool:?NmPOol4?NlHOol8?Nm6Ool004Ao
o`03001oogoo008mk`=oo`Xmkf5oo`HmkaEoo`TmkdEoo`00@goo00<007ooOol013g_KWoo1Cg_5Goo
2Sg_A7oo0011Ool20002Ool6?Nm]Ool5?NlEOol=?Nm1Ool0041oo`03001oogoo00Pmkfeoo`DmkaEo
o`hmkd1oo`00?goo00<007ooOol023g_17oo0Sg_J7oo1Cg_6goo23g_00<007ooOol0?Goo000nOol0
1000Oomoogoo1cg_17oo13g_IWoo1Sg_6goo23g_00=oo`00Ool0?Goo000lOol20004Ool5?Nl6Ool4
?NmVOol5?NlQOol5?Nl00`00Oomoo`0kOol003]oo`03001oogoo00Aoo`Dmk`Ioo`@mkfIoo`Dmkb5o
o`Dmk`03Ool007oo03]oo`00>Woo00<007ooOol01Goo13g_27oo0Sg_Igoo1Cg_8Goo1Cg_0Woo0P00
>Woo000iOol01000Oolmkcg_1Goo13g_LGoo13g_8Woo1Cg_17oo00<007ooOol0=goo000gOol20000
0goo?Nlmk`02?NmiOol4?NlROol8?Nl2Ool00`00Oomoo`0fOol003Ioo`04001oogooOol4?NnOOol9
?Nl2Ool00`00Oomoo`0eOol003Eoo`03001oogoo009oo`@mki5oo`@mk`ioo`Dmk`=oo`03001oogoo
03Aoo`00=7oo00<007ooOol017oo1Sg_SWoo1Cg_3Goo13g_1Goo00<007ooOol0<goo000bOol20008
Ool5?Nn>Ool5?Nl=Ool4?Nl6Ool00`00Oomoo`0bOol0035oo`03001oogoo00Qoo`Dmkhioo`DmkaQo
o`03001oogoo035oo`00<7oo00<007ooOol027oo1Sg_SWoo1Cg_47oo1Cg_17oo00<007ooOol0<7oo
000`Ool00`00Oomoo`07Ool5?NnUOol5?Nl5Ool00`00Oomoo`0_Ool002moo`03001oogoo00Qoo`Dm
kjEoo`Dmk`Ioo`03001oogoo02ioo`00;Woo00<007ooOol017oo2Sg_YGoo1Cg_1goo00<007ooOol0
;Goo000]Ool00`00Oomoo`05Ool:?NnVOol5?Nl7Ool00`00Oomoo`0/Ool002aoo`03001oogoo00Io
o`LmkjYoo`Dmk`Moo`03001oogoo02]oo`00;7oo00<007ooOol01Woo1cg_ZWoo1Sg_1Woo00<007oo
Ool0:goo000[Ool00`00Oomoo`07Ool7?Nn[Ool5?Nl7Ool00`00Oomoo`0ZOol002Yoo`03001oogoo
00Uoo`8mkk1oo`Dmk`Moo`03001oogoo02Uoo`00:Goo00<007ooOol0_7oo1Cg_27oo00<007ooOol0
:7oo000XOol00`00Oomoo`2mOol5?Nl9Ool00`00Oomoo`0WOol002Qoo`03001oogoo0;eoo`Dmk`Uo
o`03001oogoo02Moo`009goo00<007ooOol0/7oo0Sg_6goo00<007ooOol09Woo000VOol00`00Oomo
o`2`Ool4?NlKOol00`00Oomoo`0UOol002Eoo`03001oogoo0;5oo`@mka9oo`8mk`Qoo`03001oogoo
02Aoo`0097oo00<007ooOol0/goo0Sg_4Woo13g_27oo00<007ooOol08goo000TOol00`00Oomoo`37
Ool4?Nl8Ool00`00Oomoo`0SOol002=oo`03001oogoo0<Uoo`8mk`04Oolmkcg_?Nl6Ool00`00Oomo
o`0ROol0029oo`03001oogoo0<aoo`Dmk`Ioo`03001oogoo025oo`008Woo00<007ooOol0c7oo1Cg_
1Woo00<007ooOol08Goo000QOol00`00Oomoo`3>Ool3?Nl8Ool00`00Oomoo`0POol0021oo`03001o
ogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0
e7oo13g_1goo00<007ooOol07Goo000MOol00`00Oomoo`0eOol4?NnKOol6?Nl7Ool00`00Oomoo`0L
Ool001eoo`03001oogoo03Eoo`DmkiMoo`Tmk`Moo`03001oogoo01aoo`0077oo00<007ooOol0=Woo
1Cg_Ugoo2Cg_27oo00<007ooOol06goo000LOol00`00Oomoo`0fOol5?NnGOol9?Nl8Ool00`00Oomo
o`0KOol001]oo`03001oogoo03Moo`DmkiMoo`@mk`9oo`Dmk`Moo`03001oogoo01Yoo`006goo00<0
07ooOol0fGoo1Cg_1goo00<007ooOol06Woo000JOol00`00Oomoo`07Ool2?NoAOol7?Nl6Ool00`00
Oomoo`0IOol001Yoo`03001oogoo00Ioo`@mkm1oo`Pmk`Eoo`03001oogoo01Uoo`006Goo00<007oo
Ool01goo13g_d7oo23g_1Woo00<007ooOol067oo000IOol00`00Oomoo`06Ool4?NmLOol4?NmcOol6
?Nl6Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`@mkd=oo`8mkaQoo`@mkg=oo`Lmk`Ioo`03
001oogoo01Moo`0067oo00<007ooOol01Woo13g_@Woo13g_5goo13g_M7oo1Sg_1Woo00<007ooOol0
5goo000HOol00`00Oomoo`05Ool4?Nm2Ool5?NlGOol4?NmdOol7?Nl5Ool00`00Oomoo`0GOol001Mo
o`03001oogoo00Eoo`@mkd=oo`HmkaIoo`@mkgAoo`Lmk`Ioo`03001oogoo01Ioo`005goo00<007oo
Ool017oo1Cg_A7oo1Cg_SWoo1cg_1Woo00<007ooOol05Woo000FOol00`00Oomoo`05Ool5?Nm4Ool4
?NnAOol5?Nl7Ool00`00Oomoo`0EOol001Ioo`03001oogoo00Aoo`HmkmUoo`Dmk`Moo`03001oogoo
01Eoo`005Goo00<007ooOol01Goo1Sg_fWoo13g_27oo00<007ooOol057oo000EOol00`00Oomoo`05
Ool5?NoKOol4?Nl8Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`Dmkm]oo`@mk`Qoo`03001o
ogoo01Aoo`0057oo00<007ooOol01Woo1Cg_j7oo00<007ooOol04goo000DOol00`00Oomoo`3cOol0
0`00Oomoo`0COol001Aoo`03001oogoo00Eoo`9l`09l8003O<1oogoo0=]oo`@mk`Qoo`03001oogoo
01=oo`004goo00<007ooOol01Woo00=l`7`PO2000W`PgGoo13g_2Goo00<007ooOol04Woo000COol0
0`00Oomoo`06Ool00gc0O21l8002O23MOol4?Nl9Ool00`00Oomoo`0BOol001=oo`03001oogoo00Io
o`9l`09l8003O<1oogoo0=]oo`@mk`Uoo`03001oogoo019oo`004Woo00<007ooOol01goo17n0gWoo
13g_2Woo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3i
Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Uoo`8mknioo`03001oogoo011oo`004Goo00<007oo
Ool027oo13g_?Woo0Sg_[Woo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?NlmOol4?Nn]Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03001oogoo00moo`0047oo00<0
07ooOol027oo1Sg_?Goo0Sg_[Woo00<007ooOol03goo000@Ool00`00Oomoo`08Ool6?No]Ool00`00
Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo
1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000>Ool00`00Oomoo`0:Ool9?No/Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo`Xmkn]o
o`03001oogoo00eoo`003Woo00<007ooOol037oo23g_jgoo00<007ooOol03Goo000>Ool00`00Oomo
o`0=Ool<?NoVOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`dmknIoo`03001oogoo00aoo`00
3Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoHOol2?Nl<
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmkmIoo`Dmk`]oo`03001oogoo00aoo`003Goo
00<007ooOol03Woo3Cg_eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoGOol5
?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`hmk`Eoo`8mkm1oo`Dmk`]oo`03001oogoo
00aoo`003Goo00<007ooOol02Woo43g_17oo13g_cgoo13g_37oo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool:?Nl3Ool5?Nl4Ool4?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Tmk`Ao
o`8mk`Qoo`8mkn1oo`03001oogoo00aoo`003Goo00<007ooOol027oo2Cg_0goo13g_jGoo00<007oo
Ool037oo000=Ool00`00Oomoo`07Ool:?Nl3Ool4?NoYOol00`00Oomoo`0<Ool000aoo`03001oogoo
00Moo`Xmk`Eoo`8mkn]oo`03001oogoo00]oo`0037oo00<007ooOol027oo23g_lgoo00<007ooOol0
2goo000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`PmkoAo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo13g_igoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?Nl:Ool4?NlMOol2?No8Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
k`Yoo`@mkaaoo`@mklMoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2goo0Sg_7Goo13g_
agoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl[Ool2?No8Ool00`00Oomoo`0;Ool000ao
o`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol0
2goo000<Ool00`00Oomoo`08Ool6?Nl@Ool2?NoSOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qo
o`Hmk`moo`@mkn9oo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_3goo13g_hWoo00<007oo
Ool02goo000=Ool00`00Oomoo`07Ool5?NlAOol2?NoSOol00`00Oomoo`0;Ool000eoo`03001oogoo
00Moo`DmkoEoo`03001oogoo00aoo`003Goo00<007ooOol01goo13g_mWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool4?NoZOol2?Nl:Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`DmknQo
o`@mk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Sg_3goo13g_e7oo13g_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`07Ool6?Nl?Ool5?NoCOol4?Nl9Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Moo`Dmka1oo`Dmkm9oo`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo1Cg_
3goo13g_dgoo1Cg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool5?Nl?Ool4?NoCOol5?Nl9
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mknIoo`Hmk`Uoo`03001oogoo00aoo`003Goo
00<007ooOol027oo13g_iWoo1Cg_2Woo00<007ooOol037oo000>Ool00`00Oomoo`3aOol5?Nl9Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo0?5oo`@mk`Yoo`03001oogoo00eoo`003Woo00<007ooOol0
lGoo13g_2Woo00<007ooOol03Goo000>Ool00`00Oomoo`09Ool4?NobOol00`00Oomoo`0=Ool000mo
o`03001oogoo00Qoo`@mko9oo`03001oogoo00eoo`003goo00<007ooOol027oo1Cg_l7oo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool4?NmMOol2?NnAOol00`00Oomoo`0>Ool000moo`03001oogoo
00Qoo`Dmkeaoo`@mki1oo`03001oogoo00ioo`003goo00<007ooOol027oo1Cg_G7oo13g_T7oo00<0
07ooOol03Woo000@Ool00`00Oomoo`07Ool5?NmMOol2?NnAOol00`00Oomoo`0>Ool0011oo`03001o
ogoo00Moo`Dmknmoo`03001oogoo00moo`0047oo00<007ooOol027oo0Sg_lGoo00<007ooOol03goo
000@Ool00`00Oomoo`3POol5?NlFOol00`00Oomoo`0?Ool0011oo`03001oogoo0>1oo`HmkaEoo`03
001oogoo00moo`004Goo00<007ooOol027oo0cg_e7oo1Sg_5Goo00<007ooOol03goo000AOol00`00
Oomoo`07Ool5?NoCOol5?NlEOol00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkm=oo`@mkaIo
o`03001oogoo011oo`004Woo00<007ooOol01goo0cg_kWoo00<007ooOol047oo000BOol00`00Oomo
o`2nOol2?NlgOol00`00Oomoo`0AOol0019oo`03001oogoo0;eoo`@mkcIoo`03001oogoo015oo`00
4goo00<007ooOol0_7oo13g_=Woo00<007ooOol04Goo000COol00`00Oomoo`0gOol2?Nn4Ool2?Nlf
Ool00`00Oomoo`0BOol001=oo`03001oogoo03Ioo`@mkk]oo`03001oogoo019oo`0057oo00<007oo
Ool0=Goo13g_^goo00<007ooOol04Woo000DOol00`00Oomoo`05Ool4?Nl]Ool2?NnkOol00`00Oomo
o`0COol001Aoo`03001oogoo00Eoo`DmknUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_
jGoo00<007ooOol04goo000EOol00`00Oomoo`04Ool4?NoYOol00`00Oomoo`0DOol001Eoo`03001o
ogoo00Aoo`@mk`Aoo`8mkn=oo`03001oogoo01Aoo`005Goo00<007ooOol02Woo1Cg_hWoo00<007oo
Ool057oo000FOol00`00Oomoo`09Ool5?NoDOol2?Nl;Ool00`00Oomoo`0EOol001Ioo`03001oogoo
00Uoo`Dmkm=oo`@mk`Yoo`03001oogoo01Eoo`005goo00<007ooOol027oo1Cg_dgoo13g_2Goo00<0
07ooOol05Woo000GOol00`00Oomoo`3POol4?Nl9Ool00`00Oomoo`0FOol001Qoo`03001oogoo00Ao
o`8mkmYoo`8mk`Uoo`03001oogoo01Moo`0067oo00<007ooOol00goo1Cg_?7oo0cg_UGoo1cg_27oo
00<007ooOol05goo000IOol00`00Oomoo`02Ool6?NljOol5?NnDOol6?Nl9Ool00`00Oomoo`0GOol0
01Uoo`03001oogoo009oo`HmkcYoo`Dmki=oo`Hmk`Uoo`03001oogoo01Qoo`006Woo00@007ooOomo
o`Dmkcaoo`<mkiAoo`Dmk`Yoo`03001oogoo01Qoo`006Woo00<007ooOol00Woo1Cg_dWoo1Cg_2Goo
00<007ooOol06Goo000KOol01000Oomoogoo1Cg_dWoo1Cg_27oo00<007ooOol06Woo000KOol01000
Oomoogoo1cg_dGoo0Sg_2Woo00<007ooOol06Woo000LOol00`00Oomoo`08?NoKOol00`00Oomoo`0K
Ool001aoo`03001oogoo00Pmkm]oo`03001oogoo01]oo`007Goo00<007oo?Nl01cg_fWoo00<007oo
Ool077oo000MOol00`00Oolmk`07?NoJOol00`00Oomoo`0LOol001ioo`03001oocg_00Hmk`03Oolm
kcg_0=Ioo`03001oogoo01eoo`007Woo00<007oo?Nl01Cg_00=oocg_?Nl00Sg_`Woo0Sg_4Goo00<0
07ooOol07Goo000OOol00`00?Nlmk`04?Nl00goo?Nlmk`02?No1Ool4?Nl5Ool3?Nl7Ool00`00Oomo
o`0NOol001moo`03000mkcg_00Tmkl5oo`@mk`Aoo`Dmk`Ioo`03001oogoo01ioo`0087oo2cg_`Woo
0Sg_0goo1cg_1Goo00<007ooOol07goo000POol00`00?Nlmk`09?No3Ool:?Nl5Ool00`00Oomoo`0O
Ool0025oo`03000mkcg_00Pmkl=oo`Xmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl00Sg_00Ao
ocg_?NlmklAoo`Xmk`=oo`03001oogoo025oo`008goo00@007ooOomoo`Dmkl=oo`Tmk`=oo`03001o
ogoo029oo`0097oo00<007ooOol01Cg_agoo13g_0goo00<007ooOol08goo000TOol01000Oomoogoo
0cg_bGoo0cg_0goo00<007ooOol08goo000UOol00`00Oomoo`08Ool2?No0Ool5?Nl2Ool00`00Oomo
o`0TOol002Ioo`03001oogoo00Eoo`Dmkkioo`@mk`=oo`03001oogoo02Eoo`009Woo00<007ooOol0
1Goo1Cg__Woo13g_0goo00<007ooOol09Goo000WOol00`00Oomoo`04Ool5?NnkOol6?Nl3Ool00`00
Oomoo`0VOol002Qoo`03001oogoo00=oo`Dmkk]oo`Lmk`03Ool007oo02Qoo`00:Goo00<007ooOol0
17oo0Sg_00=oocg_Ool0^Goo1cg_00<007ooOol0:7oo000ZOol01000Oomoogoo1cg_JWoo0Sg_CGoo
1Sg_00<007ooOol0:Goo000ZOol01000Oomoogoo23g_J7oo13g_37oo13g_?7oo1Sg_00<007ooOol0
:Goo000[Ool00`00Oomoo`08?NmXOol4?Nl<Ool5?NlkOol5?Nl00`00Oomoo`0ZOol002aoo`03001o
ocg_00LmkfUoo`8mk`eoo`Dmkc1oo`@mk`Aoo`8mk`Eoo`03001oogoo02]oo`00;Goo00<007ooOol0
0Woo13g_N7oo13g_<Goo1Cg_0Woo13g_0goo00<007ooOol0;7oo000^Ool01000Oomoogoo13g_[Goo
1Cg_0Woo13g_0Woo00<007ooOol0;Goo000^Ool00`00Oomoo`2bOol4?Nl4Ool2?Nl3Ool00`00Oomo
o`0]Ool002moo`03001oogoo08Qoo`8mkbMoo`Dmk`Moo`03001oogoo02ioo`00<7oo00<007ooOol0
QWoo13g_9Goo1cg_1Goo00<007ooOol0;goo000aOol00`00Oomoo`05Ool4?NmlOol4?NlUOol7?Nl4
Ool00`00Oomoo`0`Ool0039oo`8000Eoo`Dmkgaoo`8mkbIoo`Hmk`=oo`8003=oo`00=7oo00<007oo
Ool00Woo1Cg_MWoo13g_:Woo1Cg_0goo00<007ooOol0<goo000eOol01000Oomoogoo13g_Mgoo1Cg_
:Woo0cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo13g_Mgoo1Cg_<7oo00<007ooOol0=7oo
000fOol00`00Oomoo`1kOol5?Nl_Ool00`00Oomoo`0eOol003Moo`03001oogoo07Yoo`Dmkbioo`03
001oogoo03Ioo`00>7oo00<007ooOol0NGoo1Cg_;Goo00<007ooOol0=goo000iOol2001jOol4?Nl[
Ool2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol01Woo1Cg_V7oo
00<007ooOol0>goo000mOol00`00Oomoo`05Ool5?NnGOol00`00Oomoo`0lOol003ioo`8000Eoo`Dm
kiEoo`8003moo`00@7oo00<007ooOol00Woo1Cg_U7oo00<007ooOol0?goo0011Ool20002Ool4?Nl4
Ool2?Nm[Ool2?NlPOol20012Ool004=oo`03001oogoo00Aoo`HmkfUoo`@mka5oo`Dmk`Qoo`03001o
ogoo049oo`00A7oo00<007ooOol00Woo1cg_<Goo0Sg_=Woo13g_47oo1Sg_1goo00<007ooOol0@goo
0015Ool01000Oomoogoo1Sg_<Goo13g_=Woo0Sg_4Goo1Sg_1Woo00<007ooOol0A7oo0016Ool20002
Ool5?NlaOol4?Nm9Ool6?Nl4Ool20017Ool004Qoo`800003Oolmkcg_008mkc9oo`8mkdYoo`Dmk`=o
o`8004Uoo`00BWoo00<003g_?Nl00Sg_Q7oo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001o
ogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol037oo0Sg_GWoo0Sg_3goo00<007ooOol0CWoo
001@Ool2000;Ool4?NlgOol4?NlQOol7?Nl9Ool2001AOol0059oo`8000Uoo`@mkcMoo`@mkb1oo`Tm
k`Ioo`8005=oo`00E7oo0P0027oo0Sg_>7oo13g_6Goo0cg_0Woo2cg_17oo0P00EGoo001FOol20010
Ool4?NlHOol@?Nl3Ool2001GOol005Qoo`<0015oo`DmkbMoo`@mkaQooa0mk`<005Uoo`00Fgoo0`00
3Woo1Cg_>Goo1Sg_17oo3Sg_0P00G7oo001NOol2000<Ool7?NlgOol6?Nl5Ool=?NmNOol0061oo`80
00Yoo`Pmk`Aoo`Dmkbeoo`Hmk`Ioo`Lmk`03001oogoo061oo`00HWoo0`001goo2Cg_0goo1Sg_3goo
0cg_6Woo1Sg_1Woo1Cg_0P00Hgoo001UOol30008Ool5?Nl3Ool6?Nl>Ool6?NlJOol4?Nl7Ool3001V
Ool006Qoo`@000Aoo`@mk`Aoo`Dmk`Qoo`<mk`Aoo`Hmk`03Oolmkcg_01ioo`@006Uoo`00K7oo1000
27oo1Cg_1goo4Sg_6Goo1000KGoo001`Ool30006Ool4?Nl7OolB?NlEOol4001aOol007=oo`D000ao
o`Xmk`05Oolmkcg_?Nmoo`02?NlBOol4001eOol007Qoo`L000Eoo`Xmk`04Oolmkcg_?Nl>Ool7001i
Ool007moo`D000Xmk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo0027Ool40004Ool30002Ool2002:Ool008Moo`03001oogoo00Ioo`04001oogoo0002
Ool00`00Oomoo`27Ool008Qoo`03001oogoo009oo`D000Aoo`03001oogoo08Moo`00RGoo00D007oo
Oomoo`00009oo`04001oogooOol2002:Ool008Moo`04001oogoo0003Ool00`00Ool00003Ool00`00
Oomoo`29Ool008Qoo`8000Eoo`8000=oo`<008Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(246)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.11062 .44328 m
.11005 .44406 L
.1094 .44487 L
.10863 .44563 L
.10771 .44634 L
.1067 .44694 L
.10561 .44743 L
.10459 .44772 L
.10371 .44781 L
.103 .44774 L
.10258 .44753 L
.10246 .44722 L
.10256 .44691 L
.10289 .44663 L
.10335 .44636 L
.10385 .44617 L
.10447 .44619 L
.10525 .44648 L
.10615 .447 L
.10737 .44771 L
.10866 .44856 L
.11028 .44947 L
.112 .45032 L
.11375 .45111 L
.11531 .45162 L
.11681 .45202 L
.11814 .45224 L
.11944 .45231 L
.12069 .45234 L
.12193 .45229 L
.12315 .45217 L
.12422 .45199 L
.12502 .45181 L
.12556 .45162 L
.12588 .45138 L
.12588 .45109 L
.12559 .4509 L
.12509 .45084 L
.1244 .45079 L
.12368 .45091 L
.12311 .45111 L
.12274 .45135 L
.12245 .45149 L
.12224 .45153 L
.1221 .45146 L
s
.12972 .43769 m
.12956 .43754 L
.12937 .43752 L
.12913 .43757 L
.12881 .43763 L
.12842 .4376 L
.12799 .43749 L
.12754 .43727 L
.12712 .43696 L
.12675 .43655 L
.12645 .43608 L
.1262 .43559 L
.126 .43514 L
.12583 .43475 L
.12568 .43446 L
.12554 .43428 L
.12542 .43421 L
.12535 .43425 L
.12533 .43428 L
.12534 .43431 L
.12538 .43435 L
.12543 .43439 L
.12546 .43442 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.12548 .43444 L
.1255 .43444 L
.12552 .43444 L
.12555 .43444 L
.12556 .43444 L
.12556 .43444 L
.12554 .43444 L
.12551 .43444 L
.12546 .43444 L
.12539 .43444 L
.12528 .43444 L
.12515 .43444 L
.12498 .43444 L
.12479 .43444 L
.12457 .43444 L
.12433 .43444 L
.12408 .43444 L
.12384 .43444 L
.12363 .43444 L
.12343 .43444 L
.12325 .43444 L
.12311 .43444 L
.123 .43444 L
Mistroke
.12291 .43444 L
.12286 .43444 L
.12284 .43444 L
.12288 .43444 L
.12295 .43444 L
.12304 .43444 L
.12311 .43444 L
.12313 .43444 L
.12304 .43444 L
.12285 .43444 L
.12255 .43444 L
.12216 .43444 L
.12169 .43444 L
.12118 .43444 L
.12065 .43444 L
.12009 .43444 L
.11961 .43444 L
.11909 .43444 L
.1186 .43444 L
.11816 .43444 L
.11781 .43444 L
.11757 .43444 L
.11743 .43444 L
.11739 .43444 L
.11742 .43444 L
.11749 .43444 L
.11759 .43444 L
.11766 .43444 L
.11768 .43444 L
.11769 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11768 .43444 L
.11767 .43444 L
.11763 .43444 L
.11759 .43444 L
.11755 .43444 L
.11753 .43444 L
.11755 .43444 L
.11761 .43444 L
.11771 .43444 L
.11787 .43444 L
.11806 .43444 L
.11831 .43444 L
.11863 .43444 L
.11898 .43444 L
.11933 .43444 L
Mistroke
.11965 .43444 L
.11991 .43444 L
.12006 .43444 L
.12008 .43444 L
.11995 .43444 L
.11967 .43444 L
.11927 .43444 L
.11879 .43444 L
.11824 .43444 L
.11763 .43444 L
.11711 .43444 L
.11654 .43445 L
.11603 .43445 L
.11558 .43445 L
.11522 .43445 L
.11498 .43445 L
.11484 .43445 L
.11479 .43445 L
.11481 .43445 L
.11489 .43445 L
.11498 .43445 L
.11505 .43445 L
.11508 .43445 L
.11509 .43445 L
.11511 .43445 L
.11517 .43445 L
.11526 .43445 L
.11533 .43445 L
.11537 .43445 L
.11534 .43445 L
.11523 .43445 L
.11502 .43445 L
.11472 .43445 L
.11432 .43445 L
.11386 .43445 L
.11335 .43445 L
.11281 .43445 L
.11228 .43445 L
.11175 .43445 L
.11123 .43445 L
.11074 .43445 L
.11032 .43443 L
.11003 .43438 L
.10989 .4343 L
.10984 .43423 L
.10985 .43422 L
.10987 .43428 L
.10985 .43441 L
.10973 .43458 L
.1095 .43481 L
Mistroke
.10915 .43507 L
.10875 .43533 L
.10831 .4356 L
.10785 .4359 L
.10736 .43626 L
.10694 .43663 L
.10647 .43703 L
.10602 .43744 L
.10559 .43786 L
.10521 .43828 L
.10494 .4387 L
.10477 .43912 L
.10467 .43965 L
.10462 .44019 L
.10462 .44081 L
.10462 .44146 L
.10458 .44213 L
.10448 .44277 L
.10436 .4433 L
.10426 .44364 L
.10422 .44382 L
.10424 .44386 L
.10432 .4438 L
.10445 .44366 L
.10463 .44345 L
.10488 .44315 L
.10519 .44279 L
.10554 .4424 L
.10592 .44199 L
.10627 .44161 L
.10656 .44132 L
.10673 .44114 L
.10673 .4411 L
.10656 .44116 L
.10623 .44126 L
.10575 .44138 L
.10516 .44148 L
.10451 .44155 L
.10387 .44158 L
.10322 .4416 L
.1026 .44162 L
.10204 .44162 L
.1016 .44163 L
.10127 .44162 L
.10106 .4416 L
.10099 .44158 L
.10103 .44154 L
.10118 .4415 L
.10139 .44146 L
.10161 .44142 L
Mistroke
.1018 .44139 L
.10192 .44137 L
.10198 .44136 L
.102 .44137 L
.10197 .44139 L
.10194 .4414 L
.1019 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10189 .4414 L
.10191 .44137 L
.10194 .44132 L
.10199 .44124 L
.10203 .44117 L
.10205 .44114 L
.10203 .44116 L
.10196 .44125 L
.10186 .4414 L
.10173 .44161 L
.10155 .44189 L
.10134 .44223 L
.10108 .44265 L
.10076 .44315 L
.10038 .44374 L
.09999 .4444 L
.09956 .44511 L
.09913 .44582 L
.09872 .44651 L
.09832 .44717 L
.09795 .44783 L
.09758 .44851 L
.09723 .44921 L
.09686 .44992 L
.0965 .45061 L
.09612 .45128 L
.09571 .45193 L
.0953 .45255 L
.09489 .45311 L
.09448 .4536 L
.09412 .454 L
.09374 .45441 L
.09338 .45485 L
.09301 .45536 L
.09267 .45591 L
.09237 .45647 L
.09214 .45697 L
.09194 .4575 L
.09173 .45805 L
.09149 .45864 L
Mistroke
.09121 .4593 L
.0909 .46001 L
.09047 .46075 L
.08995 .46146 L
.08935 .46208 L
.08872 .46258 L
.08801 .46296 L
.08727 .46323 L
.08645 .46344 L
.08579 .46362 L
.08485 .46379 L
.08434 .46392 L
.08398 .46403 L
.08374 .46413 L
.08361 .46425 L
.08367 .46439 L
.08387 .46452 L
.0842 .46459 L
.08458 .46463 L
.08499 .46463 L
.08536 .46461 L
.08567 .46457 L
.08585 .4645 L
.08595 .46441 L
.08596 .46431 L
.08586 .46422 L
.08567 .46417 L
.08544 .46414 L
.08518 .46414 L
.08486 .46417 L
.08449 .46422 L
.08407 .4643 L
.08363 .4644 L
.08321 .46453 L
.08284 .46465 L
.08257 .46476 L
.0824 .46485 L
.08233 .4649 L
.08232 .46492 L
.08236 .4649 L
.08245 .46486 L
.08251 .46484 L
.08255 .46482 L
.0826 .46481 L
.08271 .46481 L
.08283 .46481 L
.08293 .4648 L
.083 .4648 L
.08303 .46479 L
.08299 .46479 L
Mistroke
.08282 .46479 L
.08255 .4648 L
.08221 .4648 L
.08182 .46481 L
.08142 .46482 L
.08107 .46482 L
.08074 .46483 L
.08049 .46483 L
.08031 .46484 L
.08019 .46484 L
.08018 .46484 L
.08026 .46484 L
.0804 .46484 L
.08067 .46483 L
.08103 .46483 L
.08149 .46482 L
.08185 .46481 L
.08222 .46481 L
.08251 .4648 L
.0827 .4648 L
.0828 .4648 L
.08286 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.08279 .4648 L
.08275 .4648 L
.08269 .4648 L
.08262 .46481 L
.08257 .46481 L
.08255 .46481 L
.08255 .46481 L
.08255 .46481 L
.08254 .46481 L
.08254 .46481 L
.08253 .46481 L
.08251 .46481 L
.0825 .46481 L
.08248 .46481 L
.08247 .46481 L
.08247 .46481 L
.08249 .46481 L
.08255 .46481 L
.08259 .46481 L
.08265 .4648 L
.08272 .4648 L
.0828 .4648 L
.08289 .4648 L
.08294 .4648 L
.08295 .4648 L
Mistroke
.08293 .4648 L
.08285 .4648 L
.08273 .4648 L
.08255 .4648 L
.08234 .46481 L
.08212 .46481 L
.08192 .46482 L
.08177 .46482 L
.08166 .46482 L
.0816 .46482 L
.08156 .46482 L
.08157 .46482 L
.08162 .46482 L
.08177 .46482 L
.08189 .46482 L
.0821 .46481 L
.08234 .46482 L
.08258 .46482 L
.08278 .46483 L
.08291 .46482 L
.08297 .46481 L
.08296 .46479 L
.08291 .46476 L
.08288 .46473 L
.08287 .4647 L
.08286 .46467 L
.08283 .46465 L
.08278 .46464 L
.08269 .46463 L
.08256 .46463 L
.08243 .46463 L
.08231 .46464 L
.08225 .46466 L
.08222 .46468 L
.08221 .4647 L
.08216 .46474 L
.08208 .46477 L
.08196 .4648 L
.08182 .46483 L
.08167 .46484 L
.08151 .46485 L
.08133 .46484 L
.08108 .46483 L
.08078 .46483 L
.08044 .46484 L
.08006 .46486 L
.07966 .46488 L
.07921 .46488 L
.07877 .46487 L
.07838 .46486 L
Mistroke
.07811 .46483 L
.07802 .4648 L
.07809 .46478 L
.07831 .46475 L
.07863 .46473 L
.07901 .46471 L
.07944 .4647 L
.07997 .4647 L
.08042 .4647 L
.08097 .4647 L
.08152 .46469 L
.08199 .46468 L
.08235 .46468 L
.08256 .46467 L
.08264 .46467 L
.08264 .46467 L
.0826 .46468 L
.08253 .46467 L
.08246 .46467 L
.08239 .46466 L
.08232 .46465 L
.0823 .46465 L
.08231 .46466 L
.08233 .46468 L
.08231 .46471 L
.08226 .46474 L
.08219 .46477 L
.0821 .4648 L
.08195 .46482 L
.0818 .46484 L
.08164 .46484 L
.08146 .46483 L
.0812 .46483 L
.08085 .46482 L
.08045 .46482 L
.08001 .46483 L
.07956 .46484 L
.07914 .46485 L
.0788 .46485 L
.07856 .46486 L
.07841 .46486 L
.07835 .46486 L
.07838 .46486 L
.07846 .46486 L
.07854 .46486 L
.07868 .46486 L
.07889 .46485 L
.07916 .46485 L
.07947 .46484 L
.07978 .46484 L
Mistroke
.08005 .46483 L
.08027 .46483 L
.08041 .46483 L
.08048 .46482 L
.08048 .46482 L
.08043 .46483 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08025 .46483 L
.08021 .46483 L
.08016 .46483 L
.08012 .46483 L
.08008 .46483 L
.08005 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08003 .46483 L
.08003 .46483 L
.08004 .46484 L
.08008 .46485 L
.08016 .46487 L
.08023 .46489 L
.08027 .4649 L
.08028 .46488 L
.08026 .46484 L
.08018 .46479 L
.08003 .46472 L
.07982 .46465 L
.07955 .46459 L
.07923 .46454 L
.07888 .4645 L
.07852 .46448 L
.07821 .46447 L
.078 .46447 L
.07787 .46448 L
.07778 .4645 L
.07775 .46454 L
.07778 .46457 L
.07788 .46459 L
.07808 .46459 L
.07833 .46458 L
.0786 .46461 L
.07884 .46467 L
.07902 .46478 L
.07913 .46496 L
.07917 .46521 L
Mistroke
.07916 .46554 L
.07911 .46595 L
.07903 .46641 L
.07895 .46689 L
.07892 .46736 L
.07896 .46783 L
.07903 .46829 L
.07912 .46872 L
.07919 .4691 L
.07923 .46941 L
.07922 .46962 L
.07916 .46974 L
.07906 .46978 L
.07894 .46977 L
.07882 .46974 L
.07866 .46973 L
.07847 .46972 L
.0782 .46971 L
.07789 .46968 L
.07758 .4696 L
.07732 .46946 L
.07712 .46926 L
.07699 .46899 L
.07691 .4687 L
.07688 .4684 L
.07688 .46814 L
.07691 .46789 L
.0769 .46771 L
.07687 .46757 L
.07686 .46745 L
.07686 .46741 L
.07691 .46748 L
.077 .46766 L
.07715 .46795 L
.07735 .4684 L
.07759 .46898 L
.07785 .46964 L
.07812 .47033 L
.07839 .47101 L
.07866 .47165 L
.0789 .4722 L
.07915 .47272 L
.07938 .4732 L
.07958 .47361 L
.07972 .47391 L
.0798 .47412 L
.07981 .47425 L
.07978 .4743 L
.07974 .47428 L
.07973 .4742 L
Mistroke
.07978 .4741 L
.07992 .474 L
.08011 .47394 L
.08035 .4739 L
.08062 .47391 L
.08092 .47395 L
.08114 .47398 L
.08135 .47402 L
.08149 .47406 L
.08153 .47406 L
.08145 .47402 L
.08127 .47391 L
.081 .47373 L
.08066 .47344 L
.08028 .47313 L
.07991 .47276 L
.07964 .47237 L
.07945 .47197 L
.07936 .47154 L
.07937 .47105 L
.0795 .47064 L
.07963 .4702 L
.07979 .4698 L
.07995 .46946 L
.08009 .4692 L
.08014 .46902 L
.08009 .46892 L
.07991 .46889 L
.07964 .46892 L
.07934 .46896 L
.07904 .46898 L
.07876 .46903 L
.07854 .46911 L
.0784 .4692 L
.07837 .46928 L
.07851 .46937 L
.07879 .46946 L
.07918 .46952 L
.07961 .46957 L
.0801 .4696 L
.08057 .46959 L
.0811 .46955 L
.08147 .46952 L
.08183 .4695 L
.08211 .46952 L
.08224 .46956 L
.08226 .46962 L
.08217 .46967 L
.08198 .46968 L
.08161 .46965 L
Mistroke
.08125 .46957 L
.08081 .46946 L
.08036 .4693 L
.07989 .46909 L
.07943 .46885 L
.07901 .46858 L
.07869 .46827 L
.07846 .4679 L
.07832 .46754 L
.07828 .46716 L
.07833 .46676 L
.07845 .46638 L
.07862 .46607 L
.0788 .46577 L
.07899 .46551 L
.07913 .46535 L
.07927 .46522 L
.07938 .46513 L
.07946 .46504 L
.07949 .46497 L
.0795 .46489 L
.07952 .46482 L
.07957 .4648 L
.0796 .46481 L
.07959 .46484 L
.07955 .46487 L
.07949 .46489 L
.07942 .46491 L
.07934 .46492 L
.07924 .46493 L
.07914 .46493 L
.07905 .46493 L
.07898 .46492 L
.07894 .46492 L
.07893 .46493 L
.07895 .46493 L
.07907 .46493 L
.07929 .46491 L
.07963 .4649 L
.08009 .46487 L
.08057 .46485 L
.08107 .46482 L
.08156 .46481 L
.08202 .46479 L
.08241 .46479 L
.08269 .46479 L
.08288 .46479 L
.083 .4648 L
.08307 .4648 L
.08309 .4648 L
Mistroke
.08305 .4648 L
.08295 .4648 L
.08281 .4648 L
.08266 .46481 L
.08253 .46481 L
.08244 .46481 L
.08238 .46481 L
.08235 .46481 L
.08238 .46481 L
.08251 .46481 L
.08249 .4648 L
.0824 .46478 L
.08224 .46473 L
.08202 .46466 L
.08169 .4646 L
.08125 .46457 L
.08074 .4646 L
.08021 .46471 L
.07963 .4649 L
.07906 .46518 L
.07853 .46554 L
.07814 .46596 L
.07784 .46643 L
.07756 .46691 L
.07747 .46739 L
.07757 .46786 L
.0778 .46832 L
.07818 .46875 L
.07862 .46912 L
.07908 .46942 L
.07947 .46963 L
.07976 .46974 L
.0799 .46978 L
.07988 .46975 L
.07972 .46969 L
.07949 .46961 L
.07921 .46956 L
.07883 .46954 L
.0785 .46954 L
.07818 .46954 L
.0779 .46954 L
.07768 .46955 L
.07751 .46955 L
.07739 .46955 L
.07733 .46955 L
.07732 .46955 L
.07734 .46954 L
.07739 .46954 L
.07743 .46954 L
.07747 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46952 L
.07755 .46946 L
.07763 .46937 L
.07773 .46929 L
.07778 .46922 L
.07776 .4692 L
.07766 .46922 L
Mfstroke
.07379 .49831 m
.07394 .4983 L
.07401 .49821 L
.07402 .49806 L
.07396 .49786 L
.07388 .49764 L
.07384 .49741 L
.07388 .49719 L
.074 .497 L
.07417 .49683 L
.07433 .49665 L
.07446 .49644 L
.07455 .49621 L
.07459 .49595 L
.07459 .49565 L
.07455 .49533 L
.07449 .49502 L
.07442 .49475 L
.07434 .49452 L
.07426 .49435 L
.07416 .49418 L
.07404 .49402 L
.0739 .49386 L
.07378 .4937 L
.0737 .49353 L
.07369 .49337 L
.07373 .49325 L
.07382 .49315 L
.07393 .49306 L
s
.07632 .4808 m
.07647 .48082 L
.07658 .48088 L
.07666 .48095 L
.07671 .48103 L
.07672 .48108 L
.07669 .4811 L
.07664 .48111 L
.07659 .48113 L
.07654 .48112 L
.07649 .48107 L
.07645 .48096 L
.07639 .48077 L
.07634 .48055 L
.07627 .48032 L
.07619 .48013 L
.07609 .47989 L
.07598 .47961 L
.07589 .47933 L
.07588 .47906 L
.07594 .47878 L
.07606 .4785 L
.07622 .4782 L
.07641 .47794 L
.07658 .47771 L
.07672 .47755 L
.07678 .47737 L
.0768 .47721 L
.0768 .47705 L
.07676 .47691 L
.07671 .47676 L
.07666 .47663 L
.07667 .47654 L
.0767 .47649 L
.07672 .47649 L
.07671 .47651 L
.07667 .47654 L
.0766 .47652 L
.07654 .47647 L
.07651 .4764 L
.07651 .47633 L
.07654 .47627 L
.07656 .47624 L
.07658 .47622 L
.07659 .47621 L
.07661 .47621 L
.07663 .4762 L
.07667 .47619 L
.07677 .47618 L
.07694 .47619 L
Mistroke
.07714 .4762 L
.07731 .47621 L
.07742 .47622 L
.07746 .47623 L
.07743 .47622 L
.07736 .4762 L
.07728 .47617 L
.07718 .47614 L
.0771 .4761 L
.07707 .47609 L
.0771 .47607 L
.07719 .47605 L
.0773 .47598 L
.07747 .47589 L
.07768 .47577 L
.07797 .47561 L
.07823 .47541 L
.07857 .47519 L
.07895 .47499 L
.07929 .47481 L
.07958 .47466 L
.07982 .47454 L
.08001 .47447 L
.08013 .47443 L
.08019 .47441 L
.08021 .47443 L
.0802 .47446 L
.08018 .4745 L
.08014 .47453 L
.08013 .47456 L
.08016 .47458 L
.08022 .47457 L
.08032 .47453 L
.08047 .47447 L
.08065 .4744 L
.08086 .47432 L
.08109 .47424 L
.08136 .47419 L
.08167 .47416 L
.082 .47417 L
.08229 .47418 L
.08251 .47417 L
.08262 .47414 L
.08262 .47408 L
.08251 .474 L
.08234 .47391 L
.08216 .47382 L
.082 .47373 L
.0819 .47365 L
.08184 .47357 L
Mistroke
.0818 .47352 L
.08176 .47348 L
.08173 .47345 L
.08169 .47349 L
.08164 .47361 L
.08156 .47382 L
.0814 .4741 L
.08119 .47445 L
.08092 .47489 L
.08059 .47539 L
.0803 .47594 L
.07994 .47651 L
.07951 .47705 L
.07904 .47754 L
.07861 .47798 L
.07825 .4783 L
.07797 .47853 L
.07778 .47867 L
.07762 .47868 L
.07751 .4786 L
.07746 .47844 L
.07747 .47822 L
.07749 .47793 L
.07754 .47761 L
.0776 .4773 L
.07763 .477 L
.07759 .47675 L
.07748 .47657 L
.07731 .47646 L
.07715 .4764 L
.077 .47639 L
.07688 .47644 L
.07679 .47651 L
.07671 .47656 L
.07662 .47659 L
.07653 .47659 L
.0765 .47659 L
.07648 .47659 L
.07646 .47659 L
.0765 .47659 L
.07658 .47659 L
.07671 .47659 L
.07687 .47658 L
.07704 .47658 L
.07719 .47658 L
.0773 .47658 L
.07736 .47657 L
.07737 .47657 L
.07735 .47657 L
.07732 .47657 L
Mistroke
.07728 .47657 L
.07726 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07725 .47658 L
.07726 .47658 L
.07727 .47658 L
.0773 .47657 L
.07733 .47657 L
.07735 .47656 L
.07734 .47655 L
.0773 .47655 L
.07722 .47657 L
.07712 .47658 L
.07699 .47661 L
.07686 .47664 L
.07673 .47666 L
.07663 .47669 L
.07655 .47671 L
.0765 .47672 L
.07648 .47673 L
.07647 .47673 L
.0765 .47673 L
.07656 .47673 L
.07666 .47673 L
.07677 .47672 L
.0769 .4767 L
.07702 .47666 L
.07712 .4766 L
.0772 .47655 L
.07723 .47649 L
.07722 .47644 L
.07718 .47641 L
.07712 .47639 L
.07707 .47639 L
.07704 .47638 L
.07703 .47638 L
.07702 .47638 L
.07703 .47639 L
.07705 .4764 L
.07708 .47643 L
.07711 .47646 L
Mistroke
.07715 .47649 L
.0772 .47653 L
.07724 .47656 L
.07727 .47659 L
.07731 .47658 L
.07734 .47655 L
.07737 .4765 L
.07739 .47646 L
.0774 .47644 L
.07739 .47645 L
.07734 .47648 L
.07725 .47655 L
.0771 .47667 L
.07692 .47685 L
.07669 .47709 L
.07643 .47739 L
.07614 .47772 L
.07584 .47812 L
.07554 .47854 L
.07522 .47901 L
.07509 .47954 L
.07486 .47999 L
.07464 .48039 L
.07448 .4807 L
.0744 .4809 L
.07443 .48093 L
.07456 .48082 L
.07477 .48058 L
.07503 .48027 L
.0753 .47994 L
.07559 .47961 L
.07582 .47926 L
.07608 .47896 L
.07629 .47872 L
.07646 .47856 L
.07659 .47844 L
.07672 .47839 L
.07686 .47838 L
.07701 .47838 L
.0772 .47838 L
.07744 .47837 L
.0778 .47838 L
.07816 .47837 L
.07867 .47829 L
.07918 .47817 L
.07971 .47805 L
.08004 .47792 L
.08031 .47785 L
.08054 .47787 L
.08062 .47801 L
Mistroke
.08051 .47829 L
.08026 .47863 L
.07996 .47901 L
.07954 .47933 L
.07913 .47961 L
.07872 .47978 L
.07832 .47985 L
.07803 .4798 L
.07782 .47964 L
.07777 .47932 L
.0779 .47892 L
.07821 .47849 L
.0786 .47803 L
.07896 .4776 L
.07929 .47724 L
.07952 .47697 L
.07962 .47681 L
.0796 .47678 L
.07944 .4769 L
.07914 .47712 L
.07872 .47738 L
.07823 .47766 L
.07763 .47788 L
.07711 .47809 L
.07648 .47823 L
.0758 .47833 L
.0752 .47842 L
.07466 .47848 L
.07422 .47852 L
.07388 .47854 L
.0737 .47858 L
.07362 .47865 L
.07364 .47875 L
.07374 .4789 L
.07392 .47915 L
.07415 .47946 L
.07441 .47977 L
.07475 .48011 L
.0751 .48041 L
.07542 .48068 L
.07571 .48084 L
.07592 .48095 L
.07606 .48099 L
.0761 .48094 L
.07606 .4808 L
.07595 .48056 L
.07579 .48022 L
.07558 .47977 L
.07534 .47926 L
.0751 .47871 L
Mistroke
.07488 .47818 L
.07469 .47759 L
.07452 .47698 L
.0744 .47639 L
.07432 .47585 L
.07431 .47538 L
.07432 .47499 L
.07438 .47468 L
.07445 .47444 L
.07451 .47428 L
.07456 .47417 L
.07461 .47413 L
.07465 .47412 L
.07468 .47412 L
.07471 .47414 L
.07473 .47418 L
.07473 .47422 L
.07472 .47425 L
.07471 .47427 L
.0747 .47427 L
.0747 .47428 L
.07472 .47429 L
.07472 .47429 L
.07472 .47429 L
.07471 .47429 L
.07468 .4743 L
.07465 .47433 L
.07461 .47438 L
.07457 .47442 L
.07454 .47442 L
.07452 .47436 L
.0745 .47423 L
.0745 .474 L
.07451 .47367 L
.07452 .47333 L
.07454 .47292 L
.07457 .47247 L
.07461 .47201 L
.07465 .47158 L
.0747 .47113 L
.07476 .47069 L
.0748 .47029 L
.07484 .46994 L
.07487 .46967 L
.07488 .46946 L
.07488 .46935 L
.07486 .46932 L
.07485 .46935 L
.07485 .46942 L
.07485 .4695 L
Mistroke
.07484 .46955 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07482 .46958 L
.07479 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07469 .46958 L
.07471 .46958 L
.07478 .46958 L
.07489 .46958 L
.07507 .46958 L
.07532 .46957 L
.07564 .46957 L
.07602 .46956 L
.07645 .46956 L
.07692 .46955 L
.07741 .46954 L
.07791 .46954 L
.0784 .46953 L
.07885 .46952 L
.07924 .46952 L
.07959 .46951 L
.07988 .46951 L
.08012 .4695 L
.08029 .4695 L
.08038 .4695 L
.0804 .4695 L
.08034 .4695 L
.0802 .46951 L
.07999 .46951 L
.07973 .46952 L
.07943 .46952 L
.07911 .46953 L
.07877 .46953 L
.07844 .46954 L
.07815 .46954 L
.07792 .46956 L
.07773 .46959 L
.07764 .46962 L
.07767 .46962 L
.07779 .4696 L
.07797 .46954 L
.07818 .46947 L
.07837 .46939 L
.07854 .4693 L
.07864 .46922 L
.07869 .46915 L
Mistroke
.07867 .46911 L
.0786 .46908 L
.07849 .46907 L
.07837 .46908 L
.07823 .46908 L
.07802 .4691 L
.07779 .46915 L
.07758 .46921 L
.07743 .46929 L
.07734 .46938 L
.07732 .46947 L
.07735 .46954 L
.0774 .4696 L
.07746 .46962 L
.07749 .46962 L
.07749 .46959 L
.07749 .46956 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07749 .46954 L
.07753 .46954 L
.07759 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07747 .46955 L
.0773 .46955 L
.07707 .46956 L
.07679 .46957 L
.07651 .46957 L
.07623 .46958 L
.07595 .46958 L
.07569 .46959 L
.07549 .46959 L
.07522 .46959 L
Mistroke
.07497 .46959 L
.07478 .46959 L
.07466 .46959 L
.07462 .46959 L
.07463 .46959 L
.07466 .46958 L
.07471 .46958 L
.07476 .46958 L
.07478 .46958 L
.07476 .46958 L
.07474 .46958 L
.07478 .46958 L
.07488 .46958 L
.07503 .46958 L
.07523 .46958 L
.07548 .4696 L
.07577 .46964 L
.07609 .4697 L
.0764 .46976 L
.07671 .46978 L
.07698 .46975 L
.07719 .46966 L
.07731 .46951 L
.07731 .46928 L
.07721 .46899 L
.07702 .46864 L
.07676 .46825 L
.07647 .46782 L
.07613 .46735 L
.07587 .46688 L
.07558 .46643 L
.0753 .46599 L
.07504 .46568 L
.07482 .46546 L
.07464 .46538 L
.07453 .46546 L
.07449 .46567 L
.07449 .466 L
.07451 .46639 L
.07454 .46676 L
.07454 .46706 L
.07451 .46727 L
.07447 .46739 L
.07444 .46739 L
.07444 .46732 L
.07445 .46721 L
.07445 .4671 L
.07444 .46696 L
.07442 .46683 L
.07438 .46667 L
Mistroke
.07433 .46651 L
.07427 .46637 L
.0742 .4663 L
.07411 .46632 L
.07402 .46643 L
.07395 .46659 L
.07389 .46678 L
.07384 .46696 L
.0738 .4671 L
.07377 .46715 L
.07376 .4671 L
.07378 .46694 L
.07383 .46672 L
.07394 .4664 L
.07408 .46611 L
.07422 .46593 L
.07436 .46579 L
.07448 .46573 L
.07456 .46573 L
.07464 .4658 L
.07468 .46591 L
.07471 .46602 L
.07469 .46617 L
.07462 .46637 L
.07451 .46661 L
.07438 .46687 L
.07428 .46711 L
.07419 .46733 L
.07414 .46746 L
.0741 .46748 L
.07406 .46743 L
.07401 .46733 L
.07397 .4672 L
.07395 .46705 L
.07396 .46692 L
.074 .46682 L
.07407 .46673 L
.07418 .46662 L
.07431 .4665 L
.07441 .46636 L
.07447 .46622 L
.07452 .46611 L
.07451 .46608 L
.07448 .46613 L
.0744 .46623 L
.07428 .46638 L
.07414 .4666 L
.074 .46687 L
.07386 .46715 L
.07373 .46742 L
Mistroke
.07361 .46773 L
.07351 .46806 L
.07345 .46843 L
.07345 .46868 L
.07351 .46902 L
.07362 .46931 L
.07375 .46947 L
.07391 .46949 L
.07406 .46936 L
.0742 .4691 L
.07431 .46881 L
.0744 .46849 L
.07446 .4682 L
.0745 .46796 L
.07451 .46774 L
.07449 .46754 L
.07444 .46738 L
.07437 .46724 L
.07428 .46709 L
.07418 .46692 L
.07408 .46674 L
.07396 .46661 L
.07384 .46656 L
.07374 .46658 L
.07368 .46663 L
.07364 .46672 L
.0736 .46681 L
.07357 .46688 L
.07356 .46691 L
.07354 .46693 L
.07354 .46695 L
.07355 .46699 L
.0736 .46707 L
.07366 .4672 L
.07371 .46734 L
.07374 .46743 L
.07375 .46746 L
.0737 .46747 L
.0736 .46748 L
.07346 .46748 L
.07332 .46751 L
.07318 .4676 L
.07307 .46776 L
.07302 .46792 L
.07305 .46806 L
.07314 .46818 L
.07324 .46824 L
.07337 .46818 L
.07349 .46807 L
.0736 .46789 L
Mistroke
.0737 .46766 L
.07382 .46737 L
.07394 .46706 L
.07408 .46681 L
.07419 .4666 L
.0743 .46646 L
.0744 .4664 L
.07447 .46641 L
.07451 .46653 L
.07454 .46672 L
.07456 .46699 L
.07458 .46733 L
.0746 .46765 L
.07464 .46794 L
.07469 .46818 L
.07474 .46834 L
.07479 .46841 L
.07485 .46838 L
.07491 .46828 L
.07497 .46813 L
.075 .46792 L
.07499 .46767 L
.07496 .4674 L
.07489 .46718 L
.07481 .46702 L
.07474 .46694 L
.07469 .46698 L
.07465 .46711 L
.07463 .46727 L
.0746 .46742 L
.07457 .46762 L
.07452 .46783 L
.07444 .46801 L
.07431 .46815 L
.07416 .46823 L
.07399 .46827 L
.07383 .46828 L
.07368 .46825 L
.07357 .46818 L
.0735 .46803 L
.07345 .4678 L
.07344 .46749 L
.07345 .46715 L
.0735 .46683 L
.0736 .46652 L
.07376 .46624 L
.07396 .46604 L
.07416 .46575 L
.07436 .46558 L
.07455 .46541 L
Mistroke
.07471 .46523 L
.07486 .46506 L
.07499 .46492 L
.0751 .46483 L
.07521 .4648 L
.07534 .46479 L
.07551 .46479 L
.07575 .4648 L
.07606 .46483 L
.07644 .46486 L
.07687 .46487 L
.07733 .46487 L
.07781 .46486 L
.07828 .46485 L
.07872 .46485 L
.07912 .46484 L
.07946 .46484 L
.07975 .46483 L
.07997 .46483 L
.08014 .46483 L
.08029 .46483 L
.08041 .46483 L
.08048 .46482 L
.08049 .46482 L
.08044 .46483 L
.08034 .46483 L
.08023 .46483 L
.08012 .46483 L
.08003 .46483 L
.07994 .46484 L
.07986 .46484 L
.07977 .46484 L
.07971 .46484 L
.07969 .46484 L
.0797 .46484 L
.07977 .46484 L
.0799 .46484 L
.0801 .46483 L
.08035 .46483 L
.08065 .46483 L
.08096 .46483 L
.08126 .46482 L
.08155 .46482 L
.0818 .46482 L
.08203 .46481 L
.08222 .46481 L
.08234 .46481 L
.08248 .46481 L
.0826 .46481 L
.0827 .46481 L
Mistroke
.08273 .4648 L
.08274 .4648 L
.08274 .46481 L
.08275 .46484 L
.08276 .46486 L
.08278 .46487 L
.08279 .46487 L
.08277 .46485 L
.08271 .46483 L
.08265 .46479 L
.08263 .46472 L
.08269 .46463 L
.08284 .46451 L
.08306 .46436 L
.0834 .46418 L
.08373 .46398 L
.08418 .46376 L
.08473 .46353 L
.08539 .46331 L
.08619 .4631 L
.08693 .46291 L
.08765 .46274 L
.08829 .46263 L
.08884 .46258 L
.08926 .46257 L
.08961 .46259 L
.08982 .46259 L
.08988 .46255 L
.08986 .46245 L
.08983 .46228 L
.0898 .46203 L
.08979 .4617 L
.08982 .4613 L
.08978 .46084 L
.08978 .46036 L
.08986 .45988 L
.09 .45941 L
.09021 .45895 L
.09045 .4585 L
.09067 .4581 L
.09085 .45776 L
.09097 .4575 L
.09104 .45735 L
.09102 .45732 L
.09098 .4574 L
.09092 .45757 L
.09087 .4578 L
.0908 .45805 L
.09069 .45829 L
.09053 .45852 L
Mistroke
.09035 .45872 L
.09013 .45887 L
.08993 .45899 L
.08974 .45906 L
.08958 .45909 L
.08946 .45912 L
.08937 .45914 L
.08931 .4591 L
Mfstroke
.09439 .44937 m
.09431 .44932 L
.09432 .44915 L
.09441 .44887 L
.09458 .4485 L
.09482 .44806 L
.0951 .44756 L
.0954 .44704 L
.09569 .44656 L
.09596 .4462 L
.09618 .44596 L
.09635 .44584 L
.09649 .4458 L
.09658 .44582 L
.09664 .44589 L
.09667 .44596 L
.09666 .44602 L
.09664 .44605 L
.09659 .44606 L
.09656 .44606 L
.09657 .44604 L
.0966 .446 L
.09665 .44593 L
.09669 .44585 L
.0967 .44581 L
.09666 .44583 L
.09655 .44591 L
.09638 .44608 L
.09615 .44634 L
.0959 .44669 L
.09566 .44711 L
.09544 .44756 L
.09526 .44803 L
.09513 .44854 L
.09512 .4489 L
.09508 .44936 L
.09508 .44981 L
.09513 .45021 L
.09522 .45054 L
.09538 .45077 L
.09559 .4509 L
.09582 .45095 L
.09606 .45093 L
.09628 .45087 L
.09646 .45079 L
.09656 .45072 L
.09658 .4507 L
.09655 .45068 L
.09651 .45066 L
.0965 .45064 L
Mistroke
.09649 .45063 L
.09648 .45065 L
.09646 .45069 L
.09643 .45075 L
.09637 .45082 L
.0963 .45089 L
.09623 .45096 L
.09616 .45102 L
.0961 .45109 L
.09607 .45118 L
.09604 .45127 L
.09603 .45133 L
.09604 .45135 L
.09602 .4513 L
.09603 .45116 L
.09607 .45093 L
.09613 .45058 L
.09621 .45015 L
.0963 .44966 L
.09639 .44914 L
.09647 .44861 L
.09654 .44812 L
.09658 .44766 L
.09658 .44723 L
.09656 .44682 L
.09655 .44646 L
.09654 .44616 L
.09654 .44595 L
.09655 .44584 L
.09655 .4458 L
.09655 .44583 L
.09654 .4459 L
.09654 .44597 L
.09654 .44603 L
.09654 .44605 L
.09654 .44606 L
.09654 .44606 L
.09654 .44609 L
.09654 .44614 L
.09654 .44621 L
.09653 .44627 L
.09653 .4463 L
.09653 .44628 L
.09654 .44618 L
.09654 .44598 L
.09655 .44565 L
.09656 .4452 L
.09657 .44469 L
.09658 .44419 L
.0966 .44374 L
Mistroke
.0966 .44337 L
.09661 .44309 L
.09662 .44289 L
.09662 .44281 L
.09662 .44284 L
.09661 .443 L
.09661 .44326 L
.0966 .44362 L
.09659 .44404 L
.09658 .44453 L
.09656 .44505 L
.09655 .44554 L
.09654 .44592 L
.09654 .44615 L
.09653 .44627 L
.09653 .44631 L
.09653 .44629 L
.09654 .44622 L
.09654 .44615 L
.09654 .44609 L
.09654 .44606 L
.09654 .44602 L
.09654 .44595 L
.09654 .44587 L
.09655 .44583 L
.09655 .44582 L
.09655 .44588 L
.09655 .44601 L
Mfstroke
.07876 .46951 m
.07873 .46951 L
.07871 .46952 L
.07876 .46953 L
.07884 .46954 L
.07893 .46953 L
.07911 .46952 L
.07933 .4695 L
.07957 .46948 L
.0798 .46946 L
.07998 .46944 L
.08009 .46942 L
.08013 .4694 L
.08013 .4694 L
.0801 .46939 L
.08005 .4694 L
.07999 .46939 L
.07993 .4694 L
.07989 .46941 L
.07988 .46942 L
.07988 .46944 L
.07989 .46946 L
.07991 .46948 L
.07993 .4695 L
.07997 .46952 L
.07999 .46952 L
.08001 .46952 L
.08003 .46951 L
.08004 .4695 L
.08005 .4695 L
.08006 .4695 L
.08008 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46951 L
.08013 .46952 L
.08011 .46952 L
.08006 .46952 L
.08001 .46952 L
.07996 .46952 L
.07994 .46952 L
.07996 .46952 L
.08002 .46952 L
.08012 .46951 L
.08028 .46951 L
.08048 .46951 L
.08072 .4695 L
.081 .46949 L
.0813 .46949 L
.08161 .46948 L
Mistroke
.08193 .46948 L
.08222 .46947 L
.08248 .46947 L
.08266 .46947 L
.08276 .46947 L
.08275 .46948 L
.08265 .46948 L
.08249 .46948 L
.08227 .46949 L
.08199 .46949 L
.08161 .46949 L
.08129 .46949 L
.08091 .46949 L
.08051 .46949 L
.08009 .46949 L
.07967 .46949 L
.07927 .46949 L
.07891 .46949 L
.07857 .46949 L
.07833 .46949 L
.0781 .4695 L
.07789 .4695 L
.07771 .46951 L
.07755 .46952 L
.07744 .46953 L
.07736 .46954 L
.07733 .46954 L
.07734 .46955 L
.07737 .46955 L
.07742 .46955 L
.07746 .46955 L
.07748 .46955 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07755 .46954 L
.07759 .46954 L
.07762 .46954 L
.07762 .46954 L
.07758 .46954 L
.0775 .46955 L
.07736 .46955 L
.07717 .46955 L
.07694 .46956 L
Mistroke
.07668 .46956 L
.07642 .46957 L
.07612 .46957 L
.07589 .46957 L
.07562 .46958 L
.07536 .46958 L
.07513 .46958 L
.07494 .46958 L
.07481 .46958 L
.07473 .46958 L
.07469 .46958 L
.0747 .46958 L
.07473 .46958 L
.07477 .46958 L
.07478 .46958 L
.07475 .46958 L
.07471 .46958 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46955 L
.07757 .46955 L
.07761 .46955 L
.07763 .46954 L
.07762 .46954 L
.07756 .46953 L
.07745 .46953 L
.0773 .46953 L
.07708 .46952 L
.07682 .46952 L
Mistroke
.07651 .46953 L
.0762 .46953 L
.07591 .46953 L
.07565 .46954 L
.07544 .46954 L
.07529 .46954 L
.07523 .46955 L
.07526 .46955 L
.07538 .46956 L
.07557 .46956 L
.07582 .46956 L
.07611 .46956 L
.07642 .46956 L
.07673 .46956 L
.07702 .46955 L
.07725 .46955 L
.07742 .46954 L
.07754 .46954 L
.07761 .46954 L
.07763 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07751 .46954 L
.07756 .46954 L
.07759 .46954 L
.07761 .46954 L
.07759 .46954 L
.07751 .46952 L
.07736 .46947 L
.07712 .46941 L
.07683 .46935 L
.07656 .46932 L
.07631 .46935 L
.0761 .46945 L
.07595 .46964 L
.07585 .46991 L
.07575 .47027 L
.07571 .47069 L
.07574 .47114 L
.07586 .47162 L
.07604 .47209 L
.07627 .47255 L
.07653 .47301 L
.07681 .47345 L
.07709 .47385 L
.07734 .4742 L
.0775 .47448 L
.07759 .47466 L
.07762 .47473 L
.07759 .47468 L
.0775 .47452 L
.07736 .47427 L
.07718 .47395 L
.07698 .47357 L
.07675 .47315 L
.07651 .47268 L
Mistroke
.07625 .4722 L
.07599 .47173 L
.07573 .47127 L
.07548 .47081 L
.07525 .47038 L
.07505 .46999 L
.07489 .46969 L
.07478 .46948 L
.07472 .46936 L
.0747 .46932 L
.07471 .46935 L
.07475 .46942 L
.07481 .4695 L
.07486 .46957 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.0747 .46951 L
.0746 .46947 L
.07448 .46944 L
.07438 .46941 L
.07432 .46939 L
.0743 .46938 L
.07435 .46937 L
.07446 .46937 L
.07461 .46937 L
.07483 .46937 L
.07509 .46939 L
.07541 .46941 L
.07575 .46945 L
.07611 .46949 L
.07648 .46953 L
.07684 .46956 L
.07718 .46959 L
.07745 .4696 L
.07764 .46959 L
.07772 .46957 L
.07771 .46954 L
.07761 .46952 L
.07743 .4695 L
.07719 .46948 L
.07691 .46946 L
.07662 .46944 L
.07634 .46943 L
.07604 .46941 L
.0758 .46941 L
.07553 .46941 L
.07529 .46942 L
Mistroke
.07507 .46943 L
.0749 .46944 L
.07478 .46946 L
.07472 .46949 L
.0747 .46951 L
.07472 .46954 L
.07476 .46956 L
.0748 .46958 L
.07483 .46959 L
.07485 .46959 L
.07486 .4696 L
.07488 .46961 L
.07492 .46962 L
.07494 .46962 L
.07493 .46961 L
.07489 .46958 L
.0748 .46955 L
.0747 .46952 L
.07458 .46948 L
.07447 .46944 L
.07437 .46941 L
.0743 .4694 L
.07424 .46939 L
.07419 .46938 L
.07415 .46937 L
.07413 .46937 L
.07411 .46937 L
.07413 .46938 L
.07418 .4694 L
.07426 .46943 L
.07436 .46947 L
.07448 .46951 L
.0746 .46955 L
.07469 .46957 L
.07476 .46959 L
.07479 .46959 L
.07479 .46958 L
.07478 .46957 L
.07478 .46957 L
.0748 .46957 L
.07483 .46958 L
.07486 .46958 L
.07487 .46959 L
.07487 .46959 L
.07487 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46958 L
Mistroke
.07486 .46958 L
.07488 .46958 L
.0749 .46958 L
.07491 .46958 L
.07489 .46958 L
.07485 .46958 L
.07479 .46958 L
.07472 .46958 L
.07464 .46958 L
.07457 .46958 L
.07452 .46959 L
.07447 .46959 L
.07445 .46959 L
.07444 .46959 L
.07443 .46959 L
.07444 .46959 L
.07446 .46959 L
.0745 .46959 L
.07455 .46959 L
.07462 .46958 L
.0747 .46958 L
.07478 .46958 L
.07484 .46958 L
.07489 .46958 L
.07491 .46958 L
.0749 .46958 L
.07488 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46956 L
.07485 .46955 L
.07488 .46955 L
.07492 .46956 L
.07494 .46955 L
.07493 .46955 L
.07488 .46955 L
.07481 .46955 L
.07471 .46955 L
.07459 .46956 L
.07446 .46956 L
.07436 .46956 L
.07427 .46957 L
.07421 .46957 L
.07418 .46957 L
Mistroke
.07416 .46957 L
.07417 .46957 L
.07419 .46957 L
.07424 .46957 L
.07432 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07492 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46957 L
.07484 .46956 L
.07484 .46956 L
.07484 .46955 L
.07483 .46954 L
.07482 .46953 L
.0748 .46951 L
.07479 .46949 L
.07477 .46947 L
.07476 .46945 L
.07475 .46944 L
.07474 .46943 L
.07474 .46942 L
.07474 .46942 L
.07474 .46943 L
.07474 .46944 L
.07475 .46944 L
.07476 .46946 L
.07478 .46948 L
.0748 .46951 L
.07482 .46954 L
.07483 .46956 L
.07484 .46958 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
.07485 .46959 L
Mistroke
.07486 .46959 L
.07488 .4696 L
.0749 .46961 L
.07491 .46962 L
.07489 .46961 L
.07485 .46958 L
.07479 .46955 L
.07472 .46951 L
.07465 .46947 L
.07458 .46944 L
.07452 .46941 L
.07448 .46939 L
.07446 .46938 L
.07444 .46937 L
.07444 .46937 L
.07445 .46937 L
.07447 .46938 L
.07451 .4694 L
.07456 .46942 L
.07463 .46946 L
.0747 .4695 L
.07478 .46954 L
.07484 .46958 L
.07489 .46961 L
.07491 .46962 L
.0749 .46962 L
.07488 .4696 L
.07486 .46959 L
.07486 .46958 L
.07488 .46958 L
.07492 .46958 L
.07494 .46958 L
.07493 .46958 L
.07488 .46958 L
.0748 .46957 L
.07469 .46957 L
.07457 .46956 L
.07445 .46956 L
.07435 .46956 L
.07426 .46956 L
.07421 .46956 L
.07417 .46956 L
.07416 .46956 L
.07417 .46956 L
.07419 .46956 L
.07424 .46956 L
.07431 .46957 L
.07442 .46957 L
.07454 .46958 L
.07467 .46958 L
Mistroke
.07478 .46958 L
.07488 .46958 L
.07493 .46958 L
.07495 .46958 L
.07493 .46958 L
.07489 .46958 L
.07486 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46957 L
.07484 .46957 L
.07485 .46957 L
.07486 .46958 L
.07486 .46958 L
.07486 .46959 L
.07484 .46961 L
.07481 .46965 L
.07478 .4697 L
.07475 .46973 L
.07472 .46972 L
.07469 .46965 L
.07468 .46951 L
.07467 .46928 L
.07467 .46896 L
.07469 .46854 L
.0747 .46815 L
.07472 .4677 L
.07475 .46722 L
.07479 .46672 L
.07483 .46623 L
.07486 .4658 L
.07487 .46545 L
.07489 .46517 L
.07493 .46499 L
.07501 .4649 L
.0751 .46491 L
.0752 .46499 L
.07529 .46511 L
.07533 .46525 L
.07532 .46542 L
.07525 .46558 L
.07515 .46573 L
.07504 .46587 L
.07494 .466 L
.07484 .46611 L
.07474 .46618 L
Mistroke
.07461 .46623 L
.07445 .46625 L
.07426 .46621 L
.07403 .46612 L
.07378 .46601 L
.07354 .46594 L
.07336 .46589 L
.07324 .46587 L
.07321 .46592 L
.07325 .466 L
.07332 .46614 L
.0734 .46635 L
.07349 .46662 L
.07357 .46695 L
.07368 .46731 L
.07381 .46768 L
.07399 .46811 L
.0742 .46853 L
.07443 .46891 L
.07463 .46923 L
.07478 .46948 L
.07488 .46966 L
.07493 .46977 L
.07496 .46981 L
.07496 .46979 L
.07493 .46974 L
.07489 .46967 L
.07486 .46961 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
Mistroke
.07484 .4696 L
.07484 .46961 L
.07484 .46961 L
.07484 .46959 L
.07484 .46957 L
.07484 .46954 L
.07484 .46951 L
.07484 .46948 L
.07484 .46945 L
.07484 .46942 L
.07484 .46941 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .4694 L
.07484 .46942 L
.07484 .46944 L
.07484 .46947 L
.07484 .4695 L
.07484 .46953 L
.07484 .46957 L
.07484 .46959 L
.07484 .46961 L
.07484 .46961 L
.07484 .4696 L
.07484 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07485 .46959 L
.07486 .4696 L
.07487 .46961 L
Mistroke
.07487 .46961 L
.07486 .46959 L
.07484 .46957 L
.07481 .46954 L
.07478 .46951 L
.07475 .46948 L
.07473 .46945 L
.07471 .46943 L
.07469 .46941 L
.07468 .4694 L
.07468 .4694 L
.07468 .4694 L
.07469 .46941 L
.0747 .46942 L
.07472 .46944 L
.07474 .46947 L
.07478 .46951 L
.07482 .46956 L
.07486 .4696 L
.07488 .46962 L
.07488 .46962 L
.07486 .4696 L
.07483 .46957 L
.07479 .46952 L
.07475 .46948 L
.07473 .46946 L
.07472 .46944 L
.07471 .46944 L
.07471 .46944 L
.07471 .46944 L
.0747 .46942 L
.07468 .46941 L
.07467 .4694 L
.07467 .4694 L
.07469 .46943 L
.07472 .46947 L
.07474 .4695 L
.07474 .4695 L
.07473 .46947 L
.07469 .4694 L
.07462 .46929 L
.07454 .46917 L
.07447 .46903 L
.07443 .4689 L
.0744 .46881 L
.07437 .46874 L
.07431 .46868 L
.07422 .46861 L
.07408 .46851 L
.07393 .46841 L
Mistroke
.07379 .46832 L
.07366 .46823 L
.07356 .46817 L
.07349 .46815 L
.07343 .46818 L
.07335 .46821 L
.07327 .46828 L
.0732 .46836 L
.07315 .46843 L
.07311 .46847 L
.07309 .46853 L
.07311 .46863 L
.07317 .46877 L
.07323 .46889 L
.07327 .46902 L
.07329 .46916 L
.07328 .46928 L
.07325 .46938 L
.07324 .46945 L
.07328 .46951 L
.07336 .46953 L
.07347 .46953 L
.07359 .46953 L
.0737 .46951 L
.07378 .46947 L
.0738 .46941 L
.07381 .46934 L
.07383 .46929 L
.0739 .46926 L
.07399 .46923 L
.07409 .46921 L
.07418 .46918 L
.07422 .46915 L
.07425 .46913 L
.07426 .46912 L
.0743 .46914 L
.07436 .46918 L
.07445 .46923 L
.07456 .46928 L
.07467 .46932 L
.07476 .46935 L
.07477 .46937 L
.07469 .46936 L
.07453 .46934 L
.07432 .46931 L
.07412 .4693 L
.07396 .4693 L
.07385 .46931 L
.07374 .46935 L
.07365 .46938 L
Mistroke
.07353 .46944 L
.07342 .46951 L
.07332 .46959 L
.07322 .46965 L
.07316 .46967 L
.07313 .46963 L
.07312 .46953 L
.07316 .4694 L
.07321 .46925 L
.07326 .46909 L
.07329 .46893 L
.07335 .46876 L
.07338 .46865 L
.07348 .46859 L
.07363 .46855 L
.0738 .46852 L
.074 .46849 L
.0742 .46848 L
.07437 .4685 L
.07447 .46853 L
.07451 .46856 L
.07451 .46858 L
.07448 .46857 L
.07442 .46853 L
.07432 .46843 L
.07417 .46825 L
.07397 .46798 L
.07376 .46764 L
.07359 .46727 L
.07349 .46694 L
.07346 .46661 L
.07349 .46631 L
.07358 .46609 L
.0737 .46595 L
.07382 .46582 L
.07392 .46574 L
.07398 .46568 L
.07404 .46565 L
.07408 .46569 L
.07411 .4658 L
.07415 .46599 L
.07418 .4662 L
.07421 .4664 L
.0742 .46657 L
.07419 .46674 L
.07415 .46687 L
.0741 .46696 L
.07405 .46702 L
.07405 .46708 L
.07409 .46717 L
Mistroke
.07419 .46726 L
.07428 .46733 L
.07439 .46739 L
.0745 .46741 L
.0746 .46741 L
.07467 .46733 L
.07472 .46721 L
.07474 .46707 L
.07474 .46691 L
.07474 .46674 L
.07473 .46653 L
.07473 .46634 L
.07472 .4661 L
.0747 .46582 L
.07464 .46553 L
.07456 .46534 L
.07444 .46521 L
.0743 .46513 L
.07416 .46509 L
.07405 .46508 L
.07398 .46507 L
.07396 .46504 L
.07398 .46501 L
.07405 .465 L
.07416 .46503 L
.07428 .46507 L
.07438 .46513 L
.07445 .46523 L
.07449 .46535 L
.07452 .4655 L
.07455 .46571 L
.07458 .46594 L
.0746 .46617 L
.07457 .46638 L
.07448 .46657 L
.0743 .46673 L
.07407 .46686 L
.07383 .46692 L
.07359 .46692 L
.07339 .46691 L
.07326 .4669 L
.07316 .46688 L
.07311 .46691 L
.07307 .46697 L
.07303 .46708 L
.07299 .46721 L
.07294 .46739 L
.07289 .46764 L
.07286 .46791 L
.07287 .46816 L
Mistroke
.07294 .46845 L
.07307 .46876 L
.07324 .46903 L
.0734 .46924 L
.07355 .46939 L
.0737 .4695 L
.07383 .46953 L
.07396 .46952 L
.07406 .46946 L
.07413 .46935 L
.07418 .46919 L
.07419 .46904 L
.07417 .46892 L
.07412 .46883 L
.07407 .46881 L
.074 .46878 L
.07394 .46876 L
.07393 .46878 L
.07396 .46881 L
.07405 .46885 L
.07412 .46894 L
.07423 .46906 L
.07435 .46919 L
.07447 .46932 L
.07457 .46944 L
.07465 .46954 L
.0747 .46961 L
.07472 .46966 L
.07473 .46968 L
.07472 .46967 L
.07469 .46964 L
.07465 .4696 L
.07463 .46959 L
.07465 .46958 L
.07468 .46958 L
.07471 .46958 L
.07475 .46958 L
.07481 .46958 L
.07487 .46958 L
.07493 .46958 L
.07496 .46958 L
.07495 .4696 L
.07492 .46964 L
.07486 .46969 L
.07477 .46971 L
.07467 .46972 L
.07456 .46969 L
.07444 .46963 L
.07432 .46954 L
.0742 .4694 L
Mistroke
.07408 .46921 L
.07394 .46895 L
.07379 .46864 L
.07364 .46831 L
.07349 .46797 L
.07336 .46768 L
.07326 .46746 L
.07322 .46733 L
.07324 .4673 L
.07331 .46732 L
.0734 .46739 L
.07353 .46753 L
.07366 .46771 L
.07378 .4679 L
.0739 .46811 L
.07403 .46831 L
.07417 .46849 L
.0743 .46863 L
.0744 .46874 L
.07446 .46881 L
.07448 .46884 L
.07445 .46881 L
.07437 .46876 L
.07428 .46871 L
.0742 .46872 L
.07412 .46874 L
.07407 .46882 L
.07406 .46893 L
.07409 .46907 L
.07412 .46915 L
.07417 .46923 L
.07422 .46928 L
.07429 .4693 L
.07436 .46932 L
.07444 .46937 L
.07454 .46942 L
.07466 .46946 L
.07474 .46946 L
.07478 .46946 L
.07477 .46945 L
.07471 .46944 L
.0746 .46942 L
.07448 .46941 L
.07437 .46942 L
.07429 .46943 L
.07423 .46944 L
.07419 .46947 L
.07419 .46951 L
.07419 .46954 L
.07419 .46955 L
Mistroke
.0742 .46955 L
.07424 .46955 L
.07428 .46951 L
.07432 .46943 L
.07434 .46929 L
.07435 .4691 L
.07433 .4689 L
.07429 .46869 L
.07423 .4685 L
.07416 .46833 L
.07409 .46823 L
.07403 .46818 L
.074 .46817 L
.074 .4682 L
.07401 .46827 L
.07403 .46836 L
.07407 .46851 L
.07413 .4687 L
.07419 .46891 L
.07426 .46911 L
.07433 .46928 L
.07438 .46941 L
.07442 .46949 L
.07444 .46952 L
.07445 .46954 L
.07447 .46954 L
.07449 .46951 L
.07453 .4695 L
.0746 .46951 L
.07468 .46954 L
.07477 .46957 L
.07484 .46959 L
.07491 .46962 L
.07494 .46963 L
.07495 .46963 L
.07492 .46962 L
.07488 .4696 L
.07484 .46957 L
.0748 .46954 L
.07476 .46951 L
.07473 .4695 L
.07473 .46951 L
.07472 .46953 L
.07471 .46954 L
.0747 .46952 L
.07467 .46949 L
.07463 .46942 L
.07456 .4693 L
.07447 .46914 L
.07436 .46896 L
Mistroke
.07425 .46876 L
.07415 .46857 L
.07407 .46841 L
.07401 .46828 L
.07397 .46821 L
.07394 .46817 L
.07394 .46815 L
.07396 .4682 L
.07401 .46828 L
.07409 .46839 L
.07421 .46858 L
.07435 .46881 L
.0745 .46904 L
.07464 .46927 L
.07475 .46946 L
.07484 .46959 L
.07489 .46967 L
.07492 .4697 L
.07493 .46971 L
.07493 .4697 L
.07492 .46967 L
.0749 .46964 L
.07488 .46961 L
.07486 .4696 L
.07483 .46957 L
.0748 .46954 L
.07477 .46951 L
.07476 .46949 L
.07477 .46946 L
.07476 .46943 L
.07473 .4694 L
.07466 .46936 L
.07457 .46933 L
.07445 .46929 L
.07433 .46927 L
.07422 .46925 L
.07413 .46925 L
.07407 .46927 L
.07406 .46932 L
.0741 .4694 L
.07416 .46948 L
.07422 .46953 L
.07427 .46956 L
.07431 .46957 L
.07433 .46953 L
.07432 .46943 L
.07428 .46928 L
.07423 .4691 L
.07416 .46889 L
.07408 .46869 L
Mistroke
.07397 .4685 L
.07387 .46833 L
.07375 .46822 L
.07367 .46815 L
.07365 .46813 L
.07369 .46818 L
.07376 .46827 L
.07388 .46839 L
.07404 .46857 L
.07423 .4688 L
.07443 .46903 L
.07461 .46926 L
.07477 .46945 L
.07489 .4696 L
.07494 .46969 L
.07494 .46973 L
.07489 .46974 L
.07483 .46971 L
.07478 .46964 L
.07478 .46956 L
.07482 .4695 L
.07488 .46946 L
.07497 .46943 L
.07506 .46941 L
.07515 .46939 L
.07521 .46938 L
.07525 .46938 L
.07528 .46938 L
.07529 .46938 L
.07529 .4694 L
.07529 .46942 L
.0753 .46945 L
.07527 .46949 L
.07521 .46953 L
.07512 .46957 L
.07503 .4696 L
.07494 .46963 L
.07488 .46967 L
.07485 .46971 L
.07484 .46973 L
.07486 .46972 L
.07489 .46966 L
.07489 .46956 L
.07482 .46943 L
.07471 .46929 L
.07456 .46914 L
.07438 .46896 L
.07417 .46877 L
.07393 .46857 L
.0737 .46838 L
Mistroke
.07348 .46824 L
.0733 .46814 L
.07317 .4681 L
.07309 .46809 L
.07305 .4681 L
.07303 .4681 L
.07305 .46809 L
.07309 .46806 L
.07316 .46801 L
.07323 .46795 L
.07332 .46788 L
.07341 .4678 L
.0735 .46771 L
.07358 .46763 L
.07367 .46763 L
.07377 .46768 L
.07385 .46778 L
.07392 .46788 L
.074 .468 L
.07408 .46815 L
.07418 .46838 L
.07427 .46861 L
.07439 .46887 L
.07451 .46911 L
.0746 .46929 L
.07466 .4694 L
.07471 .46946 L
.07475 .46949 L
.07478 .46949 L
.07481 .46948 L
.07482 .46948 L
.07479 .46949 L
.07473 .46948 L
.07463 .46947 L
.07453 .46949 L
.07443 .46955 L
.07433 .46963 L
.07424 .46971 L
.07415 .46974 L
.07406 .4697 L
.074 .46958 L
.07399 .46938 L
.07403 .46908 L
.07416 .4687 L
.07439 .46826 L
.07471 .4678 L
.0751 .46737 L
.07551 .46697 L
.0759 .46659 L
.07622 .46624 L
Mistroke
.07644 .46594 L
.07656 .46572 L
.07658 .46564 L
.07651 .46571 L
.07638 .46595 L
.07622 .46631 L
.07601 .46675 L
.07581 .46722 L
.07555 .46769 L
.07526 .46809 L
.07498 .46837 L
.07475 .46859 L
.07458 .46876 L
.07452 .46889 L
.07454 .46899 L
.07463 .46907 L
.07478 .46914 L
.07495 .4692 L
.07512 .4692 L
.07524 .46916 L
.0753 .46908 L
.07529 .469 L
.07523 .46896 L
.07513 .46896 L
.07501 .46903 L
.07491 .46913 L
.07482 .46923 L
.07471 .46931 L
.0746 .46934 L
.07449 .46935 L
.07436 .46929 L
.07424 .46921 L
.07412 .46912 L
.07403 .46901 L
.07397 .46888 L
.07392 .46869 L
.0739 .46846 L
.07389 .46819 L
.07386 .46794 L
.07382 .46773 L
.07378 .46756 L
.07373 .46745 L
.07367 .4674 L
.07364 .46741 L
.07366 .4675 L
.07373 .46766 L
.07383 .46787 L
.07393 .46809 L
.07406 .46833 L
.07419 .46856 L
Mistroke
.07431 .46878 L
.07444 .469 L
.07453 .46917 L
.07463 .46933 L
.0747 .46944 L
.07475 .46951 L
.07479 .46956 L
.07482 .46959 L
.07484 .4696 L
.07485 .4696 L
.07488 .46962 L
.07492 .46964 L
.07495 .46966 L
.07497 .46964 L
.07495 .46961 L
.07489 .46957 L
.0748 .46954 L
.0747 .4695 L
.07458 .46947 L
.07446 .46943 L
.07435 .46941 L
.07427 .4694 L
.0742 .4694 L
.07417 .46941 L
.07416 .46942 L
.07417 .46942 L
.07419 .46942 L
.07424 .46942 L
.07432 .46942 L
.07443 .46942 L
.07455 .46942 L
.07468 .46942 L
.07479 .46942 L
.07487 .46942 L
.07493 .46942 L
.07496 .46943 L
.07497 .46945 L
.07495 .4695 L
.07495 .46955 L
.07496 .46959 L
.07495 .46959 L
.0749 .46953 L
.07478 .4694 L
.07464 .4692 L
.07447 .46897 L
.07429 .46873 L
.07411 .4685 L
.07395 .4683 L
.07381 .46815 L
.07373 .46808 L
Mistroke
.07365 .46805 L
.07359 .46806 L
.07356 .4681 L
.07355 .46817 L
.0736 .46831 L
.0737 .46851 L
.07387 .46874 L
.07404 .46899 L
.07423 .46923 L
.07443 .46943 L
.07461 .46956 L
.07471 .46961 L
.07476 .46959 L
.07476 .46953 L
.07472 .46947 L
.07464 .46942 L
.07455 .46939 L
.07446 .46939 L
.07437 .4694 L
.0743 .46941 L
.07424 .46942 L
.07421 .46942 L
.07418 .46941 L
.07418 .4694 L
.07419 .46941 L
.07424 .46943 L
.07431 .46946 L
.07442 .4695 L
.07454 .46954 L
.07468 .46958 L
.07482 .46962 L
.07493 .46964 L
.075 .46965 L
.075 .46962 L
.07493 .46958 L
.07484 .46954 L
.07474 .4695 L
.07465 .46946 L
.07458 .46943 L
.07452 .4694 L
.07447 .46938 L
.07445 .46937 L
.07444 .46937 L
.07443 .46937 L
.07444 .46938 L
.07446 .46939 L
.0745 .46942 L
.07456 .46945 L
.07462 .46949 L
.0747 .46953 L
Mistroke
.07478 .46957 L
.07484 .4696 L
.0749 .46962 L
.07493 .46964 L
.07494 .46964 L
.07491 .46963 L
.07488 .46962 L
.07486 .46961 L
.07483 .46959 L
.0748 .46955 L
.07475 .4695 L
.07469 .46948 L
.07463 .46946 L
.07458 .46942 L
.07453 .46935 L
.0745 .46924 L
.07449 .46908 L
.0745 .46888 L
.07454 .46864 L
.07461 .46837 L
.07466 .46808 L
.07471 .46778 L
.07472 .46748 L
.07471 .46719 L
.07467 .46691 L
.0746 .46664 L
.07453 .46636 L
.07445 .46612 L
.07439 .46589 L
.07434 .46567 L
.07431 .46553 L
.07429 .46543 L
.07429 .46534 L
.0743 .46526 L
.07435 .46521 L
.07445 .46516 L
.07459 .46513 L
.07475 .46517 L
.07492 .46526 L
.07505 .46541 L
.07512 .46558 L
.07509 .46575 L
.07497 .46591 L
.07477 .46609 L
.07451 .46626 L
.07425 .46643 L
.07401 .46662 L
.07382 .46682 L
.07367 .46705 L
.07358 .46727 L
Mistroke
.07352 .46748 L
.07349 .46765 L
.07349 .46783 L
.07352 .46796 L
.07358 .46808 L
.07365 .46818 L
.07371 .4682 L
.07376 .4682 L
.07378 .46821 L
.07377 .46819 L
.0737 .46814 L
.07356 .46803 L
.07338 .46789 L
.07322 .46781 L
.07307 .46769 L
.07294 .46759 L
.07285 .46752 L
.07281 .46752 L
.0728 .46753 L
.07279 .46756 L
.07278 .46759 L
.07277 .46763 L
.07274 .46766 L
.07269 .46766 L
.07266 .46766 L
.07262 .46764 L
.07258 .46763 L
.07252 .46763 L
.07245 .46763 L
.07237 .46768 L
.07231 .46773 L
.07227 .46773 L
.07227 .46772 L
.07233 .46766 L
.07245 .46756 L
.07262 .46743 L
.07282 .4673 L
.07306 .4672 L
.07331 .46712 L
.07357 .46702 L
.07381 .46694 L
.07405 .46684 L
.07428 .46673 L
.07449 .46663 L
.07468 .46658 L
.07484 .46658 L
.07494 .46659 L
.07497 .46663 L
.07498 .46672 L
.07496 .46687 L
Mistroke
.07495 .46704 L
.07494 .46719 L
.07491 .46736 L
.07485 .46752 L
.07476 .46769 L
.07464 .46791 L
.0745 .46818 L
.07437 .46851 L
.07426 .46879 L
.07416 .46906 L
.07405 .46932 L
.07393 .46947 L
.0738 .46953 L
.07368 .46946 L
.07359 .46929 L
.07354 .46903 L
.07357 .46872 L
.07366 .46845 L
.07378 .46823 L
.07391 .46802 L
.07401 .46782 L
.07403 .46759 L
.07399 .46735 L
.07389 .46712 L
.07374 .46696 L
.07358 .46686 L
.07344 .46687 L
.07336 .46697 L
.0733 .46711 L
.07329 .46724 L
.07329 .46733 L
.07331 .46737 L
.07335 .46735 L
.07345 .46726 L
.07361 .46716 L
.07383 .46705 L
.07411 .46694 L
.07436 .4668 L
.0746 .46668 L
.07481 .46656 L
.07496 .46642 L
.07506 .46622 L
.07509 .46599 L
.07507 .46578 L
.07499 .46558 L
.07488 .46545 L
.07474 .46541 L
.07458 .46546 L
.07441 .46559 L
.07425 .46578 L
Mistroke
.07412 .46597 L
.07405 .46615 L
.07405 .46635 L
.07409 .46658 L
.07412 .46687 L
.07416 .46712 L
.0742 .46738 L
.07425 .46762 L
.07428 .46782 L
.07428 .46798 L
.07422 .46809 L
.07411 .46818 L
.07395 .46824 L
.07374 .46828 L
.07354 .4683 L
.07336 .46829 L
.07316 .46828 L
.07307 .46824 L
.07304 .46814 L
.07309 .46794 L
.07319 .46765 L
.07333 .46728 L
.07348 .46689 L
.07361 .46654 L
.07375 .46631 L
.07388 .46619 L
.07398 .46616 L
.07405 .46619 L
.07412 .46624 L
.07419 .46631 L
.07426 .46643 L
.07431 .46662 L
.07435 .46686 L
.0744 .46713 L
.07447 .46741 L
.07452 .46762 L
.07461 .46776 L
.0747 .46783 L
.07477 .46784 L
.07478 .4678 L
.07474 .46779 L
.07465 .46783 L
.07455 .46789 L
.07447 .46802 L
.07441 .46816 L
.07438 .46828 L
.07437 .46838 L
.07438 .46842 L
.07442 .46838 L
.07449 .46828 L
Mistroke
.07456 .46808 L
.07464 .46783 L
.07472 .46757 L
.07479 .46729 L
.07484 .46696 L
.07485 .46661 L
.07484 .46627 L
.07482 .46603 L
.0748 .46583 L
.0748 .4657 L
.07484 .46562 L
.07493 .4656 L
.07507 .46561 L
.07525 .46565 L
.0755 .4657 L
.07573 .46573 L
.07601 .4657 L
.0763 .46562 L
.07662 .46553 L
.07694 .46543 L
.07722 .46533 L
.07744 .46525 L
.07758 .46523 L
.07764 .46522 L
.07761 .46524 L
.07752 .46527 L
.07738 .46531 L
.07723 .46533 L
.0771 .46535 L
.07701 .46535 L
.07695 .46536 L
.07692 .46535 L
.0769 .46536 L
.07687 .46534 L
.07688 .46531 L
.07694 .46525 L
.07706 .46515 L
.07724 .46505 L
.07748 .46495 L
.07775 .46486 L
.07805 .4648 L
.07834 .46476 L
.07863 .46476 L
.07892 .46479 L
.0792 .46482 L
.0795 .46482 L
.0798 .46481 L
.08005 .46479 L
.08022 .46479 L
.08026 .4648 L
Mistroke
.08018 .46481 L
.07999 .46481 L
.07969 .4648 L
.07932 .46481 L
.07891 .46484 L
.07854 .46491 L
.07819 .46505 L
.0779 .46524 L
.07764 .46547 L
.07747 .46571 L
.0773 .46597 L
.07715 .46626 L
.07707 .46655 L
.07702 .46684 L
.07699 .46711 L
.07694 .46734 L
.07683 .4675 L
.07664 .46758 L
.07635 .46758 L
.07596 .46751 L
.07551 .46735 L
.07497 .46713 L
.07442 .46686 L
.07392 .46653 L
.07353 .46622 L
.07325 .4659 L
.07309 .4656 L
.07302 .46536 L
.07304 .46519 L
.07313 .4651 L
.07328 .46511 L
.07349 .46517 L
.07373 .4653 L
.07399 .46548 L
.07425 .46566 L
.07449 .46579 L
.07469 .46586 L
.07484 .46589 L
.07491 .46588 L
.07495 .46585 L
.07496 .46582 L
.07497 .46576 L
.075 .46566 L
.07502 .46551 L
.07505 .46535 L
.07506 .46518 L
.07502 .46504 L
.07492 .46493 L
.07477 .46487 L
.07457 .46486 L
Mistroke
.07436 .46492 L
.07415 .465 L
.07398 .46508 L
.07385 .46513 L
.07376 .46516 L
.07371 .46517 L
.0737 .46517 L
.07374 .46517 L
.07381 .46517 L
.0739 .46517 L
.07403 .46517 L
.07419 .46517 L
.07438 .46518 L
.07459 .46519 L
.07481 .46519 L
.07503 .46519 L
.07527 .46515 L
.07552 .46507 L
.07579 .465 L
.07608 .46494 L
.07634 .46493 L
.07658 .46495 L
.07679 .46499 L
.07697 .46502 L
.07706 .46505 L
.07706 .46509 L
.07698 .46516 L
.0768 .46531 L
.07656 .46552 L
.07626 .4658 L
.07592 .4661 L
.07558 .46638 L
.07526 .46662 L
.07499 .46679 L
.07479 .46688 L
.07467 .46688 L
.0746 .46682 L
.07459 .46672 L
.07463 .4666 L
.07469 .46643 L
.07477 .46628 L
.07484 .4661 L
.0749 .46589 L
.07494 .46565 L
.07497 .4654 L
.075 .46517 L
.07501 .46498 L
.075 .46489 L
.07499 .46487 L
.07498 .4649 L
Mistroke
.07498 .46493 L
.07498 .46495 L
.07498 .46495 L
.07499 .46493 L
.07499 .46491 L
.07499 .46488 L
.07499 .46487 L
.07499 .46486 L
.075 .46487 L
.07503 .46488 L
.07505 .46489 L
.07505 .46489 L
.07503 .46489 L
.07499 .4649 L
.07492 .4649 L
.07482 .4649 L
.0747 .4649 L
.07459 .4649 L
.07451 .4649 L
.07448 .4649 L
.07451 .4649 L
.07461 .4649 L
.07476 .4649 L
.07495 .4649 L
.0752 .46489 L
.07549 .46489 L
.07582 .46489 L
.07617 .46488 L
.07652 .46488 L
.07686 .46487 L
.07717 .46487 L
.07744 .46486 L
.07764 .46486 L
.07776 .46486 L
.07781 .46486 L
.0778 .46486 L
.07777 .46486 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07769 .46482 L
.07775 .46479 L
.07782 .46478 L
.07783 .4648 L
.07779 .46485 L
.07769 .46492 L
Mistroke
.07752 .46501 L
.0773 .46508 L
.07706 .46513 L
.0768 .46515 L
.07651 .46516 L
.07618 .46518 L
.0758 .46525 L
.07542 .46538 L
.07505 .46556 L
.07468 .46576 L
.07435 .46597 L
.07411 .46614 L
.07396 .46629 L
.07389 .4664 L
.07391 .46646 L
.07397 .4665 L
.07406 .46652 L
.07416 .46651 L
.07427 .46648 L
.07438 .46641 L
.0745 .46624 L
.07463 .46601 L
.07472 .46579 L
.07476 .46559 L
.07472 .46547 L
.0746 .4654 L
.07441 .46542 L
.07419 .46551 L
.07398 .46562 L
.07383 .46571 L
.07376 .46577 L
.07375 .46579 L
.07378 .46575 L
.0738 .46568 L
.07383 .46564 L
.07385 .46558 L
.0739 .46551 L
.07396 .46543 L
.07403 .46536 L
.07408 .46533 L
.0741 .46536 L
.07408 .46547 L
.07398 .46569 L
.07386 .46598 L
.07373 .46638 L
.07363 .46682 L
.0736 .46726 L
.07369 .46771 L
.07389 .46811 L
.07417 .46843 L
Mistroke
.07454 .46875 L
.07496 .46902 L
.07539 .46924 L
.07582 .46941 L
.0762 .46954 L
.07655 .46962 L
.07686 .46967 L
.07712 .46968 L
.07734 .46968 L
.07749 .46965 L
.07755 .46961 L
.07754 .46957 L
.07751 .46955 L
.07747 .46954 L
.07744 .46954 L
.07745 .46954 L
.07752 .46954 L
.07766 .46954 L
.07786 .46954 L
.07809 .46953 L
.07835 .46953 L
.07863 .46953 L
.0789 .46952 L
.07917 .46952 L
.07944 .46952 L
.07968 .46951 L
.0799 .46951 L
.08006 .46951 L
.08018 .46951 L
.08025 .4695 L
.08027 .4695 L
.08024 .4695 L
.08016 .46951 L
.08008 .46951 L
.08 .46951 L
.07997 .46951 L
.07997 .46951 L
.08002 .46951 L
.08011 .4695 L
.08027 .4695 L
.08047 .4695 L
.08071 .4695 L
.08095 .4695 L
.0812 .46949 L
.08144 .46949 L
.08167 .46949 L
.08191 .46949 L
.08216 .46949 L
.08243 .46948 L
.0827 .46948 L
Mistroke
.08303 .46948 L
.08332 .46947 L
.08363 .46947 L
.08391 .46946 L
.08417 .46946 L
.08441 .46946 L
.08461 .46945 L
.08475 .46945 L
.08478 .46945 L
.08468 .46945 L
.08445 .46945 L
.08412 .46944 L
.08364 .4694 L
.08321 .46935 L
.08267 .46931 L
.08218 .46933 L
.08177 .4694 L
.08143 .46952 L
.08121 .46968 L
.08111 .46986 L
.08108 .47006 L
.08107 .47025 L
.08106 .47044 L
.08107 .47062 L
.08108 .47078 L
.08104 .47091 L
.08095 .47101 L
.08082 .47108 L
.08068 .47108 L
.08049 .47103 L
.08027 .47089 L
.08006 .47073 L
.07988 .47051 L
.07973 .47026 L
.07965 .47005 L
.07966 .46986 L
.07974 .46973 L
.07984 .46965 L
.07995 .46961 L
.08003 .46956 L
.08009 .4695 L
.08014 .46946 L
.08017 .46944 L
.08018 .46944 L
.08016 .46946 L
.08013 .46947 L
.08012 .46949 L
.08011 .4695 L
.08011 .46951 L
.08011 .46951 L
Mistroke
.08011 .46951 L
.08011 .46951 L
.08011 .46951 L
.08012 .46951 L
.08013 .46952 L
.08016 .46953 L
.08019 .46954 L
.08021 .46954 L
.08018 .46953 L
.08011 .46952 L
.08002 .46952 L
.07992 .46952 L
.07983 .46951 L
.07979 .46946 L
.0798 .46937 L
.07984 .46923 L
.07988 .46906 L
.07993 .46887 L
.07993 .46872 L
.07986 .46861 L
.07974 .46854 L
.07962 .46849 L
.0795 .46847 L
.07937 .46845 L
.07922 .46843 L
.07908 .46844 L
.07895 .46844 L
.07878 .46844 L
.07857 .46842 L
.07839 .46837 L
.0782 .46824 L
.07802 .46802 L
.07794 .46771 L
.07797 .46737 L
.07802 .46701 L
.07808 .46668 L
.07816 .46635 L
.07824 .46617 L
.0783 .46607 L
.07834 .46606 L
.07841 .4661 L
.07851 .46615 L
.07864 .46618 L
.07885 .46618 L
.07913 .46617 L
.07946 .46616 L
.07984 .46618 L
.08017 .46614 L
.08056 .46608 L
.08094 .46592 L
Mistroke
.08129 .46568 L
.08159 .46541 L
.08185 .46514 L
.08206 .46491 L
.08226 .46474 L
.0824 .46464 L
.08257 .46461 L
.08275 .46459 L
.08291 .46457 L
.08298 .46453 L
.08302 .46452 L
.08298 .46456 L
.08287 .46466 L
.08273 .46486 L
.08255 .46515 L
.08235 .46553 L
.08211 .46598 L
.08181 .46646 L
.08147 .46696 L
.08106 .46745 L
.08065 .46793 L
.08019 .46833 L
.07971 .46862 L
.07923 .46877 L
.0788 .4688 L
.07844 .4687 L
.0782 .46851 L
.07804 .4683 L
.07798 .46807 L
.07801 .46786 L
.07809 .4677 L
.0782 .46764 L
.07835 .46768 L
.07855 .4678 L
.0788 .46796 L
.07908 .46819 L
.07937 .46845 L
.07966 .46874 L
.07989 .46903 L
.08007 .46928 L
.08018 .46949 L
.08024 .46964 L
.08026 .46971 L
.08024 .4697 L
.0802 .46966 L
.08019 .46958 L
.08021 .46953 L
.08023 .46951 L
.08024 .4695 L
.08023 .46951 L
Mistroke
.08017 .46951 L
.08005 .46952 L
.07988 .46952 L
.07966 .46953 L
.07941 .46953 L
.07915 .46954 L
.07886 .46954 L
.07863 .46952 L
.07846 .46947 L
.07825 .46939 L
.07806 .46932 L
.07789 .46929 L
.07775 .46931 L
.07759 .46941 L
.07739 .4696 L
.07712 .46989 L
.07679 .47025 L
.07642 .47068 L
.07599 .47115 L
.07544 .47165 L
.07487 .47216 L
.07428 .47261 L
.07374 .47309 L
.07322 .47354 L
.07275 .47393 L
.07236 .47424 L
.07206 .47445 L
.07187 .47456 L
.07177 .47458 L
.07177 .47454 L
.07182 .47443 L
.07191 .47428 L
.07199 .47412 L
.07204 .47399 L
.07206 .47394 L
.07207 .47397 L
.07206 .47412 L
.07205 .47439 L
.07204 .47481 L
.07202 .47534 L
.072 .47597 L
.07198 .47666 L
.07195 .47739 L
.07193 .4781 L
.0719 .4788 L
.07188 .4795 L
.07186 .48016 L
.07185 .48071 L
.07185 .48108 L
.07185 .48129 L
Mistroke
.07185 .48136 L
.07184 .48136 L
.07183 .48133 L
.07182 .48132 L
Mfstroke
.07057 .49125 m
.07053 .49138 L
.07053 .49139 L
.07057 .4913 L
.07061 .49113 L
.07069 .49091 L
.07078 .49068 L
.07088 .49044 L
.07098 .49022 L
.07107 .49001 L
.07117 .48983 L
.07128 .48962 L
.0714 .48945 L
.07151 .48919 L
.0716 .4889 L
.07166 .48862 L
.07168 .48836 L
.07166 .4881 L
.07164 .48785 L
.07162 .48759 L
.07162 .48733 L
.07163 .48708 L
.07163 .48683 L
.07164 .48661 L
.07165 .48639 L
.07166 .48617 L
.07167 .48595 L
.07167 .48578 L
.07168 .48572 L
.07167 .48577 L
.07166 .48593 L
.07165 .48617 L
.07164 .48647 L
.07162 .48681 L
.0716 .48715 L
.07159 .48746 L
.07158 .48775 L
.07156 .48803 L
.07154 .48827 L
.0715 .48847 L
.07145 .48863 L
.07141 .48873 L
.07139 .48875 L
.07139 .48871 L
.07142 .48864 L
.07149 .48858 L
.07159 .48858 L
s
.07144 .48911 m
.07137 .48897 L
.07137 .48887 L
.07142 .48883 L
.07145 .48881 L
.07146 .48878 L
.07139 .48874 L
.07126 .48869 L
.07109 .48867 L
.07094 .48875 L
.07082 .48895 L
.07075 .48928 L
.07071 .48969 L
.07068 .49009 L
.07062 .4905 L
.07054 .49085 L
.07044 .49109 L
.07035 .49124 L
.07028 .4913 L
.07023 .49129 L
.07021 .49124 L
.07021 .49116 L
.07023 .49109 L
.07023 .49101 L
.07021 .49092 L
.07016 .49084 L
.07012 .49078 L
.07011 .49077 L
.07017 .49089 L
.0703 .49113 L
.07047 .49148 L
.07073 .49195 L
.07093 .49233 L
.0711 .49266 L
.07123 .49293 L
.07131 .49304 L
.07136 .49305 L
.07142 .49299 L
.07147 .4929 L
.0715 .49285 L
.0715 .49288 L
.07145 .49299 L
.07134 .49319 L
.07119 .4935 L
.07103 .4939 L
.0709 .49437 L
.0708 .49486 L
.07071 .49535 L
.07062 .4959 L
.07053 .49637 L
Mistroke
.07039 .49698 L
.07022 .49754 L
.07001 .49808 L
.0698 .49857 L
.06963 .49899 L
.06952 .49932 L
.06946 .49956 L
.06947 .49972 L
.0695 .4998 L
.06955 .49984 L
.06961 .49992 L
.06967 .50006 L
.06976 .50022 L
.06989 .50033 L
.07009 .50039 L
.07034 .50039 L
.07063 .50037 L
.07091 .50034 L
.07116 .50031 L
.07134 .50028 L
.07143 .50026 L
.07144 .50023 L
.07136 .50018 L
.07122 .50011 L
.07101 .50004 L
.07075 .49998 L
.07046 .49993 L
.07015 .49989 L
.06985 .49987 L
.06958 .49988 L
.06936 .49991 L
.0692 .49996 L
.0691 .50002 L
.06908 .50008 L
.06913 .50012 L
.06925 .50014 L
.06944 .50012 L
.0697 .50005 L
.06999 .49992 L
.07031 .49975 L
.07064 .49954 L
.07091 .49928 L
.07111 .49901 L
.0712 .49874 L
.07123 .49849 L
.07118 .49827 L
.07109 .49808 L
.07097 .49793 L
.07086 .49782 L
.07078 .49776 L
Mistroke
.07074 .49775 L
.07072 .49776 L
.07072 .4978 L
.07072 .49784 L
.07072 .49787 L
.07075 .49788 L
.07081 .49788 L
.0709 .49788 L
.071 .49788 L
.0711 .49788 L
.0712 .49787 L
.07127 .49787 L
.07132 .4979 L
.07133 .49795 L
.07131 .49802 L
.07127 .49809 L
.07125 .49813 L
.07124 .49813 L
.07124 .49807 L
.07124 .49794 L
Mfstroke
.07449 .47663 m
.07455 .47666 L
.07451 .4767 L
.07438 .47676 L
.07416 .47682 L
.07388 .47686 L
.07357 .47686 L
.07325 .47681 L
.07295 .47673 L
.07267 .47659 L
.07243 .47642 L
.07222 .4762 L
.07204 .47595 L
.0719 .47565 L
.0718 .47535 L
.07175 .47505 L
.07176 .47477 L
.07182 .47455 L
.07192 .4744 L
.07206 .47434 L
.07223 .47438 L
.07243 .47451 L
.07266 .4747 L
.07292 .47495 L
.07319 .47524 L
.07348 .47554 L
.07376 .47584 L
.07401 .47609 L
.07423 .47629 L
.07441 .47643 L
.07453 .47652 L
.0746 .47656 L
.07461 .47654 L
.07457 .47649 L
.07452 .47642 L
.07446 .47634 L
.0744 .47628 L
.07436 .47624 L
.07434 .47622 L
.07434 .47622 L
.07435 .47624 L
.07438 .47628 L
.07442 .47635 L
.07449 .47644 L
.07456 .47654 L
.07462 .47662 L
.07465 .47666 L
.07465 .47667 L
.07463 .47663 L
.07458 .47656 L
Mistroke
.07451 .47646 L
.07444 .47637 L
.07439 .4763 L
.07436 .47626 L
.07434 .47623 L
.07433 .47622 L
.07434 .47622 L
.07435 .47623 L
.07438 .47628 L
.07443 .47634 L
.07448 .47641 L
.07453 .47647 L
.07457 .47653 L
.07459 .47656 L
.07457 .47655 L
.07451 .4765 L
.07441 .4764 L
.07429 .47627 L
.07416 .47612 L
.07404 .47599 L
.07396 .4759 L
.07394 .47587 L
.07396 .47587 L
.074 .4759 L
.07404 .47595 L
.07407 .47598 L
.07408 .47599 L
.07406 .47599 L
.07403 .47597 L
.07397 .47593 L
.07388 .47587 L
.07376 .47579 L
.07363 .47569 L
.07349 .47559 L
.07334 .47549 L
.07319 .47539 L
.07305 .47527 L
.07289 .47514 L
.07274 .47502 L
.07262 .47493 L
.07253 .47489 L
.07248 .47489 L
.07248 .47493 L
.07253 .47502 L
.07263 .47514 L
.07276 .47528 L
.07289 .47541 L
.07303 .47553 L
.07315 .47563 L
.07325 .47569 L
Mistroke
.07332 .47573 L
.07338 .47576 L
.07344 .47579 L
.07349 .47579 L
.07351 .47577 L
.07352 .47573 L
.07349 .47566 L
.07342 .47555 L
.07333 .47543 L
.07326 .47533 L
.07324 .4753 L
.07328 .47534 L
.07339 .47545 L
.07354 .4756 L
.07374 .47577 L
.0739 .47592 L
.07401 .47601 L
.07406 .47606 L
.07403 .47602 L
.0739 .4759 L
.07369 .47572 L
.07345 .47552 L
.07322 .47532 L
.07298 .47513 L
.07276 .47495 L
.07254 .47477 L
.07234 .4746 L
.07217 .47443 L
.07205 .47431 L
.072 .47425 L
.07198 .47428 L
.072 .47438 L
.07203 .47453 L
.07206 .47471 L
.07209 .47488 L
.07209 .47501 L
.07208 .47511 L
.07206 .47517 L
.07204 .4752 L
.07203 .47519 L
.07201 .47517 L
.072 .47512 L
.07198 .47506 L
.07196 .47496 L
.07193 .47482 L
.07191 .47466 L
.0719 .4745 L
.07192 .47436 L
.07198 .47427 L
.0721 .47427 L
Mistroke
.07229 .47437 L
.07253 .47459 L
.0728 .47487 L
.07307 .47516 L
.07332 .47542 L
.07353 .47562 L
.07369 .47578 L
.0738 .47587 L
.07384 .47591 L
.07382 .47589 L
.07373 .47582 L
.07358 .47568 L
.07338 .4755 L
.07312 .47526 L
.07282 .47498 L
.0725 .4747 L
.07221 .47444 L
.07199 .47424 L
.07187 .47413 L
.07186 .47413 L
.07198 .47424 L
.07219 .47443 L
.07245 .47467 L
.07274 .47493 L
.073 .47517 L
.07322 .47538 L
.07338 .47553 L
.07349 .47563 L
.07355 .47568 L
.07355 .47568 L
.07349 .47562 L
.07338 .47551 L
.07322 .47537 L
.07304 .4752 L
.07283 .47503 L
.0726 .47486 L
.07237 .47475 L
.07217 .47471 L
.07205 .47472 L
.07201 .47475 L
.07205 .47476 L
.07217 .47472 L
.07237 .47459 L
.07259 .47437 L
.07283 .47406 L
.07309 .47365 L
.07334 .47316 L
.0736 .47265 L
.07385 .47214 L
.07412 .47167 L
Mistroke
.07437 .4712 L
.07459 .47072 L
.07476 .47024 L
.07486 .46979 L
.07486 .46938 L
.07476 .46899 L
.07455 .46861 L
.07428 .46822 L
.07403 .46782 L
.07381 .46742 L
.07366 .46702 L
.07357 .46656 L
.07352 .46609 L
.07348 .46565 L
.07346 .46526 L
.07343 .46496 L
.07339 .46477 L
.07333 .46468 L
.07328 .46469 L
.07325 .46477 L
.07327 .46487 L
.07331 .46497 L
.07331 .46504 L
.07326 .46512 L
.07317 .46524 L
.07308 .46536 L
.07299 .4655 L
.07294 .46565 L
.07294 .46578 L
.073 .46587 L
.07313 .46592 L
.07329 .46593 L
.07346 .4659 L
.07361 .46585 L
.07373 .46581 L
.07381 .46574 L
.07384 .46571 L
.07388 .46564 L
.07392 .46555 L
.07397 .46545 L
.07406 .46535 L
.07418 .46525 L
.07432 .46514 L
.07443 .46507 L
.07452 .46504 L
.07459 .46504 L
.07465 .46506 L
.07469 .46507 L
.07474 .46506 L
.07477 .46503 L
Mistroke
.07479 .46499 L
.07478 .46496 L
.07475 .46492 L
.07473 .4649 L
.07471 .46489 L
.07467 .4649 L
.07461 .46492 L
.0745 .46497 L
.07438 .46502 L
.07425 .46507 L
.07416 .46511 L
.07409 .46514 L
.07405 .46518 L
.07403 .46523 L
.07404 .4653 L
.07407 .46537 L
.0741 .46545 L
.07415 .46551 L
.07405 .46575 L
.07411 .46575 L
.07416 .46574 L
.07423 .46573 L
.07432 .46569 L
.07438 .46567 L
.07439 .46568 L
.07434 .46569 L
.07421 .46572 L
.07402 .46574 L
.07381 .46576 L
.0736 .46577 L
.07343 .46577 L
.07332 .46577 L
.07324 .46577 L
.07317 .46579 L
.07313 .46583 L
.07313 .46584 L
.07319 .46586 L
.07329 .46582 L
.07342 .46576 L
.07356 .46569 L
.0737 .46564 L
.0738 .46559 L
.07384 .46557 L
.07383 .46553 L
.07376 .46548 L
.07366 .4654 L
.07358 .46532 L
.07354 .46526 L
.07355 .46525 L
.0736 .46525 L
Mistroke
.07367 .46526 L
.07377 .46529 L
.07386 .46532 L
.07391 .46535 L
.07391 .46536 L
.07389 .46537 L
.07386 .46537 L
.07382 .46537 L
.07379 .46537 L
.07377 .46536 L
.07376 .46533 L
.07375 .46527 L
.07377 .46518 L
.07385 .46507 L
.07395 .46494 L
.07406 .46483 L
.07421 .46476 L
.07439 .46476 L
.07459 .46481 L
.07475 .46491 L
.07487 .46503 L
.07492 .46514 L
.07491 .46523 L
.07486 .46531 L
.07479 .46536 L
.07472 .46539 L
.07465 .4654 L
.07459 .4654 L
.07457 .4654 L
.07459 .46536 L
.07464 .46528 L
.0747 .46517 L
.07476 .46505 L
.07482 .46495 L
.07486 .46491 L
.07488 .46493 L
.07486 .46501 L
.07479 .46514 L
.07468 .46531 L
.07454 .4655 L
.07439 .46567 L
.07426 .46578 L
.07415 .46584 L
.07407 .46586 L
.07401 .46587 L
.074 .46584 L
.07404 .4658 L
.07411 .4657 L
.07421 .46555 L
.07437 .46535 L
Mistroke
.07454 .46514 L
.0747 .46496 L
.07483 .46484 L
.07491 .46479 L
.07494 .46482 L
.07492 .46491 L
.07486 .46504 L
.0748 .46515 L
.07475 .46522 L
.0747 .46524 L
.07467 .46524 L
.07467 .46523 L
.07465 .46527 L
.0746 .46536 L
.07452 .46546 L
.07442 .46557 L
.07432 .46566 L
.07422 .46574 L
.07414 .46579 L
.07409 .46581 L
.07406 .4658 L
.07404 .46578 L
.07404 .46575 L
.07403 .46575 L
.07404 .46576 L
.07408 .46571 L
.07418 .46559 L
.07432 .46544 L
.07449 .46526 L
.07467 .46509 L
.07483 .46494 L
.07497 .46483 L
.07507 .46477 L
.07511 .46476 L
.07511 .46479 L
.07508 .46484 L
.07504 .46487 L
.07499 .46489 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07501 .4649 L
.07516 .46489 L
.07534 .46489 L
.07558 .46489 L
.07585 .46488 L
.07613 .46488 L
Mistroke
.07641 .46488 L
.0767 .46487 L
.07698 .46487 L
.07726 .46487 L
.07752 .46487 L
.07775 .46487 L
.07792 .46487 L
.07802 .46487 L
.07806 .46487 L
.07803 .46487 L
.07803 .46487 L
.07806 .46487 L
.07807 .46487 L
.07807 .46487 L
.07807 .46487 L
.07803 .46487 L
.07794 .46487 L
.0778 .46487 L
.07766 .46487 L
.07757 .46487 L
.07752 .46487 L
.07752 .46487 L
.0775 .46487 L
.07759 .46487 L
.07774 .46486 L
.07793 .46486 L
.07819 .46486 L
.07848 .46485 L
.07882 .46485 L
.07918 .46484 L
.07955 .46484 L
.07983 .46483 L
.08003 .46483 L
.0801 .46483 L
.08001 .46483 L
.07973 .46484 L
.07936 .46484 L
.07896 .46485 L
.07858 .46485 L
.07823 .46486 L
.07791 .46486 L
.07763 .46487 L
.0774 .46487 L
.07719 .46487 L
.07704 .46487 L
.07698 .46487 L
.077 .46487 L
.07709 .46487 L
.07722 .46487 L
.07737 .46487 L
Mistroke
.07751 .46486 L
.07763 .46486 L
.0777 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07761 .46486 L
.07751 .46487 L
.0774 .46487 L
.0773 .46487 L
.07721 .46488 L
.07712 .46488 L
.07704 .46488 L
.07696 .46488 L
.07691 .46488 L
.07687 .46488 L
.07684 .46488 L
.07687 .46487 L
.07694 .46487 L
.07702 .46486 L
.07711 .46486 L
.07718 .46487 L
.07723 .46487 L
.07725 .46487 L
.07726 .46488 L
.07722 .46488 L
.07717 .46489 L
.07712 .46489 L
.0771 .46489 L
.07711 .46489 L
.07715 .46489 L
.07721 .46489 L
.07729 .46489 L
.07736 .46489 L
.07744 .46488 L
.0775 .46488 L
.07754 .46487 L
.07753 .46487 L
.07747 .46486 L
.07736 .46486 L
.07719 .46486 L
.07695 .46486 L
.07664 .46487 L
.07627 .46488 L
.07588 .46489 L
.07548 .4649 L
.0751 .46491 L
Mistroke
.07475 .46492 L
.07446 .46492 L
.07424 .46493 L
.0741 .46493 L
.07404 .46493 L
.07404 .46493 L
.07409 .46493 L
.07416 .46493 L
.07426 .46493 L
.07437 .46492 L
.0745 .46492 L
.07464 .46491 L
.07479 .4649 L
.07492 .4649 L
.07503 .46489 L
.07507 .46489 L
.07506 .46489 L
.07499 .46489 L
.07491 .4649 L
.07484 .4649 L
.07481 .4649 L
.07482 .4649 L
.07489 .4649 L
.07502 .4649 L
.07523 .46489 L
.07554 .46489 L
.07597 .46488 L
.07646 .46487 L
.07695 .46487 L
.07743 .46486 L
.07789 .46486 L
.07829 .46486 L
.07864 .46485 L
.0789 .46485 L
.07904 .46485 L
.07906 .46485 L
.07898 .46485 L
.07876 .46486 L
.07847 .46486 L
.07814 .46487 L
.07775 .46488 L
.07737 .46488 L
.07706 .46489 L
.07684 .46489 L
.07671 .46489 L
.07668 .46489 L
.07672 .46489 L
.07679 .46489 L
.07687 .46488 L
.07696 .46488 L
Mistroke
.07705 .46488 L
.07716 .46488 L
.07729 .46487 L
.07743 .46487 L
.07756 .46486 L
.07767 .46486 L
.07774 .46486 L
.07776 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07756 .46488 L
.07755 .46491 L
.07757 .46494 L
.07761 .46498 L
.07768 .46499 L
.07777 .46498 L
.07786 .46493 L
.07794 .46483 L
.07802 .46469 L
.07807 .46452 L
.07812 .46431 L
.07814 .46408 L
.07815 .46384 L
.07815 .4636 L
.07813 .46335 L
.07809 .46312 L
.07802 .46291 L
.07795 .46272 L
.07786 .46257 L
.07778 .46246 L
.07771 .46239 L
.07768 .46234 L
.07768 .46232 L
.0777 .46232 L
.07772 .46234 L
.07773 .46239 L
.07768 .46245 L
.07761 .46255 L
.07751 .46269 L
.07742 .46287 L
.07733 .46308 L
.07725 .46331 L
.07719 .46356 L
.07714 .4638 L
.07713 .46405 L
Mistroke
.07711 .46428 L
.07711 .4645 L
.07715 .46468 L
.07718 .46483 L
.07725 .46494 L
.07733 .46499 L
.07743 .46501 L
.07753 .46499 L
.07761 .46495 L
.07767 .46491 L
.07769 .46488 L
.07768 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46487 L
.07762 .4649 L
.07762 .46493 L
.07762 .46495 L
.07762 .46494 L
.07762 .4649 L
.07763 .46482 L
.07763 .46473 L
.07763 .46463 L
.07764 .46453 L
.07764 .46444 L
.07764 .46437 L
.07764 .46432 L
.07764 .4643 L
.07764 .46429 L
.07764 .46429 L
.07764 .46431 L
.07764 .46435 L
.07764 .46441 L
.07763 .4645 L
.07763 .46461 L
.07763 .46472 L
.07762 .46482 L
.07762 .46489 L
Mistroke
.07762 .46494 L
.07762 .46495 L
.07762 .46493 L
.07763 .4649 L
.07765 .46487 L
.07766 .46486 L
.07767 .46486 L
.07768 .46487 L
.07768 .46489 L
.07766 .46491 L
.07762 .46492 L
.07754 .46491 L
.07742 .46488 L
.07728 .46483 L
.07714 .46478 L
.07703 .46472 L
.07695 .46467 L
.07692 .46463 L
.07687 .4646 L
.07679 .46458 L
.07674 .46456 L
.07667 .46454 L
.07662 .46452 L
.07661 .46451 L
.07663 .46452 L
.07669 .46454 L
.07677 .46458 L
.07688 .46463 L
.07698 .46469 L
.07706 .46474 L
.0771 .46478 L
.07716 .4648 L
.07722 .46481 L
.07729 .4648 L
.07736 .4648 L
.07746 .46481 L
.07756 .46483 L
.07765 .46485 L
.07772 .46487 L
.07774 .46488 L
.07771 .46488 L
.07767 .46488 L
.07765 .46487 L
.07764 .46486 L
.07765 .46486 L
.07766 .46486 L
.07766 .46486 L
.07764 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07754 .46486 L
.07749 .46486 L
.07746 .46486 L
.07743 .46486 L
.07741 .46487 L
.0774 .46487 L
.0774 .46487 L
.07739 .46487 L
.0774 .46487 L
.07742 .46486 L
.07745 .46486 L
.07748 .46486 L
.07753 .46486 L
.07757 .46486 L
.07761 .46486 L
.07764 .46486 L
.07766 .46486 L
.07766 .46486 L
.07765 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07765 .46486 L
.07769 .46486 L
.07774 .46486 L
.07777 .46486 L
.07775 .46486 L
.07767 .46486 L
.07755 .46487 L
.0774 .46487 L
.07722 .46488 L
.07705 .46488 L
.0769 .46489 L
.07679 .46489 L
.07672 .46489 L
.07668 .46489 L
.07666 .46489 L
.07663 .46487 L
.07665 .46487 L
.07673 .46487 L
.07685 .46487 L
.07701 .46487 L
.0772 .46486 L
.07738 .46486 L
.07755 .46486 L
Mistroke
.07769 .46486 L
.07777 .46486 L
.07779 .46486 L
.07777 .46486 L
.07775 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.0776 .46486 L
.07749 .46487 L
.07737 .46487 L
.07725 .46487 L
.07714 .46488 L
.07705 .46488 L
.07699 .46488 L
.07695 .46488 L
.07694 .46488 L
.07694 .46488 L
.07695 .46488 L
.07699 .46488 L
.07707 .46487 L
.07717 .46487 L
.0773 .46487 L
.07743 .46486 L
.07755 .46486 L
.07765 .46486 L
.07772 .46486 L
.07774 .46486 L
.07772 .46486 L
.07768 .46486 L
.07766 .46486 L
.07768 .46486 L
.0777 .46486 L
.07771 .46486 L
.07768 .46486 L
.07763 .46486 L
.07755 .46486 L
.07746 .46486 L
.07736 .46486 L
.07727 .46486 L
.07719 .46486 L
.07714 .46487 L
.0771 .46487 L
.07709 .46487 L
.07708 .46487 L
.07709 .46487 L
.07712 .46487 L
.07717 .46487 L
.07725 .46486 L
.07734 .46486 L
Mistroke
.07744 .46486 L
.07754 .46486 L
.07763 .46486 L
.07769 .46486 L
.07774 .46486 L
.07778 .46486 L
.07781 .46486 L
.07783 .46486 L
.07782 .46486 L
.07776 .46486 L
.07764 .46487 L
.07743 .4649 L
.07716 .46494 L
.07685 .465 L
.07654 .46503 L
.07626 .46502 L
.07603 .46497 L
.07585 .46486 L
.07574 .46473 L
.07568 .46459 L
.07569 .4644 L
.07578 .46418 L
.07597 .46391 L
.07624 .46362 L
.07656 .46333 L
.07688 .46306 L
.07717 .46284 L
.07741 .46267 L
.07755 .46257 L
.07758 .46256 L
.07751 .46268 L
.07739 .4629 L
.07727 .46316 L
.07716 .46344 L
.07706 .46372 L
.07701 .464 L
.07698 .46425 L
.07699 .46447 L
.07707 .46466 L
.07721 .46481 L
.07735 .46492 L
.07748 .46498 L
.07757 .465 L
.0776 .46498 L
.07756 .46495 L
.07742 .46492 L
.07719 .46489 L
.07689 .46488 L
.07655 .46488 L
.07623 .46489 L
Mistroke
.07592 .46489 L
.07565 .4649 L
.07541 .4649 L
.07517 .4649 L
.07496 .4649 L
.07482 .4649 L
.07475 .4649 L
.07474 .4649 L
.07478 .4649 L
.07485 .4649 L
.07493 .4649 L
.075 .46489 L
.07504 .46489 L
.07503 .46489 L
.075 .46489 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .46491 L
.07494 .46494 L
.07489 .46498 L
.07485 .46501 L
.07483 .46503 L
.07485 .46502 L
.07491 .46496 L
.07502 .46487 L
.07518 .46473 L
.07538 .46455 L
.07562 .46433 L
.07589 .4641 L
.07618 .46384 L
.07648 .46358 L
.07683 .46331 L
.07718 .46306 L
.07749 .46282 L
Mistroke
.07771 .46261 L
.07783 .46245 L
.07782 .46238 L
.07768 .46239 L
.07742 .4625 L
.07707 .46269 L
.07669 .46293 L
.0763 .46321 L
.07594 .46351 L
.07559 .46382 L
.07529 .46406 L
.07501 .46423 L
.07472 .46444 L
.0745 .46461 L
.07437 .46471 L
.07436 .46474 L
.07447 .46469 L
.07469 .46462 L
.07498 .46455 L
.07532 .46447 L
.07567 .46439 L
.07598 .46433 L
.07624 .46433 L
.07648 .46434 L
.07673 .46439 L
.07697 .46445 L
.07721 .46453 L
.07742 .46462 L
.07758 .46472 L
.0777 .46481 L
.07776 .46489 L
.07778 .46493 L
.07776 .46495 L
.07772 .46493 L
.07768 .4649 L
.07765 .46487 L
.07765 .46486 L
.0777 .46486 L
.07778 .46486 L
.07784 .46487 L
.07785 .4649 L
.0778 .46494 L
.07767 .46498 L
.07747 .465 L
.07721 .46499 L
.0769 .46494 L
.07656 .46485 L
.07623 .46472 L
.07592 .46455 L
.0756 .46434 L
Mistroke
.07535 .46412 L
.0751 .46388 L
.07486 .46364 L
.07469 .4634 L
.07459 .46317 L
.07458 .46295 L
.07463 .46276 L
.07473 .46261 L
.07486 .4625 L
.075 .46244 L
.07511 .46242 L
.07516 .46243 L
.07515 .46247 L
.07511 .46251 L
.07508 .46254 L
.07506 .46255 L
.07506 .46256 L
.07506 .46256 L
.07506 .46255 L
.07504 .46254 L
.07502 .46251 L
.07498 .46248 L
.07494 .46244 L
.07493 .46243 L
.07498 .46244 L
.07509 .46249 L
.07524 .46258 L
.07539 .46271 L
.07552 .46289 L
.07563 .4631 L
.07571 .46333 L
.07575 .46357 L
.07575 .46381 L
.07573 .46405 L
.07568 .46429 L
.07563 .46451 L
.07556 .4647 L
.07548 .46485 L
.07536 .46496 L
.07522 .46502 L
.07506 .46504 L
.07492 .46502 L
.07483 .46499 L
.07479 .46495 L
.07481 .46492 L
.07486 .4649 L
.07494 .4649 L
.07501 .46489 L
.07503 .46489 L
.07498 .46489 L
Mistroke
.07492 .4649 L
.07486 .4649 L
.07483 .4649 L
.07483 .4649 L
.07486 .4649 L
.07492 .4649 L
.07504 .46489 L
.07522 .46489 L
.07546 .46489 L
.07578 .46489 L
.07614 .46488 L
.07654 .46488 L
.07698 .46487 L
.07745 .46486 L
.07797 .46486 L
.07851 .46485 L
.07905 .46484 L
.07956 .46484 L
.08003 .46483 L
.08043 .46483 L
.08075 .46482 L
.08097 .46482 L
.08112 .46482 L
.08119 .46482 L
.08121 .46482 L
.08118 .46482 L
.08111 .46482 L
.081 .46482 L
.08088 .46482 L
.08075 .46482 L
.08065 .46482 L
.08054 .46482 L
.08041 .46482 L
.08027 .46483 L
.08013 .46483 L
.08002 .46484 L
.07992 .46484 L
.07984 .46484 L
.07976 .46485 L
.07969 .46485 L
.07964 .46485 L
.07962 .46485 L
.07966 .46485 L
.0797 .46485 L
.0797 .46485 L
.0797 .46485 L
.07971 .46485 L
.07973 .46485 L
.07974 .46485 L
.07975 .46485 L
Mistroke
.07976 .46485 L
.07977 .46485 L
.07979 .46485 L
.07977 .46485 L
.07973 .46485 L
.07969 .46485 L
.07966 .46485 L
.07967 .46485 L
.07974 .46485 L
.07984 .46484 L
.07996 .46484 L
.08008 .46484 L
.08018 .46484 L
.08027 .46484 L
.08034 .46483 L
.08037 .46484 L
.08034 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08025 .46483 L
.08028 .46483 L
.08033 .46483 L
.08035 .46483 L
.08033 .46484 L
.08027 .46484 L
.08018 .46484 L
.08007 .46485 L
.07995 .46485 L
.07982 .46485 L
.07972 .46485 L
.07964 .46485 L
.07959 .46485 L
.07955 .46485 L
.07955 .46485 L
.07956 .46485 L
.07955 .46485 L
.07958 .46485 L
.07967 .46485 L
.0798 .46484 L
Mistroke
.07994 .46484 L
.08007 .46484 L
.08019 .46484 L
.08029 .46484 L
.08036 .46483 L
.08038 .46484 L
.08035 .46484 L
.0803 .46484 L
.08026 .46484 L
.08025 .46484 L
.08024 .46484 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08025 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08014 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08046 .46484 L
.08067 .46484 L
.0809 .46483 L
.08114 .46482 L
.08139 .46481 L
.08163 .46479 L
.08187 .46477 L
.08209 .46475 L
.0823 .46473 L
.08248 .46472 L
.08263 .46471 L
.08274 .4647 L
.08281 .4647 L
.08278 .4647 L
.08279 .46471 L
.0828 .46471 L
.08283 .46472 L
.08288 .46474 L
.08293 .46475 L
.08296 .46477 L
.08294 .46479 L
.08286 .4648 L
.08272 .46482 L
.08251 .46482 L
.08226 .46482 L
.08197 .46482 L
.08167 .46482 L
Mistroke
.08137 .46482 L
.08114 .46482 L
.08088 .46483 L
.08063 .46483 L
.08041 .46483 L
.08023 .46483 L
.08012 .46484 L
.08005 .46484 L
.08004 .46484 L
.08005 .46484 L
.0801 .46484 L
.08016 .46484 L
.08023 .46484 L
.08026 .46484 L
.0803 .46484 L
.08034 .46484 L
.08037 .46483 L
.08035 .46483 L
.08025 .46483 L
.08007 .46483 L
.07981 .46484 L
.07951 .46484 L
.0792 .46484 L
.07891 .46485 L
.07867 .46485 L
.07848 .46486 L
.07837 .46486 L
.07834 .46486 L
.07837 .46486 L
.07845 .46486 L
.07856 .46486 L
.07876 .46485 L
.07903 .46485 L
.07935 .46484 L
.07967 .46484 L
.07997 .46483 L
.08021 .46483 L
.08038 .46483 L
.08047 .46482 L
.08049 .46483 L
.08046 .46483 L
.08043 .46485 L
.08042 .46487 L
.08043 .46487 L
.08042 .46486 L
.08034 .46483 L
.0802 .46479 L
.08002 .46475 L
.07981 .46471 L
.07961 .46466 L
Mistroke
.07942 .46463 L
.07927 .46461 L
.07917 .46459 L
.07911 .46459 L
.0791 .46459 L
.07911 .46459 L
.07921 .4646 L
.0793 .46462 L
.07946 .46466 L
.07965 .4647 L
.07984 .46475 L
.08001 .46479 L
.08011 .46483 L
.08011 .46486 L
.08001 .46488 L
.07982 .46488 L
.07954 .46486 L
.07921 .46485 L
.07889 .46485 L
.07858 .46485 L
.0783 .46485 L
.07807 .46485 L
.07789 .46486 L
.07774 .46486 L
.0776 .46486 L
.07749 .46486 L
.07741 .46487 L
.07735 .46487 L
.07728 .46487 L
.07723 .46488 L
.0772 .46488 L
.07722 .46488 L
.07725 .46488 L
.07731 .46488 L
.07736 .46488 L
.07739 .46488 L
.07745 .46488 L
.07751 .46488 L
.07758 .46488 L
.07766 .46487 L
.07773 .46487 L
.07779 .46487 L
.07786 .46486 L
.07789 .46486 L
.07789 .46486 L
.07784 .46486 L
.07775 .46486 L
.07766 .46486 L
.07761 .46486 L
.07758 .46486 L
Mistroke
.07756 .46486 L
.07757 .46486 L
.07759 .46486 L
.07762 .46486 L
.07764 .46486 L
.07762 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07748 .46486 L
.0775 .46486 L
.07761 .46486 L
.0778 .46486 L
.07802 .46486 L
.07822 .46485 L
.07838 .46485 L
.07848 .46485 L
.07852 .46485 L
.0785 .46485 L
.07843 .46486 L
.07833 .46486 L
.07822 .46486 L
.07811 .46486 L
.07798 .46486 L
.07783 .46487 L
.07767 .46487 L
.07747 .46487 L
.07729 .46487 L
.07716 .46487 L
.07712 .46487 L
.07717 .46487 L
.07728 .46487 L
.07744 .46486 L
.07759 .46486 L
.0777 .46486 L
.07775 .46486 L
.07773 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.07751 .46485 L
.07752 .4648 L
.07756 .46473 L
.07762 .46467 L
.07771 .46464 L
.0778 .46466 L
.0779 .46475 L
Mistroke
.07801 .46492 L
.07812 .46519 L
.07825 .46555 L
.07842 .46597 L
.07864 .46643 L
.07892 .4669 L
.07924 .46736 L
.0796 .4678 L
.07998 .46826 L
.08042 .46872 L
.08088 .46914 L
.08132 .46949 L
.0817 .46974 L
.082 .46986 L
.08221 .46986 L
.0823 .46974 L
.08225 .46951 L
.08206 .46919 L
.08171 .46879 L
.08123 .46835 L
.08065 .46788 L
.08003 .4674 L
.07943 .46698 L
.07886 .46652 L
.07837 .46614 L
.07798 .4657 L
.07772 .4653 L
.0776 .46499 L
.07762 .46479 L
.07778 .46469 L
.07803 .46466 L
.07835 .46468 L
.07869 .46474 L
.07901 .4648 L
.07934 .46484 L
.07956 .46484 L
.07979 .46484 L
.07999 .46484 L
.08014 .46484 L
.08026 .46483 L
.08032 .46483 L
.08036 .46483 L
.0804 .46483 L
.08042 .46482 L
.08042 .46482 L
.08039 .46482 L
.08034 .46483 L
.08026 .46483 L
.08015 .46483 L
.08 .46484 L
Mistroke
.07982 .46484 L
.07963 .46485 L
.07946 .46485 L
.07932 .46485 L
.07921 .46485 L
.07914 .46486 L
.07909 .46486 L
.07907 .46485 L
.07912 .46485 L
.0792 .46485 L
.07931 .46485 L
.07948 .46484 L
.07967 .46484 L
.07987 .46483 L
.08005 .46483 L
.0802 .46483 L
.0803 .46483 L
.08035 .46483 L
.08036 .46483 L
.08036 .46483 L
.08037 .46483 L
.08037 .46483 L
.08035 .46483 L
.08031 .46483 L
.08027 .46483 L
.08021 .46483 L
.08014 .46483 L
.08006 .46484 L
.07999 .46484 L
.07993 .46484 L
.07988 .46484 L
.07985 .46484 L
.07984 .46484 L
.07984 .46484 L
.07984 .46484 L
.07985 .46484 L
.07989 .46484 L
.07995 .46484 L
.08002 .46484 L
.0801 .46483 L
.08018 .46483 L
.08025 .46483 L
.08032 .46483 L
.08036 .46483 L
.08037 .46485 L
.08035 .46488 L
.08034 .4649 L
.08035 .4649 L
.08037 .46486 L
.08036 .4648 L
Mistroke
.08029 .46472 L
.08016 .46464 L
.07995 .46456 L
.07966 .46449 L
.07932 .46444 L
.07892 .4644 L
.07863 .46439 L
.07835 .46439 L
.07814 .46439 L
.07801 .4644 L
.07794 .46443 L
.07792 .46448 L
.07799 .46456 L
.07817 .46464 L
.07842 .46473 L
.07872 .46481 L
.07905 .46487 L
.0794 .46491 L
.07973 .46492 L
.08002 .46489 L
.08025 .46486 L
.08038 .46484 L
.0804 .46483 L
.08037 .46483 L
.08032 .46484 L
.08028 .46485 L
.08023 .46488 L
.08019 .46492 L
.08017 .46495 L
.08017 .46497 L
.08018 .46495 L
.0802 .4649 L
.08022 .4648 L
.08026 .46465 L
.08031 .46444 L
.08036 .46418 L
.08039 .46391 L
.08039 .46365 L
.08037 .46342 L
.08032 .46323 L
.08024 .46309 L
.08011 .46301 L
.07996 .463 L
.07979 .46306 L
.07967 .46319 L
.07962 .46337 L
.08002 .46362 L
.08001 .46388 L
.07995 .46415 L
.07985 .46441 L
Mistroke
.07968 .46463 L
.0794 .4648 L
.07903 .46491 L
.07863 .46498 L
.07823 .465 L
.07786 .46499 L
.07755 .46496 L
.0773 .46493 L
.07712 .4649 L
.07697 .46489 L
.07681 .46489 L
.07672 .46489 L
.07666 .46489 L
.07664 .46488 L
.07674 .46485 L
.07697 .46482 L
.07726 .46481 L
.07753 .46483 L
.07769 .46486 L
.0777 .46492 L
.07759 .46498 L
.07741 .46505 L
.07724 .46512 L
.07709 .46518 L
.07697 .46522 L
.07688 .46524 L
.07684 .46525 L
.07683 .46525 L
.07683 .46525 L
.07684 .46524 L
.07689 .4652 L
.07698 .46515 L
.07711 .46508 L
.07726 .465 L
.07741 .46493 L
.07755 .46486 L
.07767 .46482 L
.07774 .46479 L
.07776 .4648 L
.07773 .46482 L
.07768 .46485 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46483 L
.07769 .4648 L
.0777 .46479 L
.07768 .46481 L
.07763 .46485 L
.07756 .46491 L
.07748 .46498 L
.0774 .46506 L
.07733 .46512 L
.07728 .46517 L
.07727 .4652 L
.07728 .46522 L
.07731 .46524 L
.07734 .46526 L
.07735 .46527 L
.07734 .46525 L
.07728 .46518 L
.07717 .46507 L
.077 .46495 L
.07678 .46485 L
.07651 .4648 L
.07621 .46485 L
.07591 .465 L
.0756 .46527 L
.07528 .46562 L
.07495 .46603 L
.07464 .46649 L
Mistroke
.07442 .46695 L
.07428 .46741 L
.07425 .46788 L
.07433 .46832 L
.07449 .4687 L
.07471 .46898 L
.07495 .46911 L
.07517 .46904 L
.07534 .46883 L
.07546 .46855 L
.07553 .46817 L
.07557 .46773 L
.07557 .46727 L
.07556 .46687 L
.07551 .4665 L
.07545 .46621 L
.07535 .46601 L
.07522 .46589 L
.07507 .46585 L
.07491 .46592 L
.07476 .4661 L
.07466 .46641 L
.0746 .46679 L
.0746 .46718 L
.07463 .46758 L
.07466 .46786 L
.07468 .46807 L
.0747 .46819 L
.07472 .46826 L
.07476 .4683 L
.0748 .46832 L
.07484 .46832 L
.07488 .46829 L
.07492 .46826 L
.07493 .46822 L
.07494 .46821 L
.07493 .46829 L
.07491 .4684 L
.07489 .46854 L
.07488 .46876 L
.07487 .469 L
.07486 .46921 L
.07485 .46939 L
.07485 .46952 L
.07485 .46958 L
.07485 .46956 L
.07485 .46949 L
.07486 .46938 L
.07486 .46926 L
.07487 .46912 L
Mistroke
.07488 .46901 L
.07488 .46893 L
.07488 .4689 L
.07488 .4689 L
.07488 .46892 L
.07488 .46896 L
.07488 .46904 L
.07487 .4691 L
.07487 .46918 L
.07487 .46927 L
.07486 .46934 L
.07486 .46937 L
.07486 .46937 L
.07486 .46933 L
.07487 .46926 L
.07487 .46918 L
.07487 .46912 L
.07488 .46905 L
.07488 .46899 L
.07489 .46893 L
.07489 .46891 L
.07489 .46893 L
.07488 .46898 L
.07488 .46902 L
.07488 .46908 L
.07487 .46916 L
.07487 .46926 L
.07487 .46932 L
.07488 .46939 L
.07491 .46943 L
.07495 .46942 L
.07497 .46934 L
.07496 .46918 L
.07492 .46896 L
.07483 .46874 L
.07472 .46851 L
.0746 .4683 L
.07448 .46816 L
.07436 .46806 L
.07427 .46802 L
.07423 .4684 L
.07419 .46845 L
.07417 .4685 L
.07417 .46856 L
.07419 .46868 L
.07424 .46886 L
.07431 .46908 L
.07441 .46929 L
.07453 .46948 L
.07466 .46962 L
Mistroke
.07478 .4697 L
.07487 .46972 L
.07493 .4697 L
.07495 .46966 L
.07493 .46962 L
.07489 .46959 L
.07486 .46958 L
.07485 .46956 L
.07485 .46955 L
.07486 .46954 L
.07486 .46953 L
.07487 .46953 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07487 .46952 L
.07486 .46953 L
.07486 .46954 L
.07486 .46955 L
.07485 .46956 L
.07485 .46957 L
.07484 .46958 L
.07484 .46958 L
.07482 .46959 L
.07479 .46959 L
.07475 .46959 L
.07471 .46959 L
.07469 .46958 L
.07471 .46958 L
.07476 .46958 L
.07487 .46958 L
.07503 .46958 L
.07522 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.0768 .46955 L
.07705 .46955 L
.07726 .46955 L
.07743 .46954 L
.07755 .46954 L
.07762 .46954 L
.07764 .46954 L
.07762 .46954 L
.07758 .46954 L
.07753 .46954 L
Mistroke
.0775 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.0775 .46954 L
.07753 .46954 L
.07758 .46954 L
.07762 .46954 L
.07763 .46954 L
.07761 .46954 L
.07755 .46954 L
.07744 .46954 L
.07727 .46954 L
Mistroke
.07706 .46954 L
.07682 .46955 L
.07655 .46955 L
.07628 .46955 L
.07599 .46956 L
.07574 .46956 L
.07547 .46956 L
.07523 .46957 L
.07502 .46957 L
.07486 .46957 L
.07475 .46958 L
.07469 .46958 L
.07468 .46958 L
.07471 .46958 L
.07476 .46958 L
.0748 .46958 L
.07484 .46958 L
.07485 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46959 L
.07484 .46961 L
.07484 .46964 L
.07484 .46966 L
.07484 .46967 L
.07484 .46967 L
.07484 .46965 L
.07485 .46958 L
.07487 .46948 L
.07489 .46934 L
.0749 .46915 L
.07491 .46894 L
.07492 .46872 L
.07491 .46851 L
.07489 .46837 L
.07485 .46829 L
.0748 .46823 L
.07474 .4682 L
.07468 .4682 L
.07461 .46823 L
.07456 .46833 L
.07452 .46851 L
.07448 .46866 L
Mistroke
.07446 .46887 L
.07446 .46908 L
.07448 .4693 L
.0745 .46943 L
.07455 .46953 L
.0746 .4696 L
.07466 .46964 L
.07473 .46964 L
.07479 .46963 L
.07484 .46961 L
.07487 .46961 L
.07488 .4696 L
.07488 .46959 L
.07487 .46959 L
.07486 .46958 L
.07483 .46958 L
.07482 .46958 L
.07484 .46959 L
.07486 .46959 L
.07486 .4696 L
.07483 .46959 L
.07478 .46957 L
.07472 .46956 L
.07465 .46954 L
.07458 .46952 L
.07452 .46951 L
.07447 .46949 L
.07443 .46949 L
.07442 .46948 L
.07443 .46948 L
.07444 .46948 L
.07446 .46948 L
.07448 .46948 L
.0745 .46949 L
.07454 .46951 L
.07458 .46953 L
.07463 .46955 L
.07467 .46957 L
.07471 .46958 L
.07473 .46959 L
.07474 .4696 L
.07472 .4696 L
.0747 .46959 L
.07467 .46958 L
.07466 .46958 L
.07468 .46958 L
.0747 .46958 L
.07473 .46958 L
.07476 .46958 L
.0748 .46958 L
Mistroke
.07483 .46958 L
.07486 .46958 L
.07488 .4696 L
.07489 .46965 L
.07488 .46972 L
.07485 .46979 L
.0748 .46983 L
.07474 .4698 L
.07468 .46971 L
.07464 .46952 L
.07463 .46925 L
.07468 .46889 L
.07478 .46847 L
.07494 .46801 L
.07514 .46753 L
.0754 .46705 L
.07566 .46659 L
.07595 .46613 L
.07625 .46569 L
.07655 .4653 L
.07684 .46499 L
.07712 .46477 L
.07737 .46465 L
.07756 .46461 L
.0777 .46463 L
.07778 .4647 L
.07781 .46477 L
.07779 .46483 L
.07773 .46486 L
.07768 .46486 L
.07765 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07761 .46486 L
.07758 .46486 L
.07754 .46486 L
.0775 .46486 L
.07747 .46486 L
Mistroke
.07748 .46486 L
.07754 .46486 L
.07768 .46486 L
.07786 .46486 L
.07806 .46486 L
.07827 .46485 L
.07847 .46485 L
.07868 .46485 L
.0789 .46485 L
.07909 .46485 L
.07926 .46485 L
.07939 .46485 L
.07947 .46485 L
.07948 .46485 L
.07944 .46485 L
.07932 .46485 L
.07912 .46485 L
.07889 .46485 L
.07863 .46485 L
.07841 .46486 L
.0782 .46486 L
.07804 .46486 L
.07791 .46486 L
.07781 .46486 L
.07771 .46486 L
.07763 .46486 L
.07755 .46486 L
.07748 .46486 L
.07743 .46486 L
.07741 .46486 L
.07743 .46486 L
.07747 .46486 L
.07754 .46486 L
.07765 .46486 L
.07781 .46486 L
.07801 .46486 L
.07824 .46485 L
.0785 .46485 L
.07877 .46485 L
.07904 .46484 L
.07932 .46484 L
.07958 .46484 L
.07983 .46483 L
.08004 .46483 L
.08021 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46483 L
.0804 .46483 L
.08036 .46483 L
Mistroke
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08028 .46483 L
.08032 .46483 L
.08037 .46483 L
.0804 .46483 L
.0804 .46483 L
.08036 .46483 L
.08028 .46483 L
.08014 .46483 L
.07994 .46484 L
.07968 .46484 L
.07938 .46485 L
.07906 .46485 L
.07875 .46485 L
.07858 .46486 L
.0784 .46486 L
.07825 .46486 L
.07813 .46486 L
.07805 .46486 L
.07802 .46486 L
.078 .46486 L
.07798 .46486 L
.07799 .46486 L
.07804 .46486 L
.07816 .46486 L
.07833 .46486 L
.07848 .46485 L
.07859 .46485 L
.07868 .46485 L
.07873 .46485 L
.07878 .46485 L
Mistroke
.07883 .46485 L
.0789 .46485 L
.07899 .46485 L
.07913 .46485 L
.07932 .46485 L
.07954 .46485 L
.0797 .46484 L
.07979 .46484 L
.07982 .46484 L
.07985 .46484 L
.07988 .46484 L
.07992 .46484 L
.07999 .46483 L
.08009 .46483 L
.08019 .46483 L
.08028 .46483 L
.08035 .46483 L
.08037 .46483 L
.08036 .46483 L
.08037 .46483 L
.08038 .46483 L
.0804 .46483 L
.08038 .46483 L
.08032 .46483 L
.08019 .46483 L
.08001 .46484 L
.0798 .46484 L
.07959 .46484 L
.0794 .46485 L
.07925 .46485 L
.07913 .46485 L
.07907 .46485 L
.07903 .46485 L
.07902 .46485 L
.07906 .46485 L
.07914 .46485 L
.07929 .46484 L
.07951 .46484 L
.07978 .46483 L
.08003 .46483 L
.08022 .46483 L
.08035 .46483 L
.08038 .46483 L
.0803 .46483 L
.08014 .46484 L
.07997 .46484 L
.07982 .46485 L
.07971 .46485 L
.07965 .46485 L
.07961 .46485 L
Mistroke
.07961 .46485 L
.07961 .46485 L
.07959 .46485 L
.07961 .46485 L
.07967 .46485 L
.07977 .46484 L
.0799 .46484 L
.08004 .46483 L
.08017 .46483 L
.08028 .46483 L
.08036 .46483 L
.0804 .46482 L
.08037 .46483 L
.08032 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.08141 .46481 L
.0817 .46481 L
.08202 .46481 L
.08233 .4648 L
.08261 .4648 L
.08283 .46479 L
.08298 .46479 L
.08304 .4648 L
.083 .4648 L
.08286 .4648 L
.08263 .46481 L
.08234 .46481 L
.08204 .46482 L
.08174 .46482 L
.08142 .46483 L
Mistroke
.08116 .46483 L
.08093 .46483 L
.08067 .46484 L
.08044 .46484 L
.08025 .46484 L
.08011 .46484 L
.08001 .46484 L
.07996 .46483 L
.07997 .46483 L
.08003 .46483 L
.08015 .46483 L
.08029 .46483 L
.08046 .46482 L
.08066 .46482 L
.0809 .46482 L
.08114 .46482 L
.08139 .46481 L
.08161 .46481 L
.08182 .46481 L
.08201 .46481 L
.08218 .4648 L
.08234 .4648 L
.08251 .4648 L
.08269 .4648 L
.0829 .4648 L
.08311 .46479 L
.08334 .46479 L
.08356 .46479 L
.08378 .46478 L
.084 .46478 L
.08419 .46478 L
.08434 .46478 L
.08445 .46478 L
.08449 .46478 L
.08446 .46478 L
.08436 .46478 L
.08421 .46478 L
.08398 .46478 L
.08372 .46478 L
.08346 .46479 L
.0832 .46479 L
.083 .46479 L
.08288 .46479 L
.08288 .46479 L
.08292 .46479 L
.08296 .46479 L
.08296 .46479 L
.08291 .4648 L
.08278 .4648 L
.08256 .46481 L
Mistroke
.08228 .46481 L
.08196 .46482 L
.08165 .46482 L
.08135 .46483 L
.08104 .46483 L
.08077 .46483 L
.08054 .46484 L
.08028 .46484 L
.08007 .46484 L
.07994 .46484 L
.0799 .46484 L
.07992 .46484 L
.08 .46483 L
.08008 .46483 L
.08018 .46483 L
.08025 .46483 L
.08027 .46483 L
.08022 .46483 L
.08015 .46483 L
.08009 .46483 L
.08006 .46483 L
.08004 .46483 L
.08004 .46483 L
.08004 .46483 L
.08005 .46483 L
.08007 .46483 L
.08009 .46483 L
.08013 .46483 L
.08016 .46483 L
.08021 .46483 L
.08024 .46483 L
.08027 .46483 L
.08029 .46483 L
.0803 .46483 L
.08029 .46483 L
.08027 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08017 .46483 L
Mistroke
.08029 .46483 L
.08049 .46482 L
.08074 .46482 L
.08101 .46482 L
.08127 .46482 L
.08151 .46481 L
.08171 .46481 L
.08188 .46481 L
.08199 .46481 L
.082 .46481 L
.08192 .46481 L
.0818 .46481 L
.0816 .46482 L
.08141 .46482 L
.08114 .46483 L
.08087 .46484 L
.08066 .46484 L
.08052 .46485 L
.08043 .46485 L
.08034 .46485 L
.0802 .46485 L
.08001 .46485 L
.07985 .46485 L
.07968 .46485 L
.07947 .46486 L
.07919 .46486 L
.07886 .46486 L
.07854 .46486 L
.07827 .46487 L
.078 .46487 L
.07775 .46487 L
.0775 .46487 L
.07731 .46487 L
.07721 .46487 L
.07723 .46488 L
.0773 .46487 L
.0774 .46487 L
.07754 .46487 L
.07768 .46486 L
.07779 .46486 L
.07783 .46486 L
.07781 .46486 L
.07773 .46486 L
.0776 .46486 L
.07744 .46486 L
.07724 .46487 L
.077 .46487 L
.07674 .46487 L
.07647 .46487 L
.07619 .46488 L
Mistroke
.07592 .46488 L
.07565 .46489 L
.07541 .46489 L
.0752 .46489 L
.07503 .46489 L
.07491 .4649 L
.07485 .4649 L
.07483 .4649 L
.07485 .4649 L
.07489 .4649 L
.07494 .4649 L
.07497 .4649 L
.07499 .4649 L
.07499 .4649 L
.07499 .4649 L
.07497 .4649 L
.07494 .4649 L
.0749 .4649 L
.07486 .4649 L
.07484 .4649 L
.07485 .4649 L
.07491 .4649 L
.07502 .4649 L
.07517 .46489 L
.07537 .46489 L
.0756 .46489 L
.07586 .46488 L
.07614 .46488 L
.07641 .46488 L
.07669 .46487 L
.07695 .46487 L
.07719 .46487 L
.07741 .46486 L
.07758 .46486 L
.07769 .46486 L
.07776 .46486 L
.07778 .46486 L
.07776 .46486 L
.07772 .46486 L
.07768 .46486 L
.07764 .46486 L
.07763 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
Mistroke
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07762 .46486 L
.07763 .46486 L
.07764 .46485 L
.07767 .46481 L
.07772 .46474 L
.07776 .46467 L
.07776 .46464 L
.07772 .46467 L
.07762 .46475 L
.07747 .46493 L
.07729 .4652 L
.07711 .46556 L
.07693 .466 L
.07677 .46646 L
.07665 .46694 L
.07656 .46739 L
.07651 .46784 L
.0765 .46828 L
.07652 .46871 L
.07657 .4691 L
.07666 .46942 L
.07679 .46962 L
.07695 .46973 L
.07711 .46976 L
.07726 .46973 L
.0774 .46967 L
.07749 .4696 L
.07751 .46955 L
.07746 .46954 L
.07735 .46956 L
.07721 .4696 L
.07702 .46968 L
.07682 .46975 L
.0766 .46977 L
.07635 .46974 L
.07608 .46966 L
.0758 .46951 L
.07553 .46924 L
.07533 .46887 L
Mistroke
.07516 .46844 L
.07505 .468 L
.07503 .46751 L
.07509 .46708 L
.07521 .46659 L
.07542 .46618 L
.07569 .46571 L
.076 .46528 L
.07633 .46493 L
.07668 .46467 L
.07698 .46452 L
.07722 .46449 L
.0774 .46458 L
.07752 .46479 L
.07757 .46508 L
.07756 .46545 L
.07752 .4659 L
.0775 .46639 L
.07754 .46689 L
.07765 .46735 L
.07786 .46778 L
.07817 .46821 L
.07857 .46865 L
.07903 .46905 L
.07952 .46936 L
.08004 .46957 L
.08057 .46968 L
.08109 .46971 L
.08158 .46969 L
.08202 .46962 L
.08241 .46954 L
.0827 .46949 L
.08289 .46947 L
.08298 .46947 L
.08298 .46946 L
.08292 .46946 L
.08283 .46947 L
.08272 .46947 L
.08261 .46947 L
.08252 .46948 L
.08245 .46948 L
.08242 .46948 L
.08239 .46949 L
.08238 .46949 L
.08235 .46949 L
.08232 .4695 L
.0823 .4695 L
.08229 .4695 L
.08228 .46949 L
.08229 .46949 L
Mistroke
.0823 .46949 L
.08234 .46949 L
.0824 .46948 L
.08236 .46948 L
.08246 .46948 L
.08259 .4695 L
.08271 .46954 L
.08282 .46959 L
.08291 .46965 L
.08298 .46967 L
.08303 .46965 L
.08307 .46956 L
.0831 .46939 L
.08312 .46912 L
.08309 .46879 L
.08304 .46838 L
.08298 .46793 L
.08293 .46743 L
.08292 .46696 L
.08292 .46653 L
.08294 .46608 L
.08295 .46565 L
.08295 .46526 L
.08297 .46495 L
.08301 .46474 L
.08306 .46462 L
.08312 .46458 L
.08323 .46459 L
.08339 .46463 L
.08356 .4647 L
.08375 .46475 L
.08392 .46477 L
.08408 .46478 L
.08422 .46478 L
.08437 .46478 L
.08454 .46478 L
.08474 .46477 L
.08499 .46477 L
.08527 .46477 L
.08558 .46476 L
.08588 .46476 L
.08613 .46475 L
.08639 .46475 L
.08667 .46475 L
.08694 .46474 L
.08722 .46474 L
.0875 .46474 L
.08773 .46474 L
.08785 .46473 L
.08781 .46473 L
Mistroke
.08765 .46474 L
.08735 .46474 L
.08695 .46475 L
.0864 .46476 L
.08576 .46477 L
.0851 .46477 L
.08447 .46479 L
.08394 .4648 L
.08357 .46483 L
.08337 .46485 L
.08333 .46486 L
.08335 .46484 L
.08346 .4648 L
.0837 .46475 L
.08403 .46468 L
.08439 .46461 L
.08484 .46454 L
.08526 .46449 L
.08566 .46444 L
.08606 .46441 L
.08647 .4644 L
.08678 .4644 L
.08695 .4644 L
.08708 .46441 L
.08716 .46445 L
.08724 .46449 L
.08733 .46455 L
.08741 .46462 L
.08757 .46469 L
.08777 .46475 L
.08798 .46482 L
.08814 .46487 L
.08823 .4649 L
.08825 .46489 L
.08821 .46486 L
.08815 .4648 L
.08807 .46471 L
.08798 .46457 L
.08789 .4644 L
.0878 .46419 L
.08774 .46396 L
.08771 .46372 L
.0877 .46348 L
.08771 .46324 L
.08775 .463 L
.08783 .46279 L
.08795 .46259 L
.08806 .46243 L
.08816 .4623 L
.08822 .4622 L
Mistroke
.08823 .46215 L
.08814 .46215 L
.08795 .4622 L
.08768 .46229 L
.08735 .46243 L
.08698 .46259 L
.0866 .46278 L
.08626 .46299 L
.08597 .46322 L
.08574 .46347 L
.08553 .46371 L
.08538 .46395 L
.08529 .46416 L
.08531 .4643 L
.08539 .46441 L
.08556 .46445 L
.0858 .46442 L
.08604 .4643 L
.08631 .46413 L
.08657 .46391 L
.08685 .46366 L
.08708 .4634 L
.08733 .46317 L
.08761 .46295 L
.08791 .46275 L
.08825 .46257 L
.08863 .46243 L
.08901 .46235 L
.08938 .46232 L
.08972 .46234 L
.09003 .46242 L
.09029 .46254 L
.09047 .4627 L
.09056 .46286 L
.09058 .463 L
.0906 .46308 L
.09065 .4631 L
.09074 .46306 L
Mfstroke
.09294 .41386 m
.09276 .41383 L
.09261 .41392 L
.09246 .41414 L
.09231 .41446 L
.09212 .41485 L
.09194 .41526 L
.09174 .41566 L
.09155 .41602 L
.09143 .41629 L
.09139 .41651 L
.09139 .41664 L
.09141 .41667 L
.09145 .41656 L
.09147 .41633 L
.09147 .41597 L
.09145 .41557 L
.0914 .41506 L
.0913 .41448 L
.09115 .41386 L
.09092 .41323 L
.09058 .41261 L
.09018 .412 L
.08972 .41141 L
.08922 .41085 L
.08874 .41035 L
.08832 .40993 L
.08798 .40961 L
.08774 .40935 L
.08758 .40922 L
.08752 .4092 L
.08753 .40931 L
s
.09738 .40673 m
.09741 .4067 L
.09733 .40685 L
.09715 .40716 L
.0969 .4076 L
.0966 .40811 L
.09628 .40866 L
.09595 .4092 L
.09564 .40971 L
.09535 .41018 L
.0951 .41059 L
.09488 .4109 L
.09471 .4111 L
.09459 .4112 L
.09452 .41126 L
.09448 .41131 L
.09447 .4114 L
s
.08261 .46503 m
.08256 .46513 L
.08261 .46515 L
.08272 .4651 L
.08282 .46501 L
.08278 .46492 L
.08261 .46486 L
.08238 .46483 L
.08212 .46482 L
.08185 .46482 L
.08154 .46482 L
.08131 .46482 L
.08104 .46483 L
.08079 .46483 L
.08055 .46483 L
.08036 .46483 L
.08024 .46483 L
.08019 .46483 L
.0802 .46483 L
.08025 .46483 L
.0803 .46481 L
.08033 .46478 L
.08032 .46476 L
.08024 .46475 L
.0801 .46478 L
.07992 .46483 L
.07971 .4649 L
.07945 .46498 L
.07915 .46507 L
.07882 .46515 L
.07848 .46522 L
.07813 .46527 L
.0778 .4653 L
.07751 .46532 L
.07728 .46531 L
.07713 .46531 L
.07704 .46528 L
.07701 .46524 L
.07701 .46519 L
.07704 .46512 L
.07709 .46505 L
.07714 .46499 L
.07719 .46494 L
.07725 .46491 L
.07731 .4649 L
.07737 .46492 L
.07743 .46495 L
.07749 .46498 L
.07751 .465 L
.07751 .465 L
Mistroke
.0775 .46499 L
.07749 .46497 L
.07751 .46495 L
.07756 .4649 L
.07762 .46482 L
.07768 .46472 L
.07771 .46463 L
.07771 .46458 L
.07767 .4646 L
.0776 .46469 L
.0775 .46488 L
.07741 .46517 L
.07732 .46553 L
.07725 .46594 L
.07719 .46639 L
.07715 .46685 L
.07713 .46733 L
.07711 .46779 L
.07711 .46826 L
.07715 .46871 L
.0772 .4691 L
.07726 .4694 L
.0773 .4696 L
.07735 .46968 L
.07735 .46971 L
.07732 .46964 L
.07725 .46954 L
.07715 .46947 L
.07704 .46942 L
.07696 .4694 L
.07691 .46937 L
.07692 .46927 L
.07699 .46912 L
.07709 .46893 L
.07726 .46866 L
.07749 .46834 L
.07777 .46797 L
.0781 .46758 L
.07843 .46719 L
.07875 .4668 L
.07909 .46638 L
.07937 .46602 L
.07966 .46565 L
.07993 .4653 L
.08018 .46502 L
.08043 .46485 L
.08068 .46476 L
.08093 .46474 L
.08116 .46475 L
.08138 .46478 L
Mistroke
.08159 .46482 L
.08181 .46484 L
.08205 .46486 L
.08227 .46487 L
.08245 .46487 L
.0826 .46485 L
.08268 .46483 L
.08268 .46481 L
.08265 .4648 L
.08259 .46479 L
.08254 .46479 L
.08252 .46479 L
.08251 .4648 L
.0825 .4648 L
.08249 .4648 L
.08242 .4648 L
.08231 .46481 L
.08215 .46481 L
.08195 .46481 L
.08173 .46482 L
.08153 .46482 L
.08132 .46482 L
.08117 .46482 L
.08098 .46483 L
.08079 .46483 L
.08059 .46483 L
.0804 .46483 L
.08025 .46483 L
.08015 .46483 L
.08011 .46483 L
.08012 .46483 L
.08014 .46483 L
.08016 .46483 L
.08016 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08028 .46483 L
.08044 .46483 L
.08064 .46482 L
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
Mistroke
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08286 .4648 L
.08281 .4648 L
.08273 .4648 L
.08267 .46481 L
.08266 .46484 L
.0827 .46486 L
.0828 .46487 L
Mfstroke
.09631 .44653 m
.09634 .44633 L
.0964 .44626 L
.0965 .44625 L
.09664 .44628 L
.09684 .4463 L
.09709 .44627 L
.09738 .4462 L
.09767 .44611 L
.09796 .44603 L
.09823 .44597 L
.09848 .44594 L
.09867 .44598 L
.0988 .44607 L
.09888 .44617 L
.09893 .44626 L
.09897 .4463 L
.09902 .44627 L
.09913 .44617 L
s
.11514 .44134 m
.11512 .4414 L
.11499 .44148 L
.11479 .44155 L
.11452 .44163 L
.1142 .44169 L
.11383 .44173 L
.11342 .44177 L
.11301 .44182 L
.11265 .44188 L
.11236 .44195 L
.11215 .442 L
.11205 .442 L
s
.1146 .44148 m
.11466 .44164 L
.11484 .44169 L
.11508 .44165 L
.11534 .44156 L
.11554 .44146 L
.11568 .44139 L
.11579 .44138 L
.11593 .44143 L
.11609 .44151 L
.11626 .44159 L
.11641 .44164 L
.11649 .44163 L
.11651 .44157 L
s
.10477 .42522 m
.10492 .42531 L
.10496 .42536 L
.10495 .42535 L
.10491 .42532 L
.10488 .42528 L
.10485 .42525 L
.10485 .42524 L
.10487 .42524 L
.10492 .42524 L
.105 .42524 L
.10508 .42526 L
.10512 .42528 L
.1051 .42532 L
.105 .42536 L
s
.09215 .41129 m
.09207 .41131 L
.09201 .41138 L
.09194 .41147 L
.09182 .41153 L
.0916 .41155 L
.09127 .41148 L
.09083 .41131 L
.09032 .41104 L
.08978 .41069 L
.08926 .41027 L
.08874 .40982 L
.08824 .40934 L
.08776 .40887 L
.08734 .4084 L
.087 .40793 L
.08677 .40747 L
.08665 .40708 L
.08661 .40678 L
.08664 .40659 L
.08671 .40651 L
.0868 .40653 L
.08686 .40661 L
.08689 .40675 L
.0869 .4069 L
.08693 .40707 L
.08697 .40723 L
.087 .40737 L
.08702 .40745 L
.08701 .40744 L
.08695 .40735 L
s
.08447 .395 m
.08447 .39492 L
.08447 .39491 L
.08446 .39496 L
.08442 .39508 L
.08438 .39522 L
.08434 .39534 L
.08432 .39541 L
.08434 .39541 L
.08438 .39535 L
s
.11333 .29236 m
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
s
.08427 .40697 m
.08427 .40711 L
.08427 .40713 L
.08427 .40709 L
.08428 .40699 L
.08428 .40687 L
.08428 .40675 L
.08428 .40666 L
.08428 .40658 L
.08428 .40651 L
.08429 .40647 L
.08428 .4065 L
.08428 .40659 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40781 L
.08425 .40827 L
.08424 .40874 L
.08424 .40921 L
.08423 .40968 L
.08422 .41014 L
.08421 .41057 L
.0842 .41095 L
.0842 .41125 L
.0842 .41146 L
.08419 .41158 L
.08419 .41161 L
.08419 .41159 L
.08419 .41152 L
.0842 .41144 L
.0842 .41139 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.0842 .41139 L
.0842 .41136 L
.0842 .41131 L
.0842 .41125 L
.08421 .41119 L
.08421 .41114 L
.08421 .41109 L
.08421 .41106 L
.08421 .41104 L
.08421 .41104 L
.08421 .41105 L
.08421 .41107 L
Mistroke
.08421 .4111 L
.08418 .41113 L
.08413 .41116 L
.08406 .41119 L
.08399 .41121 L
.08395 .41121 L
.08395 .41118 L
.084 .41113 L
.08413 .41107 L
.08439 .41101 L
.0848 .41099 L
.08531 .41101 L
.0859 .41109 L
.08654 .41118 L
.0871 .4113 L
.08776 .41144 L
.08831 .41158 L
.08884 .41173 L
.0893 .41185 L
.0897 .41194 L
.08995 .41201 L
.0901 .41205 L
.09015 .41206 L
.09009 .41202 L
.08995 .41192 L
.08977 .41178 L
.0896 .41165 L
.0895 .41153 L
.08949 .41142 L
.08957 .41134 L
.08972 .41128 L
.08993 .41127 L
.09019 .41129 L
.0905 .41132 L
.09081 .41135 L
.09109 .41137 L
.09136 .41137 L
.09161 .41137 L
.09183 .41137 L
.09201 .41137 L
.09215 .41137 L
.09228 .41137 L
.09237 .41137 L
.09239 .41137 L
.09233 .41137 L
.09219 .41137 L
.09196 .41137 L
.09162 .41137 L
.09116 .41137 L
.09066 .41137 L
Mistroke
.09017 .41137 L
.08974 .41137 L
.08939 .41137 L
.08909 .41136 L
.0888 .41136 L
.08852 .41136 L
.0883 .41136 L
.08818 .41136 L
.08818 .41136 L
.08831 .41136 L
.08852 .41136 L
.08879 .41136 L
.08908 .41136 L
.08935 .41137 L
.08952 .41137 L
.08958 .41137 L
.08958 .41137 L
.08956 .41137 L
.08952 .41137 L
.08948 .41137 L
.08945 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .41137 L
.08948 .41137 L
.08956 .41137 L
.08963 .41137 L
.08966 .41137 L
.08964 .41137 L
.08955 .41137 L
.08936 .41137 L
.08906 .41136 L
.08866 .41136 L
.08818 .41136 L
.08766 .41136 L
.08713 .41136 L
.08663 .41136 L
.08616 .41136 L
.08567 .41136 L
.08518 .41136 L
.08473 .41135 L
.08437 .41135 L
Mistroke
.08413 .41135 L
.084 .41135 L
.08395 .41135 L
.08397 .41135 L
.08404 .41135 L
.08412 .41135 L
.08418 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
Mistroke
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08418 .41135 L
.08415 .41135 L
.08411 .41135 L
.08407 .41135 L
.08406 .41135 L
.08407 .41135 L
.08412 .41135 L
.08424 .41135 L
.08443 .41135 L
.08468 .41135 L
.08496 .41136 L
.08524 .41136 L
.0855 .41136 L
.08571 .41136 L
.08587 .41136 L
.08594 .41136 L
.08594 .41136 L
.08587 .41136 L
.08576 .41136 L
.08562 .41136 L
.08548 .41136 L
.08533 .41136 L
.0852 .41136 L
.08511 .41136 L
.08507 .41136 L
.08511 .41136 L
.08525 .41136 L
.08545 .41136 L
.08569 .41136 L
.08597 .41136 L
.08625 .41135 L
.0865 .41132 L
.08667 .41129 L
.08676 .41126 L
.08681 .41124 L
Mistroke
.08683 .41125 L
.08687 .41129 L
.08693 .41138 L
.08703 .41152 L
.0872 .4117 L
.08741 .4119 L
.08767 .41213 L
.08793 .41237 L
.0882 .41261 L
.08845 .41284 L
.08871 .41307 L
.08895 .41329 L
.08916 .41347 L
.08933 .41363 L
.08944 .41373 L
.08951 .41379 L
.08953 .41381 L
.08952 .4138 L
.08948 .41376 L
.08944 .41372 L
.0894 .41369 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08942 .41368 L
.0895 .41368 L
.08957 .41368 L
.0896 .41368 L
.08958 .41368 L
.0895 .41368 L
Mistroke
.08932 .41368 L
.08903 .41368 L
.08862 .41368 L
.08812 .41368 L
.08759 .41367 L
.08707 .41367 L
.08659 .41367 L
.08614 .41367 L
.08567 .41367 L
.08517 .41367 L
.0847 .41367 L
.08433 .41367 L
.08409 .41367 L
.08397 .41367 L
.08393 .41367 L
.08394 .41367 L
.08401 .41367 L
.08409 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08407 .41367 L
.08403 .41367 L
.08401 .41367 L
.08402 .41367 L
.08407 .41367 L
.08416 .41367 L
.08429 .41367 L
.08445 .41367 L
.08463 .41367 L
.08485 .41367 L
.0851 .41367 L
.0854 .41367 L
Mistroke
.08573 .41367 L
.0861 .41367 L
.0865 .41367 L
.08692 .41367 L
.08733 .41367 L
.08772 .41367 L
.08807 .41367 L
.08836 .41368 L
.08862 .41368 L
.08884 .41368 L
.08904 .41368 L
.08921 .41368 L
.08936 .41368 L
.08946 .41368 L
.08952 .41368 L
.08953 .41368 L
.08952 .41368 L
.08948 .41368 L
.08943 .41368 L
.0894 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41369 L
.08941 .41372 L
.08945 .41375 L
.08949 .41379 L
.08952 .41381 L
.08952 .4138 L
.08948 .41375 L
.0894 .41367 L
.08927 .41354 L
.0891 .41339 L
.08891 .41324 L
.08871 .41308 L
.08848 .41291 L
.08821 .4127 L
.08796 .41243 L
.08764 .41211 L
.08728 .41173 L
.08691 .41132 L
.08653 .41089 L
.08616 .41045 L
.08582 .40999 L
Mistroke
.08551 .40951 L
.08526 .40899 L
.08504 .40844 L
.08484 .40784 L
.08464 .40717 L
.08447 .40645 L
.08433 .40572 L
.08424 .40503 L
.08419 .4044 L
.08418 .40389 L
.08421 .40344 L
.08425 .40306 L
.0843 .40273 L
.08434 .40245 L
.08435 .40223 L
.08436 .40208 L
.08436 .40198 L
.08436 .40191 L
.08436 .40185 L
.08437 .40179 L
.08437 .4017 L
.08437 .40155 L
.08438 .40134 L
.08438 .4011 L
.08439 .40087 L
.08439 .40064 L
.08439 .40039 L
.0844 .4002 L
.0844 .40001 L
.0844 .39986 L
.0844 .39975 L
.0844 .39968 L
.0844 .39967 L
.0844 .39968 L
.0844 .39971 L
.0844 .39974 L
.0844 .39977 L
.0844 .39978 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .3998 L
.08439 .39982 L
.08439 .39987 L
.08439 .39992 L
.08439 .39994 L
.08439 .39989 L
.0844 .39979 L
.0844 .39964 L
.08441 .39946 L
.08441 .39927 L
.08442 .39909 L
.08442 .39896 L
.08442 .39888 L
.08442 .39876 L
.08443 .39876 L
.08443 .39876 L
.08443 .39876 L
.08442 .39877 L
.08442 .39884 L
.08442 .39897 L
.08441 .39916 L
.08441 .39938 L
.0844 .39958 L
.0844 .39976 L
.08439 .39989 L
.08439 .39996 L
.08439 .39995 L
.08439 .39989 L
.08439 .39983 L
.0844 .3998 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
Mistroke
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39979 L
.0844 .39981 L
.0844 .39986 L
.08439 .39993 L
.08439 .4 L
.08439 .40003 L
.08439 .4 L
.08439 .39991 L
.0844 .39973 L
.0844 .39946 L
.08441 .39911 L
.08441 .39869 L
.08442 .39824 L
.08443 .39777 L
.08444 .3973 L
.08444 .39685 L
.08443 .3964 L
.08439 .39597 L
.08436 .39558 L
.08435 .39528 L
.08436 .39507 L
.08441 .39495 L
.0845 .39491 L
.08465 .39494 L
.08486 .395 L
.0851 .39508 L
.08535 .39514 L
.08562 .39516 L
.08586 .39517 L
.0861 .39517 L
.08634 .39517 L
.08658 .39517 L
.08681 .39518 L
.08699 .39518 L
.08711 .39518 L
.08718 .39518 L
.0872 .39518 L
.08719 .39518 L
.08716 .39518 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39517 L
.0871 .39514 L
.08714 .39507 L
.08718 .39499 L
.0872 .39494 L
.08719 .39492 L
.08714 .39496 L
.08705 .39509 L
.0869 .39533 L
.08668 .3957 L
.08643 .39619 L
.08616 .39676 L
.08589 .39737 L
.08564 .39798 L
.0854 .39853 L
.08515 .39905 L
.08489 .39972 L
.08465 .4004 L
Mistroke
.08446 .40106 L
.08433 .40169 L
.08426 .40229 L
.08423 .40288 L
.08423 .40343 L
.08425 .40392 L
.08429 .40436 L
.08431 .40478 L
.08431 .40521 L
.0843 .40564 L
.08429 .40603 L
.08429 .40637 L
.08428 .40664 L
.08428 .40683 L
.08428 .40694 L
.08428 .40697 L
.08428 .40695 L
.08428 .40688 L
.08428 .4068 L
.08428 .40675 L
.08428 .40671 L
.08428 .40665 L
.08428 .40658 L
.08428 .40652 L
.08429 .40648 L
.08428 .40651 L
.08428 .4066 L
.08428 .40678 L
.08427 .40705 L
.08427 .4074 L
.08426 .40782 L
.08425 .40827 L
.08424 .40875 L
.08424 .40921 L
.08423 .40966 L
.08422 .41012 L
.08421 .41055 L
.0842 .41093 L
.0842 .41124 L
.0842 .41145 L
.08419 .41156 L
.08419 .4116 L
.08419 .41158 L
.08419 .41152 L
.0842 .41144 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41142 L
.0842 .4114 L
.0842 .41134 L
.0842 .41125 L
.08421 .41112 L
.08421 .41099 L
.08422 .41085 L
.08422 .41072 L
.08423 .4106 L
.08423 .41055 L
.08423 .41056 L
.08424 .41056 L
.08424 .41057 L
.08424 .41059 L
.08424 .41062 L
.08424 .4107 L
.08424 .41121 L
.08423 .41124 L
.08423 .41128 L
.08423 .41131 L
.08422 .41135 L
.08422 .41137 L
.08421 .41138 L
.08421 .41138 L
.08421 .41138 L
.08421 .41137 L
.08421 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08419 .41135 L
.08419 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41151 L
Mistroke
.08419 .41169 L
.08419 .4119 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08413 .41375 L
.08409 .41372 L
.08405 .41369 L
.08404 .41367 L
.08405 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08478 .41367 L
.08504 .41367 L
.0853 .41367 L
.08555 .41367 L
.08579 .41367 L
.08603 .41367 L
.08628 .41367 L
.08651 .41367 L
.08669 .41367 L
.08681 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08685 .41367 L
.08681 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.0868 .41367 L
.08684 .41367 L
.08687 .41367 L
.08689 .41367 L
.08688 .41367 L
.08683 .41367 L
.08674 .41367 L
.08659 .41367 L
.08639 .41367 L
.08614 .41367 L
.08588 .41367 L
.08562 .41367 L
.08537 .41367 L
.08514 .41367 L
.08489 .41367 L
.08465 .41367 L
.08442 .41367 L
.08424 .41367 L
.08412 .41367 L
.08406 .41367 L
.08403 .41367 L
.08404 .41367 L
.08408 .41367 L
.08412 .41367 L
.08414 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08414 .41367 L
.08411 .41367 L
.08406 .41367 L
.08403 .41367 L
.084 .41367 L
.084 .41367 L
.08403 .41367 L
.08411 .41367 L
.08425 .41367 L
.08444 .41367 L
.08469 .41367 L
.085 .41367 L
.08539 .41367 L
.0858 .41367 L
.08622 .41367 L
.08668 .41367 L
.08716 .41367 L
.08766 .41367 L
.08808 .41368 L
.08844 .41368 L
.08877 .41368 L
.08904 .41368 L
.08925 .41368 L
.08939 .41368 L
Mistroke
.08947 .41368 L
.08951 .41368 L
.08952 .41368 L
.08951 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.0894 .41368 L
.08946 .41368 L
.08954 .41368 L
.08957 .41368 L
.08955 .41368 L
.08948 .41368 L
.08932 .41368 L
.08903 .41368 L
.0886 .41368 L
.08807 .41368 L
.08753 .41367 L
.08705 .41367 L
Mistroke
.0866 .41367 L
.08614 .41367 L
.08569 .41367 L
.08521 .41367 L
.08472 .41367 L
.08434 .41367 L
.08411 .41367 L
.08401 .41367 L
.08397 .41367 L
.08398 .41367 L
.08406 .41367 L
.08413 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
Mistroke
.08414 .41367 L
.08412 .41367 L
.08408 .41367 L
.08404 .41367 L
.08402 .41367 L
.08403 .41367 L
.08409 .41367 L
.08419 .41367 L
.08434 .41367 L
.08454 .41367 L
.08477 .41367 L
.08503 .41367 L
.0853 .41367 L
.08556 .41367 L
.08581 .41367 L
.08606 .41367 L
.08631 .41367 L
.08652 .41367 L
.0867 .41367 L
.08682 .41367 L
.08689 .41367 L
.08691 .41367 L
.0869 .41367 L
.08686 .41367 L
.08682 .41367 L
.08679 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08679 .41367 L
Mistroke
.08681 .41367 L
.08684 .41367 L
.08685 .41367 L
.08682 .41367 L
.08677 .41367 L
.08671 .41367 L
.08663 .41367 L
.08655 .41367 L
.08648 .41367 L
.08642 .41367 L
.08639 .41367 L
.08637 .41367 L
.08638 .41367 L
.08638 .41367 L
.08638 .41367 L
.08637 .41367 L
.08639 .41367 L
.08644 .41367 L
.08652 .41367 L
.0866 .41367 L
.08669 .41367 L
.08676 .41367 L
.08682 .41367 L
.08685 .41367 L
.08684 .41367 L
.08681 .41367 L
.08679 .41367 L
.08678 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08678 .41367 L
.08681 .41367 L
.08685 .41367 L
.08689 .41367 L
.08691 .41367 L
.08689 .41367 L
.08683 .41367 L
.08672 .41367 L
.08657 .41367 L
.08636 .41367 L
.08612 .41367 L
.08584 .41367 L
.08553 .41367 L
.08523 .41367 L
.08494 .41367 L
.08468 .41367 L
.08444 .41367 L
.08426 .41367 L
.08419 .41367 L
.08422 .41367 L
.08437 .41367 L
.08458 .41367 L
.08485 .41367 L
.08515 .41367 L
.08542 .41367 L
.0857 .41367 L
.08596 .41367 L
.08622 .41367 L
.08645 .41367 L
.08665 .41367 L
.08678 .41367 L
.08686 .41367 L
.08688 .41368 L
.08687 .41369 L
.08686 .41371 L
.08685 .41375 L
.08686 .41378 L
.08687 .4138 L
.08687 .41379 L
Mistroke
.08683 .41374 L
.08674 .41365 L
.0866 .41351 L
.08639 .41334 L
.08615 .41313 L
.08589 .4129 L
.08564 .41266 L
.0854 .41242 L
.08517 .41219 L
.08494 .41196 L
.08469 .41174 L
.08447 .41155 L
.08428 .4114 L
.08417 .4113 L
.08411 .41124 L
.08409 .41122 L
.08409 .41123 L
.08413 .41127 L
.08417 .41131 L
.08419 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41138 L
.08419 .41141 L
.08419 .41147 L
.08419 .41153 L
.08419 .41155 L
.0842 .41152 L
.0842 .41143 L
.0842 .41126 L
.08421 .411 L
.08421 .41065 L
.08422 .41021 L
.08423 .40975 L
.08423 .40927 L
.08424 .40886 L
.08425 .4084 L
.08426 .40801 L
.08427 .40757 L
.08427 .40717 L
.08428 .40685 L
.08428 .40665 L
.08428 .40654 L
.08428 .40651 L
.08428 .40653 L
.08428 .40659 L
.08428 .40667 L
.08428 .40672 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08429 .40674 L
.08429 .40676 L
.08429 .40682 L
.08429 .40689 L
.08429 .40694 L
.0843 .40691 L
.0843 .4068 L
.0843 .40668 L
Mfstroke
.08724 .38357 m
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
.08713 .38373 L
s
.08419 .41164 m
.08419 .41176 L
.08419 .41179 L
.08419 .41175 L
.08419 .41166 L
.08419 .41156 L
.0842 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41124 L
.0842 .41123 L
.0842 .41124 L
.0842 .41129 L
.0842 .41138 L
.08419 .41152 L
.08419 .41169 L
.08419 .4119 L
Mistroke
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41372 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41375 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
Mistroke
.08415 .41374 L
.08415 .41364 L
.08416 .41351 L
.08416 .41333 L
.08416 .41312 L
.08417 .4129 L
.08417 .41265 L
.08418 .4124 L
.08418 .41214 L
.08419 .41187 L
.08419 .41163 L
.0842 .41142 L
.0842 .41128 L
.0842 .41123 L
.0842 .41126 L
.0842 .41138 L
.08419 .41157 L
.08419 .4118 L
.08418 .41207 L
.08418 .41234 L
.08417 .41259 L
.08417 .41283 L
.08417 .41306 L
.08416 .41328 L
.08416 .41347 L
.08415 .41362 L
.08415 .41374 L
.08415 .41382 L
.08415 .41388 L
.08415 .4139 L
.08415 .41388 L
.08415 .41383 L
.08415 .41375 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41219 L
.08419 .41196 L
.08419 .41174 L
.08419 .41155 L
.0842 .4114 L
.0842 .4113 L
.0842 .41124 L
.0842 .41122 L
.0842 .41124 L
.0842 .41127 L
Mistroke
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41132 L
.0842 .4113 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41136 L
.08419 .41144 L
.08419 .41154 L
.08419 .41167 L
.08419 .41181 L
.08418 .41198 L
.08418 .41214 L
Mistroke
.08418 .41233 L
.08417 .41261 L
.08417 .41282 L
.08417 .413 L
.08416 .41316 L
.08416 .41324 L
.08416 .41323 L
.08416 .41315 L
.08417 .41302 L
.08417 .41285 L
.08417 .41266 L
.08418 .41247 L
.08418 .41232 L
.08418 .4122 L
.08418 .41214 L
.08418 .41216 L
.08418 .41223 L
.08418 .41238 L
.08417 .41259 L
.08417 .4128 L
.08417 .41303 L
.08416 .41325 L
.08416 .41343 L
.08416 .41354 L
.08416 .41357 L
.08416 .41353 L
.08416 .41339 L
.08416 .41326 L
.08417 .41302 L
.08417 .41282 L
.08417 .41264 L
.08418 .41249 L
.08418 .41237 L
.08418 .41231 L
.08418 .41233 L
.08418 .4124 L
.08418 .41254 L
.08417 .41269 L
.08417 .41284 L
.08417 .41295 L
.08416 .41309 L
.08416 .41319 L
.08416 .4132 L
.08416 .41316 L
.08416 .41307 L
.08417 .41292 L
.08417 .41272 L
.08418 .4125 L
.08418 .41225 L
.08419 .41198 L
Mistroke
.08419 .41173 L
.08419 .41153 L
.0842 .41138 L
.0842 .41129 L
.0842 .41124 L
.0842 .41123 L
.0842 .41125 L
.0842 .41128 L
.0842 .41132 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .41138 L
.0842 .4114 L
.08419 .41142 L
.08419 .41144 L
.08419 .41146 L
.08419 .41147 L
.08419 .41148 L
.08419 .41148 L
.08419 .41148 L
.08419 .41147 L
.08419 .41146 L
.08419 .41145 L
.08419 .41143 L
.0842 .41139 L
.0842 .41134 L
.0842 .41129 L
.08419 .41123 L
.08417 .41121 L
.08414 .41123 L
.08413 .41131 L
.08412 .41144 L
.08412 .41162 L
.08413 .41181 L
.08417 .41199 L
.08423 .41216 L
.08433 .41229 L
.08447 .41239 L
.08464 .41245 L
.08485 .41247 L
Mistroke
.08509 .41246 L
.08533 .41242 L
.08558 .41234 L
.08583 .41221 L
.08605 .41205 L
.08627 .41186 L
.08647 .41166 L
.08663 .41148 L
.08674 .41134 L
.08682 .41126 L
.08687 .41123 L
.08689 .41124 L
.0869 .41128 L
.08689 .41131 L
.08688 .41134 L
.08685 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08679 .41134 L
.08675 .41131 L
.0867 .41128 L
.08665 .41124 L
.0866 .41122 L
.08659 .41123 L
.08664 .41128 L
Mfstroke
.08276 .46504 m
.08273 .4651 L
.08271 .46509 L
.08272 .46501 L
.08267 .46493 L
.08247 .46486 L
.0822 .46483 L
.08191 .46482 L
.08162 .46482 L
.08135 .46482 L
.08114 .46483 L
.08087 .46483 L
.08062 .46483 L
.08041 .46483 L
.08026 .46483 L
.08017 .46483 L
.08013 .46483 L
.08013 .46483 L
.08015 .46483 L
.0802 .46483 L
.08024 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08027 .46482 L
.08029 .4648 L
.08035 .46476 L
.08042 .4647 L
.08047 .46464 L
.08049 .46461 L
.08044 .46464 L
.08032 .46473 L
.08009 .46491 L
.07975 .46518 L
.07931 .46554 L
.07882 .46597 L
.07829 .46643 L
.07775 .46692 L
.07732 .46738 L
.07676 .46781 L
Mistroke
.07626 .46826 L
.07577 .46871 L
.07534 .46911 L
.07501 .46942 L
.07479 .46964 L
.07466 .46975 L
.07461 .4698 L
.07462 .46979 L
.07468 .46973 L
.07474 .46966 L
.07479 .46961 L
.07482 .46959 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07483 .46958 L
.0748 .46958 L
.07476 .46958 L
.07472 .46958 L
.0747 .46958 L
.07471 .46958 L
.07477 .46958 L
.07487 .46958 L
.07503 .46958 L
.07523 .46957 L
.07546 .46957 L
.07572 .46957 L
.07599 .46956 L
.07626 .46956 L
.07654 .46956 L
.07682 .46955 L
.0771 .46955 L
.07735 .46954 L
.07756 .46954 L
.0777 .46954 L
.07775 .46954 L
.07771 .46954 L
.07759 .46954 L
.0774 .46954 L
.07715 .46955 L
.07689 .46955 L
.07661 .46956 L
.07633 .46956 L
Mistroke
.07606 .46956 L
.07579 .46957 L
.07552 .46957 L
.07528 .46957 L
.07506 .46958 L
.07489 .46958 L
.07478 .46958 L
.07471 .46958 L
.07469 .46958 L
.0747 .46958 L
.07474 .46958 L
.07479 .46958 L
.07482 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
.07484 .46958 L
Mistroke
.07484 .46958 L
.07483 .46955 L
.0748 .4695 L
.07476 .46943 L
.07472 .46936 L
.0747 .46932 L
.07471 .46934 L
.07478 .46943 L
.07489 .46962 L
.07506 .46991 L
.07525 .47028 L
.07546 .47067 L
.07566 .47108 L
.07586 .4715 L
.07605 .47192 L
.07625 .47234 L
.07645 .47275 L
.07663 .47312 L
.07679 .47344 L
.07691 .47371 L
.077 .47392 L
.07706 .47407 L
.07708 .47413 L
.07707 .47414 L
.07706 .4741 L
.07702 .47403 L
.07696 .47395 L
.07688 .47386 L
.0768 .47372 L
.0767 .47352 L
.07659 .47323 L
.07649 .47289 L
.07641 .47249 L
.07635 .47204 L
.07634 .47158 L
.07637 .47111 L
.07645 .47073 L
.07655 .47036 L
.07663 .47003 L
.07675 .46976 L
.0769 .46956 L
.07706 .46944 L
.07723 .46939 L
.07739 .46939 L
.0775 .46942 L
.07755 .46945 L
.07754 .46948 L
.07749 .4695 L
.07743 .46953 L
.07739 .46956 L
Mistroke
.07739 .46957 L
.07745 .46957 L
.07756 .46955 L
.07769 .46953 L
.07784 .46951 L
.07801 .46948 L
.07819 .46945 L
.07838 .46942 L
.07858 .4694 L
.0788 .46938 L
.07901 .46937 L
.07923 .46937 L
.07944 .46936 L
.07961 .46937 L
.07974 .46939 L
.07986 .46944 L
.07994 .46949 L
.07999 .46952 L
.08002 .46953 L
.08003 .4695 L
.08005 .46945 L
.08006 .46938 L
.08006 .4693 L
.08004 .46921 L
.08001 .46913 L
.07997 .46908 L
.07993 .46905 L
.07991 .46904 L
.07991 .46904 L
.07992 .46905 L
.07994 .46908 L
.07999 .46912 L
.08004 .46917 L
.08008 .46924 L
.08009 .46931 L
.08007 .46938 L
.08001 .46943 L
.07993 .46946 L
.07984 .46948 L
.07975 .46946 L
.07967 .46943 L
.0796 .4694 L
.07956 .46938 L
.07955 .46938 L
.07956 .46939 L
.07955 .46941 L
.07959 .46944 L
.07967 .46948 L
.0798 .46951 L
.07994 .46954 L
Mistroke
.08007 .46955 L
.08014 .46955 L
.08015 .46952 L
.08009 .46948 L
.07997 .46941 L
.07978 .46934 L
.07956 .46928 L
.07939 .46922 L
.07927 .46917 L
.07919 .46913 L
.07916 .46911 L
.07915 .4691 L
.07916 .4691 L
.07922 .46913 L
.07928 .46916 L
.07942 .46922 L
.07962 .46932 L
.07984 .46942 L
.08006 .46951 L
.08023 .46957 L
.08033 .4696 L
.08032 .46957 L
.08018 .46948 L
.07994 .46934 L
.07964 .46916 L
.0793 .46895 L
.07893 .46868 L
.07856 .4684 L
.07821 .46811 L
.07794 .46786 L
.07774 .46764 L
.07757 .46748 L
.07751 .4674 L
.07754 .46739 L
.07766 .46746 L
.07789 .4676 L
.07818 .46781 L
.07853 .46805 L
.07888 .46828 L
.07921 .46854 L
.07949 .46878 L
.07973 .469 L
.07991 .46917 L
.08004 .46932 L
.08011 .46943 L
.08009 .4695 L
.08 .4695 L
.07985 .46947 L
.0797 .46942 L
.07954 .46935 L
Mistroke
.07942 .46929 L
.07933 .46923 L
.07927 .46916 L
.07921 .46906 L
.07912 .46895 L
.079 .46884 L
.07885 .46874 L
.07869 .46868 L
.07854 .46866 L
.0784 .46866 L
.0783 .46866 L
.07824 .46866 L
.07819 .46866 L
.07815 .46866 L
.07813 .46869 L
.07818 .46873 L
.07826 .46877 L
.07834 .4688 L
.07842 .46881 L
.07852 .4688 L
.07865 .46877 L
.07878 .46873 L
.07892 .46869 L
.07905 .46866 L
.07916 .46864 L
.07924 .46866 L
.07934 .46874 L
.07941 .46885 L
.07947 .46894 L
.07945 .46903 L
.07952 .46913 L
.0796 .46922 L
.07969 .46933 L
.0798 .46947 L
.07993 .46963 L
.08007 .46975 L
.08021 .46976 L
.08031 .46967 L
.08037 .46948 L
.08037 .4692 L
.08032 .46886 L
.08023 .4685 L
.0801 .46816 L
.07991 .46783 L
.07968 .4675 L
.07945 .4672 L
.07925 .46694 L
.07908 .46672 L
.07895 .46655 L
.07884 .46646 L
Mistroke
.07875 .46649 L
.07866 .46661 L
.07858 .46685 L
.0785 .46719 L
.07843 .46761 L
.07838 .46802 L
.07835 .46833 L
.07832 .46855 L
.0783 .46869 L
.07825 .46872 L
.07817 .4687 L
.07805 .46859 L
.0779 .46839 L
.07776 .46811 L
.07765 .46778 L
.07755 .46742 L
.07749 .46703 L
.07748 .46661 L
.07752 .46619 L
.07759 .46579 L
.07769 .46549 L
.07783 .46522 L
.07801 .46501 L
.07824 .46484 L
.0785 .46477 L
.07876 .46475 L
.07899 .46478 L
.07916 .46485 L
.07929 .46496 L
.07935 .46516 L
.07937 .46547 L
.07931 .46586 L
.07919 .46627 L
.079 .46664 L
.07877 .46692 L
.0785 .46712 L
.07821 .46725 L
.07791 .46733 L
.07766 .46735 L
.07746 .46734 L
.07735 .46731 L
.07733 .46728 L
.07736 .46725 L
.07742 .46722 L
.07747 .46717 L
.0775 .46713 L
.07749 .46712 L
.07744 .46719 L
.07736 .46735 L
.07727 .46756 L
Mistroke
.07719 .46777 L
.07713 .46796 L
.0771 .46807 L
.07708 .46805 L
.07709 .46793 L
.0771 .46775 L
.07716 .46756 L
.07723 .4674 L
.0773 .46726 L
.07736 .46719 L
.07741 .46713 L
.07745 .46711 L
.07746 .46707 L
.07745 .46701 L
.07742 .46694 L
.07738 .46685 L
.07733 .46675 L
.07729 .4667 L
.07727 .46673 L
.07726 .46685 L
.07726 .46702 L
.07726 .46721 L
.07728 .46739 L
.07732 .46754 L
.07737 .46766 L
.07743 .46784 L
.0775 .46803 L
.07755 .46826 L
.07759 .46849 L
.07761 .46867 L
.07759 .46881 L
.07754 .46891 L
.07748 .46899 L
.07745 .46905 L
.07743 .46909 L
.07742 .46911 L
.0774 .4691 L
.07736 .46912 L
.0773 .46916 L
.07723 .46921 L
.07715 .46926 L
.0771 .4693 L
.07707 .46933 L
.07707 .46933 L
.07709 .46931 L
.07709 .46929 L
.07707 .4693 L
.07702 .46931 L
.07695 .46935 L
.07684 .46941 L
Mistroke
.07671 .46949 L
.07656 .46956 L
.07642 .4696 L
.07631 .4696 L
.07625 .46952 L
.07621 .46936 L
.07619 .4691 L
.07616 .46878 L
.07614 .46838 L
.07629 .46796 L
.07636 .46747 L
.07651 .467 L
.07675 .46654 L
.07707 .46607 L
.07742 .46563 L
.07779 .46522 L
.07816 .46491 L
.07851 .46472 L
.07884 .46463 L
.07914 .4646 L
.07943 .46463 L
.07968 .46469 L
.07989 .46476 L
.08007 .46481 L
.08022 .46483 L
.08033 .46483 L
.08039 .46483 L
.08041 .46482 L
.0804 .46483 L
.08035 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46484 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08024 .46483 L
.08021 .46483 L
.08017 .46483 L
.08013 .46483 L
.08011 .46483 L
.08012 .46483 L
.08018 .46483 L
.08029 .46483 L
.08044 .46483 L
.08064 .46482 L
.08088 .46482 L
.08117 .46481 L
Mistroke
.08148 .46481 L
.08176 .46481 L
.08203 .46481 L
.08227 .46481 L
.08247 .46481 L
.08261 .46481 L
.08269 .46481 L
.08273 .46481 L
.08274 .46481 L
.08273 .46482 L
.08269 .46482 L
.08264 .46482 L
.08259 .46482 L
.08252 .46482 L
.08251 .46482 L
.08253 .46481 L
.08259 .46481 L
.08266 .4648 L
.08274 .4648 L
.08281 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08299 .46479 L
.08299 .46479 L
.08297 .46479 L
.08294 .46479 L
.0829 .4648 L
.08284 .4648 L
.08277 .4648 L
.0827 .4648 L
.08263 .4648 L
.08258 .4648 L
.08254 .4648 L
.08251 .4648 L
.0825 .4648 L
.0825 .4648 L
.0825 .4648 L
.08252 .4648 L
.08256 .4648 L
.08261 .4648 L
.08268 .4648 L
.08275 .4648 L
.08283 .4648 L
.08288 .4648 L
.0829 .4648 L
.08291 .46479 L
.0829 .46479 L
.0829 .46479 L
.08291 .46479 L
Mistroke
.08294 .46479 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .46481 L
.08289 .46482 L
.08289 .46484 L
.08289 .46485 L
.08289 .46484 L
.08289 .46481 L
.08289 .46478 L
.08289 .46475 L
.0829 .46472 L
.0829 .4647 L
.0829 .46466 L
.0829 .4646 L
.0829 .46452 L
.08291 .46439 L
.08291 .46424 L
.08292 .46407 L
.08292 .46388 L
.08293 .46368 L
.08293 .46348 L
.08294 .46331 L
.08294 .46313 L
.08295 .46296 L
.08295 .4628 L
.08295 .46266 L
.08296 .46254 L
.08296 .46244 L
.08296 .46236 L
.08297 .46233 L
.08297 .46234 L
.08296 .46238 L
Mistroke
.08296 .46242 L
.08296 .46245 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46246 L
.08296 .46244 L
.08296 .46242 L
.08296 .46238 L
.08297 .46235 L
.08297 .46233 L
.08297 .46234 L
.08296 .46239 L
.08296 .46249 L
.08296 .46263 L
.08295 .4628 L
.08295 .46301 L
.08295 .46325 L
.08297 .46352 L
.08298 .46378 L
.08298 .46402 L
.08295 .46424 L
.08291 .46442 L
.08285 .46457 L
.08277 .46466 L
.0827 .46471 L
.08263 .46472 L
.08257 .46469 L
.08253 .46464 L
.08251 .46459 L
.0825 .46454 L
.0825 .46451 L
.0825 .4645 L
.08252 .46451 L
.08256 .46454 L
.08261 .46458 L
.08268 .46463 L
.08276 .46469 L
.08283 .46475 L
.08288 .46479 L
.0829 .46483 L
.0829 .46485 L
.0829 .46484 L
.0829 .46483 L
.08291 .46481 L
Mistroke
.08294 .4648 L
.08299 .46479 L
.08304 .46479 L
.08308 .46479 L
.08311 .46479 L
.08313 .46479 L
.08314 .46479 L
.08314 .46479 L
.08314 .46479 L
.08313 .46479 L
.08312 .46479 L
.08309 .46479 L
.08305 .46479 L
.083 .46479 L
.08295 .4648 L
.0829 .4648 L
.08287 .4648 L
.08285 .4648 L
.08284 .4648 L
.08285 .4648 L
.08288 .4648 L
.08289 .4648 L
.0829 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08288 .4648 L
.08285 .4648 L
.08282 .4648 L
.0828 .4648 L
.08278 .4648 L
.08278 .4648 L
.08283 .4648 L
.08293 .46479 L
.08308 .46479 L
.08325 .46479 L
.08343 .46479 L
.08362 .46479 L
Mistroke
.08378 .46479 L
.08391 .46479 L
.08399 .46478 L
.08403 .46478 L
.08402 .46479 L
.08396 .46479 L
.08388 .46479 L
.0838 .46479 L
.08373 .46479 L
.08364 .46479 L
.08353 .46479 L
.08347 .46479 L
.08342 .46479 L
.08339 .46479 L
.08339 .46479 L
.08343 .46479 L
.08346 .46479 L
.0835 .46479 L
.08353 .46479 L
.08353 .46479 L
.08348 .46479 L
.0834 .46479 L
.08331 .46479 L
.08319 .46479 L
.08307 .46479 L
.08295 .46479 L
.08286 .4648 L
.0828 .4648 L
.08279 .4648 L
.08281 .4648 L
.08285 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08288 .46478 L
.08285 .46475 L
.08281 .4647 L
.08279 .46463 L
.08278 .46458 L
.08282 .46455 L
.0829 .46458 L
.08301 .46471 L
.08315 .46496 L
.08331 .46529 L
.08348 .46568 L
.08364 .46612 L
.08376 .46658 L
.08384 .46709 L
.08389 .46751 L
.08388 .46792 L
.0838 .46832 L
.08364 .46871 L
.08343 .46912 L
.08318 .46941 L
.08292 .4696 L
.08269 .46971 L
.08257 .46937 L
.08253 .46936 L
.08255 .46935 L
.08268 .46937 L
.08289 .46942 L
.08317 .46948 L
.08346 .46951 L
.08383 .46951 L
.08422 .46945 L
.0846 .46934 L
.08494 .46924 L
.0852 .46918 L
.08538 .4692 L
.08545 .4693 L
.08545 .46948 L
.08539 .46976 L
.08531 .47012 L
.08521 .47053 L
Mistroke
.08513 .47099 L
.08506 .47148 L
.085 .47195 L
.08494 .47243 L
.08487 .47289 L
.08481 .47333 L
.08477 .47371 L
.08475 .47402 L
.08474 .47423 L
.08477 .47435 L
.0848 .47439 L
.08485 .47436 L
.0849 .47429 L
.08492 .47421 L
.08494 .47415 L
.08495 .47412 L
.08498 .47412 L
.08504 .47411 L
.0851 .47411 L
.08517 .47411 L
.08523 .47411 L
.08527 .47411 L
.08529 .47411 L
.08529 .47411 L
.08527 .47411 L
.08524 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08523 .47411 L
.08524 .47412 L
.08526 .47412 L
.08527 .47413 L
.08527 .47413 L
.08526 .47412 L
.08525 .4741 L
.08525 .47409 L
.08524 .47406 L
.08521 .47405 L
.08512 .47403 L
.08498 .47402 L
.08481 .47404 L
.08464 .4741 L
.08447 .47418 L
.08434 .47425 L
.08425 .47429 L
.08424 .47428 L
.08434 .47421 L
Mfstroke
.11417 .46929 m
.11429 .46922 L
.11435 .46914 L
.11437 .46908 L
.11433 .46905 L
.11426 .46903 L
.11416 .46899 L
.11406 .46893 L
.114 .46888 L
.114 .46886 L
.11407 .46888 L
.11421 .46895 L
s
.14739 .55002 m
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
s
.12793 .49492 m
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
s
.08021 .46474 m
.08033 .4648 L
.0804 .46482 L
.08042 .46483 L
.0804 .46483 L
.08036 .46483 L
.08031 .46483 L
.08028 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
Mistroke
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08026 .46483 L
.08025 .46483 L
.08024 .46483 L
.08024 .46483 L
.08024 .46483 L
.08026 .46483 L
.08027 .46483 L
.08029 .46483 L
.08031 .46483 L
.08033 .46483 L
.08034 .46483 L
.08035 .46483 L
.08034 .46483 L
.08031 .46483 L
.0803 .46484 L
.08031 .46486 L
.08035 .46488 L
.08038 .46489 L
.08041 .46487 L
.08042 .46483 L
.08042 .46478 L
.08041 .46472 L
.08038 .46466 L
.08035 .4646 L
.08032 .46455 L
.0803 .46451 L
.08028 .46449 L
.08028 .46448 L
.08024 .46448 L
.08017 .46448 L
.08009 .4645 L
.08003 .46454 L
.07998 .46459 L
Mistroke
.07998 .46465 L
.08005 .46471 L
.08018 .46477 L
.08038 .46483 L
.08062 .46486 L
.08089 .46488 L
.08117 .46487 L
.08144 .46485 L
.08169 .46482 L
.08196 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08293 .46479 L
.08296 .46479 L
.08296 .46479 L
.08294 .46479 L
.0829 .4648 L
.08283 .4648 L
.08275 .4648 L
.08267 .4648 L
.08259 .4648 L
.08252 .4648 L
.08247 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
Mistroke
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .46479 L
.0829 .46479 L
.08291 .46479 L
.08295 .46479 L
.08298 .46479 L
.08298 .46479 L
.08295 .4648 L
.08288 .4648 L
.08279 .4648 L
.08268 .4648 L
.08257 .46481 L
.08247 .46481 L
.0824 .46481 L
.08234 .46481 L
.0823 .46481 L
.0823 .46481 L
.08229 .46481 L
.08229 .46481 L
.08233 .46481 L
.08239 .46481 L
.08248 .4648 L
.08259 .4648 L
.0827 .4648 L
.08281 .4648 L
.08291 .46479 L
.08298 .46479 L
.083 .46479 L
.08298 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08291 .4648 L
.08294 .46479 L
Mistroke
.08298 .46479 L
.08302 .46479 L
.08304 .46479 L
.08303 .46479 L
.08297 .46479 L
.08286 .4648 L
.08269 .4648 L
.08246 .4648 L
.08218 .4648 L
.08188 .46481 L
.08158 .46481 L
.08132 .46481 L
.08111 .46482 L
.08095 .46482 L
.08086 .46482 L
.08084 .46482 L
.08091 .46482 L
.08105 .46482 L
.08126 .46482 L
.08151 .46481 L
.0818 .46481 L
.08211 .46481 L
.0824 .4648 L
.08265 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08304 .46479 L
.08303 .46479 L
.083 .46479 L
.083 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08299 .4648 L
.0829 .4648 L
.08274 .4648 L
.0825 .46481 L
.08221 .46482 L
.08191 .46482 L
.08165 .46483 L
.08146 .46483 L
.08138 .46483 L
.0813 .46483 L
.08119 .46483 L
.08109 .46483 L
.08105 .46483 L
.08107 .46482 L
.08111 .46482 L
.0811 .46482 L
Mistroke
.08105 .46482 L
.081 .46483 L
.08096 .46484 L
.0809 .46484 L
.08075 .46485 L
.08046 .46486 L
.08018 .46486 L
.07993 .46486 L
.07972 .46487 L
.07959 .46487 L
.07949 .46487 L
.07946 .46486 L
.07952 .46486 L
.07963 .46485 L
.0798 .46485 L
.08001 .46484 L
.08026 .46483 L
.08056 .46483 L
.08088 .46482 L
.08119 .46481 L
.08149 .46481 L
.08177 .46481 L
.08203 .4648 L
.0823 .4648 L
.08256 .4648 L
.0828 .46479 L
.08299 .46479 L
.0831 .46479 L
.08311 .46479 L
.08303 .4648 L
.08286 .4648 L
.08263 .46481 L
.08235 .46481 L
.08206 .46482 L
.08178 .46482 L
.08148 .46483 L
.08122 .46483 L
.08099 .46483 L
.08073 .46484 L
.0805 .46484 L
.0803 .46484 L
.08014 .46484 L
.08003 .46484 L
.07997 .46483 L
.07997 .46483 L
.08003 .46483 L
.08014 .46483 L
.08027 .46483 L
.08043 .46482 L
.08063 .46482 L
Mistroke
.08087 .46482 L
.08113 .46482 L
.0814 .46481 L
.08168 .46481 L
.08195 .46481 L
.08222 .4648 L
.08246 .4648 L
.08267 .4648 L
.08284 .4648 L
.08296 .46479 L
.08303 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08297 .46479 L
.08294 .46479 L
.08291 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.08301 .46479 L
.08303 .46479 L
.08302 .46479 L
.08297 .4648 L
.08286 .4648 L
.08268 .4648 L
.08241 .46481 L
.08211 .46482 L
.08182 .46482 L
.08158 .46483 L
.08136 .46483 L
.08121 .46483 L
.08111 .46483 L
.08104 .46483 L
.08103 .46483 L
.0811 .46483 L
.08126 .46482 L
.08149 .46482 L
.08176 .46481 L
.08206 .46481 L
.08237 .4648 L
.08266 .4648 L
.08289 .46479 L
.08301 .46479 L
.08305 .46479 L
.08305 .46479 L
.08303 .46479 L
.08299 .46479 L
.08295 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.0829 .46479 L
.08292 .46479 L
.08296 .46479 L
.083 .46479 L
.08303 .46479 L
.08302 .46479 L
.08295 .4648 L
.08283 .4648 L
.08265 .4648 L
.08244 .46481 L
.08222 .46481 L
.08204 .46481 L
.08189 .46482 L
.08176 .46482 L
.08171 .46482 L
.08167 .46482 L
.08166 .46482 L
.08169 .46482 L
.08177 .46481 L
.08191 .46481 L
.08211 .46481 L
.08235 .4648 L
.08259 .4648 L
.0828 .4648 L
.08296 .46479 L
.08303 .46479 L
.083 .46479 L
.08289 .4648 L
.08277 .4648 L
.08264 .4648 L
.08254 .4648 L
Mistroke
.08248 .4648 L
.08244 .4648 L
.08243 .4648 L
.08243 .4648 L
.08243 .4648 L
.08246 .4648 L
.0825 .4648 L
.08257 .4648 L
.08265 .4648 L
.08273 .4648 L
.08282 .4648 L
.08289 .4648 L
.08294 .46479 L
.08297 .46479 L
.08296 .46479 L
.08294 .46479 L
.08291 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .46479 L
.0829 .46479 L
.08292 .46479 L
.08295 .46479 L
.08295 .46479 L
.08293 .46479 L
.0829 .4648 L
.08284 .4648 L
.08276 .46481 L
.08268 .46481 L
.08261 .46481 L
.08256 .46482 L
.08252 .46482 L
.0825 .46482 L
.08249 .46482 L
.0825 .46482 L
.08248 .46482 L
.08249 .46482 L
.08253 .46481 L
.08258 .46481 L
.08266 .4648 L
.08274 .4648 L
.08282 .4648 L
.08289 .46479 L
.08295 .46479 L
.08298 .46479 L
.08296 .46479 L
.08293 .46479 L
.08291 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46482 L
.08289 .46482 L
.08289 .46482 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .46481 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08289 .46479 L
.08288 .46479 L
.08285 .46479 L
.08282 .46478 L
.08279 .46476 L
.08278 .46474 L
.08278 .46473 L
.08281 .46473 L
.08285 .46474 L
.08294 .46476 L
.08308 .46483 L
.08327 .46493 L
.08352 .46506 L
.08383 .46526 L
.08418 .4654 L
.08452 .46553 L
.08485 .46568 L
.08512 .46581 L
.08538 .46596 L
.08561 .46616 L
.0858 .4664 L
.08595 .46666 L
.0861 .46695 L
.08626 .46723 L
.08641 .46748 L
.08657 .46778 L
.08672 .46806 L
.08685 .46832 L
Mistroke
.08694 .46863 L
.08699 .46895 L
.087 .46923 L
.08695 .46942 L
.08679 .46945 L
.08656 .46936 L
.08624 .46912 L
.08588 .46864 L
.08544 .46818 L
.08494 .46762 L
.08448 .46708 L
.08401 .46672 L
.08351 .46645 L
.08306 .46628 L
.08268 .4662 L
.08247 .46625 L
.08231 .46639 L
.08223 .46663 L
.08222 .46695 L
.08224 .46732 L
.08224 .46776 L
.08224 .46822 L
.08222 .46867 L
.08214 .46904 L
.08197 .46928 L
.08172 .46942 L
.08135 .46948 L
.08097 .4695 L
.0804 .46951 L
.07974 .46955 L
.07902 .46966 L
.07827 .46989 L
.07753 .47023 L
.07684 .47065 L
.07625 .47112 L
.07571 .47161 L
.07524 .4721 L
.07482 .47259 L
.07453 .47306 L
.07437 .47349 L
.07433 .47388 L
.07435 .47418 L
.07443 .47439 L
.07456 .47449 L
.07471 .47448 L
.07482 .4744 L
.07486 .47429 L
.07485 .47421 L
.07481 .47418 L
.07471 .47422 L
Mistroke
.07458 .47431 L
.07444 .47446 L
.07429 .47466 L
.07413 .4749 L
.07398 .47515 L
.07382 .47539 L
.07364 .47564 L
.07343 .47588 L
.0732 .47613 L
.07296 .47645 L
.07275 .4768 L
.07259 .47717 L
.07251 .47756 L
.07251 .47798 L
.07258 .47839 L
.07273 .47881 L
.07292 .47921 L
.07313 .47956 L
.07331 .47994 L
.07343 .48033 L
.07352 .48068 L
.07359 .48095 L
.07366 .48116 L
.07373 .48129 L
.07376 .48137 L
.07376 .4814 L
.07373 .4814 L
.07368 .48138 L
.07364 .48135 L
.07363 .48132 L
.07365 .4813 L
.0737 .48129 L
.0738 .48126 L
.07391 .48116 L
.074 .48102 L
.07404 .48083 L
.07403 .48062 L
.07397 .48041 L
.07386 .48022 L
.07373 .48006 L
.07357 .47995 L
.07342 .47988 L
.07331 .47987 L
.07325 .47993 L
.07327 .48004 L
.07334 .48016 L
.07344 .48035 L
.07356 .48056 L
.0737 .48077 L
.07385 .48097 L
Mistroke
.074 .48113 L
.07413 .48124 L
.07421 .48128 L
.07425 .48129 L
.07424 .4813 L
.07419 .48131 L
.07414 .48131 L
.0741 .48128 L
.07407 .48126 L
.07409 .48122 L
.07416 .48116 L
.07427 .48107 L
.07438 .48096 L
.07449 .48083 L
.07456 .48071 L
.07457 .4806 L
.0745 .48052 L
.07435 .48046 L
.07411 .48042 L
.07381 .48039 L
.07351 .48042 L
.07325 .48053 L
.07304 .48063 L
.07287 .48076 L
.07272 .4809 L
.07262 .48101 L
.07256 .4811 L
.07257 .48116 L
.07263 .48117 L
.07277 .48113 L
.07298 .48107 L
.07323 .481 L
.07351 .48094 L
.07379 .48089 L
.07402 .48084 L
.07415 .48076 L
.07421 .48066 L
.07421 .48052 L
.07418 .48037 L
.07412 .4802 L
.07407 .48003 L
.07403 .47985 L
.07399 .47961 L
.07392 .47931 L
.07381 .47896 L
.07367 .47861 L
.07351 .47828 L
.07336 .47803 L
.07325 .47786 L
.07319 .47778 L
Mistroke
.07319 .47777 L
.07321 .47777 L
.07326 .47782 L
.07332 .47789 L
.07338 .478 L
.07344 .47816 L
.0735 .47833 L
.07358 .47851 L
.07368 .47868 L
.07396 .4788 L
.07411 .47886 L
.07426 .47883 L
.0744 .47876 L
.07448 .47861 L
.07453 .47845 L
.07454 .4783 L
.07453 .47811 L
.07451 .47798 L
.0745 .47786 L
.07447 .47778 L
.07444 .47772 L
.07441 .47768 L
.07439 .47768 L
.07437 .47775 L
.07436 .47788 L
.07435 .47804 L
.07434 .47819 L
.07436 .47831 L
.07439 .47837 L
.07442 .47838 L
.07445 .47834 L
.07448 .47827 L
.07449 .47817 L
.07449 .47805 L
.07448 .47789 L
.07447 .47775 L
.07444 .47757 L
.07441 .47735 L
.07439 .47712 L
.07439 .47696 L
.07439 .47685 L
.0744 .47679 L
.07441 .47675 L
.07443 .4767 L
.07446 .47663 L
.0745 .47658 L
.07454 .47654 L
.07459 .47652 L
.07462 .47652 L
.07464 .47655 L
Mistroke
.07465 .47664 L
.07464 .47676 L
.07462 .47688 L
.0746 .477 L
.07459 .47714 L
.07458 .47732 L
.07458 .4775 L
.07457 .47771 L
.07456 .47792 L
.07456 .47812 L
.07455 .47831 L
.07455 .47847 L
.07454 .47858 L
.07454 .47863 L
.07454 .4786 L
.07455 .47851 L
.07456 .47838 L
.07458 .4782 L
.0746 .47807 L
.0746 .47791 L
.0746 .47775 L
.07457 .47764 L
.07454 .47753 L
.07451 .47742 L
.07447 .47731 L
.07444 .4772 L
.07441 .47713 L
.07439 .4771 L
.07438 .47712 L
.07437 .47715 L
.07437 .47716 L
.07437 .47714 L
.07438 .47707 L
.0744 .47697 L
.07444 .47686 L
.07448 .47677 L
.07452 .47673 L
.07457 .47675 L
.0746 .47683 L
.07462 .47698 L
.07462 .47718 L
.07461 .47737 L
.0746 .47753 L
.07458 .47765 L
.07457 .47777 L
.07456 .4779 L
.07456 .47805 L
.07455 .47823 L
.07455 .47844 L
.07454 .47861 L
Mistroke
.07454 .4787 L
.07454 .47875 L
.07454 .47876 L
.07454 .47874 L
.07454 .47874 L
.07454 .47873 L
.07454 .47874 L
.07454 .47876 L
.07454 .47874 L
.07454 .47869 L
.07455 .47856 L
.07455 .47835 L
.07456 .47806 L
.07457 .47775 L
.07458 .47745 L
.07458 .47713 L
.07459 .47683 L
.0746 .47658 L
.07461 .47638 L
.07462 .47617 L
.07462 .47609 L
.07462 .47601 L
.07463 .47597 L
.07463 .47596 L
.07462 .47604 L
.07462 .47618 L
.07461 .47634 L
.07461 .47648 L
.07461 .47658 L
.07461 .47665 L
.07461 .47669 L
.07461 .47671 L
.07461 .47672 L
.0746 .47673 L
.0746 .47679 L
.0746 .47688 L
.07459 .47701 L
.07459 .47713 L
.07459 .47723 L
.07458 .47734 L
.07458 .47744 L
.07457 .47754 L
.07457 .47765 L
.07456 .47778 L
.07456 .47792 L
.07455 .47804 L
.07455 .47812 L
.07455 .47815 L
.07455 .47817 L
.07455 .47816 L
Mistroke
.07456 .47816 L
.07456 .47818 L
.07456 .47825 L
.07455 .47835 L
.07455 .47851 L
.07454 .47867 L
.07454 .47876 L
.07454 .47878 L
.07454 .47872 L
.07454 .47865 L
.07455 .47857 L
.07455 .47848 L
.07455 .47837 L
.07455 .47825 L
.07456 .47815 L
.07456 .47804 L
.07456 .47794 L
.07457 .47792 L
.07458 .47794 L
.07458 .47801 L
.07458 .47815 L
.07456 .47834 L
.07454 .47853 L
.07453 .47867 L
.07453 .47878 L
.07454 .47883 L
.07454 .47882 L
.07452 .47872 L
.07446 .47849 L
.07438 .47823 L
.07428 .47801 L
.07418 .47777 L
.07409 .47755 L
.07401 .47737 L
.07394 .47727 L
.07389 .47724 L
.07387 .47729 L
.07388 .47739 L
.07393 .47751 L
.07398 .47767 L
.07407 .47781 L
.07418 .47794 L
.07432 .47805 L
.07448 .47807 L
.07463 .47802 L
.07476 .47788 L
.07486 .47773 L
.07492 .47752 L
.07492 .47731 L
.07487 .47708 L
Mistroke
.07479 .47693 L
.0747 .47682 L
.07463 .47676 L
.0746 .47673 L
.07467 .47669 L
.07483 .47663 L
.07502 .47657 L
.07521 .47655 L
.07541 .47655 L
.0756 .47657 L
.07577 .4766 L
.07581 .47664 L
.0758 .47668 L
.07578 .47672 L
.07575 .47675 L
.0757 .47676 L
.07561 .47675 L
.07552 .47671 L
.07532 .47665 L
.07509 .47661 L
.07485 .47662 L
.07465 .47667 L
.07447 .47677 L
.07438 .4769 L
.07435 .47706 L
.07438 .47722 L
.07447 .47736 L
.07459 .47749 L
.07477 .4776 L
.07501 .4777 L
.0753 .47776 L
.07559 .47777 L
.07584 .47773 L
.07603 .47761 L
.07618 .4774 L
.07628 .47711 L
.07634 .47674 L
.07637 .47633 L
.07638 .47592 L
.07637 .47554 L
.07636 .47524 L
.07637 .47503 L
.07637 .47486 L
.07634 .4747 L
.07629 .47449 L
.07627 .47423 L
.07632 .47397 L
.07643 .47375 L
.07656 .47357 L
.07668 .47341 L
Mistroke
.07677 .47326 L
.07683 .47311 L
.07684 .47296 L
.07679 .47283 L
.07672 .47273 L
.07663 .47301 L
.07661 .47306 L
.07662 .47314 L
.07666 .47322 L
.07672 .47332 L
.07676 .4734 L
.07678 .47346 L
.07679 .47351 L
.07679 .47354 L
.07678 .47352 L
.07677 .4735 L
.07676 .47348 L
.07677 .47349 L
.07677 .47351 L
.07676 .47353 L
.07675 .47353 L
.07673 .47355 L
.07672 .47362 L
.07674 .47376 L
.07679 .47395 L
.07687 .47411 L
.07697 .47421 L
.07705 .47419 L
.07711 .47409 L
.07715 .47388 L
.07717 .47353 L
.07719 .47307 L
.07723 .47257 L
.0773 .47208 L
.07737 .47164 L
.07743 .47118 L
.07748 .47073 L
.07751 .47029 L
.07751 .46989 L
.07751 .46958 L
.07749 .4694 L
.07749 .46931 L
.07749 .46929 L
.07749 .46932 L
.07748 .46939 L
.07748 .46946 L
.07748 .46952 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
Mistroke
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07748 .46954 L
.07746 .46954 L
.07743 .46954 L
.07739 .46954 L
.07735 .46954 L
.07733 .46955 L
.07735 .46954 L
.0774 .46954 L
.0775 .46955 L
.07764 .46957 L
.07783 .46962 L
.07804 .46969 L
.07827 .46975 L
.07849 .46978 L
.07874 .46975 L
.079 .46965 L
.0793 .46946 L
.07962 .46918 L
.07996 .46882 L
.08031 .4684 L
.08065 .46794 L
.08098 .46745 L
.08131 .46698 L
.08155 .46651 L
.08178 .46604 L
.08198 .46561 L
.08217 .46522 L
.08237 .46491 L
.08256 .4647 L
.08273 .46458 L
.08289 .46454 L
.08306 .46456 L
.08326 .46462 L
.08349 .4647 L
.08372 .46475 L
.08397 .46478 L
.08421 .46478 L
.08441 .46478 L
.08458 .46477 L
.08469 .46477 L
.08474 .46477 L
.08471 .46477 L
.08462 .46477 L
.08447 .46478 L
.08426 .46478 L
.08401 .46478 L
.08373 .46479 L
Mistroke
.08344 .46479 L
.08317 .46479 L
.08297 .46479 L
.08283 .4648 L
.08276 .4648 L
.08274 .4648 L
.08276 .4648 L
.08279 .4648 L
.08284 .4648 L
.08287 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08287 .4648 L
.08284 .4648 L
.0828 .4648 L
.08276 .4648 L
.08274 .4648 L
.08273 .46481 L
.08276 .46484 L
.08282 .46488 L
.08293 .46491 L
Mistroke
.08309 .46493 L
.08331 .46491 L
.08359 .46486 L
.08394 .46476 L
.08436 .46462 L
.08484 .46443 L
.08539 .46422 L
.08601 .46398 L
.08666 .46373 L
.0873 .46348 L
.08792 .46323 L
.08852 .46299 L
.08907 .46277 L
.08954 .46258 L
.08995 .46242 L
.09027 .46234 L
.09052 .46233 L
.09069 .46238 L
.0908 .46246 L
.09086 .46253 L
.0909 .46255 L
.09094 .46248 L
.09102 .46231 L
.09114 .46204 L
.0913 .46168 L
.09151 .46127 L
.09177 .46081 L
.09205 .46033 L
.09233 .45985 L
.09261 .45938 L
.09289 .45892 L
.09314 .45849 L
.09337 .4581 L
.09355 .4578 L
.09367 .45758 L
.09374 .45746 L
.09377 .45743 L
.09375 .45745 L
.09371 .45752 L
.09366 .4576 L
.09363 .45765 L
.09361 .45768 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
Mistroke
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09361 .45769 L
.09362 .45769 L
.09364 .45772 L
.09365 .45777 L
.09364 .45785 L
.09362 .45792 L
.09358 .45796 L
.09354 .45796 L
.09349 .45787 L
.09345 .45768 L
.09341 .45738 L
.09338 .45697 L
.09333 .45646 L
.09329 .45581 L
.09327 .4553 L
.09326 .45471 L
.09331 .45411 L
.0934 .45347 L
.09355 .45275 L
.09377 .45206 L
.09404 .45138 L
.09435 .45073 L
.09468 .45015 L
Mistroke
.09501 .44962 L
.09531 .44914 L
.0956 .44867 L
.09587 .4482 L
.09611 .44767 L
.09632 .44708 L
.09649 .44642 L
.09662 .44573 L
.0967 .44503 L
.09673 .44436 L
.09673 .44375 L
.0967 .44323 L
.09667 .44278 L
.09665 .44239 L
.09664 .44207 L
.09664 .44182 L
.09665 .44165 L
.09665 .44157 L
.09665 .44153 L
.09665 .44149 L
.09665 .4414 L
.09666 .44123 L
.09666 .44094 L
.09667 .4405 L
.09669 .43992 L
.0967 .43925 L
.09672 .43854 L
.09673 .4379 L
.09675 .43717 L
.09677 .43651 L
.09678 .43587 L
.0968 .43528 L
.09681 .4348 L
.09682 .43445 L
.09682 .43424 L
.09682 .43416 L
.09682 .4342 L
.09682 .43434 L
.09681 .43452 L
.09681 .43469 L
.09681 .43482 L
.0968 .43485 L
.09681 .43477 L
Mfstroke
.08407 .41146 m
.08412 .4115 L
.08416 .41143 L
.08421 .41123 L
.08423 .41094 L
.08422 .41056 L
.08418 .41012 L
.08414 .40967 L
.08408 .40924 L
.08402 .4089 L
.08396 .40859 L
.08391 .40829 L
.08388 .40808 L
.08386 .40796 L
.08385 .40794 L
.08385 .40799 L
.08387 .40808 L
.08389 .40816 L
.08395 .40822 L
.08402 .40827 L
.08408 .40832 L
.08414 .40835 L
.08418 .40837 L
.08419 .40842 L
.08419 .40853 L
.08417 .40869 L
.08413 .40888 L
.08409 .4091 L
.08405 .40937 L
.08401 .40965 L
.08399 .40998 L
.08398 .41032 L
.08398 .41066 L
.08398 .41098 L
.084 .41123 L
.08402 .41142 L
.08406 .41154 L
.08411 .41159 L
.08415 .41156 L
.08419 .41149 L
.08422 .41142 L
.08424 .41138 L
.08424 .41136 L
.08422 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41125 L
.0842 .41125 L
.0842 .41127 L
.0842 .41132 L
.08418 .4114 L
.08415 .41152 L
.0841 .41165 L
.08406 .4118 L
.08404 .41196 L
.08405 .41213 L
.0841 .41232 L
.0842 .41251 L
.08435 .4127 L
.08455 .41289 L
.08478 .41306 L
.08503 .41321 L
.0853 .41334 L
.08557 .41343 L
.08583 .41349 L
.08609 .41354 L
.08633 .41357 L
.08655 .41359 L
.08671 .41363 L
.08683 .41366 L
.0869 .4137 L
.08692 .41371 L
.0869 .41371 L
.08687 .41371 L
.08682 .4137 L
.08679 .41368 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
Mistroke
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08677 .41367 L
.08676 .41367 L
.08672 .41367 L
.08668 .41367 L
.08665 .41367 L
.08663 .41367 L
.08664 .41367 L
.0867 .41367 L
.0868 .41367 L
.08696 .41367 L
.08715 .41367 L
.08739 .41367 L
.08764 .41367 L
.08792 .41367 L
.08819 .41368 L
.08847 .41368 L
.08875 .41368 L
.08903 .41368 L
.08927 .41368 L
.08947 .41368 L
.08958 .41368 L
.08961 .41368 L
.08954 .41368 L
.08938 .41368 L
.08916 .41368 L
.08889 .41368 L
.08861 .41368 L
.08832 .41367 L
.08802 .41367 L
.08778 .41367 L
.08749 .41367 L
.0872 .41367 L
.08693 .41367 L
.08673 .41367 L
.08661 .41367 L
.08658 .41367 L
.08666 .41367 L
.08681 .41367 L
.08704 .41367 L
.08731 .41367 L
.0876 .41367 L
.0879 .41367 L
Mistroke
.08818 .41368 L
.08845 .41368 L
.08871 .41368 L
.08895 .41368 L
.08916 .41368 L
.08933 .41368 L
.08945 .41368 L
.08952 .41368 L
.08954 .41368 L
.08952 .41368 L
.08948 .41368 L
.08944 .41368 L
.08941 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08939 .41368 L
.08938 .41368 L
.08937 .41368 L
.08934 .41368 L
.0893 .41368 L
Mistroke
.08926 .41368 L
.08924 .41368 L
.08926 .41368 L
.08931 .41368 L
.08942 .41368 L
.08957 .41368 L
.08977 .41368 L
.09 .41368 L
.09026 .41368 L
.09053 .41368 L
.09079 .41368 L
.09106 .41368 L
.09132 .41368 L
.09156 .41368 L
.09177 .41368 L
.09194 .41368 L
.09206 .41368 L
.09213 .41368 L
.09215 .41368 L
.09213 .41368 L
.0921 .41368 L
.09205 .41368 L
.09202 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
Mistroke
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41368 L
.092 .41369 L
.09202 .4137 L
.09204 .41373 L
.09208 .41376 L
.09212 .4138 L
.09214 .41381 L
.09213 .4138 L
.09207 .41375 L
.09195 .41366 L
.09176 .41353 L
.09153 .41336 L
.09128 .41316 L
.09105 .41295 L
.09088 .41277 L
.09076 .4126 L
.09068 .41243 L
.09063 .41223 L
.09059 .412 L
.09055 .41174 L
.09052 .41146 L
.09039 .41116 L
.09035 .41082 L
.09033 .41041 L
.09033 .40993 L
.09035 .40938 L
.09037 .40875 L
.09031 .40805 L
.09017 .40728 L
.08999 .40646 L
.0898 .40563 L
.08963 .40485 L
.08952 .40417 L
.08949 .40361 L
.08954 .40314 L
.08963 .40276 L
.08971 .40247 L
.08973 .40224 L
.08968 .40207 L
Mistroke
Mfstroke
.08454 .39045 m
.08454 .39032 L
.08454 .39027 L
.08454 .39029 L
.08454 .39036 L
.08453 .39045 L
.08453 .39054 L
.08453 .39061 L
.08452 .39065 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39066 L
.08452 .39065 L
.08453 .39063 L
.08453 .39061 L
.08453 .39058 L
.08453 .39055 L
.08454 .39053 L
.08454 .39051 L
.08454 .3905 L
.08454 .39049 L
.08454 .39048 L
.08454 .39048 L
.08454 .39048 L
.08453 .3905 L
.08453 .39053 L
.08453 .39059 L
.08453 .39071 L
.08452 .39087 L
.08452 .39108 L
.08452 .39125 L
.08451 .39143 L
.08451 .39158 L
.08451 .39169 L
.08451 .39172 L
.08451 .39175 L
.08451 .39175 L
.08451 .39172 L
.08451 .39166 L
.08451 .39159 L
.08451 .39147 L
.08451 .39133 L
.08451 .39116 L
.08452 .39099 L
.08452 .39081 L
.08452 .39069 L
.08452 .39062 L
.08453 .39058 L
Mistroke
.08453 .39056 L
.08453 .39055 L
.08453 .39056 L
.08453 .39057 L
.08453 .39056 L
.08453 .39055 L
.08453 .39055 L
.08453 .39055 L
.08453 .39056 L
.08453 .39058 L
.08452 .39059 L
.08452 .39083 L
.08452 .39083 L
.08452 .39082 L
.08452 .39082 L
.08452 .39082 L
.08452 .39081 L
.08452 .39081 L
.08452 .3908 L
.08452 .3908 L
.08452 .39078 L
.08453 .39075 L
.08453 .39071 L
.08453 .39069 L
.08453 .39069 L
.08453 .39069 L
.08453 .39074 L
.08452 .3908 L
.08452 .3909 L
.08452 .39105 L
.08452 .39125 L
.08452 .39148 L
.08451 .3917 L
.08451 .39192 L
.08451 .39209 L
.08451 .39221 L
.08451 .39228 L
.08451 .39229 L
.08451 .39225 L
.08451 .39215 L
.08451 .39195 L
.08451 .39175 L
.08449 .39149 L
.08445 .39122 L
.08442 .39096 L
.08441 .39075 L
.08442 .39059 L
.08447 .39048 L
.08457 .39042 L
.08473 .39039 L
Mistroke
.08493 .39041 L
.08516 .39046 L
.08542 .3905 L
.08569 .39053 L
.08596 .39055 L
.08622 .39057 L
.08649 .3906 L
.08676 .39063 L
.087 .39067 L
.08719 .39069 L
.0873 .39068 L
.08732 .39063 L
.08724 .39053 L
.08708 .3904 L
.08687 .39022 L
.08661 .39001 L
.08632 .38978 L
.08604 .38952 L
.08577 .38925 L
.08551 .38898 L
.08525 .38872 L
.08499 .38852 L
.08474 .38838 L
.08454 .38831 L
.08441 .3883 L
.08435 .38836 L
.08438 .38846 L
.08449 .38858 L
.08466 .38869 L
.08488 .38879 L
.08514 .38885 L
.08542 .38888 L
.08569 .38888 L
.08595 .38887 L
.0862 .38882 L
.08645 .38874 L
.0867 .38865 L
.08692 .38853 L
.0871 .38841 L
.08722 .3883 L
.08728 .38822 L
.0873 .38816 L
.08729 .38815 L
.08726 .38817 L
.08722 .3882 L
.08719 .38823 L
.08718 .38824 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
Mistroke
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38825 L
.08718 .38824 L
.08721 .38822 L
.08725 .38818 L
.08728 .38814 L
.0873 .38812 L
.08729 .38813 L
.08724 .38817 L
.08714 .38825 L
.08699 .38838 L
.08679 .38855 L
.08655 .38874 L
.08629 .38897 L
.08602 .38921 L
.08576 .38948 L
.08552 .38973 L
.08527 .38995 L
.08502 .39018 L
.08479 .39038 L
.08461 .39055 L
.08449 .39069 L
.08442 .39079 L
.0844 .39084 L
.08441 .39083 L
.08444 .39086 L
.08448 .3909 L
Mistroke
.08451 .39096 L
.0845 .39105 L
.08447 .39118 L
.08443 .39135 L
.08439 .39155 L
.08437 .39178 L
.08437 .39207 L
.08439 .39239 L
.08446 .39272 L
.08458 .39306 L
.08477 .39344 L
.08502 .39377 L
.08533 .39405 L
.08571 .39434 L
.08611 .39461 L
.08653 .39486 L
.08698 .39506 L
.08746 .39519 L
.08794 .39527 L
.08837 .3953 L
.08874 .39531 L
.08906 .39531 L
.08933 .39529 L
.08954 .39525 L
.0897 .39521 L
.08979 .3952 L
.08983 .39519 L
.08983 .39519 L
.08982 .39519 L
.08979 .39519 L
.08974 .39519 L
.0897 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39518 L
.08972 .39514 L
.08976 .39507 L
.0898 .39499 L
.08982 .39495 L
.08982 .39494 L
.08979 .39499 L
.08973 .39509 L
Mfstroke
.08419 .40693 m
.08415 .40705 L
.08414 .40709 L
.08416 .40704 L
.0842 .40696 L
.08424 .40688 L
.08427 .40687 L
.08428 .4069 L
.08428 .40693 L
.08428 .40691 L
.08428 .40683 L
.08428 .40669 L
.08429 .40647 L
.08429 .4062 L
.0843 .4059 L
.0843 .40557 L
.08431 .40522 L
.08431 .40485 L
.08432 .40449 L
.08432 .40413 L
.08433 .40379 L
.08433 .40349 L
.08433 .4032 L
.08434 .40295 L
.08434 .4028 L
.08434 .40276 L
.08434 .40281 L
.08433 .40295 L
.08433 .40317 L
.08433 .40342 L
.08433 .4037 L
.08432 .40401 L
.08432 .40437 L
.08431 .40476 L
.08431 .40511 L
.0843 .40547 L
.0843 .40581 L
.08429 .40609 L
.08429 .40631 L
.08429 .4065 L
.08428 .40669 L
.08428 .40687 L
.08427 .40708 L
.08427 .40732 L
.08426 .40762 L
.08426 .40797 L
.08425 .40837 L
.08424 .40881 L
.08424 .40926 L
.08423 .40974 L
Mistroke
.08422 .41014 L
.08421 .41056 L
.08421 .41093 L
.0842 .41122 L
.0842 .41142 L
.0842 .41153 L
.0842 .41155 L
.08419 .41152 L
.0842 .41145 L
.0842 .41137 L
.0842 .4113 L
.0842 .41125 L
.0842 .41121 L
.0842 .41118 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41117 L
.0842 .41119 L
.0842 .41121 L
.0842 .41125 L
.0842 .41129 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.0842 .41139 L
.0842 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41134 L
.0842 .41131 L
.0842 .41127 L
.0842 .41124 L
.0842 .41122 L
.0842 .41123 L
.0842 .41128 L
.0842 .41138 L
.08419 .41151 L
.08419 .41169 L
.08419 .41189 L
.08418 .41212 L
.08418 .41236 L
.08417 .4126 L
.08417 .41284 L
.08417 .41307 L
.08416 .41329 L
.08416 .41348 L
.08415 .41363 L
.08415 .41374 L
Mistroke
.08415 .41381 L
.08415 .41384 L
.08415 .41384 L
.08415 .41382 L
.08415 .41379 L
.08415 .41376 L
.08415 .41372 L
.08415 .41367 L
.08416 .41358 L
.08416 .41345 L
.08416 .41329 L
.08417 .41309 L
.08417 .41287 L
.08417 .41264 L
.08418 .41242 L
.08418 .41222 L
.08418 .41203 L
.08419 .41185 L
.08419 .41171 L
.08419 .41159 L
.08419 .4115 L
.08419 .41145 L
.08419 .41142 L
.08419 .4114 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41142 L
.0842 .41137 L
.0842 .41131 L
.0842 .41126 L
.0842 .41124 L
.0842 .41127 L
.0842 .41136 L
.0842 .41149 L
.08419 .41168 L
.08419 .41193 L
.08418 .41221 L
.08418 .41249 L
.08417 .41274 L
.08417 .41297 L
.08416 .41314 L
.08416 .41326 L
.08416 .41331 L
.08416 .41328 L
.08416 .41318 L
.08417 .41301 L
.08417 .4128 L
.08417 .41259 L
.08418 .41239 L
Mistroke
.08418 .41222 L
.08418 .4121 L
.08418 .41202 L
.08418 .41198 L
.08418 .41197 L
.08418 .41198 L
.08418 .41199 L
.08418 .41201 L
.08418 .41203 L
.08418 .41203 L
.08418 .41201 L
.08419 .41193 L
.08419 .41183 L
.08419 .41172 L
.08419 .4116 L
.08419 .41149 L
.0842 .41139 L
.0842 .41132 L
.0842 .41127 L
.0842 .41126 L
.0842 .41128 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41142 L
.08419 .41149 L
.08419 .41155 L
.08419 .41158 L
.08419 .41156 L
.08419 .41147 L
.0842 .4113 L
.0842 .41103 L
.08421 .41067 L
.08422 .41026 L
.08422 .4098 L
.08423 .40933 L
.08424 .40886 L
.08425 .40842 L
.08426 .40798 L
Mistroke
.08427 .40759 L
.08427 .40727 L
.08427 .40703 L
.08428 .40686 L
.08428 .40673 L
.08428 .40662 L
.08429 .40648 L
.08429 .40628 L
.08429 .406 L
.0843 .40564 L
.08431 .40519 L
.08431 .40472 L
.08432 .40425 L
.08433 .40381 L
.08434 .40336 L
.08435 .40293 L
.08435 .40254 L
.08436 .40223 L
.08436 .40202 L
.08436 .4019 L
.08436 .40186 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40211 L
.08436 .40211 L
.08436 .40212 L
.08436 .40213 L
.08436 .40213 L
.08436 .40212 L
.08436 .40209 L
.08436 .40206 L
.08436 .40201 L
.08436 .40197 L
.08436 .40193 L
.08436 .40189 L
.08437 .40186 L
.08437 .40184 L
.08437 .40183 L
.08437 .40183 L
.08437 .40184 L
.08437 .40176 L
Mistroke
.08437 .4018 L
.08436 .40185 L
.08436 .4019 L
.08436 .40197 L
.08436 .40205 L
.08436 .40212 L
.08436 .4022 L
.08435 .40228 L
.08435 .40235 L
.08433 .40241 L
.08431 .40245 L
.08429 .40245 L
.08429 .4024 L
Mfstroke
.09541 .33017 m
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
Mistroke
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
Mistroke
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
.09785 .3172 L
.09783 .31714 L
Mfstroke
.10578 .30311 m
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
s
.3724 .05237 m
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
s
.41535 .04018 m
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
s
.34868 .05632 m
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
s
.28211 .10325 m
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
s
.17776 .18843 m
.17773 .18844 L
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
Mfstroke
.20713 .16263 m
.20724 .1626 L
.20727 .16267 L
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
s
.24062 .12497 m
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
s
.51246 .03843 m
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
s
.40578 .0338 m
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
Mistroke
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
Mistroke
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
Mistroke
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
Mistroke
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
Mistroke
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
Mistroke
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
Mfstroke
.38497 .03476 m
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
Mistroke
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
Mistroke
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
Mfstroke
.34842 .04947 m
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
s
.34111 .05581 m
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
s
.31155 .07266 m
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
.31177 .07271 L
s
.29022 .08358 m
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
s
.23768 .11853 m
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
s
.22837 .12963 m
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
s
.09756 .31517 m
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
s
.08436 .40243 m
.08435 .40247 L
.08436 .40236 L
.08436 .40214 L
.08436 .40183 L
.08437 .40146 L
.08438 .40108 L
.08438 .40077 L
.08438 .40054 L
.08439 .40039 L
.08439 .40032 L
.08439 .4003 L
.08439 .40036 L
.08439 .40048 L
.08438 .40067 L
.08438 .40089 L
.08437 .40115 L
.08437 .40139 L
.08437 .40159 L
.08436 .40174 L
.08436 .40183 L
.08436 .4019 L
.08436 .40198 L
.08436 .4021 L
.08436 .40226 L
.08435 .40249 L
.08435 .4028 L
.08434 .40317 L
.08433 .40359 L
.08433 .404 L
.08432 .40441 L
.08431 .40482 L
.08431 .40525 L
.0843 .4057 L
.08429 .40618 L
.08428 .40667 L
.08427 .40715 L
.08426 .40761 L
.08424 .40803 L
.0842 .40842 L
.08415 .4088 L
.08409 .40918 L
.08403 .40961 L
.08399 .41009 L
.084 .41061 L
.08406 .41112 L
.08419 .41159 L
.0844 .41201 L
.0847 .41236 L
.08509 .41264 L
Mistroke
.08557 .41285 L
.08612 .41303 L
.08675 .41319 L
.08743 .41334 L
.08814 .4135 L
.08884 .41364 L
.08952 .41374 L
.09015 .4138 L
.0907 .41382 L
.09116 .41379 L
.09151 .41373 L
.09175 .41368 L
.0919 .41365 L
.09198 .41362 L
.092 .41359 L
.09201 .41355 L
.09201 .41349 L
.09205 .41344 L
.09214 .41345 L
Mfstroke
.07173 .47922 m
.07171 .47941 L
.07171 .47958 L
.07171 .47971 L
.07171 .47986 L
.07174 .48003 L
.07179 .48026 L
.07189 .48048 L
.07203 .48076 L
.07222 .48102 L
.07245 .48122 L
.07271 .48134 L
.073 .48137 L
.07332 .48133 L
.07365 .48124 L
.07396 .48115 L
.07421 .48112 L
.07439 .48114 L
.07449 .48123 L
.07448 .4814 L
.07436 .48167 L
.07415 .48204 L
.07386 .48248 L
.07354 .48295 L
.0732 .48345 L
.07289 .48396 L
.07256 .48442 L
.07229 .48489 L
.07205 .48533 L
.07182 .48572 L
.07163 .48602 L
.07151 .48622 L
.07146 .48633 L
.07146 .48635 L
.0715 .48631 L
.07156 .48623 L
.07163 .48615 L
.07167 .48609 L
.07169 .48607 L
.07168 .48606 L
.07167 .48604 L
.07168 .48597 L
.07169 .48586 L
.07169 .48575 L
.07168 .48569 L
.07167 .48572 L
.07165 .48585 L
s
.10268 .73861 m
.10274 .73873 L
.10279 .73872 L
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
s
.5034 .96476 m
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
s
.09962 .71651 m
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
s
.08473 .62507 m
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
s
.08295 .46465 m
.08305 .46464 L
.0831 .46466 L
.08308 .46469 L
.08302 .46472 L
.08295 .46474 L
.08291 .46477 L
.08289 .46479 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
Mistroke
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .4648 L
.08289 .46479 L
.08289 .46476 L
.0829 .46471 L
.08294 .46463 L
.083 .46456 L
.08304 .46452 L
.08305 .46455 L
.08301 .46465 L
Mfstroke
.0714 .49318 m
.07148 .49316 L
.07151 .49313 L
.0715 .49314 L
.07147 .49324 L
.07142 .49345 L
.07136 .49379 L
.0713 .49421 L
.07126 .49467 L
.07124 .49516 L
.07122 .49567 L
.0712 .4961 L
.07119 .49657 L
.07118 .49702 L
.07118 .49743 L
.07118 .49775 L
.07119 .49797 L
.07121 .49809 L
.07122 .49814 L
.07124 .49811 L
.07125 .49805 L
.07126 .49796 L
.07126 .4979 L
.07127 .49788 L
.07129 .49788 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07106 .49781 L
.07086 .49779 L
.07063 .49778 L
.07037 .49778 L
.07008 .49778 L
.06978 .49779 L
.06946 .49779 L
.06916 .4978 L
.0689 .49781 L
.06869 .49783 L
.06858 .49785 L
.06856 .49788 L
.06865 .4979 L
.06882 .49791 L
.06907 .49792 L
.06937 .49793 L
.06968 .49793 L
.06999 .49791 L
.07028 .4979 L
Mistroke
.07055 .49789 L
.0708 .49788 L
.07101 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07125 .49787 L
.07126 .49788 L
.07129 .49789 L
.07133 .49789 L
.07137 .49789 L
.07139 .49788 L
.07138 .49786 L
.07132 .49784 L
.07122 .49782 L
.07107 .49781 L
.07087 .49779 L
.07064 .49778 L
.07038 .49778 L
.07011 .49778 L
.06983 .49778 L
.06956 .49779 L
.0693 .4978 L
.06905 .49781 L
.06882 .49783 L
.06862 .49785 L
.06845 .49788 L
.06835 .4979 L
.0683 .49792 L
.06833 .49794 L
.06843 .49795 L
.06857 .49795 L
.06876 .49794 L
.06898 .49793 L
Mistroke
.06922 .49792 L
.06948 .49791 L
.06975 .4979 L
.07002 .4979 L
.07029 .49789 L
.07056 .49789 L
.0708 .49788 L
.07102 .49788 L
.07119 .49787 L
.07131 .49787 L
.07137 .49787 L
.0714 .49787 L
.07138 .49787 L
.07134 .49787 L
.0713 .49787 L
.07126 .49787 L
.07125 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
Mistroke
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07124 .49787 L
.07122 .49786 L
Mistroke
.07119 .49784 L
.07113 .49781 L
.07107 .49781 L
.07102 .49783 L
.071 .49787 L
.07104 .49793 L
.07116 .498 L
.07137 .49807 L
.07167 .49813 L
.07205 .49818 L
.0725 .49822 L
.07301 .49824 L
.0735 .49824 L
.07403 .49823 L
.07459 .49821 L
.07508 .49818 L
.07555 .49813 L
.07597 .49806 L
.07631 .49797 L
.07656 .49786 L
.07673 .49771 L
.07684 .49753 L
.07688 .49738 L
.07686 .49729 L
.07682 .49727 L
.07677 .49733 L
Mfstroke
.07427 .55772 m
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
s
.08112 .58633 m
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
s
.0831 .5975 m
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
s
.08007 .60551 m
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
s
.10135 .73879 m
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
Mistroke
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
Mistroke
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
Mfstroke
.12859 .76948 m
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
s
.15705 .80297 m
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
s
.47587 .96656 m
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
s
.65303 .93745 m
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
s
.64925 .93908 m
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
Mistroke
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
Mfstroke
.65987 .93732 m
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
s
.65081 .94096 m
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
s
.6847 .92617 m
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
s
.68731 .92601 m
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
Mistroke
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
Mistroke
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mfstroke
.49628 .95589 m
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
s
.07448 .48054 m
.07459 .48061 L
.07464 .48076 L
.07464 .48092 L
.07461 .48107 L
.07456 .48119 L
.07452 .48127 L
.07448 .48131 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07444 .48132 L
.07439 .48132 L
.07432 .48132 L
.07425 .48133 L
.07419 .48135 L
.07418 .48141 L
.07422 .48148 L
.07435 .48155 L
s
.09705 .42939 m
.09702 .42926 L
.09698 .4293 L
.09695 .42942 L
.09693 .42956 L
.09693 .42971 L
.09692 .42986 L
.09692 .43001 L
.09692 .43014 L
.09691 .43024 L
.09691 .4303 L
.09691 .43031 L
.09692 .43021 L
s
.08923 .4066 m
.08916 .40651 L
.0892 .4065 L
.08933 .40654 L
.08951 .40659 L
.08974 .40666 L
.09001 .40673 L
.09027 .4068 L
.09055 .40683 L
.09082 .40685 L
.09106 .40685 L
.09131 .40684 L
.09156 .40683 L
.09179 .40681 L
.09198 .40679 L
.09216 .40677 L
.09231 .40677 L
.09243 .4068 L
.09246 .40686 L
.09241 .40692 L
.09227 .40697 L
.09205 .40697 L
.09176 .40691 L
.09138 .40676 L
.09093 .40654 L
.09046 .40625 L
.08998 .40591 L
.08949 .40553 L
.08907 .40511 L
.08837 .40463 L
.08777 .4041 L
.08723 .40349 L
.08661 .4028 L
.08608 .40204 L
.08568 .40123 L
.08541 .40041 L
.08528 .39966 L
.08523 .3989 L
.08525 .39819 L
.08534 .39755 L
.0855 .397 L
.0857 .39646 L
.0859 .39595 L
.08612 .39551 L
.0863 .39519 L
.08644 .39498 L
.08651 .39488 L
.08647 .39487 L
.08634 .39494 L
.08612 .39505 L
Mistroke
.08586 .3952 L
.08557 .39531 L
.08526 .39537 L
.08497 .39536 L
.08472 .39529 L
.08453 .39514 L
.0844 .39488 L
.08431 .39452 L
.08425 .39411 L
.08423 .3937 L
.0843 .39373 L
.08436 .39352 L
.08443 .39349 L
.08453 .39352 L
.08469 .39354 L
.08489 .39354 L
.08513 .39349 L
.08539 .39348 L
.08565 .39356 L
.0859 .39381 L
.08612 .39417 L
.08636 .39456 L
.0866 .39492 L
.08682 .39519 L
.087 .39534 L
.08711 .39538 L
.08718 .39536 L
.0872 .39531 L
.08719 .39525 L
.08715 .39521 L
.08711 .39518 L
.08709 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
Mistroke
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08708 .39518 L
.08707 .39518 L
.08705 .39518 L
.08702 .39518 L
.08698 .39518 L
.08696 .39518 L
.08697 .39518 L
.08702 .39518 L
.08711 .39518 L
.08726 .39518 L
.08746 .39518 L
.0877 .39518 L
.08796 .39518 L
.08823 .39518 L
.08847 .39519 L
.0887 .39519 L
.08894 .39519 L
.08919 .39519 L
.08942 .39519 L
.0896 .39519 L
.08972 .39519 L
.08978 .39519 L
.0898 .39519 L
.0898 .39519 L
.08976 .39519 L
.08972 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
Mistroke
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39519 L
.08969 .39513 L
.08972 .39502 L
.0898 .39493 L
.08983 .39489 L
.08981 .39491 L
.08975 .39498 L
Mfstroke
.08419 .41145 m
.08419 .41154 L
.08419 .41156 L
.08419 .41153 L
.08419 .41147 L
.0842 .4114 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.08421 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.08421 .41138 L
.08422 .41144 L
.08424 .41151 L
.08425 .41156 L
.08423 .41156 L
.08419 .41149 L
.08415 .41135 L
.0841 .41113 L
.08405 .41082 L
.08401 .41043 L
.08399 .40994 L
.084 .40932 L
.08403 .40878 L
.08405 .40831 L
.08406 .4079 L
.08404 .40751 L
.08404 .40712 L
.08404 .40695 L
.08407 .40695 L
.08412 .40718 L
.08418 .40755 L
.08422 .40802 L
.08425 .40853 L
.08428 .40906 L
.08428 .4096 L
.08425 .4101 L
Mistroke
.08422 .41056 L
.0842 .41096 L
.0842 .41126 L
.08419 .41145 L
.08419 .41154 L
.08419 .41157 L
.08419 .41155 L
.08419 .41149 L
.0842 .41141 L
.0842 .41137 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .4114 L
.08419 .4114 L
.08419 .41141 L
.08419 .41141 L
.08419 .41141 L
.08419 .4114 L
.08419 .4114 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .41128 L
.0842 .41128 L
.0842 .41131 L
.0842 .41137 L
.08419 .41144 L
.08419 .41152 L
.08419 .4116 L
.08419 .41167 L
.08419 .41172 L
.08419 .41174 L
.08418 .41176 L
.08418 .41177 L
.08418 .41177 L
.08418 .41177 L
.08418 .41176 L
.08418 .41172 L
.08419 .41166 L
.08419 .41159 L
.08419 .41152 L
.08419 .41144 L
.08419 .41138 L
.08419 .41134 L
.08419 .41132 L
.08419 .41134 L
.08419 .41136 L
.08419 .41137 L
.0842 .41137 L
.0842 .41135 L
.0842 .41134 L
.0842 .41133 L
Mistroke
.0842 .41133 L
.0842 .41132 L
.0842 .41133 L
.0842 .41135 L
.0842 .41138 L
.08419 .41143 L
.08419 .41148 L
.08419 .41154 L
.08419 .41159 L
.08419 .41164 L
.08419 .41167 L
.08418 .41169 L
.08418 .4117 L
.08418 .41169 L
.08419 .41167 L
.08419 .41166 L
.08419 .41162 L
.08419 .41158 L
.08419 .41153 L
.08419 .41147 L
.0842 .41142 L
.0842 .41137 L
.0842 .41134 L
.0842 .41131 L
.0842 .4113 L
.0842 .41131 L
.0842 .41133 L
.0842 .41136 L
.0842 .41137 L
.08419 .41138 L
.08419 .41139 L
.08419 .41139 L
.08419 .41139 L
.08419 .4114 L
.08419 .41141 L
.08419 .41142 L
.08419 .41143 L
.08419 .41143 L
.0842 .41145 L
.0842 .41145 L
.0842 .41145 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41144 L
.0842 .41143 L
.0842 .41141 L
.0842 .41137 L
.0842 .41132 L
.0842 .41129 L
Mistroke
.0842 .41129 L
.0842 .41132 L
.0842 .41139 L
.08419 .41152 L
.08419 .41169 L
.08419 .41189 L
.08418 .41211 L
.08418 .41234 L
.08417 .41257 L
.08417 .41279 L
.08417 .41301 L
.08416 .41322 L
.08416 .4134 L
.08416 .41355 L
.08415 .41367 L
.08415 .41373 L
.08415 .41376 L
.08415 .41375 L
.08415 .41372 L
.08415 .41368 L
.08415 .41366 L
.08415 .41366 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41365 L
.08415 .41362 L
.08416 .4136 L
.08416 .41357 L
.08416 .41354 L
.08416 .41352 L
.08416 .41351 L
.08416 .4135 L
.08416 .41349 L
Mistroke
.08416 .4135 L
.08416 .41351 L
.08416 .41352 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41366 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41368 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41367 L
.08415 .41368 L
.08415 .41369 L
.08415 .41369 L
.08415 .41368 L
.08415 .41368 L
.08415 .41369 L
.08415 .4137 L
.08415 .41371 L
.08415 .41369 L
.08415 .41364 L
.08416 .41354 L
.08416 .41341 L
.08416 .41325 L
.08416 .41312 L
.08417 .413 L
.08417 .4129 L
.08417 .41283 L
.08417 .41281 L
.08417 .4128 L
.08417 .41283 L
.08417 .41287 L
Mistroke
.08417 .41292 L
.08417 .41301 L
.08416 .41312 L
.08416 .41326 L
.08416 .4134 L
.08416 .41354 L
.08415 .41366 L
.08415 .41374 L
.08415 .41378 L
.08415 .41378 L
.08415 .41376 L
.08415 .41374 L
.08415 .41372 L
.08415 .4137 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41355 L
.08416 .41359 L
.08415 .41363 L
.08415 .41367 L
.08415 .41369 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41371 L
.08415 .41369 L
.08415 .41367 L
.08415 .41364 L
.08416 .4136 L
.08416 .41356 L
.08416 .41352 L
.08416 .41349 L
.08416 .41347 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
.08416 .41346 L
Mistroke
.08416 .41346 L
.08416 .41348 L
.08416 .41351 L
.08416 .41356 L
.08416 .41361 L
.08415 .41366 L
.08415 .4137 L
.08415 .41372 L
.08415 .41371 L
.08415 .41368 L
.08415 .41364 L
.08416 .41359 L
.08416 .41355 L
.08416 .41354 L
.08416 .41356 L
.08416 .41359 L
.08415 .41362 L
.08415 .41364 L
.08415 .41362 L
.08416 .41358 L
.08416 .4135 L
.08416 .41339 L
.08416 .41325 L
.08417 .41307 L
.08417 .41287 L
.08417 .41264 L
.08418 .41239 L
.08418 .41213 L
.08419 .41187 L
.08419 .41162 L
.0842 .41143 L
.0842 .41132 L
.0842 .41131 L
.0842 .41139 L
.08419 .41155 L
.08419 .41177 L
.08418 .41203 L
.08418 .4123 L
.08417 .41258 L
.08417 .41284 L
.08416 .4131 L
.08416 .41334 L
.08416 .41355 L
.08415 .41369 L
.08415 .41376 L
.08415 .41375 L
.08415 .41367 L
.08416 .41356 L
.08416 .41344 L
.08416 .41332 L
Mistroke
.08416 .41322 L
.08417 .41315 L
.08417 .41309 L
.08417 .41303 L
.08417 .41296 L
.08417 .41288 L
.08417 .41281 L
.08417 .41276 L
.08417 .41273 L
.08417 .41273 L
.08417 .41277 L
.08417 .41281 L
.08417 .41286 L
.08417 .41292 L
.08417 .41297 L
.08417 .413 L
.08417 .41305 L
.08417 .41313 L
.08416 .41324 L
.08416 .41337 L
.08416 .4135 L
.08416 .4136 L
.08415 .41367 L
.08415 .41371 L
.08415 .41373 L
.08415 .41374 L
.08415 .41373 L
.08415 .41371 L
.08415 .41368 L
.08415 .41367 L
.08415 .41368 L
.08415 .41371 L
.08415 .41375 L
.08415 .41378 L
.08415 .4138 L
.08415 .41379 L
.08415 .41374 L
.08415 .41365 L
.08416 .41351 L
.08416 .41333 L
.08416 .41313 L
.08417 .4129 L
.08417 .41266 L
.08418 .41242 L
.08418 .41218 L
.08419 .41195 L
.08419 .41173 L
.08419 .41155 L
.0842 .4114 L
.0842 .41129 L
Mistroke
.0842 .41123 L
.0842 .41122 L
.0842 .41123 L
.0842 .41127 L
.0842 .41131 L
.0842 .41134 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.08419 .41139 L
.08419 .41139 L
.0842 .41138 L
.0842 .41136 L
.0842 .41133 L
.0842 .41129 L
.08421 .41125 L
.08421 .41122 L
.08421 .41119 L
.08421 .41117 L
.08421 .41116 L
.08421 .41116 L
.08421 .41116 L
Mistroke
.08421 .41116 L
.08421 .41116 L
.08421 .41118 L
.08421 .41121 L
.08421 .41124 L
.0842 .41128 L
.0842 .41132 L
.0842 .41135 L
.0842 .41138 L
.08419 .41139 L
.08419 .41139 L
.0842 .41137 L
.0842 .41136 L
.0842 .41136 L
.0842 .41136 L
.0842 .41139 L
.08419 .41143 L
.08419 .41146 L
.08419 .41145 L
.0842 .4114 L
.0842 .41132 L
.0842 .41122 L
.08421 .41111 L
.08421 .41099 L
.08422 .41089 L
.08422 .41081 L
.08422 .41078 L
.08422 .41076 L
.08422 .41076 L
.08422 .41076 L
.08422 .41075 L
.08422 .41078 L
.08422 .41084 L
.08422 .41094 L
.08421 .41105 L
.08421 .41116 L
.08421 .41127 L
.08421 .41136 L
.0842 .41142 L
.0842 .41144 L
.08421 .41141 L
.08421 .41136 L
.08421 .41133 L
.0842 .41133 L
.0842 .41133 L
.0842 .41134 L
.0842 .41134 L
.0842 .41136 L
.0842 .4114 L
.0842 .41145 L
Mistroke
.0842 .4115 L
.0842 .41152 L
.0842 .41148 L
.0842 .41135 L
.08421 .41113 L
.08421 .41076 L
.08422 .41037 L
.08423 .40989 L
.08423 .4094 L
.08424 .40892 L
.08425 .40852 L
.08425 .40816 L
.08425 .40789 L
.08426 .40774 L
.08426 .40769 L
.08425 .40774 L
.08425 .4079 L
.08425 .40819 L
.08425 .40852 L
.08424 .40892 L
.08424 .40938 L
.08423 .40982 L
.08423 .41026 L
.08422 .41066 L
.08422 .41094 L
.08422 .41109 L
.08422 .41116 L
.08422 .41112 L
.08422 .41098 L
.08422 .41078 L
.08422 .4105 L
.08423 .41014 L
.08423 .40971 L
.08424 .40925 L
.08424 .40883 L
.08425 .40837 L
.08426 .4079 L
.08426 .40747 L
.08426 .40712 L
.08427 .40686 L
.08427 .40668 L
.08427 .40659 L
.08427 .40656 L
.08427 .4069 L
.08427 .40697 L
.08427 .40706 L
.08427 .40711 L
.08427 .4071 L
.08427 .40704 L
.08427 .40696 L
Mistroke
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40676 L
.08428 .40676 L
.08428 .40675 L
.08428 .40672 L
.08428 .40667 L
.08428 .40662 L
.08429 .40655 L
.08429 .40648 L
.08429 .40642 L
.08429 .40637 L
.08429 .40633 L
.0843 .40631 L
.0843 .4063 L
.0843 .4063 L
.08429 .40633 L
.08429 .40635 L
.08429 .4064 L
.08429 .40646 L
.08429 .40653 L
.08429 .40659 L
.08428 .40665 L
.08428 .40669 L
.08428 .40672 L
.08428 .40674 L
.08428 .40677 L
.08428 .40679 L
.08428 .4068 L
.08427 .4068 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40682 L
.08427 .40682 L
.08428 .40684 L
.08428 .4069 L
.08427 .40702 L
.08427 .4072 L
.08427 .40748 L
.08426 .40778 L
Mistroke
.08426 .40815 L
.08425 .40856 L
.08424 .40897 L
.08423 .40943 L
.08423 .40984 L
.08422 .41025 L
.08421 .41061 L
.0842 .41093 L
.0842 .41119 L
.0842 .41138 L
.08419 .41151 L
.08419 .41156 L
.08419 .41155 L
.08419 .41151 L
.0842 .41145 L
.0842 .41141 L
.0842 .41138 L
.0842 .41136 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
Mistroke
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41135 L
.0842 .41136 L
.0842 .41137 L
.0842 .41139 L
.0842 .41143 L
.08419 .41147 L
.08419 .41149 L
.0842 .41146 L
.0842 .41137 L
.0842 .41125 L
.0842 .4111 L
.08421 .41094 L
.08421 .41078 L
.08422 .41062 L
.08422 .41049 L
.08422 .41037 L
.08422 .41028 L
.08423 .41022 L
.08423 .41021 L
.08423 .41021 L
.08422 .41026 L
.08422 .41034 L
.08422 .41047 L
.08422 .41064 L
.08421 .41078 L
.08421 .41093 L
.08421 .41105 L
.08421 .41114 L
.08421 .41119 L
.08421 .41121 L
.0842 .41124 L
.0842 .41127 L
.0842 .4113 L
.0842 .41131 L
.0842 .41129 L
.0842 .41124 L
.08421 .41118 L
.08421 .41113 L
.08421 .41112 L
.08421 .41113 L
.08421 .41115 L
.08421 .41114 L
.08421 .41108 L
Mistroke
.08421 .41098 L
.08422 .41084 L
.08422 .41068 L
.08422 .41047 L
.08422 .4102 L
.08423 .40989 L
.08423 .40955 L
.08424 .40923 L
.08424 .40895 L
.08424 .40872 L
.08424 .40856 L
.08425 .40844 L
.08425 .4084 L
.08425 .4085 L
.08425 .40866 L
.08424 .40886 L
.08424 .40907 L
.08423 .4093 L
.08423 .40953 L
.08423 .40972 L
.08422 .40989 L
.08422 .40999 L
.08422 .41007 L
.08422 .41013 L
.08422 .41015 L
.08422 .41012 L
.08422 .41009 L
.08422 .41009 L
.08422 .41011 L
.08422 .41022 L
.08421 .41039 L
.08421 .41061 L
.08421 .4108 L
.0842 .41098 L
.0842 .41111 L
.0842 .41118 L
.0842 .41115 L
.0842 .41105 L
.08421 .41089 L
.08421 .41067 L
.08421 .41039 L
.08422 .41005 L
.08423 .40968 L
.08423 .40929 L
.08424 .4089 L
.08425 .4085 L
.08426 .4081 L
.08426 .40778 L
.08427 .40752 L
.08427 .40736 L
Mistroke
.08427 .40731 L
.08427 .40734 L
.08427 .40743 L
.08427 .40754 L
.08426 .40763 L
.08426 .40769 L
.08426 .4077 L
.08426 .40766 L
.08426 .40758 L
.08427 .40749 L
.08427 .40739 L
.08427 .40725 L
.08427 .40711 L
.08428 .40701 L
.08428 .40697 L
.08428 .40697 L
.08428 .40702 L
.08427 .40712 L
.08427 .40724 L
.08427 .40738 L
.08427 .40753 L
.08426 .40769 L
.08426 .40782 L
.08426 .4079 L
.08426 .40793 L
.08426 .40791 L
.08426 .40784 L
.08426 .40772 L
.08427 .40757 L
.08427 .40739 L
.08427 .40725 L
.08427 .40712 L
.08428 .40702 L
.08428 .40698 L
.08428 .407 L
.08427 .40703 L
.08427 .40709 L
.08427 .40717 L
.08427 .40725 L
.08427 .40733 L
.08427 .40743 L
.08427 .40756 L
.08426 .4077 L
.08426 .40787 L
.08426 .40806 L
.08425 .40828 L
.08425 .40854 L
.08424 .40883 L
.08424 .40915 L
.08423 .40953 L
Mistroke
.08422 .4099 L
.08422 .41025 L
.08421 .41056 L
.08421 .41084 L
.08421 .41106 L
.0842 .41121 L
.0842 .4113 L
.0842 .41135 L
.0842 .41136 L
.0842 .41133 L
.0842 .41126 L
.08421 .41117 L
.08421 .41107 L
.08421 .41101 L
.08421 .41098 L
.08422 .41097 L
.08422 .41097 L
.08422 .41095 L
.08422 .4109 L
.08422 .41079 L
.08422 .4106 L
.08422 .41039 L
.08423 .41016 L
.08423 .40995 L
.08423 .40975 L
.08423 .40954 L
.08423 .40932 L
.08424 .4091 L
.08424 .40886 L
.08424 .4086 L
.08425 .40834 L
.08425 .40808 L
.08425 .40787 L
.08425 .4077 L
.08426 .40761 L
.08426 .40752 L
.08426 .40742 L
.08426 .40728 L
.08426 .4071 L
.08427 .4069 L
.08427 .40674 L
.08428 .40662 L
.08428 .40659 L
.08427 .40665 L
.08427 .4068 L
.08427 .40698 L
.08426 .40712 L
.08426 .40723 L
.08426 .4073 L
.08426 .40737 L
Mistroke
.08426 .40747 L
.08426 .4076 L
.08425 .40777 L
.08425 .40798 L
.08425 .4082 L
.08424 .40841 L
.08424 .40858 L
.08424 .4087 L
.08424 .40878 L
.08424 .40886 L
.08424 .40897 L
.08424 .40912 L
.08424 .40929 L
.08424 .40948 L
.08424 .40959 L
.08424 .40963 L
.08424 .40954 L
.08424 .40935 L
.08425 .4091 L
.08425 .40879 L
.08426 .40851 L
.08426 .40827 L
.08426 .40809 L
.08427 .40787 L
.08427 .40766 L
.08427 .40747 L
.08428 .4073 L
.08428 .40716 L
.08428 .40706 L
.08428 .40702 L
.08428 .40701 L
.08428 .40703 L
.08428 .40706 L
.08428 .40709 L
.08427 .40714 L
.08427 .40719 L
.08427 .40724 L
.08427 .40732 L
.08427 .40741 L
.08426 .40749 L
.08426 .40756 L
.08426 .40761 L
.08427 .40764 L
.08427 .40764 L
.08427 .40763 L
.08427 .4076 L
.08427 .40758 L
.08427 .40752 L
.08427 .40742 L
.08428 .40727 L
Mistroke
.08428 .4071 L
.08428 .40693 L
.08428 .40679 L
.08428 .40668 L
.08428 .40662 L
.08428 .40663 L
.08428 .40669 L
.08427 .40677 L
.08427 .40682 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40673 L
Mistroke
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40686 L
.08427 .40685 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40672 L
.08428 .40671 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40675 L
.08428 .40678 L
.08428 .4068 L
.08427 .40682 L
.08427 .40684 L
.08427 .40685 L
.08427 .40685 L
.08427 .40685 L
.08427 .40686 L
.08427 .40685 L
.08427 .40684 L
.08427 .40683 L
.08428 .40681 L
.08428 .40678 L
.08428 .40676 L
.08428 .40673 L
.08428 .40672 L
Mistroke
.08428 .4067 L
.08428 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08429 .40667 L
.0843 .40662 L
.0843 .40658 L
.0843 .4066 L
.08428 .40667 L
.08426 .40678 L
.08424 .40693 L
.08422 .40709 L
.08419 .40726 L
.08418 .4074 L
.08416 .40751 L
.08416 .40757 L
.08415 .40761 L
.08415 .40762 L
.08415 .40761 L
.08416 .4076 L
.08417 .40755 L
.08418 .40745 L
.08421 .40731 L
.08423 .40714 L
.08426 .40696 L
.08428 .40679 L
.0843 .40664 L
.08431 .40654 L
.08431 .40651 L
.0843 .40656 L
.08429 .40666 L
Mistroke
.08428 .40676 L
.08428 .40685 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40714 L
.08426 .40715 L
.08426 .40715 L
.08426 .40715 L
.08426 .40713 L
.08427 .40709 L
.08427 .40704 L
.08427 .40696 L
.08427 .40688 L
.08428 .4068 L
.08428 .40673 L
.08428 .40668 L
.08428 .40665 L
.08428 .40665 L
.08428 .40668 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40669 L
.08428 .40666 L
.08428 .40665 L
.08428 .40667 L
.08428 .40672 L
.08428 .40678 L
.08428 .40686 L
.08427 .40694 L
.08427 .40701 L
.08427 .40707 L
.08426 .40711 L
.08426 .40713 L
.08426 .40714 L
.08426 .40714 L
.08426 .40713 L
.08427 .40711 L
.08427 .40707 L
.08427 .40702 L
.08427 .40696 L
.08427 .40689 L
.08427 .40683 L
.08428 .40679 L
.08428 .40676 L
.08428 .40675 L
.08428 .40676 L
.08427 .40679 L
.08427 .40681 L
.08427 .40682 L
.08427 .40683 L
.08427 .40683 L
.08427 .40684 L
.08427 .40683 L
.08427 .40681 L
.08427 .40676 L
.08428 .40669 L
.08428 .40664 L
.08429 .4066 L
.0843 .40661 L
.08432 .40668 L
.08434 .4068 L
.08435 .40699 L
.08436 .40724 L
.08434 .40753 L
.08428 .40788 L
.08418 .40826 L
.08402 .40866 L
Mistroke
.08381 .40904 L
.08356 .40943 L
.08329 .4098 L
.08306 .41016 L
.08285 .41049 L
.08269 .41077 L
.08259 .41094 L
.08256 .41107 L
.0826 .41113 L
.0827 .41116 L
.08282 .41115 L
.08295 .41115 L
.08307 .41119 L
.08321 .41126 L
.08336 .41132 L
.08348 .41132 L
.08357 .41126 L
.08362 .41115 L
.08365 .41101 L
.08365 .41085 L
.08363 .4107 L
.08361 .41057 L
.08359 .41047 L
.08358 .41041 L
.08361 .4104 L
.08369 .41042 L
.0838 .41045 L
.08395 .4105 L
.08407 .41061 L
.08419 .41076 L
.08427 .41097 L
.0843 .41119 L
.08427 .41136 L
.08421 .41143 L
.08414 .41137 L
.08406 .41116 L
.08398 .4108 L
.08392 .41031 L
.08389 .40978 L
.08386 .40927 L
.08384 .40882 L
.08384 .40841 L
.08384 .40803 L
.08384 .40773 L
.08385 .40754 L
.08389 .40747 L
.08394 .40752 L
.08401 .40768 L
.08409 .40792 L
.08418 .40821 L
Mistroke
.08425 .40857 L
.08433 .40893 L
.08437 .40927 L
.08438 .40954 L
.08434 .40977 L
.08427 .40996 L
.08414 .41012 L
.08397 .41024 L
.08378 .4103 L
.08358 .41035 L
.0834 .41038 L
.08326 .41036 L
.08316 .41025 L
.0831 .41006 L
.08308 .40981 L
.08308 .40954 L
.08314 .40929 L
.08314 .40907 L
.0833 .4089 L
.08349 .40877 L
.08367 .40866 L
.08383 .40861 L
.08391 .4086 L
.08389 .4086 L
.08378 .40858 L
.0836 .40853 L
.08338 .40848 L
.08315 .4084 L
.08293 .40833 L
.08272 .40824 L
.08252 .4082 L
.08235 .40817 L
.08221 .40815 L
.08212 .40817 L
.0821 .40828 L
.08217 .40845 L
.08231 .40866 L
.0825 .40894 L
.08273 .4093 L
.08295 .40974 L
.08315 .41012 L
.0833 .41047 L
.08344 .41073 L
.08357 .41088 L
.08371 .41089 L
.08384 .41077 L
.08398 .41054 L
.08412 .41017 L
.08421 .40973 L
.08426 .40925 L
Mistroke
.08427 .4088 L
.08425 .40842 L
.08423 .40804 L
.08422 .40769 L
.08424 .4074 L
.08426 .40717 L
.08428 .40702 L
.08429 .40693 L
.08429 .40693 L
.08428 .40698 L
.08427 .4071 L
.08426 .40724 L
.08426 .40739 L
.08426 .40751 L
.08425 .40758 L
.08425 .40761 L
.08425 .40759 L
.08425 .40756 L
.08426 .40748 L
.08426 .40738 L
.08426 .40728 L
.08427 .40719 L
.08428 .40717 L
.08428 .40717 L
.08428 .40722 L
.08427 .40727 L
.08425 .40733 L
.08424 .40739 L
.08421 .40745 L
.08419 .4075 L
.08418 .40751 L
.08416 .40746 L
.08416 .40736 L
.08415 .40726 L
.08415 .40721 L
.08415 .40717 L
.08416 .40716 L
.08417 .4072 L
.08418 .40732 L
.08419 .40755 L
.08421 .40786 L
.08423 .40825 L
.08424 .4087 L
.08426 .40918 L
.08428 .40965 L
.08431 .41007 L
.08432 .4104 L
.0843 .4106 L
.08425 .41065 L
.08418 .41055 L
Mistroke
.08409 .41031 L
.084 .4099 L
.0839 .40938 L
.08382 .40883 L
.08376 .40833 L
.08372 .40789 L
.0837 .40757 L
.0837 .40745 L
.0837 .40747 L
.08372 .40765 L
.08376 .40797 L
.08381 .40841 L
.08388 .40887 L
.08397 .40927 L
.08406 .40964 L
.08413 .40995 L
.08419 .41018 L
.08422 .41033 L
.08422 .4104 L
.08419 .41041 L
.08415 .41042 L
.08412 .41043 L
.08412 .41041 L
.08414 .41034 L
.08417 .41023 L
.08421 .41003 L
.08421 .41001 L
.08421 .41003 L
.08419 .41008 L
.08418 .41011 L
.08415 .41008 L
.08413 .40996 L
.08412 .40974 L
.0841 .40946 L
.0841 .40911 L
.0841 .40873 L
.08411 .40841 L
.08411 .40824 L
.08412 .40819 L
.08412 .40826 L
.08414 .40843 L
.08416 .40867 L
.08418 .40895 L
.08421 .40922 L
.08424 .40949 L
.08425 .40975 L
.08425 .41002 L
.08422 .41025 L
.08419 .41047 L
.08414 .41065 L
Mistroke
.08411 .41076 L
.08411 .41079 L
.08411 .41078 L
.08412 .41074 L
.0841 .41069 L
.08405 .41066 L
.08399 .41068 L
.08392 .41074 L
.08385 .41083 L
.08379 .41089 L
.08374 .41095 L
.08371 .41096 L
.08371 .41092 L
.08374 .41082 L
.08377 .41065 L
.0838 .41042 L
.08382 .41012 L
.08384 .4098 L
.08389 .40949 L
.08396 .40918 L
.08405 .40889 L
.08414 .40859 L
.08422 .40831 L
.08428 .40803 L
.08432 .40781 L
.08433 .40763 L
.08432 .40749 L
.08429 .40738 L
.08427 .40733 L
.08426 .40731 L
.08426 .40726 L
.08427 .40719 L
.08427 .40709 L
.08427 .40698 L
.08428 .40686 L
.08428 .40677 L
.08428 .4067 L
.08428 .40665 L
.08428 .40663 L
.08428 .40663 L
.08428 .40667 L
.08428 .4067 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
.08428 .40668 L
.08428 .40664 L
.08428 .40664 L
.08428 .40666 L
.08428 .40672 L
.08428 .4068 L
.08428 .40689 L
.08427 .40699 L
.08427 .40708 L
.08427 .40714 L
.08427 .40718 L
.08426 .40722 L
.08426 .40725 L
.08426 .40728 L
.08426 .4073 L
.08426 .40731 L
.08426 .40729 L
.08427 .40725 L
.08428 .40718 L
.0843 .40708 L
.0843 .40698 L
.0843 .40688 L
.08428 .40682 L
.08425 .40679 L
.08422 .40681 L
.08418 .40685 L
.08415 .40689 L
.08412 .4069 L
.0841 .4069 L
.08409 .40689 L
.08409 .40688 L
.08409 .40688 L
.08409 .40687 L
Mistroke
.0841 .40688 L
.08411 .40689 L
.08414 .40689 L
.08417 .40687 L
.08421 .40684 L
.08425 .40681 L
.08428 .40677 L
.0843 .40674 L
.08431 .40671 L
.08431 .40669 L
.0843 .40667 L
.08429 .40667 L
.08429 .40668 L
.08428 .40671 L
.08428 .40673 L
.08427 .40677 L
.08427 .4068 L
.08426 .40684 L
.08425 .40687 L
.08425 .40689 L
.08425 .40691 L
.08424 .40692 L
.08424 .40692 L
.08424 .40692 L
.08424 .40691 L
.08425 .4069 L
.08425 .40688 L
.08426 .40685 L
.08426 .40681 L
.08427 .40677 L
.08428 .40674 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
.08429 .4067 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40672 L
.08428 .40671 L
Mistroke
.08429 .4067 L
.08429 .40669 L
.08429 .40669 L
.08429 .40669 L
.08429 .4067 L
.08428 .40673 L
.08426 .40678 L
.08425 .40684 L
.08423 .40691 L
.08421 .40698 L
.08419 .40704 L
.08418 .40708 L
.08417 .40708 L
.08416 .40706 L
.08416 .40705 L
.08416 .40705 L
.08418 .40704 L
.0842 .40707 L
.08421 .40712 L
.08422 .40721 L
.08422 .40731 L
.08422 .40745 L
.0842 .40764 L
.08418 .40786 L
.08416 .40812 L
.08413 .40836 L
.08411 .40859 L
.0841 .40875 L
.08409 .40885 L
.08409 .40888 L
.08409 .40883 L
.08409 .40869 L
.08411 .40846 L
.08414 .4082 L
.08417 .40795 L
.08421 .40768 L
.08424 .40742 L
.08427 .40719 L
.08429 .40699 L
.08431 .40683 L
.08431 .4067 L
.0843 .40662 L
.08429 .4066 L
.08428 .40659 L
.08428 .40661 L
.08428 .40666 L
.08428 .4067 L
.08428 .40671 L
.08429 .4067 L
.08429 .40669 L
Mistroke
.08429 .40669 L
.08428 .40669 L
.08428 .4067 L
.08427 .40674 L
.08427 .40678 L
.08426 .40685 L
.08425 .40692 L
.08425 .40699 L
.08424 .40706 L
.08424 .40711 L
.08424 .40716 L
.08427 .40708 L
.08427 .40709 L
.08427 .40707 L
.08427 .40702 L
.08427 .40697 L
.08427 .40692 L
.08427 .40689 L
.08427 .40687 L
.08427 .40688 L
.08427 .4069 L
.08427 .40694 L
.08427 .40699 L
.08427 .40704 L
.08427 .40708 L
.08426 .40711 L
.08426 .40712 L
.08426 .40714 L
.08426 .40713 L
.08427 .40708 L
.08427 .40702 L
.08427 .40695 L
.08427 .40689 L
.08427 .40686 L
.08428 .40683 L
.08428 .40684 L
.08428 .40688 L
.08427 .40695 L
.08427 .40704 L
.08427 .40715 L
.08426 .40726 L
.08426 .40733 L
.08426 .40735 L
.08426 .40737 L
.08426 .40737 L
.08426 .40736 L
.08426 .40731 L
.08426 .40721 L
.08426 .40712 L
.08427 .40701 L
Mistroke
.08427 .40694 L
.08427 .40693 L
.08427 .40697 L
.08427 .40708 L
.08426 .40725 L
.08426 .40742 L
.08426 .40759 L
.08425 .4077 L
.08425 .40777 L
.08425 .40785 L
.08425 .40794 L
.08425 .40803 L
.08425 .40811 L
.08425 .40821 L
.08425 .40829 L
.08425 .40837 L
.08425 .40848 L
.08425 .40861 L
.08424 .40878 L
.08424 .40897 L
.08424 .4092 L
.08424 .40948 L
.08423 .40984 L
.08423 .41017 L
.08422 .41042 L
.08422 .41065 L
.08422 .41083 L
.08422 .41095 L
.08422 .41101 L
.08422 .41105 L
.08421 .41107 L
.08421 .41109 L
.08421 .4111 L
.08421 .41109 L
.08421 .41102 L
.08422 .41089 L
.08422 .41071 L
.08422 .4105 L
.08422 .41026 L
.08423 .41002 L
.08423 .40977 L
.08423 .40952 L
.08424 .40928 L
.08424 .40903 L
.08424 .40878 L
.08424 .40856 L
.08425 .40833 L
.08425 .40812 L
.08425 .40791 L
.08425 .40774 L
Mistroke
.08426 .40763 L
.08426 .40751 L
.08426 .4074 L
.08426 .40734 L
.08426 .40724 L
.08427 .40711 L
.08427 .40697 L
.08428 .40685 L
.08428 .40675 L
.08428 .40667 L
.08428 .40663 L
.08428 .40664 L
.08428 .40666 L
.08428 .40668 L
.08428 .40669 L
.08428 .40671 L
.08428 .40672 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40676 L
.08428 .40677 L
.08428 .40677 L
.08428 .40675 L
.08428 .40671 L
.08428 .40666 L
.08429 .4066 L
.08429 .40653 L
.08429 .40646 L
.08429 .4064 L
.08429 .40636 L
.0843 .40634 L
.0843 .40632 L
.0843 .40632 L
.0843 .40634 L
.08429 .40635 L
.08429 .40639 L
.08429 .40644 L
.08429 .40651 L
.08429 .40658 L
.08428 .40665 L
.08428 .40671 L
.08428 .40675 L
.08428 .40677 L
.08428 .40677 L
.08428 .40676 L
.08428 .40675 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40677 L
Mistroke
.08428 .40679 L
.08428 .4068 L
.08428 .40678 L
.08428 .40673 L
.08428 .40667 L
.08429 .40659 L
.08429 .40651 L
.08429 .40643 L
.08429 .40637 L
.08429 .40633 L
.0843 .4063 L
.0843 .40629 L
.0843 .40629 L
.0843 .40629 L
.0843 .40631 L
.08429 .40635 L
.08429 .40641 L
.08429 .40648 L
.08429 .40657 L
.08428 .40665 L
.08428 .40672 L
.08428 .40678 L
.08428 .4068 L
.08428 .4068 L
.08428 .40677 L
.08428 .40674 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
Mistroke
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40673 L
.08428 .40674 L
.08428 .40675 L
.08428 .40674 L
.08428 .40674 L
.08428 .40672 L
.08428 .4067 L
.08428 .40667 L
.08428 .40665 L
.08429 .40663 L
.08429 .40662 L
.08429 .40662 L
.08429 .40663 L
.08429 .40664 L
.08429 .40666 L
.08429 .40669 L
.08429 .4067 L
.08429 .40668 L
.08429 .40663 L
.08429 .40656 L
.08429 .40646 L
.08429 .40634 L
.08429 .4062 L
.0843 .40607 L
.0843 .40593 L
.0843 .4063 L
.08431 .40634 L
.08431 .40641 L
.0843 .40648 L
.0843 .4065 L
.0843 .40648 L
.0843 .40641 L
.0843 .40628 L
.0843 .40609 L
.0843 .40581 L
.08431 .40548 L
.08431 .4051 L
.08432 .40467 L
.08432 .40424 L
.08433 .40377 L
.08434 .4033 L
.08434 .40285 L
.08435 .40248 L
.08436 .40218 L
Mistroke
.08436 .40197 L
.08436 .40187 L
.08436 .40185 L
.08436 .40188 L
.08436 .40195 L
.08436 .40202 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .4021 L
.08436 .40209 L
.08436 .40208 L
.08436 .40207 L
.08436 .40207 L
.08436 .40207 L
.08436 .40209 L
.08436 .4021 L
.08435 .4021 L
.08435 .4021 L
.08435 .40208 L
.08435 .40205 L
.08435 .40206 L
.08434 .40213 L
.08434 .40229 L
.08434 .4025 L
.08433 .40271 L
.08433 .40297 L
.08433 .40325 L
.08433 .40357 L
.08432 .40392 L
.08432 .40427 L
.08432 .40463 L
.08431 .40498 L
Mistroke
.08431 .40534 L
.08431 .40573 L
.08431 .40606 L
.0843 .40629 L
.0843 .40646 L
.0843 .40657 L
.0843 .40663 L
.08429 .40667 L
.08429 .4067 L
.08429 .40672 L
.08429 .40675 L
.08429 .40677 L
.08428 .40678 L
.08428 .40677 L
.08428 .40673 L
.08428 .40666 L
.08428 .40658 L
.08428 .40652 L
.08427 .40649 L
.08424 .40651 L
.0842 .4066 L
.08416 .40678 L
.08414 .40705 L
.08415 .4074 L
.0842 .40782 L
.08429 .40827 L
.08443 .40875 L
.08463 .40921 L
.08485 .40967 L
.0851 .41012 L
.08536 .41055 L
.08561 .41094 L
.08586 .41124 L
.08611 .41145 L
.08635 .41157 L
.08657 .41161 L
.08674 .41159 L
.08686 .41152 L
.08693 .41145 L
.08695 .41139 L
.08694 .41136 L
.0869 .41136 L
.08686 .41136 L
.08683 .41136 L
.08682 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
.08681 .41136 L
Mistroke
.08681 .41136 L
.0868 .41134 L
.08677 .41132 L
.08674 .41128 L
.0867 .41124 L
.08668 .41123 L
.08669 .41124 L
.08675 .41129 L
.08685 .41138 L
.087 .41152 L
.08719 .41169 L
.08742 .4119 L
.08768 .41213 L
.08794 .41237 L
.08819 .41261 L
.08844 .41285 L
.08869 .4131 L
.08893 .41334 L
.08915 .41356 L
.08932 .41375 L
.08943 .41387 L
.0895 .41392 L
.08952 .41388 L
.08951 .41377 L
.08948 .4136 L
.08944 .41339 L
.08941 .41316 L
.0894 .41292 L
.0894 .41267 L
.08941 .41243 L
.08941 .41219 L
.08942 .41196 L
.08942 .41175 L
.08943 .41156 L
.08943 .41141 L
.08943 .41131 L
.08943 .41125 L
.08943 .41123 L
.08943 .41124 L
.08943 .41128 L
.08943 .41132 L
.08943 .41135 L
.08943 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
Mistroke
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08943 .41136 L
.08941 .41135 L
.08939 .41132 L
.08934 .41128 L
.08931 .41125 L
Mistroke
.08929 .41123 L
.08928 .41123 L
.08931 .41126 L
.08937 .4113 L
.08949 .41137 L
.08966 .41148 L
.08989 .41165 L
.09018 .4119 L
.09052 .41223 L
.09089 .41264 L
.09129 .41314 L
.09173 .4137 L
.09223 .41429 L
.09278 .41487 L
.09334 .41541 L
.09385 .41593 L
.09437 .41644 L
.09486 .41696 L
.09532 .41749 L
.09572 .41803 L
.09606 .41858 L
.09636 .41913 L
.09662 .41968 L
.09683 .4202 L
.097 .42066 L
.09711 .42106 L
.09717 .42143 L
.09717 .42182 L
.09713 .42221 L
.09707 .42257 L
.09701 .42285 L
.09697 .42304 L
.09699 .42315 L
.09708 .42318 L
.09722 .42315 L
.09743 .4231 L
.09766 .42302 L
.09792 .42296 L
.09819 .42293 L
.09844 .42293 L
.09868 .42293 L
.0989 .42293 L
.0991 .42293 L
.09929 .42293 L
.09947 .42293 L
.09964 .42293 L
.0998 .42293 L
.09996 .42293 L
.10013 .42293 L
.10029 .42293 L
Mistroke
.10046 .42293 L
.10066 .42293 L
.1009 .42293 L
.1012 .42293 L
.10152 .42293 L
.10188 .42293 L
.10228 .42293 L
.10271 .42293 L
.10317 .42293 L
.10359 .42293 L
.10395 .42288 L
.1042 .4228 L
.10437 .42268 L
.10441 .42255 L
.10432 .42244 L
Mfstroke
.07146 .49316 m
.0715 .49315 L
.07154 .49304 L
.07157 .49286 L
.07156 .49266 L
.07151 .49251 L
.07141 .49248 L
s
.10295 .74191 m
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
Mistroke
.10264 .74489 L
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
Mfstroke
.25158 .89098 m
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
s
.25906 .89527 m
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
s
.3951 .94887 m
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
s
.67231 .93392 m
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
s
.88099 .71322 m
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
s
.87676 .75474 m
.87674 .75479 L
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
s
.85322 .80006 m
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
s
.85238 .79364 m
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
Mistroke
.8538 .79278 L
Mfstroke
.87517 .76164 m
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
s
.87788 .751 m
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
s
.84311 .74552 m
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
s
.81497 .81507 m
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
s
.80878 .83529 m
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
s
.6781 .93334 m
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
Mistroke
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
Mistroke
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
Mistroke
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
Mistroke
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
Mfstroke
.64082 .93339 m
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
s
.42669 .95537 m
.42657 .95534 L
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
Mistroke
.42741 .95035 L
.42729 .9505 L
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
Mistroke
.42734 .95308 L
.42736 .95287 L
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
Mfstroke
.08294 .46909 m
.08303 .46907 L
.08304 .46912 L
.08299 .46919 L
.0829 .46928 L
.08283 .46936 L
.08277 .46943 L
.08275 .46946 L
.08275 .46947 L
.08275 .46947 L
.08274 .4695 L
.08272 .46955 L
.08269 .46963 L
.08262 .4697 L
.08255 .46973 L
.08248 .46971 L
.08243 .46962 L
s
.07287 .48144 m
.07295 .48154 L
.07308 .48156 L
.07324 .48152 L
.07341 .48145 L
.07361 .48139 L
.07381 .48137 L
.07401 .48136 L
.07419 .48134 L
.07435 .48133 L
.07447 .48132 L
.07456 .48132 L
.0746 .48131 L
.07459 .48131 L
.07455 .48131 L
.07451 .48132 L
.07448 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07446 .48132 L
.07448 .48131 L
.07451 .48129 L
.07456 .48123 L
Mistroke
.0746 .48115 L
.07462 .4811 L
.0746 .4811 L
.07454 .48115 L
.07443 .48129 L
.07426 .48154 L
.07404 .48189 L
.07379 .48232 L
.07352 .48279 L
.07323 .48326 L
.07294 .48376 L
.07265 .48421 L
.07238 .48461 L
.07212 .48508 L
.07189 .48552 L
.07171 .48587 L
.07159 .48612 L
.07152 .48625 L
.0715 .48631 L
.07152 .4863 L
.07156 .48625 L
.07161 .48616 L
.07164 .48609 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07166 .48607 L
.07164 .48606 L
.07161 .48603 L
.07157 .48599 L
Mistroke
.07153 .48596 L
.07152 .48594 L
.07153 .48595 L
.07158 .48599 L
.07169 .48607 L
.07184 .48617 L
.07204 .48629 L
.07227 .48642 L
.07252 .48659 L
.07279 .4868 L
.07305 .48708 L
.07331 .48743 L
.07355 .48785 L
.07378 .48835 L
.07397 .4889 L
.07412 .48949 L
.07423 .49009 L
.07428 .49068 L
.07431 .49124 L
.07431 .49172 L
.07428 .49211 L
.07422 .49242 L
.07414 .49265 L
.07404 .4928 L
.07394 .49285 L
.07383 .4928 L
.07373 .49275 L
.07364 .49266 L
.07357 .49255 L
.07352 .49245 L
.07349 .49238 L
.07348 .49236 L
.07348 .49238 L
.07349 .49244 L
.07353 .49254 L
.07359 .49267 L
.07368 .4928 L
.07378 .49294 L
.0739 .49305 L
.074 .49314 L
.07408 .49319 L
.07411 .49319 L
.0741 .49311 L
.07404 .493 L
.07397 .4929 L
.07393 .49285 L
.07393 .49287 L
.07398 .49297 L
.07408 .49316 L
.07422 .49344 L
Mistroke
.07441 .49379 L
.07463 .49421 L
.07488 .49468 L
.07515 .49519 L
.07544 .49572 L
.07573 .49625 L
.07601 .49677 L
.07626 .49723 L
.07644 .4976 L
.07655 .49783 L
.07656 .49788 L
Mfstroke
.08811 .46473 m
.08822 .46473 L
.08828 .46473 L
.0883 .46473 L
.08828 .46473 L
.08824 .46473 L
.0882 .46473 L
.08817 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08817 .46474 L
.0882 .46476 L
Mistroke
.08822 .46478 L
.08822 .46479 L
.08819 .46477 L
.08814 .46474 L
.08807 .46468 L
.08799 .46462 L
.08791 .46455 L
.08783 .46449 L
.08778 .46443 L
.08774 .46439 L
.08772 .46437 L
.08772 .46436 L
.08771 .46436 L
.08771 .46436 L
.08773 .46438 L
.08777 .46442 L
.08783 .46447 L
.08792 .46453 L
.08801 .4646 L
.08809 .46467 L
.08816 .46473 L
.08822 .46477 L
.08824 .46479 L
.08822 .46479 L
.08819 .46477 L
.08817 .46474 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08816 .46474 L
.08818 .46477 L
.08821 .4648 L
.08823 .46482 L
.08822 .46481 L
Mistroke
.08818 .46477 L
.08812 .46469 L
.08804 .46459 L
.08796 .46448 L
.08787 .46437 L
.0878 .46428 L
.08774 .4642 L
.08771 .46415 L
.08769 .46412 L
.08769 .4641 L
.08769 .46411 L
.08769 .46413 L
.08772 .46417 L
.08777 .46425 L
.08785 .46434 L
.08793 .46445 L
.08803 .46457 L
.08811 .46468 L
.08818 .46476 L
.08822 .46481 L
.08823 .46483 L
.08821 .46481 L
.08818 .46477 L
.08816 .46475 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
Mistroke
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46473 L
.08815 .46474 L
.08815 .46477 L
.08815 .46481 L
.08815 .46484 L
.08815 .46486 L
.08815 .46486 L
.08815 .46483 L
.08813 .46478 L
.08809 .46472 L
.08801 .46467 L
.08794 .46459 L
Mfstroke
.08931 .41113 m
.08919 .41115 L
.08916 .41119 L
.08917 .41124 L
.08923 .41128 L
.08932 .41132 L
.08939 .41135 L
.08942 .41136 L
.08943 .41137 L
.08943 .41137 L
.08943 .41137 L
.08944 .4114 L
.08948 .41147 L
.08955 .41154 L
.08963 .41162 L
.08966 .41169 L
.08964 .41172 L
.08955 .41166 L
s
.24375 .11809 m
.24387 .11826 L
.24394 .11843 L
.24396 .1186 L
.24396 .11874 L
.24396 .11886 L
.24402 .11892 L
.24411 .11892 L
s
.37259 .03844 m
.3726 .0386 L
.37251 .03873 L
.37236 .03881 L
.37219 .03885 L
.37204 .03887 L
.37195 .03888 L
.37191 .03888 L
.3719 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37189 .03888 L
.37188 .03888 L
.37185 .03888 L
.3718 .03888 L
.37173 .03888 L
.37166 .03888 L
.37159 .03887 L
.37153 .03887 L
.37153 .03887 L
.37161 .03888 L
s
.40666 .03552 m
.40672 .03553 L
.40668 .03553 L
.40659 .03552 L
.40648 .03552 L
.40637 .03551 L
.40628 .03551 L
.40622 .03551 L
.40617 .03551 L
.40613 .03551 L
.4061 .03551 L
.40608 .03551 L
.40609 .03551 L
.40614 .03551 L
.40624 .03551 L
.40637 .03551 L
.40654 .03551 L
.40674 .03552 L
.40697 .03553 L
.4072 .03554 L
.40744 .03556 L
.40768 .03558 L
.4079 .03557 L
.40811 .03553 L
.4083 .03547 L
.40844 .03541 L
.40855 .03538 L
.40861 .03541 L
.40862 .03554 L
.40861 .03577 L
.40858 .0361 L
.40854 .03649 L
.40851 .03689 L
.40848 .03728 L
.40845 .03761 L
.40841 .03786 L
.40836 .03802 L
.40829 .03809 L
.40821 .03806 L
s
.71862 .09244 m
.71859 .09259 L
.71871 .09287 L
.71889 .09323 L
.7191 .09365 L
.71934 .09409 L
.71959 .09451 L
.71982 .0949 L
.72001 .09518 L
.72009 .09535 L
.72006 .0954 L
s
.75057 .10551 m
.75068 .10549 L
.75076 .10549 L
.75081 .10551 L
.75081 .10554 L
.75077 .10559 L
.75067 .10567 L
s
.852 .22448 m
.85189 .22436 L
.85184 .2243 L
.85181 .22426 L
.8518 .22422 L
.8518 .22419 L
.85178 .22417 L
.85173 .22413 L
.85167 .22413 L
.85168 .2242 L
s
.90031 .30241 m
.90034 .30246 L
.9003 .30239 L
.90023 .30227 L
.90015 .30214 L
.90008 .30203 L
.90003 .30195 L
.9 .3019 L
.89999 .30187 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89998 .30186 L
.89997 .30185 L
.89995 .30182 L
.89992 .30179 L
.89989 .30176 L
.89987 .30174 L
.89988 .30175 L
.89992 .3018 L
.9 .30188 L
.90012 .30201 L
.90026 .30216 L
.90043 .30235 L
.90062 .30255 L
.90082 .30277 L
.90102 .30299 L
.90123 .30321 L
.90142 .30342 L
.9016 .30361 L
.90175 .30378 L
.90188 .30391 L
.90196 .304 L
.90201 .30406 L
.90203 .30407 L
.90202 .30406 L
.90199 .30403 L
.90195 .30399 L
.90193 .30396 L
.90192 .30395 L
.90191 .30395 L
.90191 .30395 L
.90191 .30395 L
Mistroke
.90191 .30395 L
.90192 .30395 L
.90193 .30393 L
.90195 .30392 L
.90198 .30391 L
.902 .30391 L
.90202 .30393 L
.90201 .30396 L
.90197 .304 L
.9019 .30405 L
.9018 .30412 L
.90166 .30419 L
.9015 .30425 L
.90132 .30429 L
.90113 .30429 L
.90093 .30424 L
.90073 .30416 L
.90054 .30403 L
.90036 .30386 L
.90021 .30365 L
.90008 .3034 L
.89998 .30314 L
.89993 .30288 L
.8999 .30262 L
.8999 .30236 L
.89992 .30211 L
.89994 .30185 L
.89994 .30161 L
.89991 .30139 L
.89984 .30123 L
.89975 .30117 L
.89969 .30125 L
Mfstroke
.91002 .34885 m
.91001 .34893 L
.91004 .34898 L
.91011 .349 L
.91021 .34905 L
.91036 .34921 L
.91053 .34939 L
.91068 .34955 L
.91079 .34965 L
.91083 .34966 L
s
.90595 .31206 m
.90586 .312 L
.90579 .31201 L
.90575 .31206 L
.90573 .31212 L
.90575 .31217 L
.90579 .31221 L
.90585 .31224 L
.90594 .31226 L
.90605 .31226 L
.90619 .31226 L
.90636 .31226 L
.90654 .31226 L
.90673 .31227 L
.90692 .31227 L
.90711 .31227 L
.9073 .31227 L
.90747 .31227 L
.90762 .31227 L
.90773 .31227 L
.90782 .31227 L
.90787 .31227 L
.90788 .31227 L
.90787 .31227 L
.90784 .31227 L
.90781 .31227 L
.90779 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
Mistroke
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90777 .31227 L
.90778 .31226 L
.9078 .31223 L
.90783 .31219 L
.90786 .31215 L
.90787 .31214 L
.90786 .31216 L
.90783 .31223 L
.90776 .31233 L
.90766 .31248 L
.90753 .31267 L
.90738 .31287 L
.90721 .31309 L
.90703 .31331 L
.90685 .31354 L
.90666 .31375 L
.90648 .31393 L
.90632 .31413 L
.90617 .31429 L
.90606 .31441 L
.90597 .31448 L
.90592 .3145 L
.9059 .31448 L
.90591 .31444 L
.90593 .31439 L
.90596 .31433 L
.90598 .31431 L
.906 .31432 L
.906 .31436 L
.906 .3144 L
.906 .31444 L
.90601 .31445 L
.906 .31444 L
.906 .3144 L
.906 .31432 L
.906 .3142 L
Mfstroke
.92401 .45119 m
.92402 .45123 L
.924 .45094 L
.92395 .45041 L
.92389 .44973 L
.92384 .44895 L
.9238 .44813 L
.92377 .44737 L
.92375 .44669 L
.92373 .44614 L
.92372 .44575 L
.92373 .4455 L
.92377 .44537 L
.92382 .44534 L
.92387 .44538 L
.9239 .44546 L
.92389 .44555 L
.92381 .44561 L
.92365 .44565 L
.92341 .44567 L
.92309 .44568 L
.92273 .44569 L
.92235 .44569 L
.92199 .4457 L
.92166 .44571 L
.92138 .44571 L
.92114 .44567 L
.92096 .44559 L
.92085 .44549 L
s
.9303 .56203 m
.93036 .56208 L
.93049 .56194 L
.93068 .56166 L
.93091 .56131 L
.93114 .56095 L
.93134 .56064 L
.93147 .56042 L
.9315 .56034 L
s
.8954 .68734 m
.89542 .68734 L
.89548 .68718 L
.89558 .68693 L
.89569 .68665 L
.89577 .68642 L
.8958 .68627 L
.89575 .68625 L
.89563 .68634 L
s
.85593 .79794 m
.85588 .79801 L
.85587 .79808 L
.85598 .7981 L
.85618 .79807 L
.85645 .79798 L
.85673 .79787 L
.85699 .79771 L
.85719 .79753 L
.85733 .79732 L
.85741 .79717 L
.85746 .79703 L
.85747 .79696 L
.85744 .79694 L
.85737 .79696 L
.8573 .797 L
.85719 .79708 L
.85703 .79722 L
.85682 .79742 L
.85657 .79767 L
.85628 .79797 L
.85596 .79829 L
.85562 .79863 L
.85528 .79894 L
.85499 .79914 L
.85483 .79921 L
.85472 .79923 L
.85458 .79929 L
s
.83509 .81517 m
.83511 .81497 L
.83521 .81474 L
.83533 .81453 L
.83545 .81438 L
.83558 .81424 L
.83569 .81415 L
.83579 .81408 L
.83584 .81406 L
.83585 .81413 L
s
.81872 .82997 m
.81879 .83002 L
.81897 .82999 L
.81916 .82992 L
.81934 .82982 L
.81948 .82971 L
.8196 .82957 L
.81966 .8294 L
s
.88478 .70287 m
.88488 .70279 L
.88511 .70278 L
.88546 .70282 L
.88587 .70287 L
.88632 .70291 L
.88678 .7029 L
.88722 .70284 L
.88762 .70275 L
.88796 .70265 L
.88822 .70255 L
.88838 .70247 L
.88844 .70243 L
.88842 .70244 L
.88833 .70252 L
.88818 .70267 L
.88799 .70289 L
.88779 .70315 L
.88757 .70343 L
.88734 .70367 L
.88709 .70392 L
.88682 .70419 L
.88652 .70447 L
.88619 .70478 L
.88585 .70512 L
.88549 .70549 L
.88515 .70589 L
.88481 .7063 L
.88448 .70673 L
.88415 .70717 L
.88383 .70761 L
.88352 .70808 L
.8832 .70851 L
.88292 .70887 L
.88267 .70912 L
.88249 .70927 L
.88238 .70932 L
s
.78268 .1249 m
.78275 .12477 L
.78295 .1248 L
.78324 .12492 L
.78358 .12505 L
.78391 .12518 L
.78421 .12529 L
.78447 .12539 L
.78467 .12546 L
.78483 .12551 L
.78496 .12555 L
.78505 .12559 L
.78511 .12563 L
.78512 .12566 L
.78511 .12567 L
.78508 .12568 L
.78505 .12568 L
.78502 .12569 L
.78501 .12567 L
.78501 .12564 L
.785 .12558 L
.785 .1255 L
.785 .12544 L
.785 .1254 L
.785 .12539 L
.785 .12542 L
.78502 .1255 L
.78503 .12564 L
.78503 .12584 L
.78503 .12609 L
.78501 .12636 L
.78499 .12662 L
.78497 .12684 L
.78494 .12702 L
.78492 .12715 L
.7849 .12721 L
.78488 .12721 L
.78487 .12715 L
.78486 .12704 L
.78486 .12685 L
.78486 .12664 L
.78489 .12639 L
.78495 .12613 L
.78503 .12589 L
.78512 .12569 L
.78518 .12554 L
.7852 .12543 L
.78517 .12533 L
.7851 .12525 L
s
.65501 .06455 m
.655 .06442 L
.6551 .06437 L
.65525 .06438 L
.6554 .06442 L
.65552 .06449 L
.6556 .06457 L
.65566 .06462 L
.65569 .06464 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.65569 .06465 L
.6557 .06465 L
.65574 .06465 L
.65583 .06468 L
.65595 .06473 L
.65607 .0648 L
.65613 .06486 L
.65611 .06489 L
.65598 .06487 L
s
.64339 .05979 m
.64322 .05985 L
.64301 .05991 L
.64271 .05997 L
.64231 .06 L
.64184 .06003 L
.64132 .06004 L
.64081 .06004 L
.64034 .06001 L
.63988 .05995 L
.63944 .05985 L
.63899 .05971 L
.63855 .05953 L
.63813 .05933 L
.63775 .05911 L
.63741 .05888 L
.63712 .05865 L
.63688 .05842 L
.63669 .0582 L
.63651 .058 L
.63634 .05783 L
.63608 .05768 L
.63575 .05758 L
.63538 .05751 L
.63503 .05748 L
.63473 .05749 L
.63449 .05751 L
.63433 .05754 L
.63426 .05756 L
.63427 .05758 L
.63434 .05758 L
.63446 .05759 L
.63459 .05759 L
.63474 .0576 L
.6349 .0576 L
.63509 .05761 L
.6353 .05762 L
.63552 .05762 L
.63574 .05763 L
.63596 .05764 L
.63617 .05765 L
.63637 .05765 L
.63653 .05766 L
.63667 .05766 L
.63676 .05767 L
.63682 .05767 L
.63683 .05767 L
.63682 .05767 L
.63679 .05767 L
.63675 .05767 L
Mistroke
.63672 .05767 L
.63671 .05766 L
.63671 .05766 L
.63671 .05766 L
.63674 .05765 L
.63679 .0576 L
.63685 .05752 L
.63691 .05743 L
.63694 .05736 L
.63692 .05734 L
.63684 .05739 L
Mfstroke
.67697 .07601 m
.67709 .07611 L
.67712 .07614 L
.67707 .07611 L
.67698 .07604 L
.67688 .07595 L
.67678 .07586 L
.67668 .07577 L
.6766 .0757 L
.67654 .07567 L
.67653 .07568 L
.67657 .07578 L
s
.56957 .03605 m
.56948 .03614 L
.56954 .03621 L
.56971 .03626 L
.56996 .03627 L
.57027 .03628 L
.57058 .03629 L
.57084 .0363 L
.57107 .03631 L
.5713 .03632 L
.57152 .03632 L
.57175 .03633 L
.57197 .03634 L
.57217 .03634 L
.57234 .03635 L
.57248 .03636 L
.57257 .03636 L
.57263 .03636 L
.57265 .03636 L
.57263 .03636 L
.5726 .03636 L
.57256 .03636 L
.57253 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
Mistroke
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57252 .03636 L
.57254 .03636 L
.5726 .03636 L
.57266 .03636 L
.57273 .03636 L
.57276 .03637 L
.57276 .03636 L
.5727 .03636 L
.57261 .03636 L
Mfstroke
.46917 .03305 m
.46901 .03304 L
.46896 .03304 L
.469 .03304 L
.4691 .03304 L
.46922 .03305 L
.46932 .03305 L
.46941 .03305 L
.46949 .03306 L
.46957 .03306 L
.46966 .03306 L
.46975 .03306 L
.46981 .03307 L
.46979 .03307 L
s
.44682 .03214 m
.4466 .03211 L
.44648 .03213 L
.4464 .03222 L
.44627 .03239 L
.44609 .03265 L
.44585 .03297 L
.44553 .03335 L
.4451 .03377 L
.44459 .03421 L
.44403 .03464 L
.44345 .03506 L
.44286 .03548 L
.4423 .03587 L
.44179 .03621 L
.44139 .03648 L
.44112 .03667 L
.44096 .03677 L
.44089 .03681 L
.44086 .03679 L
.44085 .03676 L
.4408 .03669 L
.44068 .03662 L
s
.35324 .04958 m
.35321 .04966 L
.35323 .04969 L
.35328 .04966 L
.35335 .04959 L
.3534 .04952 L
.35343 .04947 L
.35345 .04945 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35345 .04944 L
.35348 .04944 L
.35354 .04944 L
.35362 .04944 L
.35374 .04943 L
.35389 .04938 L
.35403 .04928 L
.35412 .04915 L
.35412 .04901 L
s
.19418 .15185 m
.19413 .15194 L
.19418 .15192 L
.19428 .15183 L
.1944 .15169 L
.19454 .15154 L
.19465 .15142 L
.19473 .15135 L
.19476 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15132 L
.19477 .15131 L
.1948 .15127 L
.19485 .15118 L
.19493 .15107 L
.195 .15095 L
.19504 .15086 L
.19501 .15084 L
.19491 .15094 L
s
.18969 .16283 m
.18979 .1629 L
.18997 .16277 L
.19016 .16254 L
.19033 .16229 L
.19044 .16209 L
.19046 .162 L
s
.08426 .40768 m
.08426 .40776 L
.08426 .40765 L
.08427 .40742 L
.08427 .40717 L
.08428 .407 L
.08428 .40688 L
.08428 .40676 L
.08428 .40666 L
.08428 .40657 L
.08428 .40651 L
.08428 .40648 L
.08428 .40652 L
.08428 .40663 L
.08428 .40681 L
.08427 .40706 L
.08427 .40738 L
.08426 .40774 L
.08425 .40815 L
.08425 .40856 L
.08424 .40895 L
.08423 .40932 L
.08423 .40967 L
.08422 .40998 L
.08422 .41026 L
.08422 .41046 L
.08422 .41061 L
.08422 .4107 L
.08421 .41061 L
.08422 .4106 L
.08421 .4106 L
.08421 .41063 L
.0842 .41066 L
.08416 .41073 L
.08412 .41083 L
.08408 .41092 L
.08405 .41101 L
.08405 .41112 L
.08407 .41125 L
.08412 .41141 L
s
.09316 .70178 m
.09309 .70191 L
.093 .70185 L
.09293 .70165 L
.09288 .70134 L
.09287 .70096 L
.09289 .70065 L
.09295 .70049 L
.09305 .70055 L
s
.10264 .74509 m
.10263 .74521 L
.10263 .74527 L
.10263 .74527 L
.10264 .74523 L
.10264 .74515 L
.10264 .74504 L
.10264 .7449 L
.10264 .74473 L
.10265 .74453 L
.10265 .74433 L
.10265 .74412 L
.10264 .74389 L
.10261 .74368 L
.10257 .74347 L
.10251 .74328 L
.10245 .74312 L
.10239 .743 L
.10237 .74289 L
.10239 .74287 L
s
.4785 .9661 m
.47864 .96606 L
.47871 .96603 L
.47877 .966 L
.47883 .96597 L
.47891 .96594 L
.47905 .96591 L
.47924 .96588 L
.47946 .96586 L
.4797 .96584 L
.47993 .96583 L
.48011 .96583 L
.48022 .96584 L
.48023 .96587 L
.48011 .9659 L
.47986 .96594 L
.47949 .96598 L
.47908 .96602 L
.47864 .96605 L
.47819 .96608 L
.47776 .9661 L
.47739 .96613 L
.47708 .96619 L
.47685 .96627 L
.47664 .96632 L
.47644 .96632 L
.47624 .96628 L
.47608 .9662 L
s
.85345 .79336 m
.85337 .79343 L
.85333 .79366 L
.85332 .79401 L
.8533 .79445 L
.85326 .79502 L
.85321 .79557 L
.85314 .79608 L
.85308 .79664 L
.85304 .7971 L
.85302 .79745 L
.85302 .79767 L
.85304 .79781 L
.85305 .79789 L
.85303 .79795 L
.85296 .79801 L
.85286 .79805 L
.85277 .79812 L
.85272 .79823 L
.85276 .79834 L
s
.92769 .56854 m
.92762 .56875 L
.92758 .56884 L
.92759 .56881 L
.92762 .56873 L
.92767 .56862 L
.92771 .56849 L
.92773 .56837 L
.92773 .56825 L
.92771 .56811 L
s
.93108 .55755 m
.93113 .55746 L
.93117 .55742 L
.93118 .5574 L
.93119 .5574 L
.93118 .5574 L
.93116 .55741 L
.93114 .55741 L
.93112 .55741 L
.93111 .55742 L
.93111 .55745 L
.93111 .55747 L
.93111 .55747 L
.93111 .55749 L
.93111 .55751 L
.93111 .55755 L
.93111 .55758 L
.93111 .5576 L
.93111 .55759 L
.93111 .55754 L
.93111 .55745 L
.9311 .55733 L
.9311 .55717 L
.93109 .55699 L
.93109 .55681 L
.93107 .55672 L
.93105 .55671 L
.93102 .55676 L
.931 .55681 L
.93099 .55682 L
.931 .55675 L
s
.90366 .30353 m
.9036 .30354 L
.90359 .30367 L
.90362 .30389 L
.90367 .30416 L
.90372 .30444 L
.90377 .30469 L
.90381 .30489 L
.90383 .30501 L
.90384 .30508 L
.90384 .30509 L
.90384 .30506 L
.90384 .305 L
.90384 .30495 L
.90383 .30483 L
.90382 .30468 L
.90381 .30451 L
.9038 .30433 L
.90379 .30416 L
.90377 .30402 L
.90376 .3039 L
.90376 .30381 L
.90375 .30377 L
.90376 .30379 L
.90376 .30386 L
.90377 .30395 L
.90377 .30404 L
.90377 .30414 L
.90378 .30424 L
.90378 .30434 L
.90379 .30444 L
.90379 .30452 L
.90379 .30458 L
.9038 .30462 L
.9038 .30464 L
.9038 .30463 L
.90379 .30459 L
.90379 .30454 L
.90379 .30446 L
.90378 .30437 L
.90378 .30426 L
.90378 .30416 L
.90377 .30406 L
.90377 .30399 L
.90377 .30394 L
.90377 .30392 L
.90378 .3039 L
.90379 .30387 L
.9038 .30385 L
.90381 .30385 L
Mistroke
.90382 .30387 L
.90383 .30392 L
.90382 .30399 L
.9038 .30409 L
.90376 .30421 L
.90371 .30434 L
.90364 .30446 L
.90355 .30454 L
.90343 .30458 L
.90326 .30455 L
.90304 .30449 L
.90275 .30439 L
.90238 .30423 L
.90192 .304 L
.90136 .30371 L
.9007 .30336 L
.9 .30301 L
.89924 .30266 L
.89846 .30236 L
.89774 .30211 L
.89709 .30191 L
.89656 .30179 L
.89617 .30173 L
.89594 .3017 L
.89586 .30163 L
Mfstroke
.78461 .12481 m
.78454 .1248 L
.78456 .12488 L
.78462 .12501 L
.78471 .12515 L
.78481 .12528 L
.7849 .12537 L
.78496 .12543 L
.78499 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12546 L
.785 .12547 L
.78501 .12549 L
.78503 .12553 L
.78507 .12557 L
.7851 .12561 L
.78511 .12563 L
.7851 .12562 L
.78506 .12555 L
.78498 .12544 L
s
.77612 .21965 m
.77615 .21953 L
.7761 .21932 L
.77597 .21908 L
.77578 .21888 L
.77559 .21875 L
.77545 .21873 L
s
.88953 .28248 m
.88948 .2825 L
.88933 .2825 L
.88908 .28253 L
.88875 .28262 L
.88836 .28279 L
.88798 .28302 L
.88761 .28329 L
.8873 .28357 L
.88705 .28386 L
.88685 .28417 L
.88671 .2845 L
.8866 .28481 L
.88656 .28508 L
.88658 .2853 L
s
.86384 .23518 m
.86399 .23519 L
.86414 .23519 L
.86424 .2352 L
.86429 .23524 L
.86425 .2353 L
.86411 .23536 L
s
.4062 .03538 m
.40613 .03546 L
.40609 .03552 L
.40608 .03556 L
.40609 .03559 L
.40613 .03558 L
.40617 .03555 L
.4062 .03553 L
.40621 .03551 L
.40622 .03551 L
.40628 .03551 L
.40639 .03552 L
.40655 .03552 L
.40673 .03553 L
.40688 .03553 L
.40699 .0355 L
.40703 .03545 L
s
.35529 .04982 m
.3554 .04987 L
.35551 .04985 L
.3556 .04977 L
.35567 .04969 L
.35571 .04961 L
.35574 .04955 L
.35576 .04952 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35576 .04951 L
.35577 .04951 L
.3558 .04951 L
.35587 .04951 L
.35598 .04951 L
.35608 .0495 L
.35613 .04948 L
.3561 .04944 L
.35596 .04938 L
s
.34653 .05628 m
.34665 .05624 L
.34682 .05605 L
.34703 .05577 L
.34727 .05546 L
.34749 .05516 L
.34768 .05492 L
.3478 .05475 L
.34785 .05464 L
.34783 .05457 L
.34778 .05448 L
.34773 .05433 L
.34768 .05413 L
.34761 .05395 L
.34751 .05381 L
.3474 .05373 L
.34732 .05372 L
.34725 .05373 L
.34717 .05376 L
.34706 .05381 L
.3469 .05384 L
s
.09954 .72674 m
.09962 .72678 L
.09972 .7268 L
.09985 .72681 L
.10001 .72681 L
.1002 .72682 L
.10043 .72683 L
.10072 .72687 L
.10105 .72699 L
.10143 .72716 L
.10183 .72737 L
.1022 .72759 L
.10254 .72779 L
.10281 .72797 L
.10299 .72811 L
.10309 .72819 L
.10312 .72821 L
.10311 .7282 L
.10307 .72818 L
.10303 .72817 L
.10298 .72822 L
s
.19527 .83797 m
.19521 .8379 L
.19517 .83789 L
.19516 .83794 L
.19515 .838 L
.19515 .83807 L
.19515 .83813 L
.19515 .83813 L
.19513 .83808 L
.1951 .83798 L
.19503 .83784 L
.19491 .83769 L
.19478 .83757 L
.19466 .83753 L
.19459 .8376 L
s
.32489 .92245 m
.32494 .92243 L
.32494 .92241 L
.3249 .92238 L
.32481 .92235 L
.32466 .92232 L
.32444 .92226 L
.32418 .92216 L
.32394 .92205 L
.32375 .92195 L
.32366 .92192 L
.32374 .92197 L
s
.4681 .9674 m
.46822 .96733 L
.46825 .96726 L
.46823 .9672 L
.46815 .96717 L
.46805 .96714 L
.46792 .96712 L
.46782 .96709 L
.46779 .96707 L
.46783 .96705 L
.46792 .96703 L
.46809 .96702 L
.46831 .96702 L
.46854 .96703 L
.46869 .96701 L
.46877 .96697 L
.46877 .96689 L
.46872 .96675 L
.46863 .96655 L
.46855 .96629 L
.46846 .96597 L
.46837 .96558 L
.46823 .96517 L
.46808 .96473 L
.46792 .96429 L
.46772 .96382 L
.46747 .96335 L
.46722 .96295 L
.46701 .96263 L
.46685 .96237 L
.46671 .96217 L
.4666 .96202 L
.46652 .9619 L
.46642 .96181 L
.46628 .96171 L
.46612 .96161 L
.46599 .96149 L
.46586 .96135 L
.46576 .96117 L
.46568 .96098 L
.46564 .9608 L
.46556 .96063 L
.46548 .96049 L
.46541 .96041 L
.46539 .96041 L
.46541 .96047 L
s
.68725 .92427 m
.6873 .92422 L
.6873 .92426 L
.68727 .92442 L
.68724 .92459 L
.6872 .92474 L
.68712 .9249 L
.68701 .9251 L
.68689 .92532 L
.68676 .92551 L
.68662 .92563 L
.68647 .92574 L
.68629 .92588 L
.6861 .92604 L
.68592 .92622 L
.68574 .92641 L
.68558 .9266 L
.68546 .92672 L
.6854 .92679 L
s
.65967 .8895 m
.65978 .88943 L
.65988 .8894 L
.65994 .88941 L
.65997 .88944 L
.65997 .88948 L
.65991 .88951 L
.65989 .88953 L
.65988 .88953 L
.65986 .88954 L
.65986 .88957 L
.65986 .88962 L
.65988 .88969 L
.65995 .88975 L
s
.64401 .85226 m
.64401 .85216 L
.64401 .8521 L
.64401 .85208 L
.64401 .8521 L
.64401 .85213 L
.64401 .85218 L
.64401 .85223 L
.64401 .8523 L
.64401 .85238 L
.64402 .85245 L
.64403 .85248 L
.64404 .85245 L
.64404 .85236 L
.64402 .85217 L
.644 .85191 L
.64397 .85156 L
.64393 .85116 L
.6439 .85071 L
.64387 .85024 L
.64385 .84977 L
.64383 .8493 L
.64382 .84884 L
.64381 .84841 L
.64381 .84804 L
.64381 .84775 L
.64383 .84754 L
.64385 .84742 L
.64389 .84741 L
.64395 .84749 L
.64402 .84762 L
.64408 .84776 L
.64412 .84784 L
.64412 .84785 L
.64408 .84776 L
.64398 .84758 L
.64384 .84729 L
.64366 .8469 L
.64347 .84643 L
.64325 .84593 L
.64302 .84543 L
.64278 .84501 L
.64255 .84465 L
.64236 .84438 L
.64224 .84423 L
.64218 .84421 L
s
.60706 .94269 m
.60693 .94262 L
.60689 .94256 L
.60693 .94251 L
.60703 .94246 L
.60713 .94238 L
.60724 .94228 L
.60737 .9422 L
.60749 .94216 L
.60757 .94213 L
.60762 .94212 L
.60769 .94215 L
.60779 .94222 L
.60791 .94228 L
.60808 .94231 L
.60827 .94232 L
.60857 .94234 L
.60888 .94236 L
.60926 .94238 L
.60966 .94244 L
.61012 .94256 L
.61056 .94273 L
.61104 .94293 L
.61151 .94311 L
.6119 .94325 L
.61216 .94335 L
.61222 .94336 L
s
.66614 .93045 m
.66629 .93056 L
.66636 .93058 L
.66635 .93055 L
.66631 .93052 L
.66623 .93051 L
.66613 .93056 L
.66603 .93069 L
.66594 .93092 L
.66587 .93119 L
.66581 .93146 L
.66578 .9317 L
.66578 .93193 L
.66577 .93207 L
.66574 .93211 L
.66569 .9321 L
.66562 .93207 L
.66556 .932 L
.66552 .93188 L
.66553 .93175 L
.66559 .93162 L
.66564 .93152 L
.66566 .93145 L
.66562 .93148 L
s
.67493 .92312 m
.67487 .92297 L
.6748 .92297 L
.67474 .92308 L
.67469 .92325 L
.67467 .92349 L
.67465 .92375 L
.67465 .92401 L
.67466 .92421 L
.67468 .92431 L
.6747 .92434 L
.67472 .92431 L
.67473 .92426 L
.67471 .92421 L
.67465 .92415 L
.67457 .92417 L
.67447 .92423 L
.67436 .92432 L
.67426 .9244 L
.67416 .92445 L
.67407 .92446 L
.67398 .92447 L
.67388 .92447 L
.67379 .92451 L
.67371 .92458 L
.67365 .92469 L
s
.65678 .8307 m
.65671 .8307 L
.65672 .83076 L
.65679 .83086 L
.6569 .83097 L
.657 .83108 L
.65709 .83119 L
.65713 .83129 L
.65711 .83137 L
.657 .83139 L
s
.62161 .80828 m
.62159 .80818 L
.62159 .80813 L
.6216 .80811 L
.62162 .80812 L
.62165 .80816 L
.62169 .80819 L
.62175 .80822 L
.62182 .80823 L
.62189 .80823 L
.62197 .80825 L
.62203 .8083 L
.62204 .80838 L
.62198 .80845 L
s
.56031 .80425 m
.56016 .80422 L
.56016 .80419 L
.56029 .80416 L
.5605 .80413 L
.56074 .80411 L
.56095 .80409 L
.56113 .80408 L
.56125 .80407 L
.56128 .80406 L
.56125 .80407 L
.56122 .80407 L
.56119 .80407 L
.56118 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56117 .80407 L
.56118 .80407 L
.56122 .80404 L
.56131 .80397 L
.56143 .80388 L
.56156 .80377 L
.56168 .80367 L
.56174 .8036 L
.56173 .80358 L
s
.45152 .89784 m
.45145 .89769 L
.45157 .89753 L
.45178 .8974 L
.45201 .89731 L
.45218 .89726 L
.45223 .89729 L
s
.38148 .9394 m
.38163 .93942 L
.38171 .93943 L
.38173 .93943 L
.38171 .93943 L
.38168 .93943 L
.38163 .93944 L
.3816 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38158 .93944 L
.38159 .93945 L
.38162 .93947 L
.38169 .93954 L
.3818 .93963 L
.38192 .93975 L
.38204 .93986 L
.38211 .93995 L
.3821 .93997 L
s
.26248 .65266 m
.26248 .65253 L
.26248 .65243 L
.26248 .65237 L
.26248 .65236 L
.26248 .65237 L
.26248 .65241 L
.26248 .65246 L
.26248 .65253 L
.26248 .65263 L
.26248 .65277 L
.26247 .65291 L
.26247 .65302 L
.26247 .65307 L
.26247 .65302 L
s
.15128 .45764 m
.15133 .4576 L
.1513 .45753 L
.15119 .45743 L
.15105 .45734 L
.1509 .45727 L
.15075 .45724 L
.15064 .45723 L
.15059 .45723 L
.15062 .45723 L
s
.24446 .50024 m
.24444 .50042 L
.2444 .50051 L
.24436 .50051 L
.24432 .50046 L
.24429 .50039 L
.24428 .50034 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24428 .50031 L
.24427 .50034 L
.24427 .50039 L
.24426 .50046 L
.24424 .50054 L
.24419 .50061 L
.24409 .50065 L
.24399 .50065 L
.24388 .50059 L
s
.32491 .38665 m
.32486 .38674 L
.32468 .38684 L
.32442 .38693 L
.32418 .387 L
.32403 .38702 L
.32409 .38698 L
s
.45918 .30205 m
.45909 .30206 L
.45881 .30236 L
.4585 .30285 L
.45829 .30324 L
.45823 .30337 L
.45826 .30345 L
.45832 .30357 L
s
.8242 .18893 m
.82414 .18885 L
.82412 .18885 L
.82415 .18891 L
.82419 .18901 L
.82424 .18911 L
.82426 .18918 L
.82425 .18921 L
.82423 .18921 L
.82419 .18918 L
s
.83224 .20307 m
.83212 .20299 L
.83201 .20301 L
.8319 .20307 L
.8318 .20314 L
.83172 .20322 L
.83165 .20329 L
.83158 .20335 L
.83152 .20337 L
.83147 .20337 L
.83144 .20337 L
.83144 .20338 L
.83146 .20338 L
.8315 .20339 L
.83158 .2034 L
.83169 .20342 L
.83184 .20344 L
.83199 .20347 L
.83213 .20348 L
.83222 .20347 L
.83226 .20345 L
.83225 .20341 L
.83219 .20337 L
.8321 .20332 L
.832 .20328 L
.83192 .20325 L
.83184 .20323 L
.83179 .20321 L
.83175 .20321 L
.83173 .20321 L
.83175 .20321 L
.83181 .20322 L
.83192 .20324 L
.83208 .20327 L
.83228 .20331 L
.83252 .20336 L
.83278 .20341 L
.83304 .20345 L
.83328 .20349 L
.8335 .20351 L
.83369 .20351 L
.83385 .2035 L
.83398 .20348 L
.83409 .20348 L
.83418 .20348 L
.83423 .20348 L
.83424 .20348 L
.83423 .20349 L
.83421 .20351 L
.8342 .20356 L
Mistroke
.83421 .20362 L
.83423 .20368 L
.83424 .20371 L
.83423 .20369 L
.83419 .20361 L
.83411 .20346 L
.83398 .2032 L
.83383 .20286 L
.83364 .20247 L
.83344 .20204 L
.83322 .20159 L
.83301 .20115 L
.83279 .20071 L
.83258 .20029 L
.83238 .1999 L
.83221 .19956 L
.83205 .19929 L
.83193 .1991 L
.83184 .199 L
.83182 .19896 L
.83184 .199 L
.83192 .19908 L
.83203 .19917 L
.83217 .19924 L
.83234 .1993 L
.83255 .19937 L
.83281 .19945 L
.83308 .19952 L
.83332 .19955 L
.83352 .19953 L
.83367 .19945 L
.83373 .19928 L
.83367 .19904 L
.83349 .19872 L
.83321 .19834 L
.83287 .19793 L
.83248 .19749 L
.83205 .19708 L
.83164 .19668 L
.83126 .1963 L
.83084 .19595 L
.83048 .19567 L
.8302 .19546 L
.83 .19533 L
.8299 .19525 L
.82985 .19517 L
.82985 .19505 L
Mfstroke
.80506 .15256 m
.805 .15251 L
.80502 .15255 L
.8051 .15264 L
.8052 .15277 L
.8053 .15292 L
.80539 .15303 L
.80544 .15309 L
.80548 .15313 L
.80552 .15316 L
.8056 .15321 L
.80573 .1533 L
.80584 .1534 L
.8059 .15349 L
.80588 .15352 L
s
.76484 .11444 m
.76472 .11435 L
.76471 .11436 L
.76483 .11439 L
.76511 .11443 L
.76544 .11445 L
.7658 .11446 L
.76619 .11446 L
.76656 .11446 L
.76684 .11447 L
.767 .11447 L
.76707 .11448 L
.76708 .11448 L
.76706 .11449 L
.767 .11448 L
.76695 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76687 .11448 L
.76687 .11448 L
.76687 .11448 L
.76689 .11447 L
.76692 .11447 L
.76695 .11447 L
.76698 .11447 L
.767 .11448 L
.76702 .11449 L
.76702 .11451 L
.76702 .11452 L
.76702 .11453 L
.767 .11454 L
.767 .11455 L
.76699 .11455 L
.76696 .11455 L
.76695 .11455 L
.76692 .11455 L
.76689 .11454 L
.76687 .11454 L
.76685 .11453 L
.76684 .11451 L
.76684 .1145 L
.76685 .11449 L
.76687 .11448 L
.76689 .11447 L
.7669 .11447 L
.7669 .11447 L
.76691 .11448 L
Mistroke
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11448 L
.76686 .11448 L
.76684 .11448 L
.76681 .11448 L
.76681 .11448 L
.76684 .11448 L
.76691 .11448 L
.76699 .11449 L
.76708 .11449 L
.76718 .11449 L
.76726 .11449 L
.76732 .11449 L
Mistroke
.76735 .11449 L
.76734 .11449 L
.76731 .11449 L
.76727 .11448 L
.76724 .11448 L
.76724 .11448 L
.76723 .11448 L
.76723 .11448 L
.76725 .11448 L
.7673 .11449 L
.76739 .11449 L
.76752 .1145 L
.76769 .11451 L
.76788 .11452 L
.7681 .11452 L
.76833 .11453 L
.76855 .11454 L
.76872 .11454 L
.76884 .11455 L
.76893 .11455 L
.76898 .11455 L
.769 .11455 L
.76899 .11455 L
.76896 .11455 L
.76892 .11455 L
.7689 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
Mistroke
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11455 L
.76888 .11454 L
.76888 .11453 L
.7689 .11451 L
.76895 .1145 L
.76899 .1145 L
.76901 .11451 L
.76899 .11453 L
.76894 .11458 L
.76883 .11465 L
.76868 .11474 L
.76849 .11483 L
.76828 .11492 L
.76803 .115 L
.76785 .11506 L
.76764 .1151 L
.76745 .11512 L
.76725 .11512 L
.76706 .1151 L
Mistroke
.7669 .11505 L
.76679 .115 L
.76672 .11492 L
.76671 .11482 L
.76672 .11472 L
.76677 .11462 L
.76683 .11454 L
.76688 .11448 L
.76692 .11444 L
.76693 .11443 L
.76692 .11442 L
.7669 .11443 L
.76689 .11445 L
.76689 .11447 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76686 .11444 L
.76684 .11441 L
.76682 .11439 L
.76683 .11438 L
.76687 .1144 L
.76693 .11444 L
.767 .11451 L
.76708 .11461 L
.76714 .11475 L
.76718 .11491 L
.76722 .11509 L
.76725 .11528 L
.76728 .11545 L
.7673 .11561 L
.76734 .11575 L
.7674 .11589 L
.76747 .11599 L
.76754 .11608 L
.76761 .11616 L
.76768 .11622 L
.76772 .11627 L
.76774 .11631 L
.76774 .11633 L
.76771 .11633 L
.76767 .11632 L
.76762 .1163 L
.76754 .11627 L
.76742 .11621 L
.76726 .11611 L
.7671 .11599 L
.76694 .11584 L
Mistroke
.7668 .11566 L
.7667 .11548 L
.76662 .11526 L
.76659 .11507 L
.76658 .11487 L
.7666 .1147 L
.76667 .11457 L
.76676 .11448 L
.76683 .11443 L
.7669 .11441 L
.76696 .11441 L
.767 .11442 L
.76702 .11443 L
.76701 .11444 L
.76698 .11444 L
.76692 .11444 L
.76683 .11443 L
.76672 .11443 L
.7666 .11444 L
.76647 .11447 L
.76634 .11452 L
.76618 .11457 L
.76603 .11463 L
.7659 .1147 L
.76578 .11479 L
.76568 .11488 L
.76562 .11496 L
.7656 .11504 L
.76564 .1151 L
.76571 .11514 L
.76583 .11516 L
.76596 .11516 L
.76611 .11512 L
.76626 .11506 L
.76639 .11498 L
.76651 .1149 L
.7666 .11481 L
.76669 .11472 L
.76678 .11465 L
.76685 .11458 L
.7669 .11453 L
.76693 .11449 L
.76694 .11446 L
.76694 .11444 L
.76692 .11443 L
.76692 .11444 L
.76697 .11445 L
.76703 .11447 L
.76709 .11448 L
.76711 .11447 L
Mistroke
.7671 .11445 L
.76704 .11445 L
.76691 .11445 L
.7667 .11447 L
.76641 .1145 L
.76604 .11452 L
.76558 .11455 L
.76506 .11456 L
.7645 .11457 L
.76393 .11457 L
.76334 .11457 L
.76276 .11455 L
.76225 .11453 L
.76184 .11452 L
.76157 .11454 L
.76145 .11457 L
.76145 .11462 L
.76157 .11467 L
.7618 .11473 L
.7621 .11479 L
.76245 .11484 L
.76282 .11487 L
.7632 .11489 L
.76356 .11488 L
.76388 .11486 L
.76417 .11482 L
.76443 .11478 L
.76464 .11473 L
.76483 .11469 L
.76499 .11469 L
.76512 .11473 L
.76523 .11482 L
.76531 .11496 L
.76537 .11512 L
.76541 .1153 L
.76545 .11549 L
.76549 .1157 L
.76554 .1159 L
.76558 .11605 L
.76559 .11614 L
.76558 .11616 L
.76556 .11613 L
.76552 .11603 L
.76547 .1159 L
.76542 .11573 L
.76538 .11553 L
.76535 .11535 L
.76534 .1152 L
.76534 .11506 L
.76534 .11496 L
Mistroke
.76532 .11488 L
.76527 .1148 L
.76518 .11472 L
.76511 .11466 L
.76504 .1146 L
.76499 .11454 L
.76496 .11449 L
.76494 .11446 L
.76493 .11444 L
.76492 .11442 L
.7649 .1144 L
.76489 .11439 L
.76488 .11438 L
.76488 .11438 L
.76489 .11439 L
.76489 .1144 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
Mistroke
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .11441 L
.7649 .1144 L
.7649 .11439 L
.76492 .11438 L
.76494 .11439 L
.76497 .11439 L
.76497 .11439 L
.76495 .1144 L
.76491 .11442 L
.76486 .11447 L
.7648 .11453 L
.76473 .11461 L
.76466 .11469 L
.76458 .11476 L
.7645 .11482 L
.76444 .11487 L
.76442 .1149 L
.76443 .11491 L
.76448 .1149 L
.76457 .11488 L
.76473 .11485 L
.76489 .1148 L
.76513 .11474 L
.7654 .11468 L
.76568 .11461 L
.76595 .11454 L
.76621 .11449 L
.76643 .11445 L
.76661 .11443 L
.76676 .11442 L
.76688 .11442 L
.76697 .11445 L
.76702 .11447 L
.76702 .11448 L
.767 .11448 L
.76697 .11448 L
.76693 .11448 L
.76691 .11448 L
.7669 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
.76689 .11448 L
Mistroke
.76689 .11448 L
.76689 .11448 L
.76688 .11447 L
.76685 .11444 L
.76682 .11441 L
.76679 .11437 L
.76678 .11436 L
.76679 .11437 L
.76683 .11442 L
.76692 .1145 L
.76704 .11463 L
.76719 .11479 L
.76738 .11498 L
.76759 .11519 L
.76782 .11542 L
.76806 .11564 L
.76829 .11588 L
.7685 .11612 L
.76869 .11635 L
.76882 .11653 L
.76888 .11666 L
.76886 .11671 L
.76877 .1167 L
.76863 .11662 L
.76849 .11651 L
.76837 .1164 L
.7683 .1163 L
.76824 .11623 L
.76819 .11616 L
.76814 .11611 L
.76807 .11604 L
.76795 .11596 L
.76778 .11587 L
.76759 .11578 L
.76739 .11569 L
.76715 .1156 L
.76688 .11551 L
.76662 .11543 L
.76635 .11535 L
.76609 .11529 L
.76584 .11523 L
.76563 .11519 L
.76548 .11515 L
.76536 .11514 L
.76534 .11517 L
.76538 .11522 L
.76546 .11526 L
.76552 .11527 L
.76556 .11524 L
.76555 .1152 L
Mistroke
.76551 .11514 L
.76543 .11506 L
.76539 .11502 L
.76535 .11497 L
.76533 .11495 L
.76536 .11494 L
.76547 .11497 L
.76565 .11505 L
.7659 .11516 L
.76621 .11532 L
.76658 .11552 L
.767 .11575 L
.76742 .11599 L
.76782 .11619 L
.76818 .11637 L
.76849 .11651 L
.76873 .11661 L
.76891 .11666 L
.76902 .11669 L
.76908 .11669 L
.76909 .11668 L
.76905 .11666 L
.76897 .11662 L
.76887 .11657 L
.76876 .11649 L
.76864 .11639 L
.76854 .11627 L
.76847 .11615 L
.76843 .11602 L
.76842 .11589 L
.76844 .11576 L
Mfstroke
.88038 .2655 m
.8803 .26555 L
.88024 .2656 L
.88024 .26567 L
.88031 .26577 L
.88042 .26588 L
.88057 .26596 L
.88076 .26599 L
.88095 .26602 L
.88113 .26603 L
.88128 .26601 L
.8814 .26596 L
.88149 .26591 L
.88154 .26585 L
.88157 .26584 L
.88159 .2659 L
s
.89827 .29422 m
.89822 .29424 L
.89811 .29412 L
.898 .29392 L
.89791 .29367 L
.89785 .29341 L
.89782 .29314 L
.8978 .29291 L
.89779 .29271 L
.89778 .29257 L
.89778 .29245 L
.89778 .29238 L
.89778 .29235 L
.89778 .29237 L
.89778 .29243 L
.89778 .29253 L
.89779 .29266 L
.89779 .29283 L
.8978 .29302 L
.89781 .2932 L
.89781 .29337 L
.89782 .29351 L
.89782 .29361 L
.89782 .29367 L
.89783 .29369 L
.89782 .29367 L
.89782 .2936 L
.89782 .29349 L
.8978 .29336 L
.89777 .29324 L
.89774 .29315 L
.89771 .2931 L
.89768 .29311 L
.89767 .29321 L
s
.90181 .30213 m
.90191 .30217 L
.90197 .30216 L
.90198 .30211 L
.90197 .30204 L
.90194 .30197 L
.9019 .3019 L
.90184 .30184 L
.90178 .3018 L
.90174 .30177 L
.90173 .30176 L
.90174 .30177 L
.90178 .30181 L
.90185 .30187 L
.90195 .30194 L
.90208 .30203 L
.90223 .30217 L
.90241 .30236 L
.90263 .30261 L
.90287 .30291 L
.90313 .30327 L
.9034 .30368 L
.90365 .30413 L
.90388 .30461 L
.90406 .30509 L
.9042 .30556 L
.90429 .30602 L
.90434 .30646 L
.90434 .30689 L
.90432 .30732 L
.90428 .30766 L
.90423 .30795 L
.90418 .30814 L
.90411 .3082 L
.90404 .30813 L
.90397 .30792 L
.9039 .3076 L
.90385 .30722 L
.90382 .3068 L
.90382 .30638 L
.90386 .30596 L
.9039 .30553 L
.90393 .3051 L
.90395 .30474 L
.90394 .30446 L
.9039 .30426 L
.90383 .30415 L
.90373 .30413 L
s
.57887 .03645 m
.57876 .0365 L
.57871 .03654 L
.57872 .03656 L
.57875 .03657 L
.57882 .03657 L
.57889 .03657 L
.57895 .03658 L
.57897 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57898 .03658 L
.57901 .03658 L
.57909 .03658 L
.57919 .03659 L
.57929 .03659 L
.57933 .03659 L
.5793 .03659 L
.57916 .03658 L
s
.55737 .03585 m
.55723 .03584 L
.55715 .03584 L
.55713 .03584 L
.55717 .03584 L
.5573 .03584 L
.55748 .03585 L
.55768 .03586 L
.55786 .03586 L
.55798 .03587 L
.55801 .03587 L
.55793 .03587 L
s
.53293 .03501 m
.53281 .03495 L
.53281 .03488 L
.53291 .03481 L
.53305 .03475 L
.53321 .03472 L
.53335 .03477 L
s
.71236 .09197 m
.71235 .09203 L
.7123 .09204 L
.71223 .092 L
.71221 .09194 L
.71226 .09187 L
.71234 .09181 L
s
.79322 .13616 m
.79327 .13602 L
.79323 .13587 L
.79312 .13575 L
.79299 .13567 L
.79286 .13566 L
.79277 .13573 L
s
.82019 .17521 m
.82024 .17517 L
.8202 .17507 L
.82011 .17491 L
.82001 .1748 L
.81989 .17478 L
.81977 .17478 L
.81967 .17476 L
.8196 .17474 L
.81956 .17471 L
.81952 .17467 L
.8195 .17462 L
.81952 .17455 L
.81948 .17451 L
.81942 .17451 L
.81934 .17452 L
.81923 .17453 L
.8191 .17452 L
.81895 .17447 L
.8188 .1744 L
.81864 .17431 L
.8185 .17425 L
.81834 .17419 L
.81817 .17415 L
.818 .17413 L
.81783 .17413 L
.81769 .17412 L
.81759 .17409 L
.81756 .17401 L
.81761 .17393 L
s
.79318 .14178 m
.79312 .14188 L
.79311 .14198 L
.79315 .14207 L
.79321 .14216 L
.79328 .14221 L
.79332 .14223 L
.79337 .1422 L
.79344 .14213 L
.79354 .14207 L
.79363 .14201 L
.79367 .14197 L
.79366 .14197 L
.79357 .14203 L
s
.7628 .11422 m
.76268 .11426 L
.76263 .11429 L
.76265 .11432 L
.7627 .11433 L
.76276 .11434 L
.76283 .11434 L
.76288 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76291 .11434 L
.76292 .11434 L
.76295 .11434 L
.76302 .11435 L
.76312 .11435 L
.76321 .11437 L
.76328 .11442 L
.76327 .11448 L
.76317 .11453 L
s
.75077 .11424 m
.75079 .11435 L
.75082 .11433 L
.75084 .11419 L
.75082 .11396 L
.75075 .11367 L
.75061 .11333 L
.75043 .11295 L
.75022 .11253 L
.75 .11209 L
.74978 .11166 L
.74956 .11123 L
.74935 .11081 L
.74915 .11042 L
.74897 .11007 L
.74881 .1098 L
.74868 .1096 L
.7486 .10949 L
.74856 .10946 L
.74859 .10948 L
.74866 .10955 L
.74878 .10962 L
.74893 .10968 L
.74909 .10971 L
.74927 .10972 L
.74947 .10973 L
.74968 .10973 L
.74987 .10972 L
.75006 .10968 L
.75022 .10962 L
.75037 .10955 L
.75049 .10951 L
.75055 .10948 L
.75059 .10948 L
.75062 .10954 L
s
.80545 .15289 m
.80541 .15288 L
.80549 .15301 L
.80566 .15324 L
.80588 .1535 L
.80606 .15371 L
.80612 .15381 L
s
.68064 .08018 m
.68073 .0803 L
.68082 .08036 L
.68089 .08037 L
.68094 .08034 L
.68095 .0803 L
.68095 .08026 L
.68096 .08023 L
.681 .0802 L
.68107 .08017 L
.68113 .08014 L
.68116 .08012 L
.68114 .08013 L
.68105 .08018 L
.68088 .08025 L
.68064 .08037 L
.68033 .08052 L
.67996 .08069 L
.67956 .08089 L
.67914 .08109 L
.67871 .0813 L
.67829 .0815 L
.67787 .0817 L
.67749 .0819 L
.67716 .08208 L
.6769 .08224 L
.67672 .08236 L
.67661 .08243 L
.67658 .08243 L
.67661 .08237 L
.67667 .08226 L
.67673 .0821 L
.67678 .08191 L
.67681 .08171 L
.67681 .0815 L
.6768 .08129 L
.6768 .08107 L
.67679 .08085 L
.67679 .08063 L
.67679 .08044 L
.67682 .0803 L
.6769 .08022 L
.67704 .0802 L
.67721 .08022 L
.67738 .08029 L
.67752 .08039 L
.67756 .08047 L
.67745 .08049 L
s
.50604 .03414 m
.50595 .03417 L
.50622 .03419 L
.50671 .03421 L
.50728 .03423 L
.50788 .03425 L
.50845 .03427 L
.50889 .03428 L
.50921 .03429 L
.50947 .0343 L
.5097 .03428 L
.5099 .03424 L
.51008 .03418 L
.51018 .03412 L
.51018 .03409 L
s
.42196 .04009 m
.422 .0401 L
.42236 .04017 L
.42297 .04026 L
.4237 .04035 L
.42439 .04041 L
.42493 .04046 L
.42521 .04048 L
s
.07383 .48739 m
.07369 .48747 L
.0737 .48735 L
.07381 .48712 L
.07395 .48682 L
.07409 .48651 L
.07419 .48625 L
.07424 .48606 L
.07428 .48594 L
.0743 .48591 L
.0743 .48593 L
.0743 .48597 L
.0743 .486 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
Mistroke
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48602 L
.0743 .48601 L
.07432 .48596 L
.07436 .48583 L
.07441 .48564 L
.07445 .48543 L
.07448 .48525 L
.07449 .48515 L
.07446 .48515 L
Mfstroke
.08033 .59909 m
.08046 .59907 L
.08056 .59897 L
.08062 .59882 L
.08064 .59868 L
.08062 .59856 L
.08059 .59847 L
.08054 .59841 L
.08051 .59838 L
.0805 .59837 L
.0805 .59837 L
.08049 .59837 L
.08048 .59837 L
.08045 .59837 L
.0804 .59838 L
.08037 .59838 L
.08035 .59838 L
.08036 .59838 L
.08042 .59837 L
.08053 .59837 L
s
.09582 .70188 m
.09584 .70194 L
.09582 .70187 L
.09579 .70171 L
.09576 .70152 L
.09571 .70137 L
.09567 .70127 L
.09562 .7012 L
.09557 .70116 L
.09553 .70112 L
.0955 .7011 L
.09548 .70111 L
.0955 .70117 L
.09557 .70127 L
.0957 .70141 L
.09591 .70159 L
.0962 .70179 L
.09655 .70202 L
.09697 .70226 L
.09743 .7025 L
.09792 .70274 L
.09842 .70297 L
.09893 .70318 L
.09941 .70336 L
.09983 .7035 L
.10021 .7036 L
.10052 .70365 L
.10075 .70366 L
.10091 .70364 L
.10099 .7036 L
.10102 .70355 L
.10101 .70352 L
.10098 .70351 L
.10093 .70351 L
.10089 .7035 L
.10084 .70347 L
.10079 .70341 L
.10075 .70333 L
.10071 .70323 L
.10067 .70313 L
.10064 .70306 L
.10062 .70307 L
.10065 .7032 L
s
.12633 .74507 m
.12643 .74519 L
.12644 .7452 L
.12641 .74514 L
.12637 .74506 L
.12631 .74496 L
.12625 .74484 L
.12618 .74474 L
.12611 .74466 L
.12605 .7446 L
.12597 .74453 L
.12587 .74442 L
.12576 .74424 L
.12565 .74402 L
.12553 .74379 L
.1254 .74361 L
.12525 .74352 L
.12513 .74355 L
s
.88183 .74523 m
.88194 .74532 L
.88202 .74554 L
.88208 .74583 L
.88214 .74613 L
.88218 .74637 L
.88213 .74651 L
s
.87264 .61937 m
.87263 .61946 L
.87268 .6194 L
.87277 .61927 L
.87291 .61912 L
.87308 .61897 L
.87326 .61891 L
.87344 .61895 L
.87364 .61902 L
.87385 .61907 L
.87407 .61911 L
.87429 .61913 L
.87449 .61913 L
.87468 .61912 L
.87485 .61907 L
.87499 .61903 L
.8751 .61896 L
.87517 .61888 L
.8752 .61879 L
.87519 .6187 L
.8752 .61862 L
.87523 .61856 L
.87528 .61852 L
.87534 .61849 L
.87541 .61848 L
.87548 .6185 L
.8755 .61857 L
s
.7486 .64158 m
.74857 .64146 L
.74864 .64147 L
.74879 .6416 L
.74897 .64179 L
.74915 .64199 L
.74928 .64214 L
.74935 .64216 L
s
.89917 .30807 m
.89923 .30807 L
.89915 .30807 L
.89897 .30807 L
.89873 .30807 L
.89851 .30807 L
.89839 .30807 L
.89836 .30807 L
.89837 .3081 L
.89839 .30815 L
.89842 .30824 L
.89844 .30835 L
.89844 .30846 L
.89842 .30855 L
.89837 .30859 L
.89833 .30856 L
s
.87416 .26619 m
.87405 .26609 L
.87402 .26608 L
.87401 .26614 L
.87397 .26627 L
.87388 .26645 L
.87372 .26668 L
.87353 .26693 L
.87333 .26721 L
.87314 .2675 L
.87299 .26781 L
.87288 .26813 L
.87282 .26842 L
.87279 .26866 L
.87282 .26882 L
.8729 .26887 L
.87301 .26884 L
.87316 .26876 L
.87332 .26866 L
.87346 .26858 L
.87354 .26849 L
.87355 .26842 L
s
.86457 .27146 m
.86455 .27135 L
.86468 .27127 L
.86495 .2712 L
.86529 .27116 L
.86568 .27114 L
.86608 .27116 L
.86646 .27121 L
.86678 .27131 L
.86702 .27146 L
.86718 .27168 L
.86729 .27192 L
.86738 .27215 L
.86745 .27234 L
.86752 .27246 L
.86757 .2725 L
.86758 .27244 L
.86757 .27233 L
.86754 .27216 L
.86753 .27195 L
.86753 .2717 L
.86759 .27147 L
.8677 .27125 L
.86787 .27105 L
.86811 .27086 L
.86837 .27069 L
.86863 .27055 L
.86889 .27044 L
.8691 .27037 L
.86931 .27035 L
.86947 .27035 L
.8696 .27039 L
.86972 .27047 L
.86981 .27058 L
.86985 .27072 L
.86985 .27085 L
.86981 .27095 L
.86972 .27102 L
.86962 .27104 L
.86953 .27097 L
s
.75188 .1086 m
.75188 .10864 L
.7521 .10871 L
.75249 .10887 L
.75297 .1091 L
.75349 .10935 L
.75402 .1096 L
.7545 .1098 L
.75485 .10993 L
.75511 .11 L
.75531 .11002 L
.75548 .11001 L
.75563 .11 L
.75578 .10999 L
.75594 .10997 L
.75612 .10996 L
.75631 .10996 L
.75649 .10997 L
.75666 .10997 L
.75682 .10998 L
.75698 .10999 L
.75713 .10999 L
.75723 .10998 L
.75726 .10996 L
.7572 .10994 L
.75703 .10993 L
s
.47448 .03336 m
.47448 .0334 L
.47458 .03344 L
.47476 .03344 L
.47498 .0334 L
.4752 .03333 L
.47543 .03327 L
.47564 .03322 L
.47582 .03317 L
.47595 .03318 L
.47598 .03325 L
s
.46918 .04203 m
.4691 .04207 L
.46909 .04205 L
.46913 .042 L
.4692 .04193 L
.46928 .04186 L
.46934 .0418 L
.46937 .04177 L
.46937 .04177 L
.46937 .04176 L
.46935 .04171 L
.46931 .04161 L
.46925 .04145 L
.46918 .04129 L
.46911 .04116 L
.46906 .0411 L
.46906 .04112 L
s
.35891 .30775 m
.35891 .30778 L
.35902 .30801 L
.35922 .3084 L
.35948 .30891 L
.35969 .30946 L
.35979 .31001 L
.3598 .31056 L
.3598 .31105 L
.3598 .31147 L
.35979 .31179 L
.35979 .31199 L
.35979 .31207 L
.35979 .31201 L
.35979 .3119 L
.3598 .3117 L
.3598 .31143 L
.3598 .3111 L
.3598 .31075 L
.3598 .31043 L
.3598 .31017 L
.35981 .30999 L
.35981 .30987 L
.35981 .3098 L
.35981 .30976 L
.35981 .30974 L
.35981 .30976 L
.35981 .3098 L
.35981 .30985 L
.35981 .30989 L
.35981 .30994 L
.3598 .31002 L
.3598 .31015 L
.3598 .31029 L
.3598 .31042 L
.3598 .31052 L
.3598 .31063 L
.3598 .31067 L
.3598 .31071 L
.3598 .31077 L
.3598 .31084 L
.3598 .31098 L
.3598 .31116 L
.3598 .31137 L
.3598 .31153 L
.3598 .31164 L
.3598 .3117 L
.35979 .31181 L
.35979 .31195 L
.35979 .31213 L
Mistroke
.35979 .31231 L
.35979 .31248 L
.35979 .31262 L
.35978 .31273 L
.35978 .3128 L
.35978 .31281 L
.35978 .31277 L
.35978 .31271 L
.35979 .31268 L
.35979 .31268 L
.35978 .31273 L
.35978 .3128 L
.35978 .31287 L
.35978 .3129 L
.35978 .31288 L
.35978 .31278 L
.35979 .3126 L
.35979 .31234 L
.35979 .31199 L
.35979 .31159 L
.3598 .31115 L
.3598 .31068 L
.3598 .31021 L
.35981 .30975 L
.35981 .3093 L
.35982 .30888 L
.35982 .30851 L
.35982 .30821 L
.35982 .30799 L
.35982 .30782 L
.35982 .30772 L
.35982 .30768 L
.35982 .30771 L
.35982 .30781 L
.35982 .30796 L
.35982 .30816 L
.35982 .30843 L
.35982 .30878 L
.35981 .30919 L
.35981 .30963 L
.35981 .3101 L
.3598 .31057 L
.3598 .31104 L
.35979 .31151 L
.35979 .31193 L
.35979 .31229 L
.35979 .31257 L
.35978 .31275 L
.35978 .31285 L
.35978 .31285 L
Mistroke
.35979 .3128 L
.35979 .31271 L
.35979 .31263 L
.35979 .31256 L
.35979 .31252 L
.35979 .31252 L
.35979 .31252 L
.35977 .31252 L
.35974 .31253 L
.35971 .31255 L
.35967 .31257 L
.35965 .3126 L
.35966 .31262 L
.35971 .31264 L
.35981 .31266 L
.35994 .31267 L
.36012 .31267 L
.36032 .31266 L
.36055 .31264 L
.36079 .31263 L
.36103 .31262 L
.36127 .31262 L
.3615 .31261 L
.36171 .3126 L
.3619 .3126 L
.36204 .3126 L
.36215 .31259 L
.36221 .31259 L
.36222 .31259 L
.36221 .31259 L
.36217 .31259 L
.36213 .31259 L
.3621 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.36209 .31259 L
.3621 .31257 L
.36213 .31252 L
.36217 .31246 L
.3622 .3124 L
.36222 .31238 L
Mistroke
.36221 .31241 L
.36216 .31249 L
Mfstroke
.29508 .26793 m
.29524 .26794 L
.29531 .26788 L
.29534 .26782 L
.29534 .26777 L
.29533 .26775 L
.29529 .26774 L
.29525 .26774 L
.29522 .26774 L
.29521 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.2952 .26774 L
.29519 .26774 L
.29516 .26774 L
.29512 .26774 L
.29508 .26774 L
.29507 .26774 L
.29508 .26774 L
.29513 .26774 L
.29522 .26774 L
.29536 .26774 L
.29554 .26774 L
.29575 .26774 L
.29597 .26772 L
.29622 .26767 L
.29646 .2676 L
.2967 .26753 L
.29694 .2675 L
.29715 .26752 L
.29734 .26761 L
.29749 .26779 L
.2976 .26805 L
.29766 .26841 L
.29767 .26882 L
.29766 .26927 L
.29762 .26973 L
.29758 .27019 L
.29755 .27066 L
.29754 .27112 L
.29754 .27152 L
.29754 .27187 L
.29754 .27214 L
.29754 .27233 L
.29754 .27242 L
.29754 .27244 L
.29754 .27239 L
Mistroke
.29754 .27231 L
.29754 .27222 L
.29754 .27216 L
.29754 .27214 L
.29754 .27216 L
.29754 .27218 L
.29754 .2722 L
.29754 .27222 L
.29754 .27224 L
.29754 .27226 L
.29754 .27227 L
.29754 .2723 L
.29754 .27232 L
.29757 .27234 L
.29765 .27235 L
.29776 .27236 L
.29787 .27235 L
.29795 .27234 L
.29798 .27233 L
.29792 .27233 L
Mfstroke
.1774 .19178 m
.17751 .19184 L
.17756 .19195 L
.17756 .19207 L
.17752 .19219 L
.17747 .19228 L
.17741 .19234 L
.17733 .1924 L
.17724 .19247 L
.17716 .19253 L
.1771 .19257 L
.17706 .19256 L
.17707 .19249 L
s
.20002 .1742 m
.20012 .17413 L
.2001 .17421 L
.20001 .17438 L
.19986 .1746 L
.19968 .17482 L
.19953 .17495 L
.19943 .17493 L
s
.26448 .13321 m
.26454 .13328 L
.26456 .1333 L
.26454 .13329 L
.2645 .13323 L
.26446 .13314 L
.26443 .13303 L
.26442 .13293 L
.26441 .13283 L
.26441 .13274 L
.26441 .13266 L
.26441 .13261 L
.26441 .13257 L
.26442 .13261 L
.26447 .13267 L
.26456 .13272 L
.26468 .13269 L
s
.06998 .51667 m
.06999 .51675 L
.07005 .51675 L
.07018 .51673 L
.07037 .51671 L
.07065 .51672 L
.07096 .51675 L
.0713 .5168 L
.07167 .51682 L
.07202 .51683 L
.07237 .51683 L
.07269 .51682 L
.07297 .51681 L
.07318 .5168 L
.0733 .51679 L
.07334 .51678 L
.07334 .51677 L
.07332 .51678 L
.07328 .51678 L
.07324 .51678 L
.0732 .51678 L
.07318 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51678 L
.07317 .51677 L
.07318 .51674 L
.0732 .51666 L
.07325 .51655 L
.07329 .51644 L
.07332 .51636 L
.07332 .51634 L
.07328 .51642 L
s
.07199 .54575 m
.0721 .54586 L
.07216 .54588 L
.07219 .54583 L
.07217 .54575 L
.07214 .54565 L
.0721 .54556 L
.07207 .5455 L
.07206 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07209 .54548 L
.07224 .54562 L
.07243 .54579 L
.07266 .546 L
.07291 .54623 L
.07318 .54647 L
.07347 .54671 L
.07376 .54695 L
.07403 .54718 L
.07425 .5474 L
.07442 .54758 L
.07453 .54774 L
.07457 .54784 L
.07455 .54791 L
.07449 .54793 L
.0744 .54792 L
.07433 .54789 L
.07426 .54785 L
.07421 .54782 L
.07419 .54781 L
.07419 .5478 L
.07419 .5478 L
.07421 .5478 L
.07426 .5478 L
.07432 .54779 L
.0744 .54779 L
.07448 .54778 L
.07455 .54778 L
.07461 .54778 L
.07465 .54777 L
.07467 .54777 L
.07465 .54778 L
.07462 .54778 L
.0746 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
Mistroke
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07459 .54778 L
.07461 .54779 L
.07464 .54782 L
.07468 .54786 L
.07471 .54789 L
.07473 .54791 L
.07472 .5479 L
.07466 .54785 L
.07456 .54776 L
.07441 .54762 L
.07422 .54744 L
.07399 .54724 L
.07375 .54701 L
.07348 .54677 L
.07323 .54653 L
.07297 .54628 L
.07272 .54605 L
.07248 .54584 L
.07228 .54565 L
.07211 .5455 L
.072 .54539 L
.07193 .54534 L
.07191 .54532 L
.07192 .54533 L
.07196 .54537 L
.072 .54541 L
.07204 .54544 L
.07205 .54545 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
Mistroke
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54546 L
.07205 .54545 L
.07204 .54544 L
.07201 .54541 L
.07197 .54537 L
.07193 .54534 L
.07191 .54532 L
.07193 .54533 L
.07198 .54538 L
.07208 .54548 L
.07223 .54562 L
.07242 .54579 L
.07265 .546 L
.0729 .54623 L
.07316 .54647 L
.07342 .54671 L
.07367 .54695 L
.07393 .54719 L
.07416 .54741 L
.07437 .54755 L
.07454 .54759 L
.07466 .54752 L
.07473 .54737 L
Mistroke
.07476 .5472 L
.07474 .54703 L
.07467 .54694 L
Mfstroke
.10305 .73396 m
.10311 .73399 L
.1031 .73388 L
.10306 .7337 L
.103 .7335 L
.10294 .73336 L
.10289 .73335 L
.10286 .73349 L
.10283 .73381 L
.10281 .73426 L
.1028 .73477 L
.10278 .73535 L
.10277 .73583 L
.10275 .73629 L
.10274 .73678 L
.10273 .7372 L
.10272 .73765 L
.10272 .73806 L
.10272 .73835 L
.10272 .7385 L
.10272 .73857 L
.10272 .7386 L
.10273 .7386 L
.10273 .73856 L
.10274 .73849 L
.10274 .73843 L
.10275 .73831 L
.10276 .73811 L
.10276 .73783 L
.10277 .73747 L
.10277 .73703 L
.10278 .73655 L
.10279 .73603 L
.1028 .73553 L
.10281 .73502 L
.10282 .73453 L
.10283 .73407 L
.10283 .73366 L
.10284 .73334 L
.10284 .73311 L
.10285 .73299 L
.10285 .73295 L
.10285 .73298 L
.10285 .73305 L
.10284 .73313 L
.10284 .73319 L
.10284 .73321 L
.10284 .73319 L
.10285 .73315 L
.10285 .73309 L
Mistroke
.10286 .73304 L
.10285 .73302 L
.10285 .73305 L
.10284 .73315 L
.10282 .73333 L
.10281 .73361 L
.10279 .73398 L
.10278 .73443 L
.10277 .73491 L
.10275 .73543 L
.10274 .73588 L
.10272 .73635 L
.10271 .73677 L
.1027 .73723 L
.10269 .73764 L
.10268 .73794 L
.10268 .73815 L
.10269 .73826 L
.10269 .73831 L
.10271 .7383 L
.10271 .73826 L
.10272 .73819 L
.10272 .73816 L
.10272 .73815 L
.10273 .73815 L
.10274 .73816 L
.10275 .7382 L
.10277 .73826 L
.10278 .73834 L
.10279 .73842 L
.10278 .73846 L
.10276 .73845 L
.10273 .73837 L
.1027 .73822 L
.10267 .73799 L
.10264 .73768 L
.10262 .73728 L
.10261 .73682 L
.10261 .73633 L
.10261 .73579 L
.10262 .73527 L
.10263 .73467 L
.10265 .7342 L
.10267 .73371 L
.1027 .7333 L
.10274 .73302 L
.10278 .73291 L
.10281 .73301 L
.10283 .73329 L
.10285 .73372 L
Mistroke
.10285 .73422 L
.10284 .73476 L
.10282 .73528 L
.10279 .7358 L
.10278 .73626 L
.10277 .73669 L
.10276 .73715 L
.10275 .7376 L
.10272 .73797 L
.10266 .73825 L
.10258 .73845 L
.1025 .73858 L
.10243 .73871 L
Mfstroke
.51843 .96185 m
.51846 .96182 L
.51833 .96182 L
.51814 .96185 L
.51793 .96189 L
.51775 .96194 L
.51767 .962 L
s
.73177 .89518 m
.73187 .89513 L
.73192 .8951 L
.73193 .89511 L
.73192 .89516 L
.73187 .89521 L
.7318 .89527 L
.73171 .89532 L
.73162 .89536 L
.73155 .89539 L
.73152 .89541 L
.73157 .8954 L
.7317 .89535 L
s
.85924 .79698 m
.8594 .79693 L
.8594 .79696 L
.8594 .797 L
.85938 .79698 L
.85945 .79687 L
.8596 .79664 L
.85978 .79633 L
.85997 .79598 L
.8602 .79563 L
.86046 .79528 L
.8607 .79492 L
.86088 .79456 L
.86103 .79419 L
.86113 .79383 L
.86115 .79351 L
.86108 .79328 L
.86094 .79312 L
.86077 .79304 L
.86058 .79301 L
.86039 .79304 L
.86022 .79308 L
.86011 .79311 L
.86005 .79311 L
.86001 .7931 L
.85997 .79306 L
.85994 .793 L
.85991 .79296 L
.85989 .79292 L
.8599 .79286 L
.85996 .79279 L
.86005 .79271 L
.86018 .79263 L
.86034 .79256 L
.86051 .79247 L
.86064 .79244 L
.86074 .79244 L
.86078 .79248 L
.86082 .79254 L
.86086 .79264 L
.86091 .79276 L
.86098 .79285 L
.86106 .79286 L
.86116 .79275 L
s
.86276 .75883 m
.86283 .75872 L
.86292 .75873 L
.86301 .7588 L
.86305 .75887 L
.86302 .75893 L
.86289 .75897 L
.86266 .75903 L
.86232 .75909 L
.86187 .75916 L
.86135 .75923 L
.86078 .75931 L
.86018 .75937 L
.85957 .75943 L
.85901 .75948 L
.85844 .75954 L
.8579 .75959 L
.85743 .75963 L
.85706 .75966 L
.8568 .75968 L
.85666 .75969 L
.85663 .75969 L
.85667 .75969 L
.85674 .75968 L
.85682 .75967 L
.85687 .75967 L
.85687 .75967 L
.85685 .75967 L
.85686 .75967 L
.8569 .75967 L
.85698 .75966 L
.85709 .75965 L
s
.93284 .5443 m
.93285 .5444 L
.93283 .54486 L
.93279 .54555 L
.93276 .54632 L
.93275 .54703 L
.93275 .54755 L
.93277 .54781 L
s
.77494 .12091 m
.775 .12103 L
.77503 .1211 L
.77504 .12112 L
.77503 .1211 L
.77502 .12106 L
.775 .12101 L
.775 .12099 L
.775 .12098 L
.775 .12099 L
.77502 .12101 L
.77504 .12106 L
.77508 .12113 L
.77516 .1212 L
.77528 .12124 L
.77542 .12125 L
.77553 .1212 L
s
.08891 .66413 m
.08896 .66411 L
.08897 .66382 L
.08895 .66335 L
.0889 .6628 L
.08883 .66227 L
.08874 .66185 L
.08867 .66164 L
s
.1005 .72145 m
.10056 .72143 L
.1006 .72152 L
.1006 .7217 L
.10057 .72188 L
.10053 .72204 L
.10048 .72215 L
.10044 .7222 L
.10041 .72216 L
.10038 .72206 L
.10034 .72192 L
.1003 .72168 L
.10024 .72137 L
.10017 .72103 L
.10012 .72076 L
.10011 .72063 L
s
.12851 .75634 m
.12859 .75631 L
.1286 .75626 L
.12856 .7562 L
.12843 .75612 L
.12824 .75605 L
.12802 .75597 L
.12779 .75586 L
.12756 .75569 L
.12732 .75551 L
.12706 .75535 L
.12682 .75527 L
.12669 .75528 L
s
.15441 .78582 m
.15431 .78569 L
.15423 .78562 L
.15417 .78558 L
.15415 .78556 L
.15415 .78555 L
.15415 .78556 L
.15415 .78558 L
.15415 .7856 L
.15415 .78561 L
.15415 .78561 L
.15415 .78561 L
.15414 .78561 L
.15413 .78561 L
.1541 .78561 L
.15406 .78561 L
.15402 .78561 L
.154 .78561 L
.15401 .78561 L
.15407 .78561 L
.15417 .7856 L
.15433 .7856 L
.15452 .78559 L
.15475 .78558 L
.15501 .78557 L
.15528 .78555 L
.15554 .78554 L
.15581 .78553 L
.15607 .78552 L
.15631 .78551 L
.15652 .7855 L
.15669 .78549 L
.1568 .78548 L
.15687 .78548 L
.15689 .78548 L
.15687 .78548 L
.15684 .78548 L
.15679 .78548 L
.15676 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
Mistroke
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78549 L
.15674 .78548 L
.15672 .78541 L
.15666 .78527 L
.15659 .78508 L
.1565 .7849 L
.15642 .78476 L
.15636 .78469 L
.15637 .78478 L
Mfstroke
.16731 .81028 m
.16732 .81019 L
.16726 .80981 L
.16716 .80926 L
.16707 .80862 L
.16699 .80793 L
.16694 .80723 L
.16692 .80656 L
.16689 .80591 L
.16683 .8053 L
.16673 .80475 L
.16661 .80433 L
.16649 .80407 L
.16638 .80402 L
s
.48892 .96513 m
.48908 .96514 L
.48907 .96519 L
.48895 .96527 L
.4888 .96537 L
.48868 .96544 L
.48859 .96549 L
.48852 .96552 L
.48846 .96552 L
.48843 .96552 L
.48839 .9655 L
.48838 .96547 L
.48838 .96543 L
.4884 .96537 L
.48841 .96528 L
.4884 .96518 L
.48835 .96509 L
.48826 .96503 L
.48812 .965 L
.48796 .96502 L
.48779 .96506 L
.48764 .96511 L
.48753 .96516 L
.48744 .96519 L
.48736 .96523 L
.48726 .96525 L
.48715 .96527 L
.48706 .96529 L
.48703 .96533 L
.48706 .96535 L
.48714 .96537 L
.48724 .96536 L
.48735 .96535 L
.48741 .96533 L
.48743 .9653 L
.4874 .96527 L
.48734 .96523 L
.48726 .9652 L
.48715 .96521 L
.48704 .96524 L
.48696 .96528 L
.4869 .96533 L
.48687 .96538 L
.4869 .96544 L
s
.53859 .92513 m
.53869 .92507 L
.53875 .92503 L
.53877 .92501 L
.53878 .92501 L
.53879 .92501 L
.53878 .92503 L
.53876 .92506 L
.53873 .92509 L
.5387 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.53869 .9251 L
.5387 .92507 L
.53873 .92504 L
.53876 .92501 L
.53878 .92501 L
.53875 .92502 L
.53865 .92507 L
s
.873 .76417 m
.87286 .76416 L
.8726 .76434 L
.87225 .76466 L
.87186 .76504 L
.87149 .76544 L
.87114 .76585 L
.8708 .7663 L
.87054 .76675 L
.87028 .7672 L
.87008 .76764 L
.86992 .76805 L
.86981 .76842 L
.86974 .76872 L
.86968 .76896 L
.86964 .76915 L
.86963 .7693 L
.86965 .76942 L
.86967 .76952 L
.86969 .7696 L
.8697 .76965 L
.86974 .76965 L
.86979 .7696 L
.86986 .76949 L
.86993 .76935 L
.86997 .76925 L
.87 .7692 L
.87001 .7692 L
.87 .76924 L
s
.86382 .78341 m
.86373 .78368 L
.86363 .78386 L
.86354 .78397 L
.86347 .78403 L
.86342 .78404 L
.86345 .78397 L
.86354 .78389 L
s
.37844 .93936 m
.37842 .93934 L
.3785 .93936 L
.37864 .93941 L
.37878 .93948 L
.37891 .93955 L
.37903 .93961 L
.37914 .93967 L
.37921 .93972 L
.37926 .93976 L
.3793 .93979 L
.37933 .93982 L
.37936 .93984 L
.37937 .93985 L
.37935 .93984 L
.37936 .93984 L
.37934 .93983 L
.37931 .9398 L
.37926 .93976 L
.3792 .9397 L
.37915 .93966 L
.37913 .93964 L
.37913 .93965 L
.37917 .93969 L
.37924 .93974 L
.37933 .93981 L
.37943 .93989 L
.37956 .93997 L
.37972 .94005 L
.37991 .94013 L
.38011 .94021 L
.38032 .94029 L
.38047 .94036 L
.38053 .94039 L
s
.25836 .8952 m
.25839 .89512 L
.25852 .89512 L
.25869 .89518 L
.25885 .89526 L
.25898 .89534 L
.2591 .89543 L
.25926 .89555 L
.25945 .89571 L
.25963 .89588 L
.25979 .89604 L
.25987 .89615 L
.25982 .89616 L
s
.11198 .67801 m
.11206 .67787 L
.11206 .67784 L
.11201 .67789 L
.11196 .67798 L
.11191 .67809 L
.11187 .67818 L
.11185 .67825 L
.11185 .67828 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11185 .67829 L
.11186 .67829 L
.11194 .67831 L
.11211 .67837 L
s
.07 .52832 m
.06993 .52808 L
.06991 .52792 L
.06993 .52773 L
.06999 .52745 L
.0701 .52706 L
.07024 .52654 L
.07041 .52594 L
.07061 .52531 L
.07083 .52461 L
.07107 .52387 L
.07134 .52319 L
.0716 .52257 L
.07185 .52204 L
.07211 .52164 L
.07235 .52136 L
.07257 .52122 L
.07276 .52118 L
.07292 .52123 L
.07305 .52132 L
.07312 .52141 L
.07315 .52148 L
.07313 .52152 L
.07309 .52153 L
.07304 .52154 L
.07301 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07299 .52154 L
.07297 .52154 L
Mistroke
.07294 .52154 L
.0729 .52154 L
.07286 .52154 L
.07284 .52154 L
.07285 .52154 L
.07291 .52154 L
.07302 .52154 L
.07317 .52153 L
.07337 .52153 L
.07361 .52152 L
.07387 .52152 L
.07414 .52151 L
.07441 .5215 L
.07469 .52149 L
.07495 .52149 L
.0752 .52148 L
.07541 .52148 L
.07558 .52147 L
.0757 .52147 L
.07576 .52147 L
.07579 .52147 L
.07578 .5215 L
.07577 .52155 L
.07576 .52163 L
.07576 .5217 L
.07575 .52174 L
.0757 .52171 L
.07561 .52161 L
.07548 .52142 L
.07532 .52115 L
.07516 .52079 L
.07501 .52037 L
.07488 .51991 L
.07479 .51942 L
.07486 .51893 L
.07485 .51844 L
.07486 .51796 L
.0749 .51755 L
.07495 .51722 L
.07503 .51705 L
.07516 .51702 L
.0753 .51711 L
.07545 .51726 L
.07558 .51741 L
.07567 .51748 L
Mfstroke
.08277 .46972 m
.08285 .46969 L
.08288 .46992 L
.08287 .47025 L
.08284 .47067 L
.08279 .4711 L
.08273 .47151 L
.08269 .47187 L
.08266 .47214 L
.08266 .47231 L
.08266 .47234 L
.08266 .47228 L
.08266 .47213 L
.08267 .47189 L
.08268 .47156 L
.08269 .4712 L
.0827 .47084 L
.08271 .47046 L
.08272 .47013 L
.08273 .46986 L
.08274 .46966 L
.08274 .46951 L
.08275 .46942 L
.08275 .46937 L
.08275 .46938 L
.08275 .46942 L
.08274 .46948 L
.08274 .46955 L
.08274 .46962 L
.08273 .46967 L
.08273 .4697 L
.08273 .46974 L
.08273 .46978 L
.08273 .46979 L
.08273 .46977 L
.08273 .46971 L
.08273 .46965 L
.08273 .46962 L
.08273 .46965 L
.08273 .46975 L
.08272 .46991 L
.08272 .47011 L
.08271 .47032 L
.0827 .47053 L
.0827 .47076 L
.08269 .47096 L
.08269 .47112 L
.08269 .47128 L
.08268 .47144 L
.08266 .47161 L
Mistroke
.08262 .47177 L
.08256 .47192 L
.08249 .47202 L
.08243 .47205 L
.08242 .47198 L
.08245 .47183 L
Mfstroke
.0908 .46439 m
.09092 .46444 L
.09097 .46451 L
.09098 .46459 L
.09096 .46466 L
.09092 .46469 L
.09088 .4647 L
.09084 .4647 L
.0908 .4647 L
.09077 .4647 L
.09073 .4647 L
.09069 .4647 L
.09065 .4647 L
.09062 .4647 L
.0906 .4647 L
.09062 .4647 L
.09068 .4647 L
.0908 .4647 L
s
.14363 .51964 m
.14362 .51951 L
.14362 .51945 L
.14362 .51944 L
.14362 .51945 L
.14361 .51949 L
.14361 .51953 L
.14361 .51956 L
.14361 .51957 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51958 L
.14361 .51957 L
.14363 .51952 L
.14365 .51942 L
.14368 .51926 L
.14369 .51906 L
.14367 .51884 L
.14361 .51865 L
.1435 .51856 L
s
.32839 .70397 m
.32832 .70397 L
.32835 .70396 L
.32848 .70396 L
.32867 .70395 L
.32891 .70394 L
.32913 .70392 L
.32929 .70392 L
.32934 .70392 L
.32927 .70392 L
.32912 .70393 L
.32894 .70397 L
.32879 .70403 L
.32874 .70412 L
s
.43192 .59865 m
.43202 .59865 L
.43208 .59865 L
.4321 .59865 L
.43209 .59865 L
.43205 .59865 L
.43201 .59865 L
.43198 .59865 L
.43198 .59868 L
.43201 .59874 L
.43205 .59881 L
.43209 .59888 L
.43211 .59891 L
.43209 .59889 L
.43204 .59879 L
s
.89815 .30033 m
.89822 .3005 L
.89822 .30063 L
.89817 .30074 L
.89808 .3008 L
.898 .30088 L
.89797 .30097 L
.89799 .30107 L
.89805 .30121 L
.89812 .30139 L
.89818 .30159 L
.89821 .30177 L
.89819 .30189 L
.89813 .30192 L
s
.89273 .29378 m
.89287 .29378 L
.89287 .29371 L
.89276 .29356 L
.89259 .29329 L
.89242 .29292 L
.89229 .29246 L
.89221 .29194 L
.89216 .29143 L
.89214 .29091 L
.89212 .29045 L
.89211 .29006 L
.89209 .28977 L
.89209 .28957 L
.89208 .28945 L
.89208 .28946 L
.89209 .28956 L
.8921 .28975 L
.89211 .29003 L
.89212 .29038 L
.89213 .29073 L
.89215 .29105 L
.89216 .29131 L
.89216 .29149 L
.89217 .29159 L
.89217 .29161 L
.89216 .29159 L
.89215 .29154 L
.89211 .29147 L
.89206 .29139 L
.892 .29131 L
.89194 .29125 L
.89191 .29119 L
.89194 .29117 L
.89203 .29122 L
s
.67817 .08971 m
.67798 .08971 L
.67784 .08963 L
.67773 .0895 L
.67765 .08937 L
.67758 .08924 L
.67753 .08915 L
.67749 .08913 L
.67741 .08915 L
.67733 .08925 L
.67725 .08939 L
.67722 .08957 L
.67721 .08973 L
.67725 .08984 L
.6773 .08988 L
.67735 .08985 L
.67738 .08974 L
.6774 .08958 L
.67743 .08938 L
.67746 .08914 L
.67748 .08885 L
.67752 .08857 L
.67763 .0884 L
s
.74269 .16235 m
.7427 .16233 L
.74261 .16217 L
.74248 .16192 L
.74232 .16162 L
.74219 .16134 L
.74211 .16112 L
.74209 .16098 L
.74208 .16088 L
.74208 .16081 L
.74208 .16077 L
.74208 .16077 L
.74208 .16081 L
.74208 .16091 L
.74209 .16103 L
.74209 .16117 L
.74209 .16131 L
.7421 .16141 L
.7421 .16146 L
.7421 .16144 L
.74209 .16135 L
.74209 .16118 L
.74208 .16095 L
.74208 .1607 L
.74205 .16046 L
.74201 .16023 L
.74195 .16004 L
.74189 .15989 L
.74184 .1598 L
.74183 .15978 L
s
.64841 .10591 m
.64849 .10597 L
.64844 .10611 L
.64835 .10627 L
.64824 .10642 L
.64816 .10655 L
.64814 .10661 L
.64818 .10659 L
s
.66091 .11333 m
.66083 .11352 L
.66056 .11377 L
.66016 .11407 L
.65968 .1144 L
.65915 .11477 L
.65863 .11516 L
.65815 .11557 L
.65772 .11599 L
.65733 .11638 L
.65699 .11671 L
.65673 .11697 L
.65654 .11718 L
.65643 .11731 L
.65639 .11739 L
.65642 .11745 L
.65648 .11754 L
s
.65662 .12602 m
.6565 .12596 L
.65637 .12575 L
.65623 .12545 L
.65608 .12511 L
.65592 .12476 L
.65575 .12449 L
.65558 .12427 L
.65541 .12415 L
.65524 .12411 L
.6551 .12413 L
.65497 .1242 L
.65486 .12436 L
.65477 .12454 L
.65472 .12479 L
.6547 .12507 L
.65471 .12535 L
.65475 .12562 L
.65483 .12583 L
.65495 .12598 L
.65512 .12607 L
.65533 .12609 L
.65557 .12606 L
.65581 .12601 L
.65605 .12598 L
.65626 .12596 L
.65645 .12594 L
.65662 .12594 L
.65676 .12595 L
.65685 .12595 L
.65691 .12595 L
.65692 .12595 L
.65691 .12595 L
.6569 .12592 L
.65691 .12585 L
.65695 .12575 L
.657 .12566 L
.65703 .12561 L
.65701 .12565 L
.65692 .12578 L
s
.65261 .13234 m
.65251 .1325 L
.65247 .13255 L
.6525 .13252 L
.65256 .13243 L
.65263 .13232 L
.6527 .13223 L
.65276 .13215 L
.6528 .13207 L
.65283 .13201 L
.65284 .13198 L
.65281 .132 L
.65275 .13209 L
.65265 .13226 L
.6525 .1325 L
.65233 .13282 L
.65213 .13319 L
.65192 .1336 L
.65171 .13404 L
.65149 .13447 L
.65129 .1349 L
.65109 .13532 L
.65091 .13571 L
.65076 .13605 L
.65064 .13632 L
.65058 .13651 L
.65055 .13662 L
.65055 .13665 L
.65057 .13661 L
.65059 .13652 L
.65059 .13642 L
.65058 .13633 L
.65057 .13629 L
.65057 .1363 L
.65062 .13634 L
.6507 .13643 L
.65083 .13656 L
.65099 .13672 L
.65118 .13691 L
.6514 .13713 L
.65162 .13735 L
.65184 .13758 L
.65207 .13781 L
.65232 .13804 L
.65256 .13827 L
.6528 .13848 L
.653 .13864 L
.65314 .13872 L
.6532 .13869 L
s
.42708 .07944 m
.42701 .0795 L
.42684 .07978 L
.4266 .08017 L
.42635 .08054 L
.42616 .08082 L
.42607 .08095 L
.42611 .08093 L
s
.43133 .0406 m
.43147 .04055 L
.43151 .04053 L
.43148 .04055 L
.4314 .04058 L
.43131 .04061 L
.43124 .04064 L
.43119 .04065 L
.43116 .04065 L
.43113 .04065 L
.43109 .04065 L
.43106 .04065 L
.43104 .04065 L
.43105 .04065 L
.4311 .04065 L
.43119 .04066 L
.43133 .04066 L
.4315 .04066 L
.4317 .04067 L
.43192 .04068 L
.43215 .04068 L
.43239 .04069 L
.43263 .0407 L
.43286 .0407 L
.43307 .04071 L
.43325 .04072 L
.43339 .04072 L
.43349 .04072 L
.43355 .04072 L
.43356 .04073 L
.43352 .04075 L
.43342 .04079 L
.43329 .04083 L
.43313 .04085 L
.433 .04084 L
.43292 .04081 L
.43293 .04075 L
s
.22564 .12981 m
.2258 .12978 L
.22592 .12972 L
.22601 .12963 L
.22608 .12953 L
.22612 .12945 L
.22615 .12939 L
.22617 .12936 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12935 L
.22617 .12931 L
.22617 .12923 L
.22617 .12912 L
.22617 .12902 L
.22617 .12896 L
.22617 .129 L
.22617 .12915 L
.22617 .12942 L
.22617 .12983 L
.22617 .13035 L
.22618 .13096 L
.22618 .13163 L
.22618 .13234 L
.22618 .13304 L
.22618 .13375 L
.22618 .13444 L
.22618 .13508 L
.22618 .13563 L
.22618 .13607 L
.22618 .13638 L
.22618 .13656 L
.22618 .13661 L
.22618 .13656 L
.22618 .13646 L
.22618 .13635 L
.22618 .13626 L
.22619 .13621 L
.22622 .13617 L
.22628 .13612 L
Mistroke
.22636 .13605 L
.22648 .13596 L
.22664 .13588 L
.2268 .1358 L
.22691 .13577 L
.22694 .13579 L
Mfstroke
.07438 .55838 m
.07447 .55834 L
.07448 .5582 L
.07443 .55801 L
.07436 .55779 L
.07429 .55759 L
.07424 .55746 L
.07421 .55741 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .5574 L
.07421 .55739 L
.07421 .55731 L
.07422 .55715 L
.07422 .55693 L
.07421 .55668 L
.07418 .55643 L
.07412 .55624 L
.07405 .5562 L
s
.11352 .72801 m
.11342 .72821 L
.11316 .72847 L
.11279 .72877 L
.11235 .72906 L
.1119 .72927 L
.11144 .72939 L
.11107 .7294 L
.11076 .72933 L
.11045 .72916 L
.11021 .72888 L
.11003 .72853 L
.10993 .72816 L
.10991 .72769 L
.10999 .72718 L
.11012 .72667 L
.1103 .72619 L
.1105 .72578 L
.11069 .72546 L
.11084 .72526 L
.11096 .72515 L
.11104 .72511 L
.11109 .72514 L
.11107 .72524 L
.11098 .72536 L
.11084 .72547 L
.11067 .72554 L
.11044 .72562 L
.11015 .72571 L
.1098 .72583 L
.10941 .72597 L
.10902 .72612 L
.10864 .72627 L
.10828 .72639 L
.10795 .72648 L
.10773 .72652 L
.10756 .72654 L
.10742 .72653 L
.10733 .72647 L
.10728 .72642 L
.10726 .72635 L
.1073 .72625 L
.10736 .72615 L
.10743 .72605 L
.10749 .72596 L
.10756 .72586 L
.10763 .72576 L
.10774 .72558 L
.10778 .72553 L
.1078 .7255 L
Mistroke
.10784 .7255 L
.10789 .72551 L
.10795 .72553 L
.10802 .72555 L
.10809 .72556 L
.10814 .72557 L
.10816 .72558 L
.10815 .7256 L
.10809 .7256 L
.108 .7256 L
.10789 .72561 L
.10781 .72562 L
.10777 .72565 L
.10779 .72568 L
.10784 .72571 L
.10795 .72574 L
.10812 .72576 L
.10835 .72577 L
.10863 .72578 L
.10894 .72576 L
.10927 .72574 L
.10959 .72571 L
.1099 .72569 L
.11018 .72567 L
.11043 .72565 L
.11063 .72562 L
.11077 .72558 L
.11088 .72553 L
.11094 .72549 L
.11096 .72545 L
.11095 .72542 L
.11091 .72541 L
.11087 .7254 L
.11083 .72541 L
.11082 .72543 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11078 .72544 L
.11062 .72545 L
.1104 .72546 L
.11013 .72547 L
.10983 .72548 L
.10951 .7255 L
.10923 .72551 L
.10898 .72552 L
.10877 .72553 L
.10862 .72553 L
.10856 .72554 L
.10859 .72553 L
.10871 .72553 L
.1089 .72552 L
.10915 .72551 L
.10944 .7255 L
.10975 .72549 L
.11006 .72547 L
.11034 .72546 L
.11057 .72545 L
.11075 .72545 L
.11087 .72544 L
.11094 .72544 L
.11096 .72544 L
.11095 .72544 L
.11091 .72544 L
.11087 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11083 .72544 L
.11086 .72544 L
.1109 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11088 .72544 L
.11074 .72545 L
.11055 .72545 L
.11031 .72546 L
.11005 .72547 L
.10982 .72548 L
.10961 .72549 L
.10946 .7255 L
.10935 .72551 L
.10929 .72551 L
.10928 .72551 L
.10932 .72551 L
.10941 .7255 L
.10955 .7255 L
.10975 .72549 L
.10998 .72548 L
.11024 .72547 L
.11049 .72546 L
.11071 .72545 L
.11086 .72544 L
.11094 .72544 L
.11096 .72544 L
.11094 .72544 L
.11091 .72544 L
.11086 .72544 L
.11083 .72544 L
.11082 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.1108 .72544 L
.11079 .72544 L
.11078 .72544 L
.11077 .72544 L
.11076 .72544 L
.11076 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11075 .72544 L
.11076 .72544 L
.11076 .72544 L
Mistroke
.11077 .72544 L
.11079 .72544 L
.1108 .72544 L
.11081 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11082 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72542 L
.11082 .72544 L
.11081 .72546 L
.1108 .72549 L
.11078 .72551 L
.11076 .72554 L
.11074 .72556 L
.11073 .72557 L
.11072 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72558 L
.11071 .72557 L
.11072 .72555 L
.11074 .72553 L
.11075 .7255 L
.11077 .72547 L
.11079 .72545 L
.11081 .72543 L
.11082 .72542 L
.11083 .72542 L
.11083 .72543 L
.11082 .72544 L
.11082 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
Mistroke
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72544 L
.11081 .72543 L
.11081 .7254 L
.11082 .72536 L
.11082 .72534 L
.11082 .72533 L
.11082 .72534 L
.11081 .72539 L
.11081 .72549 L
.1108 .72565 L
.11079 .72585 L
.11079 .72607 L
.11078 .72628 L
.11077 .72646 L
.11076 .72663 L
.11075 .72671 L
.11071 .72672 L
.11067 .72671 L
.11064 .72666 L
.11062 .72659 L
.11064 .72652 L
.1107 .72635 L
.11081 .72615 L
.11097 .72595 L
.11117 .72577 L
.11141 .72562 L
.11167 .72551 L
.11194 .72547 L
.11221 .72546 L
.11247 .72548 L
.11273 .7255 L
.11297 .72553 L
.11318 .72558 L
.11335 .72557 L
.11347 .72555 L
.11354 .72551 L
.11356 .72547 L
.11355 .72543 L
Mistroke
.11351 .72538 L
.11347 .72534 L
.11344 .72531 L
.11342 .7253 L
.11342 .7253 L
.11342 .72531 L
.11342 .72532 L
.11342 .72533 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72534 L
.11342 .72533 L
.11343 .72533 L
.11347 .72533 L
.11355 .72533 L
.11363 .72532 L
.11366 .72532 L
.11363 .72532 L
.11353 .72533 L
.11334 .72534 L
.11304 .72536 L
.11263 .72537 L
.11213 .72539 L
.1116 .72542 L
.11106 .72544 L
.11052 .72546 L
.11006 .72549 L
.10954 .72551 L
.10902 .72553 L
.10856 .72554 L
.10821 .72556 L
.10798 .72556 L
.10786 .72557 L
.10783 .72557 L
.10785 .72556 L
.10795 .72554 L
.10807 .72551 L
.10818 .72546 L
.10827 .72541 L
.10833 .72537 L
.10836 .72533 L
.10833 .72532 L
.10824 .72536 L
Mfstroke
.1036 .73252 m
.10345 .7326 L
.10337 .73258 L
.10336 .73247 L
.10335 .73234 L
.10335 .7322 L
.10336 .73209 L
.10343 .732 L
.10355 .73193 L
.1037 .73194 L
.10389 .73205 L
.10412 .73217 L
.10438 .73233 L
.10468 .73252 L
.10496 .73269 L
.10519 .73283 L
.10536 .73294 L
.10548 .73302 L
.10555 .73304 L
.10558 .73301 L
.10558 .73295 L
.10556 .7329 L
.10553 .73284 L
.1055 .73277 L
.10548 .73272 L
.10547 .73268 L
.10548 .73265 L
.10548 .73259 L
.10549 .73249 L
.10549 .73238 L
.10549 .73226 L
.10548 .73216 L
.10547 .73209 L
.10546 .73206 L
.10538 .73192 L
.10536 .73195 L
.10533 .73201 L
.10532 .73209 L
.1053 .73218 L
.1053 .73227 L
.1053 .73239 L
.1053 .73252 L
.10531 .73266 L
.10533 .73281 L
.10535 .73295 L
.10538 .73307 L
.10541 .73315 L
.10544 .7332 L
.10548 .73319 L
.10553 .73309 L
Mistroke
.10558 .73293 L
.10561 .73277 L
.10562 .73267 L
.1056 .73266 L
.10554 .73276 L
Mfstroke
.11532 .75601 m
.11541 .75604 L
.11538 .75601 L
.11526 .75592 L
.1151 .75582 L
.11492 .75574 L
.11476 .7557 L
.11465 .7557 L
.1146 .75579 L
.11457 .75591 L
.11455 .75603 L
.1145 .75608 L
.1144 .7561 L
.11425 .75606 L
.11406 .75593 L
.11387 .7557 L
.1137 .75539 L
.1136 .75505 L
.11358 .75467 L
.11364 .75432 L
.11374 .75401 L
.11386 .75379 L
.11396 .75359 L
.11403 .7534 L
.11405 .75325 L
.11403 .75319 L
.114 .75319 L
.11397 .75326 L
.11394 .75342 L
.11388 .75365 L
.1138 .75393 L
.11371 .75425 L
.11364 .75462 L
.11361 .75502 L
.11364 .75543 L
.11374 .75581 L
.11391 .7562 L
.11414 .75654 L
.11443 .75678 L
.11473 .75691 L
.115 .75691 L
.11522 .75679 L
.11535 .75656 L
.1154 .75628 L
.11537 .75597 L
.11527 .75566 L
.11515 .7554 L
.11503 .75524 L
.11497 .75529 L
s
.73856 .89181 m
.73859 .89166 L
.73847 .89167 L
.73824 .8918 L
.73798 .892 L
.73772 .89221 L
.7375 .89238 L
.73753 .89248 L
.73739 .8925 L
.73731 .89249 L
.73727 .89247 L
.73725 .89244 L
.73721 .89241 L
.73716 .89239 L
.73709 .89238 L
.73696 .89239 L
.73678 .89242 L
.73652 .89246 L
.73627 .89249 L
.73607 .89251 L
.73594 .89252 L
.73588 .89251 L
.73591 .89248 L
.73598 .89244 L
.73606 .89242 L
.7361 .89243 L
.73606 .89248 L
.73594 .89255 L
.73574 .89264 L
.73547 .89272 L
.7352 .8928 L
.73493 .89289 L
.73467 .89298 L
.73444 .89309 L
.73423 .8932 L
.73409 .89332 L
.73402 .89345 L
.73402 .89357 L
s
.81264 .83023 m
.81264 .83037 L
.81268 .83044 L
.81273 .83048 L
.81278 .83048 L
.81281 .83046 L
.81282 .83041 L
.81282 .83036 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81282 .83033 L
.81283 .83033 L
.81285 .83032 L
.81291 .83031 L
.81299 .83028 L
.81306 .83023 L
.81308 .83018 L
.81306 .83016 L
.81296 .83018 L
.81276 .83023 L
.81245 .83032 L
.81206 .83044 L
.8116 .83062 L
.81111 .83085 L
.81062 .83113 L
.81014 .83149 L
.8097 .8319 L
.80929 .83233 L
.80891 .83277 L
.80859 .8332 L
.80835 .8336 L
.80819 .83396 L
.80814 .8343 L
.80817 .83461 L
.80826 .83485 L
.80838 .83502 L
.80848 .83509 L
.80856 .83503 L
.80861 .83484 L
.80865 .83454 L
.80872 .83418 L
.80881 .83376 L
.80892 .83333 L
.80907 .83293 L
.80926 .83263 L
.80948 .83244 L
Mistroke
.80971 .83234 L
.80992 .83231 L
.81013 .83236 L
.8103 .83249 L
.81044 .83269 L
.81055 .83295 L
.81066 .83328 L
.81076 .83359 L
.81086 .83382 L
.81096 .8339 L
.81108 .83384 L
.81122 .83362 L
.81137 .83337 L
.81155 .83298 L
.81175 .83258 L
.81195 .83224 L
.81214 .83192 L
.81231 .83171 L
.81245 .83161 L
.81257 .83168 L
.81265 .83178 L
.81266 .83193 L
.81259 .8321 L
.81245 .83229 L
.81226 .83248 L
.81205 .8326 L
.81183 .8326 L
.81169 .83243 L
.81154 .83216 L
.81139 .83187 L
.81124 .83164 L
.8111 .8314 L
.81093 .83118 L
.81075 .83099 L
.8106 .83086 L
.8105 .83079 L
.81043 .83072 L
.81039 .83065 L
.81041 .83056 L
.81046 .83058 L
.81054 .83063 L
.81063 .83068 L
.81071 .83067 L
.81078 .83067 L
.81083 .83073 L
.81088 .83085 L
.81093 .831 L
.81098 .83115 L
.81101 .83125 L
.811 .83132 L
Mistroke
.81097 .83147 L
.81095 .83169 L
.81093 .83192 L
.81089 .83216 L
.81087 .83242 L
.81084 .83272 L
.81078 .83302 L
.81067 .83327 L
.81051 .83348 L
.81027 .83364 L
.80999 .83375 L
.80973 .83383 L
.8095 .83389 L
.80933 .83396 L
.80919 .83397 L
.80913 .83392 L
.80917 .83377 L
.80933 .8335 L
.80957 .83306 L
.80991 .83254 L
.81033 .83196 L
.81086 .83145 L
.81145 .831 L
.81208 .83065 L
.81265 .8304 L
.81309 .83025 L
.81331 .8302 L
.81328 .83024 L
Mfstroke
.23882 .87478 m
.23876 .87471 L
.2388 .87473 L
.23888 .8748 L
.23888 .87469 L
.23895 .87474 L
.23902 .87478 L
.23905 .87478 L
.23901 .87474 L
.23894 .87469 L
.23887 .87466 L
.23882 .87468 L
.23878 .87472 L
.23876 .87475 L
.23878 .87478 L
.23883 .87483 L
.2389 .87489 L
.23897 .87493 L
.23905 .87495 L
.23914 .87495 L
.23919 .87492 L
.23921 .87487 L
.2392 .87479 L
.23915 .87469 L
.23906 .87458 L
.23895 .87446 L
.23888 .87435 L
.23884 .87427 L
.23882 .87419 L
.23883 .87413 L
.23886 .8741 L
.23889 .87409 L
.23891 .87404 L
.23893 .87398 L
.23899 .87392 L
.23909 .87388 L
.23923 .87384 L
.2394 .8738 L
.2396 .87376 L
.23978 .87373 L
.23993 .8737 L
.24001 .8737 L
.24006 .87376 L
s
.90793 .32161 m
.908 .32184 L
.90807 .32232 L
.90814 .32296 L
.90822 .32368 L
.90833 .32442 L
.90845 .32507 L
.90856 .32563 L
.90867 .32605 L
.90875 .32633 L
.90877 .32643 L
s
.26343 .10379 m
.26345 .10379 L
.2636 .10369 L
.26382 .10356 L
.26404 .1034 L
.26423 .10327 L
.26435 .10317 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.26439 .10313 L
.2644 .10313 L
.26446 .10311 L
.26458 .10306 L
.26477 .10296 L
.26499 .10283 L
.26522 .10267 L
.26541 .10251 L
.26549 .10241 L
s
.08992 .34962 m
.09 .34966 L
.09008 .34958 L
.09013 .34947 L
.09015 .34936 L
.09016 .34926 L
.09016 .34917 L
.09016 .3491 L
.09016 .34906 L
.09016 .34903 L
.09016 .34903 L
.09016 .34902 L
.09016 .34898 L
.09016 .3489 L
.09018 .34878 L
.09022 .34857 L
.09028 .34823 L
.09035 .34786 L
.09041 .34765 L
.09043 .34768 L
s
1 .99 0 r
.008 w
.08408 .41164 Mdot
.016 w
.08408 .41164 m
.08414 .41164 L
s
1 .979 0 r
.008 w
.08414 .41164 Mdot
.016 w
.08414 .41164 m
.08418 .41136 L
s
1 .969 0 r
.008 w
.08418 .41136 Mdot
.016 w
.08418 .41136 m
.08421 .41093 L
s
1 .959 0 r
.008 w
.08421 .41093 Mdot
.016 w
.08421 .41093 m
.08422 .41048 L
s
1 .948 0 r
.008 w
.08422 .41048 Mdot
.016 w
.08422 .41048 m
.08423 .41004 L
s
1 .938 0 r
.008 w
.08423 .41004 Mdot
.016 w
.08423 .41004 m
.08423 .40969 L
s
1 .928 0 r
.008 w
.08423 .40969 Mdot
.016 w
.08423 .40969 m
.08423 .4095 L
s
1 .918 0 r
.008 w
.08423 .4095 Mdot
.016 w
.08423 .4095 m
.08423 .40944 L
s
1 .907 0 r
.008 w
.08423 .40944 Mdot
.016 w
.08423 .40944 m
.08423 .40955 L
s
1 .897 0 r
.008 w
.08423 .40955 Mdot
.016 w
.08423 .40955 m
.08423 .40974 L
s
1 .887 0 r
.008 w
.08423 .40974 Mdot
.016 w
.08423 .40974 m
.08422 .41001 L
s
1 .876 0 r
.008 w
.08422 .41001 Mdot
.016 w
.08422 .41001 m
.08422 .4103 L
s
1 .866 0 r
.008 w
.08422 .4103 Mdot
.016 w
.08422 .4103 m
.08421 .41061 L
s
1 .856 0 r
.008 w
.08421 .41061 Mdot
.016 w
.08421 .41061 m
.08421 .4109 L
s
1 .845 0 r
.008 w
.08421 .4109 Mdot
.016 w
.08421 .4109 m
.0842 .41115 L
s
1 .835 0 r
.008 w
.0842 .41115 Mdot
.016 w
.0842 .41115 m
.0842 .41134 L
s
1 .825 0 r
.008 w
.0842 .41134 Mdot
.016 w
.0842 .41134 m
.08419 .41149 L
s
1 .814 0 r
.008 w
.08419 .41149 Mdot
.016 w
.08419 .41149 m
.08419 .41162 L
s
1 .804 0 r
.008 w
.08419 .41162 Mdot
.016 w
.08419 .41162 m
.08419 .4117 L
s
1 .794 0 r
.008 w
.08419 .4117 Mdot
.016 w
.08419 .4117 m
.08419 .41171 L
s
1 .784 0 r
.008 w
.08419 .41171 Mdot
.016 w
.08419 .41171 m
.08419 .41166 L
s
1 .773 0 r
.008 w
.08419 .41166 Mdot
.016 w
.08419 .41166 m
.08419 .41157 L
s
1 .763 0 r
.008 w
.08419 .41157 Mdot
.016 w
.08419 .41157 m
.0842 .41145 L
s
1 .753 0 r
.008 w
.0842 .41145 Mdot
.016 w
.0842 .41145 m
.0842 .41127 L
s
1 .742 0 r
.008 w
.0842 .41127 Mdot
.016 w
.0842 .41127 m
.0842 .41103 L
s
1 .732 0 r
.008 w
.0842 .41103 Mdot
.016 w
.0842 .41103 m
.08421 .41074 L
s
1 .722 0 r
.008 w
.08421 .41074 Mdot
.016 w
.08421 .41074 m
.08421 .4104 L
s
1 .711 0 r
.008 w
.08421 .4104 Mdot
.016 w
.08421 .4104 m
.08422 .41002 L
s
1 .701 0 r
.008 w
.08422 .41002 Mdot
.016 w
.08422 .41002 m
.08423 .4096 L
s
1 .691 0 r
.008 w
.08423 .4096 Mdot
.016 w
.08423 .4096 m
.08424 .40916 L
s
1 .68 0 r
.008 w
.08424 .40916 Mdot
.016 w
.08424 .40916 m
.08424 .40871 L
s
1 .67 0 r
.008 w
.08424 .40871 Mdot
.016 w
.08424 .40871 m
.08425 .40831 L
s
1 .66 0 r
.008 w
.08425 .40831 Mdot
.016 w
.08425 .40831 m
.08426 .40797 L
s
1 .649 0 r
.008 w
.08426 .40797 Mdot
.016 w
.08426 .40797 m
.08426 .40777 L
s
1 .639 0 r
.008 w
.08426 .40777 Mdot
.016 w
.08426 .40777 m
.08426 .4077 L
s
1 .629 0 r
.008 w
.08426 .4077 Mdot
.016 w
.08426 .4077 m
.08426 .40777 L
s
1 .619 0 r
.008 w
.08426 .40777 Mdot
.016 w
.08426 .40777 m
.08426 .40795 L
s
1 .608 0 r
.008 w
.08426 .40795 Mdot
.016 w
.08426 .40795 m
.08425 .40824 L
s
1 .598 0 r
.008 w
.08425 .40824 Mdot
.016 w
.08425 .40824 m
.08425 .40859 L
s
1 .588 0 r
.008 w
.08425 .40859 Mdot
.016 w
.08425 .40859 m
.08424 .40898 L
s
1 .577 0 r
.008 w
.08424 .40898 Mdot
.016 w
.08424 .40898 m
.08423 .40936 L
s
1 .567 0 r
.008 w
.08423 .40936 Mdot
.016 w
.08423 .40936 m
.08423 .40973 L
s
1 .557 0 r
.008 w
.08423 .40973 Mdot
.016 w
.08423 .40973 m
.08422 .41007 L
s
1 .546 0 r
.008 w
.08422 .41007 Mdot
.016 w
.08422 .41007 m
.08422 .41039 L
s
1 .536 0 r
.008 w
.08422 .41039 Mdot
.016 w
.08422 .41039 m
.08421 .4107 L
s
1 .526 0 r
.008 w
.08421 .4107 Mdot
.016 w
.08421 .4107 m
.08421 .411 L
s
1 .515 0 r
.008 w
.08421 .411 Mdot
.016 w
.08421 .411 m
.0842 .4114 L
s
1 .505 0 r
.008 w
.0842 .4114 Mdot
.016 w
.0842 .4114 m
.0842 .41159 L
s
1 .495 0 r
.008 w
.0842 .41159 Mdot
.016 w
.0842 .41159 m
.08419 .41169 L
s
1 .485 0 r
.008 w
.08419 .41169 Mdot
.016 w
.08419 .41169 m
.08419 .41167 L
s
1 .474 0 r
.008 w
.08419 .41167 Mdot
.016 w
.08419 .41167 m
.0842 .4115 L
s
1 .464 0 r
.008 w
.0842 .4115 Mdot
.016 w
.0842 .4115 m
.0842 .41123 L
s
1 .454 0 r
.008 w
.0842 .41123 Mdot
.016 w
.0842 .41123 m
.08421 .41087 L
s
1 .443 0 r
.008 w
.08421 .41087 Mdot
.016 w
.08421 .41087 m
.08422 .41042 L
s
1 .433 0 r
.008 w
.08422 .41042 Mdot
.016 w
.08422 .41042 m
.08423 .40988 L
s
1 .423 0 r
.008 w
.08423 .40988 Mdot
.016 w
.08423 .40988 m
.08424 .40929 L
s
1 .412 0 r
.008 w
.08424 .40929 Mdot
.016 w
.08424 .40929 m
.08424 .40874 L
s
1 .402 0 r
.008 w
.08424 .40874 Mdot
.016 w
.08424 .40874 m
.08422 .40829 L
s
1 .392 0 r
.008 w
.08422 .40829 Mdot
.016 w
.08422 .40829 m
.08419 .4079 L
s
1 .381 0 r
.008 w
.08419 .4079 Mdot
.016 w
.08419 .4079 m
.08415 .40757 L
s
1 .371 0 r
.008 w
.08415 .40757 Mdot
.016 w
.08415 .40757 m
.08413 .4074 L
s
1 .361 0 r
.008 w
.08413 .4074 Mdot
.016 w
.08413 .4074 m
.08412 .40736 L
s
1 .351 0 r
.008 w
.08412 .40736 Mdot
.016 w
.08412 .40736 m
.08413 .40746 L
s
1 .34 0 r
.008 w
.08413 .40746 Mdot
.016 w
.08413 .40746 m
.08416 .4077 L
s
1 .33 0 r
.008 w
.08416 .4077 Mdot
.016 w
.08416 .4077 m
.08421 .40808 L
s
1 .32 0 r
.008 w
.08421 .40808 Mdot
.016 w
.08421 .40808 m
.0843 .40856 L
s
1 .309 0 r
.008 w
.0843 .40856 Mdot
.016 w
.0843 .40856 m
.08443 .40909 L
s
1 .299 0 r
.008 w
.08443 .40909 Mdot
.016 w
.08443 .40909 m
.08464 .40962 L
s
1 .289 0 r
.008 w
.08464 .40962 Mdot
.016 w
.08464 .40962 m
.08496 .41011 L
s
1 .278 0 r
.008 w
.08496 .41011 Mdot
.016 w
.08496 .41011 m
.08545 .41054 L
s
1 .268 0 r
.008 w
.08545 .41054 Mdot
.016 w
.08545 .41054 m
.08605 .4109 L
s
1 .258 0 r
.008 w
.08605 .4109 Mdot
.016 w
.08605 .4109 m
.08679 .41119 L
s
1 .247 0 r
.008 w
.08679 .41119 Mdot
.016 w
.08679 .41119 m
.08768 .41142 L
s
1 .237 0 r
.008 w
.08768 .41142 Mdot
.016 w
.08768 .41142 m
.08872 .41169 L
s
1 .227 0 r
.008 w
.08872 .41169 Mdot
.016 w
.08872 .41169 m
.08985 .41207 L
s
1 .216 0 r
.008 w
.08985 .41207 Mdot
.016 w
.08985 .41207 m
.09081 .41262 L
s
1 .206 0 r
.008 w
.09081 .41262 Mdot
.016 w
.09081 .41262 m
.09182 .41335 L
s
1 .196 0 r
.008 w
.09182 .41335 Mdot
.016 w
.09182 .41335 m
.09293 .4143 L
s
1 .186 0 r
.008 w
.09293 .4143 Mdot
.016 w
.09293 .4143 m
.09384 .41551 L
s
1 .175 0 r
.008 w
.09384 .41551 Mdot
.016 w
.09384 .41551 m
.09483 .41696 L
s
1 .165 0 r
.008 w
.09483 .41696 Mdot
.016 w
.09483 .41696 m
.09559 .41868 L
s
1 .155 0 r
.008 w
.09559 .41868 Mdot
.016 w
.09559 .41868 m
.09628 .42072 L
s
1 .144 0 r
.008 w
.09628 .42072 Mdot
.016 w
.09628 .42072 m
.09684 .42295 L
s
1 .134 0 r
.008 w
.09684 .42295 Mdot
.016 w
.09684 .42295 m
.09723 .4255 L
s
1 .124 0 r
.008 w
.09723 .4255 Mdot
.016 w
.09723 .4255 m
.09742 .42835 L
s
1 .113 0 r
.008 w
.09742 .42835 Mdot
.016 w
.09742 .42835 m
.09741 .43145 L
s
1 .103 0 r
.008 w
.09741 .43145 Mdot
.016 w
.09741 .43145 m
.0972 .43474 L
s
1 .093 0 r
.008 w
.0972 .43474 Mdot
.016 w
.0972 .43474 m
.09681 .43829 L
s
1 .082 0 r
.008 w
.09681 .43829 Mdot
.016 w
.09681 .43829 m
.09626 .4419 L
s
1 .072 0 r
.008 w
.09626 .4419 Mdot
.016 w
.09626 .4419 m
.09557 .44587 L
s
1 .062 0 r
.008 w
.09557 .44587 Mdot
.016 w
.09557 .44587 m
.09479 .44925 L
s
1 .052 0 r
.008 w
.09479 .44925 Mdot
.016 w
.09479 .44925 m
.09402 .45304 L
s
1 .041 0 r
.008 w
.09402 .45304 Mdot
.016 w
.09402 .45304 m
.09316 .4561 L
s
1 .031 0 r
.008 w
.09316 .4561 Mdot
.016 w
.09316 .4561 m
.09226 .45923 L
s
1 .021 0 r
.008 w
.09226 .45923 Mdot
.016 w
.09226 .45923 m
.09145 .462 L
s
1 .01 0 r
.008 w
.09145 .462 Mdot
.016 w
.09145 .462 m
.09056 .4645 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`Aoo`<000@mk`<00003Oolmkcg_008mk`Moo`8mk`Moo`T007eoo`00KGoo13g_00=oocg_?Nl013g_
0`000Woo1Sg_0Woo1Sg_17oo1Cg_17oo0Sg_17oo23g_0`00Mgoo001ZOolA?Nl00goo?Nlmk`05?Nl2
Ool6?Nl4Ool5?Nl3Ool4?Nl2Ool:?Nl2Ool5001bOol006YooaPmk`=oo`Dmk`Eoo`Hmk`9oo`@mk`9o
o`Xmk`Moo`@006ioo`00IGoo0cg_00=oo`00?Nl01Sg_00=oocg_?Nl03Sg_0goo13g_1Woo1Sg_0goo
0Sg_17oo23g_37oo1000JWoo001SOol6?Nl00goo?Nlmk`05?Nl00goo?Nlmk`0=?Nl4Ool4?Nl7Ool5
?NlQOol3001WOol006=oo`/mk`Ioo`/mk`Moo`8mk`Qoo`DmkbAoo`<006Aoo`00H7oo00<003g_?Nl0
2cg_AGoo1Cg_17oo0`00HGoo001NOol200000goo?Nlmk`06?Nl2Ool2?Nm5Ool7?Nl6Ool2001OOol0
05aoo`8000=oo`LmkdYoo`Tmk`Ioo`8005eoo`00FWoo0P001Goo1cg_Bgoo2Cg_1goo0P00Fgoo001H
Ool00`00?Nlmk`02?NmFOol9?Nl9Ool2001IOol005Eoo`<00003Oolmkcg_00<mke]oo`8mk`9oo`Dm
k`Eoo`<005Ioo`00Dgoo0P0017oo1Cg_6goo13g_@7oo1Cg_27oo0P00E7oo001AOol20005?Nl3Ool2
?NlLOol4?Nm0Ool6?Nl9Ool2001BOol0051oo`03001oogoo00Dmkb5oo`@mkd1oo`Hmk`]oo`03001o
ogoo04moo`00Cgoo00@007ooOomoo`Dmkb5oo`@mkd5oo`Dmk`Ioo`@mk`9oo`03001oogoo04ioo`00
CGoo0P0017oo1Cg_8Goo13g_@Goo1Cg_1Goo1Sg_0Woo0P00CWoo001;Ool20007Ool4?NmVOol4?Nl6
Ool6?Nl4Ool2001<Ool004Uoo`8000=oo`8mk`=oo`8mkfYoo`8mk`Qoo`Dmk`Ioo`8004Yoo`00B7oo
00@007ooOomoo`Xmkf5oo`8mka1oo`@mk`Eoo`@mk`03001oogoo04Moo`00AWoo0P0017oo2Sg_H7oo
13g_3goo13g_1Goo1Cg_0P00Agoo0015Ool00`00Oomoo`04Ool:?NmPOol4?NlHOol8?Nm6Ool004Ao
o`03001oogoo008mk`=oo`Xmkf5oo`HmkaEoo`TmkdEoo`00@goo00<007ooOol013g_KWoo1Cg_5Goo
2Sg_A7oo0011Ool20002Ool6?Nm]Ool5?NlEOol=?Nm1Ool0041oo`03001oogoo00Pmkfeoo`DmkaEo
o`hmkd1oo`00?goo00<007ooOol023g_17oo0Sg_J7oo1Cg_6goo23g_00<007ooOol0?Goo000nOol0
1000Oomoogoo1cg_17oo13g_IWoo1Sg_6goo23g_00=oo`00Ool0?Goo000lOol20004Ool5?Nl6Ool4
?NmVOol5?NlQOol5?Nl00`00Oomoo`0kOol003]oo`03001oogoo00Aoo`Dmk`Ioo`@mkfIoo`Dmkb5o
o`Dmk`03Ool007oo03]oo`00>Woo00<007ooOol01Goo13g_27oo0Sg_Igoo1Cg_8Goo1Cg_0Woo0P00
>Woo000iOol01000Oolmkcg_1Goo13g_LGoo13g_8Woo1Cg_17oo00<007ooOol0=goo000gOol20000
0goo?Nlmk`02?NmiOol4?NlROol8?Nl2Ool00`00Oomoo`0fOol003Ioo`04001oogooOol4?NnOOol9
?Nl2Ool00`00Oomoo`0eOol003Eoo`03001oogoo009oo`@mki5oo`@mk`ioo`Dmk`=oo`03001oogoo
03Aoo`00=7oo00<007ooOol017oo1Sg_SWoo1Cg_3Goo13g_1Goo00<007ooOol0<goo000bOol20008
Ool5?Nn>Ool5?Nl=Ool4?Nl6Ool00`00Oomoo`0bOol0035oo`03001oogoo00Qoo`Dmkhioo`DmkaQo
o`03001oogoo035oo`00<7oo00<007ooOol027oo1Sg_SWoo1Cg_47oo1Cg_17oo00<007ooOol0<7oo
000`Ool00`00Oomoo`07Ool5?NnUOol5?Nl5Ool00`00Oomoo`0_Ool002moo`03001oogoo00Qoo`Dm
kjEoo`Dmk`Ioo`03001oogoo02ioo`00;Woo00<007ooOol017oo2Sg_YGoo1Cg_1goo00<007ooOol0
;Goo000]Ool00`00Oomoo`05Ool:?NnVOol5?Nl7Ool00`00Oomoo`0/Ool002aoo`03001oogoo00Io
o`LmkjYoo`Dmk`Moo`03001oogoo02]oo`00;7oo00<007ooOol01Woo1cg_ZWoo1Sg_1Woo00<007oo
Ool0:goo000[Ool00`00Oomoo`07Ool7?Nn[Ool5?Nl7Ool00`00Oomoo`0ZOol002Yoo`03001oogoo
00Uoo`8mkk1oo`Dmk`Moo`03001oogoo02Uoo`00:Goo00<007ooOol0_7oo1Cg_27oo00<007ooOol0
:7oo000XOol00`00Oomoo`2mOol5?Nl9Ool00`00Oomoo`0WOol002Qoo`03001oogoo0;eoo`Dmk`Uo
o`03001oogoo02Moo`009goo00<007ooOol0/7oo0Sg_6goo00<007ooOol09Woo000VOol00`00Oomo
o`2`Ool4?NlKOol00`00Oomoo`0UOol002Eoo`03001oogoo0;5oo`@mka9oo`8mk`Qoo`03001oogoo
02Aoo`0097oo00<007ooOol0/goo0Sg_4Woo13g_27oo00<007ooOol08goo000TOol00`00Oomoo`37
Ool4?Nl8Ool00`00Oomoo`0SOol002=oo`03001oogoo0<Uoo`8mk`04Oolmkcg_?Nl6Ool00`00Oomo
o`0ROol0029oo`03001oogoo0<aoo`Dmk`Ioo`03001oogoo025oo`008Woo00<007ooOol0c7oo1Cg_
1Woo00<007ooOol08Goo000QOol00`00Oomoo`3>Ool3?Nl8Ool00`00Oomoo`0POol0021oo`03001o
ogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0
e7oo13g_1goo00<007ooOol07Goo000MOol00`00Oomoo`0eOol4?NnKOol6?Nl7Ool00`00Oomoo`0L
Ool001eoo`03001oogoo03Eoo`DmkiMoo`Tmk`Moo`03001oogoo01aoo`0077oo00<007ooOol0=Woo
1Cg_Ugoo2Cg_27oo00<007ooOol06goo000LOol00`00Oomoo`0fOol5?NnGOol9?Nl8Ool00`00Oomo
o`0KOol001]oo`03001oogoo03Moo`DmkiMoo`@mk`9oo`Dmk`Moo`03001oogoo01Yoo`006goo00<0
07ooOol0fGoo1Cg_1goo00<007ooOol06Woo000JOol00`00Oomoo`07Ool2?NoAOol7?Nl6Ool00`00
Oomoo`0IOol001Yoo`03001oogoo00Ioo`@mkm1oo`Pmk`Eoo`03001oogoo01Uoo`006Goo00<007oo
Ool01goo13g_d7oo23g_1Woo00<007ooOol067oo000IOol00`00Oomoo`06Ool4?NmLOol4?NmcOol6
?Nl6Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`@mkd=oo`8mkaQoo`@mkg=oo`Lmk`Ioo`03
001oogoo01Moo`0067oo00<007ooOol01Woo13g_@Woo13g_5goo13g_M7oo1Sg_1Woo00<007ooOol0
5goo000HOol00`00Oomoo`05Ool4?Nm2Ool5?NlGOol4?NmdOol7?Nl5Ool00`00Oomoo`0GOol001Mo
o`03001oogoo00Eoo`@mkd=oo`HmkaIoo`@mkgAoo`Lmk`Ioo`03001oogoo01Ioo`005goo00<007oo
Ool017oo1Cg_A7oo1Cg_SWoo1cg_1Woo00<007ooOol05Woo000FOol00`00Oomoo`05Ool5?Nm4Ool4
?NnAOol5?Nl7Ool00`00Oomoo`0EOol001Ioo`03001oogoo00Aoo`HmkmUoo`Dmk`Moo`03001oogoo
01Eoo`005Goo00<007ooOol01Goo1Sg_fWoo13g_27oo00<007ooOol057oo000EOol00`00Oomoo`05
Ool5?NoKOol4?Nl8Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`Dmkm]oo`@mk`Qoo`03001o
ogoo01Aoo`0057oo00<007ooOol01Woo1Cg_j7oo00<007ooOol04goo000DOol00`00Oomoo`07Ool2
?NoZOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`Dmkmeoo`@mk`Qoo`03001oogoo01=oo`00
4goo00<007ooOol01Woo1Cg_gGoo13g_2Goo00<007ooOol04Woo000COol00`00Oomoo`06Ool5?NoM
Ool4?Nl9Ool00`00Oomoo`0BOol001=oo`03001oogoo00Qoo`<mkmeoo`@mk`Uoo`03001oogoo019o
o`004Woo00<007ooOol0jGoo13g_2Woo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomo
o`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007ooOol0nGoo00<007ooOol0
47oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo00Uoo`8mknioo`03001o
ogoo011oo`004Goo00<007ooOol027oo13g_?Woo0Sg_[Woo00<007ooOol03goo000@Ool00`00Oomo
o`08Ool5?NlmOol4?Nn]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmkceoo`@mkjeoo`03
001oogoo00moo`0047oo00<007ooOol027oo1Sg_?Goo0Sg_[Woo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool6?No]Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo00io
o`003goo00<007ooOol02Goo17e00cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool00gd0
O>1lh002O>03?No/Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`03O@1l`7bP00=lX08mknao
o`03001oogoo00ioo`003goo00<007ooOol02Goo00=m07c0O:0017b0kGoo00<007ooOol03Woo000>
Ool00`00Oomoo`0:Ool00gd0O<1lX004O802?No/Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yo
o`03ON1l`7bP00AlH0<mkn]oo`03001oogoo00eoo`003Woo00<007ooOol037oo00=lX7aPO6000WaP
0cg_jgoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool4O608?NoVOol00`00Oomoo`0=Ool000io
o`03001oogoo00eoo`Al@0TmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo17a02Cg_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0>Ool4O409?NoHOol2?Nl<Ool00`00Oomoo`0<Ool000eo
o`03001oogoo00ioo`Al80TmkmIoo`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol03Woo17`P
2Cg_eWoo1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool00cg_O21l8002O208?NoGOol5
?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`03?Nml07`0009l009l80Lmk`Eoo`8mkm1o
o`Dmk`]oo`03001oogoo00aoo`003Goo00<007ooOol02Woo0cg_17`000=l83g_?Nl01Sg_17oo13g_
cgoo13g_37oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool5?Nl4O00017`POomoogoo1Cg_17oo
13g_ggoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool5?Nl4O004Ool2?Nl8Ool2?NoPOol00`00
Oomoo`0<Ool000eoo`03001oogoo00Qoo`Dmk`Al00=oo`@mknUoo`03001oogoo00aoo`003Goo00<0
07ooOol01goo1Sg_17`00goo13g_jGoo00<007ooOol037oo000<Ool00`00Oomoo`07Ool:?Nl5Ool2
?No[Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<0
07ooOol027oo23g_lgoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool8?NodOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`@mknMoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Sg_2Woo13g_7Goo0Sg_b7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:Ool4?NlLOol4
?No7Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`]oo`8mkaeoo`@mklMoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Sg_:goo0Sg_b7oo00<007ooOol02goo000<Ool00`00Oomoo`3o
Ool4Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_47oo0Sg_hgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl?Ool4?NoR
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`moo`@mkn9oo`03001oogoo00]oo`003Goo
00<007ooOol01goo1Cg_4Goo0Sg_hgoo00<007ooOol02goo000=Ool00`00Oomoo`07Ool5?NoeOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00Moo`@mkoIoo`03001oogoo00aoo`003Goo00<007ooOol0
1goo13g_jWoo0Sg_2Woo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?NoXOol4?Nl9Ool00`00
Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`@mkmAoo`@mk`Uoo`03001oogoo00aoo`003Goo
00<007ooOol01goo1Sg_3goo1Cg_dgoo13g_2Goo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5
?Nl@Ool5?NoBOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Dmk`moo`@mkm=oo`Dm
k`Uoo`03001oogoo00aoo`003Goo00<007ooOol027oo1Cg_3goo13g_dgoo1Cg_2Goo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool4?NoVOol6?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
o`@mknIoo`Dmk`Yoo`03001oogoo00aoo`003Woo00<007ooOol0lGoo1Cg_2Goo00<007ooOol03Goo
000>Ool00`00Oomoo`3aOol4?Nl:Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?5oo`@mk`Yoo`03
001oogoo00eoo`003Woo00<007ooOol02Goo13g_lWoo00<007ooOol03Goo000?Ool00`00Oomoo`08
Ool4?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Qoo`Dmko1oo`03001oogoo00ioo`003goo
00<007ooOol02Goo13g_GGoo0Sg_TGoo00<007ooOol03Woo000?Ool00`00Oomoo`08Ool5?NmLOol4
?Nn@Ool00`00Oomoo`0>Ool000moo`03001oogoo00Qoo`Dmkeaoo`@mki1oo`03001oogoo00ioo`00
47oo00<007ooOol01goo1Cg_GGoo0Sg_TGoo00<007ooOol03Woo000@Ool00`00Oomoo`07Ool5?No_
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`8mko5oo`03001oogoo00moo`0047oo00<007oo
Ool0h7oo1Cg_5Woo00<007ooOol03goo000@Ool00`00Oomoo`3POol6?NlEOol00`00Oomoo`0?Ool0
015oo`03001oogoo00Qoo`<mkmAoo`HmkaEoo`03001oogoo00moo`004Goo00<007ooOol01goo1Cg_
dgoo1Cg_5Goo00<007ooOol047oo000AOol00`00Oomoo`07Ool5?NoCOol4?NlFOol00`00Oomoo`0@
Ool0019oo`03001oogoo00Moo`<mknioo`03001oogoo011oo`004Woo00<007ooOol0_Woo0Sg_=goo
00<007ooOol04Goo000BOol00`00Oomoo`2mOol4?NlfOol00`00Oomoo`0AOol001=oo`03001oogoo
0;aoo`@mkcIoo`03001oogoo015oo`004goo00<007ooOol0=goo0Sg_Q7oo0Sg_=Woo00<007ooOol0
4Woo000COol00`00Oomoo`0fOol4?NnkOol00`00Oomoo`0BOol001Aoo`03001oogoo03Eoo`@mkk]o
o`03001oogoo019oo`0057oo00<007ooOol01Goo13g_;Goo0Sg_^goo00<007ooOol04goo000DOol0
0`00Oomoo`05Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`DmknUoo`03001oogoo
01=oo`005Goo00<007ooOol017oo13g_jGoo00<007ooOol057oo000EOol00`00Oomoo`04Ool4?Nl4
Ool2?NoSOol00`00Oomoo`0DOol001Eoo`03001oogoo00Yoo`Dmkn9oo`03001oogoo01Aoo`005Woo
00<007ooOol02Goo1Cg_e7oo0Sg_2goo00<007ooOol05Goo000FOol00`00Oomoo`09Ool5?NoCOol4
?Nl:Ool00`00Oomoo`0EOol001Moo`03001oogoo00Qoo`Dmkm=oo`@mk`Uoo`03001oogoo01Ioo`00
5goo00<007ooOol0h7oo13g_2Goo00<007ooOol05Woo000HOol00`00Oomoo`04Ool2?NoJOol2?Nl9
Ool00`00Oomoo`0GOol001Qoo`03001oogoo00=oo`Dmkcaoo`<mkiEoo`Lmk`Qoo`03001oogoo01Mo
o`006Goo00<007ooOol00Woo1Sg_>Woo1Cg_U7oo1Sg_2Goo00<007ooOol05goo000IOol00`00Oomo
o`02Ool6?NljOol5?NnCOol6?Nl9Ool00`00Oomoo`0HOol001Yoo`04001oogooOol5?NllOol3?NnD
Ool5?Nl:Ool00`00Oomoo`0HOol001Yoo`03001oogoo009oo`Dmkm9oo`Dmk`Uoo`03001oogoo01Uo
o`006goo00@007ooOomoo`Dmkm9oo`Dmk`Qoo`03001oogoo01Yoo`006goo00@007ooOomoo`Lmkm5o
o`8mk`Yoo`03001oogoo01Yoo`0077oo00<007ooOol023g_fgoo00<007ooOol06goo000LOol00`00
Oomoo`08?NoKOol00`00Oomoo`0KOol001eoo`03001oocg_00LmkmYoo`03001oogoo01aoo`007Goo
00<007oo?Nl01cg_fWoo00<007ooOol077oo000NOol00`00Oolmk`06?Nl00goo?Nlmk`3FOol00`00
Oomoo`0MOol001ioo`03001oocg_00Dmk`03Oolmkcg_008mkl9oo`8mka5oo`03001oogoo01eoo`00
7goo00<003g_?Nl013g_00=oocg_?Nl00Sg_`Goo13g_1Goo0cg_1goo00<007ooOol07Woo000OOol0
0`00?Nlmk`09?No1Ool4?Nl4Ool5?Nl6Ool00`00Oomoo`0NOol0021oo`/mkl9oo`8mk`=oo`Lmk`Eo
o`03001oogoo01moo`0087oo00<003g_?Nl02Cg_`goo2Sg_1Goo00<007ooOol07goo000QOol00`00
?Nlmk`08?No3Ool:?Nl4Ool00`00Oomoo`0POol0029oo`03000mkcg_008mk`04Oolmkcg_?No4Ool:
?Nl3Ool00`00Oomoo`0QOol002=oo`04001oogooOol5?No3Ool9?Nl3Ool00`00Oomoo`0ROol002Ao
o`03001oogoo00DmklMoo`@mk`=oo`03001oogoo02=oo`0097oo00@007ooOomoo`<mklUoo`<mk`=o
o`03001oogoo02=oo`009Goo00<007ooOol027oo0Sg_`7oo1Cg_0Woo00<007ooOol097oo000VOol0
0`00Oomoo`05Ool5?NnnOol4?Nl3Ool00`00Oomoo`0UOol002Ioo`03001oogoo00Eoo`Dmkkioo`@m
k`=oo`03001oogoo02Eoo`009goo00<007ooOol017oo1Cg_^goo1Sg_0goo00<007ooOol09Woo000X
Ool00`00Oomoo`03Ool5?NnkOol7?Nl00goo001oo`0XOol002Uoo`03001oogoo00Aoo`8mk`03Oolm
kgoo0;Uoo`Lmk`03001oogoo02Qoo`00:Woo00@007ooOomoo`LmkfYoo`8mkdeoo`Hmk`03001oogoo
02Uoo`00:Woo00@007ooOomoo`PmkfQoo`@mk`aoo`@mkcaoo`Hmk`03001oogoo02Uoo`00:goo00<0
07ooOol023g_J7oo13g_37oo1Cg_>goo1Cg_00<007ooOol0:Woo000/Ool00`00Oolmk`07?NmYOol2
?Nl=Ool5?Nl`Ool4?Nl4Ool2?Nl5Ool00`00Oomoo`0[Ool002eoo`03001oogoo009oo`@mkgQoo`@m
kc5oo`Dmk`9oo`@mk`=oo`03001oogoo02aoo`00;Woo00@007ooOomoo`@mkjeoo`Dmk`9oo`@mk`9o
o`03001oogoo02eoo`00;Woo00<007ooOol0/Woo13g_17oo0Sg_0goo00<007ooOol0;Goo000_Ool0
0`00Oomoo`28Ool2?NlWOol5?Nl7Ool00`00Oomoo`0^Ool0031oo`03001oogoo08Ioo`@mkbEoo`Lm
k`Eoo`03001oogoo02moo`00<Goo00<007ooOol01Goo13g_O7oo13g_9Goo1cg_17oo00<007ooOol0
<7oo000bOol20005Ool5?NmlOol2?NlVOol6?Nl3Ool2000cOol003Aoo`03001oogoo009oo`DmkgIo
o`@mkbYoo`Dmk`=oo`03001oogoo03=oo`00=Goo00@007ooOomoo`@mkgMoo`DmkbYoo`<mk`=oo`03
001oogoo03Aoo`00=Goo00@007ooOomoo`@mkgMoo`Dmkc1oo`03001oogoo03Aoo`00=Woo00<007oo
Ool0Ngoo1Cg_;goo00<007ooOol0=Goo000gOol00`00Oomoo`1jOol5?Nl^Ool00`00Oomoo`0fOol0
03Qoo`03001oogoo07Uoo`Dmkbeoo`03001oogoo03Moo`00>Goo0P00NWoo13g_:goo0P00>Woo000k
Ool00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo00Ioo`DmkiQoo`03001oogoo03]o
o`00?Goo00<007ooOol01Goo1Cg_Ugoo00<007ooOol0?7oo000nOol20005Ool5?NnEOol2000oOol0
041oo`03001oogoo009oo`DmkiAoo`03001oogoo03moo`00@Goo0P000Woo13g_17oo0Sg_Jgoo0Sg_
87oo0P00@Woo0013Ool00`00Oomoo`04Ool6?NmYOol4?NlAOol5?Nl8Ool00`00Oomoo`12Ool004Ao
o`03001oogoo009oo`Lmkc5oo`8mkcIoo`@mka1oo`Hmk`Moo`03001oogoo04=oo`00AGoo00@007oo
Oomoo`Hmkc5oo`@mkcIoo`8mka5oo`Hmk`Ioo`03001oogoo04Aoo`00AWoo0P000Woo1Cg_<Goo13g_
BGoo1Sg_17oo0P00Agoo0018Ool200000goo?Nlmk`02?NlbOol2?Nm:Ool5?Nl3Ool20019Ool004Yo
o`03000mkcg_008mkhAoo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00
Oomoo`1=Ool004moo`03001oogoo00aoo`8mkeioo`8mk`moo`03001oogoo04ioo`00D7oo0P002goo
13g_=goo13g_8Goo1cg_2Goo0P00DGoo001BOol20009Ool4?NlgOol4?NlPOol9?Nl6Ool2001COol0
05Aoo`8000Qoo`8mkcQoo`@mkaUoo`<mk`9oo`/mk`Aoo`8005Eoo`00EWoo0P00@7oo13g_67oo43g_
0goo0P00Egoo001HOol3000AOol5?NlWOol4?NlHOol@?Nl3001IOol005]oo`<000ioo`DmkcUoo`Hm
k`Aoo`hmk`8005aoo`00GWoo0P0037oo1cg_=goo1Sg_1Goo3Cg_GWoo001POol2000:Ool8?Nl4Ool5
?Nl]Ool6?Nl6Ool7?Nl00`00Oomoo`1POol0069oo`<000Moo`Tmk`=oo`Hmk`moo`<mkaYoo`Hmk`Io
o`Dmk`8006=oo`00IGoo0`0027oo1Cg_0goo1Sg_3Woo1Sg_6Woo13g_1goo0`00IWoo001XOol40004
Ool4?Nl4Ool5?Nl8Ool3?Nl4Ool6?Nl00goo?Nlmk`0NOol4001YOol006aoo`@000Qoo`Dmk`Mooa8m
kaUoo`@006eoo`00L7oo0`001Woo13g_1goo4Sg_5Goo1000LGoo001cOol5000<Ool:?Nl01Goo?Nlm
kcg_Ool00Sg_4Woo1000MGoo001hOol70005Ool:?Nl017oo?Nlmkcg_3Woo1`00NGoo001oOol5000:
?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
Qgoo100017oo0`0000Aoo`00000008Yoo`00Qgoo00<007ooOol01Woo00@007ooOol0009oo`03001o
ogoo08Moo`00R7oo00<007ooOol00Woo1@0000Eoo`00Oomoo`0008Uoo`00RGoo00D007ooOomoo`00
009oo`03001oogoo00<008Yoo`00Qgoo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo08Uo
o`00R7oo0P001Goo0P000goo0`00RGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[realmovesegments]\)], "Input"],

Cell[BoxData[
    \(245\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[See[AnimSeg[i, realmovesegments], PlotLabel \[Rule] i], {i, 2, 
        100}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(2)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
1 .981 0 r
.008 w
.07766 .46922 Mdot
.016 w
.07766 .46922 m
.07747 .46934 L
s
1 .962 0 r
.008 w
.07747 .46934 Mdot
.016 w
.07747 .46934 m
.07718 .46958 L
s
1 .943 0 r
.008 w
.07718 .46958 Mdot
.016 w
.07718 .46958 m
.07678 .46998 L
s
1 .925 0 r
.008 w
.07678 .46998 Mdot
.016 w
.07678 .46998 m
.0763 .47053 L
s
1 .906 0 r
.008 w
.0763 .47053 Mdot
.016 w
.0763 .47053 m
.07577 .47122 L
s
1 .887 0 r
.008 w
.07577 .47122 Mdot
.016 w
.07577 .47122 m
.07526 .47204 L
s
1 .868 0 r
.008 w
.07526 .47204 Mdot
.016 w
.07526 .47204 m
.0748 .47296 L
s
1 .849 0 r
.008 w
.0748 .47296 Mdot
.016 w
.0748 .47296 m
.07432 .47386 L
s
1 .83 0 r
.008 w
.07432 .47386 Mdot
.016 w
.07432 .47386 m
.0739 .47495 L
s
1 .811 0 r
.008 w
.0739 .47495 Mdot
.016 w
.0739 .47495 m
.07352 .47609 L
s
1 .792 0 r
.008 w
.07352 .47609 Mdot
.016 w
.07352 .47609 m
.07314 .4773 L
s
1 .774 0 r
.008 w
.07314 .4773 Mdot
.016 w
.07314 .4773 m
.07285 .47855 L
s
1 .755 0 r
.008 w
.07285 .47855 Mdot
.016 w
.07285 .47855 m
.07262 .47968 L
s
1 .736 0 r
.008 w
.07262 .47968 Mdot
.016 w
.07262 .47968 m
.07248 .48076 L
s
1 .717 0 r
.008 w
.07248 .48076 Mdot
.016 w
.07248 .48076 m
.07239 .48175 L
s
1 .698 0 r
.008 w
.07239 .48175 Mdot
.016 w
.07239 .48175 m
.07237 .48264 L
s
1 .679 0 r
.008 w
.07237 .48264 Mdot
.016 w
.07237 .48264 m
.07238 .48342 L
s
1 .66 0 r
.008 w
.07238 .48342 Mdot
.016 w
.07238 .48342 m
.0724 .48409 L
s
1 .642 0 r
.008 w
.0724 .48409 Mdot
.016 w
.0724 .48409 m
.07237 .4847 L
s
1 .623 0 r
.008 w
.07237 .4847 Mdot
.016 w
.07237 .4847 m
.07228 .48526 L
s
1 .604 0 r
.008 w
.07228 .48526 Mdot
.016 w
.07228 .48526 m
.07213 .48578 L
s
1 .585 0 r
.008 w
.07213 .48578 Mdot
.016 w
.07213 .48578 m
.07195 .48625 L
s
1 .566 0 r
.008 w
.07195 .48625 Mdot
.016 w
.07195 .48625 m
.07179 .48667 L
s
1 .547 0 r
.008 w
.07179 .48667 Mdot
.016 w
.07179 .48667 m
.07167 .48703 L
s
1 .528 0 r
.008 w
.07167 .48703 Mdot
.016 w
.07167 .48703 m
.07157 .48731 L
s
1 .509 0 r
.008 w
.07157 .48731 Mdot
.016 w
.07157 .48731 m
.0715 .4875 L
s
1 .491 0 r
.008 w
.0715 .4875 Mdot
.016 w
.0715 .4875 m
.07148 .48765 L
s
1 .472 0 r
.008 w
.07148 .48765 Mdot
.016 w
.07148 .48765 m
.07149 .48778 L
s
1 .453 0 r
.008 w
.07149 .48778 Mdot
.016 w
.07149 .48778 m
.07153 .48796 L
s
1 .434 0 r
.008 w
.07153 .48796 Mdot
.016 w
.07153 .48796 m
.07156 .48816 L
s
1 .415 0 r
.008 w
.07156 .48816 Mdot
.016 w
.07156 .48816 m
.07157 .48843 L
s
1 .396 0 r
.008 w
.07157 .48843 Mdot
.016 w
.07157 .48843 m
.07158 .48874 L
s
1 .377 0 r
.008 w
.07158 .48874 Mdot
.016 w
.07158 .48874 m
.07157 .48907 L
s
1 .358 0 r
.008 w
.07157 .48907 Mdot
.016 w
.07157 .48907 m
.07155 .48942 L
s
1 .34 0 r
.008 w
.07155 .48942 Mdot
.016 w
.07155 .48942 m
.07149 .48983 L
s
1 .321 0 r
.008 w
.07149 .48983 Mdot
.016 w
.07149 .48983 m
.07141 .49031 L
s
1 .302 0 r
.008 w
.07141 .49031 Mdot
.016 w
.07141 .49031 m
.07132 .49088 L
s
1 .283 0 r
.008 w
.07132 .49088 Mdot
.016 w
.07132 .49088 m
.07124 .49155 L
s
1 .264 0 r
.008 w
.07124 .49155 Mdot
.016 w
.07124 .49155 m
.07119 .49231 L
s
1 .245 0 r
.008 w
.07119 .49231 Mdot
.016 w
.07119 .49231 m
.07119 .49313 L
s
1 .226 0 r
.008 w
.07119 .49313 Mdot
.016 w
.07119 .49313 m
.07124 .49397 L
s
1 .208 0 r
.008 w
.07124 .49397 Mdot
.016 w
.07124 .49397 m
.07135 .49478 L
s
1 .189 0 r
.008 w
.07135 .49478 Mdot
.016 w
.07135 .49478 m
.07151 .49552 L
s
1 .17 0 r
.008 w
.07151 .49552 Mdot
.016 w
.07151 .49552 m
.07173 .49617 L
s
1 .151 0 r
.008 w
.07173 .49617 Mdot
.016 w
.07173 .49617 m
.07195 .49666 L
s
1 .132 0 r
.008 w
.07195 .49666 Mdot
.016 w
.07195 .49666 m
.07222 .49712 L
s
1 .113 0 r
.008 w
.07222 .49712 Mdot
.016 w
.07222 .49712 m
.07249 .49749 L
s
1 .094 0 r
.008 w
.07249 .49749 Mdot
.016 w
.07249 .49749 m
.07278 .49778 L
s
1 .075 0 r
.008 w
.07278 .49778 Mdot
.016 w
.07278 .49778 m
.07307 .498 L
s
1 .057 0 r
.008 w
.07307 .498 Mdot
.016 w
.07307 .498 m
.07335 .49816 L
s
1 .038 0 r
.008 w
.07335 .49816 Mdot
.016 w
.07335 .49816 m
.07359 .49826 L
s
1 .019 0 r
.008 w
.07359 .49826 Mdot
.016 w
.07359 .49826 m
.07379 .49831 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo01Io
o`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol05Goo1Sg_iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0EOol5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo01Eoo`DmknMoo`03001oogoo
00aoo`003Goo00<007ooOol05Goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`Ao`?Aoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo17mP00=oP7ooOol0lWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4Ob000gn0Oomoo`3b
Ool00`00Oomoo`0<Ool000aoo`03001oogoo00Uoo`An`003Oh1oogoo0?=oo`03001oogoo00]oo`00
37oo00<007ooOol02Goo17j000=oP7ooOol0lgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4
OJ000gi0Oomoo`3dOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Am0003ON1oogoo0?Aoo`03
001oogoo00]oo`0037oo00<007ooOol027oo17c000=mh7ooOol0m7oo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5O83fOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`9lP003O01lP7b00?Io
o`03001oogoo00]oo`0037oo00<007ooOol027oo0Wb000=l07b0O800mWoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool5O83fOol00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo
00<007ooOol02goo000=Ool00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo
00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eo
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@
Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007oo
Ool0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo
00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007oo
Ool057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo
01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo
000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`00
6Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]o
o`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol0
0`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<0
07ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001o
ogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uo
o`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol0
0`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<0
07ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001o
ogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomo
o`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0
:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uo
o`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool0
02eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^
Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo
00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`80
0;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00
Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007oo
Ool0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo
03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001o
ogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2
000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00
Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007oo
Ool0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00
Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo
00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00
E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo
0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00
Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3
000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020
Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00SGoo1000Sgoo
002=Ool00`00Oomoo`2@Ool008ioo`03001oogoo08moo`00Sgoo00<007ooOol0SWoo002=Ool01000
Oomoo`00Sgoo002>Ool2002@Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(3)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
1 .952 0 r
.008 w
.07393 .49306 Mdot
.016 w
.07393 .49306 m
.07403 .4929 L
s
1 .905 0 r
.008 w
.07403 .4929 Mdot
.016 w
.07403 .4929 m
.07407 .49262 L
s
1 .857 0 r
.008 w
.07407 .49262 Mdot
.016 w
.07407 .49262 m
.07405 .49217 L
s
1 .81 0 r
.008 w
.07405 .49217 Mdot
.016 w
.07405 .49217 m
.07396 .49156 L
s
1 .762 0 r
.008 w
.07396 .49156 Mdot
.016 w
.07396 .49156 m
.07382 .49079 L
s
1 .714 0 r
.008 w
.07382 .49079 Mdot
.016 w
.07382 .49079 m
.07369 .48993 L
s
1 .667 0 r
.008 w
.07369 .48993 Mdot
.016 w
.07369 .48993 m
.0736 .48896 L
s
1 .619 0 r
.008 w
.0736 .48896 Mdot
.016 w
.0736 .48896 m
.07357 .48791 L
s
1 .571 0 r
.008 w
.07357 .48791 Mdot
.016 w
.07357 .48791 m
.07359 .48683 L
s
1 .524 0 r
.008 w
.07359 .48683 Mdot
.016 w
.07359 .48683 m
.07368 .48576 L
s
1 .476 0 r
.008 w
.07368 .48576 Mdot
.016 w
.07368 .48576 m
.07383 .48473 L
s
1 .429 0 r
.008 w
.07383 .48473 Mdot
.016 w
.07383 .48473 m
.07408 .48378 L
s
1 .381 0 r
.008 w
.07408 .48378 Mdot
.016 w
.07408 .48378 m
.07438 .483 L
s
1 .333 0 r
.008 w
.07438 .483 Mdot
.016 w
.07438 .483 m
.07471 .48237 L
s
1 .286 0 r
.008 w
.07471 .48237 Mdot
.016 w
.07471 .48237 m
.07504 .48186 L
s
1 .238 0 r
.008 w
.07504 .48186 Mdot
.016 w
.07504 .48186 m
.07536 .48144 L
s
1 .19 0 r
.008 w
.07536 .48144 Mdot
.016 w
.07536 .48144 m
.07565 .48114 L
s
1 .143 0 r
.008 w
.07565 .48114 Mdot
.016 w
.07565 .48114 m
.07592 .48095 L
s
1 .095 0 r
.008 w
.07592 .48095 Mdot
.016 w
.07592 .48095 m
.07614 .48084 L
s
1 .048 0 r
.008 w
.07614 .48084 Mdot
.016 w
.07614 .48084 m
.07632 .4808 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo01Io
o`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol05Goo1Sg_iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0EOol5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo01Eoo`DmknMoo`03001oogoo
00aoo`003Goo00<007ooOol05Goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`@mkoAoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo1Cg_m7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool5?NodOol00`00Oomoo`0<Ool000ao
o`03001oogoo00Uoo`8mk`9lH003?Nmoogoo0?=oo`03001oogoo00]oo`0037oo00<007ooOol02Goo
00=lP7aPO2000WaPmGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool013g_O81lH7`P0WaPmGoo
00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_O81lP002O6000gb0Oomoo`3cOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`03?NmlP7b000=lP?Eoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo00<mkgfPOJ000WfPmWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_OV1nH002
OV3fOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03?Nmo87lP009o8?Ioo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo
00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?mo
o`Aoo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0goo00<007ooOol02goo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo
00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00
Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Woo00<007ooOol0ogoo00<0
07ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001o
ogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomo
o`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00io
o`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0
011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@
Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo
00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03
001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007oo
Ool0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo
0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3c
Ool00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo
00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03
001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00
Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007oo
Ool05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo
01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0H
Ool001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo
000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`00
77oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eo
o`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol0
0`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<0
07ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001o
ogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomo
o`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0
eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==o
o`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool0
0`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<0
07ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001o
ogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomo
o`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0
:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eo
o`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0
031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000b
Ool2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo
00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03
001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00
Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol0
0`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00
Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo
00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03
001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yo
o`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool0
04moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001C
Ool005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<0
06=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eo
o`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00
L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo
3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008ioo`80
091oo`00SGoo00@007ooOol008moo`00Sgoo00<007ooOol0SWoo002@Ool00`00Oomoo`2=Ool008eo
o`04001oogoo002?Ool008ioo`80091oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(4)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
1 .978 0 r
.008 w
.08931 .4591 Mdot
.016 w
.08931 .4591 m
.08931 .45905 L
s
1 .957 0 r
.008 w
.08931 .45905 Mdot
.016 w
.08931 .45905 m
.08934 .4589 L
s
1 .935 0 r
.008 w
.08934 .4589 Mdot
.016 w
.08934 .4589 m
.08944 .45867 L
s
1 .913 0 r
.008 w
.08944 .45867 Mdot
.016 w
.08944 .45867 m
.08962 .45835 L
s
1 .891 0 r
.008 w
.08962 .45835 Mdot
.016 w
.08962 .45835 m
.08988 .45795 L
s
1 .87 0 r
.008 w
.08988 .45795 Mdot
.016 w
.08988 .45795 m
.09023 .4575 L
s
1 .848 0 r
.008 w
.09023 .4575 Mdot
.016 w
.09023 .4575 m
.09064 .45702 L
s
1 .826 0 r
.008 w
.09064 .45702 Mdot
.016 w
.09064 .45702 m
.0911 .45651 L
s
1 .804 0 r
.008 w
.0911 .45651 Mdot
.016 w
.0911 .45651 m
.09155 .45594 L
s
1 .783 0 r
.008 w
.09155 .45594 Mdot
.016 w
.09155 .45594 m
.09196 .4553 L
s
1 .761 0 r
.008 w
.09196 .4553 Mdot
.016 w
.09196 .4553 m
.09232 .45462 L
s
1 .739 0 r
.008 w
.09232 .45462 Mdot
.016 w
.09232 .45462 m
.09261 .45386 L
s
1 .717 0 r
.008 w
.09261 .45386 Mdot
.016 w
.09261 .45386 m
.09286 .45302 L
s
1 .696 0 r
.008 w
.09286 .45302 Mdot
.016 w
.09286 .45302 m
.09305 .45217 L
s
1 .674 0 r
.008 w
.09305 .45217 Mdot
.016 w
.09305 .45217 m
.0932 .45127 L
s
1 .652 0 r
.008 w
.0932 .45127 Mdot
.016 w
.0932 .45127 m
.09333 .45032 L
s
1 .63 0 r
.008 w
.09333 .45032 Mdot
.016 w
.09333 .45032 m
.09344 .44936 L
s
1 .609 0 r
.008 w
.09344 .44936 Mdot
.016 w
.09344 .44936 m
.09355 .44839 L
s
1 .587 0 r
.008 w
.09355 .44839 Mdot
.016 w
.09355 .44839 m
.09365 .44746 L
s
1 .565 0 r
.008 w
.09365 .44746 Mdot
.016 w
.09365 .44746 m
.09375 .44653 L
s
1 .543 0 r
.008 w
.09375 .44653 Mdot
.016 w
.09375 .44653 m
.09387 .44563 L
s
1 .522 0 r
.008 w
.09387 .44563 Mdot
.016 w
.09387 .44563 m
.09402 .44479 L
s
1 .5 0 r
.008 w
.09402 .44479 Mdot
.016 w
.09402 .44479 m
.09422 .44403 L
s
1 .478 0 r
.008 w
.09422 .44403 Mdot
.016 w
.09422 .44403 m
.09446 .44341 L
s
1 .457 0 r
.008 w
.09446 .44341 Mdot
.016 w
.09446 .44341 m
.09476 .44292 L
s
1 .435 0 r
.008 w
.09476 .44292 Mdot
.016 w
.09476 .44292 m
.09508 .44261 L
s
1 .413 0 r
.008 w
.09508 .44261 Mdot
.016 w
.09508 .44261 m
.0954 .44249 L
s
1 .391 0 r
.008 w
.0954 .44249 Mdot
.016 w
.0954 .44249 m
.09571 .44254 L
s
1 .37 0 r
.008 w
.09571 .44254 Mdot
.016 w
.09571 .44254 m
.096 .44273 L
s
1 .348 0 r
.008 w
.096 .44273 Mdot
.016 w
.096 .44273 m
.09628 .44301 L
s
1 .326 0 r
.008 w
.09628 .44301 Mdot
.016 w
.09628 .44301 m
.09651 .44336 L
s
1 .304 0 r
.008 w
.09651 .44336 Mdot
.016 w
.09651 .44336 m
.09669 .44377 L
s
1 .283 0 r
.008 w
.09669 .44377 Mdot
.016 w
.09669 .44377 m
.09681 .44425 L
s
1 .261 0 r
.008 w
.09681 .44425 Mdot
.016 w
.09681 .44425 m
.09684 .4448 L
s
1 .239 0 r
.008 w
.09684 .4448 Mdot
.016 w
.09684 .4448 m
.09678 .44539 L
s
1 .217 0 r
.008 w
.09678 .44539 Mdot
.016 w
.09678 .44539 m
.09663 .44598 L
s
1 .196 0 r
.008 w
.09663 .44598 Mdot
.016 w
.09663 .44598 m
.09641 .44656 L
s
1 .174 0 r
.008 w
.09641 .44656 Mdot
.016 w
.09641 .44656 m
.09615 .44714 L
s
1 .152 0 r
.008 w
.09615 .44714 Mdot
.016 w
.09615 .44714 m
.09587 .44771 L
s
1 .13 0 r
.008 w
.09587 .44771 Mdot
.016 w
.09587 .44771 m
.09558 .4482 L
s
1 .109 0 r
.008 w
.09558 .4482 Mdot
.016 w
.09558 .4482 m
.09529 .4486 L
s
1 .087 0 r
.008 w
.09529 .4486 Mdot
.016 w
.09529 .4486 m
.09502 .44889 L
s
1 .065 0 r
.008 w
.09502 .44889 Mdot
.016 w
.09502 .44889 m
.09476 .44913 L
s
1 .043 0 r
.008 w
.09476 .44913 Mdot
.016 w
.09476 .44913 m
.09454 .4493 L
s
1 .022 0 r
.008 w
.09454 .4493 Mdot
.016 w
.09454 .4493 m
.09439 .44937 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0>Ool4O@05Ool4?NoVOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00eoo`03OP1lP7b0009lP0Aoo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo00=n
07b0O0000Wb00goo1Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool00gh0O81l0002O803
Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`03Of1n07b000=lP0=oo`DmknMoo`03
001oogoo00aoo`003Goo00<007ooOol037oo00=oH7i0O8000gb00goo1Cg_igoo00<007ooOol037oo
000=Ool00`00Oomoo`0<Ool00gmPOZ1nX002OZ3`Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uo
o`<mk`03Of1o07l0009o0?1oo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_17o0lGoo00<0
07ooOol037oo000=Ool00`00Oomoo`08Ool5?NodOol00`00Oomoo`0<Ool000aoo`03001oogoo00Uo
o`DmkoEoo`03001oogoo00]oo`0037oo00<007ooOol02Goo1Cg_mGoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nof
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool0
00aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol0
2goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001o
ogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000=Ool00`00Oomoo`3oOol3Ool0
0`00Oomoo`0;Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo
0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo
0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00
Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo
00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol0
37oo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eo
o`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool0
00moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?
Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo
00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00
Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007oo
Ool0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3g
Ool00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo
00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03
001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00
Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007oo
Ool04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo
01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0E
Ool001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo
000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`00
67oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uo
o`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol0
0`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<0
07ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001o
ogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0
ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol0
0`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<0
07ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001o
ogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomo
o`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol0
9Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Mo
o`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol0
02Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/
Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo
00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03
001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00
Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007oo
Ool0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo
03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0f
Ool003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomo
o`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0
XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03mo
o`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo
09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017
Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03
001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001k
Ool2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol0
05Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]o
o`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@0
06Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo
1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00Sgoo0`00SWoo002@Ool00`00Oomoo`2=Ool008eoo`D008ioo`00SGoo
00@007ooOol008moo`00SWoo00<007oo0000Sgoo002?Ool2002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(5)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
1 .985 0 r
.008 w
.09655 .44601 Mdot
.016 w
.09655 .44601 m
.09656 .44622 L
s
1 .97 0 r
.008 w
.09656 .44622 Mdot
.016 w
.09656 .44622 m
.0966 .44651 L
s
1 .955 0 r
.008 w
.0966 .44651 Mdot
.016 w
.0966 .44651 m
.09665 .44688 L
s
1 .94 0 r
.008 w
.09665 .44688 Mdot
.016 w
.09665 .44688 m
.09667 .4473 L
s
1 .925 0 r
.008 w
.09667 .4473 Mdot
.016 w
.09667 .4473 m
.09668 .44777 L
s
1 .91 0 r
.008 w
.09668 .44777 Mdot
.016 w
.09668 .44777 m
.09666 .44829 L
s
1 .896 0 r
.008 w
.09666 .44829 Mdot
.016 w
.09666 .44829 m
.09662 .44872 L
s
1 .881 0 r
.008 w
.09662 .44872 Mdot
.016 w
.09662 .44872 m
.09654 .44924 L
s
1 .866 0 r
.008 w
.09654 .44924 Mdot
.016 w
.09654 .44924 m
.09642 .44983 L
s
1 .851 0 r
.008 w
.09642 .44983 Mdot
.016 w
.09642 .44983 m
.09622 .45046 L
s
1 .836 0 r
.008 w
.09622 .45046 Mdot
.016 w
.09622 .45046 m
.09594 .4511 L
s
1 .821 0 r
.008 w
.09594 .4511 Mdot
.016 w
.09594 .4511 m
.09557 .45174 L
s
1 .806 0 r
.008 w
.09557 .45174 Mdot
.016 w
.09557 .45174 m
.09508 .45233 L
s
1 .791 0 r
.008 w
.09508 .45233 Mdot
.016 w
.09508 .45233 m
.09463 .45291 L
s
1 .776 0 r
.008 w
.09463 .45291 Mdot
.016 w
.09463 .45291 m
.09399 .45349 L
s
1 .761 0 r
.008 w
.09399 .45349 Mdot
.016 w
.09399 .45349 m
.09326 .45408 L
s
1 .746 0 r
.008 w
.09326 .45408 Mdot
.016 w
.09326 .45408 m
.09245 .45471 L
s
1 .731 0 r
.008 w
.09245 .45471 Mdot
.016 w
.09245 .45471 m
.09161 .45541 L
s
1 .716 0 r
.008 w
.09161 .45541 Mdot
.016 w
.09161 .45541 m
.09066 .45615 L
s
1 .701 0 r
.008 w
.09066 .45615 Mdot
.016 w
.09066 .45615 m
.08967 .45694 L
s
1 .687 0 r
.008 w
.08967 .45694 Mdot
.016 w
.08967 .45694 m
.08861 .45773 L
s
1 .672 0 r
.008 w
.08861 .45773 Mdot
.016 w
.08861 .45773 m
.08774 .45848 L
s
1 .657 0 r
.008 w
.08774 .45848 Mdot
.016 w
.08774 .45848 m
.087 .45918 L
s
1 .642 0 r
.008 w
.087 .45918 Mdot
.016 w
.087 .45918 m
.0863 .45983 L
s
1 .627 0 r
.008 w
.0863 .45983 Mdot
.016 w
.0863 .45983 m
.08576 .4604 L
s
1 .612 0 r
.008 w
.08576 .4604 Mdot
.016 w
.08576 .4604 m
.08535 .46093 L
s
1 .597 0 r
.008 w
.08535 .46093 Mdot
.016 w
.08535 .46093 m
.08512 .46143 L
s
1 .582 0 r
.008 w
.08512 .46143 Mdot
.016 w
.08512 .46143 m
.08507 .46189 L
s
1 .567 0 r
.008 w
.08507 .46189 Mdot
.016 w
.08507 .46189 m
.08518 .46232 L
s
1 .552 0 r
.008 w
.08518 .46232 Mdot
.016 w
.08518 .46232 m
.08539 .46273 L
s
1 .537 0 r
.008 w
.08539 .46273 Mdot
.016 w
.08539 .46273 m
.08567 .46311 L
s
1 .522 0 r
.008 w
.08567 .46311 Mdot
.016 w
.08567 .46311 m
.08601 .46345 L
s
1 .507 0 r
.008 w
.08601 .46345 Mdot
.016 w
.08601 .46345 m
.08639 .46373 L
s
1 .493 0 r
.008 w
.08639 .46373 Mdot
.016 w
.08639 .46373 m
.08685 .46394 L
s
1 .478 0 r
.008 w
.08685 .46394 Mdot
.016 w
.08685 .46394 m
.0872 .46411 L
s
1 .463 0 r
.008 w
.0872 .46411 Mdot
.016 w
.0872 .46411 m
.08759 .46427 L
s
1 .448 0 r
.008 w
.08759 .46427 Mdot
.016 w
.08759 .46427 m
.08793 .46442 L
s
1 .433 0 r
.008 w
.08793 .46442 Mdot
.016 w
.08793 .46442 m
.08819 .46456 L
s
1 .418 0 r
.008 w
.08819 .46456 Mdot
.016 w
.08819 .46456 m
.08829 .46464 L
s
1 .403 0 r
.008 w
.08829 .46464 Mdot
.016 w
.08829 .46464 m
.08831 .46466 L
s
1 .388 0 r
.008 w
.08831 .46466 Mdot
.016 w
.08831 .46466 m
.08821 .46464 L
s
1 .373 0 r
.008 w
.08821 .46464 Mdot
.016 w
.08821 .46464 m
.088 .46462 L
s
1 .358 0 r
.008 w
.088 .46462 Mdot
.016 w
.088 .46462 m
.0877 .46463 L
s
1 .343 0 r
.008 w
.0877 .46463 Mdot
.016 w
.0877 .46463 m
.08734 .46469 L
s
1 .328 0 r
.008 w
.08734 .46469 Mdot
.016 w
.08734 .46469 m
.08692 .46484 L
s
1 .313 0 r
.008 w
.08692 .46484 Mdot
.016 w
.08692 .46484 m
.08644 .46509 L
s
1 .299 0 r
.008 w
.08644 .46509 Mdot
.016 w
.08644 .46509 m
.08585 .46544 L
s
1 .284 0 r
.008 w
.08585 .46544 Mdot
.016 w
.08585 .46544 m
.0852 .46587 L
s
1 .269 0 r
.008 w
.0852 .46587 Mdot
.016 w
.0852 .46587 m
.0845 .46634 L
s
1 .254 0 r
.008 w
.0845 .46634 Mdot
.016 w
.0845 .46634 m
.08376 .46683 L
s
1 .239 0 r
.008 w
.08376 .46683 Mdot
.016 w
.08376 .46683 m
.08308 .46731 L
s
1 .224 0 r
.008 w
.08308 .46731 Mdot
.016 w
.08308 .46731 m
.08241 .4678 L
s
1 .209 0 r
.008 w
.08241 .4678 Mdot
.016 w
.08241 .4678 m
.08185 .46827 L
s
1 .194 0 r
.008 w
.08185 .46827 Mdot
.016 w
.08185 .46827 m
.08139 .4687 L
s
1 .179 0 r
.008 w
.08139 .4687 Mdot
.016 w
.08139 .4687 m
.08101 .46908 L
s
1 .164 0 r
.008 w
.08101 .46908 Mdot
.016 w
.08101 .46908 m
.0807 .46939 L
s
1 .149 0 r
.008 w
.0807 .46939 Mdot
.016 w
.0807 .46939 m
.08046 .4696 L
s
1 .134 0 r
.008 w
.08046 .4696 Mdot
.016 w
.08046 .4696 m
.08024 .46971 L
s
1 .119 0 r
.008 w
.08024 .46971 Mdot
.016 w
.08024 .46971 m
.07999 .46975 L
s
1 .104 0 r
.008 w
.07999 .46975 Mdot
.016 w
.07999 .46975 m
.07974 .46972 L
s
1 .09 0 r
.008 w
.07974 .46972 Mdot
.016 w
.07974 .46972 m
.07951 .46966 L
s
1 .075 0 r
.008 w
.07951 .46966 Mdot
.016 w
.07951 .46966 m
.07928 .46959 L
s
1 .06 0 r
.008 w
.07928 .46959 Mdot
.016 w
.07928 .46959 m
.07908 .46953 L
s
1 .045 0 r
.008 w
.07908 .46953 Mdot
.016 w
.07908 .46953 m
.0789 .46951 L
s
1 .03 0 r
.008 w
.0789 .46951 Mdot
.016 w
.0789 .46951 m
.07879 .46951 L
s
1 .015 0 r
.008 w
.07879 .46951 Mdot
.016 w
.07879 .46951 m
.07876 .46951 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eo
o`03?NmoX7nP009oX0Aoo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo00<mkgm0Od00
0Wm00goo1Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool4O^0017l0Oomoogoo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0<Ool4OZ000gk0O`1oo`02Ool5?NoWOol00`00Oomoo`0<
Ool000eoo`03001oogoo00]oo`An8003OX1n`7l000=oo`DmknMoo`03001oogoo00aoo`003Goo00<0
07ooOol02goo17d000=m@7k0O`00kgoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool2O402O000
17a0O>1m@7k0l7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool00cg_O41l0003O0000gcPOD1o
o`3`Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`03?Nml@7`000=l0003O>1m@7oo0?1oo`03
001oogoo00aoo`0037oo00<007ooOol02Goo00<mkga0O4000W`000=l@7cPOol0lWoo00<007ooOol0
2goo000<Ool00`00Oomoo`09Ool5?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo
17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo
0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00
Oomoo`3oOol4Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`=oo`03001oogoo00]oo`003Goo
00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol0
37oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001o
ogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo
0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000ioo`03001oogoo
0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3o
Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo
00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007oo
Ool03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo
00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?
Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo
000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`00
4Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=o
o`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol0
0`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<0
07ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001o
ogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomo
o`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0
kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eo
o`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool0
0`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001o
ogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomo
o`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol0
6goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01ao
o`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol0
01moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000P
Ool00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo
00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03
001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00
Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007oo
Ool0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo
0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39
Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo
00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03
001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00
Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007oo
Ool0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo
031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001o
ogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomo
o`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0
Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yo
o`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol0
03ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012
Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo
0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00
BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007oo
Ool0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00
Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo
001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001R
Ool3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4
001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007mo
o`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
002>Ool2002@Ool008eoo`04001oogoo002?Ool0091oo`03001oogoo08eoo`00SWoo0P00T7oo002>
Ool00`00Oomoo`2?Ool008ioo`<008moo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(6)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
1 .938 0 r
.008 w
.07182 .48132 Mdot
.016 w
.07182 .48132 m
.07181 .48142 L
s
1 .875 0 r
.008 w
.07181 .48142 Mdot
.016 w
.07181 .48142 m
.07177 .4817 L
s
1 .813 0 r
.008 w
.07177 .4817 Mdot
.016 w
.07177 .4817 m
.0717 .48221 L
s
1 .75 0 r
.008 w
.0717 .48221 Mdot
.016 w
.0717 .48221 m
.07161 .48293 L
s
1 .688 0 r
.008 w
.07161 .48293 Mdot
.016 w
.07161 .48293 m
.07151 .48379 L
s
1 .625 0 r
.008 w
.07151 .48379 Mdot
.016 w
.07151 .48379 m
.0714 .48473 L
s
1 .563 0 r
.008 w
.0714 .48473 Mdot
.016 w
.0714 .48473 m
.0713 .48569 L
s
1 .5 0 r
.008 w
.0713 .48569 Mdot
.016 w
.0713 .48569 m
.07122 .48667 L
s
1 .438 0 r
.008 w
.07122 .48667 Mdot
.016 w
.07122 .48667 m
.07114 .4876 L
s
1 .375 0 r
.008 w
.07114 .4876 Mdot
.016 w
.07114 .4876 m
.07105 .48846 L
s
1 .313 0 r
.008 w
.07105 .48846 Mdot
.016 w
.07105 .48846 m
.07094 .48927 L
s
1 .25 0 r
.008 w
.07094 .48927 Mdot
.016 w
.07094 .48927 m
.07084 .49003 L
s
1 .188 0 r
.008 w
.07084 .49003 Mdot
.016 w
.07084 .49003 m
.07073 .49059 L
s
1 .125 0 r
.008 w
.07073 .49059 Mdot
.016 w
.07073 .49059 m
.07063 .491 L
s
1 .063 0 r
.008 w
.07063 .491 Mdot
.016 w
.07063 .491 m
.07057 .49125 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eo
o`Dmk`Aoo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo1Cg_0goo1Sg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool5?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00aoo`Hmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uo
o`Pmko1oo`03001oogoo00aoo`003Goo00<007ooOol027oo23g_lGoo00<007ooOol037oo000=Ool0
0`00Oomoo`08Ool7?NobOol00`00Oomoo`0<Ool000aoo`03001oogoo00Uoo`Lmko=oo`03001oogoo
00]oo`0037oo00<007ooOol027oo17iP0Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4
OF02?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`9mH004O>1mH3g_?NoeOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`9mH004O41mH3g_?NoeOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Qoo`9mH003O41mH3g_0?Ioo`03001oogoo00]oo`0037oo00<007ooOol027oo17eP00<mkgoo
Ool0m7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo
000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000eoo`03001oogoo0?moo`=oo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0Woo
00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000ioo`03001oogoo0?moo`03001oogoo00eo
o`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool0
00ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?
Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo
00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03
001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00
Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007oo
Ool0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3h
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo
00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03
001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00
Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007oo
Ool04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo
01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0D
Ool001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo
000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`00
67oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uo
o`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol0
0`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<0
07ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001o
ogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0
ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol0
0`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<0
07ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001o
ogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomo
o`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol0
9Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Io
o`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol0
02Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[
Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo
00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03
001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00
Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo
0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo
03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0e
Ool003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo
000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0
Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003mo
o`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo
09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2A
Ool00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2
001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00
Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2
001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001L
Ool005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol0
06Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qo
o`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00
SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002=Ool3002@Ool008eo
o`04001oogoo002?Ool008eoo`04001oogoo002?Ool008eoo`<0091oo`00SWoo00<007ooOol0Sgoo
002>Ool3002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(7)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
1 .971 0 r
.008 w
.07159 .48858 Mdot
.016 w
.07159 .48858 m
.07174 .48865 L
s
1 .943 0 r
.008 w
.07174 .48865 Mdot
.016 w
.07174 .48865 m
.07194 .48881 L
s
1 .914 0 r
.008 w
.07194 .48881 Mdot
.016 w
.07194 .48881 m
.07221 .48909 L
s
1 .886 0 r
.008 w
.07221 .48909 Mdot
.016 w
.07221 .48909 m
.07256 .48953 L
s
1 .857 0 r
.008 w
.07256 .48953 Mdot
.016 w
.07256 .48953 m
.07299 .4901 L
s
1 .829 0 r
.008 w
.07299 .4901 Mdot
.016 w
.07299 .4901 m
.0735 .49075 L
s
1 .8 0 r
.008 w
.0735 .49075 Mdot
.016 w
.0735 .49075 m
.07408 .49146 L
s
1 .771 0 r
.008 w
.07408 .49146 Mdot
.016 w
.07408 .49146 m
.07473 .49223 L
s
1 .743 0 r
.008 w
.07473 .49223 Mdot
.016 w
.07473 .49223 m
.07542 .49307 L
s
1 .714 0 r
.008 w
.07542 .49307 Mdot
.016 w
.07542 .49307 m
.0761 .49393 L
s
1 .686 0 r
.008 w
.0761 .49393 Mdot
.016 w
.0761 .49393 m
.07676 .49477 L
s
1 .657 0 r
.008 w
.07676 .49477 Mdot
.016 w
.07676 .49477 m
.07737 .49552 L
s
1 .629 0 r
.008 w
.07737 .49552 Mdot
.016 w
.07737 .49552 m
.07788 .4961 L
s
1 .6 0 r
.008 w
.07788 .4961 Mdot
.016 w
.07788 .4961 m
.07829 .49654 L
s
1 .571 0 r
.008 w
.07829 .49654 Mdot
.016 w
.07829 .49654 m
.07861 .49684 L
s
1 .543 0 r
.008 w
.07861 .49684 Mdot
.016 w
.07861 .49684 m
.07883 .49699 L
s
1 .514 0 r
.008 w
.07883 .49699 Mdot
.016 w
.07883 .49699 m
.07895 .497 L
s
1 .486 0 r
.008 w
.07895 .497 Mdot
.016 w
.07895 .497 m
.07897 .49688 L
s
1 .457 0 r
.008 w
.07897 .49688 Mdot
.016 w
.07897 .49688 m
.07885 .4966 L
s
1 .429 0 r
.008 w
.07885 .4966 Mdot
.016 w
.07885 .4966 m
.07858 .49617 L
s
1 .4 0 r
.008 w
.07858 .49617 Mdot
.016 w
.07858 .49617 m
.07818 .4956 L
s
1 .371 0 r
.008 w
.07818 .4956 Mdot
.016 w
.07818 .4956 m
.07766 .49492 L
s
1 .343 0 r
.008 w
.07766 .49492 Mdot
.016 w
.07766 .49492 m
.07705 .49414 L
s
1 .314 0 r
.008 w
.07705 .49414 Mdot
.016 w
.07705 .49414 m
.07639 .49331 L
s
1 .286 0 r
.008 w
.07639 .49331 Mdot
.016 w
.07639 .49331 m
.07571 .4925 L
s
1 .257 0 r
.008 w
.07571 .4925 Mdot
.016 w
.07571 .4925 m
.07502 .49178 L
s
1 .229 0 r
.008 w
.07502 .49178 Mdot
.016 w
.07502 .49178 m
.07437 .49117 L
s
1 .2 0 r
.008 w
.07437 .49117 Mdot
.016 w
.07437 .49117 m
.07377 .49066 L
s
1 .171 0 r
.008 w
.07377 .49066 Mdot
.016 w
.07377 .49066 m
.07323 .49026 L
s
1 .143 0 r
.008 w
.07323 .49026 Mdot
.016 w
.07323 .49026 m
.07273 .48994 L
s
1 .114 0 r
.008 w
.07273 .48994 Mdot
.016 w
.07273 .48994 m
.07229 .48967 L
s
1 .086 0 r
.008 w
.07229 .48967 Mdot
.016 w
.07229 .48967 m
.07191 .48948 L
s
1 .057 0 r
.008 w
.07191 .48948 Mdot
.016 w
.07191 .48948 m
.07162 .48929 L
s
1 .029 0 r
.008 w
.07162 .48929 Mdot
.016 w
.07162 .48929 m
.07144 .48911 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eo
o`Dmk`Aoo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo1Cg_0goo1Sg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool5?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00aoo`Hmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uo
o`Pmko1oo`03001oogoo00aoo`003Goo00<007ooOol027oo23g_lGoo00<007ooOol037oo000=Ool0
0`00Oomoo`08Ool7?NobOol00`00Oomoo`0<Ool000aoo`03001oogoo00Uoo`Lmko=oo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool2?Nl2
On02?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`9l@004O01l@7a0?NoeOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`9l@004O01l@7a0O@3eOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Qoo`El@003O@1oogoo0?=oo`03001oogoo00]oo`0037oo00<007ooOol027oo1Ga000=m07oo
Ool0lgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_O>1lh002O>000gd0Oomoo`3cOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`8mk`AmH?Eoo`03001oogoo00]oo`0037oo00<007oo
Ool0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03
001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<
Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`=oo`03001oogoo00]o
o`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomo
o`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<0
07ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9o
o`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3o
Ool2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000ioo`03
001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00
Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007oo
Ool0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo
0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3m
Ool00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03
001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00
Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo
015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0A
Ool001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo
000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`00
57oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eo
o`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol0
0`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<0
07ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001o
ogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomo
o`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0
jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Mo
o`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol0
0`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<0
07ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001o
ogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomo
o`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol0
7Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01mo
o`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol0
02=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000T
Ool00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo
00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03
001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00
Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007oo
Ool0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo
0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2o
Ool00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo
00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03
001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eo
o`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol0
0`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<0
07ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001o
ogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomo
o`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002I
Ool20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007oo
Ool0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00
Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo
00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00
DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo
0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0
H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4
000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001i
Ool007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002@
Ool00`00Oomoo`2=Ool008eoo`04001oogoo002?Ool008eoo`@008moo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(8)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
1 .976 0 r
.008 w
.07124 .49794 Mdot
.016 w
.07124 .49794 m
.07125 .49775 L
s
1 .952 0 r
.008 w
.07125 .49775 Mdot
.016 w
.07125 .49775 m
.07126 .49749 L
s
1 .929 0 r
.008 w
.07126 .49749 Mdot
.016 w
.07126 .49749 m
.07127 .49714 L
s
1 .905 0 r
.008 w
.07127 .49714 Mdot
.016 w
.07127 .49714 m
.07129 .49669 L
s
1 .881 0 r
.008 w
.07129 .49669 Mdot
.016 w
.07129 .49669 m
.07131 .49614 L
s
1 .857 0 r
.008 w
.07131 .49614 Mdot
.016 w
.07131 .49614 m
.07133 .49551 L
s
1 .833 0 r
.008 w
.07133 .49551 Mdot
.016 w
.07133 .49551 m
.07135 .49481 L
s
1 .81 0 r
.008 w
.07135 .49481 Mdot
.016 w
.07135 .49481 m
.07137 .494 L
s
1 .786 0 r
.008 w
.07137 .494 Mdot
.016 w
.07137 .494 m
.07139 .49309 L
s
1 .762 0 r
.008 w
.07139 .49309 Mdot
.016 w
.07139 .49309 m
.07141 .49208 L
s
1 .738 0 r
.008 w
.07141 .49208 Mdot
.016 w
.07141 .49208 m
.07144 .49098 L
s
1 .714 0 r
.008 w
.07144 .49098 Mdot
.016 w
.07144 .49098 m
.07149 .48991 L
s
1 .69 0 r
.008 w
.07149 .48991 Mdot
.016 w
.07149 .48991 m
.07156 .48882 L
s
1 .667 0 r
.008 w
.07156 .48882 Mdot
.016 w
.07156 .48882 m
.07164 .48776 L
s
1 .643 0 r
.008 w
.07164 .48776 Mdot
.016 w
.07164 .48776 m
.07172 .48675 L
s
1 .619 0 r
.008 w
.07172 .48675 Mdot
.016 w
.07172 .48675 m
.07181 .48579 L
s
1 .595 0 r
.008 w
.07181 .48579 Mdot
.016 w
.07181 .48579 m
.07189 .48487 L
s
1 .571 0 r
.008 w
.07189 .48487 Mdot
.016 w
.07189 .48487 m
.07196 .48398 L
s
1 .548 0 r
.008 w
.07196 .48398 Mdot
.016 w
.07196 .48398 m
.07202 .48316 L
s
1 .524 0 r
.008 w
.07202 .48316 Mdot
.016 w
.07202 .48316 m
.07206 .48239 L
s
1 .5 0 r
.008 w
.07206 .48239 Mdot
.016 w
.07206 .48239 m
.07209 .48167 L
s
1 .476 0 r
.008 w
.07209 .48167 Mdot
.016 w
.07209 .48167 m
.07212 .481 L
s
1 .452 0 r
.008 w
.07212 .481 Mdot
.016 w
.07212 .481 m
.07213 .4804 L
s
1 .429 0 r
.008 w
.07213 .4804 Mdot
.016 w
.07213 .4804 m
.07212 .47984 L
s
1 .405 0 r
.008 w
.07212 .47984 Mdot
.016 w
.07212 .47984 m
.07208 .47934 L
s
1 .381 0 r
.008 w
.07208 .47934 Mdot
.016 w
.07208 .47934 m
.07202 .47888 L
s
1 .357 0 r
.008 w
.07202 .47888 Mdot
.016 w
.07202 .47888 m
.07194 .47849 L
s
1 .333 0 r
.008 w
.07194 .47849 Mdot
.016 w
.07194 .47849 m
.07188 .47811 L
s
1 .31 0 r
.008 w
.07188 .47811 Mdot
.016 w
.07188 .47811 m
.07184 .47781 L
s
1 .286 0 r
.008 w
.07184 .47781 Mdot
.016 w
.07184 .47781 m
.07186 .47749 L
s
1 .262 0 r
.008 w
.07186 .47749 Mdot
.016 w
.07186 .47749 m
.07194 .4772 L
s
1 .238 0 r
.008 w
.07194 .4772 Mdot
.016 w
.07194 .4772 m
.07209 .47694 L
s
1 .214 0 r
.008 w
.07209 .47694 Mdot
.016 w
.07209 .47694 m
.07229 .47674 L
s
1 .19 0 r
.008 w
.07229 .47674 Mdot
.016 w
.07229 .47674 m
.07255 .47663 L
s
1 .167 0 r
.008 w
.07255 .47663 Mdot
.016 w
.07255 .47663 m
.07285 .47657 L
s
1 .143 0 r
.008 w
.07285 .47657 Mdot
.016 w
.07285 .47657 m
.07318 .47656 L
s
1 .119 0 r
.008 w
.07318 .47656 Mdot
.016 w
.07318 .47656 m
.0735 .47657 L
s
1 .095 0 r
.008 w
.0735 .47657 Mdot
.016 w
.0735 .47657 m
.0738 .47659 L
s
1 .071 0 r
.008 w
.0738 .47659 Mdot
.016 w
.0738 .47659 m
.07409 .4766 L
s
1 .048 0 r
.008 w
.07409 .4766 Mdot
.016 w
.07409 .4766 m
.07432 .47661 L
s
1 .024 0 r
.008 w
.07432 .47661 Mdot
.016 w
.07432 .47661 m
.07449 .47663 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00
Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol05goo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0GOol4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eo
o`Dmk`Aoo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo1Cg_0goo1Sg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool5?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00aoo`Hmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uo
o`Pmko1oo`03001oogoo00aoo`003Goo00<007ooOol027oo00<mkgcPO>001Cg_lGoo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool017cPO01l07cP0cg_lWoo00<007ooOol037oo000<Ool00`00Oomo
o`08Ool00gcPO01l0002O0000gcP?Nlmk`3cOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03
O>1l07`0009l0003?Nmoogoo0?=oo`03001oogoo00]oo`0037oo00<007ooOol027oo00ImP7cPO01l
07f0?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`9mP004O>1mP7f0?NoeOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`03OP1m`7g0009m`003?Nmoogoo0?=oo`03001oogoo00]oo`00
37oo00<007ooOol027oo17i00Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4OZ02?Noe
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Anh003?Nmoogoo0?Aoo`03001oogoo00]oo`00
37oo00<007ooOol027oo17m000<mkgooOol0m7oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4
Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0
ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo0?moo`Aoo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0goo00<007ooOol02goo000=Ool0
0`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`00
3Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<
Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007oo
Ool037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03
001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2
Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Woo00<007ooOol0
ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol0
0`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001o
ogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00mo
o`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0
019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000B
Ool00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03
001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00
Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo
0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_
Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo
00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03
001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00
Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007oo
Ool06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo
01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0K
Ool001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo
000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`00
7goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021o
o`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<0
07ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomo
o`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0
cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uo
o`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool0
0`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<0
07ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001o
ogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomo
o`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0
<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007oo
Ool0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo
0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[
Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo
000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00
?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049o
o`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0
04Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019
Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomo
o`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001g
Ool2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol0
05]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069o
o`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@0
06eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo
3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
08ioo`80091oo`00SGoo00@007ooOol008moo`00SGoo00@007ooOol008moo`00SWoo0P00T7oo002=
Ool01000Oomoo`00Sgoo002>Ool2002@Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(9)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
1 .989 0 r
.008 w
.09074 .46306 Mdot
.016 w
.09074 .46306 m
.09086 .46294 L
s
1 .978 0 r
.008 w
.09086 .46294 Mdot
.016 w
.09086 .46294 m
.09101 .4627 L
s
1 .967 0 r
.008 w
.09101 .4627 Mdot
.016 w
.09101 .4627 m
.09122 .46234 L
s
1 .956 0 r
.008 w
.09122 .46234 Mdot
.016 w
.09122 .46234 m
.09154 .46184 L
s
1 .944 0 r
.008 w
.09154 .46184 Mdot
.016 w
.09154 .46184 m
.092 .4612 L
s
1 .933 0 r
.008 w
.092 .4612 Mdot
.016 w
.092 .4612 m
.09256 .46044 L
s
1 .922 0 r
.008 w
.09256 .46044 Mdot
.016 w
.09256 .46044 m
.09313 .45962 L
s
1 .911 0 r
.008 w
.09313 .45962 Mdot
.016 w
.09313 .45962 m
.0937 .45876 L
s
1 .9 0 r
.008 w
.0937 .45876 Mdot
.016 w
.0937 .45876 m
.09425 .45789 L
s
1 .889 0 r
.008 w
.09425 .45789 Mdot
.016 w
.09425 .45789 m
.09478 .45702 L
s
1 .878 0 r
.008 w
.09478 .45702 Mdot
.016 w
.09478 .45702 m
.0953 .45619 L
s
1 .867 0 r
.008 w
.0953 .45619 Mdot
.016 w
.0953 .45619 m
.09574 .45546 L
s
1 .856 0 r
.008 w
.09574 .45546 Mdot
.016 w
.09574 .45546 m
.09611 .45482 L
s
1 .844 0 r
.008 w
.09611 .45482 Mdot
.016 w
.09611 .45482 m
.09644 .45422 L
s
1 .833 0 r
.008 w
.09644 .45422 Mdot
.016 w
.09644 .45422 m
.09675 .45365 L
s
1 .822 0 r
.008 w
.09675 .45365 Mdot
.016 w
.09675 .45365 m
.09701 .4531 L
s
1 .811 0 r
.008 w
.09701 .4531 Mdot
.016 w
.09701 .4531 m
.09725 .45256 L
s
1 .8 0 r
.008 w
.09725 .45256 Mdot
.016 w
.09725 .45256 m
.09746 .45201 L
s
1 .789 0 r
.008 w
.09746 .45201 Mdot
.016 w
.09746 .45201 m
.09768 .45143 L
s
1 .778 0 r
.008 w
.09768 .45143 Mdot
.016 w
.09768 .45143 m
.0979 .45083 L
s
1 .767 0 r
.008 w
.0979 .45083 Mdot
.016 w
.0979 .45083 m
.09815 .4502 L
s
1 .756 0 r
.008 w
.09815 .4502 Mdot
.016 w
.09815 .4502 m
.09841 .44958 L
s
1 .744 0 r
.008 w
.09841 .44958 Mdot
.016 w
.09841 .44958 m
.09865 .44897 L
s
1 .733 0 r
.008 w
.09865 .44897 Mdot
.016 w
.09865 .44897 m
.09884 .44837 L
s
1 .722 0 r
.008 w
.09884 .44837 Mdot
.016 w
.09884 .44837 m
.09898 .44778 L
s
1 .711 0 r
.008 w
.09898 .44778 Mdot
.016 w
.09898 .44778 m
.09907 .44722 L
s
1 .7 0 r
.008 w
.09907 .44722 Mdot
.016 w
.09907 .44722 m
.09913 .44673 L
s
1 .689 0 r
.008 w
.09913 .44673 Mdot
.016 w
.09913 .44673 m
.09917 .44633 L
s
1 .678 0 r
.008 w
.09917 .44633 Mdot
.016 w
.09917 .44633 m
.09921 .44604 L
s
1 .667 0 r
.008 w
.09921 .44604 Mdot
.016 w
.09921 .44604 m
.09928 .44585 L
s
1 .656 0 r
.008 w
.09928 .44585 Mdot
.016 w
.09928 .44585 m
.09939 .44577 L
s
1 .644 0 r
.008 w
.09939 .44577 Mdot
.016 w
.09939 .44577 m
.09954 .44576 L
s
1 .633 0 r
.008 w
.09954 .44576 Mdot
.016 w
.09954 .44576 m
.09972 .4458 L
s
1 .622 0 r
.008 w
.09972 .4458 Mdot
.016 w
.09972 .4458 m
.09993 .44587 L
s
1 .611 0 r
.008 w
.09993 .44587 Mdot
.016 w
.09993 .44587 m
.10016 .44595 L
s
1 .6 0 r
.008 w
.10016 .44595 Mdot
.016 w
.10016 .44595 m
.10043 .44604 L
s
1 .589 0 r
.008 w
.10043 .44604 Mdot
.016 w
.10043 .44604 m
.10075 .44613 L
s
1 .578 0 r
.008 w
.10075 .44613 Mdot
.016 w
.10075 .44613 m
.10111 .44624 L
s
1 .567 0 r
.008 w
.10111 .44624 Mdot
.016 w
.10111 .44624 m
.10149 .44637 L
s
1 .556 0 r
.008 w
.10149 .44637 Mdot
.016 w
.10149 .44637 m
.10187 .44645 L
s
1 .544 0 r
.008 w
.10187 .44645 Mdot
.016 w
.10187 .44645 m
.10224 .44646 L
s
1 .533 0 r
.008 w
.10224 .44646 Mdot
.016 w
.10224 .44646 m
.10256 .44637 L
s
1 .522 0 r
.008 w
.10256 .44637 Mdot
.016 w
.10256 .44637 m
.10282 .44614 L
s
1 .511 0 r
.008 w
.10282 .44614 Mdot
.016 w
.10282 .44614 m
.10299 .44575 L
s
1 .5 0 r
.008 w
.10299 .44575 Mdot
.016 w
.10299 .44575 m
.10307 .4452 L
s
1 .489 0 r
.008 w
.10307 .4452 Mdot
.016 w
.10307 .4452 m
.10306 .44449 L
s
1 .478 0 r
.008 w
.10306 .44449 Mdot
.016 w
.10306 .44449 m
.10299 .44364 L
s
1 .467 0 r
.008 w
.10299 .44364 Mdot
.016 w
.10299 .44364 m
.10287 .44268 L
s
1 .456 0 r
.008 w
.10287 .44268 Mdot
.016 w
.10287 .44268 m
.10271 .44177 L
s
1 .444 0 r
.008 w
.10271 .44177 Mdot
.016 w
.10271 .44177 m
.1025 .44057 L
s
1 .433 0 r
.008 w
.1025 .44057 Mdot
.016 w
.1025 .44057 m
.10222 .43947 L
s
1 .422 0 r
.008 w
.10222 .43947 Mdot
.016 w
.10222 .43947 m
.10189 .4383 L
s
1 .411 0 r
.008 w
.10189 .4383 Mdot
.016 w
.10189 .4383 m
.10151 .43705 L
s
1 .4 0 r
.008 w
.10151 .43705 Mdot
.016 w
.10151 .43705 m
.10111 .43577 L
s
1 .389 0 r
.008 w
.10111 .43577 Mdot
.016 w
.10111 .43577 m
.10069 .43454 L
s
1 .378 0 r
.008 w
.10069 .43454 Mdot
.016 w
.10069 .43454 m
.10028 .43332 L
s
1 .367 0 r
.008 w
.10028 .43332 Mdot
.016 w
.10028 .43332 m
.09989 .43214 L
s
1 .356 0 r
.008 w
.09989 .43214 Mdot
.016 w
.09989 .43214 m
.09956 .43106 L
s
1 .344 0 r
.008 w
.09956 .43106 Mdot
.016 w
.09956 .43106 m
.09926 .43 L
s
1 .333 0 r
.008 w
.09926 .43 Mdot
.016 w
.09926 .43 m
.09896 .42897 L
s
1 .322 0 r
.008 w
.09896 .42897 Mdot
.016 w
.09896 .42897 m
.09868 .42794 L
s
1 .311 0 r
.008 w
.09868 .42794 Mdot
.016 w
.09868 .42794 m
.0984 .42697 L
s
1 .3 0 r
.008 w
.0984 .42697 Mdot
.016 w
.0984 .42697 m
.09814 .42604 L
s
1 .289 0 r
.008 w
.09814 .42604 Mdot
.016 w
.09814 .42604 m
.09788 .42518 L
s
1 .278 0 r
.008 w
.09788 .42518 Mdot
.016 w
.09788 .42518 m
.09767 .42444 L
s
1 .267 0 r
.008 w
.09767 .42444 Mdot
.016 w
.09767 .42444 m
.09746 .42384 L
s
1 .256 0 r
.008 w
.09746 .42384 Mdot
.016 w
.09746 .42384 m
.09728 .4234 L
s
1 .244 0 r
.008 w
.09728 .4234 Mdot
.016 w
.09728 .4234 m
.09714 .42311 L
s
1 .233 0 r
.008 w
.09714 .42311 Mdot
.016 w
.09714 .42311 m
.09706 .42296 L
s
1 .222 0 r
.008 w
.09706 .42296 Mdot
.016 w
.09706 .42296 m
.09704 .42292 L
s
1 .211 0 r
.008 w
.09704 .42292 Mdot
.016 w
.09704 .42292 m
.09708 .42294 L
s
1 .2 0 r
.008 w
.09708 .42294 Mdot
.016 w
.09708 .42294 m
.09714 .42298 L
s
1 .189 0 r
.008 w
.09714 .42298 Mdot
.016 w
.09714 .42298 m
.09721 .42298 L
s
1 .178 0 r
.008 w
.09721 .42298 Mdot
.016 w
.09721 .42298 m
.09725 .4229 L
s
1 .167 0 r
.008 w
.09725 .4229 Mdot
.016 w
.09725 .4229 m
.09722 .42267 L
s
1 .156 0 r
.008 w
.09722 .42267 Mdot
.016 w
.09722 .42267 m
.09709 .42228 L
s
1 .144 0 r
.008 w
.09709 .42228 Mdot
.016 w
.09709 .42228 m
.09688 .42175 L
s
1 .133 0 r
.008 w
.09688 .42175 Mdot
.016 w
.09688 .42175 m
.09658 .42109 L
s
1 .122 0 r
.008 w
.09658 .42109 Mdot
.016 w
.09658 .42109 m
.09623 .42031 L
s
1 .111 0 r
.008 w
.09623 .42031 Mdot
.016 w
.09623 .42031 m
.09586 .41955 L
s
1 .1 0 r
.008 w
.09586 .41955 Mdot
.016 w
.09586 .41955 m
.09546 .41871 L
s
1 .089 0 r
.008 w
.09546 .41871 Mdot
.016 w
.09546 .41871 m
.09507 .41776 L
s
1 .078 0 r
.008 w
.09507 .41776 Mdot
.016 w
.09507 .41776 m
.09468 .41701 L
s
1 .067 0 r
.008 w
.09468 .41701 Mdot
.016 w
.09468 .41701 m
.09429 .41622 L
s
1 .056 0 r
.008 w
.09429 .41622 Mdot
.016 w
.09429 .41622 m
.09395 .41553 L
s
1 .044 0 r
.008 w
.09395 .41553 Mdot
.016 w
.09395 .41553 m
.09364 .41492 L
s
1 .033 0 r
.008 w
.09364 .41492 Mdot
.016 w
.09364 .41492 m
.09337 .41438 L
s
1 .022 0 r
.008 w
.09337 .41438 Mdot
.016 w
.09337 .41438 m
.09314 .41405 L
s
1 .011 0 r
.008 w
.09314 .41405 Mdot
.016 w
.09314 .41405 m
.09294 .41386 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`0=Ool00g`P
Oomoo`3]Ool00`00Oomoo`0>Ool000moo`03001oogoo00aoo`=l8>ioo`03001oogoo00ioo`003goo
00<007ooOol02goo0W`P00=l07`PO200kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0<Ool2O200
17`0O21l87`PkGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool4O2000gc0Oomoo`3[Ool00`00
Oomoo`0=Ool000ioo`03001oogoo00eoo`05O61l87`PO61l`03]Ool00`00Oomoo`0=Ool000ioo`03
001oogoo00eoo`AlH003O@1oogoo0>]oo`03001oogoo00eoo`003Woo00<007ooOol03Goo17b000=m
07f0Ool0k7oo00<007ooOol037oo000=Ool00`00Oomoo`0?Ool4OB0017f0Oomoogoo13g_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0?Ool4OD0017f0Oomoogoo13g_iWoo00<007ooOol037oo000=
Ool00`00Oomoo`0=Ool2?Nl5OH02Ool5?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`8m
k`03OT1mX7fP009mX003Oolmkcg_00@mknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo00<m
kglPOT0017g000=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool013g_Oh1o
87i017gP00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;Ool2?Nl00gn0Of1n
h003O^02Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`8mk`05Oh1oH7mPOb1oH03_
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`@mk`03Oh1oH7mP009oH>moo`03001oogoo00ao
o`003Goo00<007ooOol027oo1Cg_17nPl7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool5?Nl4
Ol3`Ool00`00Oomoo`0<Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<0
07ooOol01goo1cg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`06Ool8?NoeOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Eoo`TmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo
00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo
00<007ooOol02goo000=Ool00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo
00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eo
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@
Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007oo
Ool0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo
00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007oo
Ool057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo
01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo
000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`00
6Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]o
o`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol0
0`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<0
07ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001o
ogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uo
o`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol0
0`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<0
07ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001o
ogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomo
o`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0
:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uo
o`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool0
02eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^
Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo
00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`80
0;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00
Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007oo
Ool0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo
03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001o
ogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2
000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00
Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007oo
Ool0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00
Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo
00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00
E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo
0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00
Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3
000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020
Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00SGoo0`00T7oo
002?Ool00`00Oomoo`2>Ool008ioo`<008moo`00SGoo00@007ooOol008moo`00SGoo00@007ooOol0
08moo`00SWoo0`00Sgoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(10)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
1 .981 0 r
.008 w
.08753 .40931 Mdot
.016 w
.08753 .40931 m
.08758 .40949 L
s
1 .963 0 r
.008 w
.08758 .40949 Mdot
.016 w
.08758 .40949 m
.08767 .40974 L
s
1 .944 0 r
.008 w
.08767 .40974 Mdot
.016 w
.08767 .40974 m
.08779 .41 L
s
1 .926 0 r
.008 w
.08779 .41 Mdot
.016 w
.08779 .41 m
.08794 .41032 L
s
1 .907 0 r
.008 w
.08794 .41032 Mdot
.016 w
.08794 .41032 m
.08815 .4106 L
s
1 .889 0 r
.008 w
.08815 .4106 Mdot
.016 w
.08815 .4106 m
.0884 .4108 L
s
1 .87 0 r
.008 w
.0884 .4108 Mdot
.016 w
.0884 .4108 m
.08871 .41084 L
s
1 .852 0 r
.008 w
.08871 .41084 Mdot
.016 w
.08871 .41084 m
.08906 .41068 L
s
1 .833 0 r
.008 w
.08906 .41068 Mdot
.016 w
.08906 .41068 m
.08945 .41027 L
s
1 .815 0 r
.008 w
.08945 .41027 Mdot
.016 w
.08945 .41027 m
.08988 .40962 L
s
1 .796 0 r
.008 w
.08988 .40962 Mdot
.016 w
.08988 .40962 m
.09034 .40876 L
s
1 .778 0 r
.008 w
.09034 .40876 Mdot
.016 w
.09034 .40876 m
.09083 .40785 L
s
1 .759 0 r
.008 w
.09083 .40785 Mdot
.016 w
.09083 .40785 m
.09132 .40686 L
s
1 .741 0 r
.008 w
.09132 .40686 Mdot
.016 w
.09132 .40686 m
.09177 .40588 L
s
1 .722 0 r
.008 w
.09177 .40588 Mdot
.016 w
.09177 .40588 m
.09221 .40498 L
s
1 .704 0 r
.008 w
.09221 .40498 Mdot
.016 w
.09221 .40498 m
.09261 .40431 L
s
1 .685 0 r
.008 w
.09261 .40431 Mdot
.016 w
.09261 .40431 m
.09296 .40382 L
s
1 .667 0 r
.008 w
.09296 .40382 Mdot
.016 w
.09296 .40382 m
.09324 .40352 L
s
1 .648 0 r
.008 w
.09324 .40352 Mdot
.016 w
.09324 .40352 m
.09345 .40342 L
s
1 .63 0 r
.008 w
.09345 .40342 Mdot
.016 w
.09345 .40342 m
.09358 .40353 L
s
1 .611 0 r
.008 w
.09358 .40353 Mdot
.016 w
.09358 .40353 m
.09363 .40383 L
s
1 .593 0 r
.008 w
.09363 .40383 Mdot
.016 w
.09363 .40383 m
.09358 .40422 L
s
1 .574 0 r
.008 w
.09358 .40422 Mdot
.016 w
.09358 .40422 m
.09343 .40467 L
s
1 .556 0 r
.008 w
.09343 .40467 Mdot
.016 w
.09343 .40467 m
.09318 .40516 L
s
1 .537 0 r
.008 w
.09318 .40516 Mdot
.016 w
.09318 .40516 m
.09285 .40561 L
s
1 .519 0 r
.008 w
.09285 .40561 Mdot
.016 w
.09285 .40561 m
.09249 .40597 L
s
1 .5 0 r
.008 w
.09249 .40597 Mdot
.016 w
.09249 .40597 m
.09211 .40622 L
s
1 .481 0 r
.008 w
.09211 .40622 Mdot
.016 w
.09211 .40622 m
.09172 .40636 L
s
1 .463 0 r
.008 w
.09172 .40636 Mdot
.016 w
.09172 .40636 m
.09135 .40645 L
s
1 .444 0 r
.008 w
.09135 .40645 Mdot
.016 w
.09135 .40645 m
.09101 .40657 L
s
1 .426 0 r
.008 w
.09101 .40657 Mdot
.016 w
.09101 .40657 m
.0907 .40674 L
s
1 .407 0 r
.008 w
.0907 .40674 Mdot
.016 w
.0907 .40674 m
.09043 .40698 L
s
1 .389 0 r
.008 w
.09043 .40698 Mdot
.016 w
.09043 .40698 m
.09018 .40726 L
s
1 .37 0 r
.008 w
.09018 .40726 Mdot
.016 w
.09018 .40726 m
.08996 .40756 L
s
1 .352 0 r
.008 w
.08996 .40756 Mdot
.016 w
.08996 .40756 m
.08979 .40799 L
s
1 .333 0 r
.008 w
.08979 .40799 Mdot
.016 w
.08979 .40799 m
.08969 .40852 L
s
1 .315 0 r
.008 w
.08969 .40852 Mdot
.016 w
.08969 .40852 m
.08969 .4091 L
s
1 .296 0 r
.008 w
.08969 .4091 Mdot
.016 w
.08969 .4091 m
.08982 .40969 L
s
1 .278 0 r
.008 w
.08982 .40969 Mdot
.016 w
.08982 .40969 m
.09007 .41025 L
s
1 .259 0 r
.008 w
.09007 .41025 Mdot
.016 w
.09007 .41025 m
.09045 .41073 L
s
1 .241 0 r
.008 w
.09045 .41073 Mdot
.016 w
.09045 .41073 m
.09094 .41108 L
s
1 .222 0 r
.008 w
.09094 .41108 Mdot
.016 w
.09094 .41108 m
.09154 .41126 L
s
1 .204 0 r
.008 w
.09154 .41126 Mdot
.016 w
.09154 .41126 m
.0922 .41126 L
s
1 .185 0 r
.008 w
.0922 .41126 Mdot
.016 w
.0922 .41126 m
.09291 .41107 L
s
1 .167 0 r
.008 w
.09291 .41107 Mdot
.016 w
.09291 .41107 m
.09361 .41068 L
s
1 .148 0 r
.008 w
.09361 .41068 Mdot
.016 w
.09361 .41068 m
.0943 .41014 L
s
1 .13 0 r
.008 w
.0943 .41014 Mdot
.016 w
.0943 .41014 m
.09496 .40954 L
s
1 .111 0 r
.008 w
.09496 .40954 Mdot
.016 w
.09496 .40954 m
.09558 .40892 L
s
1 .093 0 r
.008 w
.09558 .40892 Mdot
.016 w
.09558 .40892 m
.09614 .40832 L
s
1 .074 0 r
.008 w
.09614 .40832 Mdot
.016 w
.09614 .40832 m
.09661 .40776 L
s
1 .056 0 r
.008 w
.09661 .40776 Mdot
.016 w
.09661 .40776 m
.09698 .40729 L
s
1 .037 0 r
.008 w
.09698 .40729 Mdot
.016 w
.09698 .40729 m
.09724 .40693 L
s
1 .019 0 r
.008 w
.09724 .40693 Mdot
.016 w
.09724 .40693 m
.09738 .40673 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00]oo`An
@>ioo`03001oogoo00ioo`003goo00<007ooOol02Woo0WeP17a0kGoo00<007ooOol03Woo000?Ool0
0`00Oomoo`0:Ool01Wd0O81l@7a0O01l@>eoo`03001oogoo00ioo`003goo00<007ooOol02Woo00Im
07b0O41l@7`0O43]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`03O@1lP7a000=l@>eoo`03
001oogoo00ioo`003Woo00<007ooOol02goo00=m07b0O4000ga0kWoo00<007ooOol03Goo000>Ool0
0`00Oomoo`0=Ool5?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`Dmkneoo`03001oogoo
00eoo`003Woo00<007ooOol03Goo1Cg_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool6?No]
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00moo`Dmk`=oo`@mknIoo`03001oogoo00aoo`003Goo
00<007ooOol03goo1Cg_0goo13g_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool7?Nl2Ool5
?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`Lmk`03Oolmkcg_00@mknIoo`03001oogoo
00aoo`003Goo00<007ooOol03Goo1cg_00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00
Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`Lmk`=o
o`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_kgoo00<007ooOol037oo000=Ool0
0`00Oomoo`09Ool9?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Tmko1oo`03001oogoo
00aoo`003Goo00<007ooOol027oo2Cg_l7oo00<007ooOol037oo000<Ool00`00Oomoo`08Ool8?Noc
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`LmkoEoo`03001oogoo00]oo`0037oo00<007oo
Ool01Woo23g_mGoo00<007ooOol02goo000<Ool00`00Oomoo`05Ool9?NoeOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qo
o`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool0
0`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`00
37oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;
Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0goo00<007oo
Ool02goo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03
001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2
Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0
ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool0
0`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`00
3Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000io
o`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool0
0`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomo
o`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yo
o`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<0
07ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001o
ogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol0
4goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=o
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00
Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007oo
Ool0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo
025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0S
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo
000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uo
o`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<0
07ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001o
ogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomo
o`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0
^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=o
o`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000h
Ool00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo
00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03
001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045o
o`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol0
0`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018
Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomo
o`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00
DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3
001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00
Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol0
06aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025o
o`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol008Yoo`D0009oo`8008eoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yo
o`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00S7oo00D007ooOomoo`00009oo`03001o
ogoo08Yoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00Rgoo0P0017oo0P00SGoo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(11)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
1 .985 0 r
.008 w
.09447 .4114 Mdot
.016 w
.09447 .4114 m
.09446 .41156 L
s
1 .969 0 r
.008 w
.09446 .41156 Mdot
.016 w
.09446 .41156 m
.09446 .41185 L
s
1 .954 0 r
.008 w
.09446 .41185 Mdot
.016 w
.09446 .41185 m
.09447 .41226 L
s
1 .938 0 r
.008 w
.09447 .41226 Mdot
.016 w
.09447 .41226 m
.09449 .41278 L
s
1 .923 0 r
.008 w
.09449 .41278 Mdot
.016 w
.09449 .41278 m
.09454 .41336 L
s
1 .908 0 r
.008 w
.09454 .41336 Mdot
.016 w
.09454 .41336 m
.09463 .41399 L
s
1 .892 0 r
.008 w
.09463 .41399 Mdot
.016 w
.09463 .41399 m
.09477 .41465 L
s
1 .877 0 r
.008 w
.09477 .41465 Mdot
.016 w
.09477 .41465 m
.09496 .4153 L
s
1 .862 0 r
.008 w
.09496 .4153 Mdot
.016 w
.09496 .4153 m
.09518 .41599 L
s
1 .846 0 r
.008 w
.09518 .41599 Mdot
.016 w
.09518 .41599 m
.09542 .41673 L
s
1 .831 0 r
.008 w
.09542 .41673 Mdot
.016 w
.09542 .41673 m
.09568 .41751 L
s
1 .815 0 r
.008 w
.09568 .41751 Mdot
.016 w
.09568 .41751 m
.09594 .4183 L
s
1 .8 0 r
.008 w
.09594 .4183 Mdot
.016 w
.09594 .4183 m
.09619 .41911 L
s
1 .785 0 r
.008 w
.09619 .41911 Mdot
.016 w
.09619 .41911 m
.09644 .41995 L
s
1 .769 0 r
.008 w
.09644 .41995 Mdot
.016 w
.09644 .41995 m
.09667 .42085 L
s
1 .754 0 r
.008 w
.09667 .42085 Mdot
.016 w
.09667 .42085 m
.09687 .42174 L
s
1 .738 0 r
.008 w
.09687 .42174 Mdot
.016 w
.09687 .42174 m
.09705 .42272 L
s
1 .723 0 r
.008 w
.09705 .42272 Mdot
.016 w
.09705 .42272 m
.09716 .4238 L
s
1 .708 0 r
.008 w
.09716 .4238 Mdot
.016 w
.09716 .4238 m
.09721 .42502 L
s
1 .692 0 r
.008 w
.09721 .42502 Mdot
.016 w
.09721 .42502 m
.09719 .4264 L
s
1 .677 0 r
.008 w
.09719 .4264 Mdot
.016 w
.09719 .4264 m
.0971 .4278 L
s
1 .662 0 r
.008 w
.0971 .4278 Mdot
.016 w
.0971 .4278 m
.09698 .42929 L
s
1 .646 0 r
.008 w
.09698 .42929 Mdot
.016 w
.09698 .42929 m
.09686 .43085 L
s
1 .631 0 r
.008 w
.09686 .43085 Mdot
.016 w
.09686 .43085 m
.09675 .43243 L
s
1 .615 0 r
.008 w
.09675 .43243 Mdot
.016 w
.09675 .43243 m
.09667 .43398 L
s
1 .6 0 r
.008 w
.09667 .43398 Mdot
.016 w
.09667 .43398 m
.09658 .4356 L
s
1 .585 0 r
.008 w
.09658 .4356 Mdot
.016 w
.09658 .4356 m
.09647 .43721 L
s
1 .569 0 r
.008 w
.09647 .43721 Mdot
.016 w
.09647 .43721 m
.09634 .43892 L
s
1 .554 0 r
.008 w
.09634 .43892 Mdot
.016 w
.09634 .43892 m
.09616 .44056 L
s
1 .538 0 r
.008 w
.09616 .44056 Mdot
.016 w
.09616 .44056 m
.09596 .44225 L
s
1 .523 0 r
.008 w
.09596 .44225 Mdot
.016 w
.09596 .44225 m
.09573 .44393 L
s
1 .508 0 r
.008 w
.09573 .44393 Mdot
.016 w
.09573 .44393 m
.09548 .44548 L
s
1 .492 0 r
.008 w
.09548 .44548 Mdot
.016 w
.09548 .44548 m
.09522 .44702 L
s
1 .477 0 r
.008 w
.09522 .44702 Mdot
.016 w
.09522 .44702 m
.09498 .44846 L
s
1 .462 0 r
.008 w
.09498 .44846 Mdot
.016 w
.09498 .44846 m
.09476 .44971 L
s
1 .446 0 r
.008 w
.09476 .44971 Mdot
.016 w
.09476 .44971 m
.09454 .45074 L
s
1 .431 0 r
.008 w
.09454 .45074 Mdot
.016 w
.09454 .45074 m
.09434 .45163 L
s
1 .415 0 r
.008 w
.09434 .45163 Mdot
.016 w
.09434 .45163 m
.09415 .45233 L
s
1 .4 0 r
.008 w
.09415 .45233 Mdot
.016 w
.09415 .45233 m
.09399 .45283 L
s
1 .385 0 r
.008 w
.09399 .45283 Mdot
.016 w
.09399 .45283 m
.09384 .45312 L
s
1 .369 0 r
.008 w
.09384 .45312 Mdot
.016 w
.09384 .45312 m
.09372 .45324 L
s
1 .354 0 r
.008 w
.09372 .45324 Mdot
.016 w
.09372 .45324 m
.09363 .45325 L
s
1 .338 0 r
.008 w
.09363 .45325 Mdot
.016 w
.09363 .45325 m
.09361 .4532 L
s
1 .323 0 r
.008 w
.09361 .4532 Mdot
.016 w
.09361 .4532 m
.09364 .45312 L
s
1 .308 0 r
.008 w
.09364 .45312 Mdot
.016 w
.09364 .45312 m
.09375 .45305 L
s
1 .292 0 r
.008 w
.09375 .45305 Mdot
.016 w
.09375 .45305 m
.09393 .45303 L
s
1 .277 0 r
.008 w
.09393 .45303 Mdot
.016 w
.09393 .45303 m
.0941 .45312 L
s
1 .262 0 r
.008 w
.0941 .45312 Mdot
.016 w
.0941 .45312 m
.09417 .45336 L
s
1 .246 0 r
.008 w
.09417 .45336 Mdot
.016 w
.09417 .45336 m
.09412 .45376 L
s
1 .231 0 r
.008 w
.09412 .45376 Mdot
.016 w
.09412 .45376 m
.09393 .45432 L
s
1 .215 0 r
.008 w
.09393 .45432 Mdot
.016 w
.09393 .45432 m
.09355 .45503 L
s
1 .2 0 r
.008 w
.09355 .45503 Mdot
.016 w
.09355 .45503 m
.09294 .45586 L
s
1 .185 0 r
.008 w
.09294 .45586 Mdot
.016 w
.09294 .45586 m
.09208 .45678 L
s
1 .169 0 r
.008 w
.09208 .45678 Mdot
.016 w
.09208 .45678 m
.09106 .4578 L
s
1 .154 0 r
.008 w
.09106 .4578 Mdot
.016 w
.09106 .4578 m
.08998 .45887 L
s
1 .138 0 r
.008 w
.08998 .45887 Mdot
.016 w
.08998 .45887 m
.0889 .45996 L
s
1 .123 0 r
.008 w
.0889 .45996 Mdot
.016 w
.0889 .45996 m
.08789 .46095 L
s
1 .108 0 r
.008 w
.08789 .46095 Mdot
.016 w
.08789 .46095 m
.08694 .46189 L
s
1 .092 0 r
.008 w
.08694 .46189 Mdot
.016 w
.08694 .46189 m
.08596 .46275 L
s
1 .077 0 r
.008 w
.08596 .46275 Mdot
.016 w
.08596 .46275 m
.08495 .46346 L
s
1 .062 0 r
.008 w
.08495 .46346 Mdot
.016 w
.08495 .46346 m
.08399 .46405 L
s
1 .046 0 r
.008 w
.08399 .46405 Mdot
.016 w
.08399 .46405 m
.08325 .4645 L
s
1 .031 0 r
.008 w
.08325 .4645 Mdot
.016 w
.08325 .4645 m
.08281 .46482 L
s
1 .015 0 r
.008 w
.08281 .46482 Mdot
.016 w
.08281 .46482 m
.08261 .46503 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool2?Nl4On3]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`8mk`AoP>eoo`03001o
ogoo00ioo`003goo00<007ooOol02Woo0Sg_17lPkGoo00<007ooOol03Woo000>Ool00`00Oomoo`0;
Ool2?Nl4O^3^Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`An`003?Nmoogoo0>]oo`03001o
ogoo00eoo`003Woo00<007ooOol03Goo17j000<mkgooOol0jgoo00<007ooOol03Goo000>Ool00`00
Oomoo`0=Ool4OV000cg_Oomoo`3[Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`An@08mkneo
o`03001oogoo00aoo`003Goo00<007ooOol03Woo17hP0Sg_0goo13g_iWoo00<007ooOol037oo000=
Ool00`00Oomoo`0>Ool4OP02?Nl3Ool4?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`03
?Nmmh7gP009mh08mk`9oo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo00<mkgfPOJ00
0WfP0Sg_00=oocg_?Nl013g_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool5O<02?Nl00goo
?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`03O81l@7a0009lP004O<0mkcg_
Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`03?Nml@7a0009l@003O81l`7oo009o
o`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Woo1G`00Wa000=l`7ooOol0kGoo00<007oo
Ool037oo000=Ool00`00Oomoo`09Ool00cg_O01l0003O0000ga0O80mk`3_Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qoo`8mk`El0003O80mkgoo0>moo`03001oogoo00aoo`003Goo00<007ooOol0
27oo0Sg_1G`00Sg_l7oo00<007ooOol037oo000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Moo`LmkoEoo`03001oogoo00]oo`0037oo00<007ooOol01Woo23g_mGoo
00<007ooOol02goo000<Ool00`00Oomoo`05Ool9?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4
Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0
ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo0?moo`Aoo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0goo00<007ooOol02goo000=Ool0
0`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`00
3Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<
Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007oo
Ool037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03
001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2
Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Woo00<007ooOol0
ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol0
0`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001o
ogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00mo
o`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0
019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000B
Ool00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03
001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00
Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo
0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_
Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo
00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03
001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00
Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007oo
Ool06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo
01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0K
Ool001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo
000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`00
7goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021o
o`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<0
07ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomo
o`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0
cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uo
o`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool0
0`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<0
07ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001o
ogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomo
o`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0
<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007oo
Ool0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo
0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[
Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo
000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00
?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049o
o`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0
04Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019
Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomo
o`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001g
Ool2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol0
05]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069o
o`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@0
06eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo
3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
08Yoo`D00003Ool0000000<008]oo`00S7oo00<007ooOol00goo00<007ooOol0Rgoo002<Ool00`00
Oomoo`03Ool00`00Oomoo`2;Ool008aoo`03001oogoo00=oo`03001oogoo08]oo`00S7oo00<007oo
Ool00goo00<007ooOol0Rgoo002;Ool20004Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(12)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
1 .979 0 r
.008 w
.0828 .46487 Mdot
.016 w
.0828 .46487 m
.08297 .46486 L
s
1 .957 0 r
.008 w
.08297 .46486 Mdot
.016 w
.08297 .46486 m
.08324 .46484 L
s
1 .936 0 r
.008 w
.08324 .46484 Mdot
.016 w
.08324 .46484 m
.08358 .46481 L
s
1 .915 0 r
.008 w
.08358 .46481 Mdot
.016 w
.08358 .46481 m
.08396 .46476 L
s
1 .894 0 r
.008 w
.08396 .46476 Mdot
.016 w
.08396 .46476 m
.08436 .46469 L
s
1 .872 0 r
.008 w
.08436 .46469 Mdot
.016 w
.08436 .46469 m
.08473 .46459 L
s
1 .851 0 r
.008 w
.08473 .46459 Mdot
.016 w
.08473 .46459 m
.08505 .46446 L
s
1 .83 0 r
.008 w
.08505 .46446 Mdot
.016 w
.08505 .46446 m
.08533 .46432 L
s
1 .809 0 r
.008 w
.08533 .46432 Mdot
.016 w
.08533 .46432 m
.08561 .46418 L
s
1 .787 0 r
.008 w
.08561 .46418 Mdot
.016 w
.08561 .46418 m
.08589 .46406 L
s
1 .766 0 r
.008 w
.08589 .46406 Mdot
.016 w
.08589 .46406 m
.08616 .46396 L
s
1 .745 0 r
.008 w
.08616 .46396 Mdot
.016 w
.08616 .46396 m
.08641 .46384 L
s
1 .723 0 r
.008 w
.08641 .46384 Mdot
.016 w
.08641 .46384 m
.08666 .4637 L
s
1 .702 0 r
.008 w
.08666 .4637 Mdot
.016 w
.08666 .4637 m
.08694 .46353 L
s
1 .681 0 r
.008 w
.08694 .46353 Mdot
.016 w
.08694 .46353 m
.08722 .46333 L
s
1 .66 0 r
.008 w
.08722 .46333 Mdot
.016 w
.08722 .46333 m
.08755 .46308 L
s
1 .638 0 r
.008 w
.08755 .46308 Mdot
.016 w
.08755 .46308 m
.08791 .46278 L
s
1 .617 0 r
.008 w
.08791 .46278 Mdot
.016 w
.08791 .46278 m
.08842 .46237 L
s
1 .596 0 r
.008 w
.08842 .46237 Mdot
.016 w
.08842 .46237 m
.08889 .46189 L
s
1 .574 0 r
.008 w
.08889 .46189 Mdot
.016 w
.08889 .46189 m
.08954 .46127 L
s
1 .553 0 r
.008 w
.08954 .46127 Mdot
.016 w
.08954 .46127 m
.09027 .46051 L
s
1 .532 0 r
.008 w
.09027 .46051 Mdot
.016 w
.09027 .46051 m
.09108 .45965 L
s
1 .511 0 r
.008 w
.09108 .45965 Mdot
.016 w
.09108 .45965 m
.09184 .4587 L
s
1 .489 0 r
.008 w
.09184 .4587 Mdot
.016 w
.09184 .4587 m
.09258 .45766 L
s
1 .468 0 r
.008 w
.09258 .45766 Mdot
.016 w
.09258 .45766 m
.0933 .45657 L
s
1 .447 0 r
.008 w
.0933 .45657 Mdot
.016 w
.0933 .45657 m
.09393 .45548 L
s
1 .426 0 r
.008 w
.09393 .45548 Mdot
.016 w
.09393 .45548 m
.09447 .45449 L
s
1 .404 0 r
.008 w
.09447 .45449 Mdot
.016 w
.09447 .45449 m
.09493 .45358 L
s
1 .383 0 r
.008 w
.09493 .45358 Mdot
.016 w
.09493 .45358 m
.09531 .45278 L
s
1 .362 0 r
.008 w
.09531 .45278 Mdot
.016 w
.09531 .45278 m
.09565 .45216 L
s
1 .34 0 r
.008 w
.09565 .45216 Mdot
.016 w
.09565 .45216 m
.09594 .45164 L
s
1 .319 0 r
.008 w
.09594 .45164 Mdot
.016 w
.09594 .45164 m
.09617 .45122 L
s
1 .298 0 r
.008 w
.09617 .45122 Mdot
.016 w
.09617 .45122 m
.09635 .45087 L
s
1 .277 0 r
.008 w
.09635 .45087 Mdot
.016 w
.09635 .45087 m
.09647 .45052 L
s
1 .255 0 r
.008 w
.09647 .45052 Mdot
.016 w
.09647 .45052 m
.09655 .45014 L
s
1 .234 0 r
.008 w
.09655 .45014 Mdot
.016 w
.09655 .45014 m
.0966 .44976 L
s
1 .213 0 r
.008 w
.0966 .44976 Mdot
.016 w
.0966 .44976 m
.09661 .44944 L
s
1 .191 0 r
.008 w
.09661 .44944 Mdot
.016 w
.09661 .44944 m
.09659 .44914 L
s
1 .17 0 r
.008 w
.09659 .44914 Mdot
.016 w
.09659 .44914 m
.09656 .44884 L
s
1 .149 0 r
.008 w
.09656 .44884 Mdot
.016 w
.09656 .44884 m
.09652 .44848 L
s
1 .128 0 r
.008 w
.09652 .44848 Mdot
.016 w
.09652 .44848 m
.09649 .44814 L
s
1 .106 0 r
.008 w
.09649 .44814 Mdot
.016 w
.09649 .44814 m
.09646 .4478 L
s
1 .085 0 r
.008 w
.09646 .4478 Mdot
.016 w
.09646 .4478 m
.09642 .44746 L
s
1 .064 0 r
.008 w
.09642 .44746 Mdot
.016 w
.09642 .44746 m
.09637 .44713 L
s
1 .043 0 r
.008 w
.09637 .44713 Mdot
.016 w
.09637 .44713 m
.09632 .44679 L
s
1 .021 0 r
.008 w
.09632 .44679 Mdot
.016 w
.09632 .44679 m
.09631 .44653 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool6?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`Hmkneoo`03001oogoo00io
o`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool6?No^Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo`Dmkneoo`03001oogoo00eoo`003Woo00<007ooOol0
3Goo1Cg_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool5?No]Ool00`00Oomoo`0=Ool000io
o`03001oogoo00eoo`Hmkneoo`03001oogoo00aoo`003Goo00<007ooOol03Woo1Sg_0goo13g_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0>Ool6?Nl3Ool4?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`03?NmlH7aP009lH08mk`9oo`DmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo00DmkgaPO61l07aP008mk`03Oolmkcg_00@mknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo00DmkgaPO61l07aP008mk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol0
37oo00<mkgg0O6000gaP0Sg_00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;
Ool00cg_OR1m`004O603Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00Yoo`04On1nh7hP
OL04OD3_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`05?Nmoh7kPOR1m`004OJ3_Ool00`00
Oomoo`0<Ool000eoo`03001oogoo00Qoo`8mk`03On1nh7hP00An0?1oo`03001oogoo00aoo`003Goo
00<007ooOol027oo0Sg_00=oh7kPOV000giP00<mkgooOol0kWoo00<007ooOol037oo000<Ool00`00
Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`LmkoEoo`03001oogoo00]o
o`0037oo00<007ooOol01Woo23g_mGoo00<007ooOol02goo000<Ool00`00Oomoo`05Ool9?NoeOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol0
27oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000ao
o`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007oo
Ool02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03
001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4
Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`003Goo00<007ooOol0
ogoo0goo00<007ooOol02goo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool0
0`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`00
3Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<
Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007oo
Ool037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03
001oogoo00aoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00
Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007oo
Ool03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo
00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo
000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015o
o`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol0
0`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<0
07ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001o
ogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomo
o`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0
lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9o
o`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol0
0`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<0
07ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001o
ogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol0
5goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qo
o`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol0
01]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000L
Ool00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo
00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03
001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00
Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007oo
Ool0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo
0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3C
Ool00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo
00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03
001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00
Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007oo
Ool0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo
02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/
Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo
000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00
<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=o
o`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol0
0`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<0
07ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo
00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03
001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00
Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool0
0`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00
Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo
001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00
D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo
0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001P
Ool2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol4
0017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001e
Ool007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol008Yoo`D00003Ool00000008008aoo`00S7oo00D007ooOomo
o`0008moo`00S7oo00<007ooOol00Woo00<007ooOol0S7oo002<Ool00`00Oomoo`03Ool00`00Oomo
o`2;Ool008aoo`05001oogooOol00002Ool00`00Oomoo`2:Ool008]oo`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(13)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
1 .955 0 r
.008 w
.09913 .44617 Mdot
.016 w
.09913 .44617 m
.09933 .44599 L
s
1 .909 0 r
.008 w
.09933 .44599 Mdot
.016 w
.09933 .44599 m
.09966 .44572 L
s
1 .864 0 r
.008 w
.09966 .44572 Mdot
.016 w
.09966 .44572 m
.10015 .44536 L
s
1 .818 0 r
.008 w
.10015 .44536 Mdot
.016 w
.10015 .44536 m
.10083 .44495 L
s
1 .773 0 r
.008 w
.10083 .44495 Mdot
.016 w
.10083 .44495 m
.10163 .44449 L
s
1 .727 0 r
.008 w
.10163 .44449 Mdot
.016 w
.10163 .44449 m
.1026 .44401 L
s
1 .682 0 r
.008 w
.1026 .44401 Mdot
.016 w
.1026 .44401 m
.10367 .44353 L
s
1 .636 0 r
.008 w
.10367 .44353 Mdot
.016 w
.10367 .44353 m
.10483 .44306 L
s
1 .591 0 r
.008 w
.10483 .44306 Mdot
.016 w
.10483 .44306 m
.10607 .44259 L
s
1 .545 0 r
.008 w
.10607 .44259 Mdot
.016 w
.10607 .44259 m
.10734 .44216 L
s
1 .5 0 r
.008 w
.10734 .44216 Mdot
.016 w
.10734 .44216 m
.10856 .44178 L
s
1 .455 0 r
.008 w
.10856 .44178 Mdot
.016 w
.10856 .44178 m
.10974 .44147 L
s
1 .409 0 r
.008 w
.10974 .44147 Mdot
.016 w
.10974 .44147 m
.11085 .44126 L
s
1 .364 0 r
.008 w
.11085 .44126 Mdot
.016 w
.11085 .44126 m
.11183 .44113 L
s
1 .318 0 r
.008 w
.11183 .44113 Mdot
.016 w
.11183 .44113 m
.11268 .44109 L
s
1 .273 0 r
.008 w
.11268 .44109 Mdot
.016 w
.11268 .44109 m
.1134 .44111 L
s
1 .227 0 r
.008 w
.1134 .44111 Mdot
.016 w
.1134 .44111 m
.11399 .44116 L
s
1 .182 0 r
.008 w
.11399 .44116 Mdot
.016 w
.11399 .44116 m
.11447 .4412 L
s
1 .136 0 r
.008 w
.11447 .4412 Mdot
.016 w
.11447 .4412 m
.11483 .44125 L
s
1 .091 0 r
.008 w
.11483 .44125 Mdot
.016 w
.11483 .44125 m
.11505 .44129 L
s
1 .045 0 r
.008 w
.11505 .44129 Mdot
.016 w
.11505 .44129 m
.11514 .44134 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool6?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`Hmkneoo`03001oogoo00io
o`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool6?No^Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo`Dmkneoo`03001oogoo00eoo`003Woo00<007ooOol0
3Goo1Cg_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool5?No]Ool00`00Oomoo`0=Ool000io
o`03001oogoo00eoo`Hmkneoo`03001oogoo00aoo`003Goo00<007ooOol03Woo1Sg_0goo13g_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0>Ool2?Nl01gj0ON1m@7e0O:1l87e000@mknIoo`03001o
ogoo00aoo`003Goo00<007ooOol03Goo0Sg_00=o07j0ON000We000=lX7`POD0013g_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool2?Nl00gl0OX1mh005OD04?NoVOol00`00Oomoo`0<Ool000eo
o`03001oogoo00eoo`8mk`03O`1nP7gP00Em@0<mknMoo`03001oogoo00aoo`003Goo00<007ooOol0
37oo0cg_00=o07kPO^000WkP00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;
Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00Yoo`Pmknmoo`03001oogoo00ao
o`003Goo00<007ooOol02Goo2Cg_kgoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?No`Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Tmko1oo`03001oogoo00aoo`0037oo00<007ooOol0
27oo23g_lgoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7?NoeOol00`00Oomoo`0;Ool000ao
o`03001oogoo00Ioo`PmkoEoo`03001oogoo00]oo`0037oo00<007ooOol01Goo2Cg_mGoo00<007oo
Ool02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
koEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]o
o`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomo
o`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<0
07ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`=o
o`03001oogoo00]oo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3o
Ool2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03
001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=
Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00ao
o`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomo
o`0<Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eo
o`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?
Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00
Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo
0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3f
Ool00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo
00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00
Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007oo
Ool057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo
01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0F
Ool001Moo`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo
000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`00
6Goo00<007ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yo
o`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol0
0`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<0
07ooOol0hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001o
ogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomo
o`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0
gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]o
o`03001oogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol0
0`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<0
07ooOol08goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001o
ogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomo
o`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol0
9goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uo
o`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol0
02aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^
Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo
00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03
001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00
Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007oo
Ool0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo
03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03001o
ogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomo
o`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0
?goo0011Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007oo
Ool0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`80
04Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo
00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`80
07]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Mo
o`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00
Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo
1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001h
Ool7000QOol7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002:Ool50002Ool2002=Ool008aoo`05001oogooOol00002Ool00`00
Oomoo`2:Ool008aoo`03001oogoo00=oo`03001oogoo08]oo`00S7oo00<007ooOol017oo00<007oo
Ool0RWoo002<Ool01@00Oomoogoo00000Woo00<007ooOol0RWoo002;Ool20004Ool2002=Ool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(14)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
1 .969 0 r
.008 w
.11205 .442 Mdot
.016 w
.11205 .442 m
.11208 .44193 L
s
1 .938 0 r
.008 w
.11208 .44193 Mdot
.016 w
.11208 .44193 m
.11226 .44179 L
s
1 .906 0 r
.008 w
.11226 .44179 Mdot
.016 w
.11226 .44179 m
.11257 .44155 L
s
1 .875 0 r
.008 w
.11257 .44155 Mdot
.016 w
.11257 .44155 m
.11303 .44121 L
s
1 .844 0 r
.008 w
.11303 .44121 Mdot
.016 w
.11303 .44121 m
.11363 .44077 L
s
1 .813 0 r
.008 w
.11363 .44077 Mdot
.016 w
.11363 .44077 m
.11433 .44024 L
s
1 .781 0 r
.008 w
.11433 .44024 Mdot
.016 w
.11433 .44024 m
.11511 .43968 L
s
1 .75 0 r
.008 w
.11511 .43968 Mdot
.016 w
.11511 .43968 m
.11594 .43908 L
s
1 .719 0 r
.008 w
.11594 .43908 Mdot
.016 w
.11594 .43908 m
.11682 .43846 L
s
1 .688 0 r
.008 w
.11682 .43846 Mdot
.016 w
.11682 .43846 m
.11775 .43778 L
s
1 .656 0 r
.008 w
.11775 .43778 Mdot
.016 w
.11775 .43778 m
.11871 .43708 L
s
1 .625 0 r
.008 w
.11871 .43708 Mdot
.016 w
.11871 .43708 m
.11968 .43637 L
s
1 .594 0 r
.008 w
.11968 .43637 Mdot
.016 w
.11968 .43637 m
.12056 .43569 L
s
1 .563 0 r
.008 w
.12056 .43569 Mdot
.016 w
.12056 .43569 m
.12137 .43508 L
s
1 .531 0 r
.008 w
.12137 .43508 Mdot
.016 w
.12137 .43508 m
.12202 .43459 L
s
1 .5 0 r
.008 w
.12202 .43459 Mdot
.016 w
.12202 .43459 m
.12248 .43425 L
s
1 .469 0 r
.008 w
.12248 .43425 Mdot
.016 w
.12248 .43425 m
.12274 .43411 L
s
1 .438 0 r
.008 w
.12274 .43411 Mdot
.016 w
.12274 .43411 m
.12277 .43416 L
s
1 .406 0 r
.008 w
.12277 .43416 Mdot
.016 w
.12277 .43416 m
.12255 .4344 L
s
1 .375 0 r
.008 w
.12255 .4344 Mdot
.016 w
.12255 .4344 m
.12208 .43483 L
s
1 .344 0 r
.008 w
.12208 .43483 Mdot
.016 w
.12208 .43483 m
.12143 .4354 L
s
1 .313 0 r
.008 w
.12143 .4354 Mdot
.016 w
.12143 .4354 m
.12066 .43607 L
s
1 .281 0 r
.008 w
.12066 .43607 Mdot
.016 w
.12066 .43607 m
.1198 .4368 L
s
1 .25 0 r
.008 w
.1198 .4368 Mdot
.016 w
.1198 .4368 m
.11892 .43747 L
s
1 .219 0 r
.008 w
.11892 .43747 Mdot
.016 w
.11892 .43747 m
.11806 .43825 L
s
1 .188 0 r
.008 w
.11806 .43825 Mdot
.016 w
.11806 .43825 m
.1172 .43892 L
s
1 .156 0 r
.008 w
.1172 .43892 Mdot
.016 w
.1172 .43892 m
.11639 .43958 L
s
1 .125 0 r
.008 w
.11639 .43958 Mdot
.016 w
.11639 .43958 m
.11567 .44021 L
s
1 .094 0 r
.008 w
.11567 .44021 Mdot
.016 w
.11567 .44021 m
.11509 .44076 L
s
1 .063 0 r
.008 w
.11509 .44076 Mdot
.016 w
.11509 .44076 m
.11473 .4412 L
s
1 .031 0 r
.008 w
.11473 .4412 Mdot
.016 w
.11473 .4412 m
.1146 .44148 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool6?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`Hmkneoo`03001oogoo00io
o`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool6?No^Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo`Dmkneoo`03001oogoo00eoo`003Woo00<007ooOol0
3Goo1Cg_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool5?Nl3Ool2O>000gg0Oomoo`3UOol0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo`Hmk`03Oomlh7cP009lh003OL1oogoo0>Eoo`03001o
ogoo00aoo`003Goo00<007ooOol03Woo1Cg_1GaP0WcP00<mkgooOol0i7oo00<007ooOol037oo000=
Ool00`00Oomoo`0>Ool4?Nl017o0O61lH7`00WaP00=lh3g_?Nl0iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0=Ool5?Nl017o0O61lH7`00WaP0cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=
Ool5?Nl00go0O61lH003O603?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`Dmk`03Ol1l
H7aP009lH0<mknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl00cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03
001oogoo00Yoo`Pmknmoo`03001oogoo00aoo`003Goo00<007ooOol02Goo2Cg_kgoo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool9?No`Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Tmko1o
o`03001oogoo00aoo`0037oo00<007ooOol027oo23g_lgoo00<007ooOol02goo000<Ool00`00Oomo
o`07Ool7?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`PmkoEoo`03001oogoo00]oo`00
37oo00<007ooOol01Goo2Cg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo
000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000eoo`03001oogoo0?moo`=oo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0Woo
00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000ioo`03001oogoo0?moo`03001oogoo00eo
o`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool0
00ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?
Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo
00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03
001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00
Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007oo
Ool0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3h
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo
00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03
001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00
Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007oo
Ool04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo
01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0D
Ool001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo
000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`00
67oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uo
o`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol0
0`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<0
07ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001o
ogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0
ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol0
0`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<0
07ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001o
ogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomo
o`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol0
9Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Io
o`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol0
02Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[
Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo
00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03
001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00
Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo
0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo
03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0e
Ool003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo
000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0
Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003mo
o`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo
09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2A
Ool00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2
001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00
Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2
001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001L
Ool005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol0
06Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qo
o`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00
SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool50003Ool3002;
Ool008aoo`03001oogoo00Aoo`03001oogoo08Yoo`00S7oo00@007ooOomoo`D008]oo`00S7oo00D0
07ooOomoo`00009oo`03001oogoo08Yoo`00S7oo00<007ooOol00Woo00<007oo0000S7oo002;Ool2
0005Ool2002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(15)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
1 .98 0 r
.008 w
.11651 .44157 Mdot
.016 w
.11651 .44157 m
.11648 .44142 L
s
1 .96 0 r
.008 w
.11648 .44142 Mdot
.016 w
.11648 .44142 m
.1164 .44117 L
s
1 .94 0 r
.008 w
.1164 .44117 Mdot
.016 w
.1164 .44117 m
.11633 .44082 L
s
1 .92 0 r
.008 w
.11633 .44082 Mdot
.016 w
.11633 .44082 m
.11632 .44038 L
s
1 .9 0 r
.008 w
.11632 .44038 Mdot
.016 w
.11632 .44038 m
.1164 .43988 L
s
1 .88 0 r
.008 w
.1164 .43988 Mdot
.016 w
.1164 .43988 m
.11656 .43934 L
s
1 .86 0 r
.008 w
.11656 .43934 Mdot
.016 w
.11656 .43934 m
.11676 .43875 L
s
1 .84 0 r
.008 w
.11676 .43875 Mdot
.016 w
.11676 .43875 m
.11692 .43812 L
s
1 .82 0 r
.008 w
.11692 .43812 Mdot
.016 w
.11692 .43812 m
.11701 .43743 L
s
1 .8 0 r
.008 w
.11701 .43743 Mdot
.016 w
.11701 .43743 m
.11696 .4367 L
s
1 .78 0 r
.008 w
.11696 .4367 Mdot
.016 w
.11696 .4367 m
.11681 .43595 L
s
1 .76 0 r
.008 w
.11681 .43595 Mdot
.016 w
.11681 .43595 m
.11655 .43523 L
s
1 .74 0 r
.008 w
.11655 .43523 Mdot
.016 w
.11655 .43523 m
.11625 .43448 L
s
1 .72 0 r
.008 w
.11625 .43448 Mdot
.016 w
.11625 .43448 m
.11592 .43371 L
s
1 .7 0 r
.008 w
.11592 .43371 Mdot
.016 w
.11592 .43371 m
.11559 .43292 L
s
1 .68 0 r
.008 w
.11559 .43292 Mdot
.016 w
.11559 .43292 m
.11523 .43212 L
s
1 .66 0 r
.008 w
.11523 .43212 Mdot
.016 w
.11523 .43212 m
.11487 .43136 L
s
1 .64 0 r
.008 w
.11487 .43136 Mdot
.016 w
.11487 .43136 m
.11445 .43058 L
s
1 .62 0 r
.008 w
.11445 .43058 Mdot
.016 w
.11445 .43058 m
.11399 .42977 L
s
1 .6 0 r
.008 w
.11399 .42977 Mdot
.016 w
.11399 .42977 m
.11351 .42894 L
s
1 .58 0 r
.008 w
.11351 .42894 Mdot
.016 w
.11351 .42894 m
.11303 .42814 L
s
1 .56 0 r
.008 w
.11303 .42814 Mdot
.016 w
.11303 .42814 m
.11268 .42741 L
s
1 .54 0 r
.008 w
.11268 .42741 Mdot
.016 w
.11268 .42741 m
.11248 .42678 L
s
1 .52 0 r
.008 w
.11248 .42678 Mdot
.016 w
.11248 .42678 m
.1124 .42623 L
s
1 .5 0 r
.008 w
.1124 .42623 Mdot
.016 w
.1124 .42623 m
.11243 .42578 L
s
1 .48 0 r
.008 w
.11243 .42578 Mdot
.016 w
.11243 .42578 m
.11256 .42544 L
s
1 .46 0 r
.008 w
.11256 .42544 Mdot
.016 w
.11256 .42544 m
.11275 .42522 L
s
1 .44 0 r
.008 w
.11275 .42522 Mdot
.016 w
.11275 .42522 m
.11295 .42512 L
s
1 .42 0 r
.008 w
.11295 .42512 Mdot
.016 w
.11295 .42512 m
.11305 .42509 L
s
1 .4 0 r
.008 w
.11305 .42509 Mdot
.016 w
.11305 .42509 m
.113 .42509 L
s
1 .38 0 r
.008 w
.113 .42509 Mdot
.016 w
.113 .42509 m
.11279 .42509 L
s
1 .36 0 r
.008 w
.11279 .42509 Mdot
.016 w
.11279 .42509 m
.11242 .42507 L
s
1 .34 0 r
.008 w
.11242 .42507 Mdot
.016 w
.11242 .42507 m
.11185 .42503 L
s
1 .32 0 r
.008 w
.11185 .42503 Mdot
.016 w
.11185 .42503 m
.11111 .42495 L
s
1 .3 0 r
.008 w
.11111 .42495 Mdot
.016 w
.11111 .42495 m
.11024 .42482 L
s
1 .28 0 r
.008 w
.11024 .42482 Mdot
.016 w
.11024 .42482 m
.10934 .42468 L
s
1 .26 0 r
.008 w
.10934 .42468 Mdot
.016 w
.10934 .42468 m
.10848 .42455 L
s
1 .24 0 r
.008 w
.10848 .42455 Mdot
.016 w
.10848 .42455 m
.1078 .42446 L
s
1 .22 0 r
.008 w
.1078 .42446 Mdot
.016 w
.1078 .42446 m
.10698 .4244 L
s
1 .2 0 r
.008 w
.10698 .4244 Mdot
.016 w
.10698 .4244 m
.10627 .42437 L
s
1 .18 0 r
.008 w
.10627 .42437 Mdot
.016 w
.10627 .42437 m
.10556 .42436 L
s
1 .16 0 r
.008 w
.10556 .42436 Mdot
.016 w
.10556 .42436 m
.1049 .42438 L
s
1 .14 0 r
.008 w
.1049 .42438 Mdot
.016 w
.1049 .42438 m
.10438 .42443 L
s
1 .12 0 r
.008 w
.10438 .42443 Mdot
.016 w
.10438 .42443 m
.1041 .42451 L
s
1 .1 0 r
.008 w
.1041 .42451 Mdot
.016 w
.1041 .42451 m
.10404 .42463 L
s
1 .08 0 r
.008 w
.10404 .42463 Mdot
.016 w
.10404 .42463 m
.10412 .42477 L
s
1 .06 0 r
.008 w
.10412 .42477 Mdot
.016 w
.10412 .42477 m
.1043 .42493 L
s
1 .04 0 r
.008 w
.1043 .42493 Mdot
.016 w
.1043 .42493 m
.10454 .42508 L
s
1 .02 0 r
.008 w
.10454 .42508 Mdot
.016 w
.10454 .42508 m
.10477 .42522 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool6?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Yoo`Hmkneoo`03001oogoo00io
o`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool6?No^Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo`8mk`ElP003O>1m@7oo0>Qoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo0Sg_0Wb000El07b0O81lh7e00>Uoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo0Sg_0Wb000El07b0O81lh7e0008mknMoo`03001oogoo00eoo`003Woo00<007ooOol03Goo
0Sg_1Gb000=lh7e0O/000Sg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool5?Nl4ON02O/02
?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`Dmk`AnH004O/0mkcg_?NoVOol00`00Oomo
o`0<Ool000eoo`03001oogoo00eoo`Lmk`04Ob1n`7k0Ob03?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`Lmk`Ao80<mknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo1cg_17nP0Sg_
igoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<
Ool000eoo`03001oogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Woo
23g_kgoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool9?No_Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`Tmko1oo`03001oogoo00aoo`003Goo00<007ooOol027oo2Cg_l7oo00<007ooOol0
37oo000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`LmkoEo
o`03001oogoo00]oo`0037oo00<007ooOol01Woo23g_mGoo00<007ooOol02goo000<Ool00`00Oomo
o`05Ool9?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool0
0`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`00
3Goo00<007ooOol0ogoo0goo00<007ooOol02goo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<
Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007oo
Ool037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03
001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2
Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0
ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo0?moo`9oo`03001oogoo00aoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00
Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007oo
Ool0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo
0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3m
Ool00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo
00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03
001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00
Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo
011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0A
Ool001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo
000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`00
57oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eo
o`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol0
0`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<0
07ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001o
ogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomo
o`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0
jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qo
o`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol0
0`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<0
07ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001o
ogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomo
o`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol0
7Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01mo
o`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0
029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000T
Ool00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo
00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03
001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00
Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007oo
Ool0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo
0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31
Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo
00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03
001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Ao
o`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol0
0`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<0
07ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uo
o`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomo
o`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00
Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007oo
Ool0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo
04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo
0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03
001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eo
o`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00
GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo
0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001c
Ool5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yoo`D0009oo`8008eoo`00S7oo00D0
07ooOomoo`00009oo`03001oogoo08Yoo`00S7oo00<007ooOol017oo00<007ooOol0RWoo002<Ool0
0`00Oomoo`02Ool2002=Ool008aoo`03001oogoo009oo`03001oogoo08aoo`00Rgoo0P0017oo0`00
S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(16)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
1 .968 0 r
.008 w
.105 .42536 Mdot
.016 w
.105 .42536 m
.10481 .4254 L
s
1 .935 0 r
.008 w
.10481 .4254 Mdot
.016 w
.10481 .4254 m
.10454 .42545 L
s
1 .903 0 r
.008 w
.10454 .42545 Mdot
.016 w
.10454 .42545 m
.1042 .42547 L
s
1 .871 0 r
.008 w
.1042 .42547 Mdot
.016 w
.1042 .42547 m
.10378 .42545 L
s
1 .839 0 r
.008 w
.10378 .42545 Mdot
.016 w
.10378 .42545 m
.10329 .42537 L
s
1 .806 0 r
.008 w
.10329 .42537 Mdot
.016 w
.10329 .42537 m
.10274 .42523 L
s
1 .774 0 r
.008 w
.10274 .42523 Mdot
.016 w
.10274 .42523 m
.10214 .42499 L
s
1 .742 0 r
.008 w
.10214 .42499 Mdot
.016 w
.10214 .42499 m
.10152 .42464 L
s
1 .71 0 r
.008 w
.10152 .42464 Mdot
.016 w
.10152 .42464 m
.10086 .42416 L
s
1 .677 0 r
.008 w
.10086 .42416 Mdot
.016 w
.10086 .42416 m
.10019 .42356 L
s
1 .645 0 r
.008 w
.10019 .42356 Mdot
.016 w
.10019 .42356 m
.09957 .42284 L
s
1 .613 0 r
.008 w
.09957 .42284 Mdot
.016 w
.09957 .42284 m
.09904 .422 L
s
1 .581 0 r
.008 w
.09904 .422 Mdot
.016 w
.09904 .422 m
.09863 .42107 L
s
1 .548 0 r
.008 w
.09863 .42107 Mdot
.016 w
.09863 .42107 m
.09831 .42011 L
s
1 .516 0 r
.008 w
.09831 .42011 Mdot
.016 w
.09831 .42011 m
.09804 .41914 L
s
1 .484 0 r
.008 w
.09804 .41914 Mdot
.016 w
.09804 .41914 m
.09779 .41812 L
s
1 .452 0 r
.008 w
.09779 .41812 Mdot
.016 w
.09779 .41812 m
.09752 .4171 L
s
1 .419 0 r
.008 w
.09752 .4171 Mdot
.016 w
.09752 .4171 m
.09721 .41611 L
s
1 .387 0 r
.008 w
.09721 .41611 Mdot
.016 w
.09721 .41611 m
.09682 .41523 L
s
1 .355 0 r
.008 w
.09682 .41523 Mdot
.016 w
.09682 .41523 m
.09634 .41442 L
s
1 .323 0 r
.008 w
.09634 .41442 Mdot
.016 w
.09634 .41442 m
.09582 .4137 L
s
1 .29 0 r
.008 w
.09582 .4137 Mdot
.016 w
.09582 .4137 m
.0953 .41308 L
s
1 .258 0 r
.008 w
.0953 .41308 Mdot
.016 w
.0953 .41308 m
.09478 .41257 L
s
1 .226 0 r
.008 w
.09478 .41257 Mdot
.016 w
.09478 .41257 m
.0943 .41217 L
s
1 .194 0 r
.008 w
.0943 .41217 Mdot
.016 w
.0943 .41217 m
.09383 .41187 L
s
1 .161 0 r
.008 w
.09383 .41187 Mdot
.016 w
.09383 .41187 m
.09336 .41165 L
s
1 .129 0 r
.008 w
.09336 .41165 Mdot
.016 w
.09336 .41165 m
.09291 .41148 L
s
1 .097 0 r
.008 w
.09291 .41148 Mdot
.016 w
.09291 .41148 m
.09255 .41137 L
s
1 .065 0 r
.008 w
.09255 .41137 Mdot
.016 w
.09255 .41137 m
.0923 .4113 L
s
1 .032 0 r
.008 w
.0923 .4113 Mdot
.016 w
.0923 .4113 m
.09215 .41129 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool000moo`03001oogoo00eoo`8m
knioo`03001oogoo00ioo`003goo00<007ooOol02Woo1Sg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`0:Ool01Sg_O81l87`PO80mkneoo`03001oogoo00ioo`003goo00<007ooOol02Woo00<mkg`P
O2000W`P00=l`7ooOol0jgoo00<007ooOol03Woo000?Ool00`00Oomoo`0:Ool00cg_O21l8002O200
0gc0OL1oo`3[Ool00`00Oomoo`0>Ool000ioo`03001oogoo00]oo`07?NmlP7`PO21lP7c0OL00kGoo
00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool4O80017c0OL1n`7o00Sg_jGoo00<007ooOol03Goo
000>Ool00`00Oomoo`0=Ool4OF000gg0O/1o`002?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo
00eoo`03?Nmmh7gP009mh003O/1o`3g_00<mknMoo`03001oogoo00eoo`003Woo00<007ooOol03Goo
00<mkgiPOV000WiP00=n`7o0?Nl013g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoV
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007oo
Ool03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_
?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<
Ool000eoo`03001oogoo00Yoo`Pmknmoo`03001oogoo00aoo`003Goo00<007ooOol02Goo2Cg_kgoo
00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?No`Ool00`00Oomoo`0<Ool000eoo`03001oogoo
00Qoo`Tmko1oo`03001oogoo00aoo`0037oo00<007ooOol027oo23g_lgoo00<007ooOol02goo000<
Ool00`00Oomoo`07Ool7?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`PmkoEoo`03001o
ogoo00]oo`0037oo00<007ooOol01Goo2Cg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<0
07ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Ao
o`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3o
Ool4Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`=oo`03001oogoo00]oo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03
001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=
Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00ao
o`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomo
o`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<0
07ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000ioo`03001oogoo0?moo`03
001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00
Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007oo
Ool03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo
00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo
000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015o
o`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol0
0`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<0
07ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001o
ogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomo
o`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0
lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5o
o`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol0
0`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<0
07ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001o
ogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol0
67oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uo
o`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol0
01aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000M
Ool00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo
00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03
001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00
Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007oo
Ool0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo
0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3C
Ool00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo
00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03
001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00
Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007oo
Ool0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo
02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]
Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo
000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00
<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5o
o`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool0
0`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<0
07ooOol0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo
00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`80
09moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=o
o`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool0
0`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:
Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo
001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00
Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3
001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001E
Ool3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0
071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eo
o`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool5
000017oo00000000SGoo002<Ool01@00Oomoogoo00000Woo00<007ooOol0RWoo002<Ool01@00Oomo
ogoo00000Woo00<007ooOol0RWoo002<Ool01000Oomoogoo0`00SGoo002<Ool00`00Oomoo`02Ool0
0`00Oomoo`2<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(17)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
1 .955 0 r
.008 w
.08695 .40735 Mdot
.016 w
.08695 .40735 m
.08685 .40715 L
s
1 .909 0 r
.008 w
.08685 .40715 Mdot
.016 w
.08685 .40715 m
.0867 .40685 L
s
1 .864 0 r
.008 w
.0867 .40685 Mdot
.016 w
.0867 .40685 m
.08652 .40643 L
s
1 .818 0 r
.008 w
.08652 .40643 Mdot
.016 w
.08652 .40643 m
.08629 .40588 L
s
1 .773 0 r
.008 w
.08629 .40588 Mdot
.016 w
.08629 .40588 m
.08605 .40523 L
s
1 .727 0 r
.008 w
.08605 .40523 Mdot
.016 w
.08605 .40523 m
.08579 .40447 L
s
1 .682 0 r
.008 w
.08579 .40447 Mdot
.016 w
.08579 .40447 m
.08554 .40368 L
s
1 .636 0 r
.008 w
.08554 .40368 Mdot
.016 w
.08554 .40368 m
.08528 .40282 L
s
1 .591 0 r
.008 w
.08528 .40282 Mdot
.016 w
.08528 .40282 m
.08503 .40186 L
s
1 .545 0 r
.008 w
.08503 .40186 Mdot
.016 w
.08503 .40186 m
.08481 .40095 L
s
1 .5 0 r
.008 w
.08481 .40095 Mdot
.016 w
.08481 .40095 m
.08461 .40002 L
s
1 .455 0 r
.008 w
.08461 .40002 Mdot
.016 w
.08461 .40002 m
.08446 .39912 L
s
1 .409 0 r
.008 w
.08446 .39912 Mdot
.016 w
.08446 .39912 m
.08435 .39828 L
s
1 .364 0 r
.008 w
.08435 .39828 Mdot
.016 w
.08435 .39828 m
.0843 .39753 L
s
1 .318 0 r
.008 w
.0843 .39753 Mdot
.016 w
.0843 .39753 m
.08429 .39692 L
s
1 .273 0 r
.008 w
.08429 .39692 Mdot
.016 w
.08429 .39692 m
.08431 .39641 L
s
1 .227 0 r
.008 w
.08431 .39641 Mdot
.016 w
.08431 .39641 m
.08436 .39599 L
s
1 .182 0 r
.008 w
.08436 .39599 Mdot
.016 w
.08436 .39599 m
.08441 .39566 L
s
1 .136 0 r
.008 w
.08441 .39566 Mdot
.016 w
.08441 .39566 m
.08444 .39538 L
s
1 .091 0 r
.008 w
.08444 .39538 Mdot
.016 w
.08444 .39538 m
.08446 .39516 L
s
1 .045 0 r
.008 w
.08446 .39516 Mdot
.016 w
.08446 .39516 m
.08447 .395 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006Goo00<007ooOol0jGoo00<0
07ooOol067oo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomo
o`0GOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol0
5Woo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00
Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nWoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol027oo
00Am@7`PO21m@>moo`03001oogoo00moo`0047oo00<007ooOol027oo17`Pkgoo00<007ooOol03goo
000?Ool00`00Oomoo`09Ool4O202?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`05OD1l
87`POD1oH002?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Am@003Of0mkcg_0>eoo`03
001oogoo00ioo`003goo00<007ooOol02Goo17gP00=oH3g_?Nl0kGoo00<007ooOol03Woo000?Ool0
0`00Oomoo`09Ool4OZ0017mP?Nlmkcg_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool7?No]
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007oo
Ool03Goo2Cg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool0
00ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eo
o`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<m
knMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=
Ool00`00Oomoo`0:Ool8?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`Tmknmoo`03001o
ogoo00aoo`003Goo00<007ooOol027oo2Cg_l7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9
?No`Ool00`00Oomoo`0<Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<0
07ooOol01goo1cg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`06Ool8?NoeOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Eoo`TmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo
00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo
00<007ooOol02goo000=Ool00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo
00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eo
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@
Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007oo
Ool0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo
00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007oo
Ool057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo
01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo
000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`00
6Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]o
o`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol0
0`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<0
07ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001o
ogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uo
o`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol0
0`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<0
07ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001o
ogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomo
o`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0
:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uo
o`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool0
02eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^
Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo
00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`80
0;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00
Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007oo
Ool0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo
03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001o
ogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2
000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00
Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007oo
Ool0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00
Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo
00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00
E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo
0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00
Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3
000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020
Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo1@000goo
00<007ooOol0Rgoo002<Ool00`00Oomoo`03Ool00`00Oomoo`2;Ool008aoo`03001oogoo00=oo`03
001oogoo08]oo`00S7oo00<007ooOol017oo00<007ooOol0RWoo002<Ool01@00Oomoogoo00000Woo
00<007ooOol0RWoo002;Ool20003Ool4002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(18)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
1 .993 0 r
.008 w
.08438 .39535 Mdot
.016 w
.08438 .39535 m
.08448 .39522 L
s
1 .985 0 r
.008 w
.08448 .39522 Mdot
.016 w
.08448 .39522 m
.08463 .39503 L
s
1 .978 0 r
.008 w
.08463 .39503 Mdot
.016 w
.08463 .39503 m
.08481 .39476 L
s
1 .97 0 r
.008 w
.08481 .39476 Mdot
.016 w
.08481 .39476 m
.08501 .39442 L
s
1 .963 0 r
.008 w
.08501 .39442 Mdot
.016 w
.08501 .39442 m
.08522 .39398 L
s
1 .955 0 r
.008 w
.08522 .39398 Mdot
.016 w
.08522 .39398 m
.08542 .39344 L
s
1 .948 0 r
.008 w
.08542 .39344 Mdot
.016 w
.08542 .39344 m
.08562 .39282 L
s
1 .94 0 r
.008 w
.08562 .39282 Mdot
.016 w
.08562 .39282 m
.08581 .39214 L
s
1 .933 0 r
.008 w
.08581 .39214 Mdot
.016 w
.08581 .39214 m
.08602 .39138 L
s
1 .925 0 r
.008 w
.08602 .39138 Mdot
.016 w
.08602 .39138 m
.08626 .39053 L
s
1 .918 0 r
.008 w
.08626 .39053 Mdot
.016 w
.08626 .39053 m
.08654 .38961 L
s
1 .91 0 r
.008 w
.08654 .38961 Mdot
.016 w
.08654 .38961 m
.08686 .38868 L
s
1 .903 0 r
.008 w
.08686 .38868 Mdot
.016 w
.08686 .38868 m
.08716 .38771 L
s
1 .896 0 r
.008 w
.08716 .38771 Mdot
.016 w
.08716 .38771 m
.08743 .38674 L
s
1 .888 0 r
.008 w
.08743 .38674 Mdot
.016 w
.08743 .38674 m
.08772 .38582 L
s
1 .881 0 r
.008 w
.08772 .38582 Mdot
.016 w
.08772 .38582 m
.088 .38496 L
s
1 .873 0 r
.008 w
.088 .38496 Mdot
.016 w
.088 .38496 m
.08829 .3841 L
s
1 .866 0 r
.008 w
.08829 .3841 Mdot
.016 w
.08829 .3841 m
.08859 .38322 L
s
1 .858 0 r
.008 w
.08859 .38322 Mdot
.016 w
.08859 .38322 m
.08891 .38231 L
s
1 .851 0 r
.008 w
.08891 .38231 Mdot
.016 w
.08891 .38231 m
.08923 .38135 L
s
1 .843 0 r
.008 w
.08923 .38135 Mdot
.016 w
.08923 .38135 m
.08951 .38041 L
s
1 .836 0 r
.008 w
.08951 .38041 Mdot
.016 w
.08951 .38041 m
.08973 .37941 L
s
1 .828 0 r
.008 w
.08973 .37941 Mdot
.016 w
.08973 .37941 m
.08987 .37835 L
s
1 .821 0 r
.008 w
.08987 .37835 Mdot
.016 w
.08987 .37835 m
.08993 .37722 L
s
1 .813 0 r
.008 w
.08993 .37722 Mdot
.016 w
.08993 .37722 m
.0899 .37612 L
s
1 .806 0 r
.008 w
.0899 .37612 Mdot
.016 w
.0899 .37612 m
.08981 .3749 L
s
1 .799 0 r
.008 w
.08981 .3749 Mdot
.016 w
.08981 .3749 m
.08971 .3737 L
s
1 .791 0 r
.008 w
.08971 .3737 Mdot
.016 w
.08971 .3737 m
.08963 .37248 L
s
1 .784 0 r
.008 w
.08963 .37248 Mdot
.016 w
.08963 .37248 m
.08956 .37117 L
s
1 .776 0 r
.008 w
.08956 .37117 Mdot
.016 w
.08956 .37117 m
.08951 .36984 L
s
1 .769 0 r
.008 w
.08951 .36984 Mdot
.016 w
.08951 .36984 m
.0895 .36862 L
s
1 .761 0 r
.008 w
.0895 .36862 Mdot
.016 w
.0895 .36862 m
.0895 .36741 L
s
1 .754 0 r
.008 w
.0895 .36741 Mdot
.016 w
.0895 .36741 m
.08949 .36629 L
s
1 .746 0 r
.008 w
.08949 .36629 Mdot
.016 w
.08949 .36629 m
.08949 .36529 L
s
1 .739 0 r
.008 w
.08949 .36529 Mdot
.016 w
.08949 .36529 m
.08952 .36442 L
s
1 .731 0 r
.008 w
.08952 .36442 Mdot
.016 w
.08952 .36442 m
.08958 .36366 L
s
1 .724 0 r
.008 w
.08958 .36366 Mdot
.016 w
.08958 .36366 m
.08969 .363 L
s
1 .716 0 r
.008 w
.08969 .363 Mdot
.016 w
.08969 .363 m
.08983 .3624 L
s
1 .709 0 r
.008 w
.08983 .3624 Mdot
.016 w
.08983 .3624 m
.09 .36179 L
s
1 .701 0 r
.008 w
.09 .36179 Mdot
.016 w
.09 .36179 m
.09019 .36113 L
s
1 .694 0 r
.008 w
.09019 .36113 Mdot
.016 w
.09019 .36113 m
.09037 .36037 L
s
1 .687 0 r
.008 w
.09037 .36037 Mdot
.016 w
.09037 .36037 m
.09055 .35951 L
s
1 .679 0 r
.008 w
.09055 .35951 Mdot
.016 w
.09055 .35951 m
.09073 .3585 L
s
1 .672 0 r
.008 w
.09073 .3585 Mdot
.016 w
.09073 .3585 m
.09096 .35732 L
s
1 .664 0 r
.008 w
.09096 .35732 Mdot
.016 w
.09096 .35732 m
.09126 .35621 L
s
1 .657 0 r
.008 w
.09126 .35621 Mdot
.016 w
.09126 .35621 m
.09164 .35488 L
s
1 .649 0 r
.008 w
.09164 .35488 Mdot
.016 w
.09164 .35488 m
.0921 .35349 L
s
1 .642 0 r
.008 w
.0921 .35349 Mdot
.016 w
.0921 .35349 m
.09264 .35185 L
s
1 .634 0 r
.008 w
.09264 .35185 Mdot
.016 w
.09264 .35185 m
.09322 .35031 L
s
1 .627 0 r
.008 w
.09322 .35031 Mdot
.016 w
.09322 .35031 m
.09382 .34854 L
s
1 .619 0 r
.008 w
.09382 .34854 Mdot
.016 w
.09382 .34854 m
.09442 .34661 L
s
1 .612 0 r
.008 w
.09442 .34661 Mdot
.016 w
.09442 .34661 m
.09499 .3448 L
s
1 .604 0 r
.008 w
.09499 .3448 Mdot
.016 w
.09499 .3448 m
.09554 .34293 L
s
1 .597 0 r
.008 w
.09554 .34293 Mdot
.016 w
.09554 .34293 m
.09606 .3411 L
s
1 .59 0 r
.008 w
.09606 .3411 Mdot
.016 w
.09606 .3411 m
.09658 .33931 L
s
1 .582 0 r
.008 w
.09658 .33931 Mdot
.016 w
.09658 .33931 m
.09711 .33785 L
s
1 .575 0 r
.008 w
.09711 .33785 Mdot
.016 w
.09711 .33785 m
.09765 .33638 L
s
1 .567 0 r
.008 w
.09765 .33638 Mdot
.016 w
.09765 .33638 m
.09819 .33506 L
s
1 .56 0 r
.008 w
.09819 .33506 Mdot
.016 w
.09819 .33506 m
.09867 .33394 L
s
1 .552 0 r
.008 w
.09867 .33394 Mdot
.016 w
.09867 .33394 m
.09908 .3329 L
s
1 .545 0 r
.008 w
.09908 .3329 Mdot
.016 w
.09908 .3329 m
.09941 .33207 L
s
1 .537 0 r
.008 w
.09941 .33207 Mdot
.016 w
.09941 .33207 m
.09966 .3314 L
s
1 .53 0 r
.008 w
.09966 .3314 Mdot
.016 w
.09966 .3314 m
.09987 .33089 L
s
1 .522 0 r
.008 w
.09987 .33089 Mdot
.016 w
.09987 .33089 m
.10005 .33055 L
s
1 .515 0 r
.008 w
.10005 .33055 Mdot
.016 w
.10005 .33055 m
.10024 .3304 L
s
1 .507 0 r
.008 w
.10024 .3304 Mdot
.016 w
.10024 .3304 m
.10045 .33039 L
s
1 .5 0 r
.008 w
.10045 .33039 Mdot
.016 w
.10045 .33039 m
.10063 .3305 L
s
1 .493 0 r
.008 w
.10063 .3305 Mdot
.016 w
.10063 .3305 m
.10076 .33068 L
s
1 .485 0 r
.008 w
.10076 .33068 Mdot
.016 w
.10076 .33068 m
.10083 .33086 L
s
1 .478 0 r
.008 w
.10083 .33086 Mdot
.016 w
.10083 .33086 m
.10083 .33098 L
s
1 .47 0 r
.008 w
.10083 .33098 Mdot
.016 w
.10083 .33098 m
.10076 .33099 L
s
1 .463 0 r
.008 w
.10076 .33099 Mdot
.016 w
.10076 .33099 m
.10062 .33085 L
s
1 .455 0 r
.008 w
.10062 .33085 Mdot
.016 w
.10062 .33085 m
.10043 .33056 L
s
1 .448 0 r
.008 w
.10043 .33056 Mdot
.016 w
.10043 .33056 m
.10021 .3301 L
s
1 .44 0 r
.008 w
.10021 .3301 Mdot
.016 w
.10021 .3301 m
.09997 .3295 L
s
1 .433 0 r
.008 w
.09997 .3295 Mdot
.016 w
.09997 .3295 m
.09971 .32876 L
s
1 .425 0 r
.008 w
.09971 .32876 Mdot
.016 w
.09971 .32876 m
.09945 .32793 L
s
1 .418 0 r
.008 w
.09945 .32793 Mdot
.016 w
.09945 .32793 m
.09919 .3271 L
s
1 .41 0 r
.008 w
.09919 .3271 Mdot
.016 w
.09919 .3271 m
.09893 .32618 L
s
1 .403 0 r
.008 w
.09893 .32618 Mdot
.016 w
.09893 .32618 m
.09868 .32521 L
s
1 .396 0 r
.008 w
.09868 .32521 Mdot
.016 w
.09868 .32521 m
.09844 .32421 L
s
1 .388 0 r
.008 w
.09844 .32421 Mdot
.016 w
.09844 .32421 m
.09823 .32335 L
s
1 .381 0 r
.008 w
.09823 .32335 Mdot
.016 w
.09823 .32335 m
.09807 .32258 L
s
1 .373 0 r
.008 w
.09807 .32258 Mdot
.016 w
.09807 .32258 m
.09794 .32197 L
s
1 .366 0 r
.008 w
.09794 .32197 Mdot
.016 w
.09794 .32197 m
.09785 .32156 L
s
1 .358 0 r
.008 w
.09785 .32156 Mdot
.016 w
.09785 .32156 m
.09779 .32142 L
s
1 .351 0 r
.008 w
.09779 .32142 Mdot
.016 w
.09779 .32142 m
.09776 .32155 L
s
1 .343 0 r
.008 w
.09776 .32155 Mdot
.016 w
.09776 .32155 m
.09778 .32191 L
s
1 .336 0 r
.008 w
.09778 .32191 Mdot
.016 w
.09778 .32191 m
.09782 .32242 L
s
1 .328 0 r
.008 w
.09782 .32242 Mdot
.016 w
.09782 .32242 m
.09787 .32301 L
s
1 .321 0 r
.008 w
.09787 .32301 Mdot
.016 w
.09787 .32301 m
.09794 .3236 L
s
1 .313 0 r
.008 w
.09794 .3236 Mdot
.016 w
.09794 .3236 m
.09806 .32412 L
s
1 .306 0 r
.008 w
.09806 .32412 Mdot
.016 w
.09806 .32412 m
.09823 .32454 L
s
1 .299 0 r
.008 w
.09823 .32454 Mdot
.016 w
.09823 .32454 m
.09845 .32484 L
s
1 .291 0 r
.008 w
.09845 .32484 Mdot
.016 w
.09845 .32484 m
.09873 .32496 L
s
1 .284 0 r
.008 w
.09873 .32496 Mdot
.016 w
.09873 .32496 m
.09906 .3249 L
s
1 .276 0 r
.008 w
.09906 .3249 Mdot
.016 w
.09906 .3249 m
.09944 .32466 L
s
1 .269 0 r
.008 w
.09944 .32466 Mdot
.016 w
.09944 .32466 m
.09988 .32423 L
s
1 .261 0 r
.008 w
.09988 .32423 Mdot
.016 w
.09988 .32423 m
.10037 .32364 L
s
1 .254 0 r
.008 w
.10037 .32364 Mdot
.016 w
.10037 .32364 m
.1009 .32294 L
s
1 .246 0 r
.008 w
.1009 .32294 Mdot
.016 w
.1009 .32294 m
.10147 .32212 L
s
1 .239 0 r
.008 w
.10147 .32212 Mdot
.016 w
.10147 .32212 m
.10202 .3212 L
s
1 .231 0 r
.008 w
.10202 .3212 Mdot
.016 w
.10202 .3212 m
.10254 .32026 L
s
1 .224 0 r
.008 w
.10254 .32026 Mdot
.016 w
.10254 .32026 m
.10305 .3194 L
s
1 .216 0 r
.008 w
.10305 .3194 Mdot
.016 w
.10305 .3194 m
.10353 .31868 L
s
1 .209 0 r
.008 w
.10353 .31868 Mdot
.016 w
.10353 .31868 m
.10397 .31807 L
s
1 .201 0 r
.008 w
.10397 .31807 Mdot
.016 w
.10397 .31807 m
.10439 .31754 L
s
1 .194 0 r
.008 w
.10439 .31754 Mdot
.016 w
.10439 .31754 m
.10479 .31708 L
s
1 .187 0 r
.008 w
.10479 .31708 Mdot
.016 w
.10479 .31708 m
.10519 .31666 L
s
1 .179 0 r
.008 w
.10519 .31666 Mdot
.016 w
.10519 .31666 m
.1056 .31625 L
s
1 .172 0 r
.008 w
.1056 .31625 Mdot
.016 w
.1056 .31625 m
.10604 .31581 L
s
1 .164 0 r
.008 w
.10604 .31581 Mdot
.016 w
.10604 .31581 m
.10652 .3153 L
s
1 .157 0 r
.008 w
.10652 .3153 Mdot
.016 w
.10652 .3153 m
.10703 .31468 L
s
1 .149 0 r
.008 w
.10703 .31468 Mdot
.016 w
.10703 .31468 m
.10757 .31393 L
s
1 .142 0 r
.008 w
.10757 .31393 Mdot
.016 w
.10757 .31393 m
.10816 .31302 L
s
1 .134 0 r
.008 w
.10816 .31302 Mdot
.016 w
.10816 .31302 m
.1088 .31191 L
s
1 .127 0 r
.008 w
.1088 .31191 Mdot
.016 w
.1088 .31191 m
.10946 .31073 L
s
1 .119 0 r
.008 w
.10946 .31073 Mdot
.016 w
.10946 .31073 m
.11008 .30929 L
s
1 .112 0 r
.008 w
.11008 .30929 Mdot
.016 w
.11008 .30929 m
.1107 .30767 L
s
1 .104 0 r
.008 w
.1107 .30767 Mdot
.016 w
.1107 .30767 m
.11132 .30609 L
s
1 .097 0 r
.008 w
.11132 .30609 Mdot
.016 w
.11132 .30609 m
.11189 .30436 L
s
1 .09 0 r
.008 w
.11189 .30436 Mdot
.016 w
.11189 .30436 m
.11238 .30262 L
s
1 .082 0 r
.008 w
.11238 .30262 Mdot
.016 w
.11238 .30262 m
.11278 .30089 L
s
1 .075 0 r
.008 w
.11278 .30089 Mdot
.016 w
.11278 .30089 m
.1131 .29934 L
s
1 .067 0 r
.008 w
.1131 .29934 Mdot
.016 w
.1131 .29934 m
.11332 .29788 L
s
1 .06 0 r
.008 w
.11332 .29788 Mdot
.016 w
.11332 .29788 m
.11347 .29659 L
s
1 .052 0 r
.008 w
.11347 .29659 Mdot
.016 w
.11347 .29659 m
.11356 .29553 L
s
1 .045 0 r
.008 w
.11356 .29553 Mdot
.016 w
.11356 .29553 m
.11358 .29464 L
s
1 .037 0 r
.008 w
.11358 .29464 Mdot
.016 w
.11358 .29464 m
.11356 .29388 L
s
1 .03 0 r
.008 w
.11356 .29388 Mdot
.016 w
.11356 .29388 m
.11352 .29328 L
s
1 .022 0 r
.008 w
.11352 .29328 Mdot
.016 w
.11352 .29328 m
.11346 .29282 L
s
1 .015 0 r
.008 w
.11346 .29282 Mdot
.016 w
.11346 .29282 m
.1134 .29252 L
s
1 .007 0 r
.008 w
.1134 .29252 Mdot
.016 w
.1134 .29252 m
.11333 .29236 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Moo`03001oogoo0<eoo`03001oogoo02Ioo`009Woo00<007ooOol0cgoo00<007ooOol09Goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`00
97oo00<007ooOol0dgoo00<007ooOol08goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=ioo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001]oo`03001oogoo0>Eo
o`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000JOol00`00Oomoo`3WOol0
0`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`04O21l07`PO23MOol00`00Oomoo`0IOol001Uoo`03
001oogoo00Moo`04O21l07`PO23NOol00`00Oomoo`0HOol001Uoo`03001oogoo00Moo`04O21l07`P
O23NOol00`00Oomoo`0HOol001Qoo`03001oogoo00Moo`03O41l87`P009l8=moo`03001oogoo01Mo
o`0067oo00<007ooOol01goo00=l@7`PO2000W`Pggoo00<007ooOol05goo000HOol00`00Oomoo`06
Ool00gb0O41l@003O43OOol00`00Oomoo`0GOol001Moo`03001oogoo00Moo`03O81l@7a000=l@>1o
o`03001oogoo01Ioo`005goo00<007ooOol01Woo00=lX7b0O6000gaPhGoo00<007ooOol05Woo000F
Ool00`00Oomoo`06Ool00gcPO:1lP004O63ROol00`00Oomoo`0EOol001Ioo`03001oogoo00Ioo`9l
h0AlP>=oo`03001oogoo01Eoo`005Goo00<007ooOol01goo0gcP00=lX7cPOol0i7oo00<007ooOol0
57oo000EOol00`00Oomoo`07Ool5O>3UOol00`00Oomoo`0DOol001Eoo`03001oogoo00Ioo`03OT1m
07d0009m0003ON1oogoo0>=oo`03001oogoo01Aoo`0057oo00<007ooOol01goo00=n@7fPOJ000WfP
igoo00<007ooOol04goo000DOol00`00Oomoo`07Ool00gi0OR1n8002OR3WOol00`00Oomoo`0COol0
01Aoo`03001oogoo00Ioo`03OV1n@7i000=n@>Moo`03001oogoo01=oo`004goo00<007ooOol01goo
00=nH7i0OT000Wi0jGoo00<007ooOol04Woo000COol00`00Oomoo`07Ool5OV3YOol00`00Oomoo`0B
Ool001=oo`03001oogoo00Moo`EnH>Uoo`03001oogoo019oo`004Woo00<007ooOol01goo00=n`7j0
OX000Wj000=n`7ooOol0j7oo00<007ooOol04Goo000BOol00`00Oomoo`07Ool00gk0OX1nP002OX3[
Ool00`00Oomoo`0AOol0019oo`03001oogoo00Moo`03O^1nX7jP009nX>]oo`03001oogoo015oo`00
4Goo00<007ooOol027oo0WkP00=n`7kPOol0k7oo00<007ooOol047oo000AOol00`00Oomoo`08Ool4
O^3]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Qoo`Ao0>eoo`03001oogoo011oo`004Goo00<0
07ooOol027oo17lPkWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool00gnPOb1o8002Ob3^Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`03Oj1o@7m0009o@>ioo`03001oogoo00moo`0047oo
00<007ooOol027oo00=oX7mPOf000WmPkWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool00gnP
Oh1oP002Oh3^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`AoX08mknioo`03001oogoo00io
o`003goo00<007ooOol02Goo17o00cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]
Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007oo
Ool02Goo23g_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool7?No]Ool00`00Oomoo`0=Ool0
00ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2Cg_jGoo00<0
07ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eo
o``mknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo
00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoW
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00ao
o`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool8
?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`Tmknmoo`03001oogoo00aoo`003Goo00<0
07ooOol027oo2Cg_l7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?No`Ool00`00Oomoo`0<
Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<007ooOol01goo1cg_mGoo
00<007ooOol02goo000<Ool00`00Oomoo`06Ool8?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Eoo`TmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5
?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007oo
Ool0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03
001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000=
Ool00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00ao
o`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomo
o`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<0
07ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9o
o`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3o
Ool2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001o
ogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomo
o`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<007ooOol0
oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eo
o`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomoo`3lOol0
0`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<0
07ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001o
ogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol00`00Oomo
o`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<007ooOol0
47oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015o
o`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol0
01=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol04Woo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`005Goo
00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03
001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000FOol00`00
Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo00<007oo
Ool0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03001oogoo
0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00Oomoo`3Z
Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007ooOol0j7oo
00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo0>Eoo`03
001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3SOol00`00
Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo00<007oo
Ool077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo
01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0N
Ool001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo
000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo021oo`00
8Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Ao
o`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000UOol0
0`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Woo00<0
07ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qoo`03001o
ogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol00`00Oomo
o`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<007ooOol0
aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001oogoo0<5o
o`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomoo`2oOol0
0`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0^goo00<0
07ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=oo`00=7oo
00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03
001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000gOol00`00
Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo
0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo
03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001o
ogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol00`00Oomo
o`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<007ooOol0
A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool2
0023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0OGoo00<0
07ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo
001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001NOol2001N
Ool3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3
001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001aOol007=o
o`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D008ioo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo1@000Woo0P00SGoo002<Ool01@00
Oomoogoo00000Woo00<007ooOol0RWoo002<Ool01@00Oomoogoo00000Woo00<007ooOol0RWoo002<
Ool00`00Oomoo`02Ool2002=Ool008aoo`05001oogooOol00002Ool00`00Oomoo`2:Ool008]oo`80
00Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(19)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
1 .996 0 r
.008 w
.11315 .2931 Mdot
.016 w
.11315 .2931 m
.11331 .29307 L
s
1 .993 0 r
.008 w
.11331 .29307 Mdot
.016 w
.11331 .29307 m
.11361 .29294 L
s
1 .989 0 r
.008 w
.11361 .29294 Mdot
.016 w
.11361 .29294 m
.11404 .29268 L
s
1 .986 0 r
.008 w
.11404 .29268 Mdot
.016 w
.11404 .29268 m
.11463 .29229 L
s
1 .982 0 r
.008 w
.11463 .29229 Mdot
.016 w
.11463 .29229 m
.11536 .29178 L
s
1 .978 0 r
.008 w
.11536 .29178 Mdot
.016 w
.11536 .29178 m
.11625 .29112 L
s
1 .975 0 r
.008 w
.11625 .29112 Mdot
.016 w
.11625 .29112 m
.11731 .29033 L
s
1 .971 0 r
.008 w
.11731 .29033 Mdot
.016 w
.11731 .29033 m
.11842 .28943 L
s
1 .968 0 r
.008 w
.11842 .28943 Mdot
.016 w
.11842 .28943 m
.11967 .28847 L
s
1 .964 0 r
.008 w
.11967 .28847 Mdot
.016 w
.11967 .28847 m
.12087 .28743 L
s
1 .961 0 r
.008 w
.12087 .28743 Mdot
.016 w
.12087 .28743 m
.12212 .28636 L
s
1 .957 0 r
.008 w
.12212 .28636 Mdot
.016 w
.12212 .28636 m
.12336 .28532 L
s
1 .953 0 r
.008 w
.12336 .28532 Mdot
.016 w
.12336 .28532 m
.12444 .28444 L
s
1 .95 0 r
.008 w
.12444 .28444 Mdot
.016 w
.12444 .28444 m
.12548 .28368 L
s
1 .946 0 r
.008 w
.12548 .28368 Mdot
.016 w
.12548 .28368 m
.12644 .28305 L
s
1 .943 0 r
.008 w
.12644 .28305 Mdot
.016 w
.12644 .28305 m
.12728 .28255 L
s
1 .939 0 r
.008 w
.12728 .28255 Mdot
.016 w
.12728 .28255 m
.12797 .28215 L
s
1 .935 0 r
.008 w
.12797 .28215 Mdot
.016 w
.12797 .28215 m
.12853 .28182 L
s
1 .932 0 r
.008 w
.12853 .28182 Mdot
.016 w
.12853 .28182 m
.129 .28149 L
s
1 .928 0 r
.008 w
.129 .28149 Mdot
.016 w
.129 .28149 m
.12937 .28114 L
s
1 .925 0 r
.008 w
.12937 .28114 Mdot
.016 w
.12937 .28114 m
.12968 .28071 L
s
1 .921 0 r
.008 w
.12968 .28071 Mdot
.016 w
.12968 .28071 m
.12996 .28019 L
s
1 .918 0 r
.008 w
.12996 .28019 Mdot
.016 w
.12996 .28019 m
.13026 .27956 L
s
1 .914 0 r
.008 w
.13026 .27956 Mdot
.016 w
.13026 .27956 m
.13061 .27882 L
s
1 .91 0 r
.008 w
.13061 .27882 Mdot
.016 w
.13061 .27882 m
.131 .27794 L
s
1 .907 0 r
.008 w
.131 .27794 Mdot
.016 w
.131 .27794 m
.13143 .27705 L
s
1 .903 0 r
.008 w
.13143 .27705 Mdot
.016 w
.13143 .27705 m
.13189 .27607 L
s
1 .9 0 r
.008 w
.13189 .27607 Mdot
.016 w
.13189 .27607 m
.13238 .27505 L
s
1 .896 0 r
.008 w
.13238 .27505 Mdot
.016 w
.13238 .27505 m
.13287 .27401 L
s
1 .892 0 r
.008 w
.13287 .27401 Mdot
.016 w
.13287 .27401 m
.13336 .27304 L
s
1 .889 0 r
.008 w
.13336 .27304 Mdot
.016 w
.13336 .27304 m
.13384 .27214 L
s
1 .885 0 r
.008 w
.13384 .27214 Mdot
.016 w
.13384 .27214 m
.13429 .27135 L
s
1 .882 0 r
.008 w
.13429 .27135 Mdot
.016 w
.13429 .27135 m
.1347 .27075 L
s
1 .878 0 r
.008 w
.1347 .27075 Mdot
.016 w
.1347 .27075 m
.13507 .27031 L
s
1 .875 0 r
.008 w
.13507 .27031 Mdot
.016 w
.13507 .27031 m
.13539 .26998 L
s
1 .871 0 r
.008 w
.13539 .26998 Mdot
.016 w
.13539 .26998 m
.13564 .26973 L
s
1 .867 0 r
.008 w
.13564 .26973 Mdot
.016 w
.13564 .26973 m
.13582 .2695 L
s
1 .864 0 r
.008 w
.13582 .2695 Mdot
.016 w
.13582 .2695 m
.13594 .26922 L
s
1 .86 0 r
.008 w
.13594 .26922 Mdot
.016 w
.13594 .26922 m
.13603 .26883 L
s
1 .857 0 r
.008 w
.13603 .26883 Mdot
.016 w
.13603 .26883 m
.1361 .26829 L
s
1 .853 0 r
.008 w
.1361 .26829 Mdot
.016 w
.1361 .26829 m
.13619 .26761 L
s
1 .849 0 r
.008 w
.13619 .26761 Mdot
.016 w
.13619 .26761 m
.13631 .2668 L
s
1 .846 0 r
.008 w
.13631 .2668 Mdot
.016 w
.13631 .2668 m
.13647 .26592 L
s
1 .842 0 r
.008 w
.13647 .26592 Mdot
.016 w
.13647 .26592 m
.13664 .26513 L
s
1 .839 0 r
.008 w
.13664 .26513 Mdot
.016 w
.13664 .26513 m
.13684 .26407 L
s
1 .835 0 r
.008 w
.13684 .26407 Mdot
.016 w
.13684 .26407 m
.13706 .26307 L
s
1 .832 0 r
.008 w
.13706 .26307 Mdot
.016 w
.13706 .26307 m
.13727 .26199 L
s
1 .828 0 r
.008 w
.13727 .26199 Mdot
.016 w
.13727 .26199 m
.13747 .26083 L
s
1 .824 0 r
.008 w
.13747 .26083 Mdot
.016 w
.13747 .26083 m
.13764 .25958 L
s
1 .821 0 r
.008 w
.13764 .25958 Mdot
.016 w
.13764 .25958 m
.13778 .25835 L
s
1 .817 0 r
.008 w
.13778 .25835 Mdot
.016 w
.13778 .25835 m
.13789 .25707 L
s
1 .814 0 r
.008 w
.13789 .25707 Mdot
.016 w
.13789 .25707 m
.13801 .25573 L
s
1 .81 0 r
.008 w
.13801 .25573 Mdot
.016 w
.13801 .25573 m
.13814 .25434 L
s
1 .806 0 r
.008 w
.13814 .25434 Mdot
.016 w
.13814 .25434 m
.1383 .25308 L
s
1 .803 0 r
.008 w
.1383 .25308 Mdot
.016 w
.1383 .25308 m
.13846 .25161 L
s
1 .799 0 r
.008 w
.13846 .25161 Mdot
.016 w
.13846 .25161 m
.13867 .25012 L
s
1 .796 0 r
.008 w
.13867 .25012 Mdot
.016 w
.13867 .25012 m
.13892 .24856 L
s
1 .792 0 r
.008 w
.13892 .24856 Mdot
.016 w
.13892 .24856 m
.13923 .24694 L
s
1 .789 0 r
.008 w
.13923 .24694 Mdot
.016 w
.13923 .24694 m
.13964 .24518 L
s
1 .785 0 r
.008 w
.13964 .24518 Mdot
.016 w
.13964 .24518 m
.14014 .24367 L
s
1 .781 0 r
.008 w
.14014 .24367 Mdot
.016 w
.14014 .24367 m
.14076 .24217 L
s
1 .778 0 r
.008 w
.14076 .24217 Mdot
.016 w
.14076 .24217 m
.1415 .24071 L
s
1 .774 0 r
.008 w
.1415 .24071 Mdot
.016 w
.1415 .24071 m
.14228 .23935 L
s
1 .771 0 r
.008 w
.14228 .23935 Mdot
.016 w
.14228 .23935 m
.14313 .23811 L
s
1 .767 0 r
.008 w
.14313 .23811 Mdot
.016 w
.14313 .23811 m
.14402 .23692 L
s
1 .763 0 r
.008 w
.14402 .23692 Mdot
.016 w
.14402 .23692 m
.14494 .23575 L
s
1 .76 0 r
.008 w
.14494 .23575 Mdot
.016 w
.14494 .23575 m
.14581 .23462 L
s
1 .756 0 r
.008 w
.14581 .23462 Mdot
.016 w
.14581 .23462 m
.14671 .23346 L
s
1 .753 0 r
.008 w
.14671 .23346 Mdot
.016 w
.14671 .23346 m
.1476 .23233 L
s
1 .749 0 r
.008 w
.1476 .23233 Mdot
.016 w
.1476 .23233 m
.14857 .23124 L
s
1 .746 0 r
.008 w
.14857 .23124 Mdot
.016 w
.14857 .23124 m
.14952 .23012 L
s
1 .742 0 r
.008 w
.14952 .23012 Mdot
.016 w
.14952 .23012 m
.15056 .22897 L
s
1 .738 0 r
.008 w
.15056 .22897 Mdot
.016 w
.15056 .22897 m
.15171 .2278 L
s
1 .735 0 r
.008 w
.15171 .2278 Mdot
.016 w
.15171 .2278 m
.15289 .22663 L
s
1 .731 0 r
.008 w
.15289 .22663 Mdot
.016 w
.15289 .22663 m
.15413 .22539 L
s
1 .728 0 r
.008 w
.15413 .22539 Mdot
.016 w
.15413 .22539 m
.1554 .22417 L
s
1 .724 0 r
.008 w
.1554 .22417 Mdot
.016 w
.1554 .22417 m
.15654 .22293 L
s
1 .72 0 r
.008 w
.15654 .22293 Mdot
.016 w
.15654 .22293 m
.15766 .22171 L
s
1 .717 0 r
.008 w
.15766 .22171 Mdot
.016 w
.15766 .22171 m
.15872 .22053 L
s
1 .713 0 r
.008 w
.15872 .22053 Mdot
.016 w
.15872 .22053 m
.15972 .21954 L
s
1 .71 0 r
.008 w
.15972 .21954 Mdot
.016 w
.15972 .21954 m
.16067 .21854 L
s
1 .706 0 r
.008 w
.16067 .21854 Mdot
.016 w
.16067 .21854 m
.16146 .21763 L
s
1 .703 0 r
.008 w
.16146 .21763 Mdot
.016 w
.16146 .21763 m
.16215 .21692 L
s
1 .699 0 r
.008 w
.16215 .21692 Mdot
.016 w
.16215 .21692 m
.1627 .2163 L
s
1 .695 0 r
.008 w
.1627 .2163 Mdot
.016 w
.1627 .2163 m
.16311 .21577 L
s
1 .692 0 r
.008 w
.16311 .21577 Mdot
.016 w
.16311 .21577 m
.16339 .21532 L
s
1 .688 0 r
.008 w
.16339 .21532 Mdot
.016 w
.16339 .21532 m
.16351 .21493 L
s
1 .685 0 r
.008 w
.16351 .21493 Mdot
.016 w
.16351 .21493 m
.16352 .21458 L
s
1 .681 0 r
.008 w
.16352 .21458 Mdot
.016 w
.16352 .21458 m
.16346 .21426 L
s
1 .677 0 r
.008 w
.16346 .21426 Mdot
.016 w
.16346 .21426 m
.16339 .21391 L
s
1 .674 0 r
.008 w
.16339 .21391 Mdot
.016 w
.16339 .21391 m
.16332 .21351 L
s
1 .67 0 r
.008 w
.16332 .21351 Mdot
.016 w
.16332 .21351 m
.16328 .213 L
s
1 .667 0 r
.008 w
.16328 .213 Mdot
.016 w
.16328 .213 m
.16326 .21242 L
s
1 .663 0 r
.008 w
.16326 .21242 Mdot
.016 w
.16326 .21242 m
.16326 .21185 L
s
1 .659 0 r
.008 w
.16326 .21185 Mdot
.016 w
.16326 .21185 m
.16324 .21139 L
s
1 .656 0 r
.008 w
.16324 .21139 Mdot
.016 w
.16324 .21139 m
.16318 .21101 L
s
1 .652 0 r
.008 w
.16318 .21101 Mdot
.016 w
.16318 .21101 m
.16308 .21078 L
s
1 .649 0 r
.008 w
.16308 .21078 Mdot
.016 w
.16308 .21078 m
.16294 .21077 L
s
1 .645 0 r
.008 w
.16294 .21077 Mdot
.016 w
.16294 .21077 m
.16275 .21098 L
s
1 .642 0 r
.008 w
.16275 .21098 Mdot
.016 w
.16275 .21098 m
.16251 .21144 L
s
1 .638 0 r
.008 w
.16251 .21144 Mdot
.016 w
.16251 .21144 m
.16224 .21211 L
s
1 .634 0 r
.008 w
.16224 .21211 Mdot
.016 w
.16224 .21211 m
.16195 .21296 L
s
1 .631 0 r
.008 w
.16195 .21296 Mdot
.016 w
.16195 .21296 m
.16165 .21384 L
s
1 .627 0 r
.008 w
.16165 .21384 Mdot
.016 w
.16165 .21384 m
.16137 .21496 L
s
1 .624 0 r
.008 w
.16137 .21496 Mdot
.016 w
.16137 .21496 m
.1611 .21598 L
s
1 .62 0 r
.008 w
.1611 .21598 Mdot
.016 w
.1611 .21598 m
.16088 .217 L
s
1 .616 0 r
.008 w
.16088 .217 Mdot
.016 w
.16088 .217 m
.16072 .21793 L
s
1 .613 0 r
.008 w
.16072 .21793 Mdot
.016 w
.16072 .21793 m
.16066 .21869 L
s
1 .609 0 r
.008 w
.16066 .21869 Mdot
.016 w
.16066 .21869 m
.16071 .21926 L
s
1 .606 0 r
.008 w
.16071 .21926 Mdot
.016 w
.16071 .21926 m
.16091 .21961 L
s
1 .602 0 r
.008 w
.16091 .21961 Mdot
.016 w
.16091 .21961 m
.16125 .21977 L
s
1 .599 0 r
.008 w
.16125 .21977 Mdot
.016 w
.16125 .21977 m
.16173 .2198 L
s
1 .595 0 r
.008 w
.16173 .2198 Mdot
.016 w
.16173 .2198 m
.16232 .21974 L
s
1 .591 0 r
.008 w
.16232 .21974 Mdot
.016 w
.16232 .21974 m
.16302 .21964 L
s
1 .588 0 r
.008 w
.16302 .21964 Mdot
.016 w
.16302 .21964 m
.1638 .21953 L
s
1 .584 0 r
.008 w
.1638 .21953 Mdot
.016 w
.1638 .21953 m
.16461 .21946 L
s
1 .581 0 r
.008 w
.16461 .21946 Mdot
.016 w
.16461 .21946 m
.16534 .21944 L
s
1 .577 0 r
.008 w
.16534 .21944 Mdot
.016 w
.16534 .21944 m
.16601 .21945 L
s
1 .573 0 r
.008 w
.16601 .21945 Mdot
.016 w
.16601 .21945 m
.16657 .21947 L
s
1 .57 0 r
.008 w
.16657 .21947 Mdot
.016 w
.16657 .21947 m
.16697 .21947 L
s
1 .566 0 r
.008 w
.16697 .21947 Mdot
.016 w
.16697 .21947 m
.16721 .21948 L
s
1 .563 0 r
.008 w
.16721 .21948 Mdot
.016 w
.16721 .21948 m
.16727 .21947 L
s
1 .559 0 r
.008 w
.16727 .21947 Mdot
.016 w
.16727 .21947 m
.16717 .21944 L
s
1 .556 0 r
.008 w
.16717 .21944 Mdot
.016 w
.16717 .21944 m
.16698 .21938 L
s
1 .552 0 r
.008 w
.16698 .21938 Mdot
.016 w
.16698 .21938 m
.16672 .21929 L
s
1 .548 0 r
.008 w
.16672 .21929 Mdot
.016 w
.16672 .21929 m
.16633 .21918 L
s
1 .545 0 r
.008 w
.16633 .21918 Mdot
.016 w
.16633 .21918 m
.16586 .21906 L
s
1 .541 0 r
.008 w
.16586 .21906 Mdot
.016 w
.16586 .21906 m
.16527 .21897 L
s
1 .538 0 r
.008 w
.16527 .21897 Mdot
.016 w
.16527 .21897 m
.16457 .21895 L
s
1 .534 0 r
.008 w
.16457 .21895 Mdot
.016 w
.16457 .21895 m
.1638 .21902 L
s
1 .53 0 r
.008 w
.1638 .21902 Mdot
.016 w
.1638 .21902 m
.16296 .21921 L
s
1 .527 0 r
.008 w
.16296 .21921 Mdot
.016 w
.16296 .21921 m
.16206 .21956 L
s
1 .523 0 r
.008 w
.16206 .21956 Mdot
.016 w
.16206 .21956 m
.1611 .22009 L
s
1 .52 0 r
.008 w
.1611 .22009 Mdot
.016 w
.1611 .22009 m
.16008 .2208 L
s
1 .516 0 r
.008 w
.16008 .2208 Mdot
.016 w
.16008 .2208 m
.15901 .22174 L
s
1 .513 0 r
.008 w
.15901 .22174 Mdot
.016 w
.15901 .22174 m
.15802 .22285 L
s
1 .509 0 r
.008 w
.15802 .22285 Mdot
.016 w
.15802 .22285 m
.15693 .22418 L
s
1 .505 0 r
.008 w
.15693 .22418 Mdot
.016 w
.15693 .22418 m
.15568 .22572 L
s
1 .502 0 r
.008 w
.15568 .22572 Mdot
.016 w
.15568 .22572 m
.15413 .22738 L
s
1 .498 0 r
.008 w
.15413 .22738 Mdot
.016 w
.15413 .22738 m
.15273 .22902 L
s
1 .495 0 r
.008 w
.15273 .22902 Mdot
.016 w
.15273 .22902 m
.15127 .23076 L
s
1 .491 0 r
.008 w
.15127 .23076 Mdot
.016 w
.15127 .23076 m
.14976 .23258 L
s
1 .487 0 r
.008 w
.14976 .23258 Mdot
.016 w
.14976 .23258 m
.14833 .23433 L
s
1 .484 0 r
.008 w
.14833 .23433 Mdot
.016 w
.14833 .23433 m
.14687 .23593 L
s
1 .48 0 r
.008 w
.14687 .23593 Mdot
.016 w
.14687 .23593 m
.14544 .23751 L
s
1 .477 0 r
.008 w
.14544 .23751 Mdot
.016 w
.14544 .23751 m
.14415 .23906 L
s
1 .473 0 r
.008 w
.14415 .23906 Mdot
.016 w
.14415 .23906 m
.14295 .24047 L
s
1 .47 0 r
.008 w
.14295 .24047 Mdot
.016 w
.14295 .24047 m
.14174 .24189 L
s
1 .466 0 r
.008 w
.14174 .24189 Mdot
.016 w
.14174 .24189 m
.14051 .24335 L
s
1 .462 0 r
.008 w
.14051 .24335 Mdot
.016 w
.14051 .24335 m
.13927 .24489 L
s
1 .459 0 r
.008 w
.13927 .24489 Mdot
.016 w
.13927 .24489 m
.1381 .24641 L
s
1 .455 0 r
.008 w
.1381 .24641 Mdot
.016 w
.1381 .24641 m
.137 .24804 L
s
1 .452 0 r
.008 w
.137 .24804 Mdot
.016 w
.137 .24804 m
.13592 .24983 L
s
1 .448 0 r
.008 w
.13592 .24983 Mdot
.016 w
.13592 .24983 m
.13488 .25177 L
s
1 .444 0 r
.008 w
.13488 .25177 Mdot
.016 w
.13488 .25177 m
.13392 .25363 L
s
1 .441 0 r
.008 w
.13392 .25363 Mdot
.016 w
.13392 .25363 m
.13302 .25572 L
s
1 .437 0 r
.008 w
.13302 .25572 Mdot
.016 w
.13302 .25572 m
.13217 .25774 L
s
1 .434 0 r
.008 w
.13217 .25774 Mdot
.016 w
.13217 .25774 m
.13136 .25981 L
s
1 .43 0 r
.008 w
.13136 .25981 Mdot
.016 w
.13136 .25981 m
.13065 .26173 L
s
1 .427 0 r
.008 w
.13065 .26173 Mdot
.016 w
.13065 .26173 m
.13006 .2634 L
s
1 .423 0 r
.008 w
.13006 .2634 Mdot
.016 w
.13006 .2634 m
.12958 .2649 L
s
1 .419 0 r
.008 w
.12958 .2649 Mdot
.016 w
.12958 .2649 m
.12923 .2662 L
s
1 .416 0 r
.008 w
.12923 .2662 Mdot
.016 w
.12923 .2662 m
.12897 .26717 L
s
1 .412 0 r
.008 w
.12897 .26717 Mdot
.016 w
.12897 .26717 m
.12877 .26794 L
s
1 .409 0 r
.008 w
.12877 .26794 Mdot
.016 w
.12877 .26794 m
.12859 .26855 L
s
1 .405 0 r
.008 w
.12859 .26855 Mdot
.016 w
.12859 .26855 m
.12841 .26902 L
s
1 .401 0 r
.008 w
.12841 .26902 Mdot
.016 w
.12841 .26902 m
.12819 .26938 L
s
1 .398 0 r
.008 w
.12819 .26938 Mdot
.016 w
.12819 .26938 m
.12788 .26971 L
s
1 .394 0 r
.008 w
.12788 .26971 Mdot
.016 w
.12788 .26971 m
.12747 .27006 L
s
1 .391 0 r
.008 w
.12747 .27006 Mdot
.016 w
.12747 .27006 m
.12697 .27042 L
s
1 .387 0 r
.008 w
.12697 .27042 Mdot
.016 w
.12697 .27042 m
.12639 .27082 L
s
1 .384 0 r
.008 w
.12639 .27082 Mdot
.016 w
.12639 .27082 m
.12573 .27127 L
s
1 .38 0 r
.008 w
.12573 .27127 Mdot
.016 w
.12573 .27127 m
.12509 .27178 L
s
1 .376 0 r
.008 w
.12509 .27178 Mdot
.016 w
.12509 .27178 m
.12428 .27246 L
s
1 .373 0 r
.008 w
.12428 .27246 Mdot
.016 w
.12428 .27246 m
.1235 .27321 L
s
1 .369 0 r
.008 w
.1235 .27321 Mdot
.016 w
.1235 .27321 m
.12264 .27409 L
s
1 .366 0 r
.008 w
.12264 .27409 Mdot
.016 w
.12264 .27409 m
.12172 .27509 L
s
1 .362 0 r
.008 w
.12172 .27509 Mdot
.016 w
.12172 .27509 m
.12078 .27618 L
s
1 .358 0 r
.008 w
.12078 .27618 Mdot
.016 w
.12078 .27618 m
.11987 .27735 L
s
1 .355 0 r
.008 w
.11987 .27735 Mdot
.016 w
.11987 .27735 m
.119 .27861 L
s
1 .351 0 r
.008 w
.119 .27861 Mdot
.016 w
.119 .27861 m
.11823 .27984 L
s
1 .348 0 r
.008 w
.11823 .27984 Mdot
.016 w
.11823 .27984 m
.11745 .28115 L
s
1 .344 0 r
.008 w
.11745 .28115 Mdot
.016 w
.11745 .28115 m
.1167 .2825 L
s
1 .341 0 r
.008 w
.1167 .2825 Mdot
.016 w
.1167 .2825 m
.11598 .28389 L
s
1 .337 0 r
.008 w
.11598 .28389 Mdot
.016 w
.11598 .28389 m
.11528 .28523 L
s
1 .333 0 r
.008 w
.11528 .28523 Mdot
.016 w
.11528 .28523 m
.11457 .28668 L
s
1 .33 0 r
.008 w
.11457 .28668 Mdot
.016 w
.11457 .28668 m
.11392 .28825 L
s
1 .326 0 r
.008 w
.11392 .28825 Mdot
.016 w
.11392 .28825 m
.11341 .28981 L
s
1 .323 0 r
.008 w
.11341 .28981 Mdot
.016 w
.11341 .28981 m
.11302 .29131 L
s
1 .319 0 r
.008 w
.11302 .29131 Mdot
.016 w
.11302 .29131 m
.11269 .29276 L
s
1 .315 0 r
.008 w
.11269 .29276 Mdot
.016 w
.11269 .29276 m
.11239 .2942 L
s
1 .312 0 r
.008 w
.11239 .2942 Mdot
.016 w
.11239 .2942 m
.11208 .29539 L
s
1 .308 0 r
.008 w
.11208 .29539 Mdot
.016 w
.11208 .29539 m
.11172 .29664 L
s
1 .305 0 r
.008 w
.11172 .29664 Mdot
.016 w
.11172 .29664 m
.11124 .29777 L
s
1 .301 0 r
.008 w
.11124 .29777 Mdot
.016 w
.11124 .29777 m
.11062 .29899 L
s
1 .297 0 r
.008 w
.11062 .29899 Mdot
.016 w
.11062 .29899 m
.10995 .30028 L
s
1 .294 0 r
.008 w
.10995 .30028 Mdot
.016 w
.10995 .30028 m
.10908 .30152 L
s
1 .29 0 r
.008 w
.10908 .30152 Mdot
.016 w
.10908 .30152 m
.10808 .3028 L
s
1 .287 0 r
.008 w
.10808 .3028 Mdot
.016 w
.10808 .3028 m
.107 .3041 L
s
1 .283 0 r
.008 w
.107 .3041 Mdot
.016 w
.107 .3041 m
.10597 .30542 L
s
1 .28 0 r
.008 w
.10597 .30542 Mdot
.016 w
.10597 .30542 m
.10488 .30675 L
s
1 .276 0 r
.008 w
.10488 .30675 Mdot
.016 w
.10488 .30675 m
.10369 .30799 L
s
1 .272 0 r
.008 w
.10369 .30799 Mdot
.016 w
.10369 .30799 m
.10243 .30926 L
s
1 .269 0 r
.008 w
.10243 .30926 Mdot
.016 w
.10243 .30926 m
.10117 .31056 L
s
1 .265 0 r
.008 w
.10117 .31056 Mdot
.016 w
.10117 .31056 m
.10008 .31194 L
s
1 .262 0 r
.008 w
.10008 .31194 Mdot
.016 w
.10008 .31194 m
.09911 .31324 L
s
1 .258 0 r
.008 w
.09911 .31324 Mdot
.016 w
.09911 .31324 m
.09828 .3146 L
s
1 .254 0 r
.008 w
.09828 .3146 Mdot
.016 w
.09828 .3146 m
.09758 .31601 L
s
1 .251 0 r
.008 w
.09758 .31601 Mdot
.016 w
.09758 .31601 m
.09701 .31745 L
s
1 .247 0 r
.008 w
.09701 .31745 Mdot
.016 w
.09701 .31745 m
.09655 .31882 L
s
1 .244 0 r
.008 w
.09655 .31882 Mdot
.016 w
.09655 .31882 m
.09619 .32016 L
s
1 .24 0 r
.008 w
.09619 .32016 Mdot
.016 w
.09619 .32016 m
.09591 .32153 L
s
1 .237 0 r
.008 w
.09591 .32153 Mdot
.016 w
.09591 .32153 m
.09569 .32297 L
s
1 .233 0 r
.008 w
.09569 .32297 Mdot
.016 w
.09569 .32297 m
.09552 .32443 L
s
1 .229 0 r
.008 w
.09552 .32443 Mdot
.016 w
.09552 .32443 m
.09537 .32594 L
s
1 .226 0 r
.008 w
.09537 .32594 Mdot
.016 w
.09537 .32594 m
.09524 .32751 L
s
1 .222 0 r
.008 w
.09524 .32751 Mdot
.016 w
.09524 .32751 m
.09508 .32907 L
s
1 .219 0 r
.008 w
.09508 .32907 Mdot
.016 w
.09508 .32907 m
.0949 .33049 L
s
1 .215 0 r
.008 w
.0949 .33049 Mdot
.016 w
.0949 .33049 m
.0947 .33178 L
s
1 .211 0 r
.008 w
.0947 .33178 Mdot
.016 w
.0947 .33178 m
.09451 .33292 L
s
1 .208 0 r
.008 w
.09451 .33292 Mdot
.016 w
.09451 .33292 m
.09433 .33392 L
s
1 .204 0 r
.008 w
.09433 .33392 Mdot
.016 w
.09433 .33392 m
.09413 .3348 L
s
1 .201 0 r
.008 w
.09413 .3348 Mdot
.016 w
.09413 .3348 m
.09389 .33553 L
s
1 .197 0 r
.008 w
.09389 .33553 Mdot
.016 w
.09389 .33553 m
.09362 .33618 L
s
1 .194 0 r
.008 w
.09362 .33618 Mdot
.016 w
.09362 .33618 m
.09333 .33676 L
s
1 .19 0 r
.008 w
.09333 .33676 Mdot
.016 w
.09333 .33676 m
.09303 .3373 L
s
1 .186 0 r
.008 w
.09303 .3373 Mdot
.016 w
.09303 .3373 m
.09274 .33784 L
s
1 .183 0 r
.008 w
.09274 .33784 Mdot
.016 w
.09274 .33784 m
.09247 .33842 L
s
1 .179 0 r
.008 w
.09247 .33842 Mdot
.016 w
.09247 .33842 m
.09221 .33908 L
s
1 .176 0 r
.008 w
.09221 .33908 Mdot
.016 w
.09221 .33908 m
.09195 .33988 L
s
1 .172 0 r
.008 w
.09195 .33988 Mdot
.016 w
.09195 .33988 m
.09169 .34087 L
s
1 .168 0 r
.008 w
.09169 .34087 Mdot
.016 w
.09169 .34087 m
.09142 .34199 L
s
1 .165 0 r
.008 w
.09142 .34199 Mdot
.016 w
.09142 .34199 m
.0911 .34328 L
s
1 .161 0 r
.008 w
.0911 .34328 Mdot
.016 w
.0911 .34328 m
.09072 .34479 L
s
1 .158 0 r
.008 w
.09072 .34479 Mdot
.016 w
.09072 .34479 m
.09028 .34661 L
s
1 .154 0 r
.008 w
.09028 .34661 Mdot
.016 w
.09028 .34661 m
.0898 .34849 L
s
1 .151 0 r
.008 w
.0898 .34849 Mdot
.016 w
.0898 .34849 m
.08933 .35058 L
s
1 .147 0 r
.008 w
.08933 .35058 Mdot
.016 w
.08933 .35058 m
.08888 .35285 L
s
1 .143 0 r
.008 w
.08888 .35285 Mdot
.016 w
.08888 .35285 m
.08848 .35486 L
s
1 .14 0 r
.008 w
.08848 .35486 Mdot
.016 w
.08848 .35486 m
.08811 .35718 L
s
1 .136 0 r
.008 w
.08811 .35718 Mdot
.016 w
.08811 .35718 m
.08775 .35927 L
s
1 .133 0 r
.008 w
.08775 .35927 Mdot
.016 w
.08775 .35927 m
.08741 .36153 L
s
1 .129 0 r
.008 w
.08741 .36153 Mdot
.016 w
.08741 .36153 m
.08708 .36398 L
s
1 .125 0 r
.008 w
.08708 .36398 Mdot
.016 w
.08708 .36398 m
.08674 .36645 L
s
1 .122 0 r
.008 w
.08674 .36645 Mdot
.016 w
.08674 .36645 m
.08641 .36865 L
s
1 .118 0 r
.008 w
.08641 .36865 Mdot
.016 w
.08641 .36865 m
.0861 .37091 L
s
1 .115 0 r
.008 w
.0861 .37091 Mdot
.016 w
.0861 .37091 m
.08582 .37331 L
s
1 .111 0 r
.008 w
.08582 .37331 Mdot
.016 w
.08582 .37331 m
.08559 .37576 L
s
1 .108 0 r
.008 w
.08559 .37576 Mdot
.016 w
.08559 .37576 m
.08541 .37783 L
s
1 .104 0 r
.008 w
.08541 .37783 Mdot
.016 w
.08541 .37783 m
.08524 .38005 L
s
1 .1 0 r
.008 w
.08524 .38005 Mdot
.016 w
.08524 .38005 m
.08507 .38216 L
s
1 .097 0 r
.008 w
.08507 .38216 Mdot
.016 w
.08507 .38216 m
.08492 .38421 L
s
1 .093 0 r
.008 w
.08492 .38421 Mdot
.016 w
.08492 .38421 m
.08477 .38618 L
s
1 .09 0 r
.008 w
.08477 .38618 Mdot
.016 w
.08477 .38618 m
.08464 .38791 L
s
1 .086 0 r
.008 w
.08464 .38791 Mdot
.016 w
.08464 .38791 m
.08451 .38949 L
s
1 .082 0 r
.008 w
.08451 .38949 Mdot
.016 w
.08451 .38949 m
.08444 .39082 L
s
1 .079 0 r
.008 w
.08444 .39082 Mdot
.016 w
.08444 .39082 m
.08441 .39195 L
s
1 .075 0 r
.008 w
.08441 .39195 Mdot
.016 w
.08441 .39195 m
.0844 .39287 L
s
1 .072 0 r
.008 w
.0844 .39287 Mdot
.016 w
.0844 .39287 m
.08442 .3936 L
s
1 .068 0 r
.008 w
.08442 .3936 Mdot
.016 w
.08442 .3936 m
.08445 .39418 L
s
1 .065 0 r
.008 w
.08445 .39418 Mdot
.016 w
.08445 .39418 m
.08447 .39463 L
s
1 .061 0 r
.008 w
.08447 .39463 Mdot
.016 w
.08447 .39463 m
.08447 .39502 L
s
1 .057 0 r
.008 w
.08447 .39502 Mdot
.016 w
.08447 .39502 m
.08447 .39544 L
s
1 .054 0 r
.008 w
.08447 .39544 Mdot
.016 w
.08447 .39544 m
.08446 .39591 L
s
1 .05 0 r
.008 w
.08446 .39591 Mdot
.016 w
.08446 .39591 m
.08445 .39647 L
s
1 .047 0 r
.008 w
.08445 .39647 Mdot
.016 w
.08445 .39647 m
.08444 .39715 L
s
1 .043 0 r
.008 w
.08444 .39715 Mdot
.016 w
.08444 .39715 m
.08443 .39796 L
s
1 .039 0 r
.008 w
.08443 .39796 Mdot
.016 w
.08443 .39796 m
.08441 .3988 L
s
1 .036 0 r
.008 w
.08441 .3988 Mdot
.016 w
.08441 .3988 m
.08439 .39975 L
s
1 .032 0 r
.008 w
.08439 .39975 Mdot
.016 w
.08439 .39975 m
.08438 .40078 L
s
1 .029 0 r
.008 w
.08438 .40078 Mdot
.016 w
.08438 .40078 m
.08436 .40187 L
s
1 .025 0 r
.008 w
.08436 .40187 Mdot
.016 w
.08436 .40187 m
.08434 .40297 L
s
1 .022 0 r
.008 w
.08434 .40297 Mdot
.016 w
.08434 .40297 m
.08432 .40391 L
s
1 .018 0 r
.008 w
.08432 .40391 Mdot
.016 w
.08432 .40391 m
.08431 .40479 L
s
1 .014 0 r
.008 w
.08431 .40479 Mdot
.016 w
.08431 .40479 m
.0843 .40556 L
s
1 .011 0 r
.008 w
.0843 .40556 Mdot
.016 w
.0843 .40556 m
.08429 .4062 L
s
1 .007 0 r
.008 w
.08429 .4062 Mdot
.016 w
.08429 .4062 m
.08428 .40668 L
s
1 .004 0 r
.008 w
.08428 .40668 Mdot
.016 w
.08428 .40668 m
.08427 .40697 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Gj0`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5OX31
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`=nH09n@<9oo`03001oogoo02Ioo`009Woo00<0
07ooOol01Woo1Wh000=n87ooOol0`7oo00<007ooOol09Goo000UOol00`00Oomoo`06Ool00gh0ON1m
h004OP000ghPOomoo`31Ool00`00Oomoo`0TOol002Aoo`03001oogoo00Ioo`03O^1mh7gP009mh0=n
0003OR1oogoo0<9oo`03001oogoo02=oo`0097oo00<007ooOol01Goo00=nh7gPON0017gP0Wh000=n
87ooOol0`Woo00<007ooOol08goo000SOol00`00Oomoo`06Ool6ON000gh0Oomoo`36Ool00`00Oomo
o`0ROol0029oo`03001oogoo00Ioo`Imh003OP1oogoo0<Qoo`03001oogoo025oo`008Woo00<007oo
Ool01Goo1Gg000=mh7kPOol0bWoo00<007ooOol08Goo000QOol00`00Oomoo`06Ool5OL000ggPOomo
o`3;Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Im`003ON1oogoo0<aoo`03001oogoo01mo
o`0087oo00<007ooOol01Goo1gg0cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool4OJ02OL3A
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`AmX003OL1o87oo0=5oo`03001oogoo01eoo`00
7Woo00<007ooOol01Woo1WfP00=o87ooOol0d7oo00<007ooOol07Goo000MOol00`00Oomoo`07Ool4
OH000gfPOb1o803COol00`00Oomoo`0LOol001eoo`03001oogoo00Ioo`AmH004OH1mX7m0Od3COol0
0`00Oomoo`0LOol001aoo`03001oogoo00Ioo`EmH003OH1o@7m00=Eoo`03001oogoo01]oo`0077oo
00<007ooOol01Goo00=mH7e0OD000geP00=mP7m0Od00eGoo00<007ooOol06goo000KOol00`00Oomo
o`06Ool4OD02OF000gf0Of1oH03FOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`Im@003OF1o
P7n00=Moo`03001oogoo01Yoo`006Woo00<007ooOol01Woo00=m@7dPOB000We000AmH7n0Oh1oP=Qo
o`03001oogoo01Uoo`006Woo00<007ooOol01Woo17dP00AmH7nPOj1oX=Uoo`03001oogoo01Uoo`00
6Goo00<007ooOol01Woo1WdP0Wo0fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool5OB02Ol3L
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Am009m8=moo`03001oogoo01Moo`0067oo00<0
07ooOol01Goo1Gd000=m83g_Ool0gWoo00<007ooOol05goo000HOol00`00Oomoo`04Ool6O@000gdP
?Nmoo`3NOol00`00Oomoo`0GOol001Moo`03001oogoo00Eoo`Im008mkn1oo`03001oogoo01Ioo`00
5goo00<007ooOol017oo17cP0gd000<mkgooOol0ggoo00<007ooOol05Woo000FOol00`00Oomoo`05
Ool4O>0017d0?Nlmkcg_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool4O>000gd0?Nmoo`3S
Ool00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`Al`08mknEoo`03001oogoo01Aoo`005Goo00<0
07ooOol01Woo17c00Sg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool4O:02O<000cg_Oomo
o`3SOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`AlX003O<0mkgoo0>Ioo`03001oogoo01=o
o`0057oo00<007ooOol01Woo17bP00=l`3g_Ool0iWoo00<007ooOol04goo000DOol00`00Oomoo`05
Ool5O802?NoWOol00`00Oomoo`0COol001=oo`03001oogoo00Ioo`ElP003?Nmoogoo0>Moo`03001o
ogoo019oo`004goo00<007ooOol01Woo1Gb000<mkgooOol0igoo00<007ooOol04Woo000COol00`00
Oomoo`06Ool5O8000cg_Oomoo`3WOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`AlH003?Nmo
ogoo0>Uoo`03001oogoo015oo`004Woo00<007ooOol01goo17aP00<mkgooOol0jGoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool6O63[Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`ElH>eo
o`03001oogoo011oo`004Goo00<007ooOol01goo1GaPkGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool4O6000cg_Oomoo`3[Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Al@003?Nmoogoo
0>aoo`03001oogoo00moo`0047oo00<007ooOol027oo17a000<mkgooOol0k7oo00<007ooOol03goo
000@Ool00`00Oomoo`08Ool4O4000cg_Oomoo`3/Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qo
o`Al8003?Nmoogoo0>aoo`03001oogoo00moo`0047oo00<007ooOol027oo17`P00<mkgooOol0k7oo
00<007ooOol03goo000?Ool00`00Oomoo`09Ool4O002?No^Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00Uoo`Al00<mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo17`00cg_kGoo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool4O003?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Al00@mknaoo`03001oogoo00ioo`003Woo00<007ooOol02goo1cg_kGoo00<007ooOol03Goo000>
Ool00`00Oomoo`0<Ool:?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`TmknUoo`03001o
ogoo00eoo`003Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<
?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<0
07ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<
Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Woo23g_
kgoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool9?No_Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo00Qoo`Tmko1oo`03001oogoo00aoo`003Goo00<007ooOol027oo2Cg_l7oo00<007ooOol037oo
000<Ool00`00Oomoo`08Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`LmkoEoo`03
001oogoo00]oo`0037oo00<007ooOol01Woo23g_mGoo00<007ooOol02goo000<Ool00`00Oomoo`05
Ool9?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo
00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_
mWoo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo
0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00
Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`003Goo
00<007ooOol0ogoo0goo00<007ooOol02goo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol0
37oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001o
ogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo
0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo
0?moo`9oo`03001oogoo00aoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomo
o`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0
ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eo
o`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol0
0`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<0
07ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001o
ogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol0
47oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011o
o`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0
01=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000C
Ool00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo
00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03
001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00
Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007oo
Ool0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo
0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[
Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo
00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03
001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00
Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007oo
Ool06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo
01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0M
Ool001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo
000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`00
87oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol0
0`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<0
07ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001o
ogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomo
o`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0
agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eo
o`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool0
0`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<0
07ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001o
ogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00
Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007oo
Ool0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`80
03Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0k
Ool003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomo
o`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0
@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Ao
o`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00
Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001o
ogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00
EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo
0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00
IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5
000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yoo`D00004Ool00000002=Ool008aoo`03
001oogoo00=oo`03001oogoo08]oo`00S7oo00<007ooOol00Woo0`00S7oo002<Ool01@00Oomoogoo
00000Woo00<007ooOol0RWoo002<Ool01@00Oomoogoo00000Woo00<007ooOol0RWoo002;Ool20004
Ool3002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(20)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
1 .971 0 r
.008 w
.0843 .40668 Mdot
.016 w
.0843 .40668 m
.08431 .40651 L
s
1 .941 0 r
.008 w
.08431 .40651 Mdot
.016 w
.08431 .40651 m
.08431 .40629 L
s
1 .912 0 r
.008 w
.08431 .40629 Mdot
.016 w
.08431 .40629 m
.08429 .40601 L
s
1 .882 0 r
.008 w
.08429 .40601 Mdot
.016 w
.08429 .40601 m
.08426 .40564 L
s
1 .853 0 r
.008 w
.08426 .40564 Mdot
.016 w
.08426 .40564 m
.08422 .40537 L
s
1 .824 0 r
.008 w
.08422 .40537 Mdot
.016 w
.08422 .40537 m
.08421 .40494 L
s
1 .794 0 r
.008 w
.08421 .40494 Mdot
.016 w
.08421 .40494 m
.08422 .4045 L
s
1 .765 0 r
.008 w
.08422 .4045 Mdot
.016 w
.08422 .4045 m
.08427 .40399 L
s
1 .735 0 r
.008 w
.08427 .40399 Mdot
.016 w
.08427 .40399 m
.08436 .4033 L
s
1 .706 0 r
.008 w
.08436 .4033 Mdot
.016 w
.08436 .4033 m
.08451 .40262 L
s
1 .676 0 r
.008 w
.08451 .40262 Mdot
.016 w
.08451 .40262 m
.08473 .40208 L
s
1 .647 0 r
.008 w
.08473 .40208 Mdot
.016 w
.08473 .40208 m
.08498 .40132 L
s
1 .618 0 r
.008 w
.08498 .40132 Mdot
.016 w
.08498 .40132 m
.08526 .40059 L
s
1 .588 0 r
.008 w
.08526 .40059 Mdot
.016 w
.08526 .40059 m
.08553 .39979 L
s
1 .559 0 r
.008 w
.08553 .39979 Mdot
.016 w
.08553 .39979 m
.08578 .39891 L
s
1 .529 0 r
.008 w
.08578 .39891 Mdot
.016 w
.08578 .39891 m
.08603 .39786 L
s
1 .5 0 r
.008 w
.08603 .39786 Mdot
.016 w
.08603 .39786 m
.08628 .39697 L
s
1 .471 0 r
.008 w
.08628 .39697 Mdot
.016 w
.08628 .39697 m
.08654 .39605 L
s
1 .441 0 r
.008 w
.08654 .39605 Mdot
.016 w
.08654 .39605 m
.08679 .39498 L
s
1 .412 0 r
.008 w
.08679 .39498 Mdot
.016 w
.08679 .39498 m
.087 .39377 L
s
1 .382 0 r
.008 w
.087 .39377 Mdot
.016 w
.087 .39377 m
.08714 .39255 L
s
1 .353 0 r
.008 w
.08714 .39255 Mdot
.016 w
.08714 .39255 m
.08722 .39156 L
s
1 .324 0 r
.008 w
.08722 .39156 Mdot
.016 w
.08722 .39156 m
.08725 .39047 L
s
1 .294 0 r
.008 w
.08725 .39047 Mdot
.016 w
.08725 .39047 m
.08726 .38935 L
s
1 .265 0 r
.008 w
.08726 .38935 Mdot
.016 w
.08726 .38935 m
.08724 .38838 L
s
1 .235 0 r
.008 w
.08724 .38838 Mdot
.016 w
.08724 .38838 m
.08721 .38742 L
s
1 .206 0 r
.008 w
.08721 .38742 Mdot
.016 w
.08721 .38742 m
.0872 .38652 L
s
1 .176 0 r
.008 w
.0872 .38652 Mdot
.016 w
.0872 .38652 m
.08721 .38576 L
s
1 .147 0 r
.008 w
.08721 .38576 Mdot
.016 w
.08721 .38576 m
.08722 .38514 L
s
1 .118 0 r
.008 w
.08722 .38514 Mdot
.016 w
.08722 .38514 m
.08723 .38461 L
s
1 .088 0 r
.008 w
.08723 .38461 Mdot
.016 w
.08723 .38461 m
.08723 .38416 L
s
1 .059 0 r
.008 w
.08723 .38416 Mdot
.016 w
.08723 .38416 m
.08723 .38381 L
s
1 .029 0 r
.008 w
.08723 .38381 Mdot
.016 w
.08723 .38381 m
.08724 .38357 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo
011oo`004Goo00<007ooOol01goo00<mkgbPO0000WbPkWoo00<007ooOol03goo000@Ool00`00Oomo
o`08Ool00cg_O:1l0002O:3^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`03?NmlX7`P009l
X>ioo`03001oogoo00moo`0047oo00<007ooOol027oo00=m`7bPO:000WbPkWoo00<007ooOol03goo
000@Ool00`00Oomoo`08Ool00gg0O:1lX002O:3^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uo
o`03OL1m87dP009m8003?Nmoogoo0>aoo`03001oogoo00ioo`003goo00<007ooOol02Goo00=m`7f0
OH000Wf00Sg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4ON03?No]Ool00`00Oomoo`0>
Ool000moo`03001oogoo00Uoo`AnH0<mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo17l0
13g_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0;Ool7?No]Ool00`00Oomoo`0=Ool000ioo`03
001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2Cg_jGoo00<007ooOol0
3Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMo
o`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomo
o`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`00
3Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo
00<007ooOol02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool8?No_Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`Tmknmoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo2Cg_l7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?No`Ool00`00Oomoo`0<Ool000ao
o`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<007ooOol01goo1cg_mGoo00<007oo
Ool02goo000<Ool00`00Oomoo`06Ool8?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`Tm
koEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol0
0`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo
17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo
0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000=Ool00`00
Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo
00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol0
37oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001o
ogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo
0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol0
0`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001o
ogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomoo`3lOol00`00Oomo
o`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00mo
o`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0
015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<007ooOol047oo000B
Ool00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004goo
00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03
001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol04Woo000DOol00`00
Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`005Goo00<007oo
Ool0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo
0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000FOol00`00Oomoo`3_
Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo00<007ooOol0kGoo
00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03001oogoo0>]oo`03
001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00Oomoo`3ZOol00`00
Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007ooOol0j7oo00<007oo
Ool067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo0>Eoo`03001oogoo
01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3SOol00`00Oomoo`0K
Ool001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo00<007ooOol077oo
000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo01eoo`00
7Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001mo
o`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo000POol0
0`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo021oo`008Woo00<0
07ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000UOol00`00Oomo
o`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Woo00<007ooOol0
cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qoo`03001oogoo0<]o
o`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol00`00Oomoo`37Ool0
0`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<007ooOol0aGoo00<0
07ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001oogoo0<5oo`03001o
ogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomoo`2oOol00`00Oomo
o`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0^goo00<007ooOol0
;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=oo`00=7oo00<007oo
Ool0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03001oogoo
0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000gOol00`00Oomoo`2]
Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo
000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]oo`00
?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001oogoo09]o
o`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol00`00Oomoo`12Ool0
04Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<007ooOol0A7oo0016
Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2
001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0OGoo00<007ooOol0
CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo001FOol2
001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001NOol2001NOol3001O
Ool0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3001VOol0
06Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001aOol007=oo`D002mo
o`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D008ioo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo10000goo0P00SGoo002:Ool00`00Oomoo`03
Ool01000Oomoo`00S7oo002;Ool00`00Oomoo`02Ool01000Oomoo`00S7oo002<Ool01@00Oomoogoo
00000Woo00<007ooOol0RWoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00Rgoo0P0017oo
0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(21)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
1 .98 0 r
.008 w
.08713 .38373 Mdot
.016 w
.08713 .38373 m
.08712 .38356 L
s
1 .959 0 r
.008 w
.08712 .38356 Mdot
.016 w
.08712 .38356 m
.08714 .38329 L
s
1 .939 0 r
.008 w
.08714 .38329 Mdot
.016 w
.08714 .38329 m
.0872 .38293 L
s
1 .918 0 r
.008 w
.0872 .38293 Mdot
.016 w
.0872 .38293 m
.08731 .3825 L
s
1 .898 0 r
.008 w
.08731 .3825 Mdot
.016 w
.08731 .3825 m
.08747 .38204 L
s
1 .878 0 r
.008 w
.08747 .38204 Mdot
.016 w
.08747 .38204 m
.08768 .38156 L
s
1 .857 0 r
.008 w
.08768 .38156 Mdot
.016 w
.08768 .38156 m
.08794 .38107 L
s
1 .837 0 r
.008 w
.08794 .38107 Mdot
.016 w
.08794 .38107 m
.08825 .3806 L
s
1 .816 0 r
.008 w
.08825 .3806 Mdot
.016 w
.08825 .3806 m
.08859 .38012 L
s
1 .796 0 r
.008 w
.08859 .38012 Mdot
.016 w
.08859 .38012 m
.08888 .37965 L
s
1 .776 0 r
.008 w
.08888 .37965 Mdot
.016 w
.08888 .37965 m
.08913 .37925 L
s
1 .755 0 r
.008 w
.08913 .37925 Mdot
.016 w
.08913 .37925 m
.08937 .37895 L
s
1 .735 0 r
.008 w
.08937 .37895 Mdot
.016 w
.08937 .37895 m
.08961 .37881 L
s
1 .714 0 r
.008 w
.08961 .37881 Mdot
.016 w
.08961 .37881 m
.08978 .37885 L
s
1 .694 0 r
.008 w
.08978 .37885 Mdot
.016 w
.08978 .37885 m
.08982 .37906 L
s
1 .673 0 r
.008 w
.08982 .37906 Mdot
.016 w
.08982 .37906 m
.08972 .3794 L
s
1 .653 0 r
.008 w
.08972 .3794 Mdot
.016 w
.08972 .3794 m
.08952 .37983 L
s
1 .633 0 r
.008 w
.08952 .37983 Mdot
.016 w
.08952 .37983 m
.08926 .38034 L
s
1 .612 0 r
.008 w
.08926 .38034 Mdot
.016 w
.08926 .38034 m
.08897 .38086 L
s
1 .592 0 r
.008 w
.08897 .38086 Mdot
.016 w
.08897 .38086 m
.08865 .38125 L
s
1 .571 0 r
.008 w
.08865 .38125 Mdot
.016 w
.08865 .38125 m
.08835 .38152 L
s
1 .551 0 r
.008 w
.08835 .38152 Mdot
.016 w
.08835 .38152 m
.08806 .38185 L
s
1 .531 0 r
.008 w
.08806 .38185 Mdot
.016 w
.08806 .38185 m
.0878 .38224 L
s
1 .51 0 r
.008 w
.0878 .38224 Mdot
.016 w
.0878 .38224 m
.0876 .38265 L
s
1 .49 0 r
.008 w
.0876 .38265 Mdot
.016 w
.0876 .38265 m
.08744 .38306 L
s
1 .469 0 r
.008 w
.08744 .38306 Mdot
.016 w
.08744 .38306 m
.08732 .38344 L
s
1 .449 0 r
.008 w
.08732 .38344 Mdot
.016 w
.08732 .38344 m
.08724 .38383 L
s
1 .429 0 r
.008 w
.08724 .38383 Mdot
.016 w
.08724 .38383 m
.08718 .38435 L
s
1 .408 0 r
.008 w
.08718 .38435 Mdot
.016 w
.08718 .38435 m
.08708 .38507 L
s
1 .388 0 r
.008 w
.08708 .38507 Mdot
.016 w
.08708 .38507 m
.08694 .38601 L
s
1 .367 0 r
.008 w
.08694 .38601 Mdot
.016 w
.08694 .38601 m
.08675 .38715 L
s
1 .347 0 r
.008 w
.08675 .38715 Mdot
.016 w
.08675 .38715 m
.08648 .38843 L
s
1 .327 0 r
.008 w
.08648 .38843 Mdot
.016 w
.08648 .38843 m
.08625 .38971 L
s
1 .306 0 r
.008 w
.08625 .38971 Mdot
.016 w
.08625 .38971 m
.08595 .39142 L
s
1 .286 0 r
.008 w
.08595 .39142 Mdot
.016 w
.08595 .39142 m
.08567 .39365 L
s
1 .265 0 r
.008 w
.08567 .39365 Mdot
.016 w
.08567 .39365 m
.08542 .39534 L
s
1 .245 0 r
.008 w
.08542 .39534 Mdot
.016 w
.08542 .39534 m
.08515 .3977 L
s
1 .224 0 r
.008 w
.08515 .3977 Mdot
.016 w
.08515 .3977 m
.08487 .3996 L
s
1 .204 0 r
.008 w
.08487 .3996 Mdot
.016 w
.08487 .3996 m
.08461 .40164 L
s
1 .184 0 r
.008 w
.08461 .40164 Mdot
.016 w
.08461 .40164 m
.0844 .40381 L
s
1 .163 0 r
.008 w
.0844 .40381 Mdot
.016 w
.0844 .40381 m
.08427 .40532 L
s
1 .143 0 r
.008 w
.08427 .40532 Mdot
.016 w
.08427 .40532 m
.08419 .40693 L
s
1 .122 0 r
.008 w
.08419 .40693 Mdot
.016 w
.08419 .40693 m
.08414 .40844 L
s
1 .102 0 r
.008 w
.08414 .40844 Mdot
.016 w
.08414 .40844 m
.08413 .40944 L
s
1 .082 0 r
.008 w
.08413 .40944 Mdot
.016 w
.08413 .40944 m
.08415 .41026 L
s
1 .061 0 r
.008 w
.08415 .41026 Mdot
.016 w
.08415 .41026 m
.08417 .41091 L
s
1 .041 0 r
.008 w
.08417 .41091 Mdot
.016 w
.08417 .41091 m
.08419 .41137 L
s
1 .02 0 r
.008 w
.08419 .41137 Mdot
.016 w
.08419 .41137 m
.08419 .41164 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool3?Nl2O/3]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`03?Nmn07h0009n
0003O/1oogoo0>Yoo`03001oogoo011oo`004Goo00<007ooOol01goo00<mkgePOF000WeP00=n`7oo
Ool0jgoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4OD000gePOomoo`3/Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Qoo`Am8003OF1oogoo0>aoo`03001oogoo00moo`0047oo00<007ooOol0
27oo17cP00=mH7ooOol0k7oo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4O<000gePOomoo`3/
Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`AlX08mknioo`03001oogoo00ioo`003goo00<0
07ooOol02Goo17aP0cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4O003?No]Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Uoo`Al00<mkneoo`03001oogoo00ioo`003goo00<007ooOol0
2Goo17`013g_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool4O004?No]Ool00`00Oomoo`0=
Ool000ioo`03001oogoo00Yoo`Al00PmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2Cg_
jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001o
ogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo
000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03
001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=
Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001o
ogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomo
o`0:Ool8?No_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`Tmknmoo`03001oogoo00aoo`00
3Goo00<007ooOol027oo2Cg_l7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?No`Ool00`00
Oomoo`0<Ool000aoo`03001oogoo00Qoo`Pmko=oo`03001oogoo00]oo`0037oo00<007ooOol01goo
1cg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`06Ool8?NoeOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Eoo`TmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_mGoo00<007ooOol0
2goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo
00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol0
2goo000=Ool00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool000eoo`03001oogoo0?moo`9oo`03001o
ogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo
0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo
0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00
Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo
00<007ooOol0ogoo0Woo00<007ooOol037oo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000io
o`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool0
0`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomo
o`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]o
o`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<0
07ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001o
ogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol0
4Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=o
o`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00
Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007oo
Ool0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo
021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0R
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qo
o`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<0
07ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001o
ogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomo
o`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0
^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=o
o`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000g
Ool00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo
0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03
001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041o
o`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol0
0`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<0
07ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo
001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0
OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo
0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001N
Ool2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3
001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001a
Ool007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D0
08ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo10000Woo1@00Rgoo002:
Ool00`00Oomoo`05Ool00`00Oomoo`2;Ool008]oo`03001oogoo00Aoo`03001oogoo08]oo`00S7oo
00<007ooOol00goo00<007ooOol0Rgoo002:Ool01000Oomoo`0017oo00<007ooOol0Rgoo002;Ool2
0004Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(22)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
1 .985 0 r
.008 w
.08664 .41128 Mdot
.016 w
.08664 .41128 m
.08676 .41138 L
s
1 .971 0 r
.008 w
.08676 .41138 Mdot
.016 w
.08676 .41138 m
.08694 .41151 L
s
1 .956 0 r
.008 w
.08694 .41151 Mdot
.016 w
.08694 .41151 m
.0872 .41169 L
s
1 .941 0 r
.008 w
.0872 .41169 Mdot
.016 w
.0872 .41169 m
.08756 .4119 L
s
1 .926 0 r
.008 w
.08756 .4119 Mdot
.016 w
.08756 .4119 m
.08804 .41213 L
s
1 .912 0 r
.008 w
.08804 .41213 Mdot
.016 w
.08804 .41213 m
.08857 .41236 L
s
1 .897 0 r
.008 w
.08857 .41236 Mdot
.016 w
.08857 .41236 m
.08905 .41257 L
s
1 .882 0 r
.008 w
.08905 .41257 Mdot
.016 w
.08905 .41257 m
.08958 .41275 L
s
1 .868 0 r
.008 w
.08958 .41275 Mdot
.016 w
.08958 .41275 m
.09014 .41294 L
s
1 .853 0 r
.008 w
.09014 .41294 Mdot
.016 w
.09014 .41294 m
.0906 .41315 L
s
1 .838 0 r
.008 w
.0906 .41315 Mdot
.016 w
.0906 .41315 m
.09099 .41342 L
s
1 .824 0 r
.008 w
.09099 .41342 Mdot
.016 w
.09099 .41342 m
.0913 .41366 L
s
1 .809 0 r
.008 w
.0913 .41366 Mdot
.016 w
.0913 .41366 m
.09151 .41393 L
s
1 .794 0 r
.008 w
.09151 .41393 Mdot
.016 w
.09151 .41393 m
.0917 .41422 L
s
1 .779 0 r
.008 w
.0917 .41422 Mdot
.016 w
.0917 .41422 m
.09191 .41456 L
s
1 .765 0 r
.008 w
.09191 .41456 Mdot
.016 w
.09191 .41456 m
.09211 .41484 L
s
1 .75 0 r
.008 w
.09211 .41484 Mdot
.016 w
.09211 .41484 m
.0923 .41519 L
s
1 .735 0 r
.008 w
.0923 .41519 Mdot
.016 w
.0923 .41519 m
.09246 .41559 L
s
1 .721 0 r
.008 w
.09246 .41559 Mdot
.016 w
.09246 .41559 m
.09271 .41603 L
s
1 .706 0 r
.008 w
.09271 .41603 Mdot
.016 w
.09271 .41603 m
.09307 .41656 L
s
1 .691 0 r
.008 w
.09307 .41656 Mdot
.016 w
.09307 .41656 m
.09351 .41719 L
s
1 .676 0 r
.008 w
.09351 .41719 Mdot
.016 w
.09351 .41719 m
.09395 .41791 L
s
1 .662 0 r
.008 w
.09395 .41791 Mdot
.016 w
.09395 .41791 m
.09449 .4187 L
s
1 .647 0 r
.008 w
.09449 .4187 Mdot
.016 w
.09449 .4187 m
.09508 .41959 L
s
1 .632 0 r
.008 w
.09508 .41959 Mdot
.016 w
.09508 .41959 m
.09555 .42058 L
s
1 .618 0 r
.008 w
.09555 .42058 Mdot
.016 w
.09555 .42058 m
.09599 .42153 L
s
1 .603 0 r
.008 w
.09599 .42153 Mdot
.016 w
.09599 .42153 m
.09641 .42256 L
s
1 .588 0 r
.008 w
.09641 .42256 Mdot
.016 w
.09641 .42256 m
.09675 .42372 L
s
1 .574 0 r
.008 w
.09675 .42372 Mdot
.016 w
.09675 .42372 m
.09696 .42498 L
s
1 .559 0 r
.008 w
.09696 .42498 Mdot
.016 w
.09696 .42498 m
.0971 .42627 L
s
1 .544 0 r
.008 w
.0971 .42627 Mdot
.016 w
.0971 .42627 m
.09715 .4275 L
s
1 .529 0 r
.008 w
.09715 .4275 Mdot
.016 w
.09715 .4275 m
.09712 .42879 L
s
1 .515 0 r
.008 w
.09712 .42879 Mdot
.016 w
.09712 .42879 m
.09701 .43022 L
s
1 .5 0 r
.008 w
.09701 .43022 Mdot
.016 w
.09701 .43022 m
.09682 .43194 L
s
1 .485 0 r
.008 w
.09682 .43194 Mdot
.016 w
.09682 .43194 m
.09657 .43335 L
s
1 .471 0 r
.008 w
.09657 .43335 Mdot
.016 w
.09657 .43335 m
.09631 .43488 L
s
1 .456 0 r
.008 w
.09631 .43488 Mdot
.016 w
.09631 .43488 m
.09602 .43666 L
s
1 .441 0 r
.008 w
.09602 .43666 Mdot
.016 w
.09602 .43666 m
.09572 .43856 L
s
1 .426 0 r
.008 w
.09572 .43856 Mdot
.016 w
.09572 .43856 m
.0954 .4403 L
s
1 .412 0 r
.008 w
.0954 .4403 Mdot
.016 w
.0954 .4403 m
.09513 .44162 L
s
1 .397 0 r
.008 w
.09513 .44162 Mdot
.016 w
.09513 .44162 m
.09488 .44351 L
s
1 .382 0 r
.008 w
.09488 .44351 Mdot
.016 w
.09488 .44351 m
.09462 .44487 L
s
1 .368 0 r
.008 w
.09462 .44487 Mdot
.016 w
.09462 .44487 m
.09435 .44647 L
s
1 .353 0 r
.008 w
.09435 .44647 Mdot
.016 w
.09435 .44647 m
.09407 .44826 L
s
1 .338 0 r
.008 w
.09407 .44826 Mdot
.016 w
.09407 .44826 m
.09385 .44967 L
s
1 .324 0 r
.008 w
.09385 .44967 Mdot
.016 w
.09385 .44967 m
.09367 .45088 L
s
1 .309 0 r
.008 w
.09367 .45088 Mdot
.016 w
.09367 .45088 m
.0935 .452 L
s
1 .294 0 r
.008 w
.0935 .452 Mdot
.016 w
.0935 .452 m
.09336 .45302 L
s
1 .279 0 r
.008 w
.09336 .45302 Mdot
.016 w
.09336 .45302 m
.09321 .45392 L
s
1 .265 0 r
.008 w
.09321 .45392 Mdot
.016 w
.09321 .45392 m
.09304 .45468 L
s
1 .25 0 r
.008 w
.09304 .45468 Mdot
.016 w
.09304 .45468 m
.09281 .45532 L
s
1 .235 0 r
.008 w
.09281 .45532 Mdot
.016 w
.09281 .45532 m
.09249 .45589 L
s
1 .221 0 r
.008 w
.09249 .45589 Mdot
.016 w
.09249 .45589 m
.09206 .45648 L
s
1 .206 0 r
.008 w
.09206 .45648 Mdot
.016 w
.09206 .45648 m
.09151 .45711 L
s
1 .191 0 r
.008 w
.09151 .45711 Mdot
.016 w
.09151 .45711 m
.09083 .45778 L
s
1 .176 0 r
.008 w
.09083 .45778 Mdot
.016 w
.09083 .45778 m
.08999 .45852 L
s
1 .162 0 r
.008 w
.08999 .45852 Mdot
.016 w
.08999 .45852 m
.08901 .45937 L
s
1 .147 0 r
.008 w
.08901 .45937 Mdot
.016 w
.08901 .45937 m
.08802 .46027 L
s
1 .132 0 r
.008 w
.08802 .46027 Mdot
.016 w
.08802 .46027 m
.08717 .46112 L
s
1 .118 0 r
.008 w
.08717 .46112 Mdot
.016 w
.08717 .46112 m
.08638 .46177 L
s
1 .103 0 r
.008 w
.08638 .46177 Mdot
.016 w
.08638 .46177 m
.08565 .4625 L
s
1 .088 0 r
.008 w
.08565 .4625 Mdot
.016 w
.08565 .4625 m
.08498 .46309 L
s
1 .074 0 r
.008 w
.08498 .46309 Mdot
.016 w
.08498 .46309 m
.08431 .46365 L
s
1 .059 0 r
.008 w
.08431 .46365 Mdot
.016 w
.08431 .46365 m
.08365 .46416 L
s
1 .044 0 r
.008 w
.08365 .46416 Mdot
.016 w
.08365 .46416 m
.08314 .46458 L
s
1 .029 0 r
.008 w
.08314 .46458 Mdot
.016 w
.08314 .46458 m
.08287 .46487 L
s
1 .015 0 r
.008 w
.08287 .46487 Mdot
.016 w
.08287 .46487 m
.08276 .46504 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool00cg_Ol1o`002Ol02?No]Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`03?NmoH7kP00=nh003?Nmoogoo0>]oo`03001oogoo00ioo`003goo00<007oo
Ool02Goo00<mkgmPOZ0017j000<mkgooOol0jWoo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool0
0cg_Of1nX004OV000cg_Oomoo`3[Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo`03?NmoH7jP
00An80DmknUoo`03001oogoo00eoo`003Woo00<007ooOol037oo00=nX7h0OP000Wh01Cg_jGoo00<0
07ooOol03Goo000>Ool00`00Oomoo`0=Ool4ON07?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo
00eoo`Am`0PmknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo17fP2Cg_iWoo00<007ooOol0
37oo000=Ool00`00Oomoo`0>Ool4OH09?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`03
?NmmH7eP009mH0TmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo17dP00=m@3g_?Nl01cg_
iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool4O>000ge0?Nlmk`06?NoWOol00`00Oomoo`0<
Ool000eoo`03001oogoo00aoo`ElX004OD0mkcg_Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Al@003O61lX7e000=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Woo1G`0
00=lH7bP?Nl0kgoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool00cg_O01l0003O0000gaPO:0m
k`3_Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`8mk`El0003O60mkgoo0>moo`03001oogoo
00aoo`003Goo00<007ooOol027oo0Sg_1G`00Sg_l7oo00<007ooOol037oo000<Ool00`00Oomoo`08
Ool8?NocOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`LmkoEoo`03001oogoo00]oo`0037oo
00<007ooOol01Woo23g_mGoo00<007ooOol02goo000<Ool00`00Oomoo`05Ool9?NoeOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_
mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Qoo`DmkoIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_mWoo00<007ooOol02goo
000<Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo
00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<Ool00`00Oomoo`3oOol4Ool00`00
Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]oo`003Goo00<007ooOol0ogoo0goo
00<007ooOol02goo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?mo
o`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomo
o`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo
000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo
00aoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=
Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo
000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`00
3goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000mo
o`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool0
0`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<0
07ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001o
ogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomo
o`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0
mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Io
o`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol0
0`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<0
07ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001o
ogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomo
o`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol0
5Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Io
o`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol0
01Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000I
Ool00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo
00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03
001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00
Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007oo
Ool0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo
0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3M
Ool00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo
00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03
001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00
Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007oo
Ool097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo
02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0W
Ool002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo
000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00
;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002io
o`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool0
0`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<0
07ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001o
ogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomo
o`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0
=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007oo
Ool0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo
0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0o
Ool0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomo
o`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00
Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool0
0`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00
Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo
001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001K
Ool00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4
001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qo
o`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol008Yoo`@0009oo`@008aoo`00RWoo00<007ooOol00goo00<007ooOol0
SGoo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008aoo`03001oogoo00=oo`03001oogoo08]o
o`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(23)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
1 .983 0 r
.008 w
.08434 .47421 Mdot
.016 w
.08434 .47421 m
.0845 .47406 L
s
1 .966 0 r
.008 w
.0845 .47406 Mdot
.016 w
.0845 .47406 m
.08479 .47385 L
s
1 .948 0 r
.008 w
.08479 .47385 Mdot
.016 w
.08479 .47385 m
.08522 .47357 L
s
1 .931 0 r
.008 w
.08522 .47357 Mdot
.016 w
.08522 .47357 m
.08576 .47324 L
s
1 .914 0 r
.008 w
.08576 .47324 Mdot
.016 w
.08576 .47324 m
.08636 .47286 L
s
1 .897 0 r
.008 w
.08636 .47286 Mdot
.016 w
.08636 .47286 m
.08712 .4724 L
s
1 .879 0 r
.008 w
.08712 .4724 Mdot
.016 w
.08712 .4724 m
.08802 .47186 L
s
1 .862 0 r
.008 w
.08802 .47186 Mdot
.016 w
.08802 .47186 m
.08904 .47126 L
s
1 .845 0 r
.008 w
.08904 .47126 Mdot
.016 w
.08904 .47126 m
.09013 .47057 L
s
1 .828 0 r
.008 w
.09013 .47057 Mdot
.016 w
.09013 .47057 m
.09116 .46984 L
s
1 .81 0 r
.008 w
.09116 .46984 Mdot
.016 w
.09116 .46984 m
.09213 .46908 L
s
1 .793 0 r
.008 w
.09213 .46908 Mdot
.016 w
.09213 .46908 m
.09303 .46834 L
s
1 .776 0 r
.008 w
.09303 .46834 Mdot
.016 w
.09303 .46834 m
.09381 .46764 L
s
1 .759 0 r
.008 w
.09381 .46764 Mdot
.016 w
.09381 .46764 m
.09445 .46701 L
s
1 .741 0 r
.008 w
.09445 .46701 Mdot
.016 w
.09445 .46701 m
.09498 .46648 L
s
1 .724 0 r
.008 w
.09498 .46648 Mdot
.016 w
.09498 .46648 m
.09539 .46602 L
s
1 .707 0 r
.008 w
.09539 .46602 Mdot
.016 w
.09539 .46602 m
.0957 .46561 L
s
1 .69 0 r
.008 w
.0957 .46561 Mdot
.016 w
.0957 .46561 m
.09593 .46526 L
s
1 .672 0 r
.008 w
.09593 .46526 Mdot
.016 w
.09593 .46526 m
.09612 .46495 L
s
1 .655 0 r
.008 w
.09612 .46495 Mdot
.016 w
.09612 .46495 m
.09629 .46469 L
s
1 .638 0 r
.008 w
.09629 .46469 Mdot
.016 w
.09629 .46469 m
.09646 .4645 L
s
1 .621 0 r
.008 w
.09646 .4645 Mdot
.016 w
.09646 .4645 m
.09667 .46439 L
s
1 .603 0 r
.008 w
.09667 .46439 Mdot
.016 w
.09667 .46439 m
.09696 .46436 L
s
1 .586 0 r
.008 w
.09696 .46436 Mdot
.016 w
.09696 .46436 m
.09732 .46438 L
s
1 .569 0 r
.008 w
.09732 .46438 Mdot
.016 w
.09732 .46438 m
.09773 .46445 L
s
1 .552 0 r
.008 w
.09773 .46445 Mdot
.016 w
.09773 .46445 m
.09821 .46452 L
s
1 .534 0 r
.008 w
.09821 .46452 Mdot
.016 w
.09821 .46452 m
.09877 .46457 L
s
1 .517 0 r
.008 w
.09877 .46457 Mdot
.016 w
.09877 .46457 m
.09938 .46459 L
s
1 .5 0 r
.008 w
.09938 .46459 Mdot
.016 w
.09938 .46459 m
.1 .46459 L
s
1 .483 0 r
.008 w
.1 .46459 Mdot
.016 w
.1 .46459 m
.10062 .46458 L
s
1 .466 0 r
.008 w
.10062 .46458 Mdot
.016 w
.10062 .46458 m
.10124 .46457 L
s
1 .448 0 r
.008 w
.10124 .46457 Mdot
.016 w
.10124 .46457 m
.10187 .46456 L
s
1 .431 0 r
.008 w
.10187 .46456 Mdot
.016 w
.10187 .46456 m
.10254 .46456 L
s
1 .414 0 r
.008 w
.10254 .46456 Mdot
.016 w
.10254 .46456 m
.10322 .46454 L
s
1 .397 0 r
.008 w
.10322 .46454 Mdot
.016 w
.10322 .46454 m
.10395 .46451 L
s
1 .379 0 r
.008 w
.10395 .46451 Mdot
.016 w
.10395 .46451 m
.10472 .46445 L
s
1 .362 0 r
.008 w
.10472 .46445 Mdot
.016 w
.10472 .46445 m
.10554 .46437 L
s
1 .345 0 r
.008 w
.10554 .46437 Mdot
.016 w
.10554 .46437 m
.10634 .46429 L
s
1 .328 0 r
.008 w
.10634 .46429 Mdot
.016 w
.10634 .46429 m
.10716 .46425 L
s
1 .31 0 r
.008 w
.10716 .46425 Mdot
.016 w
.10716 .46425 m
.10793 .46426 L
s
1 .293 0 r
.008 w
.10793 .46426 Mdot
.016 w
.10793 .46426 m
.10862 .46435 L
s
1 .276 0 r
.008 w
.10862 .46435 Mdot
.016 w
.10862 .46435 m
.10932 .46453 L
s
1 .259 0 r
.008 w
.10932 .46453 Mdot
.016 w
.10932 .46453 m
.10994 .46479 L
s
1 .241 0 r
.008 w
.10994 .46479 Mdot
.016 w
.10994 .46479 m
.11051 .46514 L
s
1 .224 0 r
.008 w
.11051 .46514 Mdot
.016 w
.11051 .46514 m
.11105 .46554 L
s
1 .207 0 r
.008 w
.11105 .46554 Mdot
.016 w
.11105 .46554 m
.11154 .46599 L
s
1 .19 0 r
.008 w
.11154 .46599 Mdot
.016 w
.11154 .46599 m
.11197 .46647 L
s
1 .172 0 r
.008 w
.11197 .46647 Mdot
.016 w
.11197 .46647 m
.11232 .46693 L
s
1 .155 0 r
.008 w
.11232 .46693 Mdot
.016 w
.11232 .46693 m
.1126 .4674 L
s
1 .138 0 r
.008 w
.1126 .4674 Mdot
.016 w
.1126 .4674 m
.11284 .46786 L
s
1 .121 0 r
.008 w
.11284 .46786 Mdot
.016 w
.11284 .46786 m
.11304 .46829 L
s
1 .103 0 r
.008 w
.11304 .46829 Mdot
.016 w
.11304 .46829 m
.11322 .46866 L
s
1 .086 0 r
.008 w
.11322 .46866 Mdot
.016 w
.11322 .46866 m
.1134 .46896 L
s
1 .069 0 r
.008 w
.1134 .46896 Mdot
.016 w
.1134 .46896 m
.1136 .46917 L
s
1 .052 0 r
.008 w
.1136 .46917 Mdot
.016 w
.1136 .46917 m
.11381 .46928 L
s
1 .034 0 r
.008 w
.11381 .46928 Mdot
.016 w
.11381 .46928 m
.11401 .46932 L
s
1 .017 0 r
.008 w
.11401 .46932 Mdot
.016 w
.11401 .46932 m
.11417 .46929 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool0
0`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo
00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoW
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007oo
Ool03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ao
o`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0:Ool4?Nl017i0OL1mH7dP17c0jgoo00<007ooOol037oo
000=Ool00`00Oomoo`09Ool4?Nl01Gl0OT1m`7ePOB000WbP00=lP7bPO:00jWoo00<007ooOol037oo
000=Ool00`00Oomoo`08Ool3?Nl01gn0Od1o07i0OL1mH7dP009lX003O01lX7bP0>Yoo`03001oogoo
00aoo`003Goo00<007ooOol027oo0cg_00MoP7m0O`1n@7g0OF1m8002O:000g`0O:1lX03ZOol00`00
Oomoo`0<Ool000aoo`03001oogoo00Qoo`@mk`03Oh1o@7l000Anh0ElX>]oo`03001oogoo00]oo`00
37oo00<007ooOol01goo1Cg_00=oP7m0Ob000glPlGoo00<007ooOol02goo000<Ool00`00Oomoo`06
Ool6?Nl4Oj3cOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`TmkoEoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Sg_mGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?NoeOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`HmkoEoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Cg_mWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?NofOol00`00Oomoo`0;Ool000aoo`03
001oogoo0?moo`Aoo`03001oogoo00]oo`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000<
Ool00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool000aoo`03001oogoo0?moo`Aoo`03001oogoo00]o
o`0037oo00<007ooOol0ogoo17oo00<007ooOol02goo000=Ool00`00Oomoo`3oOol3Ool00`00Oomo
o`0;Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<0
07ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9o
o`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3o
Ool2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03
001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000>
Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo
00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03
001oogoo0?ioo`03001oogoo00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00
Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007oo
Ool0oGoo00<007ooOol03Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo
0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo
00<007ooOol03goo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03
001oogoo011oo`004Woo00<007ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00
Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007oo
Ool04Goo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo
019oo`0057oo00<007ooOol0m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0C
Ool001Aoo`03001oogoo0?=oo`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo
000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`00
5Goo00<007ooOol0lGoo00<007ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Io
o`03001oogoo0>moo`03001oogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol0
0`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<0
07ooOol0jgoo00<007ooOol05goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001o
ogoo0>Uoo`03001oogoo01Qoo`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomo
o`3WOol00`00Oomoo`0IOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0
iGoo00<007ooOol06Woo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=o
o`03001oogoo01]oo`007Goo00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol0
0`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<0
07ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001o
ogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomo
o`0OOol0025oo`03001oogoo0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol0
8Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=o
o`0097oo00<007ooOol0dgoo00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol0
02Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000W
Ool00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo
00<007ooOol0bGoo00<007ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03
001oogoo0<Moo`03001oogoo02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00
Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007oo
Ool0_goo00<007ooOol0;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo
0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2i
Ool00`00Oomoo`0`Ool0039oo`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo
000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00
=Woo00<007ooOol0[goo00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qo
o`03001oogoo0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol0
0`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<0
07ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo
0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03
001oogoo04=oo`00AGoo00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qo
o`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo
07moo`03001oogoo04eoo`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001A
Ool0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<0
06Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001o
ogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00
K7oo1000?goo1000KGoo001`Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo
1`00NGoo001oOol>0005Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00RWoo10000goo0P00SGoo002:Ool00`00Oomoo`03Ool01000Oomoo`00S7oo002;
Ool00`00Oomoo`04Ool00`00Oomoo`2;Ool008aoo`03001oogoo00Aoo`03001oogoo08Yoo`00RWoo
00@007ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(24)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
1 .993 0 r
.008 w
.11421 .46895 Mdot
.016 w
.11421 .46895 m
.11439 .46905 L
s
1 .986 0 r
.008 w
.11439 .46905 Mdot
.016 w
.11439 .46905 m
.11462 .46919 L
s
1 .978 0 r
.008 w
.11462 .46919 Mdot
.016 w
.11462 .46919 m
.1149 .46936 L
s
1 .971 0 r
.008 w
.1149 .46936 Mdot
.016 w
.1149 .46936 m
.11523 .46956 L
s
1 .964 0 r
.008 w
.11523 .46956 Mdot
.016 w
.11523 .46956 m
.11562 .4698 L
s
1 .957 0 r
.008 w
.11562 .4698 Mdot
.016 w
.11562 .4698 m
.11603 .47009 L
s
1 .949 0 r
.008 w
.11603 .47009 Mdot
.016 w
.11603 .47009 m
.11655 .4705 L
s
1 .942 0 r
.008 w
.11655 .4705 Mdot
.016 w
.11655 .4705 m
.11707 .47097 L
s
1 .935 0 r
.008 w
.11707 .47097 Mdot
.016 w
.11707 .47097 m
.11765 .47155 L
s
1 .928 0 r
.008 w
.11765 .47155 Mdot
.016 w
.11765 .47155 m
.11831 .47227 L
s
1 .92 0 r
.008 w
.11831 .47227 Mdot
.016 w
.11831 .47227 m
.11899 .47305 L
s
1 .913 0 r
.008 w
.11899 .47305 Mdot
.016 w
.11899 .47305 m
.11961 .47379 L
s
1 .906 0 r
.008 w
.11961 .47379 Mdot
.016 w
.11961 .47379 m
.12027 .47464 L
s
1 .899 0 r
.008 w
.12027 .47464 Mdot
.016 w
.12027 .47464 m
.12087 .47549 L
s
1 .891 0 r
.008 w
.12087 .47549 Mdot
.016 w
.12087 .47549 m
.12145 .47634 L
s
1 .884 0 r
.008 w
.12145 .47634 Mdot
.016 w
.12145 .47634 m
.12199 .47716 L
s
1 .877 0 r
.008 w
.12199 .47716 Mdot
.016 w
.12199 .47716 m
.1225 .47794 L
s
1 .87 0 r
.008 w
.1225 .47794 Mdot
.016 w
.1225 .47794 m
.12298 .47859 L
s
1 .862 0 r
.008 w
.12298 .47859 Mdot
.016 w
.12298 .47859 m
.12341 .47917 L
s
1 .855 0 r
.008 w
.12341 .47917 Mdot
.016 w
.12341 .47917 m
.1238 .47968 L
s
1 .848 0 r
.008 w
.1238 .47968 Mdot
.016 w
.1238 .47968 m
.12411 .48007 L
s
1 .841 0 r
.008 w
.12411 .48007 Mdot
.016 w
.12411 .48007 m
.12431 .48033 L
s
1 .833 0 r
.008 w
.12431 .48033 Mdot
.016 w
.12431 .48033 m
.1244 .48048 L
s
1 .826 0 r
.008 w
.1244 .48048 Mdot
.016 w
.1244 .48048 m
.12438 .48059 L
s
1 .819 0 r
.008 w
.12438 .48059 Mdot
.016 w
.12438 .48059 m
.1243 .48075 L
s
1 .812 0 r
.008 w
.1243 .48075 Mdot
.016 w
.1243 .48075 m
.12419 .481 L
s
1 .804 0 r
.008 w
.12419 .481 Mdot
.016 w
.12419 .481 m
.12409 .48133 L
s
1 .797 0 r
.008 w
.12409 .48133 Mdot
.016 w
.12409 .48133 m
.12404 .48176 L
s
1 .79 0 r
.008 w
.12404 .48176 Mdot
.016 w
.12404 .48176 m
.12408 .48229 L
s
1 .783 0 r
.008 w
.12408 .48229 Mdot
.016 w
.12408 .48229 m
.12425 .48291 L
s
1 .775 0 r
.008 w
.12425 .48291 Mdot
.016 w
.12425 .48291 m
.12456 .48357 L
s
1 .768 0 r
.008 w
.12456 .48357 Mdot
.016 w
.12456 .48357 m
.12501 .48426 L
s
1 .761 0 r
.008 w
.12501 .48426 Mdot
.016 w
.12501 .48426 m
.12557 .48494 L
s
1 .754 0 r
.008 w
.12557 .48494 Mdot
.016 w
.12557 .48494 m
.12624 .48559 L
s
1 .746 0 r
.008 w
.12624 .48559 Mdot
.016 w
.12624 .48559 m
.12696 .48617 L
s
1 .739 0 r
.008 w
.12696 .48617 Mdot
.016 w
.12696 .48617 m
.12764 .48666 L
s
1 .732 0 r
.008 w
.12764 .48666 Mdot
.016 w
.12764 .48666 m
.12833 .48705 L
s
1 .725 0 r
.008 w
.12833 .48705 Mdot
.016 w
.12833 .48705 m
.12902 .4873 L
s
1 .717 0 r
.008 w
.12902 .4873 Mdot
.016 w
.12902 .4873 m
.12975 .48744 L
s
1 .71 0 r
.008 w
.12975 .48744 Mdot
.016 w
.12975 .48744 m
.13039 .48749 L
s
1 .703 0 r
.008 w
.13039 .48749 Mdot
.016 w
.13039 .48749 m
.13097 .48749 L
s
1 .696 0 r
.008 w
.13097 .48749 Mdot
.016 w
.13097 .48749 m
.13148 .4875 L
s
1 .688 0 r
.008 w
.13148 .4875 Mdot
.016 w
.13148 .4875 m
.13191 .48757 L
s
1 .681 0 r
.008 w
.13191 .48757 Mdot
.016 w
.13191 .48757 m
.13226 .48774 L
s
1 .674 0 r
.008 w
.13226 .48774 Mdot
.016 w
.13226 .48774 m
.13254 .48801 L
s
1 .667 0 r
.008 w
.13254 .48801 Mdot
.016 w
.13254 .48801 m
.1328 .48838 L
s
1 .659 0 r
.008 w
.1328 .48838 Mdot
.016 w
.1328 .48838 m
.13303 .48876 L
s
1 .652 0 r
.008 w
.13303 .48876 Mdot
.016 w
.13303 .48876 m
.13327 .48918 L
s
1 .645 0 r
.008 w
.13327 .48918 Mdot
.016 w
.13327 .48918 m
.13349 .48962 L
s
1 .638 0 r
.008 w
.13349 .48962 Mdot
.016 w
.13349 .48962 m
.13369 .49002 L
s
1 .63 0 r
.008 w
.13369 .49002 Mdot
.016 w
.13369 .49002 m
.13385 .49043 L
s
1 .623 0 r
.008 w
.13385 .49043 Mdot
.016 w
.13385 .49043 m
.13396 .49081 L
s
1 .616 0 r
.008 w
.13396 .49081 Mdot
.016 w
.13396 .49081 m
.134 .49115 L
s
1 .609 0 r
.008 w
.134 .49115 Mdot
.016 w
.134 .49115 m
.13395 .49143 L
s
1 .601 0 r
.008 w
.13395 .49143 Mdot
.016 w
.13395 .49143 m
.13382 .4916 L
s
1 .594 0 r
.008 w
.13382 .4916 Mdot
.016 w
.13382 .4916 m
.13361 .49166 L
s
1 .587 0 r
.008 w
.13361 .49166 Mdot
.016 w
.13361 .49166 m
.13333 .49165 L
s
1 .58 0 r
.008 w
.13333 .49165 Mdot
.016 w
.13333 .49165 m
.13301 .49159 L
s
1 .572 0 r
.008 w
.13301 .49159 Mdot
.016 w
.13301 .49159 m
.13268 .49151 L
s
1 .565 0 r
.008 w
.13268 .49151 Mdot
.016 w
.13268 .49151 m
.13236 .49147 L
s
1 .558 0 r
.008 w
.13236 .49147 Mdot
.016 w
.13236 .49147 m
.13209 .49156 L
s
1 .551 0 r
.008 w
.13209 .49156 Mdot
.016 w
.13209 .49156 m
.13189 .49184 L
s
1 .543 0 r
.008 w
.13189 .49184 Mdot
.016 w
.13189 .49184 m
.13177 .49233 L
s
1 .536 0 r
.008 w
.13177 .49233 Mdot
.016 w
.13177 .49233 m
.13173 .493 L
s
1 .529 0 r
.008 w
.13173 .493 Mdot
.016 w
.13173 .493 m
.13178 .49384 L
s
1 .522 0 r
.008 w
.13178 .49384 Mdot
.016 w
.13178 .49384 m
.13191 .49482 L
s
1 .514 0 r
.008 w
.13191 .49482 Mdot
.016 w
.13191 .49482 m
.13209 .49591 L
s
1 .507 0 r
.008 w
.13209 .49591 Mdot
.016 w
.13209 .49591 m
.13232 .49689 L
s
1 .5 0 r
.008 w
.13232 .49689 Mdot
.016 w
.13232 .49689 m
.13256 .49792 L
s
1 .493 0 r
.008 w
.13256 .49792 Mdot
.016 w
.13256 .49792 m
.13277 .49894 L
s
1 .486 0 r
.008 w
.13277 .49894 Mdot
.016 w
.13277 .49894 m
.13298 .49994 L
s
1 .478 0 r
.008 w
.13298 .49994 Mdot
.016 w
.13298 .49994 m
.13314 .5009 L
s
1 .471 0 r
.008 w
.13314 .5009 Mdot
.016 w
.13314 .5009 m
.13331 .5016 L
s
1 .464 0 r
.008 w
.13331 .5016 Mdot
.016 w
.13331 .5016 m
.13347 .50228 L
s
1 .457 0 r
.008 w
.13347 .50228 Mdot
.016 w
.13347 .50228 m
.13362 .50283 L
s
1 .449 0 r
.008 w
.13362 .50283 Mdot
.016 w
.13362 .50283 m
.13375 .50328 L
s
1 .442 0 r
.008 w
.13375 .50328 Mdot
.016 w
.13375 .50328 m
.13388 .50371 L
s
1 .435 0 r
.008 w
.13388 .50371 Mdot
.016 w
.13388 .50371 m
.13404 .50418 L
s
1 .428 0 r
.008 w
.13404 .50418 Mdot
.016 w
.13404 .50418 m
.13426 .50479 L
s
1 .42 0 r
.008 w
.13426 .50479 Mdot
.016 w
.13426 .50479 m
.13454 .50558 L
s
1 .413 0 r
.008 w
.13454 .50558 Mdot
.016 w
.13454 .50558 m
.13492 .50658 L
s
1 .406 0 r
.008 w
.13492 .50658 Mdot
.016 w
.13492 .50658 m
.13538 .50763 L
s
1 .399 0 r
.008 w
.13538 .50763 Mdot
.016 w
.13538 .50763 m
.13592 .50887 L
s
1 .391 0 r
.008 w
.13592 .50887 Mdot
.016 w
.13592 .50887 m
.13652 .51027 L
s
1 .384 0 r
.008 w
.13652 .51027 Mdot
.016 w
.13652 .51027 m
.13717 .51183 L
s
1 .377 0 r
.008 w
.13717 .51183 Mdot
.016 w
.13717 .51183 m
.13782 .51333 L
s
1 .37 0 r
.008 w
.13782 .51333 Mdot
.016 w
.13782 .51333 m
.13837 .5147 L
s
1 .362 0 r
.008 w
.13837 .5147 Mdot
.016 w
.13837 .5147 m
.13891 .51605 L
s
1 .355 0 r
.008 w
.13891 .51605 Mdot
.016 w
.13891 .51605 m
.13937 .51713 L
s
1 .348 0 r
.008 w
.13937 .51713 Mdot
.016 w
.13937 .51713 m
.13982 .51809 L
s
1 .341 0 r
.008 w
.13982 .51809 Mdot
.016 w
.13982 .51809 m
.14026 .51889 L
s
1 .333 0 r
.008 w
.14026 .51889 Mdot
.016 w
.14026 .51889 m
.14069 .51951 L
s
1 .326 0 r
.008 w
.14069 .51951 Mdot
.016 w
.14069 .51951 m
.14113 .51995 L
s
1 .319 0 r
.008 w
.14113 .51995 Mdot
.016 w
.14113 .51995 m
.14158 .52025 L
s
1 .312 0 r
.008 w
.14158 .52025 Mdot
.016 w
.14158 .52025 m
.14205 .52047 L
s
1 .304 0 r
.008 w
.14205 .52047 Mdot
.016 w
.14205 .52047 m
.14254 .52062 L
s
1 .297 0 r
.008 w
.14254 .52062 Mdot
.016 w
.14254 .52062 m
.143 .52074 L
s
1 .29 0 r
.008 w
.143 .52074 Mdot
.016 w
.143 .52074 m
.14346 .52085 L
s
1 .283 0 r
.008 w
.14346 .52085 Mdot
.016 w
.14346 .52085 m
.1439 .52097 L
s
1 .275 0 r
.008 w
.1439 .52097 Mdot
.016 w
.1439 .52097 m
.14438 .52116 L
s
1 .268 0 r
.008 w
.14438 .52116 Mdot
.016 w
.14438 .52116 m
.14489 .52138 L
s
1 .261 0 r
.008 w
.14489 .52138 Mdot
.016 w
.14489 .52138 m
.14538 .52161 L
s
1 .254 0 r
.008 w
.14538 .52161 Mdot
.016 w
.14538 .52161 m
.14581 .5218 L
s
1 .246 0 r
.008 w
.14581 .5218 Mdot
.016 w
.14581 .5218 m
.14613 .52193 L
s
1 .239 0 r
.008 w
.14613 .52193 Mdot
.016 w
.14613 .52193 m
.1463 .52197 L
s
1 .232 0 r
.008 w
.1463 .52197 Mdot
.016 w
.1463 .52197 m
.14632 .52189 L
s
1 .225 0 r
.008 w
.14632 .52189 Mdot
.016 w
.14632 .52189 m
.14621 .52168 L
s
1 .217 0 r
.008 w
.14621 .52168 Mdot
.016 w
.14621 .52168 m
.146 .52137 L
s
1 .21 0 r
.008 w
.146 .52137 Mdot
.016 w
.146 .52137 m
.14571 .52101 L
s
1 .203 0 r
.008 w
.14571 .52101 Mdot
.016 w
.14571 .52101 m
.14538 .52065 L
s
1 .196 0 r
.008 w
.14538 .52065 Mdot
.016 w
.14538 .52065 m
.14503 .52031 L
s
1 .188 0 r
.008 w
.14503 .52031 Mdot
.016 w
.14503 .52031 m
.1447 .52006 L
s
1 .181 0 r
.008 w
.1447 .52006 Mdot
.016 w
.1447 .52006 m
.14438 .51994 L
s
1 .174 0 r
.008 w
.14438 .51994 Mdot
.016 w
.14438 .51994 m
.14409 .51998 L
s
1 .167 0 r
.008 w
.14409 .51998 Mdot
.016 w
.14409 .51998 m
.14384 .52025 L
s
1 .159 0 r
.008 w
.14384 .52025 Mdot
.016 w
.14384 .52025 m
.14367 .52081 L
s
1 .152 0 r
.008 w
.14367 .52081 Mdot
.016 w
.14367 .52081 m
.14358 .5217 L
s
1 .145 0 r
.008 w
.14358 .5217 Mdot
.016 w
.14358 .5217 m
.14358 .52293 L
s
1 .138 0 r
.008 w
.14358 .52293 Mdot
.016 w
.14358 .52293 m
.14365 .52439 L
s
1 .13 0 r
.008 w
.14365 .52439 Mdot
.016 w
.14365 .52439 m
.14376 .52607 L
s
1 .123 0 r
.008 w
.14376 .52607 Mdot
.016 w
.14376 .52607 m
.14392 .52806 L
s
1 .116 0 r
.008 w
.14392 .52806 Mdot
.016 w
.14392 .52806 m
.1441 .53035 L
s
1 .109 0 r
.008 w
.1441 .53035 Mdot
.016 w
.1441 .53035 m
.14431 .53244 L
s
1 .101 0 r
.008 w
.14431 .53244 Mdot
.016 w
.14431 .53244 m
.14453 .5349 L
s
1 .094 0 r
.008 w
.14453 .5349 Mdot
.016 w
.14453 .5349 m
.14477 .53705 L
s
1 .087 0 r
.008 w
.14477 .53705 Mdot
.016 w
.14477 .53705 m
.14504 .53929 L
s
1 .08 0 r
.008 w
.14504 .53929 Mdot
.016 w
.14504 .53929 m
.1453 .54152 L
s
1 .072 0 r
.008 w
.1453 .54152 Mdot
.016 w
.1453 .54152 m
.14557 .5433 L
s
1 .065 0 r
.008 w
.14557 .5433 Mdot
.016 w
.14557 .5433 m
.14584 .54492 L
s
1 .058 0 r
.008 w
.14584 .54492 Mdot
.016 w
.14584 .54492 m
.1461 .54633 L
s
1 .051 0 r
.008 w
.1461 .54633 Mdot
.016 w
.1461 .54633 m
.14632 .54748 L
s
1 .043 0 r
.008 w
.14632 .54748 Mdot
.016 w
.14632 .54748 m
.14652 .54833 L
s
1 .036 0 r
.008 w
.14652 .54833 Mdot
.016 w
.14652 .54833 m
.1467 .54897 L
s
1 .029 0 r
.008 w
.1467 .54897 Mdot
.016 w
.1467 .54897 m
.14689 .54942 L
s
1 .022 0 r
.008 w
.14689 .54942 Mdot
.016 w
.14689 .54942 m
.14707 .54971 L
s
1 .014 0 r
.008 w
.14707 .54971 Mdot
.016 w
.14707 .54971 m
.14724 .5499 L
s
1 .007 0 r
.008 w
.14724 .5499 Mdot
.016 w
.14724 .5499 m
.14739 .55002 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool0
0`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo
00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoW
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007oo
Ool03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ao
o`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0:Ool;?Nl00go0Oomoo`3YOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Uoo`/mk`9o`003Oj1oogoo0>Qoo`03001oogoo00aoo`003Goo00<007ooOol027oo
2cg_0Wo00gnPjGoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool;?Nl00go0Oj1oP003Oh3XOol0
0`00Oomoo`0<Ool000aoo`03001oogoo00Qoo`dmk`03Oj1oH7lP00=o8>Qoo`03001oogoo00]oo`00
37oo00<007ooOol01goo2cg_17oo00=oH7l0O`000Wl0j7oo00<007ooOol02goo000<Ool00`00Oomo
o`06Ool:?Nl6Ool00gmPO^1n`004OZ3VOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`Tmk`Qo
o`03Of1nh7k000An8003OV1oogoo0>=oo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Goo
00=nh7k0OP000gh000=nH7ooOol0hgoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl9Ool0
0gkPO/1mh003ON000giPOomoo`3SOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`]oo`Am
`003OV1oogoo0>=oo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_37oo1GfPiGoo00<007oo
Ool02goo000<Ool00`00Oomoo`08Ool5?Nl<Ool00gfPOH1mP002OH3UOol00`00Oomoo`0;Ool000ao
o`03001oogoo01Uoo`03OJ1mP7eP00=mH>Aoo`03001oogoo00]oo`0037oo00<007ooOol06Goo00=m
X7f0OF000gePi7oo00<007ooOol02goo000<Ool00`00Oomoo`0JOol00gf0OD1lP003O8000gc0Oomo
o`3POol00`00Oomoo`0;Ool000aoo`03001oogoo01Yoo`03OH1m@7b000=lP003O<1oogoo0>1oo`03
001oogoo00]oo`0037oo00<007ooOol06goo00=m@7aPO6000WaP00=l`7ooOol0h7oo00<007ooOol0
2goo000=Ool00`00Oomoo`0JOol00ge0O61lH002O6000gc0Oomoo`3POol00`00Oomoo`0;Ool000eo
o`03001oogoo01]oo`9lH003O41lH7c00>5oo`03001oogoo00aoo`003Goo00<007ooOol06goo00Al
H7a0O41l@>9oo`03001oogoo00aoo`003Goo00<007ooOol06goo1Ga0hGoo00<007ooOol037oo000=
Ool00`00Oomoo`0KOol00ga0O21l8002O2000ga0Oomoo`3NOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01]oo`03O61l07`0009l0>5oo`03001oogoo00aoo`003Goo00<007ooOol077oo17`0hGoo00<0
07ooOol037oo000=Ool00`00Oomoo`0LOol4O03QOol00`00Oomoo`0<Ool000eoo`03001oogoo01ao
o`Al0>5oo`03001oogoo00aoo`003Goo00<007ooOol077oo17`0hGoo00<007ooOol037oo000=Ool0
0`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`00
3Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000io
o`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool0
0`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomo
o`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yo
o`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<0
07ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001o
ogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol0
4goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=o
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00
Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007oo
Ool0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo
025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0S
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo
000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uo
o`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<0
07ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001o
ogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomo
o`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0
^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=o
o`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000h
Ool00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo
00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03
001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045o
o`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol0
0`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018
Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomo
o`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00
DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3
001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00
Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol0
06aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025o
o`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol008Yoo`@000Aoo`<008]oo`00RWoo00<007ooOol01Woo00<007ooOol0RWoo002;
Ool00`00Oomoo`02Ool5002;Ool008aoo`05001oogooOol00002Ool00`00Oomoo`2:Ool008Yoo`04
001oogoo0003Ool00`00Ool0002<Ool008]oo`8000Eoo`8008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(25)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
1 .992 0 r
.008 w
.14734 .54959 Mdot
.016 w
.14734 .54959 m
.14739 .54968 L
s
1 .984 0 r
.008 w
.14739 .54968 Mdot
.016 w
.14739 .54968 m
.14751 .54986 L
s
1 .976 0 r
.008 w
.14751 .54986 Mdot
.016 w
.14751 .54986 m
.1477 .55014 L
s
1 .967 0 r
.008 w
.1477 .55014 Mdot
.016 w
.1477 .55014 m
.148 .55052 L
s
1 .959 0 r
.008 w
.148 .55052 Mdot
.016 w
.148 .55052 m
.14841 .551 L
s
1 .951 0 r
.008 w
.14841 .551 Mdot
.016 w
.14841 .551 m
.14893 .55155 L
s
1 .943 0 r
.008 w
.14893 .55155 Mdot
.016 w
.14893 .55155 m
.14955 .55217 L
s
1 .935 0 r
.008 w
.14955 .55217 Mdot
.016 w
.14955 .55217 m
.15027 .55283 L
s
1 .927 0 r
.008 w
.15027 .55283 Mdot
.016 w
.15027 .55283 m
.15108 .55359 L
s
1 .919 0 r
.008 w
.15108 .55359 Mdot
.016 w
.15108 .55359 m
.15192 .55442 L
s
1 .911 0 r
.008 w
.15192 .55442 Mdot
.016 w
.15192 .55442 m
.15282 .55527 L
s
1 .902 0 r
.008 w
.15282 .55527 Mdot
.016 w
.15282 .55527 m
.15376 .55611 L
s
1 .894 0 r
.008 w
.15376 .55611 Mdot
.016 w
.15376 .55611 m
.15469 .5569 L
s
1 .886 0 r
.008 w
.15469 .5569 Mdot
.016 w
.15469 .5569 m
.15554 .55763 L
s
1 .878 0 r
.008 w
.15554 .55763 Mdot
.016 w
.15554 .55763 m
.15636 .55835 L
s
1 .87 0 r
.008 w
.15636 .55835 Mdot
.016 w
.15636 .55835 m
.15712 .55904 L
s
1 .862 0 r
.008 w
.15712 .55904 Mdot
.016 w
.15712 .55904 m
.1578 .55971 L
s
1 .854 0 r
.008 w
.1578 .55971 Mdot
.016 w
.1578 .55971 m
.15838 .56038 L
s
1 .846 0 r
.008 w
.15838 .56038 Mdot
.016 w
.15838 .56038 m
.15885 .56106 L
s
1 .837 0 r
.008 w
.15885 .56106 Mdot
.016 w
.15885 .56106 m
.15922 .56179 L
s
1 .829 0 r
.008 w
.15922 .56179 Mdot
.016 w
.15922 .56179 m
.1595 .56255 L
s
1 .821 0 r
.008 w
.1595 .56255 Mdot
.016 w
.1595 .56255 m
.15969 .5633 L
s
1 .813 0 r
.008 w
.15969 .5633 Mdot
.016 w
.15969 .5633 m
.1598 .56396 L
s
1 .805 0 r
.008 w
.1598 .56396 Mdot
.016 w
.1598 .56396 m
.15984 .56449 L
s
1 .797 0 r
.008 w
.15984 .56449 Mdot
.016 w
.15984 .56449 m
.1598 .56494 L
s
1 .789 0 r
.008 w
.1598 .56494 Mdot
.016 w
.1598 .56494 m
.15969 .56527 L
s
1 .78 0 r
.008 w
.15969 .56527 Mdot
.016 w
.15969 .56527 m
.15949 .56546 L
s
1 .772 0 r
.008 w
.15949 .56546 Mdot
.016 w
.15949 .56546 m
.15921 .56548 L
s
1 .764 0 r
.008 w
.15921 .56548 Mdot
.016 w
.15921 .56548 m
.15888 .56534 L
s
1 .756 0 r
.008 w
.15888 .56534 Mdot
.016 w
.15888 .56534 m
.15851 .56505 L
s
1 .748 0 r
.008 w
.15851 .56505 Mdot
.016 w
.15851 .56505 m
.15817 .56465 L
s
1 .74 0 r
.008 w
.15817 .56465 Mdot
.016 w
.15817 .56465 m
.15787 .56418 L
s
1 .732 0 r
.008 w
.15787 .56418 Mdot
.016 w
.15787 .56418 m
.15762 .56367 L
s
1 .724 0 r
.008 w
.15762 .56367 Mdot
.016 w
.15762 .56367 m
.15747 .56312 L
s
1 .715 0 r
.008 w
.15747 .56312 Mdot
.016 w
.15747 .56312 m
.15747 .56258 L
s
1 .707 0 r
.008 w
.15747 .56258 Mdot
.016 w
.15747 .56258 m
.15767 .56211 L
s
1 .699 0 r
.008 w
.15767 .56211 Mdot
.016 w
.15767 .56211 m
.15809 .56175 L
s
1 .691 0 r
.008 w
.15809 .56175 Mdot
.016 w
.15809 .56175 m
.15876 .56149 L
s
1 .683 0 r
.008 w
.15876 .56149 Mdot
.016 w
.15876 .56149 m
.15962 .56133 L
s
1 .675 0 r
.008 w
.15962 .56133 Mdot
.016 w
.15962 .56133 m
.16074 .56124 L
s
1 .667 0 r
.008 w
.16074 .56124 Mdot
.016 w
.16074 .56124 m
.16203 .56121 L
s
1 .659 0 r
.008 w
.16203 .56121 Mdot
.016 w
.16203 .56121 m
.16355 .56121 L
s
1 .65 0 r
.008 w
.16355 .56121 Mdot
.016 w
.16355 .56121 m
.16511 .56122 L
s
1 .642 0 r
.008 w
.16511 .56122 Mdot
.016 w
.16511 .56122 m
.16675 .56122 L
s
1 .634 0 r
.008 w
.16675 .56122 Mdot
.016 w
.16675 .56122 m
.16815 .56119 L
s
1 .626 0 r
.008 w
.16815 .56119 Mdot
.016 w
.16815 .56119 m
.1695 .56115 L
s
1 .618 0 r
.008 w
.1695 .56115 Mdot
.016 w
.1695 .56115 m
.17054 .56111 L
s
1 .61 0 r
.008 w
.17054 .56111 Mdot
.016 w
.17054 .56111 m
.17134 .5611 L
s
1 .602 0 r
.008 w
.17134 .5611 Mdot
.016 w
.17134 .5611 m
.17182 .56111 L
s
1 .593 0 r
.008 w
.17182 .56111 Mdot
.016 w
.17182 .56111 m
.17193 .56115 L
s
1 .585 0 r
.008 w
.17193 .56115 Mdot
.016 w
.17193 .56115 m
.17169 .5612 L
s
1 .577 0 r
.008 w
.17169 .5612 Mdot
.016 w
.17169 .5612 m
.17118 .56125 L
s
1 .569 0 r
.008 w
.17118 .56125 Mdot
.016 w
.17118 .56125 m
.17044 .56128 L
s
1 .561 0 r
.008 w
.17044 .56128 Mdot
.016 w
.17044 .56128 m
.16952 .56132 L
s
1 .553 0 r
.008 w
.16952 .56132 Mdot
.016 w
.16952 .56132 m
.1686 .56137 L
s
1 .545 0 r
.008 w
.1686 .56137 Mdot
.016 w
.1686 .56137 m
.16761 .56143 L
s
1 .537 0 r
.008 w
.16761 .56143 Mdot
.016 w
.16761 .56143 m
.16655 .56147 L
s
1 .528 0 r
.008 w
.16655 .56147 Mdot
.016 w
.16655 .56147 m
.16553 .56146 L
s
1 .52 0 r
.008 w
.16553 .56146 Mdot
.016 w
.16553 .56146 m
.16466 .56135 L
s
1 .512 0 r
.008 w
.16466 .56135 Mdot
.016 w
.16466 .56135 m
.16396 .56109 L
s
1 .504 0 r
.008 w
.16396 .56109 Mdot
.016 w
.16396 .56109 m
.16343 .56062 L
s
1 .496 0 r
.008 w
.16343 .56062 Mdot
.016 w
.16343 .56062 m
.16301 .55994 L
s
1 .488 0 r
.008 w
.16301 .55994 Mdot
.016 w
.16301 .55994 m
.16267 .55901 L
s
1 .48 0 r
.008 w
.16267 .55901 Mdot
.016 w
.16267 .55901 m
.16236 .55779 L
s
1 .472 0 r
.008 w
.16236 .55779 Mdot
.016 w
.16236 .55779 m
.16205 .55624 L
s
1 .463 0 r
.008 w
.16205 .55624 Mdot
.016 w
.16205 .55624 m
.16168 .55436 L
s
1 .455 0 r
.008 w
.16168 .55436 Mdot
.016 w
.16168 .55436 m
.16119 .5525 L
s
1 .447 0 r
.008 w
.16119 .5525 Mdot
.016 w
.16119 .5525 m
.16058 .55028 L
s
1 .439 0 r
.008 w
.16058 .55028 Mdot
.016 w
.16058 .55028 m
.15984 .54769 L
s
1 .431 0 r
.008 w
.15984 .54769 Mdot
.016 w
.15984 .54769 m
.15897 .54518 L
s
1 .423 0 r
.008 w
.15897 .54518 Mdot
.016 w
.15897 .54518 m
.15809 .54247 L
s
1 .415 0 r
.008 w
.15809 .54247 Mdot
.016 w
.15809 .54247 m
.15707 .53958 L
s
1 .407 0 r
.008 w
.15707 .53958 Mdot
.016 w
.15707 .53958 m
.15598 .53682 L
s
1 .398 0 r
.008 w
.15598 .53682 Mdot
.016 w
.15598 .53682 m
.1549 .53423 L
s
1 .39 0 r
.008 w
.1549 .53423 Mdot
.016 w
.1549 .53423 m
.1538 .53177 L
s
1 .382 0 r
.008 w
.1538 .53177 Mdot
.016 w
.1538 .53177 m
.15273 .52937 L
s
1 .374 0 r
.008 w
.15273 .52937 Mdot
.016 w
.15273 .52937 m
.15179 .52756 L
s
1 .366 0 r
.008 w
.15179 .52756 Mdot
.016 w
.15179 .52756 m
.15098 .52588 L
s
1 .358 0 r
.008 w
.15098 .52588 Mdot
.016 w
.15098 .52588 m
.1503 .52448 L
s
1 .35 0 r
.008 w
.1503 .52448 Mdot
.016 w
.1503 .52448 m
.14978 .52347 L
s
1 .341 0 r
.008 w
.14978 .52347 Mdot
.016 w
.14978 .52347 m
.14942 .52264 L
s
1 .333 0 r
.008 w
.14942 .52264 Mdot
.016 w
.14942 .52264 m
.14918 .52202 L
s
1 .325 0 r
.008 w
.14918 .52202 Mdot
.016 w
.14918 .52202 m
.14898 .5216 L
s
1 .317 0 r
.008 w
.14898 .5216 Mdot
.016 w
.14898 .5216 m
.14877 .52132 L
s
1 .309 0 r
.008 w
.14877 .52132 Mdot
.016 w
.14877 .52132 m
.1485 .52115 L
s
1 .301 0 r
.008 w
.1485 .52115 Mdot
.016 w
.1485 .52115 m
.1481 .52106 L
s
1 .293 0 r
.008 w
.1481 .52106 Mdot
.016 w
.1481 .52106 m
.14751 .521 L
s
1 .285 0 r
.008 w
.14751 .521 Mdot
.016 w
.14751 .521 m
.1467 .52095 L
s
1 .276 0 r
.008 w
.1467 .52095 Mdot
.016 w
.1467 .52095 m
.14565 .52087 L
s
1 .268 0 r
.008 w
.14565 .52087 Mdot
.016 w
.14565 .52087 m
.14448 .52073 L
s
1 .26 0 r
.008 w
.14448 .52073 Mdot
.016 w
.14448 .52073 m
.14307 .52052 L
s
1 .252 0 r
.008 w
.14307 .52052 Mdot
.016 w
.14307 .52052 m
.14144 .52022 L
s
1 .244 0 r
.008 w
.14144 .52022 Mdot
.016 w
.14144 .52022 m
.13966 .51987 L
s
1 .236 0 r
.008 w
.13966 .51987 Mdot
.016 w
.13966 .51987 m
.13802 .51949 L
s
1 .228 0 r
.008 w
.13802 .51949 Mdot
.016 w
.13802 .51949 m
.13636 .5191 L
s
1 .22 0 r
.008 w
.13636 .5191 Mdot
.016 w
.13636 .5191 m
.13475 .51874 L
s
1 .211 0 r
.008 w
.13475 .51874 Mdot
.016 w
.13475 .51874 m
.13329 .51844 L
s
1 .203 0 r
.008 w
.13329 .51844 Mdot
.016 w
.13329 .51844 m
.13207 .51816 L
s
1 .195 0 r
.008 w
.13207 .51816 Mdot
.016 w
.13207 .51816 m
.13112 .51793 L
s
1 .187 0 r
.008 w
.13112 .51793 Mdot
.016 w
.13112 .51793 m
.13039 .51769 L
s
1 .179 0 r
.008 w
.13039 .51769 Mdot
.016 w
.13039 .51769 m
.12989 .51739 L
s
1 .171 0 r
.008 w
.12989 .51739 Mdot
.016 w
.12989 .51739 m
.1296 .51696 L
s
1 .163 0 r
.008 w
.1296 .51696 Mdot
.016 w
.1296 .51696 m
.1295 .51647 L
s
1 .154 0 r
.008 w
.1295 .51647 Mdot
.016 w
.1295 .51647 m
.12958 .516 L
s
1 .146 0 r
.008 w
.12958 .516 Mdot
.016 w
.12958 .516 m
.12976 .51539 L
s
1 .138 0 r
.008 w
.12976 .51539 Mdot
.016 w
.12976 .51539 m
.13003 .51468 L
s
1 .13 0 r
.008 w
.13003 .51468 Mdot
.016 w
.13003 .51468 m
.13035 .51384 L
s
1 .122 0 r
.008 w
.13035 .51384 Mdot
.016 w
.13035 .51384 m
.13066 .51281 L
s
1 .114 0 r
.008 w
.13066 .51281 Mdot
.016 w
.13066 .51281 m
.13094 .51168 L
s
1 .106 0 r
.008 w
.13094 .51168 Mdot
.016 w
.13094 .51168 m
.1311 .51036 L
s
1 .098 0 r
.008 w
.1311 .51036 Mdot
.016 w
.1311 .51036 m
.1311 .50879 L
s
1 .089 0 r
.008 w
.1311 .50879 Mdot
.016 w
.1311 .50879 m
.13094 .50702 L
s
1 .081 0 r
.008 w
.13094 .50702 Mdot
.016 w
.13094 .50702 m
.13068 .50518 L
s
1 .073 0 r
.008 w
.13068 .50518 Mdot
.016 w
.13068 .50518 m
.13034 .50339 L
s
1 .065 0 r
.008 w
.13034 .50339 Mdot
.016 w
.13034 .50339 m
.12996 .50148 L
s
1 .057 0 r
.008 w
.12996 .50148 Mdot
.016 w
.12996 .50148 m
.12956 .49993 L
s
1 .049 0 r
.008 w
.12956 .49993 Mdot
.016 w
.12956 .49993 m
.12916 .49844 L
s
1 .041 0 r
.008 w
.12916 .49844 Mdot
.016 w
.12916 .49844 m
.12879 .49729 L
s
1 .033 0 r
.008 w
.12879 .49729 Mdot
.016 w
.12879 .49729 m
.12848 .49634 L
s
1 .024 0 r
.008 w
.12848 .49634 Mdot
.016 w
.12848 .49634 m
.12822 .49559 L
s
1 .016 0 r
.008 w
.12822 .49559 Mdot
.016 w
.12822 .49559 m
.12804 .49517 L
s
1 .008 0 r
.008 w
.12804 .49517 Mdot
.016 w
.12804 .49517 m
.12793 .49492 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool0
0`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo
00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoW
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007oo
Ool03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ao
o`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0:Ool<?No[Ool00`00Oomoo`0<Ool000eoo`03001oogoo
00Uoo`hmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<007ooOol037oo000=
Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<mknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<Ool00`00Oomo
o`06Ool:?Nl6Ool7?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`Tmk`Qoo`LmknIoo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Goo00<mkg`0O0000W`000<mkgooOol0i7oo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl9Ool00cg_O01l0002O0000cg_Oomoo`3TOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`Al0003?Nmoogoo0>Aoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_2goo17`000=l@3g_Ool0i7oo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool5?Nl;Ool4O002O43UOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Al8003O40mkcg_
0>Aoo`03001oogoo00]oo`0037oo00<007ooOol067oo00=lP7a0O4000Wa000<mkgd0Ool0hgoo00<0
07ooOol02goo000<Ool00`00Oomoo`0HOol00gb0O41l@002O40017c0O>1lh3g_hWoo00<007ooOol0
2goo000<Ool00`00Oomoo`0HOol00gb0O61lH002O6001Gc0O>1lh7d0OB00hGoo00<007ooOol02goo
000<Ool00`00Oomoo`0HOol00gb0O61lH002O6000gc0O>1lh002O@3QOol00`00Oomoo`0;Ool000eo
o`03001oogoo01Moo`ElX006O<1lh7cPO@1m87ePh7oo00<007ooOol02goo000=Ool00`00Oomoo`0K
Ool013g_OB1m07d00WdP0WePgWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol2?Nl5OF000gf0
Oomoo`3LOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`<mk`03OH1mH7eP00=mP=eoo`03001o
ogoo00aoo`003Goo00<007ooOol06goo0cg_1Gf0gWoo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool3On000gfPOH1mP002OJ3MOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`03Ol1oX7nP00Im
X=aoo`03001oogoo00aoo`003Goo00<007ooOol077oo00=o`7nPOh001GfPgGoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol01Go0Oj1oP7mPOL000WfP00=m`7gPOol0fgoo00<007ooOol037oo000=
Ool00`00Oomoo`0LOol017o0Oj1oP7jP17g000=mh7hPOR00fWoo00<007ooOol037oo000=Ool00`00
Oomoo`0MOol00gnPOh1nX004OL000ggPOR1n803JOol00`00Oomoo`0<Ool000eoo`03001oogoo01io
o`03Oh1nX7gP00Amh09n8=Yoo`03001oogoo00aoo`003Woo00<007ooOol07Woo0WjP17h00WhPfGoo
00<007ooOol03Goo000>Ool00`00Oomoo`0NOol4O^000gl0Oomoo`3JOol00`00Oomoo`0=Ool000io
o`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool0
0`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomo
o`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yo
o`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<0
07ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001o
ogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol0
4goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=o
o`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00
Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007oo
Ool0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo
025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0S
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo
000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uo
o`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<0
07ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001o
ogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomo
o`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0
^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=o
o`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000h
Ool00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo
00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03
001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045o
o`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol0
0`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018
Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomo
o`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00
DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3
001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00
Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol0
06aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025o
o`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol008Yoo`@000=oo`8008eoo`00RWoo00<007ooOol00goo00@007ooOol008aoo`00
Rgoo00<007ooOol01Goo00<007ooOol0RWoo002<Ool00`00Oomoo`02Ool2002=Ool008Yoo`04001o
ogoo0003Ool00`00Oomoo`2<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(26)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
1 .985 0 r
.008 w
.12986 .49201 Mdot
.016 w
.12986 .49201 m
.1296 .49208 L
s
1 .97 0 r
.008 w
.1296 .49208 Mdot
.016 w
.1296 .49208 m
.12902 .49209 L
s
1 .955 0 r
.008 w
.12902 .49209 Mdot
.016 w
.12902 .49209 m
.12805 .492 L
s
1 .94 0 r
.008 w
.12805 .492 Mdot
.016 w
.12805 .492 m
.12672 .49178 L
s
1 .925 0 r
.008 w
.12672 .49178 Mdot
.016 w
.12672 .49178 m
.12504 .49143 L
s
1 .91 0 r
.008 w
.12504 .49143 Mdot
.016 w
.12504 .49143 m
.12299 .49099 L
s
1 .896 0 r
.008 w
.12299 .49099 Mdot
.016 w
.12299 .49099 m
.12101 .49047 L
s
1 .881 0 r
.008 w
.12101 .49047 Mdot
.016 w
.12101 .49047 m
.11853 .48989 L
s
1 .866 0 r
.008 w
.11853 .48989 Mdot
.016 w
.11853 .48989 m
.1159 .48931 L
s
1 .851 0 r
.008 w
.1159 .48931 Mdot
.016 w
.1159 .48931 m
.11321 .48872 L
s
1 .836 0 r
.008 w
.11321 .48872 Mdot
.016 w
.11321 .48872 m
.11041 .48815 L
s
1 .821 0 r
.008 w
.11041 .48815 Mdot
.016 w
.11041 .48815 m
.1077 .48761 L
s
1 .806 0 r
.008 w
.1077 .48761 Mdot
.016 w
.1077 .48761 m
.10474 .48712 L
s
1 .791 0 r
.008 w
.10474 .48712 Mdot
.016 w
.10474 .48712 m
.10239 .48667 L
s
1 .776 0 r
.008 w
.10239 .48667 Mdot
.016 w
.10239 .48667 m
.10015 .48627 L
s
1 .761 0 r
.008 w
.10015 .48627 Mdot
.016 w
.10015 .48627 m
.09785 .4859 L
s
1 .746 0 r
.008 w
.09785 .4859 Mdot
.016 w
.09785 .4859 m
.09582 .48555 L
s
1 .731 0 r
.008 w
.09582 .48555 Mdot
.016 w
.09582 .48555 m
.09386 .4852 L
s
1 .716 0 r
.008 w
.09386 .4852 Mdot
.016 w
.09386 .4852 m
.09199 .48486 L
s
1 .701 0 r
.008 w
.09199 .48486 Mdot
.016 w
.09199 .48486 m
.09027 .4845 L
s
1 .687 0 r
.008 w
.09027 .4845 Mdot
.016 w
.09027 .4845 m
.08881 .48416 L
s
1 .672 0 r
.008 w
.08881 .48416 Mdot
.016 w
.08881 .48416 m
.0878 .48381 L
s
1 .657 0 r
.008 w
.0878 .48381 Mdot
.016 w
.0878 .48381 m
.08656 .48346 L
s
1 .642 0 r
.008 w
.08656 .48346 Mdot
.016 w
.08656 .48346 m
.08561 .48309 L
s
1 .627 0 r
.008 w
.08561 .48309 Mdot
.016 w
.08561 .48309 m
.08467 .48267 L
s
1 .612 0 r
.008 w
.08467 .48267 Mdot
.016 w
.08467 .48267 m
.08374 .4822 L
s
1 .597 0 r
.008 w
.08374 .4822 Mdot
.016 w
.08374 .4822 m
.08287 .48169 L
s
1 .582 0 r
.008 w
.08287 .48169 Mdot
.016 w
.08287 .48169 m
.08207 .48119 L
s
1 .567 0 r
.008 w
.08207 .48119 Mdot
.016 w
.08207 .48119 m
.08133 .48068 L
s
1 .552 0 r
.008 w
.08133 .48068 Mdot
.016 w
.08133 .48068 m
.08064 .48015 L
s
1 .537 0 r
.008 w
.08064 .48015 Mdot
.016 w
.08064 .48015 m
.08002 .47956 L
s
1 .522 0 r
.008 w
.08002 .47956 Mdot
.016 w
.08002 .47956 m
.07945 .47893 L
s
1 .507 0 r
.008 w
.07945 .47893 Mdot
.016 w
.07945 .47893 m
.07891 .47827 L
s
1 .493 0 r
.008 w
.07891 .47827 Mdot
.016 w
.07891 .47827 m
.07826 .47753 L
s
1 .478 0 r
.008 w
.07826 .47753 Mdot
.016 w
.07826 .47753 m
.07757 .47668 L
s
1 .463 0 r
.008 w
.07757 .47668 Mdot
.016 w
.07757 .47668 m
.07687 .4757 L
s
1 .448 0 r
.008 w
.07687 .4757 Mdot
.016 w
.07687 .4757 m
.0762 .47471 L
s
1 .433 0 r
.008 w
.0762 .47471 Mdot
.016 w
.0762 .47471 m
.07561 .47373 L
s
1 .418 0 r
.008 w
.07561 .47373 Mdot
.016 w
.07561 .47373 m
.07513 .4728 L
s
1 .403 0 r
.008 w
.07513 .4728 Mdot
.016 w
.07513 .4728 m
.07478 .47197 L
s
1 .388 0 r
.008 w
.07478 .47197 Mdot
.016 w
.07478 .47197 m
.07458 .47129 L
s
1 .373 0 r
.008 w
.07458 .47129 Mdot
.016 w
.07458 .47129 m
.07452 .47071 L
s
1 .358 0 r
.008 w
.07452 .47071 Mdot
.016 w
.07452 .47071 m
.07459 .47026 L
s
1 .343 0 r
.008 w
.07459 .47026 Mdot
.016 w
.07459 .47026 m
.07477 .46994 L
s
1 .328 0 r
.008 w
.07477 .46994 Mdot
.016 w
.07477 .46994 m
.07502 .46972 L
s
1 .313 0 r
.008 w
.07502 .46972 Mdot
.016 w
.07502 .46972 m
.0753 .46959 L
s
1 .299 0 r
.008 w
.0753 .46959 Mdot
.016 w
.0753 .46959 m
.07561 .46949 L
s
1 .284 0 r
.008 w
.07561 .46949 Mdot
.016 w
.07561 .46949 m
.07592 .46939 L
s
1 .269 0 r
.008 w
.07592 .46939 Mdot
.016 w
.07592 .46939 m
.0762 .46926 L
s
1 .254 0 r
.008 w
.0762 .46926 Mdot
.016 w
.0762 .46926 m
.07645 .46906 L
s
1 .239 0 r
.008 w
.07645 .46906 Mdot
.016 w
.07645 .46906 m
.07669 .46879 L
s
1 .224 0 r
.008 w
.07669 .46879 Mdot
.016 w
.07669 .46879 m
.07693 .46843 L
s
1 .209 0 r
.008 w
.07693 .46843 Mdot
.016 w
.07693 .46843 m
.07717 .46799 L
s
1 .194 0 r
.008 w
.07717 .46799 Mdot
.016 w
.07717 .46799 m
.07741 .46751 L
s
1 .179 0 r
.008 w
.07741 .46751 Mdot
.016 w
.07741 .46751 m
.07765 .46703 L
s
1 .164 0 r
.008 w
.07765 .46703 Mdot
.016 w
.07765 .46703 m
.07789 .46657 L
s
1 .149 0 r
.008 w
.07789 .46657 Mdot
.016 w
.07789 .46657 m
.07813 .46611 L
s
1 .134 0 r
.008 w
.07813 .46611 Mdot
.016 w
.07813 .46611 m
.07836 .46567 L
s
1 .119 0 r
.008 w
.07836 .46567 Mdot
.016 w
.07836 .46567 m
.07859 .46528 L
s
1 .104 0 r
.008 w
.07859 .46528 Mdot
.016 w
.07859 .46528 m
.07883 .46497 L
s
1 .09 0 r
.008 w
.07883 .46497 Mdot
.016 w
.07883 .46497 m
.07907 .46475 L
s
1 .075 0 r
.008 w
.07907 .46475 Mdot
.016 w
.07907 .46475 m
.07933 .46463 L
s
1 .06 0 r
.008 w
.07933 .46463 Mdot
.016 w
.07933 .46463 m
.0796 .46459 L
s
1 .045 0 r
.008 w
.0796 .46459 Mdot
.016 w
.0796 .46459 m
.07984 .46461 L
s
1 .03 0 r
.008 w
.07984 .46461 Mdot
.016 w
.07984 .46461 m
.08005 .46467 L
s
1 .015 0 r
.008 w
.08005 .46467 Mdot
.016 w
.08005 .46467 m
.08021 .46474 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool0
0`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo
00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoW
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007oo
Ool03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ao
o`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`09Ool2O402O0000ga0?Nlmk`06?No[Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00Qoo`03OB1l@7`000=l00TmknYoo`03001oogoo00aoo`003Goo00<007oo
Ool027oo00=m87a0O0000g`02Sg_jGoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool00gdPO41l
@002O0000ga0?Nlmk`09?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qoo`03?Nmm87b000=l
P003OP1nX3g_00XmknQoo`03001oogoo00]oo`0037oo00<007ooOol01goo0Sg_17e000EmX7h0OV1n
X3g_009oo`03Od1oocg_00@mknQoo`03001oogoo00]oo`0037oo00<007ooOol01Woo0cg_1GfP00An
07iPOZ1nX09nh003O`1o83g_008mk`04Oj0mkcg_?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Eoo`Dmk`Amh003OP1nH7jP009nX003O^1o07lP009o@003Of1oP7nP008mknIoo`03001oogoo00]o
o`0037oo00<007ooOol027oo0cg_17i000=nH7jPOZ000WkP00Io07lPOd1o@7mPOh02Oj000cg_Oomo
o`3TOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03O^1nX7jP00=nh006O`1o87m0Od1o
H7n00gnPiWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl5Ool5Od001GmPOh1oX7nP?Nl0
iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;Ool00cg_Oj1oX003?NoUOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol0
6Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol7?NoTOol00`00Oomoo`0;Ool000ao
o`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_hGoo00<007oo
Ool02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eoo`03001oogoo01Moo`/m
kn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_ggoo00<007ooOol037oo000=Ool00`00
Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00ao
o`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol0
77oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol9?NoLOol00`00Oomoo`0<Ool000eo
o`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Goo2Sg_fWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo01ioo`Pm
kmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007ooOol03Goo000>Ool00`00
Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007oo
Ool0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo
0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3m
Ool00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo
00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03
001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00
Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007oo
Ool047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo
015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0A
Ool001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo
000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`00
57oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eo
o`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol0
0`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<0
07ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001o
ogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomo
o`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0
jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Mo
o`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol0
0`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<0
07ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001o
ogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomo
o`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol0
7Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01mo
o`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol0
02=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000T
Ool00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo
00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03
001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00
Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007oo
Ool0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo
0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2o
Ool00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo
00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03
001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eo
o`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol0
0`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<0
07ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001o
ogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomo
o`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002I
Ool20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007oo
Ool0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00
Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo
00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00
DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo
0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0
H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4
000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001i
Ool007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo002:Ool40002Ool3002=Ool008Yoo`03001oogoo00=oo`04001oogoo002<Ool008]oo`03
001oogoo009oo`04001oogoo002<Ool008aoo`04001oogooOol3002=Ool008Yoo`04001oogoo0003
Ool00`00Oomoo`2<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(27)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
1 .984 0 r
.008 w
.09681 .43477 Mdot
.016 w
.09681 .43477 m
.09681 .43455 L
s
1 .967 0 r
.008 w
.09681 .43455 Mdot
.016 w
.09681 .43455 m
.09682 .43418 L
s
1 .951 0 r
.008 w
.09682 .43418 Mdot
.016 w
.09682 .43418 m
.09683 .43366 L
s
1 .934 0 r
.008 w
.09683 .43366 Mdot
.016 w
.09683 .43366 m
.09684 .43299 L
s
1 .918 0 r
.008 w
.09684 .43299 Mdot
.016 w
.09684 .43299 m
.09686 .43219 L
s
1 .902 0 r
.008 w
.09686 .43219 Mdot
.016 w
.09686 .43219 m
.09688 .4313 L
s
1 .885 0 r
.008 w
.09688 .4313 Mdot
.016 w
.09688 .4313 m
.0969 .4305 L
s
1 .869 0 r
.008 w
.0969 .4305 Mdot
.016 w
.0969 .4305 m
.09692 .4296 L
s
1 .852 0 r
.008 w
.09692 .4296 Mdot
.016 w
.09692 .4296 m
.09694 .42862 L
s
1 .836 0 r
.008 w
.09694 .42862 Mdot
.016 w
.09694 .42862 m
.09696 .42778 L
s
1 .82 0 r
.008 w
.09696 .42778 Mdot
.016 w
.09696 .42778 m
.09698 .427 L
s
1 .803 0 r
.008 w
.09698 .427 Mdot
.016 w
.09698 .427 m
.09699 .42631 L
s
1 .787 0 r
.008 w
.09699 .42631 Mdot
.016 w
.09699 .42631 m
.097 .42576 L
s
1 .77 0 r
.008 w
.097 .42576 Mdot
.016 w
.097 .42576 m
.09701 .42539 L
s
1 .754 0 r
.008 w
.09701 .42539 Mdot
.016 w
.09701 .42539 m
.09701 .42519 L
s
1 .738 0 r
.008 w
.09701 .42519 Mdot
.016 w
.09701 .42519 m
.09701 .42515 L
s
1 .721 0 r
.008 w
.09701 .42515 Mdot
.016 w
.09701 .42515 m
.09701 .42521 L
s
1 .705 0 r
.008 w
.09701 .42521 Mdot
.016 w
.09701 .42521 m
.09701 .42529 L
s
1 .689 0 r
.008 w
.09701 .42529 Mdot
.016 w
.09701 .42529 m
.09701 .42528 L
s
1 .672 0 r
.008 w
.09701 .42528 Mdot
.016 w
.09701 .42528 m
.09701 .42513 L
s
1 .656 0 r
.008 w
.09701 .42513 Mdot
.016 w
.09701 .42513 m
.09702 .42482 L
s
1 .639 0 r
.008 w
.09702 .42482 Mdot
.016 w
.09702 .42482 m
.09704 .42431 L
s
1 .623 0 r
.008 w
.09704 .42431 Mdot
.016 w
.09704 .42431 m
.09708 .42359 L
s
1 .607 0 r
.008 w
.09708 .42359 Mdot
.016 w
.09708 .42359 m
.09714 .42276 L
s
1 .59 0 r
.008 w
.09714 .42276 Mdot
.016 w
.09714 .42276 m
.0972 .42177 L
s
1 .574 0 r
.008 w
.0972 .42177 Mdot
.016 w
.0972 .42177 m
.09724 .42067 L
s
1 .557 0 r
.008 w
.09724 .42067 Mdot
.016 w
.09724 .42067 m
.09725 .4196 L
s
1 .541 0 r
.008 w
.09725 .4196 Mdot
.016 w
.09725 .4196 m
.09723 .41846 L
s
1 .525 0 r
.008 w
.09723 .41846 Mdot
.016 w
.09723 .41846 m
.09717 .41719 L
s
1 .508 0 r
.008 w
.09717 .41719 Mdot
.016 w
.09717 .41719 m
.09707 .41613 L
s
1 .492 0 r
.008 w
.09707 .41613 Mdot
.016 w
.09707 .41613 m
.09694 .41512 L
s
1 .475 0 r
.008 w
.09694 .41512 Mdot
.016 w
.09694 .41512 m
.09677 .4142 L
s
1 .459 0 r
.008 w
.09677 .4142 Mdot
.016 w
.09677 .4142 m
.09655 .4134 L
s
1 .443 0 r
.008 w
.09655 .4134 Mdot
.016 w
.09655 .4134 m
.09629 .41275 L
s
1 .426 0 r
.008 w
.09629 .41275 Mdot
.016 w
.09629 .41275 m
.096 .41224 L
s
1 .41 0 r
.008 w
.096 .41224 Mdot
.016 w
.096 .41224 m
.0957 .41181 L
s
1 .393 0 r
.008 w
.0957 .41181 Mdot
.016 w
.0957 .41181 m
.09539 .41142 L
s
1 .377 0 r
.008 w
.09539 .41142 Mdot
.016 w
.09539 .41142 m
.09503 .41102 L
s
1 .361 0 r
.008 w
.09503 .41102 Mdot
.016 w
.09503 .41102 m
.09463 .41058 L
s
1 .344 0 r
.008 w
.09463 .41058 Mdot
.016 w
.09463 .41058 m
.09419 .41012 L
s
1 .328 0 r
.008 w
.09419 .41012 Mdot
.016 w
.09419 .41012 m
.09368 .40964 L
s
1 .311 0 r
.008 w
.09368 .40964 Mdot
.016 w
.09368 .40964 m
.0931 .40922 L
s
1 .295 0 r
.008 w
.0931 .40922 Mdot
.016 w
.0931 .40922 m
.09246 .4088 L
s
1 .279 0 r
.008 w
.09246 .4088 Mdot
.016 w
.09246 .4088 m
.09174 .40845 L
s
1 .262 0 r
.008 w
.09174 .40845 Mdot
.016 w
.09174 .40845 m
.09095 .40815 L
s
1 .246 0 r
.008 w
.09095 .40815 Mdot
.016 w
.09095 .40815 m
.09008 .40791 L
s
1 .23 0 r
.008 w
.09008 .40791 Mdot
.016 w
.09008 .40791 m
.08919 .40778 L
s
1 .213 0 r
.008 w
.08919 .40778 Mdot
.016 w
.08919 .40778 m
.0884 .40777 L
s
1 .197 0 r
.008 w
.0884 .40777 Mdot
.016 w
.0884 .40777 m
.08761 .40787 L
s
1 .18 0 r
.008 w
.08761 .40787 Mdot
.016 w
.08761 .40787 m
.08682 .40807 L
s
1 .164 0 r
.008 w
.08682 .40807 Mdot
.016 w
.08682 .40807 m
.08606 .40837 L
s
1 .148 0 r
.008 w
.08606 .40837 Mdot
.016 w
.08606 .40837 m
.08545 .40872 L
s
1 .131 0 r
.008 w
.08545 .40872 Mdot
.016 w
.08545 .40872 m
.08493 .40915 L
s
1 .115 0 r
.008 w
.08493 .40915 Mdot
.016 w
.08493 .40915 m
.08453 .40961 L
s
1 .098 0 r
.008 w
.08453 .40961 Mdot
.016 w
.08453 .40961 m
.08424 .41002 L
s
1 .082 0 r
.008 w
.08424 .41002 Mdot
.016 w
.08424 .41002 m
.08405 .41044 L
s
1 .066 0 r
.008 w
.08405 .41044 Mdot
.016 w
.08405 .41044 m
.08396 .41081 L
s
1 .049 0 r
.008 w
.08396 .41081 Mdot
.016 w
.08396 .41081 m
.08396 .41111 L
s
1 .033 0 r
.008 w
.08396 .41111 Mdot
.016 w
.08396 .41111 m
.08401 .41135 L
s
1 .016 0 r
.008 w
.08401 .41135 Mdot
.016 w
.08401 .41135 m
.08407 .41146 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0
00moo`03001oogoo00Uoo`<mk`03O>0mkcg_0>ioo`03001oogoo00ioo`003goo00<007ooOol02Goo
00<mkgbPO:000WbP0Sg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool00gbPO01l0002O:00
0gcPOD1oo`3/Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al0003O:1lh7cP0>eoo`03001o
ogoo00ioo`003goo00<007ooOol02Goo17`000AlX7cPOD0mknaoo`03001oogoo00ioo`003Woo00<0
07ooOol02Woo00=lX7`0O0000WbP0We000<mkgooOol0jgoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool3?Nl4OH05?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`03?Nmmh7gP009mh003
O/0mkcg_008mknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo17hP00=n`3g_?Nl013g_igoo
00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool4OT08?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00ioo`Ao80TmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo17mP2Cg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool00cg_Oj1oX002Oj09?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6
?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<0
07ooOol067oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;
Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo
00<007ooOol02goo000=Ool00`00Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo
01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=
Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001o
ogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8
?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<0
07ooOol077oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<
Ool000eoo`03001oogoo01ioo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo
00<007ooOol03Goo000>Ool00`00Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo
0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3n
Ool00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo
00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03
001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00
Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007oo
Ool03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo
00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@
Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo
000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`00
4goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Ao
o`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol0
0`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<0
07ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001o
ogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomo
o`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0
kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]o
o`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol0
0`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<0
07ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001o
ogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomo
o`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol0
77oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eo
o`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0
021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000Q
Ool00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo
00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03
001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00
Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007oo
Ool0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo
0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37
Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo
00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00
Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007oo
Ool0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<0
07ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001o
ogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomo
o`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0
>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03ao
o`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80
049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13
Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool2
0019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00
Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2
001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001I
Ool005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0
069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003mo
o`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00
Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool008Yoo`@000Aoo`03001oogoo08]oo`00RWoo00<007ooOol01Goo00<007ooOol0Rgoo002;Ool0
0`00Oomoo`04Ool00`00Oomoo`2;Ool008aoo`03001oogoo00Aoo`03001oogoo08Yoo`00RWoo00@0
07ooOol0009oo`04001oogoo002<Ool008]oo`8000=oo`@008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(28)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
1 .958 0 r
.008 w
.08968 .40207 Mdot
.016 w
.08968 .40207 m
.08952 .40196 L
s
1 .917 0 r
.008 w
.08952 .40196 Mdot
.016 w
.08952 .40196 m
.08923 .40188 L
s
1 .875 0 r
.008 w
.08923 .40188 Mdot
.016 w
.08923 .40188 m
.08882 .4018 L
s
1 .833 0 r
.008 w
.08882 .4018 Mdot
.016 w
.08882 .4018 m
.08832 .4017 L
s
1 .792 0 r
.008 w
.08832 .4017 Mdot
.016 w
.08832 .4017 m
.08779 .40155 L
s
1 .75 0 r
.008 w
.08779 .40155 Mdot
.016 w
.08779 .40155 m
.08728 .40131 L
s
1 .708 0 r
.008 w
.08728 .40131 Mdot
.016 w
.08728 .40131 m
.08681 .40096 L
s
1 .667 0 r
.008 w
.08681 .40096 Mdot
.016 w
.08681 .40096 m
.08637 .40051 L
s
1 .625 0 r
.008 w
.08637 .40051 Mdot
.016 w
.08637 .40051 m
.08591 .39996 L
s
1 .583 0 r
.008 w
.08591 .39996 Mdot
.016 w
.08591 .39996 m
.08543 .39931 L
s
1 .542 0 r
.008 w
.08543 .39931 Mdot
.016 w
.08543 .39931 m
.08496 .39856 L
s
1 .5 0 r
.008 w
.08496 .39856 Mdot
.016 w
.08496 .39856 m
.0846 .39772 L
s
1 .458 0 r
.008 w
.0846 .39772 Mdot
.016 w
.0846 .39772 m
.08438 .39687 L
s
1 .417 0 r
.008 w
.08438 .39687 Mdot
.016 w
.08438 .39687 m
.08428 .39602 L
s
1 .375 0 r
.008 w
.08428 .39602 Mdot
.016 w
.08428 .39602 m
.08425 .39515 L
s
1 .333 0 r
.008 w
.08425 .39515 Mdot
.016 w
.08425 .39515 m
.08428 .39429 L
s
1 .292 0 r
.008 w
.08428 .39429 Mdot
.016 w
.08428 .39429 m
.08436 .39347 L
s
1 .25 0 r
.008 w
.08436 .39347 Mdot
.016 w
.08436 .39347 m
.08446 .39274 L
s
1 .208 0 r
.008 w
.08446 .39274 Mdot
.016 w
.08446 .39274 m
.08451 .3921 L
s
1 .167 0 r
.008 w
.08451 .3921 Mdot
.016 w
.08451 .3921 m
.08452 .39152 L
s
1 .125 0 r
.008 w
.08452 .39152 Mdot
.016 w
.08452 .39152 m
.08453 .39104 L
s
1 .083 0 r
.008 w
.08453 .39104 Mdot
.016 w
.08453 .39104 m
.08454 .39069 L
s
1 .042 0 r
.008 w
.08454 .39069 Mdot
.016 w
.08454 .39069 m
.08454 .39045 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`05O>1l87cPO>0mk`3^Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Qoo`05O>1l87cPO>0mk`3^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qo
o`05O>1lH7cPO>0mk`3^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Alh003OZ0mkgoo0>eo
o`03001oogoo00ioo`003goo00<007ooOol02Goo17cP0WjP00<mkgooOol0jgoo00<007ooOol03Woo
000?Ool00`00Oomoo`09Ool4OL000gjP?Nlmk`3]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uo
o`8mk`9nX0<mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo
000>Ool00`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03
001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=
Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo
00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomo
o`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_
iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo
1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<007ooOol0
37oo000=Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<mknQo
o`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<Ool0
0`00Oomoo`06OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03001oogoo
00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl0
0goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001oogoo
00]oo`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9?NoR
Ool00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007oo
Ool067oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;Ool0
00eoo`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]o
o`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo
00aoo`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJ
Ool00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<007oo
Ool07Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=Ool0
00ioo`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eo
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@
Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007oo
Ool0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo
00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007oo
Ool057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo
01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo
000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`00
6Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]o
o`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol0
0`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<0
07ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001o
ogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uo
o`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol0
0`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<0
07ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001o
ogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomo
o`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0
:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uo
o`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool0
02eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^
Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo
00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`80
0;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00
Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007oo
Ool0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo
03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001o
ogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2
000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00
Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007oo
Ool0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00
Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo
00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00
E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo
0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00
Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3
000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020
Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo10000goo
0P00SGoo002:Ool00`00Oomoo`03Ool01000Oomoo`00S7oo002;Ool00`00Oomoo`02Ool01000Oomo
o`00S7oo002<Ool00`00Oomoo`02Ool2002=Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo
002;Ool20004Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(29)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
1 .95 0 r
.008 w
.08973 .39509 Mdot
.016 w
.08973 .39509 m
.08962 .39525 L
s
1 .9 0 r
.008 w
.08962 .39525 Mdot
.016 w
.08962 .39525 m
.08947 .39547 L
s
1 .85 0 r
.008 w
.08947 .39547 Mdot
.016 w
.08947 .39547 m
.08926 .39578 L
s
1 .8 0 r
.008 w
.08926 .39578 Mdot
.016 w
.08926 .39578 m
.08901 .39619 L
s
1 .75 0 r
.008 w
.08901 .39619 Mdot
.016 w
.08901 .39619 m
.0887 .39673 L
s
1 .7 0 r
.008 w
.0887 .39673 Mdot
.016 w
.0887 .39673 m
.08833 .39745 L
s
1 .65 0 r
.008 w
.08833 .39745 Mdot
.016 w
.08833 .39745 m
.08796 .39815 L
s
1 .6 0 r
.008 w
.08796 .39815 Mdot
.016 w
.08796 .39815 m
.08755 .39902 L
s
1 .55 0 r
.008 w
.08755 .39902 Mdot
.016 w
.08755 .39902 m
.08711 .39998 L
s
1 .5 0 r
.008 w
.08711 .39998 Mdot
.016 w
.08711 .39998 m
.08664 .40099 L
s
1 .45 0 r
.008 w
.08664 .40099 Mdot
.016 w
.08664 .40099 m
.08617 .40201 L
s
1 .4 0 r
.008 w
.08617 .40201 Mdot
.016 w
.08617 .40201 m
.08575 .40298 L
s
1 .35 0 r
.008 w
.08575 .40298 Mdot
.016 w
.08575 .40298 m
.08539 .40382 L
s
1 .3 0 r
.008 w
.08539 .40382 Mdot
.016 w
.08539 .40382 m
.08508 .40457 L
s
1 .25 0 r
.008 w
.08508 .40457 Mdot
.016 w
.08508 .40457 m
.08481 .40525 L
s
1 .2 0 r
.008 w
.08481 .40525 Mdot
.016 w
.08481 .40525 m
.08459 .40584 L
s
1 .15 0 r
.008 w
.08459 .40584 Mdot
.016 w
.08459 .40584 m
.08441 .40633 L
s
1 .1 0 r
.008 w
.08441 .40633 Mdot
.016 w
.08441 .40633 m
.08427 .4067 L
s
1 .05 0 r
.008 w
.08427 .4067 Mdot
.016 w
.08427 .4067 m
.08419 .40693 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol0
0`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo
01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoW
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007oo
Ool01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0
01=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<0
07ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol0
0`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo
011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007oo
Ool027oo00<mkgk0O/000Wk0kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool00cg_ON1mh002
ON3^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Am8003OL0mkgoo0>eoo`03001oogoo00io
o`003goo00<007ooOol02Goo00Em87b0O>1m87g0008mkneoo`03001oogoo00ioo`003goo00<007oo
Ool02Goo00Em87`PO>1m87g0008mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo00Em87`P
OB1m87g0008mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo17dP13g_k7oo00<007ooOol0
3Woo000>Ool00`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUo
o`03001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`00
3Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00
Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo
3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03
001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_
0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool000eo
o`03001oogoo00Qoo`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<007oo
Ool037oo000=Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<m
knQoo`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<
Ool00`00Oomoo`06OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001o
ogoo00]oo`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9
?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<0
07ooOol067oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;
Ool000eoo`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo
00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo
01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=
Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001o
ogoo00aoo`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;
?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<0
07ooOol07Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=
Ool000ioo`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007oo
Ool03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo
00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo
000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol0
0`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<0
07ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001o
ogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomo
o`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0
m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=o
o`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol0
0`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<0
07ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001o
ogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomo
o`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol0
5goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qo
o`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol0
01]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000L
Ool00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo
00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03
001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00
Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007oo
Ool0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo
0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3E
Ool00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo
00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03
001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00
Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007oo
Ool0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo
02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[
Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo
000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00
<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039o
o`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol0
0`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<0
07ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001o
ogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03
001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002O
Ool2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool0
0`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<0
07ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo
0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00
Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=o
o`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00
Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo
0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`
Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>
0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo1000
0Woo0`00SGoo002:Ool00`00Oomoo`05Ool00`00Oomoo`2;Ool008]oo`03001oogoo00=oo`<008ao
o`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00RWoo00@007ooOol0009oo`04001oogoo
002<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(30)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
1 .976 0 r
.008 w
.08429 .4024 Mdot
.016 w
.08429 .4024 m
.0843 .40228 L
s
1 .951 0 r
.008 w
.0843 .40228 Mdot
.016 w
.0843 .40228 m
.08432 .40205 L
s
1 .927 0 r
.008 w
.08432 .40205 Mdot
.016 w
.08432 .40205 m
.08436 .4017 L
s
1 .902 0 r
.008 w
.08436 .4017 Mdot
.016 w
.08436 .4017 m
.08441 .40118 L
s
1 .878 0 r
.008 w
.08441 .40118 Mdot
.016 w
.08441 .40118 m
.08449 .40048 L
s
1 .854 0 r
.008 w
.08449 .40048 Mdot
.016 w
.08449 .40048 m
.08459 .39957 L
s
1 .829 0 r
.008 w
.08459 .39957 Mdot
.016 w
.08459 .39957 m
.08472 .39841 L
s
1 .805 0 r
.008 w
.08472 .39841 Mdot
.016 w
.08472 .39841 m
.08489 .39699 L
s
1 .78 0 r
.008 w
.08489 .39699 Mdot
.016 w
.08489 .39699 m
.0851 .39537 L
s
1 .756 0 r
.008 w
.0851 .39537 Mdot
.016 w
.0851 .39537 m
.08529 .39337 L
s
1 .732 0 r
.008 w
.08529 .39337 Mdot
.016 w
.08529 .39337 m
.08547 .39123 L
s
1 .707 0 r
.008 w
.08547 .39123 Mdot
.016 w
.08547 .39123 m
.08569 .38875 L
s
1 .683 0 r
.008 w
.08569 .38875 Mdot
.016 w
.08569 .38875 m
.08595 .38607 L
s
1 .659 0 r
.008 w
.08595 .38607 Mdot
.016 w
.08595 .38607 m
.08623 .38352 L
s
1 .634 0 r
.008 w
.08623 .38352 Mdot
.016 w
.08623 .38352 m
.08648 .3804 L
s
1 .61 0 r
.008 w
.08648 .3804 Mdot
.016 w
.08648 .3804 m
.08677 .37778 L
s
1 .585 0 r
.008 w
.08677 .37778 Mdot
.016 w
.08677 .37778 m
.08707 .37466 L
s
1 .561 0 r
.008 w
.08707 .37466 Mdot
.016 w
.08707 .37466 m
.08739 .37179 L
s
1 .537 0 r
.008 w
.08739 .37179 Mdot
.016 w
.08739 .37179 m
.08773 .36873 L
s
1 .512 0 r
.008 w
.08773 .36873 Mdot
.016 w
.08773 .36873 m
.08811 .36528 L
s
1 .488 0 r
.008 w
.08811 .36528 Mdot
.016 w
.08811 .36528 m
.08852 .36261 L
s
1 .463 0 r
.008 w
.08852 .36261 Mdot
.016 w
.08852 .36261 m
.08894 .35976 L
s
1 .439 0 r
.008 w
.08894 .35976 Mdot
.016 w
.08894 .35976 m
.08937 .35691 L
s
1 .415 0 r
.008 w
.08937 .35691 Mdot
.016 w
.08937 .35691 m
.08979 .35401 L
s
1 .39 0 r
.008 w
.08979 .35401 Mdot
.016 w
.08979 .35401 m
.09022 .35103 L
s
1 .366 0 r
.008 w
.09022 .35103 Mdot
.016 w
.09022 .35103 m
.09066 .34875 L
s
1 .341 0 r
.008 w
.09066 .34875 Mdot
.016 w
.09066 .34875 m
.09111 .3461 L
s
1 .317 0 r
.008 w
.09111 .3461 Mdot
.016 w
.09111 .3461 m
.09157 .34367 L
s
1 .293 0 r
.008 w
.09157 .34367 Mdot
.016 w
.09157 .34367 m
.09202 .34143 L
s
1 .268 0 r
.008 w
.09202 .34143 Mdot
.016 w
.09202 .34143 m
.09246 .33923 L
s
1 .244 0 r
.008 w
.09246 .33923 Mdot
.016 w
.09246 .33923 m
.09289 .33736 L
s
1 .22 0 r
.008 w
.09289 .33736 Mdot
.016 w
.09289 .33736 m
.09331 .3356 L
s
1 .195 0 r
.008 w
.09331 .3356 Mdot
.016 w
.09331 .3356 m
.0937 .33419 L
s
1 .171 0 r
.008 w
.0937 .33419 Mdot
.016 w
.0937 .33419 m
.09406 .33298 L
s
1 .146 0 r
.008 w
.09406 .33298 Mdot
.016 w
.09406 .33298 m
.09438 .33206 L
s
1 .122 0 r
.008 w
.09438 .33206 Mdot
.016 w
.09438 .33206 m
.09467 .33132 L
s
1 .098 0 r
.008 w
.09467 .33132 Mdot
.016 w
.09467 .33132 m
.09491 .33079 L
s
1 .073 0 r
.008 w
.09491 .33079 Mdot
.016 w
.09491 .33079 m
.09511 .33045 L
s
1 .049 0 r
.008 w
.09511 .33045 Mdot
.016 w
.09511 .33045 m
.09528 .33025 L
s
1 .024 0 r
.008 w
.09528 .33025 Mdot
.016 w
.09528 .33025 m
.09541 .33017 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoL
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Ioo`Hmkmmoo`03001oogoo01Moo`0067oo00<007oo
Ool01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol0
01Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<0
07ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eo
o`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo00AlH7`0O01lH08mknEoo`03001oogoo
01Aoo`005Goo00<007ooOol01Goo00=lX7`0O0000W`00Sg_iGoo00<007ooOol057oo000EOol00`00
Oomoo`05Ool00gbPO01l0002O002?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`06O:1l
H7`0O01lH3g_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool00gbPO61lH002O6000cg_Oomo
o`3UOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`03?Nml`7c0009l`08mknMoo`03001oogoo
01=oo`004goo00<007ooOol01Woo00=mH7cPO>000WcP00=mH7ooOol0igoo00<007ooOol04Woo000C
Ool00`00Oomoo`06Ool00gePOB1m8002OB000cg_Oomoo`3WOol00`00Oomoo`0BOol001=oo`03001o
ogoo00Ioo`03OH1m@7e0009m@003?Nmoogoo0>Moo`03001oogoo019oo`004Woo00<007ooOol01goo
0Wf000=mH7f0?Nl0jgoo00<007ooOol04Goo000BOol00`00Oomoo`07Ool4OH000cg_Oomoo`3YOol0
0`00Oomoo`0AOol0019oo`03001oogoo00Ioo`03?Nmm`7g0009m`>aoo`03001oogoo015oo`004Goo
00<007ooOol01goo00<mkgg0OL000Wg0kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool00cg_
ON1mh002ON3]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`03OV1n07h0009n0003OV1oogoo
0>Yoo`03001oogoo011oo`004Goo00<007ooOol01goo00=nH7hPOR000WhP00<mkgooOol0jgoo00<0
07ooOol03goo000@Ool00`00Oomoo`08Ool00gj0OT1n@002OT3^Ool00`00Oomoo`0?Ool0011oo`03
001oogoo00Qoo`9nP003OV1nP3g_0>ioo`03001oogoo00moo`0047oo00<007ooOol027oo17j000<m
kgooOol0k7oo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4OZ000cg_Oomoo`3/Ool00`00Oomo
o`0?Ool000moo`03001oogoo00Uoo`An`08mknioo`03001oogoo00ioo`003goo00<007ooOol02Goo
17kP0cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4Ob03?No]Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Uoo`AoP0<mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo
00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00Yoo``mknUoo`03001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>
Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001o
ogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=
?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<0
07ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<
Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007oo
Ool02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomo
o`0<Ool000eoo`03001oogoo00Qoo`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_
jGoo00<007ooOol037oo000=Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001o
ogoo00Qooa<mknQoo`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007oo
Ool02goo000<Ool00`00Oomoo`06OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPm
knIoo`03001oogoo00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Io
o`TmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo
000<Ool00`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`Hm
knAoo`03001oogoo00]oo`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00
Oomoo`0HOol9?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]o
o`0037oo00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol0
0`00Oomoo`0;Ool000eoo`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol0
6goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eo
o`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007oo
Ool037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pm
kmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00
Oomoo`0LOol;?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00ao
o`003Goo00<007ooOol07Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol0
0`00Oomoo`0=Ool000ioo`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0
ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?io
o`03001oogoo00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol0
0`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001o
ogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol0
3goo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011o
o`004Woo00<007ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0
019oo`03001oogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000C
Ool00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo
00<007ooOol0m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03
001oogoo0?=oo`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00
Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo
0>moo`03001oogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]
Ool00`00Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo
00<007ooOol05goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03
001oogoo01Qoo`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00
Oomoo`0IOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007oo
Ool06Woo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo
01]oo`007Goo00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0L
Ool001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo
000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`00
87oo00<007ooOol0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025o
o`03001oogoo0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol0
0`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<0
07ooOol0dgoo00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001o
ogoo0<moo`03001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomo
o`3=Ool00`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0
bGoo00<007ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Mo
o`03001oogoo02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool0
0`00Oomoo`0[Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<0
07ooOol0;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001o
ogoo02ioo`00<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomo
o`0`Ool0039oo`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00
Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007oo
Ool0[goo00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo
0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0j
Ool003aoo`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo
000nOol2002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00
@Woo0013Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=o
o`00AGoo00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`80
04Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001o
ogoo04eoo`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`80
07Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uo
o`00Fgoo0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00
HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo
1000KGoo001`Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001o
Ool>0005Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00Rgoo0P0017oo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00S7oo00D007oo
Oomoo`00009oo`03001oogoo08Yoo`00SGoo00@007ooOol0009oo`03001oogoo08Yoo`00RWoo00@0
07ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(31)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
1 .955 0 r
.008 w
.09783 .31714 Mdot
.016 w
.09783 .31714 m
.09784 .31699 L
s
1 .909 0 r
.008 w
.09784 .31699 Mdot
.016 w
.09784 .31699 m
.09792 .3167 L
s
1 .864 0 r
.008 w
.09792 .3167 Mdot
.016 w
.09792 .3167 m
.09807 .31627 L
s
1 .818 0 r
.008 w
.09807 .31627 Mdot
.016 w
.09807 .31627 m
.09829 .31569 L
s
1 .773 0 r
.008 w
.09829 .31569 Mdot
.016 w
.09829 .31569 m
.09858 .31497 L
s
1 .727 0 r
.008 w
.09858 .31497 Mdot
.016 w
.09858 .31497 m
.09895 .31417 L
s
1 .682 0 r
.008 w
.09895 .31417 Mdot
.016 w
.09895 .31417 m
.09939 .31322 L
s
1 .636 0 r
.008 w
.09939 .31322 Mdot
.016 w
.09939 .31322 m
.09989 .31218 L
s
1 .591 0 r
.008 w
.09989 .31218 Mdot
.016 w
.09989 .31218 m
.10046 .31112 L
s
1 .545 0 r
.008 w
.10046 .31112 Mdot
.016 w
.10046 .31112 m
.10108 .31 L
s
1 .5 0 r
.008 w
.10108 .31 Mdot
.016 w
.10108 .31 m
.10175 .30886 L
s
1 .455 0 r
.008 w
.10175 .30886 Mdot
.016 w
.10175 .30886 m
.1024 .30776 L
s
1 .409 0 r
.008 w
.1024 .30776 Mdot
.016 w
.1024 .30776 m
.10304 .30678 L
s
1 .364 0 r
.008 w
.10304 .30678 Mdot
.016 w
.10304 .30678 m
.10364 .30589 L
s
1 .318 0 r
.008 w
.10364 .30589 Mdot
.016 w
.10364 .30589 m
.10419 .30513 L
s
1 .273 0 r
.008 w
.10419 .30513 Mdot
.016 w
.10419 .30513 m
.10464 .30451 L
s
1 .227 0 r
.008 w
.10464 .30451 Mdot
.016 w
.10464 .30451 m
.10501 .30404 L
s
1 .182 0 r
.008 w
.10501 .30404 Mdot
.016 w
.10501 .30404 m
.1053 .30368 L
s
1 .136 0 r
.008 w
.1053 .30368 Mdot
.016 w
.1053 .30368 m
.10552 .30342 L
s
1 .091 0 r
.008 w
.10552 .30342 Mdot
.016 w
.10552 .30342 m
.10567 .30323 L
s
1 .045 0 r
.008 w
.10567 .30323 Mdot
.016 w
.10567 .30323 m
.10578 .30311 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00JGoo1000AGoo1000JWoo001VOol3001=Ool3001WOol006=oo`<005=oo`<006Aoo`00H7oo0`00
FGoo0`00HGoo001NOol2001OOol2001OOol005aoo`8006=oo`8005eoo`00FWoo0P00Igoo0P00Fgoo
001HOol2001[Ool2001IOol005Eoo`<006moo`<005Ioo`00Dgoo0P00MGoo0P00E7oo001AOol2001i
Ool2001BOol0051oo`03001oogoo07]oo`03001oogoo04moo`00Cgoo00<007ooOol0OGoo00<007oo
Ool0CWoo001=Ool20021Ool2001>Ool004]oo`8008Eoo`8004aoo`00BGoo0P00RGoo0P00BWoo0018
Ool00`00Oomoo`2;Ool00`00Oomoo`17Ool004Ioo`8008moo`8004Moo`00AGoo00<007ooOol0TGoo
00<007ooOol0A7oo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004=oo`03001oogoo09Eoo`03
001oogoo049oo`00@Goo0P00VGoo0P00@Woo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol003mo
o`03001oogoo09eoo`8003moo`00?Woo00<007ooOol0X7oo00<007ooOol0?7oo000lOol2002TOol0
0`00Oomoo`0kOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00>Woo00<007ooOol0Ygoo0P00
>Woo000iOol00`00Oomoo`2ZOol00`00Oomoo`0gOol003Moo`800:ioo`03001oogoo03Ioo`00=Woo
00<007ooOol0[goo00<007ooOol0=Goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00<Woo0P00]goo00<007ooOol0<Woo000aOol00`00Oomoo`2h
Ool00`00Oomoo`0aOol0031oo`03001oogoo0;Yoo`03001oogoo031oo`00<7oo00<007ooOol0^goo
00<007ooOol0;goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool002ioo`03001oogoo0;moo`03
001oogoo02eoo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000/Ool00`00Oomoo`33Ool00`00
Oomoo`0[Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Uoo`03001oogoo0<Uoo`03001oogoo
02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1
Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007oo
Ool01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol0
02Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<0
07ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Io
o`LmklYoo`03001oogoo025oo`008Woo00<007ooOol01Goo1cg_bgoo00<007ooOol08Goo000QOol0
0`00Oomoo`06Ool6?No=Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Lmklioo`03001oogoo
01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoA
Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007oo
Ool01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol0
01eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<0
07ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Io
o`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol0
0`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo
01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool2O405
?NoLOol00`00Oomoo`0HOol001Qoo`03001oogoo00Eoo`03O>1l@7`P009l@08mkmmoo`03001oogoo
01Moo`0067oo00<007ooOol01Goo00=lh7a0O2000Wa00Sg_ggoo00<007ooOol05goo000HOol00`00
Oomoo`04Ool00ggPO>1lh002O4000gcP?Nlmk`3OOol00`00Oomoo`0GOol001Moo`03001oogoo00Eo
o`03ON1lh7cP00=lh08mkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo00<mkgjPOF000geP
0Sg_hGoo00<007ooOol05Woo000FOol00`00Oomoo`05Ool01Cg_OZ1nX7gPOZ000cg_hWoo00<007oo
Ool05Goo000FOol00`00Oomoo`05Ool00cg_OZ1nX002OZ000cg_Oomoo`3ROol00`00Oomoo`0EOol0
01Eoo`03001oogoo00Ioo`03?NmoX7nP009oX003?Nmoogoo0>=oo`03001oogoo01Aoo`005Goo00<0
07ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0D
Ool001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_igoo
00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001oogoo
00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000C
Ool00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03001o
ogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool5
?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<0
07ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomoo`0@
Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo
00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo
00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000?
Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001o
ogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7
?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003Woo00<0
07ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool<?NoYOol00`00Oomoo`0=
Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2cg_igoo
00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=
Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001o
ogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool8
?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`Lmk`=oo`DmknMoo`03
001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007ooOol037oo000=Ool00`00Oomoo`08
Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0mknUoo`03001oogoo00aoo`003Goo
00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00Oomoo`08OolC?NoXOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001oogoo00]oo`0037oo00<007ooOol0
1Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH?NoVOol00`00Oomoo`0;Ool000ao
o`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_?Nl0
33g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_
2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoTOol00`00Oomoo`0;Ool000ao
o`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol067oo2Cg_hWoo00<007oo
Ool02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xm
kn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo00<007ooOol02goo000=Ool00`00
Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00ao
o`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol0
77oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eo
o`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<007ooOol077oo2cg_fWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`Tm
kmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo00<007ooOol03Goo000>Ool00`00
Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo
00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03
001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00
Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007oo
Ool0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo
0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3k
Ool00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo
00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03
001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00
Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007oo
Ool04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo
019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0C
Ool001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo
000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`00
5Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Mo
o`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol0
0`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<0
07ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001o
ogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomo
o`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5o
o`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol0
0`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<0
07ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001o
ogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomo
o`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol0
8Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=o
o`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol0
02Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000X
Ool00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo
00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03
001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00
Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007oo
Ool0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo
0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000c
Ool003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo
000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00
=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uo
o`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol0
0`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010
Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo
00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03
001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]o
o`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo
07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=o
o`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00
GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo
0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000
LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5
002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000=oo`D008]oo`00
RWoo00@007ooOol000Aoo`03001oogoo08]oo`00S7oo00<007ooOol00goo00<007ooOol0Rgoo002=
Ool00`00Oomoo`02Ool00`00Oomoo`2;Ool008Yoo`04001oogoo0004Ool00`00Oomoo`2;Ool008]o
o`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(32)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
1 .997 0 r
.008 w
.10571 .30326 Mdot
.016 w
.10571 .30326 m
.10587 .30329 L
s
1 .994 0 r
.008 w
.10587 .30329 Mdot
.016 w
.10587 .30329 m
.10608 .30331 L
s
1 .99 0 r
.008 w
.10608 .30331 Mdot
.016 w
.10608 .30331 m
.10634 .30332 L
s
1 .987 0 r
.008 w
.10634 .30332 Mdot
.016 w
.10634 .30332 m
.10665 .30331 L
s
1 .984 0 r
.008 w
.10665 .30331 Mdot
.016 w
.10665 .30331 m
.10698 .30328 L
s
1 .981 0 r
.008 w
.10698 .30328 Mdot
.016 w
.10698 .30328 m
.1073 .30322 L
s
1 .977 0 r
.008 w
.1073 .30322 Mdot
.016 w
.1073 .30322 m
.10761 .30313 L
s
1 .974 0 r
.008 w
.10761 .30313 Mdot
.016 w
.10761 .30313 m
.1079 .30302 L
s
1 .971 0 r
.008 w
.1079 .30302 Mdot
.016 w
.1079 .30302 m
.10819 .30284 L
s
1 .968 0 r
.008 w
.10819 .30284 Mdot
.016 w
.10819 .30284 m
.10844 .30258 L
s
1 .965 0 r
.008 w
.10844 .30258 Mdot
.016 w
.10844 .30258 m
.10868 .3022 L
s
1 .961 0 r
.008 w
.10868 .3022 Mdot
.016 w
.10868 .3022 m
.10893 .30175 L
s
1 .958 0 r
.008 w
.10893 .30175 Mdot
.016 w
.10893 .30175 m
.1092 .30121 L
s
1 .955 0 r
.008 w
.1092 .30121 Mdot
.016 w
.1092 .30121 m
.10954 .30054 L
s
1 .952 0 r
.008 w
.10954 .30054 Mdot
.016 w
.10954 .30054 m
.11003 .29983 L
s
1 .948 0 r
.008 w
.11003 .29983 Mdot
.016 w
.11003 .29983 m
.11067 .29895 L
s
1 .945 0 r
.008 w
.11067 .29895 Mdot
.016 w
.11067 .29895 m
.11139 .29792 L
s
1 .942 0 r
.008 w
.11139 .29792 Mdot
.016 w
.11139 .29792 m
.11236 .29675 L
s
1 .939 0 r
.008 w
.11236 .29675 Mdot
.016 w
.11236 .29675 m
.11344 .29551 L
s
1 .935 0 r
.008 w
.11344 .29551 Mdot
.016 w
.11344 .29551 m
.11477 .29416 L
s
1 .932 0 r
.008 w
.11477 .29416 Mdot
.016 w
.11477 .29416 m
.11614 .29272 L
s
1 .929 0 r
.008 w
.11614 .29272 Mdot
.016 w
.11614 .29272 m
.11765 .29129 L
s
1 .926 0 r
.008 w
.11765 .29129 Mdot
.016 w
.11765 .29129 m
.11913 .28989 L
s
1 .923 0 r
.008 w
.11913 .28989 Mdot
.016 w
.11913 .28989 m
.12057 .28871 L
s
1 .919 0 r
.008 w
.12057 .28871 Mdot
.016 w
.12057 .28871 m
.12169 .28763 L
s
1 .916 0 r
.008 w
.12169 .28763 Mdot
.016 w
.12169 .28763 m
.12292 .28659 L
s
1 .913 0 r
.008 w
.12292 .28659 Mdot
.016 w
.12292 .28659 m
.12389 .28574 L
s
1 .91 0 r
.008 w
.12389 .28574 Mdot
.016 w
.12389 .28574 m
.12473 .28492 L
s
1 .906 0 r
.008 w
.12473 .28492 Mdot
.016 w
.12473 .28492 m
.12541 .28409 L
s
1 .903 0 r
.008 w
.12541 .28409 Mdot
.016 w
.12541 .28409 m
.12599 .28323 L
s
1 .9 0 r
.008 w
.12599 .28323 Mdot
.016 w
.12599 .28323 m
.12652 .28232 L
s
1 .897 0 r
.008 w
.12652 .28232 Mdot
.016 w
.12652 .28232 m
.12703 .28127 L
s
1 .894 0 r
.008 w
.12703 .28127 Mdot
.016 w
.12703 .28127 m
.12755 .28003 L
s
1 .89 0 r
.008 w
.12755 .28003 Mdot
.016 w
.12755 .28003 m
.12811 .27861 L
s
1 .887 0 r
.008 w
.12811 .27861 Mdot
.016 w
.12811 .27861 m
.12868 .27715 L
s
1 .884 0 r
.008 w
.12868 .27715 Mdot
.016 w
.12868 .27715 m
.12916 .27562 L
s
1 .881 0 r
.008 w
.12916 .27562 Mdot
.016 w
.12916 .27562 m
.12974 .27373 L
s
1 .877 0 r
.008 w
.12974 .27373 Mdot
.016 w
.12974 .27373 m
.13035 .27189 L
s
1 .874 0 r
.008 w
.13035 .27189 Mdot
.016 w
.13035 .27189 m
.13103 .26987 L
s
1 .871 0 r
.008 w
.13103 .26987 Mdot
.016 w
.13103 .26987 m
.13162 .26773 L
s
1 .868 0 r
.008 w
.13162 .26773 Mdot
.016 w
.13162 .26773 m
.13218 .2659 L
s
1 .865 0 r
.008 w
.13218 .2659 Mdot
.016 w
.13218 .2659 m
.1327 .26406 L
s
1 .861 0 r
.008 w
.1327 .26406 Mdot
.016 w
.1327 .26406 m
.13317 .26228 L
s
1 .858 0 r
.008 w
.13317 .26228 Mdot
.016 w
.13317 .26228 m
.13362 .26059 L
s
1 .855 0 r
.008 w
.13362 .26059 Mdot
.016 w
.13362 .26059 m
.13409 .25909 L
s
1 .852 0 r
.008 w
.13409 .25909 Mdot
.016 w
.13409 .25909 m
.13461 .25766 L
s
1 .848 0 r
.008 w
.13461 .25766 Mdot
.016 w
.13461 .25766 m
.13522 .25623 L
s
1 .845 0 r
.008 w
.13522 .25623 Mdot
.016 w
.13522 .25623 m
.13591 .25476 L
s
1 .842 0 r
.008 w
.13591 .25476 Mdot
.016 w
.13591 .25476 m
.1368 .25323 L
s
1 .839 0 r
.008 w
.1368 .25323 Mdot
.016 w
.1368 .25323 m
.1378 .25187 L
s
1 .835 0 r
.008 w
.1378 .25187 Mdot
.016 w
.1378 .25187 m
.13898 .25031 L
s
1 .832 0 r
.008 w
.13898 .25031 Mdot
.016 w
.13898 .25031 m
.1403 .24869 L
s
1 .829 0 r
.008 w
.1403 .24869 Mdot
.016 w
.1403 .24869 m
.14177 .2471 L
s
1 .826 0 r
.008 w
.14177 .2471 Mdot
.016 w
.14177 .2471 m
.14326 .2454 L
s
1 .823 0 r
.008 w
.14326 .2454 Mdot
.016 w
.14326 .2454 m
.14497 .24368 L
s
1 .819 0 r
.008 w
.14497 .24368 Mdot
.016 w
.14497 .24368 m
.14637 .24202 L
s
1 .816 0 r
.008 w
.14637 .24202 Mdot
.016 w
.14637 .24202 m
.14776 .24033 L
s
1 .813 0 r
.008 w
.14776 .24033 Mdot
.016 w
.14776 .24033 m
.14917 .23876 L
s
1 .81 0 r
.008 w
.14917 .23876 Mdot
.016 w
.14917 .23876 m
.15041 .23723 L
s
1 .806 0 r
.008 w
.15041 .23723 Mdot
.016 w
.15041 .23723 m
.1516 .23586 L
s
1 .803 0 r
.008 w
.1516 .23586 Mdot
.016 w
.1516 .23586 m
.15265 .23455 L
s
1 .8 0 r
.008 w
.15265 .23455 Mdot
.016 w
.15265 .23455 m
.15369 .2333 L
s
1 .797 0 r
.008 w
.15369 .2333 Mdot
.016 w
.15369 .2333 m
.15456 .23217 L
s
1 .794 0 r
.008 w
.15456 .23217 Mdot
.016 w
.15456 .23217 m
.15538 .23107 L
s
1 .79 0 r
.008 w
.15538 .23107 Mdot
.016 w
.15538 .23107 m
.15614 .22997 L
s
1 .787 0 r
.008 w
.15614 .22997 Mdot
.016 w
.15614 .22997 m
.15684 .22881 L
s
1 .784 0 r
.008 w
.15684 .22881 Mdot
.016 w
.15684 .22881 m
.15751 .22769 L
s
1 .781 0 r
.008 w
.15751 .22769 Mdot
.016 w
.15751 .22769 m
.15809 .22647 L
s
1 .777 0 r
.008 w
.15809 .22647 Mdot
.016 w
.15809 .22647 m
.15865 .2251 L
s
1 .774 0 r
.008 w
.15865 .2251 Mdot
.016 w
.15865 .2251 m
.15917 .22364 L
s
1 .771 0 r
.008 w
.15917 .22364 Mdot
.016 w
.15917 .22364 m
.15963 .22203 L
s
1 .768 0 r
.008 w
.15963 .22203 Mdot
.016 w
.15963 .22203 m
.16007 .22026 L
s
1 .765 0 r
.008 w
.16007 .22026 Mdot
.016 w
.16007 .22026 m
.16051 .21862 L
s
1 .761 0 r
.008 w
.16051 .21862 Mdot
.016 w
.16051 .21862 m
.16097 .21668 L
s
1 .758 0 r
.008 w
.16097 .21668 Mdot
.016 w
.16097 .21668 m
.16147 .21476 L
s
1 .755 0 r
.008 w
.16147 .21476 Mdot
.016 w
.16147 .21476 m
.162 .21253 L
s
1 .752 0 r
.008 w
.162 .21253 Mdot
.016 w
.162 .21253 m
.16258 .2103 L
s
1 .748 0 r
.008 w
.16258 .2103 Mdot
.016 w
.16258 .2103 m
.16323 .20812 L
s
1 .745 0 r
.008 w
.16323 .20812 Mdot
.016 w
.16323 .20812 m
.16399 .20573 L
s
1 .742 0 r
.008 w
.16399 .20573 Mdot
.016 w
.16399 .20573 m
.16488 .2033 L
s
1 .739 0 r
.008 w
.16488 .2033 Mdot
.016 w
.16488 .2033 m
.16579 .20121 L
s
1 .735 0 r
.008 w
.16579 .20121 Mdot
.016 w
.16579 .20121 m
.16684 .19918 L
s
1 .732 0 r
.008 w
.16684 .19918 Mdot
.016 w
.16684 .19918 m
.1679 .19713 L
s
1 .729 0 r
.008 w
.1679 .19713 Mdot
.016 w
.1679 .19713 m
.16907 .19515 L
s
1 .726 0 r
.008 w
.16907 .19515 Mdot
.016 w
.16907 .19515 m
.17032 .1934 L
s
1 .723 0 r
.008 w
.17032 .1934 Mdot
.016 w
.17032 .1934 m
.17153 .19159 L
s
1 .719 0 r
.008 w
.17153 .19159 Mdot
.016 w
.17153 .19159 m
.17285 .18975 L
s
1 .716 0 r
.008 w
.17285 .18975 Mdot
.016 w
.17285 .18975 m
.17427 .18802 L
s
1 .713 0 r
.008 w
.17427 .18802 Mdot
.016 w
.17427 .18802 m
.17573 .18628 L
s
1 .71 0 r
.008 w
.17573 .18628 Mdot
.016 w
.17573 .18628 m
.17727 .18463 L
s
1 .706 0 r
.008 w
.17727 .18463 Mdot
.016 w
.17727 .18463 m
.17872 .18303 L
s
1 .703 0 r
.008 w
.17872 .18303 Mdot
.016 w
.17872 .18303 m
.18019 .1816 L
s
1 .7 0 r
.008 w
.18019 .1816 Mdot
.016 w
.18019 .1816 m
.18167 .18022 L
s
1 .697 0 r
.008 w
.18167 .18022 Mdot
.016 w
.18167 .18022 m
.18304 .17891 L
s
1 .694 0 r
.008 w
.18304 .17891 Mdot
.016 w
.18304 .17891 m
.18438 .17776 L
s
1 .69 0 r
.008 w
.18438 .17776 Mdot
.016 w
.18438 .17776 m
.18567 .17671 L
s
1 .687 0 r
.008 w
.18567 .17671 Mdot
.016 w
.18567 .17671 m
.1868 .17583 L
s
1 .684 0 r
.008 w
.1868 .17583 Mdot
.016 w
.1868 .17583 m
.18786 .17508 L
s
1 .681 0 r
.008 w
.18786 .17508 Mdot
.016 w
.18786 .17508 m
.18869 .17449 L
s
1 .677 0 r
.008 w
.18869 .17449 Mdot
.016 w
.18869 .17449 m
.18937 .17409 L
s
1 .674 0 r
.008 w
.18937 .17409 Mdot
.016 w
.18937 .17409 m
.18987 .17388 L
s
1 .671 0 r
.008 w
.18987 .17388 Mdot
.016 w
.18987 .17388 m
.19018 .17384 L
s
1 .668 0 r
.008 w
.19018 .17384 Mdot
.016 w
.19018 .17384 m
.19029 .17395 L
s
1 .665 0 r
.008 w
.19029 .17395 Mdot
.016 w
.19029 .17395 m
.19023 .17414 L
s
1 .661 0 r
.008 w
.19023 .17414 Mdot
.016 w
.19023 .17414 m
.19006 .17435 L
s
1 .658 0 r
.008 w
.19006 .17435 Mdot
.016 w
.19006 .17435 m
.18986 .17452 L
s
1 .655 0 r
.008 w
.18986 .17452 Mdot
.016 w
.18986 .17452 m
.18969 .17457 L
s
1 .652 0 r
.008 w
.18969 .17457 Mdot
.016 w
.18969 .17457 m
.18961 .17444 L
s
1 .648 0 r
.008 w
.18961 .17444 Mdot
.016 w
.18961 .17444 m
.18969 .17407 L
s
1 .645 0 r
.008 w
.18969 .17407 Mdot
.016 w
.18969 .17407 m
.18996 .17346 L
s
1 .642 0 r
.008 w
.18996 .17346 Mdot
.016 w
.18996 .17346 m
.19043 .17257 L
s
1 .639 0 r
.008 w
.19043 .17257 Mdot
.016 w
.19043 .17257 m
.1911 .17139 L
s
1 .635 0 r
.008 w
.1911 .17139 Mdot
.016 w
.1911 .17139 m
.19192 .17005 L
s
1 .632 0 r
.008 w
.19192 .17005 Mdot
.016 w
.19192 .17005 m
.19287 .16838 L
s
1 .629 0 r
.008 w
.19287 .16838 Mdot
.016 w
.19287 .16838 m
.19393 .16639 L
s
1 .626 0 r
.008 w
.19393 .16639 Mdot
.016 w
.19393 .16639 m
.19497 .16444 L
s
1 .623 0 r
.008 w
.19497 .16444 Mdot
.016 w
.19497 .16444 m
.19612 .16219 L
s
1 .619 0 r
.008 w
.19612 .16219 Mdot
.016 w
.19612 .16219 m
.19748 .15954 L
s
1 .616 0 r
.008 w
.19748 .15954 Mdot
.016 w
.19748 .15954 m
.19881 .1573 L
s
1 .613 0 r
.008 w
.19881 .1573 Mdot
.016 w
.19881 .1573 m
.20025 .15503 L
s
1 .61 0 r
.008 w
.20025 .15503 Mdot
.016 w
.20025 .15503 m
.20156 .15273 L
s
1 .606 0 r
.008 w
.20156 .15273 Mdot
.016 w
.20156 .15273 m
.20281 .15059 L
s
1 .603 0 r
.008 w
.20281 .15059 Mdot
.016 w
.20281 .15059 m
.20395 .14865 L
s
1 .6 0 r
.008 w
.20395 .14865 Mdot
.016 w
.20395 .14865 m
.20494 .14716 L
s
1 .597 0 r
.008 w
.20494 .14716 Mdot
.016 w
.20494 .14716 m
.20586 .1458 L
s
1 .594 0 r
.008 w
.20586 .1458 Mdot
.016 w
.20586 .1458 m
.20672 .14475 L
s
1 .59 0 r
.008 w
.20672 .14475 Mdot
.016 w
.20672 .14475 m
.20757 .14389 L
s
1 .587 0 r
.008 w
.20757 .14389 Mdot
.016 w
.20757 .14389 m
.20838 .14318 L
s
1 .584 0 r
.008 w
.20838 .14318 Mdot
.016 w
.20838 .14318 m
.20915 .14262 L
s
1 .581 0 r
.008 w
.20915 .14262 Mdot
.016 w
.20915 .14262 m
.20987 .14217 L
s
1 .577 0 r
.008 w
.20987 .14217 Mdot
.016 w
.20987 .14217 m
.21052 .14182 L
s
1 .574 0 r
.008 w
.21052 .14182 Mdot
.016 w
.21052 .14182 m
.21111 .14156 L
s
1 .571 0 r
.008 w
.21111 .14156 Mdot
.016 w
.21111 .14156 m
.2117 .14137 L
s
1 .568 0 r
.008 w
.2117 .14137 Mdot
.016 w
.2117 .14137 m
.21232 .14125 L
s
1 .565 0 r
.008 w
.21232 .14125 Mdot
.016 w
.21232 .14125 m
.21302 .14118 L
s
1 .561 0 r
.008 w
.21302 .14118 Mdot
.016 w
.21302 .14118 m
.21384 .14109 L
s
1 .558 0 r
.008 w
.21384 .14109 Mdot
.016 w
.21384 .14109 m
.2148 .14097 L
s
1 .555 0 r
.008 w
.2148 .14097 Mdot
.016 w
.2148 .14097 m
.21591 .14083 L
s
1 .552 0 r
.008 w
.21591 .14083 Mdot
.016 w
.21591 .14083 m
.21715 .14069 L
s
1 .548 0 r
.008 w
.21715 .14069 Mdot
.016 w
.21715 .14069 m
.21831 .14058 L
s
1 .545 0 r
.008 w
.21831 .14058 Mdot
.016 w
.21831 .14058 m
.21958 .14052 L
s
1 .542 0 r
.008 w
.21958 .14052 Mdot
.016 w
.21958 .14052 m
.22064 .1405 L
s
1 .539 0 r
.008 w
.22064 .1405 Mdot
.016 w
.22064 .1405 m
.22178 .14052 L
s
1 .535 0 r
.008 w
.22178 .14052 Mdot
.016 w
.22178 .14052 m
.22287 .14061 L
s
1 .532 0 r
.008 w
.22287 .14061 Mdot
.016 w
.22287 .14061 m
.22376 .14075 L
s
1 .529 0 r
.008 w
.22376 .14075 Mdot
.016 w
.22376 .14075 m
.22455 .14094 L
s
1 .526 0 r
.008 w
.22455 .14094 Mdot
.016 w
.22455 .14094 m
.2252 .14113 L
s
1 .523 0 r
.008 w
.2252 .14113 Mdot
.016 w
.2252 .14113 m
.22566 .14128 L
s
1 .519 0 r
.008 w
.22566 .14128 Mdot
.016 w
.22566 .14128 m
.22595 .14135 L
s
1 .516 0 r
.008 w
.22595 .14135 Mdot
.016 w
.22595 .14135 m
.22611 .14131 L
s
1 .513 0 r
.008 w
.22611 .14131 Mdot
.016 w
.22611 .14131 m
.22622 .14114 L
s
1 .51 0 r
.008 w
.22622 .14114 Mdot
.016 w
.22622 .14114 m
.22637 .1408 L
s
1 .506 0 r
.008 w
.22637 .1408 Mdot
.016 w
.22637 .1408 m
.22667 .14029 L
s
1 .503 0 r
.008 w
.22667 .14029 Mdot
.016 w
.22667 .14029 m
.22718 .13957 L
s
1 .5 0 r
.008 w
.22718 .13957 Mdot
.016 w
.22718 .13957 m
.22795 .13861 L
s
1 .497 0 r
.008 w
.22795 .13861 Mdot
.016 w
.22795 .13861 m
.22902 .13742 L
s
1 .494 0 r
.008 w
.22902 .13742 Mdot
.016 w
.22902 .13742 m
.23027 .13612 L
s
1 .49 0 r
.008 w
.23027 .13612 Mdot
.016 w
.23027 .13612 m
.23183 .13444 L
s
1 .487 0 r
.008 w
.23183 .13444 Mdot
.016 w
.23183 .13444 m
.23354 .13265 L
s
1 .484 0 r
.008 w
.23354 .13265 Mdot
.016 w
.23354 .13265 m
.23562 .13059 L
s
1 .481 0 r
.008 w
.23562 .13059 Mdot
.016 w
.23562 .13059 m
.23751 .12834 L
s
1 .477 0 r
.008 w
.23751 .12834 Mdot
.016 w
.23751 .12834 m
.23967 .12603 L
s
1 .474 0 r
.008 w
.23967 .12603 Mdot
.016 w
.23967 .12603 m
.24197 .12365 L
s
1 .471 0 r
.008 w
.24197 .12365 Mdot
.016 w
.24197 .12365 m
.24385 .12139 L
s
1 .468 0 r
.008 w
.24385 .12139 Mdot
.016 w
.24385 .12139 m
.24582 .11919 L
s
1 .465 0 r
.008 w
.24582 .11919 Mdot
.016 w
.24582 .11919 m
.24764 .11716 L
s
1 .461 0 r
.008 w
.24764 .11716 Mdot
.016 w
.24764 .11716 m
.24917 .11545 L
s
1 .458 0 r
.008 w
.24917 .11545 Mdot
.016 w
.24917 .11545 m
.25055 .11388 L
s
1 .455 0 r
.008 w
.25055 .11388 Mdot
.016 w
.25055 .11388 m
.25172 .11249 L
s
1 .452 0 r
.008 w
.25172 .11249 Mdot
.016 w
.25172 .11249 m
.25268 .11139 L
s
1 .448 0 r
.008 w
.25268 .11139 Mdot
.016 w
.25268 .11139 m
.2535 .1105 L
s
1 .445 0 r
.008 w
.2535 .1105 Mdot
.016 w
.2535 .1105 m
.2542 .10984 L
s
1 .442 0 r
.008 w
.2542 .10984 Mdot
.016 w
.2542 .10984 m
.25482 .10942 L
s
1 .439 0 r
.008 w
.25482 .10942 Mdot
.016 w
.25482 .10942 m
.2554 .10921 L
s
1 .435 0 r
.008 w
.2554 .10921 Mdot
.016 w
.2554 .10921 m
.25596 .10915 L
s
1 .432 0 r
.008 w
.25596 .10915 Mdot
.016 w
.25596 .10915 m
.25655 .1092 L
s
1 .429 0 r
.008 w
.25655 .1092 Mdot
.016 w
.25655 .1092 m
.25716 .10932 L
s
1 .426 0 r
.008 w
.25716 .10932 Mdot
.016 w
.25716 .10932 m
.25782 .10946 L
s
1 .423 0 r
.008 w
.25782 .10946 Mdot
.016 w
.25782 .10946 m
.25848 .10959 L
s
1 .419 0 r
.008 w
.25848 .10959 Mdot
.016 w
.25848 .10959 m
.2591 .10971 L
s
1 .416 0 r
.008 w
.2591 .10971 Mdot
.016 w
.2591 .10971 m
.25968 .10981 L
s
1 .413 0 r
.008 w
.25968 .10981 Mdot
.016 w
.25968 .10981 m
.26023 .10989 L
s
1 .41 0 r
.008 w
.26023 .10989 Mdot
.016 w
.26023 .10989 m
.26073 .10992 L
s
1 .406 0 r
.008 w
.26073 .10992 Mdot
.016 w
.26073 .10992 m
.26118 .10991 L
s
1 .403 0 r
.008 w
.26118 .10991 Mdot
.016 w
.26118 .10991 m
.26158 .10987 L
s
1 .4 0 r
.008 w
.26158 .10987 Mdot
.016 w
.26158 .10987 m
.26192 .10981 L
s
1 .397 0 r
.008 w
.26192 .10981 Mdot
.016 w
.26192 .10981 m
.26219 .10973 L
s
1 .394 0 r
.008 w
.26219 .10973 Mdot
.016 w
.26219 .10973 m
.26243 .10966 L
s
1 .39 0 r
.008 w
.26243 .10966 Mdot
.016 w
.26243 .10966 m
.26263 .10961 L
s
1 .387 0 r
.008 w
.26263 .10961 Mdot
.016 w
.26263 .10961 m
.26281 .10958 L
s
1 .384 0 r
.008 w
.26281 .10958 Mdot
.016 w
.26281 .10958 m
.26299 .10959 L
s
1 .381 0 r
.008 w
.26299 .10959 Mdot
.016 w
.26299 .10959 m
.26318 .10961 L
s
1 .377 0 r
.008 w
.26318 .10961 Mdot
.016 w
.26318 .10961 m
.26336 .10982 L
s
1 .374 0 r
.008 w
.26336 .10982 Mdot
.016 w
.26336 .10982 m
.26357 .10977 L
s
1 .371 0 r
.008 w
.26357 .10977 Mdot
.016 w
.26357 .10977 m
.2638 .10966 L
s
1 .368 0 r
.008 w
.2638 .10966 Mdot
.016 w
.2638 .10966 m
.26401 .10952 L
s
1 .365 0 r
.008 w
.26401 .10952 Mdot
.016 w
.26401 .10952 m
.2642 .10937 L
s
1 .361 0 r
.008 w
.2642 .10937 Mdot
.016 w
.2642 .10937 m
.26435 .10923 L
s
1 .358 0 r
.008 w
.26435 .10923 Mdot
.016 w
.26435 .10923 m
.26444 .10908 L
s
1 .355 0 r
.008 w
.26444 .10908 Mdot
.016 w
.26444 .10908 m
.26448 .10892 L
s
1 .352 0 r
.008 w
.26448 .10892 Mdot
.016 w
.26448 .10892 m
.26445 .10871 L
s
1 .348 0 r
.008 w
.26445 .10871 Mdot
.016 w
.26445 .10871 m
.2644 .10849 L
s
1 .345 0 r
.008 w
.2644 .10849 Mdot
.016 w
.2644 .10849 m
.26433 .10822 L
s
1 .342 0 r
.008 w
.26433 .10822 Mdot
.016 w
.26433 .10822 m
.26428 .10795 L
s
1 .339 0 r
.008 w
.26428 .10795 Mdot
.016 w
.26428 .10795 m
.26426 .10765 L
s
1 .335 0 r
.008 w
.26426 .10765 Mdot
.016 w
.26426 .10765 m
.2643 .10729 L
s
1 .332 0 r
.008 w
.2643 .10729 Mdot
.016 w
.2643 .10729 m
.26442 .10697 L
s
1 .329 0 r
.008 w
.26442 .10697 Mdot
.016 w
.26442 .10697 m
.26459 .10668 L
s
1 .326 0 r
.008 w
.26459 .10668 Mdot
.016 w
.26459 .10668 m
.26482 .10645 L
s
1 .323 0 r
.008 w
.26482 .10645 Mdot
.016 w
.26482 .10645 m
.26509 .10618 L
s
1 .319 0 r
.008 w
.26509 .10618 Mdot
.016 w
.26509 .10618 m
.2654 .10589 L
s
1 .316 0 r
.008 w
.2654 .10589 Mdot
.016 w
.2654 .10589 m
.26574 .10559 L
s
1 .313 0 r
.008 w
.26574 .10559 Mdot
.016 w
.26574 .10559 m
.26614 .10529 L
s
1 .31 0 r
.008 w
.26614 .10529 Mdot
.016 w
.26614 .10529 m
.26659 .105 L
s
1 .306 0 r
.008 w
.26659 .105 Mdot
.016 w
.26659 .105 m
.26711 .1047 L
s
1 .303 0 r
.008 w
.26711 .1047 Mdot
.016 w
.26711 .1047 m
.26769 .10441 L
s
1 .3 0 r
.008 w
.26769 .10441 Mdot
.016 w
.26769 .10441 m
.26835 .10411 L
s
1 .297 0 r
.008 w
.26835 .10411 Mdot
.016 w
.26835 .10411 m
.26908 .1038 L
s
1 .294 0 r
.008 w
.26908 .1038 Mdot
.016 w
.26908 .1038 m
.2699 .10347 L
s
1 .29 0 r
.008 w
.2699 .10347 Mdot
.016 w
.2699 .10347 m
.27079 .1031 L
s
1 .287 0 r
.008 w
.27079 .1031 Mdot
.016 w
.27079 .1031 m
.27171 .10267 L
s
1 .284 0 r
.008 w
.27171 .10267 Mdot
.016 w
.27171 .10267 m
.27271 .1022 L
s
1 .281 0 r
.008 w
.27271 .1022 Mdot
.016 w
.27271 .1022 m
.27375 .10173 L
s
1 .277 0 r
.008 w
.27375 .10173 Mdot
.016 w
.27375 .10173 m
.27486 .10127 L
s
1 .274 0 r
.008 w
.27486 .10127 Mdot
.016 w
.27486 .10127 m
.27599 .10085 L
s
1 .271 0 r
.008 w
.27599 .10085 Mdot
.016 w
.27599 .10085 m
.27713 .10045 L
s
1 .268 0 r
.008 w
.27713 .10045 Mdot
.016 w
.27713 .10045 m
.27823 .10008 L
s
1 .265 0 r
.008 w
.27823 .10008 Mdot
.016 w
.27823 .10008 m
.27929 .09975 L
s
1 .261 0 r
.008 w
.27929 .09975 Mdot
.016 w
.27929 .09975 m
.28021 .09949 L
s
1 .258 0 r
.008 w
.28021 .09949 Mdot
.016 w
.28021 .09949 m
.28101 .09931 L
s
1 .255 0 r
.008 w
.28101 .09931 Mdot
.016 w
.28101 .09931 m
.28164 .09922 L
s
1 .252 0 r
.008 w
.28164 .09922 Mdot
.016 w
.28164 .09922 m
.28213 .09918 L
s
1 .248 0 r
.008 w
.28213 .09918 Mdot
.016 w
.28213 .09918 m
.2825 .09917 L
s
1 .245 0 r
.008 w
.2825 .09917 Mdot
.016 w
.2825 .09917 m
.28282 .09911 L
s
1 .242 0 r
.008 w
.28282 .09911 Mdot
.016 w
.28282 .09911 m
.2831 .09898 L
s
1 .239 0 r
.008 w
.2831 .09898 Mdot
.016 w
.2831 .09898 m
.2834 .09874 L
s
1 .235 0 r
.008 w
.2834 .09874 Mdot
.016 w
.2834 .09874 m
.28371 .09836 L
s
1 .232 0 r
.008 w
.28371 .09836 Mdot
.016 w
.28371 .09836 m
.28406 .09784 L
s
1 .229 0 r
.008 w
.28406 .09784 Mdot
.016 w
.28406 .09784 m
.28443 .09723 L
s
1 .226 0 r
.008 w
.28443 .09723 Mdot
.016 w
.28443 .09723 m
.28484 .09656 L
s
1 .223 0 r
.008 w
.28484 .09656 Mdot
.016 w
.28484 .09656 m
.28527 .09592 L
s
1 .219 0 r
.008 w
.28527 .09592 Mdot
.016 w
.28527 .09592 m
.28567 .09526 L
s
1 .216 0 r
.008 w
.28567 .09526 Mdot
.016 w
.28567 .09526 m
.28606 .0946 L
s
1 .213 0 r
.008 w
.28606 .0946 Mdot
.016 w
.28606 .0946 m
.28641 .09404 L
s
1 .21 0 r
.008 w
.28641 .09404 Mdot
.016 w
.28641 .09404 m
.28674 .09354 L
s
1 .206 0 r
.008 w
.28674 .09354 Mdot
.016 w
.28674 .09354 m
.28704 .09313 L
s
1 .203 0 r
.008 w
.28704 .09313 Mdot
.016 w
.28704 .09313 m
.28733 .09281 L
s
1 .2 0 r
.008 w
.28733 .09281 Mdot
.016 w
.28733 .09281 m
.28763 .0926 L
s
1 .197 0 r
.008 w
.28763 .0926 Mdot
.016 w
.28763 .0926 m
.28797 .09244 L
s
1 .194 0 r
.008 w
.28797 .09244 Mdot
.016 w
.28797 .09244 m
.28838 .0923 L
s
1 .19 0 r
.008 w
.28838 .0923 Mdot
.016 w
.28838 .0923 m
.28888 .09213 L
s
1 .187 0 r
.008 w
.28888 .09213 Mdot
.016 w
.28888 .09213 m
.28949 .09188 L
s
1 .184 0 r
.008 w
.28949 .09188 Mdot
.016 w
.28949 .09188 m
.29027 .09152 L
s
1 .181 0 r
.008 w
.29027 .09152 Mdot
.016 w
.29027 .09152 m
.29119 .09102 L
s
1 .177 0 r
.008 w
.29119 .09102 Mdot
.016 w
.29119 .09102 m
.29234 .09039 L
s
1 .174 0 r
.008 w
.29234 .09039 Mdot
.016 w
.29234 .09039 m
.29363 .08968 L
s
1 .171 0 r
.008 w
.29363 .08968 Mdot
.016 w
.29363 .08968 m
.29508 .08887 L
s
1 .168 0 r
.008 w
.29508 .08887 Mdot
.016 w
.29508 .08887 m
.29673 .08802 L
s
1 .165 0 r
.008 w
.29673 .08802 Mdot
.016 w
.29673 .08802 m
.29829 .08715 L
s
1 .161 0 r
.008 w
.29829 .08715 Mdot
.016 w
.29829 .08715 m
.2999 .0863 L
s
1 .158 0 r
.008 w
.2999 .0863 Mdot
.016 w
.2999 .0863 m
.30149 .08553 L
s
1 .155 0 r
.008 w
.30149 .08553 Mdot
.016 w
.30149 .08553 m
.30304 .08482 L
s
1 .152 0 r
.008 w
.30304 .08482 Mdot
.016 w
.30304 .08482 m
.30451 .08416 L
s
1 .148 0 r
.008 w
.30451 .08416 Mdot
.016 w
.30451 .08416 m
.30593 .08355 L
s
1 .145 0 r
.008 w
.30593 .08355 Mdot
.016 w
.30593 .08355 m
.30734 .08297 L
s
1 .142 0 r
.008 w
.30734 .08297 Mdot
.016 w
.30734 .08297 m
.30871 .0824 L
s
1 .139 0 r
.008 w
.30871 .0824 Mdot
.016 w
.30871 .0824 m
.31011 .0818 L
s
1 .135 0 r
.008 w
.31011 .0818 Mdot
.016 w
.31011 .0818 m
.31151 .08112 L
s
1 .132 0 r
.008 w
.31151 .08112 Mdot
.016 w
.31151 .08112 m
.31295 .0803 L
s
1 .129 0 r
.008 w
.31295 .0803 Mdot
.016 w
.31295 .0803 m
.31441 .07932 L
s
1 .126 0 r
.008 w
.31441 .07932 Mdot
.016 w
.31441 .07932 m
.31575 .07828 L
s
1 .123 0 r
.008 w
.31575 .07828 Mdot
.016 w
.31575 .07828 m
.31712 .07707 L
s
1 .119 0 r
.008 w
.31712 .07707 Mdot
.016 w
.31712 .07707 m
.31839 .07564 L
s
1 .116 0 r
.008 w
.31839 .07564 Mdot
.016 w
.31839 .07564 m
.31963 .07419 L
s
1 .113 0 r
.008 w
.31963 .07419 Mdot
.016 w
.31963 .07419 m
.32086 .07263 L
s
1 .11 0 r
.008 w
.32086 .07263 Mdot
.016 w
.32086 .07263 m
.32204 .07113 L
s
1 .106 0 r
.008 w
.32204 .07113 Mdot
.016 w
.32204 .07113 m
.32322 .06956 L
s
1 .103 0 r
.008 w
.32322 .06956 Mdot
.016 w
.32322 .06956 m
.32441 .06807 L
s
1 .1 0 r
.008 w
.32441 .06807 Mdot
.016 w
.32441 .06807 m
.32557 .06666 L
s
1 .097 0 r
.008 w
.32557 .06666 Mdot
.016 w
.32557 .06666 m
.3268 .06521 L
s
1 .094 0 r
.008 w
.3268 .06521 Mdot
.016 w
.3268 .06521 m
.32809 .06399 L
s
1 .09 0 r
.008 w
.32809 .06399 Mdot
.016 w
.32809 .06399 m
.32955 .06281 L
s
1 .087 0 r
.008 w
.32955 .06281 Mdot
.016 w
.32955 .06281 m
.33115 .06165 L
s
1 .084 0 r
.008 w
.33115 .06165 Mdot
.016 w
.33115 .06165 m
.33301 .06051 L
s
1 .081 0 r
.008 w
.33301 .06051 Mdot
.016 w
.33301 .06051 m
.33497 .05944 L
s
1 .077 0 r
.008 w
.33497 .05944 Mdot
.016 w
.33497 .05944 m
.33703 .05833 L
s
1 .074 0 r
.008 w
.33703 .05833 Mdot
.016 w
.33703 .05833 m
.33929 .05727 L
s
1 .071 0 r
.008 w
.33929 .05727 Mdot
.016 w
.33929 .05727 m
.34171 .0562 L
s
1 .068 0 r
.008 w
.34171 .0562 Mdot
.016 w
.34171 .0562 m
.34402 .05513 L
s
1 .065 0 r
.008 w
.34402 .05513 Mdot
.016 w
.34402 .05513 m
.34627 .05407 L
s
1 .061 0 r
.008 w
.34627 .05407 Mdot
.016 w
.34627 .05407 m
.34837 .05309 L
s
1 .058 0 r
.008 w
.34837 .05309 Mdot
.016 w
.34837 .05309 m
.35013 .05219 L
s
1 .055 0 r
.008 w
.35013 .05219 Mdot
.016 w
.35013 .05219 m
.35198 .05139 L
s
1 .052 0 r
.008 w
.35198 .05139 Mdot
.016 w
.35198 .05139 m
.35372 .05075 L
s
1 .048 0 r
.008 w
.35372 .05075 Mdot
.016 w
.35372 .05075 m
.35535 .0503 L
s
1 .045 0 r
.008 w
.35535 .0503 Mdot
.016 w
.35535 .0503 m
.357 .05004 L
s
1 .042 0 r
.008 w
.357 .05004 Mdot
.016 w
.357 .05004 m
.35864 .04994 L
s
1 .039 0 r
.008 w
.35864 .04994 Mdot
.016 w
.35864 .04994 m
.36036 .04999 L
s
1 .035 0 r
.008 w
.36036 .04999 Mdot
.016 w
.36036 .04999 m
.3621 .05014 L
s
1 .032 0 r
.008 w
.3621 .05014 Mdot
.016 w
.3621 .05014 m
.36373 .05038 L
s
1 .029 0 r
.008 w
.36373 .05038 Mdot
.016 w
.36373 .05038 m
.36507 .05067 L
s
1 .026 0 r
.008 w
.36507 .05067 Mdot
.016 w
.36507 .05067 m
.36639 .05101 L
s
1 .023 0 r
.008 w
.36639 .05101 Mdot
.016 w
.36639 .05101 m
.36752 .05134 L
s
1 .019 0 r
.008 w
.36752 .05134 Mdot
.016 w
.36752 .05134 m
.36866 .05165 L
s
1 .016 0 r
.008 w
.36866 .05165 Mdot
.016 w
.36866 .05165 m
.3698 .05191 L
s
1 .013 0 r
.008 w
.3698 .05191 Mdot
.016 w
.3698 .05191 m
.37083 .05211 L
s
1 .01 0 r
.008 w
.37083 .05211 Mdot
.016 w
.37083 .05211 m
.37162 .05225 L
s
1 .006 0 r
.008 w
.37162 .05225 Mdot
.016 w
.37162 .05225 m
.37213 .05233 L
s
1 .003 0 r
.008 w
.37213 .05233 Mdot
.016 w
.37213 .05233 m
.3724 .05237 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001aOol5000cOol5001bOol006eoo`@003eoo`@006io
o`00IWoo0W`P00=oo`0000000P00AGoo1000JWoo001TOol017a0O21l87`P17`0BWoo0`00Igoo001R
Ool00ga0O21l8003O206O01;Ool3001TOol0061oo`=l@0El80Il04ioo`<0065oo`00GWoo00<007a0
O4000Wa01G`P1W`0DGoo0P00Ggoo001LOol00`00O61l@004O405O206O01COol2001MOol005Yoo`80
0003OomlH7a000Ml@5eoo`8005]oo`00F7oo0P000Woo0gaP1Ga0HGoo0P00FGoo001EOol30003Ool5
O6000ga0O61oo`1TOol3001FOol005=oo`8000Aoo`03O81lH7aP00ElH6Uoo`8005Aoo`00DGoo0P00
17oo00=lX7b0O8001GaPKGoo0P00DWoo001@Ool00`00Oomoo`02Ool00gbPO81lP002O805O61_Ool0
0`00Oomoo`1?Ool004moo`03001oogoo009oo`9lX0AlP0ElH71oo`03001oogoo04ioo`00CGoo0P00
0goo00Al`7bPO:1lX0QlP79oo`8004ioo`00Bgoo0P001Goo00Al`7bPO:1lX0ElP7Moo`8004aoo`00
BGoo0P0017oo0Wd000=lh7c0O<001GbPNgoo0P00BWoo0018Ool00`00Oomoo`02Ool2OB02O@001WcP
O<1l`7c0O:1l`7moo`03001oogoo04Moo`00AWoo0P000Woo0WfP00=m@7dPOB000Wd000=lh7c0O<00
0Wc0PGoo0P00Agoo0015Ool02000OomoogooOL1mX7f0OD02OB02O@05O>23Ool00`00Oomoo`14Ool0
04Aoo`04001oogooOol2OL000gfPOH1m@002OB04O@27Ool00`00Oomoo`13Ool004=oo`04001oogoo
Ool3OL000gfPOH1m@004OD2:Ool00`00Oomoo`12Ool0045oo`8000=oo`06ON1m`7g0OL1mX7f017eP
S7oo0P00@Woo0010Ool00`00Oomoo`03Ool00ggPOL1m`004OL2AOol00`00Oomoo`0oOol003moo`03
001oogoo009oo`=mh0Em`9=oo`8003moo`00?Woo00<007ooOol00Woo17gP17g0UWoo00<007ooOol0
?7oo000lOol200000gooOT1n@002Ool7ON2HOol00`00Oomoo`0kOol003]oo`03001oogoo00=n8003
OP1mh7gP00Emh9Yoo`03001oogoo03Yoo`00>Woo00@007ooOT1n@0=n8003OP1mh7gP00Amh9aoo`80
03Yoo`00>Goo00<007ooOol00Wi00ghP0Wh017gPWgoo00<007ooOol0=goo000gOol20002Ool00giP
OT1n@003OR03OP000ggPOP1oo`2POol00`00Oomoo`0fOol003Ioo`03001oogoo009oo`03OV1n@7i0
00=n@:Moo`03001oogoo03Eoo`00=Goo00<007ooOol00Woo1WiPZGoo00<007ooOol0=7oo000dOol0
0`00Oomoo`03Ool5OV2[Ool00`00Oomoo`0cOol0039oo`8000Eoo`InH:aoo`03001oogoo039oo`00
<Goo00<007ooOol017oo00=nP7iPOV000giP[Woo00<007ooOol0<Goo000`Ool00`00Oomoo`05Ool2
OX04OV2_Ool00`00Oomoo`0`Ool0031oo`03001oogoo00=oo`03O/1nX7j0009nP003OV1nP7oo0;1o
o`03001oogoo02moo`00;goo00<007ooOol00goo0Wk000=nX7j0OX000gj0/Woo00<007ooOol0;Woo
000^Ool00`00Oomoo`03Ool4O/04OX2dOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`En`003
OZ1n`7oo0;Eoo`03001oogoo02aoo`00;7oo00<007ooOol017oo1gk0^7oo00<007ooOol0:goo000/
Ool00`00Oomoo`03Ool00gkPO/1n`004O/2iOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`9n
h0An`;]oo`03001oogoo02Yoo`00:Woo00<007ooOol017oo17kP00=n`7kPOol0_7oo00<007ooOol0
:Goo000YOol00`00Oomoo`05Ool5O^2oOol00`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Inh<1o
o`03001oogoo02Moo`00:7oo00<007ooOol01Goo1GkP`Goo00<007ooOol09goo000WOol00`00Oomo
o`06Ool5O^32Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Ioo`03?Nmnh7kP00=nh003?Nmoogoo
0<1oo`03001oogoo02Eoo`009Goo00<007ooOol01Woo00<mkgl0O`0017l000<mkgooOol0`Goo00<0
07ooOol097oo000TOol00`00Oomoo`06Ool2?Nl5O`000cg_Oomoo`33Ool00`00Oomoo`0SOol002Ao
o`03001oogoo00Eoo`8mk`03Ob1o07l000=o0<Ioo`03001oogoo02=oo`008goo00<007ooOol01Woo
00<mkglPOb0017l0b7oo00<007ooOol08Woo000ROol00`00Oomoo`06Ool013g_Od1o87lP17l0bGoo
00<007ooOol08Goo000ROol00`00Oomoo`05Ool2?Nl00gm0Ob1o8004Ob39Ool00`00Oomoo`0QOol0
025oo`03001oogoo00Ioo`03?Nmo@7m000Eo8<]oo`03001oogoo021oo`0087oo00<007ooOol01Woo
00@mkgm0Od1o@0Ao8<eoo`03001oogoo01moo`0087oo00<007ooOol01Goo00<mkgm0Od001Gm0cWoo
00<007ooOol07goo000OOol00`00Oomoo`06Ool00cg_Od1o@003Od3AOol00`00Oomoo`0NOol001mo
o`03001oogoo00Ioo`03Of1o@7m000=o@=9oo`03001oogoo01eoo`007Woo00<007ooOol01Woo00<m
kgmPOd0017m0dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool00cg_Of1oH003Of000cg_Oomo
o`3AOol00`00Oomoo`0LOol001eoo`03001oogoo00Ioo`8mk`EoH003?Nmoogoo0=5oo`03001oogoo
01aoo`0077oo00<007ooOol01Woo0Sg_00=oP7mPOf000WmP00=oP7ooOol0dgoo00<007ooOol06goo
000LOol00`00Oomoo`05Ool3?Nl00gn0Of1oH002Of000cg_Oomoo`3COol00`00Oomoo`0KOol001]o
o`03001oogoo00Ioo`8mk`9oP0AoH003?Nmoogoo0=Aoo`03001oogoo01Yoo`006goo00<007ooOol0
1Goo0Sg_00=oX7n0Oh000gn000<mkgooOol0eGoo00<007ooOol06Woo000JOol00`00Oomoo`06Ool0
0cg_Oj1oX005Oh000cg_Oomoo`3FOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`=oX0EoP=Uo
o`03001oogoo01Uoo`006Goo00<007ooOol01Woo00Ao`7nPOj1oX0AoP=]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Woo00=o`7nPOj0017nPg7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool0
0cg_Ol1o`005Oj3NOol00`00Oomoo`0GOol001Qoo`03001oogoo00Eoo`03?Nmo`7o000AoX=moo`03
001oogoo01Moo`0067oo00<007ooOol017oo0cg_17o000<mkgooOol0gGoo00<007ooOol05goo000G
Ool00`00Oomoo`05Ool4?Nl017o0?Nlmkcg_h7oo00<007ooOol05Woo000GOol00`00Oomoo`04Ool8
?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<0
07ooOol01Goo1Sg_i7oo00<007ooOol05Goo000EOol00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0D
Ool001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo
00<007ooOol057oo000DOol00`00Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo
00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Goo1cg_igoo00<007ooOol04goo000C
Ool00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001o
ogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000BOol00`00Oomoo`07Ool5
?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<0
07ooOol01Woo1Cg_k7oo00<007ooOol04Goo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@
Ool0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo
00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo
00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@
Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001o
ogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7
?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<0
07ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>
Ool000ioo`03001oogoo00Yoo`Pmkneoo`03001oogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo
00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool:?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo
00eoo`/mknMoo`03001oogoo00eoo`003Woo00<007ooOol03Goo33g_igoo00<007ooOol037oo000=
Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001o
ogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>
?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`dmknMoo`03001oogoo00aoo`003Goo00<0
07ooOol037oo23g_00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3
Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo
00<007ooOol027oo3cg_jWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Qooa4mknQoo`03001oogoo00aoo`0037oo00<007ooOol027oo4cg_
j7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000ao
o`03001oogoo00IooaLmknIoo`03001oogoo00]oo`0037oo00<007ooOol01Goo63g_iWoo00<007oo
Ool02goo000<Ool00`00Oomoo`08OolE?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
k`03Oolmkcg_00`mknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol06Goo1Sg_i7oo00<007oo
Ool02goo000<Ool00`00Oomoo`0HOol7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tm
kn9oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000<Ool00`00
Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eoo`03001oogoo01Moo`/mkn1oo`03001oogoo00]o
o`003Goo00<007ooOol06goo1cg_ggoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol0
6goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eo
o`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007oo
Ool037oo000=Ool00`00Oomoo`0LOol9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/m
kmYoo`03001oogoo00aoo`003Goo00<007ooOol07Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00
Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo01ioo`PmkmUoo`03001oogoo00eo
o`003Woo00<007ooOol07Woo1Cg_g7oo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol0
3Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00io
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@
Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03
001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol00`00
Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<007oo
Ool0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001oogoo
0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomoo`3d
Ool00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo
00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03
001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007oo
Ool05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo
01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0G
Ool001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo
000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`00
6goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001ao
o`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol0
0`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo00<0
07ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03001o
ogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00Oomo
o`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007ooOol0
fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo0=Eo
o`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3COol0
0`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo00<0
07ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03001o
ogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00Oomo
o`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0
:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]o
o`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool0
02ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`
Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo
0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03
001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00
Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007oo
Ool0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<0
07ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009mo
o`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=oo`03
001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool00`00
Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool2
0027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?
Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo
001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3001S
Ool3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3
001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0071o
o`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eoo`h0
081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002;Ool20003
Ool4002<Ool008Yoo`04001oogoo0002Ool00`00Oomoo`2=Ool008aoo`03001oogoo009oo`03001o
ogoo08aoo`00SGoo00<007ooOol00Woo00<007ooOol0Rgoo002:Ool01000Oomoo`000Woo00@007oo
Ool008aoo`00Rgoo0P0017oo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(33)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
1 .972 0 r
.008 w
.37152 .05234 Mdot
.016 w
.37152 .05234 m
.37174 .05226 L
s
1 .944 0 r
.008 w
.37174 .05226 Mdot
.016 w
.37174 .05226 m
.37215 .0521 L
s
1 .917 0 r
.008 w
.37215 .0521 Mdot
.016 w
.37215 .0521 m
.37273 .05183 L
s
1 .889 0 r
.008 w
.37273 .05183 Mdot
.016 w
.37273 .05183 m
.37349 .05141 L
s
1 .861 0 r
.008 w
.37349 .05141 Mdot
.016 w
.37349 .05141 m
.37441 .05086 L
s
1 .833 0 r
.008 w
.37441 .05086 Mdot
.016 w
.37441 .05086 m
.37547 .05018 L
s
1 .806 0 r
.008 w
.37547 .05018 Mdot
.016 w
.37547 .05018 m
.37653 .04937 L
s
1 .778 0 r
.008 w
.37653 .04937 Mdot
.016 w
.37653 .04937 m
.37768 .04848 L
s
1 .75 0 r
.008 w
.37768 .04848 Mdot
.016 w
.37768 .04848 m
.37893 .04752 L
s
1 .722 0 r
.008 w
.37893 .04752 Mdot
.016 w
.37893 .04752 m
.38029 .04662 L
s
1 .694 0 r
.008 w
.38029 .04662 Mdot
.016 w
.38029 .04662 m
.38158 .04565 L
s
1 .667 0 r
.008 w
.38158 .04565 Mdot
.016 w
.38158 .04565 m
.3829 .04463 L
s
1 .639 0 r
.008 w
.3829 .04463 Mdot
.016 w
.3829 .04463 m
.38423 .04373 L
s
1 .611 0 r
.008 w
.38423 .04373 Mdot
.016 w
.38423 .04373 m
.38549 .04287 L
s
1 .583 0 r
.008 w
.38549 .04287 Mdot
.016 w
.38549 .04287 m
.38673 .04209 L
s
1 .556 0 r
.008 w
.38673 .04209 Mdot
.016 w
.38673 .04209 m
.38794 .04141 L
s
1 .528 0 r
.008 w
.38794 .04141 Mdot
.016 w
.38794 .04141 m
.38922 .04085 L
s
1 .5 0 r
.008 w
.38922 .04085 Mdot
.016 w
.38922 .04085 m
.39063 .04041 L
s
1 .472 0 r
.008 w
.39063 .04041 Mdot
.016 w
.39063 .04041 m
.39215 .0401 L
s
1 .444 0 r
.008 w
.39215 .0401 Mdot
.016 w
.39215 .0401 m
.39379 .0399 L
s
1 .417 0 r
.008 w
.39379 .0399 Mdot
.016 w
.39379 .0399 m
.39563 .03978 L
s
1 .389 0 r
.008 w
.39563 .03978 Mdot
.016 w
.39563 .03978 m
.39765 .03971 L
s
1 .361 0 r
.008 w
.39765 .03971 Mdot
.016 w
.39765 .03971 m
.39964 .03966 L
s
1 .333 0 r
.008 w
.39964 .03966 Mdot
.016 w
.39964 .03966 m
.40168 .03963 L
s
1 .306 0 r
.008 w
.40168 .03963 Mdot
.016 w
.40168 .03963 m
.40377 .03962 L
s
1 .278 0 r
.008 w
.40377 .03962 Mdot
.016 w
.40377 .03962 m
.40572 .03963 L
s
1 .25 0 r
.008 w
.40572 .03963 Mdot
.016 w
.40572 .03963 m
.40759 .03968 L
s
1 .222 0 r
.008 w
.40759 .03968 Mdot
.016 w
.40759 .03968 m
.40932 .03974 L
s
1 .194 0 r
.008 w
.40932 .03974 Mdot
.016 w
.40932 .03974 m
.41083 .03983 L
s
1 .167 0 r
.008 w
.41083 .03983 Mdot
.016 w
.41083 .03983 m
.41223 .03992 L
s
1 .139 0 r
.008 w
.41223 .03992 Mdot
.016 w
.41223 .03992 m
.41344 .04001 L
s
1 .111 0 r
.008 w
.41344 .04001 Mdot
.016 w
.41344 .04001 m
.41439 .04007 L
s
1 .083 0 r
.008 w
.41439 .04007 Mdot
.016 w
.41439 .04007 m
.41502 .04012 L
s
1 .056 0 r
.008 w
.41502 .04012 Mdot
.016 w
.41502 .04012 m
.41534 .04016 L
s
1 .028 0 r
.008 w
.41534 .04016 Mdot
.016 w
.41534 .04016 m
.41535 .04018 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00LGoo0Wg00goo1@00:7oo1P00Mgoo001_Ool01WiPOH1m@7dPO>1l`09lH09l031o
o`D0079oo`00KGoo00T007h0OL1mP7e0OB1lh7c0O40017`0=7oo1000KWoo001YOol300002WjPOV1n
07g0OH1m@7dPO>1l`7a017`0>7oo1000JWoo001UOol6?Nl00gkPOZ1nH002OP001Gf0OD1m87cPO<00
0Wa00W`000=l@7ooOol0>Woo0`00Igoo001SOol7?Nl017mPO^1nX7jP0gh000Am`7h0Oomoo`El@3mo
o`<006Aoo`00H7oo00<003g_?Nl01cg_00=oH7kPOZ000WjP00=nH7jPOol0BWoo0`00HGoo001NOol0
0`00?Nlmk`0:?Nl5O^1?Ool2001OOol005aoo`03000mkcg_00Pmk`03Oolmkcg_008mk`03Of0mkgoo
059oo`8005eoo`00FWoo0P0000=oocg_?Nl01Sg_GWoo0P00Fgoo001HOol20002Ool7?NmROol2001I
Ool005Eoo`<000=oo`HmkfIoo`<005Ioo`00Dgoo0P001Goo1Sg_JWoo0P00E7oo001AOol20005Ool7
?Nm]Ool2001BOol0051oo`03001oogoo00=oo`Tmkfmoo`03001oogoo04moo`00Cgoo00<007ooOol0
0Woo2cg_L7oo00<007ooOol0CWoo001=Ool20003Ool<?NmbOol2001>Ool004]oo`8000Eoo`PmkgQo
o`8004aoo`00BGoo0P0017oo2Cg_O7oo0P00BWoo0018Ool00`00Oomoo`02Ool:?NmoOol00`00Oomo
o`17Ool004Ioo`8000Aoo`Xmkh5oo`8004Moo`00AGoo00@007ooOomoo`dmkh=oo`03001oogoo04Ao
o`00A7oo00@007ooOomoo`/mkhMoo`03001oogoo04=oo`00@goo00@007ooOomoo`XmkhYoo`03001o
ogoo049oo`00@Goo0P000goo2Sg_S7oo0P00@Woo0010Ool00`00Oomoo`03Ool7?NnAOol00`00Oomo
o`0oOol003moo`03001oogoo009oo`Pmki=oo`8003moo`00?Woo00<007ooOol00Woo23g_UWoo00<0
07ooOol0?7oo000lOol20005Ool6?NnIOol00`00Oomoo`0kOol003]oo`03001oogoo00Xmki]oo`03
001oogoo03Yoo`00>Woo00<007oo?Nl02cg_W7oo0P00>Woo000iOol00`00Oomoo`0:?NnPOol00`00
Oomoo`0gOol003Moo`80009oo`/mkj5oo`03001oogoo03Ioo`00=Woo00<007ooOol00Woo1Cg_Z7oo
00<007ooOol0=Goo000eOol00`00Oomoo`02Ool5?NnZOol00`00Oomoo`0dOol003Aoo`03001oogoo
00=oo`Dmkj]oo`03001oogoo03=oo`00<Woo0P001Goo1Cg_[Goo00<007ooOol0<Woo000aOol00`00
Oomoo`04Ool6?Nn^Ool00`00Oomoo`0aOol0031oo`03001oogoo00Eoo`Dmkk1oo`03001oogoo031o
o`00<7oo00<007ooOol00goo1cg_/Goo00<007ooOol0;goo000_Ool00`00Oomoo`03Ool8?NnbOol0
0`00Oomoo`0^Ool002ioo`03001oogoo00=oo`PmkkAoo`03001oogoo02eoo`00;Goo00<007ooOol0
17oo1Sg_]goo00<007ooOol0;7oo000/Ool00`00Oomoo`04Ool7?NnhOol00`00Oomoo`0[Ool002ao
o`03001oogoo00=oo`LmkkUoo`03001oogoo02]oo`00:goo00<007ooOol017oo1Cg__7oo00<007oo
Ool0:Woo000ZOol00`00Oomoo`04Ool5?NnnOol00`00Oomoo`0YOol002Uoo`03001oogoo00Eoo`Dm
kkmoo`03001oogoo02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00
Oomoo`05Ool5?No1Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Io
o`009Woo00<007ooOol01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool0
0`00Oomoo`0TOol002Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol0
1Goo23g_aWoo00<007ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029o
o`03001oogoo00Ioo`PmklUoo`03001oogoo025oo`008Woo00<007ooOol01Goo2Cg_bGoo00<007oo
Ool08Goo000QOol00`00Oomoo`06Ool8?No;Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Pm
kleoo`03001oogoo01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00
Oomoo`06Ool6?NoAOol00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eo
o`007Woo00<007ooOol01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol0
0`00Oomoo`0LOol001eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol0
1Woo23g_eGoo00<007ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]o
o`03001oogoo00Ioo`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007oo
Ool06Woo000JOol00`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`Pm
kmUoo`03001oogoo01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00
Oomoo`06Ool7?NoLOol00`00Oomoo`0HOol001Qoo`03001oogoo00Eoo`Pmkmioo`03001oogoo01Mo
o`0067oo00<007ooOol01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol0
0`00Oomoo`0GOol001Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol0
17oo23g_hGoo00<007ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Io
o`03001oogoo00Eoo`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007oo
Ool057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`Lm
knEoo`03001oogoo01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00
Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=o
o`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol0
0`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol0
1goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019o
o`03001oogoo00Ioo`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007oo
Ool047oo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hm
knaoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00mo
o`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol0
2Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007oo
Ool03Woo000>Ool00`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``m
knUoo`03001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00
Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00ao
o`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eo
o`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo
1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qoo`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<0
07ooOol037oo000=Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qo
oa<mknQoo`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo
000<Ool00`00Oomoo`06OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03
001oogoo00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08
Ool6?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03
001oogoo00]oo`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0H
Ool9?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo
00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomo
o`0;Ool000eoo`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_
gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool;?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo
00<007ooOol07Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomo
o`0=Ool000ioo`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<0
07ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001o
ogoo00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomo
o`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol0
3Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00mo
o`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0
011oo`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000A
Ool00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo
00<007ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03
001oogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00
Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007oo
Ool0m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo
0?=oo`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3a
Ool00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo
00<007ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03
001oogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00
Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007oo
Ool05goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo
01Qoo`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0I
Ool001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo
000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`00
7Goo00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001io
o`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol0
0`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001o
ogoo0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomo
o`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0
dgoo00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<mo
o`03001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool0
0`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<0
07ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001o
ogoo02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomo
o`0[Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0
;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02io
o`00<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0
039oo`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2a
Ool00`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo
00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03
001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003ao
o`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2
002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013
Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo
00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00
BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eo
o`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`80
05=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo
0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00
EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo
001`Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005
Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo
0P0017oo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00S7oo00<007ooOol00goo
00<007ooOol0Rgoo002=Ool00`00Oomoo`03Ool00`00Oomoo`2:Ool008Yoo`04001oogoo0002Ool0
1000Oomoo`00S7oo002;Ool20004Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(34)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
1 .987 0 r
.008 w
.40831 .03963 Mdot
.016 w
.40831 .03963 m
.40845 .03975 L
s
1 .975 0 r
.008 w
.40845 .03975 Mdot
.016 w
.40845 .03975 m
.40868 .04001 L
s
1 .962 0 r
.008 w
.40868 .04001 Mdot
.016 w
.40868 .04001 m
.40899 .04043 L
s
1 .949 0 r
.008 w
.40899 .04043 Mdot
.016 w
.40899 .04043 m
.40936 .04101 L
s
1 .937 0 r
.008 w
.40936 .04101 Mdot
.016 w
.40936 .04101 m
.40979 .04174 L
s
1 .924 0 r
.008 w
.40979 .04174 Mdot
.016 w
.40979 .04174 m
.41025 .04263 L
s
1 .911 0 r
.008 w
.41025 .04263 Mdot
.016 w
.41025 .04263 m
.41071 .04357 L
s
1 .899 0 r
.008 w
.41071 .04357 Mdot
.016 w
.41071 .04357 m
.41119 .04465 L
s
1 .886 0 r
.008 w
.41119 .04465 Mdot
.016 w
.41119 .04465 m
.41167 .04572 L
s
1 .873 0 r
.008 w
.41167 .04572 Mdot
.016 w
.41167 .04572 m
.41214 .04681 L
s
1 .861 0 r
.008 w
.41214 .04681 Mdot
.016 w
.41214 .04681 m
.41257 .04784 L
s
1 .848 0 r
.008 w
.41257 .04784 Mdot
.016 w
.41257 .04784 m
.41293 .04872 L
s
1 .835 0 r
.008 w
.41293 .04872 Mdot
.016 w
.41293 .04872 m
.4132 .04932 L
s
1 .823 0 r
.008 w
.4132 .04932 Mdot
.016 w
.4132 .04932 m
.41335 .04968 L
s
1 .81 0 r
.008 w
.41335 .04968 Mdot
.016 w
.41335 .04968 m
.41338 .04979 L
s
1 .797 0 r
.008 w
.41338 .04979 Mdot
.016 w
.41338 .04979 m
.41329 .04965 L
s
1 .785 0 r
.008 w
.41329 .04965 Mdot
.016 w
.41329 .04965 m
.41312 .04925 L
s
1 .772 0 r
.008 w
.41312 .04925 Mdot
.016 w
.41312 .04925 m
.41291 .04862 L
s
1 .759 0 r
.008 w
.41291 .04862 Mdot
.016 w
.41291 .04862 m
.4127 .0479 L
s
1 .747 0 r
.008 w
.4127 .0479 Mdot
.016 w
.4127 .0479 m
.41252 .04704 L
s
1 .734 0 r
.008 w
.41252 .04704 Mdot
.016 w
.41252 .04704 m
.41237 .04616 L
s
1 .722 0 r
.008 w
.41237 .04616 Mdot
.016 w
.41237 .04616 m
.41223 .04526 L
s
1 .709 0 r
.008 w
.41223 .04526 Mdot
.016 w
.41223 .04526 m
.41207 .04447 L
s
1 .696 0 r
.008 w
.41207 .04447 Mdot
.016 w
.41207 .04447 m
.41187 .04371 L
s
1 .684 0 r
.008 w
.41187 .04371 Mdot
.016 w
.41187 .04371 m
.4116 .04304 L
s
1 .671 0 r
.008 w
.4116 .04304 Mdot
.016 w
.4116 .04304 m
.41123 .0425 L
s
1 .658 0 r
.008 w
.41123 .0425 Mdot
.016 w
.41123 .0425 m
.41073 .04208 L
s
1 .646 0 r
.008 w
.41073 .04208 Mdot
.016 w
.41073 .04208 m
.41009 .0418 L
s
1 .633 0 r
.008 w
.41009 .0418 Mdot
.016 w
.41009 .0418 m
.4093 .04166 L
s
1 .62 0 r
.008 w
.4093 .04166 Mdot
.016 w
.4093 .04166 m
.40827 .04163 L
s
1 .608 0 r
.008 w
.40827 .04163 Mdot
.016 w
.40827 .04163 m
.40705 .04165 L
s
1 .595 0 r
.008 w
.40705 .04165 Mdot
.016 w
.40705 .04165 m
.40557 .04167 L
s
1 .582 0 r
.008 w
.40557 .04167 Mdot
.016 w
.40557 .04167 m
.40385 .04167 L
s
1 .57 0 r
.008 w
.40385 .04167 Mdot
.016 w
.40385 .04167 m
.40185 .04162 L
s
1 .557 0 r
.008 w
.40185 .04162 Mdot
.016 w
.40185 .04162 m
.39968 .04151 L
s
1 .544 0 r
.008 w
.39968 .04151 Mdot
.016 w
.39968 .04151 m
.39749 .04134 L
s
1 .532 0 r
.008 w
.39749 .04134 Mdot
.016 w
.39749 .04134 m
.39513 .04114 L
s
1 .519 0 r
.008 w
.39513 .04114 Mdot
.016 w
.39513 .04114 m
.39288 .04093 L
s
1 .506 0 r
.008 w
.39288 .04093 Mdot
.016 w
.39288 .04093 m
.39078 .04071 L
s
1 .494 0 r
.008 w
.39078 .04071 Mdot
.016 w
.39078 .04071 m
.38872 .04049 L
s
1 .481 0 r
.008 w
.38872 .04049 Mdot
.016 w
.38872 .04049 m
.38671 .04027 L
s
1 .468 0 r
.008 w
.38671 .04027 Mdot
.016 w
.38671 .04027 m
.38508 .04005 L
s
1 .456 0 r
.008 w
.38508 .04005 Mdot
.016 w
.38508 .04005 m
.38356 .03981 L
s
1 .443 0 r
.008 w
.38356 .03981 Mdot
.016 w
.38356 .03981 m
.38216 .03956 L
s
1 .43 0 r
.008 w
.38216 .03956 Mdot
.016 w
.38216 .03956 m
.38084 .0393 L
s
1 .418 0 r
.008 w
.38084 .0393 Mdot
.016 w
.38084 .0393 m
.3796 .03905 L
s
1 .405 0 r
.008 w
.3796 .03905 Mdot
.016 w
.3796 .03905 m
.37838 .03883 L
s
1 .392 0 r
.008 w
.37838 .03883 Mdot
.016 w
.37838 .03883 m
.37719 .03866 L
s
1 .38 0 r
.008 w
.37719 .03866 Mdot
.016 w
.37719 .03866 m
.37599 .03857 L
s
1 .367 0 r
.008 w
.37599 .03857 Mdot
.016 w
.37599 .03857 m
.37468 .03856 L
s
1 .354 0 r
.008 w
.37468 .03856 Mdot
.016 w
.37468 .03856 m
.37324 .03866 L
s
1 .342 0 r
.008 w
.37324 .03866 Mdot
.016 w
.37324 .03866 m
.37181 .03889 L
s
1 .329 0 r
.008 w
.37181 .03889 Mdot
.016 w
.37181 .03889 m
.37028 .03924 L
s
1 .316 0 r
.008 w
.37028 .03924 Mdot
.016 w
.37028 .03924 m
.36857 .03968 L
s
1 .304 0 r
.008 w
.36857 .03968 Mdot
.016 w
.36857 .03968 m
.36675 .04021 L
s
1 .291 0 r
.008 w
.36675 .04021 Mdot
.016 w
.36675 .04021 m
.36496 .04081 L
s
1 .278 0 r
.008 w
.36496 .04081 Mdot
.016 w
.36496 .04081 m
.36339 .04151 L
s
1 .266 0 r
.008 w
.36339 .04151 Mdot
.016 w
.36339 .04151 m
.36187 .04229 L
s
1 .253 0 r
.008 w
.36187 .04229 Mdot
.016 w
.36187 .04229 m
.36043 .0431 L
s
1 .241 0 r
.008 w
.36043 .0431 Mdot
.016 w
.36043 .0431 m
.35912 .04384 L
s
1 .228 0 r
.008 w
.35912 .04384 Mdot
.016 w
.35912 .04384 m
.35797 .04456 L
s
1 .215 0 r
.008 w
.35797 .04456 Mdot
.016 w
.35797 .04456 m
.35701 .04538 L
s
1 .203 0 r
.008 w
.35701 .04538 Mdot
.016 w
.35701 .04538 m
.3562 .04612 L
s
1 .19 0 r
.008 w
.3562 .04612 Mdot
.016 w
.3562 .04612 m
.35548 .04686 L
s
1 .177 0 r
.008 w
.35548 .04686 Mdot
.016 w
.35548 .04686 m
.35481 .04764 L
s
1 .165 0 r
.008 w
.35481 .04764 Mdot
.016 w
.35481 .04764 m
.35418 .04836 L
s
1 .152 0 r
.008 w
.35418 .04836 Mdot
.016 w
.35418 .04836 m
.35358 .04914 L
s
1 .139 0 r
.008 w
.35358 .04914 Mdot
.016 w
.35358 .04914 m
.35297 .04994 L
s
1 .127 0 r
.008 w
.35297 .04994 Mdot
.016 w
.35297 .04994 m
.35235 .05077 L
s
1 .114 0 r
.008 w
.35235 .05077 Mdot
.016 w
.35235 .05077 m
.35175 .05162 L
s
1 .101 0 r
.008 w
.35175 .05162 Mdot
.016 w
.35175 .05162 m
.3512 .05246 L
s
1 .089 0 r
.008 w
.3512 .05246 Mdot
.016 w
.3512 .05246 m
.35073 .05324 L
s
1 .076 0 r
.008 w
.35073 .05324 Mdot
.016 w
.35073 .05324 m
.35029 .05396 L
s
1 .063 0 r
.008 w
.35029 .05396 Mdot
.016 w
.35029 .05396 m
.34987 .05465 L
s
1 .051 0 r
.008 w
.34987 .05465 Mdot
.016 w
.34987 .05465 m
.34946 .05527 L
s
1 .038 0 r
.008 w
.34946 .05527 Mdot
.016 w
.34946 .05527 m
.34912 .05575 L
s
1 .025 0 r
.008 w
.34912 .05575 Mdot
.016 w
.34912 .05575 m
.34886 .05611 L
s
1 .013 0 r
.008 w
.34886 .05611 Mdot
.016 w
.34886 .05611 m
.34868 .05632 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00JWoo0WdP0goo00=m`7ooOol017oo1@00:7oo1P00Mgoo001XOol2O>03OB0017e0
OF1mP7fP0cg_0Wo000=oP7o0?Nl0<7oo1@00LWoo001WOol4O>002Gd0OB1m87ePOH1mX7g0ON1n0002
OR0017i0OV1nX3g_=7oo1000KWoo001UOol4O:0027c0O>1lh7dPOD1mH7f0OJ02OL001gh0OR1n87i0
OV1nX3g_03Qoo`@006Yoo`00I7oo17aP00AlP7c0O>1m009m@006OF1mP7fPOL1mh7h00WhP00An@7iP
OZ1oP3aoo`<006Moo`00Hgoo00<mkga0O4000Wa000AlP7c0O@1m008mk`03ON1m`7g0009mh007OP1n
87hPOT1nH7jPOb00?goo0`00I7oo001POol00`00?Nlmk`05O0000gb0O<0mk`05?Nl5Ool4OZ000glP
Oomoo`10Ool3001QOol005ioo`03000mkcg_008mk`El0003O80mkcg_00Dmk`Eoo`Anh4Ioo`8005mo
o`00G7oo00<003g_?Nl013g_1G`01Sg_Dgoo0P00GGoo001JOol200000goo?Nlmk`04?Nl5O01KOol2
001KOol005Qoo`80009oo`Lmkf9oo`8005Uoo`00EGoo0`000goo1Sg_IWoo0`00EWoo001COol20005
Ool6?NmZOol2001DOol0055oo`8000Eoo`Lmkfeoo`80059oo`00D7oo00<007ooOol00goo2Cg_Kgoo
00<007ooOol0Cgoo001?Ool00`00Oomoo`02Ool;?Nm`Ool00`00Oomoo`1>Ool004eoo`8000=oo``m
kg9oo`8004ioo`00Bgoo0P001Goo23g_N7oo0P00C7oo0019Ool20004Ool9?NmlOol2001:Ool004Qo
o`03001oogoo009oo`Xmkgmoo`03001oogoo04Moo`00AWoo0P0017oo2Sg_PGoo0P00Agoo0015Ool0
1000Oomoogoo3Cg_Pgoo00<007ooOol0A7oo0014Ool01000Oomoogoo2cg_Qgoo00<007ooOol0@goo
0013Ool01000Oomoogoo2Sg_RWoo00<007ooOol0@Woo0011Ool20003Ool:?Nn<Ool20012Ool0041o
o`03001oogoo00=oo`Lmki5oo`03001oogoo03moo`00?goo00<007ooOol00Woo23g_Tgoo0P00?goo
000nOol00`00Oomoo`02Ool8?NnFOol00`00Oomoo`0lOol003aoo`8000Eoo`HmkiUoo`03001oogoo
03]oo`00>goo00<007ooOol02Sg_Vgoo00<007ooOol0>Woo000jOol00`00Oolmk`0;?NnLOol2000j
Ool003Uoo`03001oogoo00Xmkj1oo`03001oogoo03Moo`00=goo0P000Woo2cg_XGoo00<007ooOol0
=Woo000fOol00`00Oomoo`02Ool5?NnXOol00`00Oomoo`0eOol003Eoo`03001oogoo009oo`DmkjYo
o`03001oogoo03Aoo`00=7oo00<007ooOol00goo1Cg_Zgoo00<007ooOol0<goo000bOol20005Ool5
?Nn]Ool00`00Oomoo`0bOol0035oo`03001oogoo00Aoo`Hmkjioo`03001oogoo035oo`00<7oo00<0
07ooOol01Goo1Cg_/7oo00<007ooOol0<7oo000`Ool00`00Oomoo`03Ool7?NnaOol00`00Oomoo`0_
Ool002moo`03001oogoo00=oo`Pmkk9oo`03001oogoo02ioo`00;Woo00<007ooOol00goo23g_]7oo
00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool6?NngOol00`00Oomoo`0/Ool002aoo`03001oogoo
00Aoo`LmkkQoo`03001oogoo02]oo`00;7oo00<007ooOol00goo1cg_^Goo00<007ooOol0:goo000[
Ool00`00Oomoo`04Ool5?NnlOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`Dmkkioo`03001o
ogoo02Uoo`00:Goo00<007ooOol01Goo1Cg__goo00<007ooOol0:7oo000XOol00`00Oomoo`05Ool5
?No1Ool00`00Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`009goo00<0
07ooOol01Woo1Cg_`Woo00<007ooOol09Woo000VOol00`00Oomoo`06Ool7?No2Ool00`00Oomoo`0U
Ool002Eoo`03001oogoo00Ioo`Pmkl=oo`03001oogoo02Aoo`0097oo00<007ooOol01Woo23g_aGoo
00<007ooOol08goo000TOol00`00Oomoo`05Ool8?No6Ool00`00Oomoo`0SOol002=oo`03001oogoo
00Ioo`LmklQoo`03001oogoo029oo`008Woo00<007ooOol01Woo23g_bGoo00<007ooOol08Goo000R
Ool00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0025oo`03001oogoo00Ioo`Pmkl]oo`03001o
ogoo021oo`0087oo00<007ooOol01Woo23g_cGoo00<007ooOol07goo000POol00`00Oomoo`05Ool7
?No?Ool00`00Oomoo`0OOol001moo`03001oogoo00Ioo`Hmkm5oo`03001oogoo01ioo`007goo00<0
07ooOol01Woo1Sg_dWoo00<007ooOol07Goo000NOol00`00Oomoo`06Ool7?NoBOol00`00Oomoo`0M
Ool001eoo`03001oogoo00Moo`Lmkm=oo`03001oogoo01aoo`007Goo00<007ooOol01Woo23g_dgoo
00<007ooOol077oo000LOol00`00Oomoo`06Ool8?NoEOol00`00Oomoo`0KOol001aoo`03001oogoo
00Eoo`TmkmEoo`03001oogoo01]oo`006goo00<007ooOol01Woo2Cg_eWoo00<007ooOol06Woo000K
Ool00`00Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Ioo`TmkmQoo`03001o
ogoo01Uoo`006Woo00<007ooOol01Woo23g_fGoo00<007ooOol06Goo000IOol00`00Oomoo`06Ool8
?NoKOol00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lmkmaoo`03001oogoo01Qoo`0067oo00<0
07ooOol01Goo23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`05Ool7?NoOOol00`00Oomoo`0G
Ool001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol01Goo23g_h7oo
00<007ooOol05Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo
00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<007ooOol01Goo1Sg_i7oo00<007ooOol05Goo000E
Ool00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001o
ogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00Oomoo`06Ool6
?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<0
07ooOol01Goo1cg_igoo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0B
Ool001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo
00<007ooOol04Woo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo
00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Cg_k7oo00<007ooOol04Goo000A
Ool00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03001o
ogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00Oomoo`07Ool6
?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<0
07ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo
00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo
00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?
Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Pmkneoo`03001o
ogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool:
?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo00eoo`003Woo00<0
07ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<
Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo
00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl00cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo00<007ooOol027oo3cg_jWoo00<007ooOol037oo
000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa4mknQoo`03
001oogoo00aoo`0037oo00<007ooOol027oo4cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00IooaLmknIoo`03001oogoo00]o
o`0037oo00<007ooOol01Goo63g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08OolE?NoVOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;
Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol06Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol7?NoTOol0
0`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol0
67oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eo
o`03001oogoo01Moo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_ggoo00<007oo
Ool037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pm
kmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00ao
o`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol9?NoLOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol0
7Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000io
o`03001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007oo
Ool03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo
000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol0
0`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<0
07ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001o
ogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomo
o`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0
mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=o
o`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol0
0`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<0
07ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001o
ogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomo
o`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol0
5goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Mo
o`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol0
01Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000K
Ool00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo
00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03
001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00
Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007oo
Ool0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo
0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3G
Ool00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo
00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03
001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00
Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007oo
Ool09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo
02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0Z
Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo
000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00
;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035o
o`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol0
0`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<0
07ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001o
ogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03
001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00
Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007oo
Ool0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<0
07ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008mo
o`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00
CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051o
o`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`80
05Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo
0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000
Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo
001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002;Ool20005Ool3002;Ool008Yoo`04001oogoo0005Ool00`00
Oomoo`2:Ool008aoo`04001oogooOol5002;Ool008eoo`04001oogoo0002Ool00`00Oomoo`2:Ool0
08Yoo`04001oogoo0003Ool00`00Ool0002<Ool008]oo`8000Eoo`8008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(35)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
1 .99 0 r
.008 w
.34937 .05462 Mdot
.016 w
.34937 .05462 m
.34922 .0546 L
s
1 .979 0 r
.008 w
.34922 .0546 Mdot
.016 w
.34922 .0546 m
.34895 .05457 L
s
1 .969 0 r
.008 w
.34895 .05457 Mdot
.016 w
.34895 .05457 m
.34853 .05459 L
s
1 .958 0 r
.008 w
.34853 .05459 Mdot
.016 w
.34853 .05459 m
.34796 .05467 L
s
1 .948 0 r
.008 w
.34796 .05467 Mdot
.016 w
.34796 .05467 m
.34725 .05484 L
s
1 .938 0 r
.008 w
.34725 .05484 Mdot
.016 w
.34725 .05484 m
.34643 .05505 L
s
1 .927 0 r
.008 w
.34643 .05505 Mdot
.016 w
.34643 .05505 m
.34548 .05535 L
s
1 .917 0 r
.008 w
.34548 .05535 Mdot
.016 w
.34548 .05535 m
.34445 .05572 L
s
1 .906 0 r
.008 w
.34445 .05572 Mdot
.016 w
.34445 .05572 m
.34332 .05613 L
s
1 .896 0 r
.008 w
.34332 .05613 Mdot
.016 w
.34332 .05613 m
.3422 .05654 L
s
1 .885 0 r
.008 w
.3422 .05654 Mdot
.016 w
.3422 .05654 m
.34098 .05695 L
s
1 .875 0 r
.008 w
.34098 .05695 Mdot
.016 w
.34098 .05695 m
.33965 .05736 L
s
1 .865 0 r
.008 w
.33965 .05736 Mdot
.016 w
.33965 .05736 m
.33827 .05777 L
s
1 .854 0 r
.008 w
.33827 .05777 Mdot
.016 w
.33827 .05777 m
.33688 .05821 L
s
1 .844 0 r
.008 w
.33688 .05821 Mdot
.016 w
.33688 .05821 m
.33543 .05871 L
s
1 .833 0 r
.008 w
.33543 .05871 Mdot
.016 w
.33543 .05871 m
.33399 .0593 L
s
1 .823 0 r
.008 w
.33399 .0593 Mdot
.016 w
.33399 .0593 m
.33252 .05995 L
s
1 .813 0 r
.008 w
.33252 .05995 Mdot
.016 w
.33252 .05995 m
.33098 .06067 L
s
1 .802 0 r
.008 w
.33098 .06067 Mdot
.016 w
.33098 .06067 m
.32938 .06146 L
s
1 .792 0 r
.008 w
.32938 .06146 Mdot
.016 w
.32938 .06146 m
.32786 .0623 L
s
1 .781 0 r
.008 w
.32786 .0623 Mdot
.016 w
.32786 .0623 m
.32632 .06324 L
s
1 .771 0 r
.008 w
.32632 .06324 Mdot
.016 w
.32632 .06324 m
.32467 .06422 L
s
1 .76 0 r
.008 w
.32467 .06422 Mdot
.016 w
.32467 .06422 m
.32301 .0652 L
s
1 .75 0 r
.008 w
.32301 .0652 Mdot
.016 w
.32301 .0652 m
.32146 .06621 L
s
1 .74 0 r
.008 w
.32146 .06621 Mdot
.016 w
.32146 .06621 m
.31995 .06722 L
s
1 .729 0 r
.008 w
.31995 .06722 Mdot
.016 w
.31995 .06722 m
.31854 .06819 L
s
1 .719 0 r
.008 w
.31854 .06819 Mdot
.016 w
.31854 .06819 m
.31731 .06905 L
s
1 .708 0 r
.008 w
.31731 .06905 Mdot
.016 w
.31731 .06905 m
.31616 .06981 L
s
1 .698 0 r
.008 w
.31616 .06981 Mdot
.016 w
.31616 .06981 m
.31511 .07042 L
s
1 .688 0 r
.008 w
.31511 .07042 Mdot
.016 w
.31511 .07042 m
.31417 .07087 L
s
1 .677 0 r
.008 w
.31417 .07087 Mdot
.016 w
.31417 .07087 m
.3134 .07116 L
s
1 .667 0 r
.008 w
.3134 .07116 Mdot
.016 w
.3134 .07116 m
.31274 .07132 L
s
1 .656 0 r
.008 w
.31274 .07132 Mdot
.016 w
.31274 .07132 m
.31217 .07141 L
s
1 .646 0 r
.008 w
.31217 .07141 Mdot
.016 w
.31217 .07141 m
.31166 .07151 L
s
1 .635 0 r
.008 w
.31166 .07151 Mdot
.016 w
.31166 .07151 m
.31119 .07166 L
s
1 .625 0 r
.008 w
.31119 .07166 Mdot
.016 w
.31119 .07166 m
.31075 .07191 L
s
1 .615 0 r
.008 w
.31075 .07191 Mdot
.016 w
.31075 .07191 m
.31029 .0723 L
s
1 .604 0 r
.008 w
.31029 .0723 Mdot
.016 w
.31029 .0723 m
.30991 .07275 L
s
1 .594 0 r
.008 w
.30991 .07275 Mdot
.016 w
.30991 .07275 m
.30946 .07341 L
s
1 .583 0 r
.008 w
.30946 .07341 Mdot
.016 w
.30946 .07341 m
.30895 .07426 L
s
1 .573 0 r
.008 w
.30895 .07426 Mdot
.016 w
.30895 .07426 m
.30839 .07528 L
s
1 .563 0 r
.008 w
.30839 .07528 Mdot
.016 w
.30839 .07528 m
.30776 .07636 L
s
1 .552 0 r
.008 w
.30776 .07636 Mdot
.016 w
.30776 .07636 m
.30702 .07763 L
s
1 .542 0 r
.008 w
.30702 .07763 Mdot
.016 w
.30702 .07763 m
.30622 .07904 L
s
1 .531 0 r
.008 w
.30622 .07904 Mdot
.016 w
.30622 .07904 m
.30536 .08039 L
s
1 .521 0 r
.008 w
.30536 .08039 Mdot
.016 w
.30536 .08039 m
.30449 .08171 L
s
1 .51 0 r
.008 w
.30449 .08171 Mdot
.016 w
.30449 .08171 m
.30363 .08294 L
s
1 .5 0 r
.008 w
.30363 .08294 Mdot
.016 w
.30363 .08294 m
.30281 .08408 L
s
1 .49 0 r
.008 w
.30281 .08408 Mdot
.016 w
.30281 .08408 m
.30206 .08508 L
s
1 .479 0 r
.008 w
.30206 .08508 Mdot
.016 w
.30206 .08508 m
.30139 .08594 L
s
1 .469 0 r
.008 w
.30139 .08594 Mdot
.016 w
.30139 .08594 m
.30082 .08671 L
s
1 .458 0 r
.008 w
.30082 .08671 Mdot
.016 w
.30082 .08671 m
.30036 .08741 L
s
1 .448 0 r
.008 w
.30036 .08741 Mdot
.016 w
.30036 .08741 m
.3 .08804 L
s
1 .438 0 r
.008 w
.3 .08804 Mdot
.016 w
.3 .08804 m
.29976 .08863 L
s
1 .427 0 r
.008 w
.29976 .08863 Mdot
.016 w
.29976 .08863 m
.29962 .08919 L
s
1 .417 0 r
.008 w
.29962 .08919 Mdot
.016 w
.29962 .08919 m
.29956 .08972 L
s
1 .406 0 r
.008 w
.29956 .08972 Mdot
.016 w
.29956 .08972 m
.29955 .0902 L
s
1 .396 0 r
.008 w
.29955 .0902 Mdot
.016 w
.29955 .0902 m
.29959 .09063 L
s
1 .385 0 r
.008 w
.29959 .09063 Mdot
.016 w
.29959 .09063 m
.29969 .09096 L
s
1 .375 0 r
.008 w
.29969 .09096 Mdot
.016 w
.29969 .09096 m
.29983 .09122 L
s
1 .365 0 r
.008 w
.29983 .09122 Mdot
.016 w
.29983 .09122 m
.29997 .09147 L
s
1 .354 0 r
.008 w
.29997 .09147 Mdot
.016 w
.29997 .09147 m
.30009 .09175 L
s
1 .344 0 r
.008 w
.30009 .09175 Mdot
.016 w
.30009 .09175 m
.30018 .09202 L
s
1 .333 0 r
.008 w
.30018 .09202 Mdot
.016 w
.30018 .09202 m
.30023 .09228 L
s
1 .323 0 r
.008 w
.30023 .09228 Mdot
.016 w
.30023 .09228 m
.30021 .09258 L
s
1 .313 0 r
.008 w
.30021 .09258 Mdot
.016 w
.30021 .09258 m
.3001 .09295 L
s
1 .302 0 r
.008 w
.3001 .09295 Mdot
.016 w
.3001 .09295 m
.29986 .09343 L
s
1 .292 0 r
.008 w
.29986 .09343 Mdot
.016 w
.29986 .09343 m
.29946 .09402 L
s
1 .281 0 r
.008 w
.29946 .09402 Mdot
.016 w
.29946 .09402 m
.29887 .09474 L
s
1 .271 0 r
.008 w
.29887 .09474 Mdot
.016 w
.29887 .09474 m
.29809 .09559 L
s
1 .26 0 r
.008 w
.29809 .09559 Mdot
.016 w
.29809 .09559 m
.29712 .09656 L
s
1 .25 0 r
.008 w
.29712 .09656 Mdot
.016 w
.29712 .09656 m
.29606 .09752 L
s
1 .24 0 r
.008 w
.29606 .09752 Mdot
.016 w
.29606 .09752 m
.29488 .09857 L
s
1 .229 0 r
.008 w
.29488 .09857 Mdot
.016 w
.29488 .09857 m
.29364 .09965 L
s
1 .219 0 r
.008 w
.29364 .09965 Mdot
.016 w
.29364 .09965 m
.29246 .10073 L
s
1 .208 0 r
.008 w
.29246 .10073 Mdot
.016 w
.29246 .10073 m
.29136 .10166 L
s
1 .198 0 r
.008 w
.29136 .10166 Mdot
.016 w
.29136 .10166 m
.29026 .10249 L
s
1 .188 0 r
.008 w
.29026 .10249 Mdot
.016 w
.29026 .10249 m
.28914 .10316 L
s
1 .177 0 r
.008 w
.28914 .10316 Mdot
.016 w
.28914 .10316 m
.28817 .10365 L
s
1 .167 0 r
.008 w
.28817 .10365 Mdot
.016 w
.28817 .10365 m
.28729 .10397 L
s
1 .156 0 r
.008 w
.28729 .10397 Mdot
.016 w
.28729 .10397 m
.28651 .10412 L
s
1 .146 0 r
.008 w
.28651 .10412 Mdot
.016 w
.28651 .10412 m
.28582 .10414 L
s
1 .135 0 r
.008 w
.28582 .10414 Mdot
.016 w
.28582 .10414 m
.28527 .10407 L
s
1 .125 0 r
.008 w
.28527 .10407 Mdot
.016 w
.28527 .10407 m
.28485 .10398 L
s
1 .115 0 r
.008 w
.28485 .10398 Mdot
.016 w
.28485 .10398 m
.28454 .1039 L
s
1 .104 0 r
.008 w
.28454 .1039 Mdot
.016 w
.28454 .1039 m
.28431 .10381 L
s
1 .094 0 r
.008 w
.28431 .10381 Mdot
.016 w
.28431 .10381 m
.2841 .10374 L
s
1 .083 0 r
.008 w
.2841 .10374 Mdot
.016 w
.2841 .10374 m
.28386 .10368 L
s
1 .073 0 r
.008 w
.28386 .10368 Mdot
.016 w
.28386 .10368 m
.28357 .10364 L
s
1 .063 0 r
.008 w
.28357 .10364 Mdot
.016 w
.28357 .10364 m
.28323 .10359 L
s
1 .052 0 r
.008 w
.28323 .10359 Mdot
.016 w
.28323 .10359 m
.28288 .10352 L
s
1 .042 0 r
.008 w
.28288 .10352 Mdot
.016 w
.28288 .10352 m
.28256 .10344 L
s
1 .031 0 r
.008 w
.28256 .10344 Mdot
.016 w
.28256 .10344 m
.28231 .10337 L
s
1 .021 0 r
.008 w
.28231 .10337 Mdot
.016 w
.28231 .10337 m
.28216 .1033 L
s
1 .01 0 r
.008 w
.28216 .1033 Mdot
.016 w
.28216 .1033 m
.28211 .10325 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001YOol@?Nl`Ool5001bOol006Mooa<mkcAoo`@006io
o`00IGoo5Cg_>7oo1000JWoo001TOolF?NllOol3001WOol006=oo`Ao`003On0mkcg_010mkcmoo`<0
06Aoo`00H7oo1GmP00=oP7nPOn0023g_1Woo13g_@Woo0`00HGoo001NOol5Ob001Gm0Of1oP7nPOn00
23g_1goo0Sg_AWoo0P00Ggoo001LOol4O^02O`001WlPOd1oH7n0Oj1oh0Hmke=oo`8005eoo`00FWoo
00<007k0O/000Wk000Unh7l0O`1o87m0Of1oP7nP?Nl0Fgoo0P00Fgoo001HOol00`00OV1nH002OV00
0gj0O/1nh002O`000glPOd1oo`1POol2001IOol005Eoo`<000An8004OT1nP7k0O^02O`1UOol3001F
Ool005=oo`8000=oo`An0004OT1nP7k0O^1ZOol2001DOol0055oo`8000Aoo`Amh004OP1n@7j0O/1]
Ool2001BOol0051oo`03001oogoo00=oo`Am`003ON1n07i0008mkfmoo`03001oogoo04moo`00Cgoo
00<007ooOol00Woo0Sg_17eP00=mh7h0?Nl00Sg_L7oo00<007ooOol0CWoo001=Ool20003Ool4?Nl4
O@0017gPOP0mkcg_LWoo0P00CWoo001;Ool20005Ool3?Nl2O<02O>000gd0ON1oo`1fOol2001<Ool0
04Uoo`8000Aoo`Dmk`Al`003O>1m07oo07Uoo`8004Yoo`00B7oo00<007ooOol00Woo13g_0Wa000Al
07a0O41lP09l`003O@1oogoo07Yoo`03001oogoo04Moo`00AWoo0P0017oo1Cg_0Wa000Ml07a0O41l
P7c0O>1m001mOol20017Ool004Eoo`04001oogooOol8?Nl2O40017`PO41l@7b00WcPP7oo00<007oo
Ool0A7oo0014Ool01000Oomoogoo2Cg_1Ga000=lP7ooOol0PGoo00<007ooOol0@goo0013Ool01000
Oomoogoo2Sg_RWoo00<007ooOol0@Woo0011Ool20003Ool:?Nn<Ool20012Ool0041oo`03001oogoo
00=oo`Lmki5oo`03001oogoo03moo`00?goo00<007ooOol00Woo23g_Tgoo0P00?goo000nOol00`00
Oomoo`02Ool8?NnFOol00`00Oomoo`0lOol003aoo`8000Eoo`HmkiUoo`03001oogoo03]oo`00>goo
00<007ooOol02Sg_Vgoo00<007ooOol0>Woo000jOol00`00Oolmk`0;?NnLOol2000jOol003Uoo`03
001oogoo00Xmkj1oo`03001oogoo03Moo`00=goo0P000Woo2cg_XGoo00<007ooOol0=Woo000fOol0
0`00Oomoo`02Ool5?NnXOol00`00Oomoo`0eOol003Eoo`03001oogoo009oo`DmkjYoo`03001oogoo
03Aoo`00=7oo00<007ooOol00goo1Cg_Zgoo00<007ooOol0<goo000bOol20005Ool5?Nn]Ool00`00
Oomoo`0bOol0035oo`03001oogoo00Aoo`Hmkjioo`03001oogoo035oo`00<7oo00<007ooOol01Goo
1Cg_/7oo00<007ooOol0<7oo000`Ool00`00Oomoo`03Ool7?NnaOol00`00Oomoo`0_Ool002moo`03
001oogoo00=oo`Pmkk9oo`03001oogoo02ioo`00;Woo00<007ooOol00goo23g_]7oo00<007ooOol0
;Goo000]Ool00`00Oomoo`04Ool6?NngOol00`00Oomoo`0/Ool002aoo`03001oogoo00Aoo`LmkkQo
o`03001oogoo02]oo`00;7oo00<007ooOol00goo1cg_^Goo00<007ooOol0:goo000[Ool00`00Oomo
o`04Ool5?NnlOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`Dmkkioo`03001oogoo02Uoo`00
:Goo00<007ooOol01Goo1Cg__goo00<007ooOol0:7oo000XOol00`00Oomoo`05Ool5?No1Ool00`00
Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`009goo00<007ooOol01Woo
1Cg_`Woo00<007ooOol09Woo000VOol00`00Oomoo`06Ool7?No2Ool00`00Oomoo`0UOol002Eoo`03
001oogoo00Ioo`Pmkl=oo`03001oogoo02Aoo`0097oo00<007ooOol01Woo23g_aGoo00<007ooOol0
8goo000TOol00`00Oomoo`05Ool8?No6Ool00`00Oomoo`0SOol002=oo`03001oogoo00Ioo`LmklQo
o`03001oogoo029oo`008Woo00<007ooOol01Woo23g_bGoo00<007ooOol08Goo000ROol00`00Oomo
o`05Ool9?No9Ool00`00Oomoo`0QOol0025oo`03001oogoo00Ioo`Pmkl]oo`03001oogoo021oo`00
87oo00<007ooOol01Woo23g_cGoo00<007ooOol07goo000POol00`00Oomoo`05Ool7?No?Ool00`00
Oomoo`0OOol001moo`03001oogoo00Ioo`Hmkm5oo`03001oogoo01ioo`007goo00<007ooOol01Woo
1Sg_dWoo00<007ooOol07Goo000NOol00`00Oomoo`06Ool7?NoBOol00`00Oomoo`0MOol001eoo`03
001oogoo00Moo`Lmkm=oo`03001oogoo01aoo`007Goo00<007ooOol01Woo23g_dgoo00<007ooOol0
77oo000LOol00`00Oomoo`06Ool8?NoEOol00`00Oomoo`0KOol001aoo`03001oogoo00Eoo`TmkmEo
o`03001oogoo01]oo`006goo00<007ooOol01Woo2Cg_eWoo00<007ooOol06Woo000KOol00`00Oomo
o`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Ioo`TmkmQoo`03001oogoo01Uoo`00
6Woo00<007ooOol01Woo23g_fGoo00<007ooOol06Goo000IOol00`00Oomoo`06Ool8?NoKOol00`00
Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lmkmaoo`03001oogoo01Qoo`0067oo00<007ooOol01Goo
23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`05Ool7?NoOOol00`00Oomoo`0GOol001Qoo`03
001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol01Goo23g_h7oo00<007ooOol0
5Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`Pmkn9o
o`03001oogoo01Eoo`005Woo00<007ooOol01Goo1Sg_i7oo00<007ooOol05Goo000EOol00`00Oomo
o`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`00
5Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00Oomoo`06Ool6?NoWOol00`00
Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Goo
1cg_igoo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=oo`03
001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol0
4Woo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Moo`Dmkn]o
o`03001oogoo015oo`004Woo00<007ooOol01Woo1Cg_k7oo00<007ooOol04Goo000AOol00`00Oomo
o`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`00
4Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No]Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03
001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneo
o`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomo
o`09Ool8?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Pmkneoo`03001oogoo00eoo`00
3Woo00<007ooOol02Woo33g_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool:?NoYOol00`00
Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo00eoo`003Woo00<007ooOol03Goo
33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol0
37oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`dmknMo
o`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl00cg_igoo00<007ooOol037oo
000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`dm
kn]oo`03001oogoo00aoo`003Goo00<007ooOol027oo3cg_jWoo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa4mknQoo`03001oogoo00ao
o`0037oo00<007ooOol027oo4cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool;?Nl4Ool5
?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00IooaLmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol01Goo63g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08OolE?NoVOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;Ool6?NoUOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<0
07ooOol06Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol7?NoTOol00`00Oomoo`0;
Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_hGoo
00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eoo`03001oogoo
01Moo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_ggoo00<007ooOol037oo000=
Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001o
ogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8
?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<0
07ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol9?NoLOol00`00Oomoo`0<
Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Goo2Sg_fWoo
00<007ooOol037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo
01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007ooOol03Goo000>
Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003goo
00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03
001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00
Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`0047oo00<007oo
Ool0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo
0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00Oomoo`3j
Ool00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo
00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03
001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00
Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0mGoo00<007oo
Ool04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo
01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0C
Ool001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo
000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`00
5Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Mo
o`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol0
0`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<0
07ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001o
ogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomo
o`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0
hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5o
o`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol0
0`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007ooOol0gGoo00<0
07ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001o
ogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomo
o`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol0
8goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Ao
o`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol0
02Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007ooOol09goo000Y
Ool00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo
00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03
001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00
Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;goo00<007oo
Ool0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo
0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0c
Ool003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo
000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00
>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03001oogoo0:Eo
o`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol0
0`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011
Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo
00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00
B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007oo
Ool0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80
055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo
0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<0
07ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo
001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000Q
Ool7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo002;Ool20004Ool2002=Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo
002<Ool00`00Oomoo`04Ool00`00Oomoo`2:Ool008eoo`04001oogooOol2002=Ool008Yoo`04001o
ogoo0003Ool00`00Oomoo`2<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(36)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
1 .993 0 r
.008 w
.28352 .10375 Mdot
.016 w
.28352 .10375 m
.28332 .10372 L
s
1 .986 0 r
.008 w
.28332 .10372 Mdot
.016 w
.28332 .10372 m
.283 .10365 L
s
1 .98 0 r
.008 w
.283 .10365 Mdot
.016 w
.283 .10365 m
.28258 .10353 L
s
1 .973 0 r
.008 w
.28258 .10353 Mdot
.016 w
.28258 .10353 m
.28208 .10334 L
s
1 .966 0 r
.008 w
.28208 .10334 Mdot
.016 w
.28208 .10334 m
.28149 .10306 L
s
1 .959 0 r
.008 w
.28149 .10306 Mdot
.016 w
.28149 .10306 m
.2808 .10273 L
s
1 .952 0 r
.008 w
.2808 .10273 Mdot
.016 w
.2808 .10273 m
.28015 .10236 L
s
1 .946 0 r
.008 w
.28015 .10236 Mdot
.016 w
.28015 .10236 m
.27937 .10203 L
s
1 .939 0 r
.008 w
.27937 .10203 Mdot
.016 w
.27937 .10203 m
.27855 .10172 L
s
1 .932 0 r
.008 w
.27855 .10172 Mdot
.016 w
.27855 .10172 m
.27771 .10148 L
s
1 .925 0 r
.008 w
.27771 .10148 Mdot
.016 w
.27771 .10148 m
.27693 .10131 L
s
1 .918 0 r
.008 w
.27693 .10131 Mdot
.016 w
.27693 .10131 m
.2762 .10122 L
s
1 .912 0 r
.008 w
.2762 .10122 Mdot
.016 w
.2762 .10122 m
.27557 .10118 L
s
1 .905 0 r
.008 w
.27557 .10118 Mdot
.016 w
.27557 .10118 m
.27503 .1012 L
s
1 .898 0 r
.008 w
.27503 .1012 Mdot
.016 w
.27503 .1012 m
.27464 .10131 L
s
1 .891 0 r
.008 w
.27464 .10131 Mdot
.016 w
.27464 .10131 m
.27433 .10147 L
s
1 .884 0 r
.008 w
.27433 .10147 Mdot
.016 w
.27433 .10147 m
.27414 .10167 L
s
1 .878 0 r
.008 w
.27414 .10167 Mdot
.016 w
.27414 .10167 m
.27404 .10193 L
s
1 .871 0 r
.008 w
.27404 .10193 Mdot
.016 w
.27404 .10193 m
.27399 .10221 L
s
1 .864 0 r
.008 w
.27399 .10221 Mdot
.016 w
.27399 .10221 m
.27398 .10245 L
s
1 .857 0 r
.008 w
.27398 .10245 Mdot
.016 w
.27398 .10245 m
.27397 .10263 L
s
1 .85 0 r
.008 w
.27397 .10263 Mdot
.016 w
.27397 .10263 m
.2739 .10277 L
s
1 .844 0 r
.008 w
.2739 .10277 Mdot
.016 w
.2739 .10277 m
.27374 .10283 L
s
1 .837 0 r
.008 w
.27374 .10283 Mdot
.016 w
.27374 .10283 m
.27344 .10286 L
s
1 .83 0 r
.008 w
.27344 .10286 Mdot
.016 w
.27344 .10286 m
.27298 .1029 L
s
1 .823 0 r
.008 w
.27298 .1029 Mdot
.016 w
.27298 .1029 m
.27239 .10301 L
s
1 .816 0 r
.008 w
.27239 .10301 Mdot
.016 w
.27239 .10301 m
.27165 .10328 L
s
1 .81 0 r
.008 w
.27165 .10328 Mdot
.016 w
.27165 .10328 m
.27077 .10377 L
s
1 .803 0 r
.008 w
.27077 .10377 Mdot
.016 w
.27077 .10377 m
.26982 .10446 L
s
1 .796 0 r
.008 w
.26982 .10446 Mdot
.016 w
.26982 .10446 m
.26885 .10533 L
s
1 .789 0 r
.008 w
.26885 .10533 Mdot
.016 w
.26885 .10533 m
.26782 .10629 L
s
1 .782 0 r
.008 w
.26782 .10629 Mdot
.016 w
.26782 .10629 m
.26673 .10727 L
s
1 .776 0 r
.008 w
.26673 .10727 Mdot
.016 w
.26673 .10727 m
.26564 .10811 L
s
1 .769 0 r
.008 w
.26564 .10811 Mdot
.016 w
.26564 .10811 m
.26461 .10893 L
s
1 .762 0 r
.008 w
.26461 .10893 Mdot
.016 w
.26461 .10893 m
.26366 .10968 L
s
1 .755 0 r
.008 w
.26366 .10968 Mdot
.016 w
.26366 .10968 m
.26283 .11038 L
s
1 .748 0 r
.008 w
.26283 .11038 Mdot
.016 w
.26283 .11038 m
.26212 .11089 L
s
1 .741 0 r
.008 w
.26212 .11089 Mdot
.016 w
.26212 .11089 m
.26153 .11127 L
s
1 .735 0 r
.008 w
.26153 .11127 Mdot
.016 w
.26153 .11127 m
.26105 .11149 L
s
1 .728 0 r
.008 w
.26105 .11149 Mdot
.016 w
.26105 .11149 m
.26066 .11157 L
s
1 .721 0 r
.008 w
.26066 .11157 Mdot
.016 w
.26066 .11157 m
.26036 .11145 L
s
1 .714 0 r
.008 w
.26036 .11145 Mdot
.016 w
.26036 .11145 m
.26016 .11117 L
s
1 .707 0 r
.008 w
.26016 .11117 Mdot
.016 w
.26016 .11117 m
.26005 .11076 L
s
1 .701 0 r
.008 w
.26005 .11076 Mdot
.016 w
.26005 .11076 m
.26001 .11033 L
s
1 .694 0 r
.008 w
.26001 .11033 Mdot
.016 w
.26001 .11033 m
.26001 .10995 L
s
1 .687 0 r
.008 w
.26001 .10995 Mdot
.016 w
.26001 .10995 m
.26 .10968 L
s
1 .68 0 r
.008 w
.26 .10968 Mdot
.016 w
.26 .10968 m
.25996 .10951 L
s
1 .673 0 r
.008 w
.25996 .10951 Mdot
.016 w
.25996 .10951 m
.25982 .10946 L
s
1 .667 0 r
.008 w
.25982 .10946 Mdot
.016 w
.25982 .10946 m
.2595 .10956 L
s
1 .66 0 r
.008 w
.2595 .10956 Mdot
.016 w
.2595 .10956 m
.25897 .1098 L
s
1 .653 0 r
.008 w
.25897 .1098 Mdot
.016 w
.25897 .1098 m
.25824 .11014 L
s
1 .646 0 r
.008 w
.25824 .11014 Mdot
.016 w
.25824 .11014 m
.25729 .11056 L
s
1 .639 0 r
.008 w
.25729 .11056 Mdot
.016 w
.25729 .11056 m
.25609 .11107 L
s
1 .633 0 r
.008 w
.25609 .11107 Mdot
.016 w
.25609 .11107 m
.25485 .11165 L
s
1 .626 0 r
.008 w
.25485 .11165 Mdot
.016 w
.25485 .11165 m
.25335 .1123 L
s
1 .619 0 r
.008 w
.25335 .1123 Mdot
.016 w
.25335 .1123 m
.25173 .11295 L
s
1 .612 0 r
.008 w
.25173 .11295 Mdot
.016 w
.25173 .11295 m
.25011 .11366 L
s
1 .605 0 r
.008 w
.25011 .11366 Mdot
.016 w
.25011 .11366 m
.24837 .11437 L
s
1 .599 0 r
.008 w
.24837 .11437 Mdot
.016 w
.24837 .11437 m
.24663 .11508 L
s
1 .592 0 r
.008 w
.24663 .11508 Mdot
.016 w
.24663 .11508 m
.24495 .1158 L
s
1 .585 0 r
.008 w
.24495 .1158 Mdot
.016 w
.24495 .1158 m
.24342 .11651 L
s
1 .578 0 r
.008 w
.24342 .11651 Mdot
.016 w
.24342 .11651 m
.24187 .11727 L
s
1 .571 0 r
.008 w
.24187 .11727 Mdot
.016 w
.24187 .11727 m
.24032 .11808 L
s
1 .565 0 r
.008 w
.24032 .11808 Mdot
.016 w
.24032 .11808 m
.23884 .11893 L
s
1 .558 0 r
.008 w
.23884 .11893 Mdot
.016 w
.23884 .11893 m
.23745 .11982 L
s
1 .551 0 r
.008 w
.23745 .11982 Mdot
.016 w
.23745 .11982 m
.23627 .12073 L
s
1 .544 0 r
.008 w
.23627 .12073 Mdot
.016 w
.23627 .12073 m
.23503 .12172 L
s
1 .537 0 r
.008 w
.23503 .12172 Mdot
.016 w
.23503 .12172 m
.23384 .1228 L
s
1 .531 0 r
.008 w
.23384 .1228 Mdot
.016 w
.23384 .1228 m
.23274 .12389 L
s
1 .524 0 r
.008 w
.23274 .12389 Mdot
.016 w
.23274 .12389 m
.23171 .12509 L
s
1 .517 0 r
.008 w
.23171 .12509 Mdot
.016 w
.23171 .12509 m
.23069 .12646 L
s
1 .51 0 r
.008 w
.23069 .12646 Mdot
.016 w
.23069 .12646 m
.22976 .1278 L
s
1 .503 0 r
.008 w
.22976 .1278 Mdot
.016 w
.22976 .1278 m
.2289 .12921 L
s
1 .497 0 r
.008 w
.2289 .12921 Mdot
.016 w
.2289 .12921 m
.22815 .13061 L
s
1 .49 0 r
.008 w
.22815 .13061 Mdot
.016 w
.22815 .13061 m
.22752 .13189 L
s
1 .483 0 r
.008 w
.22752 .13189 Mdot
.016 w
.22752 .13189 m
.22702 .13296 L
s
1 .476 0 r
.008 w
.22702 .13296 Mdot
.016 w
.22702 .13296 m
.22666 .13376 L
s
1 .469 0 r
.008 w
.22666 .13376 Mdot
.016 w
.22666 .13376 m
.2264 .13434 L
s
1 .463 0 r
.008 w
.2264 .13434 Mdot
.016 w
.2264 .13434 m
.22621 .13467 L
s
1 .456 0 r
.008 w
.22621 .13467 Mdot
.016 w
.22621 .13467 m
.22606 .13478 L
s
1 .449 0 r
.008 w
.22606 .13478 Mdot
.016 w
.22606 .13478 m
.22596 .13466 L
s
1 .442 0 r
.008 w
.22596 .13466 Mdot
.016 w
.22596 .13466 m
.22588 .13438 L
s
1 .435 0 r
.008 w
.22588 .13438 Mdot
.016 w
.22588 .13438 m
.22583 .13401 L
s
1 .429 0 r
.008 w
.22583 .13401 Mdot
.016 w
.22583 .13401 m
.22581 .13364 L
s
1 .422 0 r
.008 w
.22581 .13364 Mdot
.016 w
.22581 .13364 m
.22582 .13329 L
s
1 .415 0 r
.008 w
.22582 .13329 Mdot
.016 w
.22582 .13329 m
.22587 .13302 L
s
1 .408 0 r
.008 w
.22587 .13302 Mdot
.016 w
.22587 .13302 m
.22593 .1329 L
s
1 .401 0 r
.008 w
.22593 .1329 Mdot
.016 w
.22593 .1329 m
.226 .133 L
s
1 .395 0 r
.008 w
.226 .133 Mdot
.016 w
.226 .133 m
.22606 .13338 L
s
1 .388 0 r
.008 w
.22606 .13338 Mdot
.016 w
.22606 .13338 m
.2261 .13403 L
s
1 .381 0 r
.008 w
.2261 .13403 Mdot
.016 w
.2261 .13403 m
.22615 .13488 L
s
1 .374 0 r
.008 w
.22615 .13488 Mdot
.016 w
.22615 .13488 m
.22621 .13576 L
s
1 .367 0 r
.008 w
.22621 .13576 Mdot
.016 w
.22621 .13576 m
.22629 .13689 L
s
1 .361 0 r
.008 w
.22629 .13689 Mdot
.016 w
.22629 .13689 m
.22635 .13786 L
s
1 .354 0 r
.008 w
.22635 .13786 Mdot
.016 w
.22635 .13786 m
.22641 .13879 L
s
1 .347 0 r
.008 w
.22641 .13879 Mdot
.016 w
.22641 .13879 m
.22643 .13959 L
s
1 .34 0 r
.008 w
.22643 .13959 Mdot
.016 w
.22643 .13959 m
.22644 .14019 L
s
1 .333 0 r
.008 w
.22644 .14019 Mdot
.016 w
.22644 .14019 m
.22643 .14055 L
s
1 .327 0 r
.008 w
.22643 .14055 Mdot
.016 w
.22643 .14055 m
.22638 .14068 L
s
1 .32 0 r
.008 w
.22638 .14068 Mdot
.016 w
.22638 .14068 m
.22626 .14064 L
s
1 .313 0 r
.008 w
.22626 .14064 Mdot
.016 w
.22626 .14064 m
.22604 .14048 L
s
1 .306 0 r
.008 w
.22604 .14048 Mdot
.016 w
.22604 .14048 m
.22572 .14025 L
s
1 .299 0 r
.008 w
.22572 .14025 Mdot
.016 w
.22572 .14025 m
.22528 .14 L
s
1 .293 0 r
.008 w
.22528 .14 Mdot
.016 w
.22528 .14 m
.22469 .13975 L
s
1 .286 0 r
.008 w
.22469 .13975 Mdot
.016 w
.22469 .13975 m
.22395 .13955 L
s
1 .279 0 r
.008 w
.22395 .13955 Mdot
.016 w
.22395 .13955 m
.22303 .13941 L
s
1 .272 0 r
.008 w
.22303 .13941 Mdot
.016 w
.22303 .13941 m
.22194 .1393 L
s
1 .265 0 r
.008 w
.22194 .1393 Mdot
.016 w
.22194 .1393 m
.22068 .13926 L
s
1 .259 0 r
.008 w
.22068 .13926 Mdot
.016 w
.22068 .13926 m
.21923 .13931 L
s
1 .252 0 r
.008 w
.21923 .13931 Mdot
.016 w
.21923 .13931 m
.21761 .13948 L
s
1 .245 0 r
.008 w
.21761 .13948 Mdot
.016 w
.21761 .13948 m
.21608 .13979 L
s
1 .238 0 r
.008 w
.21608 .13979 Mdot
.016 w
.21608 .13979 m
.21438 .14024 L
s
1 .231 0 r
.008 w
.21438 .14024 Mdot
.016 w
.21438 .14024 m
.21244 .14085 L
s
1 .224 0 r
.008 w
.21244 .14085 Mdot
.016 w
.21244 .14085 m
.21033 .14161 L
s
1 .218 0 r
.008 w
.21033 .14161 Mdot
.016 w
.21033 .14161 m
.20831 .14251 L
s
1 .211 0 r
.008 w
.20831 .14251 Mdot
.016 w
.20831 .14251 m
.2064 .14357 L
s
1 .204 0 r
.008 w
.2064 .14357 Mdot
.016 w
.2064 .14357 m
.20437 .14481 L
s
1 .197 0 r
.008 w
.20437 .14481 Mdot
.016 w
.20437 .14481 m
.20236 .14613 L
s
1 .19 0 r
.008 w
.20236 .14613 Mdot
.016 w
.20236 .14613 m
.20037 .1477 L
s
1 .184 0 r
.008 w
.20037 .1477 Mdot
.016 w
.20037 .1477 m
.19858 .14946 L
s
1 .177 0 r
.008 w
.19858 .14946 Mdot
.016 w
.19858 .14946 m
.19669 .15134 L
s
1 .17 0 r
.008 w
.19669 .15134 Mdot
.016 w
.19669 .15134 m
.19513 .15325 L
s
1 .163 0 r
.008 w
.19513 .15325 Mdot
.016 w
.19513 .15325 m
.19357 .15535 L
s
1 .156 0 r
.008 w
.19357 .15535 Mdot
.016 w
.19357 .15535 m
.19193 .15745 L
s
1 .15 0 r
.008 w
.19193 .15745 Mdot
.016 w
.19193 .15745 m
.1904 .15975 L
s
1 .143 0 r
.008 w
.1904 .15975 Mdot
.016 w
.1904 .15975 m
.18885 .16187 L
s
1 .136 0 r
.008 w
.18885 .16187 Mdot
.016 w
.18885 .16187 m
.18731 .16409 L
s
1 .129 0 r
.008 w
.18731 .16409 Mdot
.016 w
.18731 .16409 m
.18579 .16637 L
s
1 .122 0 r
.008 w
.18579 .16637 Mdot
.016 w
.18579 .16637 m
.18455 .16833 L
s
1 .116 0 r
.008 w
.18455 .16833 Mdot
.016 w
.18455 .16833 m
.18327 .1704 L
s
1 .109 0 r
.008 w
.18327 .1704 Mdot
.016 w
.18327 .1704 m
.18215 .17237 L
s
1 .102 0 r
.008 w
.18215 .17237 Mdot
.016 w
.18215 .17237 m
.18116 .17423 L
s
1 .095 0 r
.008 w
.18116 .17423 Mdot
.016 w
.18116 .17423 m
.18018 .17612 L
s
1 .088 0 r
.008 w
.18018 .17612 Mdot
.016 w
.18018 .17612 m
.17933 .17762 L
s
1 .082 0 r
.008 w
.17933 .17762 Mdot
.016 w
.17933 .17762 m
.1786 .17908 L
s
1 .075 0 r
.008 w
.1786 .17908 Mdot
.016 w
.1786 .17908 m
.17803 .18052 L
s
1 .068 0 r
.008 w
.17803 .18052 Mdot
.016 w
.17803 .18052 m
.17762 .18191 L
s
1 .061 0 r
.008 w
.17762 .18191 Mdot
.016 w
.17762 .18191 m
.17738 .18321 L
s
1 .054 0 r
.008 w
.17738 .18321 Mdot
.016 w
.17738 .18321 m
.1773 .18432 L
s
1 .048 0 r
.008 w
.1773 .18432 Mdot
.016 w
.1773 .18432 m
.17733 .18536 L
s
1 .041 0 r
.008 w
.17733 .18536 Mdot
.016 w
.17733 .18536 m
.17743 .18628 L
s
1 .034 0 r
.008 w
.17743 .18628 Mdot
.016 w
.17743 .18628 m
.17754 .18704 L
s
1 .027 0 r
.008 w
.17754 .18704 Mdot
.016 w
.17754 .18704 m
.17764 .18761 L
s
1 .02 0 r
.008 w
.17764 .18761 Mdot
.016 w
.17764 .18761 m
.17772 .18801 L
s
1 .014 0 r
.008 w
.17772 .18801 Mdot
.016 w
.17772 .18801 m
.17776 .18827 L
s
1 .007 0 r
.008 w
.17776 .18827 Mdot
.016 w
.17776 .18827 m
.17776 .18843 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001YOol@?Nl`Ool5001bOol006Mooa<mkcAoo`@006io
o`00IGoo5Cg_>7oo1000JWoo001TOolF?NllOol3001WOol006=ooaLmkcmoo`<006Aoo`00H7oo43g_
1Woo13g_@Woo0`00HGoo001NOolB?Nl7Ool2?Nm6Ool2001OOol005aooa8mke=oo`8005eoo`00FWoo
00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol00`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEo
o`<005Ioo`00Dgoo0P000goo23g_JWoo0P00E7oo001AOol20004Ool8?Nm]Ool2001BOol0051oo`03
001oogoo00=oo`Tmkfmoo`03001oogoo04moo`00Cgoo00<007ooOol00Woo2cg_L7oo00<007ooOol0
CWoo001=Ool20003Ool<?NmbOol2001>Ool004]oo`8000Eoo`TmkgMoo`8004aoo`00BGoo0P0017oo
0WlP0WmP00=oX3g_?Nl013g_NWoo0P00BWoo0018Ool00`00Oomoo`02Ool00cg_Ob1o8002Ob0017m0
Oj1o`7oP13g_O7oo00<007ooOol0Agoo0016Ool20004Ool2OZ03O`02Ob000gnPOl1oh004?NmmOol2
0017Ool004Eoo`03001oogoo009n@0=nH09nP007O^1o07lPOd1oX7o0On000cg_P7oo00<007ooOol0
A7oo0014Ool00`00Oomoo`04OT02OV02OX0017kPO`1o@7m00Wo000=oh7ooOol0PWoo00<007ooOol0
@goo0013Ool00`00Oomn8003OR03OT001GiPOX1nP7kPO`00RWoo00<007ooOol0@Woo0011Ool20000
0gooOP1n0002OP000ghPOT1n@002OV02OX000gkPOomoo`2:Ool20012Ool0041oo`03001oogoo00En
0003OR1n@7iP009nH95oo`03001oogoo03moo`00?goo00<007ooOol01GgP00=n07hPOT000Sg_Tgoo
0P00?goo000nOol01000Oomoogoo17f000=mh7h0OR000Sg_UWoo00<007ooOol0?7oo000lOol20004
Ool4OF000ggPOP0mk`2IOol00`00Oomoo`0kOol003]oo`03001oogc000=l`09lh09m0003OB1mh3g_
09]oo`03001oogoo03Yoo`00>Woo00@007ooO:1lX0=l`09lh09m0003OB0mkcg_09aoo`8003Yoo`00
>Goo00<007ooO:000gbP0Wc00WcP0Wd000=m87ooOol0WWoo00<007ooOol0=goo000gOol200000goo
O81lP004O:000gc0O>1lh002O@000gdPOomoo`2OOol00`00Oomoo`0fOol003Ioo`03001oogoo00Al
P09lX09l`:Moo`03001oogoo03Eoo`00=Goo00<007ooOol01Wb000<mkgooOol0Z7oo00<007ooOol0
=7oo000dOol01000Oomoogoo0WaP0gb00Sg_Zgoo00<007ooOol0<goo000bOol20003Ool4O602O800
0cg_Oomoo`2[Ool00`00Oomoo`0bOol0035oo`03001oogoo009oo`IlH08mkjioo`03001oogoo035o
o`00<7oo00<007ooOol00Woo1WaP00=lP3g_Ool0[goo00<007ooOol0<7oo000`Ool00`00Oomoo`02
Ool4O40017aP?Nlmkcg_/Goo00<007ooOol0;goo000_Ool00`00Oomoo`02Ool4O2000ga0O60mk`02
?NnbOol00`00Oomoo`0^Ool002ioo`03001oogoo00=oo`Al8004O41lH3g_?NndOol00`00Oomoo`0]
Ool002eoo`03001oogoo00Aoo`El0003?Nmoogoo0;Eoo`03001oogoo02aoo`00;7oo00<007ooOol0
17oo00<mkg`0O0000g`000<mkgooOol0]Woo00<007ooOol0:goo000/Ool00`00Oomoo`03Ool2?Nl5
O02iOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`8mk`El0;Yoo`03001oogoo02Yoo`00:Woo
00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomoo`05Ool5?NnoOol00`00Oomo
o`0XOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`00:7oo00<007ooOol01Goo1Cg_
`Goo00<007ooOol09goo000WOol00`00Oomoo`06Ool5?No2Ool00`00Oomoo`0VOol002Ioo`03001o
ogoo00Ioo`Lmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Woo23g_`goo00<007ooOol097oo
000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`PmklIoo`03
001oogoo02=oo`008goo00<007ooOol01Woo1cg_b7oo00<007ooOol08Woo000ROol00`00Oomoo`06
Ool8?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Goo
00<007ooOol01Woo23g_bgoo00<007ooOol087oo000POol00`00Oomoo`06Ool8?No=Ool00`00Oomo
o`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo00<007ooOol01Woo1Sg_
dGoo00<007ooOol07Woo000OOol00`00Oomoo`06Ool6?NoBOol00`00Oomoo`0MOol001ioo`03001o
ogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01goo1cg_dgoo00<007ooOol077oo
000MOol00`00Oomoo`06Ool8?NoCOol00`00Oomoo`0LOol001aoo`03001oogoo00Ioo`PmkmEoo`03
001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo000KOol00`00Oomoo`06
Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03001oogoo01Yoo`006Woo
00<007ooOol01Woo2Cg_f7oo00<007ooOol06Goo000JOol00`00Oomoo`06Ool8?NoIOol00`00Oomo
o`0IOol001Uoo`03001oogoo00Ioo`Pmkm]oo`03001oogoo01Qoo`006Goo00<007ooOol01Woo1cg_
g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomoo`0GOol001Qoo`03001o
ogoo00Eoo`Lmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo
000GOol00`00Oomoo`05Ool8?NoPOol00`00Oomoo`0FOol001Moo`03001oogoo00Aoo`Pmkn5oo`03
001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05
Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03001oogoo01Aoo`005Goo
00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomo
o`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_
igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001o
ogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo
000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03
001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06
Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo
00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomo
o`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_
kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo
000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03
001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09
Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003Woo
00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool<?NoYOol00`00Oomo
o`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2cg_
igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo
000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03
001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0<
Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`Lmk`=oo`DmknMo
o`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007ooOol037oo000=Ool00`00Oomo
o`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0mknUoo`03001oogoo00aoo`00
3Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00Oomoo`08OolC?NoXOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001oogoo00]oo`0037oo00<007oo
Ool01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH?NoVOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_
?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoTOol00`00Oomoo`0;Ool0
00aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol067oo2Cg_hWoo00<0
07ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qo
o`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo00<007ooOol02goo000=Ool0
0`00Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo
00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoN
Ool00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007oo
Ool077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool0
00eoo`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<007ooOol077oo2cg_fWoo00<0
07ooOol037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01io
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo00<007ooOol03Goo000>Ool0
0`00Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`00
3Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000mo
o`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool0
0`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<0
07ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001o
ogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomo
o`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0
nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qo
o`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol0
0`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<0
07ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001o
ogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomo
o`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol0
57oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Ao
o`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol0
01Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000H
Ool00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo
00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03
001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00
Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007oo
Ool0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo
0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3O
Ool00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo
00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03
001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00
Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007oo
Ool08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo
02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0U
Ool002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo
000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00
:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]o
o`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool0
0`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<0
07ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001o
ogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2
000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0
=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eo
o`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol0
03Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2S
Ool00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo
0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0
UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095o
o`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`80
04]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001o
ogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`80
07=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005ao
o`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00
IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo
1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=
Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000=oo`<008eo
o`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008aoo`05001oogooOol00002Ool00`00Oomo
o`2:Ool008eoo`03001oogoo00<008eoo`00RWoo00@007ooOol000=oo`03001oogoo08aoo`00Rgoo
0P0017oo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(37)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
1 .958 0 r
.008 w
.18985 .18586 Mdot
.016 w
.18985 .18586 m
.18987 .18563 L
s
1 .917 0 r
.008 w
.18987 .18563 Mdot
.016 w
.18987 .18563 m
.18992 .18529 L
s
1 .875 0 r
.008 w
.18992 .18529 Mdot
.016 w
.18992 .18529 m
.19007 .18482 L
s
1 .833 0 r
.008 w
.19007 .18482 Mdot
.016 w
.19007 .18482 m
.19035 .18422 L
s
1 .792 0 r
.008 w
.19035 .18422 Mdot
.016 w
.19035 .18422 m
.19077 .18347 L
s
1 .75 0 r
.008 w
.19077 .18347 Mdot
.016 w
.19077 .18347 m
.19134 .18259 L
s
1 .708 0 r
.008 w
.19134 .18259 Mdot
.016 w
.19134 .18259 m
.19203 .18155 L
s
1 .667 0 r
.008 w
.19203 .18155 Mdot
.016 w
.19203 .18155 m
.19288 .18029 L
s
1 .625 0 r
.008 w
.19288 .18029 Mdot
.016 w
.19288 .18029 m
.19388 .17882 L
s
1 .583 0 r
.008 w
.19388 .17882 Mdot
.016 w
.19388 .17882 m
.19502 .17726 L
s
1 .542 0 r
.008 w
.19502 .17726 Mdot
.016 w
.19502 .17726 m
.19629 .17556 L
s
1 .5 0 r
.008 w
.19629 .17556 Mdot
.016 w
.19629 .17556 m
.19761 .17382 L
s
1 .458 0 r
.008 w
.19761 .17382 Mdot
.016 w
.19761 .17382 m
.19898 .17204 L
s
1 .417 0 r
.008 w
.19898 .17204 Mdot
.016 w
.19898 .17204 m
.20035 .17045 L
s
1 .375 0 r
.008 w
.20035 .17045 Mdot
.016 w
.20035 .17045 m
.20161 .16891 L
s
1 .333 0 r
.008 w
.20161 .16891 Mdot
.016 w
.20161 .16891 m
.2028 .16751 L
s
1 .292 0 r
.008 w
.2028 .16751 Mdot
.016 w
.2028 .16751 m
.20379 .16639 L
s
1 .25 0 r
.008 w
.20379 .16639 Mdot
.016 w
.20379 .16639 m
.20468 .16533 L
s
1 .208 0 r
.008 w
.20468 .16533 Mdot
.016 w
.20468 .16533 m
.20543 .16446 L
s
1 .167 0 r
.008 w
.20543 .16446 Mdot
.016 w
.20543 .16446 m
.20609 .16368 L
s
1 .125 0 r
.008 w
.20609 .16368 Mdot
.016 w
.20609 .16368 m
.20655 .16318 L
s
1 .083 0 r
.008 w
.20655 .16318 Mdot
.016 w
.20655 .16318 m
.20691 .16282 L
s
1 .042 0 r
.008 w
.20691 .16282 Mdot
.016 w
.20691 .16282 m
.20713 .16263 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001YOol@?Nl`Ool5001bOol006Mooa<mkcAoo`@006io
o`00IGoo5Cg_>7oo1000JWoo001TOolF?NllOol3001WOol006=ooaLmkcmoo`<006Aoo`00H7oo43g_
1Woo13g_@Woo0`00HGoo001NOolB?Nl7Ool2?Nm6Ool2001OOol005aooa8mke=oo`8005eoo`00FWoo
00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol00`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEo
o`<005Ioo`00Dgoo0P000goo23g_JWoo0P00E7oo001AOol20004Ool8?Nm]Ool2001BOol0051oo`03
001oogoo00=oo`Tmkfmoo`03001oogoo04moo`00Cgoo00<007ooOol00Woo2cg_L7oo00<007ooOol0
CWoo001=Ool20003Ool<?NmbOol2001>Ool004]oo`8000Eoo`TmkgMoo`8004aoo`00BGoo0P0017oo
2cg_NWoo0P00BWoo0018Ool00`00Oomoo`02Ool=?NmlOol00`00Oomoo`17Ool004Ioo`8000Aoo`hm
kgeoo`8004Moo`00AGoo00@007ooOomooa0mkh1oo`03001oogoo04Aoo`00A7oo00<007ooOol03cg_
Q7oo00<007ooOol0@goo0013Ool00`00Oolmk`0;?Nn:Ool00`00Oomoo`12Ool0045oo`800003Oolm
kcg_00Xmkhaoo`80049oo`00@7oo00<007ooOol02Sg_TGoo00<007ooOol0?goo000oOol00`00Oomo
o`0:?NnCOol2000oOol003ioo`04001oogooOol9?NnFOol00`00Oomoo`0lOol003aoo`8000Aoo`Lm
kiUoo`03001oogoo03]oo`00>goo00<007oo?Nl02Sg_Vgoo00<007ooOol0>Woo000jOol00`00Oolm
k`0;?NnLOol2000jOol003Uoo`03001oocg_00Xmkj1oo`03001oogoo03Moo`00=goo0P0000=oocg_
?Nl02Sg_XGoo00<007ooOol0=Woo000fOol00`00Oomoo`08?NnWOol00`00Oomoo`0eOol003Eoo`03
001oogoo00LmkjYoo`03001oogoo03Aoo`00=7oo00@007ooOomoo`@mk`El@:Uoo`03001oogoo03=o
o`00<Woo0P000goo13g_00Am87a0O41l809l@:Yoo`03001oogoo039oo`00<Goo00<007ooOol00Woo
1Cg_00Am87a0O41l809l@:]oo`03001oogoo035oo`00<7oo00<007ooOol00Woo1Cg_00=mX7dPO400
17a0[7oo00<007ooOol0<7oo000`Ool00`00Oomoo`02Ool4?Nl00ghPOJ1m8004O:2^Ool00`00Oomo
o`0_Ool002moo`03001oogoo009oo`@mk`03OZ1n87gP00Am@;1oo`03001oogoo02ioo`00;Woo00<0
07ooOol00goo13g_00InX7hPON1mh7fPON2bOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`@m
k`03OZ1n87gP00=mh;=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo1Cg_00=nX7i0OT000Wi0
]Goo00<007ooOol0:goo000/Ool00`00Oomoo`03Ool6?Nl4O/2fOol00`00Oomoo`0[Ool002]oo`03
001oogoo00Aoo`Hmk`Ao`;Moo`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007oo
Ool0:Goo000YOol00`00Oomoo`05Ool5?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Dm
kl5oo`03001oogoo02Moo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000WOol00`00
Oomoo`06Ool5?No2Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Ioo`Lmkl9oo`03001oogoo02Eo
o`009Goo00<007ooOol01Woo23g_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool0
0`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol0
1Woo1cg_b7oo00<007ooOol08Woo000ROol00`00Oomoo`06Ool8?No9Ool00`00Oomoo`0QOol0029o
o`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Goo00<007ooOol01Woo23g_bgoo00<007oo
Ool087oo000POol00`00Oomoo`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lm
klmoo`03001oogoo01moo`007goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00
Oomoo`06Ool6?NoBOol00`00Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eo
o`007Goo00<007ooOol01goo1cg_dgoo00<007ooOol077oo000MOol00`00Oomoo`06Ool8?NoCOol0
0`00Oomoo`0LOol001aoo`03001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol0
1Goo2Cg_eGoo00<007ooOol06goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]o
o`03001oogoo00Eoo`TmkmMoo`03001oogoo01Yoo`006Woo00<007ooOol01Woo2Cg_f7oo00<007oo
Ool06Goo000JOol00`00Oomoo`06Ool8?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Ioo`Pm
km]oo`03001oogoo01Qoo`006Goo00<007ooOol01Woo1cg_g7oo00<007ooOol067oo000HOol00`00
Oomoo`05Ool8?NoNOol00`00Oomoo`0GOol001Qoo`03001oogoo00Eoo`Lmkmmoo`03001oogoo01Mo
o`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`05Ool8?NoPOol0
0`00Oomoo`0FOol001Moo`03001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol0
1Goo23g_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eo
o`03001oogoo00Ioo`HmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007oo
Ool057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`Hm
knMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00
Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019o
o`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol0
0`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol0
1goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015o
o`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007oo
Ool047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hm
kneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00mo
o`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol0
2Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007oo
Ool03Goo000>Ool00`00Oomoo`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`Xm
knUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00
Oomoo`0=Ool<?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00ao
o`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo3Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007oo
Ool02Goo3Cg_jgoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qooa0mknUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<0
07ooOol037oo000<Ool00`00Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Mo
o`/mk`Aoo`DmknQoo`03001oogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo
000<Ool00`00Oomoo`05OolH?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03
001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]o
o`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo
000<Ool00`00Oomoo`0IOol6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03
001oogoo00]oo`0037oo00<007ooOol067oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`0H
Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`003Goo
00<007ooOol05goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`0KOol7?NoOOol00`00Oomo
o`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_
gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Tmkmaoo`03
001oogoo00aoo`003Goo00<007ooOol077oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0M
Ool:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`TmkmYoo`03001oogoo00aoo`003Woo
00<007ooOol07Woo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomoo`0NOol5?NoLOol00`00Oomo
o`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol0
3Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00io
o`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@
Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03
001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007oo
Ool0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo
0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo
00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03
001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007oo
Ool05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo
01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0G
Ool001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo
000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`00
6Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]o
o`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol0
0`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<0
07ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001o
ogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomo
o`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0
fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Mo
o`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol0
0`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<0
07ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001o
ogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomo
o`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0
:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yo
o`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool0
02ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_
Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo
00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03
001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00
Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007oo
Ool0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<0
07ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001o
ogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomo
o`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00
Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo
0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>
Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo
0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00
Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2
001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017
Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol0
07Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol008]oo`8000Eoo`03001oogoo08]oo`00RWoo00@007ooOol000Ao
o`03001oogoo08]oo`00S7oo00<007ooOol00goo00<007ooOol0Rgoo002=Ool00`00Oomoo`03Ool0
0`00Oomoo`2:Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002;Ool20003Ool4002<Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(38)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
1 .981 0 r
.008 w
.20672 .16354 Mdot
.016 w
.20672 .16354 m
.2067 .16331 L
s
1 .962 0 r
.008 w
.2067 .16331 Mdot
.016 w
.2067 .16331 m
.20674 .1629 L
s
1 .942 0 r
.008 w
.20674 .1629 Mdot
.016 w
.20674 .1629 m
.20685 .16229 L
s
1 .923 0 r
.008 w
.20685 .16229 Mdot
.016 w
.20685 .16229 m
.20704 .16145 L
s
1 .904 0 r
.008 w
.20704 .16145 Mdot
.016 w
.20704 .16145 m
.20732 .16037 L
s
1 .885 0 r
.008 w
.20732 .16037 Mdot
.016 w
.20732 .16037 m
.20767 .15917 L
s
1 .865 0 r
.008 w
.20767 .15917 Mdot
.016 w
.20767 .15917 m
.20809 .15772 L
s
1 .846 0 r
.008 w
.20809 .15772 Mdot
.016 w
.20809 .15772 m
.20855 .15605 L
s
1 .827 0 r
.008 w
.20855 .15605 Mdot
.016 w
.20855 .15605 m
.20901 .15442 L
s
1 .808 0 r
.008 w
.20901 .15442 Mdot
.016 w
.20901 .15442 m
.2095 .15265 L
s
1 .788 0 r
.008 w
.2095 .15265 Mdot
.016 w
.2095 .15265 m
.20998 .15075 L
s
1 .769 0 r
.008 w
.20998 .15075 Mdot
.016 w
.20998 .15075 m
.21039 .14917 L
s
1 .75 0 r
.008 w
.21039 .14917 Mdot
.016 w
.21039 .14917 m
.21074 .14767 L
s
1 .731 0 r
.008 w
.21074 .14767 Mdot
.016 w
.21074 .14767 m
.21105 .14628 L
s
1 .712 0 r
.008 w
.21105 .14628 Mdot
.016 w
.21105 .14628 m
.21129 .14511 L
s
1 .692 0 r
.008 w
.21129 .14511 Mdot
.016 w
.21129 .14511 m
.21145 .1442 L
s
1 .673 0 r
.008 w
.21145 .1442 Mdot
.016 w
.21145 .1442 m
.21158 .14351 L
s
1 .654 0 r
.008 w
.21158 .14351 Mdot
.016 w
.21158 .14351 m
.21172 .14304 L
s
1 .635 0 r
.008 w
.21172 .14304 Mdot
.016 w
.21172 .14304 m
.21189 .1427 L
s
1 .615 0 r
.008 w
.21189 .1427 Mdot
.016 w
.21189 .1427 m
.21213 .14245 L
s
1 .596 0 r
.008 w
.21213 .14245 Mdot
.016 w
.21213 .14245 m
.21248 .14222 L
s
1 .577 0 r
.008 w
.21248 .14222 Mdot
.016 w
.21248 .14222 m
.21297 .14199 L
s
1 .558 0 r
.008 w
.21297 .14199 Mdot
.016 w
.21297 .14199 m
.21362 .14172 L
s
1 .538 0 r
.008 w
.21362 .14172 Mdot
.016 w
.21362 .14172 m
.21436 .14139 L
s
1 .519 0 r
.008 w
.21436 .14139 Mdot
.016 w
.21436 .14139 m
.21528 .14101 L
s
1 .5 0 r
.008 w
.21528 .14101 Mdot
.016 w
.21528 .14101 m
.21627 .14054 L
s
1 .481 0 r
.008 w
.21627 .14054 Mdot
.016 w
.21627 .14054 m
.2174 .13996 L
s
1 .462 0 r
.008 w
.2174 .13996 Mdot
.016 w
.2174 .13996 m
.21865 .13924 L
s
1 .442 0 r
.008 w
.21865 .13924 Mdot
.016 w
.21865 .13924 m
.21981 .13839 L
s
1 .423 0 r
.008 w
.21981 .13839 Mdot
.016 w
.21981 .13839 m
.22104 .1375 L
s
1 .404 0 r
.008 w
.22104 .1375 Mdot
.016 w
.22104 .1375 m
.22235 .13657 L
s
1 .385 0 r
.008 w
.22235 .13657 Mdot
.016 w
.22235 .13657 m
.22363 .13565 L
s
1 .365 0 r
.008 w
.22363 .13565 Mdot
.016 w
.22363 .13565 m
.22494 .13474 L
s
1 .346 0 r
.008 w
.22494 .13474 Mdot
.016 w
.22494 .13474 m
.22621 .13386 L
s
1 .327 0 r
.008 w
.22621 .13386 Mdot
.016 w
.22621 .13386 m
.22753 .13307 L
s
1 .308 0 r
.008 w
.22753 .13307 Mdot
.016 w
.22753 .13307 m
.22878 .13227 L
s
1 .288 0 r
.008 w
.22878 .13227 Mdot
.016 w
.22878 .13227 m
.23007 .13147 L
s
1 .269 0 r
.008 w
.23007 .13147 Mdot
.016 w
.23007 .13147 m
.23132 .1307 L
s
1 .25 0 r
.008 w
.23132 .1307 Mdot
.016 w
.23132 .1307 m
.23259 .12994 L
s
1 .231 0 r
.008 w
.23259 .12994 Mdot
.016 w
.23259 .12994 m
.23379 .12921 L
s
1 .212 0 r
.008 w
.23379 .12921 Mdot
.016 w
.23379 .12921 m
.23489 .12851 L
s
1 .192 0 r
.008 w
.23489 .12851 Mdot
.016 w
.23489 .12851 m
.23596 .12786 L
s
1 .173 0 r
.008 w
.23596 .12786 Mdot
.016 w
.23596 .12786 m
.23694 .12728 L
s
1 .154 0 r
.008 w
.23694 .12728 Mdot
.016 w
.23694 .12728 m
.23779 .12681 L
s
1 .135 0 r
.008 w
.23779 .12681 Mdot
.016 w
.23779 .12681 m
.23853 .12641 L
s
1 .115 0 r
.008 w
.23853 .12641 Mdot
.016 w
.23853 .12641 m
.23916 .12607 L
s
1 .096 0 r
.008 w
.23916 .12607 Mdot
.016 w
.23916 .12607 m
.23965 .12575 L
s
1 .077 0 r
.008 w
.23965 .12575 Mdot
.016 w
.23965 .12575 m
.24002 .12547 L
s
1 .058 0 r
.008 w
.24002 .12547 Mdot
.016 w
.24002 .12547 m
.2403 .12523 L
s
1 .038 0 r
.008 w
.2403 .12523 Mdot
.016 w
.2403 .12523 m
.24049 .12506 L
s
1 .019 0 r
.008 w
.24049 .12506 Mdot
.016 w
.24049 .12506 m
.24062 .12497 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@00:7oo1P00Mgoo001YOol@?Nl`Ool5001bOol006Mooa<mkcAoo`@006io
o`00IGoo5Cg_>7oo1000JWoo001TOolF?NllOol3001WOol006=ooaLmkcmoo`<006Aoo`00H7oo43g_
1Woo13g_@Woo0`00HGoo001NOolB?Nl7Ool2?Nm6Ool2001OOol005aooa8mke=oo`8005eoo`00FWoo
00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol00`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEo
o`<005Ioo`00Dgoo0P000goo23g_JWoo0P00E7oo001AOol20004Ool8?Nm]Ool2001BOol0051oo`03
001oogoo00=oo`Tmkfmoo`03001oogoo04moo`00Cgoo00<007ooOol00Woo2cg_L7oo00<007ooOol0
CWoo001=Ool20003Ool<?NmbOol2001>Ool004]oo`8000Eoo`TmkgMoo`8004aoo`00BGoo0P0017oo
2cg_NWoo0P00BWoo0018Ool00`00Oomoo`02Ool=?NmlOol00`00Oomoo`17Ool004Ioo`8000Aoo`hm
kgeoo`8004Moo`00AGoo00@007ooOomooa0mkh1oo`03001oogoo04Aoo`00A7oo00<007ooOol03cg_
Q7oo00<007ooOol0@goo0013Ool00`00Oolmk`0;?Nn:Ool00`00Oomoo`12Ool0045oo`800003Oolm
kcg_00Xmkhaoo`80049oo`00@7oo00<007ooOol00Sg_0WaP00=l07aPO6000cg_TGoo00<007ooOol0
?goo000oOol01P00Oomoocg_O>1l`09lH003O01lH7aP008mki=oo`8003moo`00?Woo00L007ooOomm
H7dPO>1l`002O60017`PO61lH3g_UWoo00<007ooOol0?7oo000lOol20002Ool01Gf0OF1m87cPO<00
1GaPV7oo00<007ooOol0>goo000kOol02P00OolmkghPOL1mP7ePOB1lh7c017bPVWoo00<007ooOol0
>Woo000jOol02@00Oolmkcg_OR1m`7f0OF1m8004O@000cg_Oomoo`2JOol2000jOol003Uoo`08001o
ocg_?Nmnh7hPOL1mP0AmH003?Nmoogoo09ioo`03001oogoo03Moo`00=goo0P0000Ioocg_?NlmkgkP
OR05OL02?NnQOol00`00Oomoo`0fOol003Ioo`03001oogoo00@mk`03O^1n@7i0009n@:Ioo`03001o
ogoo03Eoo`00=Goo00<007ooOol01Cg_00=nh7k0O/000Wk0Ygoo00<007ooOol0=7oo000dOol01000
Oomoogoo13g_00=o`7l0O`000Wl0ZGoo00<007ooOol0<goo000bOol20003Ool5?Nl00go0Ob1o8002
Ob2ZOol00`00Oomoo`0bOol0035oo`03001oogoo009oo`Hmk`03Ol1oH7mP009oH:]oo`03001oogoo
035oo`00<7oo00<007ooOol00Woo1cg_00=o`7n0Oh000Wn0[7oo00<007ooOol0<7oo000`Ool00`00
Oomoo`02Ool;?Nn^Ool00`00Oomoo`0_Ool002moo`03001oogoo009oo`Xmkk5oo`03001oogoo02io
o`00;Woo00<007ooOol00goo2Sg_/Woo00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool:?NncOol0
0`00Oomoo`0/Ool002aoo`03001oogoo00Aoo`XmkkEoo`03001oogoo02]oo`00;7oo00<007ooOol0
0goo2Sg_]Woo00<007ooOol0:goo000[Ool00`00Oomoo`04Ool:?NngOol00`00Oomoo`0ZOol002Yo
o`03001oogoo00Aoo`Dmkkioo`03001oogoo02Uoo`00:Goo00<007ooOol01Goo1Cg__goo00<007oo
Ool0:7oo000XOol00`00Oomoo`05Ool5?No1Ool00`00Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dm
kl5oo`03001oogoo02Moo`009goo00<007ooOol01Woo1Cg_`Woo00<007ooOol09Woo000VOol00`00
Oomoo`06Ool7?No2Ool00`00Oomoo`0UOol002Eoo`03001oogoo00Ioo`Pmkl=oo`03001oogoo02Ao
o`0097oo00<007ooOol01Woo23g_aGoo00<007ooOol08goo000TOol00`00Oomoo`05Ool8?No6Ool0
0`00Oomoo`0SOol002=oo`03001oogoo00Ioo`LmklQoo`03001oogoo029oo`008Woo00<007ooOol0
1Woo23g_bGoo00<007ooOol08Goo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0025o
o`03001oogoo00Ioo`Pmkl]oo`03001oogoo021oo`0087oo00<007ooOol01Woo23g_cGoo00<007oo
Ool07goo000POol00`00Oomoo`05Ool7?No?Ool00`00Oomoo`0OOol001moo`03001oogoo00Ioo`Hm
km5oo`03001oogoo01ioo`007goo00<007ooOol01Woo1Sg_dWoo00<007ooOol07Goo000NOol00`00
Oomoo`06Ool7?NoBOol00`00Oomoo`0MOol001eoo`03001oogoo00Moo`Lmkm=oo`03001oogoo01ao
o`007Goo00<007ooOol01Woo23g_dgoo00<007ooOol077oo000LOol00`00Oomoo`06Ool8?NoEOol0
0`00Oomoo`0KOol001aoo`03001oogoo00Eoo`TmkmEoo`03001oogoo01]oo`006goo00<007ooOol0
1Woo2Cg_eWoo00<007ooOol06Woo000KOol00`00Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yo
o`03001oogoo00Ioo`TmkmQoo`03001oogoo01Uoo`006Woo00<007ooOol01Woo23g_fGoo00<007oo
Ool06Goo000IOol00`00Oomoo`06Ool8?NoKOol00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lm
kmaoo`03001oogoo01Qoo`0067oo00<007ooOol01Goo23g_gWoo00<007ooOol05goo000HOol00`00
Oomoo`05Ool7?NoOOol00`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Mo
o`005goo00<007ooOol01Goo23g_h7oo00<007ooOol05Woo000GOol00`00Oomoo`04Ool8?NoQOol0
0`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<007ooOol0
1Goo1Sg_i7oo00<007ooOol05Goo000EOol00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eo
o`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007oo
Ool057oo000DOol00`00Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`Hm
knMoo`03001oogoo01=oo`0057oo00<007ooOol01Goo1cg_igoo00<007ooOol04goo000COol00`00
Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019o
o`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000BOol00`00Oomoo`07Ool5?No[Ool0
0`00Oomoo`0AOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol0
1Woo1Cg_k7oo00<007ooOol04Goo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015o
o`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007oo
Ool047oo000AOol00`00Oomoo`07Ool6?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dm
knioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00mo
o`003goo00<007ooOol02Goo1Sg_kWoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol0
2Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000io
o`03001oogoo00Yoo`Pmkneoo`03001oogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo00<007oo
Ool03Goo000>Ool00`00Oomoo`0<Ool:?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/m
knMoo`03001oogoo00eoo`003Woo00<007ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00
Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00ao
o`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol0
37oo23g_00=oocg_?Nl00cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoW
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo00<007oo
Ool027oo3cg_jWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qooa4mknQoo`03001oogoo00aoo`0037oo00<007ooOol027oo4cg_j7oo00<0
07ooOol02goo000<Ool00`00Oomoo`07Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00IooaLmknIoo`03001oogoo00]oo`0037oo00<007ooOol01Goo63g_iWoo00<007ooOol02goo
000<Ool00`00Oomoo`08OolE?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolm
kcg_00`mknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol0
2goo000<Ool00`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qo
o`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol06Goo1Sg_i7oo00<007ooOol02goo
000<Ool00`00Oomoo`0HOol7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03
001oogoo00]oo`0037oo00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0H
Ool:?NoQOol00`00Oomoo`0;Ool000eoo`03001oogoo01Moo`/mkn1oo`03001oogoo00]oo`003Goo
00<007ooOol06goo1cg_ggoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomo
o`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_
gWoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03
001oogoo00aoo`003Goo00<007ooOol07Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0N
Ool9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo
00<007ooOol07Woo1Cg_g7oo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool0
00ioo`03001oogoo0?moo`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?
Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo
00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03
001oogoo0?aoo`03001oogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00
Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007oo
Ool0ngoo00<007ooOol03goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo
0?Uoo`03001oogoo011oo`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3h
Ool00`00Oomoo`0@Ool0019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo
00<007ooOol04Goo000COol00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03
001oogoo019oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00
Oomoo`0BOol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007oo
Ool04goo000EOol00`00Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo
01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0D
Ool001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo
000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`00
67oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uo
o`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol0
0`00Oomoo`3XOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<0
07ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001o
ogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomo
o`3QOol00`00Oomoo`0LOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0
ggoo00<007ooOol07Goo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eo
o`03001oogoo01ioo`007goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol0
0`00Oomoo`0OOol0021oo`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<0
07ooOol087oo000ROol00`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001o
ogoo029oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomo
o`0SOol002Eoo`03001oogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol0
9Goo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Io
o`00:7oo00<007ooOol0bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol0
02Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[
Ool00`00Oomoo`35Ool00`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo
00<007ooOol0`Goo00<007ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03
001oogoo0;moo`03001oogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00
Oomoo`2kOol00`00Oomoo`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo
0P00<goo000dOol00`00Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo
03Aoo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0e
Ool003Moo`03001oogoo0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo
000iOol2002YOol2000jOol003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0
Xgoo00<007ooOol0>goo000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003mo
o`00@7oo00<007ooOol0Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo
09Eoo`03001oogoo049oo`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2A
Ool00`00Oomoo`14Ool004Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2
001;Ool004aoo`8008=oo`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00
Oomoo`1mOol00`00Oomoo`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2
001cOol2001EOol005Ioo`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001L
Ool005ioo`8005ioo`<005moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol0
06Eoo`<004moo`<006Ioo`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qo
o`@0075oo`00Lgoo1@00;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00
SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002;Ool20004Ool2002=
Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002<Ool01@00Oomoogoo00000Woo00<007oo
Ool0RWoo002=Ool01000Oomoogoo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00
Rgoo0P0017oo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(39)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
1 .996 0 r
.008 w
.24016 .12551 Mdot
.016 w
.24016 .12551 m
.24022 .12537 L
s
1 .993 0 r
.008 w
.24022 .12537 Mdot
.016 w
.24022 .12537 m
.2404 .1251 L
s
1 .989 0 r
.008 w
.2404 .1251 Mdot
.016 w
.2404 .1251 m
.24072 .12469 L
s
1 .986 0 r
.008 w
.24072 .12469 Mdot
.016 w
.24072 .12469 m
.2412 .12413 L
s
1 .982 0 r
.008 w
.2412 .12413 Mdot
.016 w
.2412 .12413 m
.24185 .12342 L
s
1 .978 0 r
.008 w
.24185 .12342 Mdot
.016 w
.24185 .12342 m
.24266 .12258 L
s
1 .975 0 r
.008 w
.24266 .12258 Mdot
.016 w
.24266 .12258 m
.2436 .12169 L
s
1 .971 0 r
.008 w
.2436 .12169 Mdot
.016 w
.2436 .12169 m
.24451 .1207 L
s
1 .968 0 r
.008 w
.24451 .1207 Mdot
.016 w
.24451 .1207 m
.24559 .11965 L
s
1 .964 0 r
.008 w
.24559 .11965 Mdot
.016 w
.24559 .11965 m
.24661 .11861 L
s
1 .96 0 r
.008 w
.24661 .11861 Mdot
.016 w
.24661 .11861 m
.2477 .11759 L
s
1 .957 0 r
.008 w
.2477 .11759 Mdot
.016 w
.2477 .11759 m
.24858 .11664 L
s
1 .953 0 r
.008 w
.24858 .11664 Mdot
.016 w
.24858 .11664 m
.24945 .11584 L
s
1 .949 0 r
.008 w
.24945 .11584 Mdot
.016 w
.24945 .11584 m
.25028 .11515 L
s
1 .946 0 r
.008 w
.25028 .11515 Mdot
.016 w
.25028 .11515 m
.25103 .11461 L
s
1 .942 0 r
.008 w
.25103 .11461 Mdot
.016 w
.25103 .11461 m
.25166 .11422 L
s
1 .939 0 r
.008 w
.25166 .11422 Mdot
.016 w
.25166 .11422 m
.25225 .11399 L
s
1 .935 0 r
.008 w
.25225 .11399 Mdot
.016 w
.25225 .11399 m
.25283 .11392 L
s
1 .931 0 r
.008 w
.25283 .11392 Mdot
.016 w
.25283 .11392 m
.25346 .11397 L
s
1 .928 0 r
.008 w
.25346 .11397 Mdot
.016 w
.25346 .11397 m
.25416 .11407 L
s
1 .924 0 r
.008 w
.25416 .11407 Mdot
.016 w
.25416 .11407 m
.25496 .11417 L
s
1 .921 0 r
.008 w
.25496 .11417 Mdot
.016 w
.25496 .11417 m
.25584 .1142 L
s
1 .917 0 r
.008 w
.25584 .1142 Mdot
.016 w
.25584 .1142 m
.25675 .11417 L
s
1 .913 0 r
.008 w
.25675 .11417 Mdot
.016 w
.25675 .11417 m
.2577 .11407 L
s
1 .91 0 r
.008 w
.2577 .11407 Mdot
.016 w
.2577 .11407 m
.25874 .11389 L
s
1 .906 0 r
.008 w
.25874 .11389 Mdot
.016 w
.25874 .11389 m
.25992 .11367 L
s
1 .903 0 r
.008 w
.25992 .11367 Mdot
.016 w
.25992 .11367 m
.26117 .11347 L
s
1 .899 0 r
.008 w
.26117 .11347 Mdot
.016 w
.26117 .11347 m
.26246 .11332 L
s
1 .895 0 r
.008 w
.26246 .11332 Mdot
.016 w
.26246 .11332 m
.26376 .11325 L
s
1 .892 0 r
.008 w
.26376 .11325 Mdot
.016 w
.26376 .11325 m
.26507 .11321 L
s
1 .888 0 r
.008 w
.26507 .11321 Mdot
.016 w
.26507 .11321 m
.26635 .11319 L
s
1 .884 0 r
.008 w
.26635 .11319 Mdot
.016 w
.26635 .11319 m
.26759 .1132 L
s
1 .881 0 r
.008 w
.26759 .1132 Mdot
.016 w
.26759 .1132 m
.2688 .11325 L
s
1 .877 0 r
.008 w
.2688 .11325 Mdot
.016 w
.2688 .11325 m
.26987 .11331 L
s
1 .874 0 r
.008 w
.26987 .11331 Mdot
.016 w
.26987 .11331 m
.27089 .11342 L
s
1 .87 0 r
.008 w
.27089 .11342 Mdot
.016 w
.27089 .11342 m
.27182 .11357 L
s
1 .866 0 r
.008 w
.27182 .11357 Mdot
.016 w
.27182 .11357 m
.2726 .11373 L
s
1 .863 0 r
.008 w
.2726 .11373 Mdot
.016 w
.2726 .11373 m
.2732 .11386 L
s
1 .859 0 r
.008 w
.2732 .11386 Mdot
.016 w
.2732 .11386 m
.27365 .11393 L
s
1 .856 0 r
.008 w
.27365 .11393 Mdot
.016 w
.27365 .11393 m
.27398 .11392 L
s
1 .852 0 r
.008 w
.27398 .11392 Mdot
.016 w
.27398 .11392 m
.27419 .1138 L
s
1 .848 0 r
.008 w
.27419 .1138 Mdot
.016 w
.27419 .1138 m
.27433 .11356 L
s
1 .845 0 r
.008 w
.27433 .11356 Mdot
.016 w
.27433 .11356 m
.27444 .11313 L
s
1 .841 0 r
.008 w
.27444 .11313 Mdot
.016 w
.27444 .11313 m
.27453 .11254 L
s
1 .838 0 r
.008 w
.27453 .11254 Mdot
.016 w
.27453 .11254 m
.27464 .11191 L
s
1 .834 0 r
.008 w
.27464 .11191 Mdot
.016 w
.27464 .11191 m
.2748 .11122 L
s
1 .83 0 r
.008 w
.2748 .11122 Mdot
.016 w
.2748 .11122 m
.27503 .11051 L
s
1 .827 0 r
.008 w
.27503 .11051 Mdot
.016 w
.27503 .11051 m
.27533 .10979 L
s
1 .823 0 r
.008 w
.27533 .10979 Mdot
.016 w
.27533 .10979 m
.27565 .10908 L
s
1 .819 0 r
.008 w
.27565 .10908 Mdot
.016 w
.27565 .10908 m
.27603 .1084 L
s
1 .816 0 r
.008 w
.27603 .1084 Mdot
.016 w
.27603 .1084 m
.27646 .10777 L
s
1 .812 0 r
.008 w
.27646 .10777 Mdot
.016 w
.27646 .10777 m
.27695 .1072 L
s
1 .809 0 r
.008 w
.27695 .1072 Mdot
.016 w
.27695 .1072 m
.27745 .10671 L
s
1 .805 0 r
.008 w
.27745 .10671 Mdot
.016 w
.27745 .10671 m
.27793 .10634 L
s
1 .801 0 r
.008 w
.27793 .10634 Mdot
.016 w
.27793 .10634 m
.27836 .1061 L
s
1 .798 0 r
.008 w
.27836 .1061 Mdot
.016 w
.27836 .1061 m
.27872 .10598 L
s
1 .794 0 r
.008 w
.27872 .10598 Mdot
.016 w
.27872 .10598 m
.27903 .10595 L
s
1 .791 0 r
.008 w
.27903 .10595 Mdot
.016 w
.27903 .10595 m
.27929 .106 L
s
1 .787 0 r
.008 w
.27929 .106 Mdot
.016 w
.27929 .106 m
.27953 .10606 L
s
1 .783 0 r
.008 w
.27953 .10606 Mdot
.016 w
.27953 .10606 m
.27978 .10609 L
s
1 .78 0 r
.008 w
.27978 .10609 Mdot
.016 w
.27978 .10609 m
.28007 .10603 L
s
1 .776 0 r
.008 w
.28007 .10603 Mdot
.016 w
.28007 .10603 m
.28041 .10584 L
s
1 .773 0 r
.008 w
.28041 .10584 Mdot
.016 w
.28041 .10584 m
.28081 .10546 L
s
1 .769 0 r
.008 w
.28081 .10546 Mdot
.016 w
.28081 .10546 m
.28126 .10484 L
s
1 .765 0 r
.008 w
.28126 .10484 Mdot
.016 w
.28126 .10484 m
.2818 .10396 L
s
1 .762 0 r
.008 w
.2818 .10396 Mdot
.016 w
.2818 .10396 m
.28244 .10288 L
s
1 .758 0 r
.008 w
.28244 .10288 Mdot
.016 w
.28244 .10288 m
.28315 .1015 L
s
1 .755 0 r
.008 w
.28315 .1015 Mdot
.016 w
.28315 .1015 m
.28403 .09999 L
s
1 .751 0 r
.008 w
.28403 .09999 Mdot
.016 w
.28403 .09999 m
.28499 .09825 L
s
1 .747 0 r
.008 w
.28499 .09825 Mdot
.016 w
.28499 .09825 m
.28612 .09635 L
s
1 .744 0 r
.008 w
.28612 .09635 Mdot
.016 w
.28612 .09635 m
.28742 .09438 L
s
1 .74 0 r
.008 w
.28742 .09438 Mdot
.016 w
.28742 .09438 m
.28888 .09248 L
s
1 .736 0 r
.008 w
.28888 .09248 Mdot
.016 w
.28888 .09248 m
.29057 .09049 L
s
1 .733 0 r
.008 w
.29057 .09049 Mdot
.016 w
.29057 .09049 m
.2922 .08873 L
s
1 .729 0 r
.008 w
.2922 .08873 Mdot
.016 w
.2922 .08873 m
.29406 .0869 L
s
1 .726 0 r
.008 w
.29406 .0869 Mdot
.016 w
.29406 .0869 m
.29577 .08537 L
s
1 .722 0 r
.008 w
.29577 .08537 Mdot
.016 w
.29577 .08537 m
.29772 .08389 L
s
1 .718 0 r
.008 w
.29772 .08389 Mdot
.016 w
.29772 .08389 m
.29967 .0826 L
s
1 .715 0 r
.008 w
.29967 .0826 Mdot
.016 w
.29967 .0826 m
.30176 .0814 L
s
1 .711 0 r
.008 w
.30176 .0814 Mdot
.016 w
.30176 .0814 m
.30398 .08027 L
s
1 .708 0 r
.008 w
.30398 .08027 Mdot
.016 w
.30398 .08027 m
.30609 .07921 L
s
1 .704 0 r
.008 w
.30609 .07921 Mdot
.016 w
.30609 .07921 m
.30825 .07826 L
s
1 .7 0 r
.008 w
.30825 .07826 Mdot
.016 w
.30825 .07826 m
.3104 .07729 L
s
1 .697 0 r
.008 w
.3104 .07729 Mdot
.016 w
.3104 .07729 m
.31248 .07628 L
s
1 .693 0 r
.008 w
.31248 .07628 Mdot
.016 w
.31248 .07628 m
.31458 .07518 L
s
1 .69 0 r
.008 w
.31458 .07518 Mdot
.016 w
.31458 .07518 m
.31668 .07405 L
s
1 .686 0 r
.008 w
.31668 .07405 Mdot
.016 w
.31668 .07405 m
.31875 .07276 L
s
1 .682 0 r
.008 w
.31875 .07276 Mdot
.016 w
.31875 .07276 m
.32101 .07128 L
s
1 .679 0 r
.008 w
.32101 .07128 Mdot
.016 w
.32101 .07128 m
.32313 .06976 L
s
1 .675 0 r
.008 w
.32313 .06976 Mdot
.016 w
.32313 .06976 m
.32538 .06812 L
s
1 .671 0 r
.008 w
.32538 .06812 Mdot
.016 w
.32538 .06812 m
.32775 .06644 L
s
1 .668 0 r
.008 w
.32775 .06644 Mdot
.016 w
.32775 .06644 m
.32997 .06462 L
s
1 .664 0 r
.008 w
.32997 .06462 Mdot
.016 w
.32997 .06462 m
.33231 .0629 L
s
1 .661 0 r
.008 w
.33231 .0629 Mdot
.016 w
.33231 .0629 m
.33478 .06109 L
s
1 .657 0 r
.008 w
.33478 .06109 Mdot
.016 w
.33478 .06109 m
.3371 .05923 L
s
1 .653 0 r
.008 w
.3371 .05923 Mdot
.016 w
.3371 .05923 m
.33952 .05767 L
s
1 .65 0 r
.008 w
.33952 .05767 Mdot
.016 w
.33952 .05767 m
.34202 .05612 L
s
1 .646 0 r
.008 w
.34202 .05612 Mdot
.016 w
.34202 .05612 m
.34432 .05461 L
s
1 .643 0 r
.008 w
.34432 .05461 Mdot
.016 w
.34432 .05461 m
.34663 .05326 L
s
1 .639 0 r
.008 w
.34663 .05326 Mdot
.016 w
.34663 .05326 m
.34879 .05206 L
s
1 .635 0 r
.008 w
.34879 .05206 Mdot
.016 w
.34879 .05206 m
.35084 .05097 L
s
1 .632 0 r
.008 w
.35084 .05097 Mdot
.016 w
.35084 .05097 m
.35252 .05001 L
s
1 .628 0 r
.008 w
.35252 .05001 Mdot
.016 w
.35252 .05001 m
.35404 .04914 L
s
1 .625 0 r
.008 w
.35404 .04914 Mdot
.016 w
.35404 .04914 m
.3553 .04838 L
s
1 .621 0 r
.008 w
.3553 .04838 Mdot
.016 w
.3553 .04838 m
.35635 .04771 L
s
1 .617 0 r
.008 w
.35635 .04771 Mdot
.016 w
.35635 .04771 m
.35715 .04714 L
s
1 .614 0 r
.008 w
.35715 .04714 Mdot
.016 w
.35715 .04714 m
.35774 .04667 L
s
1 .61 0 r
.008 w
.35774 .04667 Mdot
.016 w
.35774 .04667 m
.35814 .04625 L
s
1 .606 0 r
.008 w
.35814 .04625 Mdot
.016 w
.35814 .04625 m
.35837 .04589 L
s
1 .603 0 r
.008 w
.35837 .04589 Mdot
.016 w
.35837 .04589 m
.35845 .0456 L
s
1 .599 0 r
.008 w
.35845 .0456 Mdot
.016 w
.35845 .0456 m
.35841 .04536 L
s
1 .596 0 r
.008 w
.35841 .04536 Mdot
.016 w
.35841 .04536 m
.35829 .04517 L
s
1 .592 0 r
.008 w
.35829 .04517 Mdot
.016 w
.35829 .04517 m
.35813 .04504 L
s
1 .588 0 r
.008 w
.35813 .04504 Mdot
.016 w
.35813 .04504 m
.35797 .04498 L
s
1 .585 0 r
.008 w
.35797 .04498 Mdot
.016 w
.35797 .04498 m
.35781 .04496 L
s
1 .581 0 r
.008 w
.35781 .04496 Mdot
.016 w
.35781 .04496 m
.35768 .045 L
s
1 .578 0 r
.008 w
.35768 .045 Mdot
.016 w
.35768 .045 m
.35761 .04507 L
s
1 .574 0 r
.008 w
.35761 .04507 Mdot
.016 w
.35761 .04507 m
.35761 .04515 L
s
1 .57 0 r
.008 w
.35761 .04515 Mdot
.016 w
.35761 .04515 m
.35771 .0452 L
s
1 .567 0 r
.008 w
.35771 .0452 Mdot
.016 w
.35771 .0452 m
.35794 .04523 L
s
1 .563 0 r
.008 w
.35794 .04523 Mdot
.016 w
.35794 .04523 m
.35833 .04524 L
s
1 .56 0 r
.008 w
.35833 .04524 Mdot
.016 w
.35833 .04524 m
.35891 .04524 L
s
1 .556 0 r
.008 w
.35891 .04524 Mdot
.016 w
.35891 .04524 m
.35969 .04525 L
s
1 .552 0 r
.008 w
.35969 .04525 Mdot
.016 w
.35969 .04525 m
.36066 .04526 L
s
1 .549 0 r
.008 w
.36066 .04526 Mdot
.016 w
.36066 .04526 m
.36184 .04529 L
s
1 .545 0 r
.008 w
.36184 .04529 Mdot
.016 w
.36184 .04529 m
.36321 .04536 L
s
1 .542 0 r
.008 w
.36321 .04536 Mdot
.016 w
.36321 .04536 m
.36453 .04546 L
s
1 .538 0 r
.008 w
.36453 .04546 Mdot
.016 w
.36453 .04546 m
.36596 .04556 L
s
1 .534 0 r
.008 w
.36596 .04556 Mdot
.016 w
.36596 .04556 m
.36731 .04563 L
s
1 .531 0 r
.008 w
.36731 .04563 Mdot
.016 w
.36731 .04563 m
.3687 .04565 L
s
1 .527 0 r
.008 w
.3687 .04565 Mdot
.016 w
.3687 .04565 m
.36985 .04561 L
s
1 .523 0 r
.008 w
.36985 .04561 Mdot
.016 w
.36985 .04561 m
.37092 .04547 L
s
1 .52 0 r
.008 w
.37092 .04547 Mdot
.016 w
.37092 .04547 m
.37191 .04524 L
s
1 .516 0 r
.008 w
.37191 .04524 Mdot
.016 w
.37191 .04524 m
.37271 .04493 L
s
1 .513 0 r
.008 w
.37271 .04493 Mdot
.016 w
.37271 .04493 m
.37341 .04455 L
s
1 .509 0 r
.008 w
.37341 .04455 Mdot
.016 w
.37341 .04455 m
.37404 .04413 L
s
1 .505 0 r
.008 w
.37404 .04413 Mdot
.016 w
.37404 .04413 m
.37462 .04369 L
s
1 .502 0 r
.008 w
.37462 .04369 Mdot
.016 w
.37462 .04369 m
.37517 .04325 L
s
1 .498 0 r
.008 w
.37517 .04325 Mdot
.016 w
.37517 .04325 m
.37568 .04282 L
s
1 .495 0 r
.008 w
.37568 .04282 Mdot
.016 w
.37568 .04282 m
.37616 .04239 L
s
1 .491 0 r
.008 w
.37616 .04239 Mdot
.016 w
.37616 .04239 m
.37666 .04199 L
s
1 .487 0 r
.008 w
.37666 .04199 Mdot
.016 w
.37666 .04199 m
.37722 .04164 L
s
1 .484 0 r
.008 w
.37722 .04164 Mdot
.016 w
.37722 .04164 m
.37784 .04136 L
s
1 .48 0 r
.008 w
.37784 .04136 Mdot
.016 w
.37784 .04136 m
.37848 .04114 L
s
1 .477 0 r
.008 w
.37848 .04114 Mdot
.016 w
.37848 .04114 m
.37912 .04101 L
s
1 .473 0 r
.008 w
.37912 .04101 Mdot
.016 w
.37912 .04101 m
.37968 .04096 L
s
1 .469 0 r
.008 w
.37968 .04096 Mdot
.016 w
.37968 .04096 m
.38018 .04097 L
s
1 .466 0 r
.008 w
.38018 .04097 Mdot
.016 w
.38018 .04097 m
.3806 .04106 L
s
1 .462 0 r
.008 w
.3806 .04106 Mdot
.016 w
.3806 .04106 m
.38095 .0412 L
s
1 .458 0 r
.008 w
.38095 .0412 Mdot
.016 w
.38095 .0412 m
.38122 .0414 L
s
1 .455 0 r
.008 w
.38122 .0414 Mdot
.016 w
.38122 .0414 m
.38142 .04165 L
s
1 .451 0 r
.008 w
.38142 .04165 Mdot
.016 w
.38142 .04165 m
.38158 .04194 L
s
1 .448 0 r
.008 w
.38158 .04194 Mdot
.016 w
.38158 .04194 m
.38178 .04227 L
s
1 .444 0 r
.008 w
.38178 .04227 Mdot
.016 w
.38178 .04227 m
.38202 .04256 L
s
1 .44 0 r
.008 w
.38202 .04256 Mdot
.016 w
.38202 .04256 m
.3823 .04278 L
s
1 .437 0 r
.008 w
.3823 .04278 Mdot
.016 w
.3823 .04278 m
.3826 .04292 L
s
1 .433 0 r
.008 w
.3826 .04292 Mdot
.016 w
.3826 .04292 m
.38294 .043 L
s
1 .43 0 r
.008 w
.38294 .043 Mdot
.016 w
.38294 .043 m
.3833 .04307 L
s
1 .426 0 r
.008 w
.3833 .04307 Mdot
.016 w
.3833 .04307 m
.38366 .04315 L
s
1 .422 0 r
.008 w
.38366 .04315 Mdot
.016 w
.38366 .04315 m
.38403 .04324 L
s
1 .419 0 r
.008 w
.38403 .04324 Mdot
.016 w
.38403 .04324 m
.38441 .04335 L
s
1 .415 0 r
.008 w
.38441 .04335 Mdot
.016 w
.38441 .04335 m
.3848 .04348 L
s
1 .412 0 r
.008 w
.3848 .04348 Mdot
.016 w
.3848 .04348 m
.38525 .04358 L
s
1 .408 0 r
.008 w
.38525 .04358 Mdot
.016 w
.38525 .04358 m
.38579 .04366 L
s
1 .404 0 r
.008 w
.38579 .04366 Mdot
.016 w
.38579 .04366 m
.38641 .04373 L
s
1 .401 0 r
.008 w
.38641 .04373 Mdot
.016 w
.38641 .04373 m
.3872 .04383 L
s
1 .397 0 r
.008 w
.3872 .04383 Mdot
.016 w
.3872 .04383 m
.38798 .04398 L
s
1 .394 0 r
.008 w
.38798 .04398 Mdot
.016 w
.38798 .04398 m
.38898 .04428 L
s
1 .39 0 r
.008 w
.38898 .04428 Mdot
.016 w
.38898 .04428 m
.39016 .04471 L
s
1 .386 0 r
.008 w
.39016 .04471 Mdot
.016 w
.39016 .04471 m
.39139 .04528 L
s
1 .383 0 r
.008 w
.39139 .04528 Mdot
.016 w
.39139 .04528 m
.39285 .04594 L
s
1 .379 0 r
.008 w
.39285 .04594 Mdot
.016 w
.39285 .04594 m
.39439 .04664 L
s
1 .375 0 r
.008 w
.39439 .04664 Mdot
.016 w
.39439 .04664 m
.39621 .04734 L
s
1 .372 0 r
.008 w
.39621 .04734 Mdot
.016 w
.39621 .04734 m
.39826 .048 L
s
1 .368 0 r
.008 w
.39826 .048 Mdot
.016 w
.39826 .048 m
.40015 .04858 L
s
1 .365 0 r
.008 w
.40015 .04858 Mdot
.016 w
.40015 .04858 m
.40225 .04906 L
s
1 .361 0 r
.008 w
.40225 .04906 Mdot
.016 w
.40225 .04906 m
.40436 .04952 L
s
1 .357 0 r
.008 w
.40436 .04952 Mdot
.016 w
.40436 .04952 m
.40648 .04995 L
s
1 .354 0 r
.008 w
.40648 .04995 Mdot
.016 w
.40648 .04995 m
.4087 .05037 L
s
1 .35 0 r
.008 w
.4087 .05037 Mdot
.016 w
.4087 .05037 m
.41075 .05077 L
s
1 .347 0 r
.008 w
.41075 .05077 Mdot
.016 w
.41075 .05077 m
.41277 .05113 L
s
1 .343 0 r
.008 w
.41277 .05113 Mdot
.016 w
.41277 .05113 m
.41472 .05144 L
s
1 .339 0 r
.008 w
.41472 .05144 Mdot
.016 w
.41472 .05144 m
.41647 .05166 L
s
1 .336 0 r
.008 w
.41647 .05166 Mdot
.016 w
.41647 .05166 m
.4182 .05177 L
s
1 .332 0 r
.008 w
.4182 .05177 Mdot
.016 w
.4182 .05177 m
.41971 .05178 L
s
1 .329 0 r
.008 w
.41971 .05178 Mdot
.016 w
.41971 .05178 m
.42102 .05167 L
s
1 .325 0 r
.008 w
.42102 .05167 Mdot
.016 w
.42102 .05167 m
.42201 .05147 L
s
1 .321 0 r
.008 w
.42201 .05147 Mdot
.016 w
.42201 .05147 m
.42277 .0512 L
s
1 .318 0 r
.008 w
.42277 .0512 Mdot
.016 w
.42277 .0512 m
.4233 .05091 L
s
1 .314 0 r
.008 w
.4233 .05091 Mdot
.016 w
.4233 .05091 m
.42368 .0506 L
s
1 .31 0 r
.008 w
.42368 .0506 Mdot
.016 w
.42368 .0506 m
.42394 .05028 L
s
1 .307 0 r
.008 w
.42394 .05028 Mdot
.016 w
.42394 .05028 m
.42415 .04994 L
s
1 .303 0 r
.008 w
.42415 .04994 Mdot
.016 w
.42415 .04994 m
.42439 .04955 L
s
1 .3 0 r
.008 w
.42439 .04955 Mdot
.016 w
.42439 .04955 m
.42474 .04912 L
s
1 .296 0 r
.008 w
.42474 .04912 Mdot
.016 w
.42474 .04912 m
.42526 .04861 L
s
1 .292 0 r
.008 w
.42526 .04861 Mdot
.016 w
.42526 .04861 m
.42598 .04803 L
s
1 .289 0 r
.008 w
.42598 .04803 Mdot
.016 w
.42598 .04803 m
.42689 .04737 L
s
1 .285 0 r
.008 w
.42689 .04737 Mdot
.016 w
.42689 .04737 m
.42794 .0466 L
s
1 .282 0 r
.008 w
.42794 .0466 Mdot
.016 w
.42794 .0466 m
.4292 .04596 L
s
1 .278 0 r
.008 w
.4292 .04596 Mdot
.016 w
.4292 .04596 m
.43065 .04526 L
s
1 .274 0 r
.008 w
.43065 .04526 Mdot
.016 w
.43065 .04526 m
.43227 .0446 L
s
1 .271 0 r
.008 w
.43227 .0446 Mdot
.016 w
.43227 .0446 m
.43392 .04401 L
s
1 .267 0 r
.008 w
.43392 .04401 Mdot
.016 w
.43392 .04401 m
.43556 .04344 L
s
1 .264 0 r
.008 w
.43556 .04344 Mdot
.016 w
.43556 .04344 m
.43721 .04287 L
s
1 .26 0 r
.008 w
.43721 .04287 Mdot
.016 w
.43721 .04287 m
.43852 .04234 L
s
1 .256 0 r
.008 w
.43852 .04234 Mdot
.016 w
.43852 .04234 m
.43969 .04182 L
s
1 .253 0 r
.008 w
.43969 .04182 Mdot
.016 w
.43969 .04182 m
.44058 .04137 L
s
1 .249 0 r
.008 w
.44058 .04137 Mdot
.016 w
.44058 .04137 m
.4413 .04101 L
s
1 .245 0 r
.008 w
.4413 .04101 Mdot
.016 w
.4413 .04101 m
.44182 .04077 L
s
1 .242 0 r
.008 w
.44182 .04077 Mdot
.016 w
.44182 .04077 m
.44214 .04065 L
s
1 .238 0 r
.008 w
.44214 .04065 Mdot
.016 w
.44214 .04065 m
.44237 .04064 L
s
1 .235 0 r
.008 w
.44237 .04064 Mdot
.016 w
.44237 .04064 m
.44262 .04069 L
s
1 .231 0 r
.008 w
.44262 .04069 Mdot
.016 w
.44262 .04069 m
.44298 .04078 L
s
1 .227 0 r
.008 w
.44298 .04078 Mdot
.016 w
.44298 .04078 m
.44348 .04086 L
s
1 .224 0 r
.008 w
.44348 .04086 Mdot
.016 w
.44348 .04086 m
.44419 .04093 L
s
1 .22 0 r
.008 w
.44419 .04093 Mdot
.016 w
.44419 .04093 m
.44513 .04098 L
s
1 .217 0 r
.008 w
.44513 .04098 Mdot
.016 w
.44513 .04098 m
.44633 .04102 L
s
1 .213 0 r
.008 w
.44633 .04102 Mdot
.016 w
.44633 .04102 m
.44759 .04106 L
s
1 .209 0 r
.008 w
.44759 .04106 Mdot
.016 w
.44759 .04106 m
.44929 .04113 L
s
1 .206 0 r
.008 w
.44929 .04113 Mdot
.016 w
.44929 .04113 m
.45106 .04124 L
s
1 .202 0 r
.008 w
.45106 .04124 Mdot
.016 w
.45106 .04124 m
.45309 .04138 L
s
1 .199 0 r
.008 w
.45309 .04138 Mdot
.016 w
.45309 .04138 m
.45538 .04156 L
s
1 .195 0 r
.008 w
.45538 .04156 Mdot
.016 w
.45538 .04156 m
.45752 .04178 L
s
1 .191 0 r
.008 w
.45752 .04178 Mdot
.016 w
.45752 .04178 m
.45987 .04203 L
s
1 .188 0 r
.008 w
.45987 .04203 Mdot
.016 w
.45987 .04203 m
.46208 .04229 L
s
1 .184 0 r
.008 w
.46208 .04229 Mdot
.016 w
.46208 .04229 m
.46425 .04257 L
s
1 .181 0 r
.008 w
.46425 .04257 Mdot
.016 w
.46425 .04257 m
.46633 .04285 L
s
1 .177 0 r
.008 w
.46633 .04285 Mdot
.016 w
.46633 .04285 m
.46818 .04308 L
s
1 .173 0 r
.008 w
.46818 .04308 Mdot
.016 w
.46818 .04308 m
.46987 .04328 L
s
1 .17 0 r
.008 w
.46987 .04328 Mdot
.016 w
.46987 .04328 m
.47139 .04344 L
s
1 .166 0 r
.008 w
.47139 .04344 Mdot
.016 w
.47139 .04344 m
.47267 .04358 L
s
1 .162 0 r
.008 w
.47267 .04358 Mdot
.016 w
.47267 .04358 m
.4738 .04372 L
s
1 .159 0 r
.008 w
.4738 .04372 Mdot
.016 w
.4738 .04372 m
.47474 .04387 L
s
1 .155 0 r
.008 w
.47474 .04387 Mdot
.016 w
.47474 .04387 m
.47546 .04405 L
s
1 .152 0 r
.008 w
.47546 .04405 Mdot
.016 w
.47546 .04405 m
.47597 .04428 L
s
1 .148 0 r
.008 w
.47597 .04428 Mdot
.016 w
.47597 .04428 m
.47629 .04456 L
s
1 .144 0 r
.008 w
.47629 .04456 Mdot
.016 w
.47629 .04456 m
.47646 .04489 L
s
1 .141 0 r
.008 w
.47646 .04489 Mdot
.016 w
.47646 .04489 m
.47651 .04527 L
s
1 .137 0 r
.008 w
.47651 .04527 Mdot
.016 w
.47651 .04527 m
.47648 .0457 L
s
1 .134 0 r
.008 w
.47648 .0457 Mdot
.016 w
.47648 .0457 m
.4764 .04614 L
s
1 .13 0 r
.008 w
.4764 .04614 Mdot
.016 w
.4764 .04614 m
.4763 .0466 L
s
1 .126 0 r
.008 w
.4763 .0466 Mdot
.016 w
.4763 .0466 m
.47621 .04707 L
s
1 .123 0 r
.008 w
.47621 .04707 Mdot
.016 w
.47621 .04707 m
.47613 .04754 L
s
1 .119 0 r
.008 w
.47613 .04754 Mdot
.016 w
.47613 .04754 m
.47602 .04795 L
s
1 .116 0 r
.008 w
.47602 .04795 Mdot
.016 w
.47602 .04795 m
.47589 .04827 L
s
1 .112 0 r
.008 w
.47589 .04827 Mdot
.016 w
.47589 .04827 m
.47574 .04847 L
s
1 .108 0 r
.008 w
.47574 .04847 Mdot
.016 w
.47574 .04847 m
.4756 .0485 L
s
1 .105 0 r
.008 w
.4756 .0485 Mdot
.016 w
.4756 .0485 m
.47553 .04838 L
s
1 .101 0 r
.008 w
.47553 .04838 Mdot
.016 w
.47553 .04838 m
.47556 .04811 L
s
1 .097 0 r
.008 w
.47556 .04811 Mdot
.016 w
.47556 .04811 m
.47572 .04775 L
s
1 .094 0 r
.008 w
.47572 .04775 Mdot
.016 w
.47572 .04775 m
.47605 .04731 L
s
1 .09 0 r
.008 w
.47605 .04731 Mdot
.016 w
.47605 .04731 m
.47658 .04688 L
s
1 .087 0 r
.008 w
.47658 .04688 Mdot
.016 w
.47658 .04688 m
.47734 .04642 L
s
1 .083 0 r
.008 w
.47734 .04642 Mdot
.016 w
.47734 .04642 m
.47836 .04601 L
s
1 .079 0 r
.008 w
.47836 .04601 Mdot
.016 w
.47836 .04601 m
.47955 .04562 L
s
1 .076 0 r
.008 w
.47955 .04562 Mdot
.016 w
.47955 .04562 m
.48106 .04525 L
s
1 .072 0 r
.008 w
.48106 .04525 Mdot
.016 w
.48106 .04525 m
.48255 .04493 L
s
1 .069 0 r
.008 w
.48255 .04493 Mdot
.016 w
.48255 .04493 m
.48442 .04467 L
s
1 .065 0 r
.008 w
.48442 .04467 Mdot
.016 w
.48442 .04467 m
.48635 .04444 L
s
1 .061 0 r
.008 w
.48635 .04444 Mdot
.016 w
.48635 .04444 m
.48826 .04424 L
s
1 .058 0 r
.008 w
.48826 .04424 Mdot
.016 w
.48826 .04424 m
.49045 .04403 L
s
1 .054 0 r
.008 w
.49045 .04403 Mdot
.016 w
.49045 .04403 m
.4927 .04377 L
s
1 .051 0 r
.008 w
.4927 .04377 Mdot
.016 w
.4927 .04377 m
.49499 .04349 L
s
1 .047 0 r
.008 w
.49499 .04349 Mdot
.016 w
.49499 .04349 m
.49727 .04315 L
s
1 .043 0 r
.008 w
.49727 .04315 Mdot
.016 w
.49727 .04315 m
.49946 .04275 L
s
1 .04 0 r
.008 w
.49946 .04275 Mdot
.016 w
.49946 .04275 m
.50154 .04232 L
s
1 .036 0 r
.008 w
.50154 .04232 Mdot
.016 w
.50154 .04232 m
.50359 .04184 L
s
1 .032 0 r
.008 w
.50359 .04184 Mdot
.016 w
.50359 .04184 m
.50529 .04132 L
s
1 .029 0 r
.008 w
.50529 .04132 Mdot
.016 w
.50529 .04132 m
.50682 .04082 L
s
1 .025 0 r
.008 w
.50682 .04082 Mdot
.016 w
.50682 .04082 m
.5083 .04036 L
s
1 .022 0 r
.008 w
.5083 .04036 Mdot
.016 w
.5083 .04036 m
.5095 .03991 L
s
1 .018 0 r
.008 w
.5095 .03991 Mdot
.016 w
.5095 .03991 m
.51055 .03948 L
s
1 .014 0 r
.008 w
.51055 .03948 Mdot
.016 w
.51055 .03948 m
.51133 .03906 L
s
1 .011 0 r
.008 w
.51133 .03906 Mdot
.016 w
.51133 .03906 m
.51191 .03877 L
s
1 .007 0 r
.008 w
.51191 .03877 Mdot
.016 w
.51191 .03877 m
.51228 .03854 L
s
1 .004 0 r
.008 w
.51228 .03854 Mdot
.016 w
.51228 .03854 m
.51246 .03843 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007]oo`X0
01Eoo`T007eoo`00MWoo1@005Woo0W`047oo1P00Mgoo001YOol3?Nl2OP0;?Nl>Ool00gbPOomoo`03
Ool2O2000gooO01l0002O00EOol5001bOol006Moo`@mk`03ON1m`7fP00AmP0Pmk`04Oomm07d0O>05
O<06O:03Ool2O207O00IOol4001^Ool006Eoo`04OX1n87hPOR02OP000ggPOL1mX002OH05OF001Cg_
OF0mkcg_OB000gd000=lh7c0O<000gc00gbP0ga01G`P1W`07Woo1000JWoo001TOol00gj0OV1n8002
OR02OP000ggPOL1mX002OH08OF02OB03O@000gcPO<1l`003O<03O:03O405O205O00SOol3001WOol0
069oo`=nP004OV1n87hPOR02OP000ggPOL1mX002OH05OF03OD02OB03O@000gcPO<1l`003O<03O:03
O405O205O00VOol3001TOol0061oo`03?NmnP7j0009nP004OV1n87hPOR05OP02OH05OF03OD02OB05
O@07Ool3O406O20]Ool3001QOol005ioo`8mk`EnP0EnH0Hmk`03OommH7eP009mH0=m@0Em80Uoo`Al
H3Eoo`8005moo`00G7oo0Sg_0WjP1gj01cg_1goo1ge0AGoo0P00GGoo001JOol00`00?Nlmk`04OZ05
OX02?NmKOol2001KOol005Qoo`03000mkcg_00MnX003OX0mkgoo061oo`8005Uoo`00EGoo0`0000<m
kgk0O/0027jPI7oo0`00EWoo001COol20002Ool4O/07OZ1XOol2001DOol0055oo`8000=oo`En`0En
X6aoo`80059oo`00D7oo00D007ooOomoogkP00In`0AnX6moo`03001oogoo04moo`00Cgoo00@007oo
Oomoo`9nh0Qn`08mkg1oo`03001oogoo04ioo`00CGoo0P000goo00@mkgkPO^1nh0En`0<mkg9oo`80
04ioo`00Bgoo0P001Goo1GkP00An`7kP?NlmkgMoo`8004aoo`00BGoo0P0017oo0Sg_00=o07kPO^00
17kP0Sg_NWoo0P00BWoo0018Ool00`00Oomoo`02Ool4?Nl2O`04O^03?NmlOol00`00Oomoo`17Ool0
04Ioo`8000Aoo`<mk`03Od1o87l0009o0003O^1o03g_00<mkgeoo`8004Moo`00AGoo00@007ooOomo
o`Hmk`03Od1o87l000Ao00<mkh1oo`03001oogoo04Aoo`00A7oo00D007ooOolmkgo0009oX0=oP003
Of1o@7lP00Ao0003?Nmoogoo089oo`03001oogoo04=oo`00@goo00@007oo?Nlmk`9o`09oX0=oP003
Of1o@7lP00Ao08Ioo`03001oogoo049oo`00@Goo0P0000Aoocg_?Nmoh09o`09oX0=oP003Of1o@7m0
009o@8Uoo`80049oo`00@7oo00<007ooOol00cg_00=oh7o0Ol000WnP0gn000=oH7m0Od000Wm0Rgoo
00<007ooOol0?goo000oOol00`00Oomoo`04?Nl00goPOl1o`003Ol2COol2000oOol003ioo`03001o
ogoo00Dmk`03On1o`7o0009o`9Ioo`03001oogoo03aoo`00?7oo0P000Woo1Sg_17oPV7oo00<007oo
Ool0>goo000kOol00`00Oolmk`0;?NnJOol00`00Oomoo`0jOol003Yoo`03001oocg_00/mkiaoo`80
03Yoo`00>Goo00<007oo?Nl02Sg_X7oo00<007ooOol0=goo000gOol200000goo?Nlmk`0:?NnQOol0
0`00Oomoo`0fOol003Ioo`03001oogoo00TmkjIoo`03001oogoo03Eoo`00=Goo00<007ooOol02Sg_
Ygoo00<007ooOol0=7oo000dOol01000Oomoogoo2Cg_ZGoo00<007ooOol0<goo000bOol20003Ool:
?NnZOol00`00Oomoo`0bOol0035oo`03001oogoo009oo`/mkj]oo`03001oogoo035oo`00<7oo00<0
07ooOol00Woo33g_[7oo00<007ooOol0<7oo000`Ool00`00Oomoo`02Ool;?Nn^Ool00`00Oomoo`0_
Ool002moo`03001oogoo009oo`Xmkk5oo`03001oogoo02ioo`00;Woo00<007ooOol00goo2Sg_/Woo
00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool:?NncOol00`00Oomoo`0/Ool002aoo`03001oogoo
00Aoo`XmkkEoo`03001oogoo02]oo`00;7oo00<007ooOol00goo2Sg_]Woo00<007ooOol0:goo000[
Ool00`00Oomoo`04Ool:?NngOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`Dmkkioo`03001o
ogoo02Uoo`00:Goo00<007ooOol01Goo1Cg__goo00<007ooOol0:7oo000XOol00`00Oomoo`05Ool5
?No1Ool00`00Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`009goo00<0
07ooOol01Woo1Cg_`Woo00<007ooOol09Woo000VOol00`00Oomoo`06Ool7?No2Ool00`00Oomoo`0U
Ool002Eoo`03001oogoo00Ioo`Pmkl=oo`03001oogoo02Aoo`0097oo00<007ooOol01Woo23g_aGoo
00<007ooOol08goo000TOol00`00Oomoo`05Ool8?No6Ool00`00Oomoo`0SOol002=oo`03001oogoo
00Ioo`LmklQoo`03001oogoo029oo`008Woo00<007ooOol01Woo23g_bGoo00<007ooOol08Goo000R
Ool00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0025oo`03001oogoo00Ioo`Pmkl]oo`03001o
ogoo021oo`0087oo00<007ooOol01Woo23g_cGoo00<007ooOol07goo000POol00`00Oomoo`05Ool7
?No?Ool00`00Oomoo`0OOol001moo`03001oogoo00Ioo`Hmkm5oo`03001oogoo01ioo`007goo00<0
07ooOol01Woo1Sg_dWoo00<007ooOol07Goo000NOol00`00Oomoo`06Ool7?NoBOol00`00Oomoo`0M
Ool001eoo`03001oogoo00Moo`Lmkm=oo`03001oogoo01aoo`007Goo00<007ooOol01Woo23g_dgoo
00<007ooOol077oo000LOol00`00Oomoo`06Ool8?NoEOol00`00Oomoo`0KOol001aoo`03001oogoo
00Eoo`TmkmEoo`03001oogoo01]oo`006goo00<007ooOol01Woo2Cg_eWoo00<007ooOol06Woo000K
Ool00`00Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Ioo`TmkmQoo`03001o
ogoo01Uoo`006Woo00<007ooOol01Woo23g_fGoo00<007ooOol06Goo000IOol00`00Oomoo`06Ool8
?NoKOol00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lmkmaoo`03001oogoo01Qoo`0067oo00<0
07ooOol01Goo23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`05Ool7?NoOOol00`00Oomoo`0G
Ool001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol01Goo23g_h7oo
00<007ooOol05Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo
00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<007ooOol01Goo1Sg_i7oo00<007ooOol05Goo000E
Ool00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001o
ogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00Oomoo`06Ool6
?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<0
07ooOol01Goo1cg_igoo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0B
Ool001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo
00<007ooOol04Woo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo
00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Cg_k7oo00<007ooOol04Goo000A
Ool00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03001o
ogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00Oomoo`07Ool6
?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<0
07ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo
00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo
00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?
Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Pmkneoo`03001o
ogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool:
?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo00eoo`003Woo00<0
07ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<
Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo
00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl00cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo00<007ooOol027oo3cg_jWoo00<007ooOol037oo
000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa4mknQoo`03
001oogoo00aoo`0037oo00<007ooOol027oo4cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00IooaLmknIoo`03001oogoo00]o
o`0037oo00<007ooOol01Goo63g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08OolE?NoVOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;
Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol06Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol7?NoTOol0
0`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol0
67oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eo
o`03001oogoo01Moo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_ggoo00<007oo
Ool037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pm
kmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00ao
o`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol9?NoLOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol0
7Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000io
o`03001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007oo
Ool03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo
000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol0
0`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<0
07ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001o
ogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomo
o`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0
mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=o
o`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol0
0`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<0
07ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001o
ogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomo
o`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol0
5goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Mo
o`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol0
01Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000K
Ool00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo
00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03
001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00
Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007oo
Ool0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo
0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3G
Ool00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo
00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03
001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00
Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007oo
Ool09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo
02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0Z
Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo
000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00
;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035o
o`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol0
0`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<0
07ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001o
ogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03
001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00
Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007oo
Ool0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<0
07ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008mo
o`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00
CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051o
o`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`80
05Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo
0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000
Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo
001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002;Ool20003Ool3002=Ool008Yoo`04001oogoo0004Ool00`00
Oomoo`2;Ool008aoo`03001oogoo009oo`<008aoo`00SGoo00@007ooOol0009oo`03001oogoo08Yo
o`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(40)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
1 .985 0 r
.008 w
.51382 .04322 Mdot
.016 w
.51382 .04322 m
.51382 .04305 L
s
1 .971 0 r
.008 w
.51382 .04305 Mdot
.016 w
.51382 .04305 m
.51377 .04279 L
s
1 .956 0 r
.008 w
.51377 .04279 Mdot
.016 w
.51377 .04279 m
.51369 .04246 L
s
1 .941 0 r
.008 w
.51369 .04246 Mdot
.016 w
.51369 .04246 m
.51354 .04208 L
s
1 .926 0 r
.008 w
.51354 .04208 Mdot
.016 w
.51354 .04208 m
.51332 .04168 L
s
1 .912 0 r
.008 w
.51332 .04168 Mdot
.016 w
.51332 .04168 m
.51302 .04126 L
s
1 .897 0 r
.008 w
.51302 .04126 Mdot
.016 w
.51302 .04126 m
.51267 .04085 L
s
1 .882 0 r
.008 w
.51267 .04085 Mdot
.016 w
.51267 .04085 m
.51226 .04042 L
s
1 .868 0 r
.008 w
.51226 .04042 Mdot
.016 w
.51226 .04042 m
.51181 .03997 L
s
1 .853 0 r
.008 w
.51181 .03997 Mdot
.016 w
.51181 .03997 m
.51133 .0395 L
s
1 .838 0 r
.008 w
.51133 .0395 Mdot
.016 w
.51133 .0395 m
.51085 .03904 L
s
1 .824 0 r
.008 w
.51085 .03904 Mdot
.016 w
.51085 .03904 m
.51035 .03863 L
s
1 .809 0 r
.008 w
.51035 .03863 Mdot
.016 w
.51035 .03863 m
.50986 .03829 L
s
1 .794 0 r
.008 w
.50986 .03829 Mdot
.016 w
.50986 .03829 m
.50938 .03803 L
s
1 .779 0 r
.008 w
.50938 .03803 Mdot
.016 w
.50938 .03803 m
.50895 .03781 L
s
1 .765 0 r
.008 w
.50895 .03781 Mdot
.016 w
.50895 .03781 m
.50856 .03762 L
s
1 .75 0 r
.008 w
.50856 .03762 Mdot
.016 w
.50856 .03762 m
.50813 .03743 L
s
1 .735 0 r
.008 w
.50813 .03743 Mdot
.016 w
.50813 .03743 m
.50769 .03718 L
s
1 .721 0 r
.008 w
.50769 .03718 Mdot
.016 w
.50769 .03718 m
.50719 .03691 L
s
1 .706 0 r
.008 w
.50719 .03691 Mdot
.016 w
.50719 .03691 m
.50664 .03658 L
s
1 .691 0 r
.008 w
.50664 .03658 Mdot
.016 w
.50664 .03658 m
.50599 .03619 L
s
1 .676 0 r
.008 w
.50599 .03619 Mdot
.016 w
.50599 .03619 m
.50521 .03581 L
s
1 .662 0 r
.008 w
.50521 .03581 Mdot
.016 w
.50521 .03581 m
.50418 .03545 L
s
1 .647 0 r
.008 w
.50418 .03545 Mdot
.016 w
.50418 .03545 m
.50285 .03516 L
s
1 .632 0 r
.008 w
.50285 .03516 Mdot
.016 w
.50285 .03516 m
.5012 .03486 L
s
1 .618 0 r
.008 w
.5012 .03486 Mdot
.016 w
.5012 .03486 m
.49914 .03458 L
s
1 .603 0 r
.008 w
.49914 .03458 Mdot
.016 w
.49914 .03458 m
.49694 .03433 L
s
1 .588 0 r
.008 w
.49694 .03433 Mdot
.016 w
.49694 .03433 m
.49431 .03409 L
s
1 .574 0 r
.008 w
.49431 .03409 Mdot
.016 w
.49431 .03409 m
.49146 .03386 L
s
1 .559 0 r
.008 w
.49146 .03386 Mdot
.016 w
.49146 .03386 m
.48856 .03364 L
s
1 .544 0 r
.008 w
.48856 .03364 Mdot
.016 w
.48856 .03364 m
.48527 .03344 L
s
1 .529 0 r
.008 w
.48527 .03344 Mdot
.016 w
.48527 .03344 m
.48253 .03328 L
s
1 .515 0 r
.008 w
.48253 .03328 Mdot
.016 w
.48253 .03328 m
.47911 .03317 L
s
1 .5 0 r
.008 w
.47911 .03317 Mdot
.016 w
.47911 .03317 m
.47637 .03312 L
s
1 .485 0 r
.008 w
.47637 .03312 Mdot
.016 w
.47637 .03312 m
.47295 .03309 L
s
1 .471 0 r
.008 w
.47295 .03309 Mdot
.016 w
.47295 .03309 m
.47022 .03304 L
s
1 .456 0 r
.008 w
.47022 .03304 Mdot
.016 w
.47022 .03304 m
.46738 .03297 L
s
1 .441 0 r
.008 w
.46738 .03297 Mdot
.016 w
.46738 .03297 m
.46439 .03288 L
s
1 .426 0 r
.008 w
.46439 .03288 Mdot
.016 w
.46439 .03288 m
.4618 .0328 L
s
1 .412 0 r
.008 w
.4618 .0328 Mdot
.016 w
.4618 .0328 m
.45899 .03272 L
s
1 .397 0 r
.008 w
.45899 .03272 Mdot
.016 w
.45899 .03272 m
.45596 .03261 L
s
1 .382 0 r
.008 w
.45596 .03261 Mdot
.016 w
.45596 .03261 m
.4534 .03247 L
s
1 .368 0 r
.008 w
.4534 .03247 Mdot
.016 w
.4534 .03247 m
.45009 .03231 L
s
1 .353 0 r
.008 w
.45009 .03231 Mdot
.016 w
.45009 .03231 m
.44739 .03216 L
s
1 .338 0 r
.008 w
.44739 .03216 Mdot
.016 w
.44739 .03216 m
.44436 .03203 L
s
1 .324 0 r
.008 w
.44436 .03203 Mdot
.016 w
.44436 .03203 m
.44077 .03195 L
s
1 .309 0 r
.008 w
.44077 .03195 Mdot
.016 w
.44077 .03195 m
.43764 .03194 L
s
1 .294 0 r
.008 w
.43764 .03194 Mdot
.016 w
.43764 .03194 m
.43413 .03201 L
s
1 .279 0 r
.008 w
.43413 .03201 Mdot
.016 w
.43413 .03201 m
.43076 .03217 L
s
1 .265 0 r
.008 w
.43076 .03217 Mdot
.016 w
.43076 .03217 m
.42708 .0324 L
s
1 .25 0 r
.008 w
.42708 .0324 Mdot
.016 w
.42708 .0324 m
.42413 .03271 L
s
1 .235 0 r
.008 w
.42413 .03271 Mdot
.016 w
.42413 .03271 m
.42105 .03308 L
s
1 .221 0 r
.008 w
.42105 .03308 Mdot
.016 w
.42105 .03308 m
.41822 .03349 L
s
1 .206 0 r
.008 w
.41822 .03349 Mdot
.016 w
.41822 .03349 m
.41552 .03392 L
s
1 .191 0 r
.008 w
.41552 .03392 Mdot
.016 w
.41552 .03392 m
.4132 .03434 L
s
1 .176 0 r
.008 w
.4132 .03434 Mdot
.016 w
.4132 .03434 m
.41119 .03472 L
s
1 .162 0 r
.008 w
.41119 .03472 Mdot
.016 w
.41119 .03472 m
.40942 .03501 L
s
1 .147 0 r
.008 w
.40942 .03501 Mdot
.016 w
.40942 .03501 m
.40808 .03519 L
s
1 .132 0 r
.008 w
.40808 .03519 Mdot
.016 w
.40808 .03519 m
.40702 .03525 L
s
1 .118 0 r
.008 w
.40702 .03525 Mdot
.016 w
.40702 .03525 m
.40624 .03519 L
s
1 .103 0 r
.008 w
.40624 .03519 Mdot
.016 w
.40624 .03519 m
.4057 .03502 L
s
1 .088 0 r
.008 w
.4057 .03502 Mdot
.016 w
.4057 .03502 m
.4054 .03479 L
s
1 .074 0 r
.008 w
.4054 .03479 Mdot
.016 w
.4054 .03479 m
.40528 .03453 L
s
1 .059 0 r
.008 w
.40528 .03453 Mdot
.016 w
.40528 .03453 m
.40531 .03425 L
s
1 .044 0 r
.008 w
.40531 .03425 Mdot
.016 w
.40531 .03425 m
.40542 .03404 L
s
1 .029 0 r
.008 w
.40542 .03404 Mdot
.016 w
.40542 .03404 m
.4056 .03388 L
s
1 .015 0 r
.008 w
.4056 .03388 Mdot
.016 w
.4056 .03388 m
.40578 .0338 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001iOol2O>09Ool00gfP0000
000C0026Ool007Qoo`Elh09m009m809m@003OF1mP7f001Aoo`T007eoo`00Lgoo00=lP7`0O0000Wb0
00=lX7c0O<000WcP0Wd00WdP0We000AmH7f0OH1mX09m`09mh09n009n8004OT1nH7j0OZ0@Ool6001g
Ool006Uoo`Xmk`03O81l07`0009lP003O:1l`7c0009lh09m009m809m@003OF1mP7f0009mX003OL1m
h7gP009n009n8005OT1nH7j0OZ1o000EOol5001bOol006Moo``mk`03O81l87a0009lP003O:1l`7c0
009lh09m009m809m@004OF1mP7f0OJ02OL02ON02OP02OR001Wi0OV1nP7jPO`1oP1Uoo`@006ioo`00
IGoo3Sg_1Gb000=lX7c0O<0023g_00=m`7fPOJ000gg00WgP0Wh00WhP00In@7iPOX1nX7l0Oh0MOol4
001ZOol006Aoob/mk`An`003O`1oP7oo021oo`<006Moo`00HWoo;Sg_17mP00=oP7ooOol08Woo0`00
I7oo001POolO?Nl7Ool8?Nl^Ool3001QOol005iooa8mk`03Oolmkcg_00Xmk`Uoo`@mkcEoo`8005mo
o`00G7oo4Sg_27oo1Sg_AGoo0P00GGoo001JOol00`00?Nlmk`0;?NmKOol2001KOol005Qoo`03000m
kcg_00Tmkf5oo`8005Uoo`00EGoo0`002Sg_IGoo0`00EWoo001COol20003Ool:?NmXOol2001DOol0
055oo`8000=oo`Tmkfeoo`80059oo`00D7oo00@007ooOomoo`/mkfmoo`03001oogoo04moo`00Cgoo
00@007ooOomoo``mkg1oo`03001oogoo04ioo`00CGoo0P000goo33g_LWoo0P00CWoo001;Ool20005
Ool9?NmgOol2001<Ool004Uoo`8000Aoo`/mkgYoo`8004Yoo`00B7oo00<007ooOol00Woo3Cg_O7oo
00<007ooOol0Agoo0016Ool20004Ool>?NmmOol20017Ool004Eoo`04001oogooOol@?Nn0Ool00`00
Oomoo`14Ool004Aoo`03001oogoo00lmkhAoo`03001oogoo04=oo`00@goo00<007oo?Nl03cg_QWoo
00<007ooOol0@Woo0011Ool200000goo?Nlmk`0=?Nn9Ool20012Ool0041oo`03001oogoo010mkh]o
o`03001oogoo03moo`00?goo00<007ooOol02Sg_Tgoo0P00?goo000nOol00`00Oomoo`0:?NnFOol0
0`00Oomoo`0lOol003aoo`80009oo`XmkiQoo`03001oogoo03]oo`00>goo00<007oo?Nl02cg_VWoo
00<007ooOol0>Woo000jOol00`00Oolmk`0;?NnLOol2000jOol003Uoo`03001oocg_00Xmkj1oo`03
001oogoo03Moo`00=goo0P0000=oocg_?Nl02Sg_XGoo00<007ooOol0=Woo000fOol00`00Oomoo`09
?NnVOol00`00Oomoo`0eOol003Eoo`03001oogoo00XmkjMoo`03001oogoo03Aoo`00=7oo00@007oo
Oomoo`TmkjUoo`03001oogoo03=oo`00<Woo0P000goo2Sg_ZWoo00<007ooOol0<Woo000aOol00`00
Oomoo`02Ool;?Nn[Ool00`00Oomoo`0aOol0031oo`03001oogoo009oo``mkjaoo`03001oogoo031o
o`00<7oo00<007ooOol00Woo2cg_[Woo00<007ooOol0;goo000_Ool00`00Oomoo`02Ool:?NnaOol0
0`00Oomoo`0^Ool002ioo`03001oogoo00=oo`Xmkk9oo`03001oogoo02eoo`00;Goo00<007ooOol0
17oo2Sg_/goo00<007ooOol0;7oo000/Ool00`00Oomoo`04Ool:?NneOol00`00Oomoo`0[Ool002ao
o`03001oogoo00=oo`XmkkIoo`03001oogoo02]oo`00:goo00<007ooOol017oo2Sg_]goo00<007oo
Ool0:Woo000ZOol00`00Oomoo`04Ool5?NnnOol00`00Oomoo`0YOol002Uoo`03001oogoo00Eoo`Dm
kkmoo`03001oogoo02Qoo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00
Oomoo`05Ool5?No1Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Io
o`009Woo00<007ooOol01Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool0
0`00Oomoo`0TOol002Aoo`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol0
1Goo23g_aWoo00<007ooOol08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029o
o`03001oogoo00Ioo`PmklUoo`03001oogoo025oo`008Woo00<007ooOol01Goo2Cg_bGoo00<007oo
Ool08Goo000QOol00`00Oomoo`06Ool8?No;Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Pm
kleoo`03001oogoo01moo`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00
Oomoo`06Ool6?NoAOol00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eo
o`007Woo00<007ooOol01Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol0
0`00Oomoo`0LOol001eoo`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol0
1Woo23g_eGoo00<007ooOol06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]o
o`03001oogoo00Ioo`TmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007oo
Ool06Woo000JOol00`00Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`Pm
kmUoo`03001oogoo01Uoo`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00
Oomoo`06Ool7?NoLOol00`00Oomoo`0HOol001Qoo`03001oogoo00Eoo`Pmkmioo`03001oogoo01Mo
o`0067oo00<007ooOol01Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol0
0`00Oomoo`0GOol001Moo`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol0
17oo23g_hGoo00<007ooOol05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Io
o`03001oogoo00Eoo`HmknAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007oo
Ool057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`Lm
knEoo`03001oogoo01Aoo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00
Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=o
o`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol0
0`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol0
1goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019o
o`03001oogoo00Ioo`Dmknaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007oo
Ool047oo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hm
knaoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00mo
o`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol0
2Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007oo
Ool03Woo000>Ool00`00Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``m
knUoo`03001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00
Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00ao
o`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eo
o`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo
1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qoo`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<0
07ooOol037oo000=Ool00`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qo
oa<mknQoo`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo
000<Ool00`00Oomoo`06OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03
001oogoo00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08
Ool6?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03
001oogoo00]oo`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0H
Ool9?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo
00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomo
o`0;Ool000eoo`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_
gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool;?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo
00<007ooOol07Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomo
o`0=Ool000ioo`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<0
07ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001o
ogoo00eoo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomo
o`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol0
3Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00mo
o`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0
011oo`03001oogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000A
Ool00`00Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo
00<007ooOol0n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03
001oogoo0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00
Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007oo
Ool0m7oo00<007ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo
0?=oo`03001oogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3a
Ool00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo
00<007ooOol057oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03
001oogoo01Eoo`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00
Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007oo
Ool05goo000IOol00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo
01Qoo`006Woo00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0I
Ool001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo
000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`00
7Goo00<007ooOol0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001io
o`03001oogoo0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol0
0`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<0
07ooOol0fgoo00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001o
ogoo0=Uoo`03001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomo
o`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0
dgoo00<007ooOol08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<mo
o`03001oogoo02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool0
0`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<0
07ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001o
ogoo02Uoo`00:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomo
o`0[Ool002eoo`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0
;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02io
o`00<7oo00<007ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0
039oo`800;Moo`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2a
Ool00`00Oomoo`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo
00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03
001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003ao
o`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2
002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013
Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo
00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00
BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eo
o`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`80
05=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo
0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00
EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo
001`Ool3000hOol4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005
Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo
0`000Woo0P00SGoo002=Ool01000Oomoo`000Woo00<007ooOol0RWoo002:Ool500001Goo001oogoo
0000S7oo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00Rgoo00<007oo00000Woo00@007oo
Ool008aoo`00S7oo0P000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(41)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
1 .98 0 r
.008 w
.41089 .03979 Mdot
.016 w
.41089 .03979 m
.41071 .03984 L
s
1 .961 0 r
.008 w
.41071 .03984 Mdot
.016 w
.41071 .03984 m
.41045 .03998 L
s
1 .941 0 r
.008 w
.41045 .03998 Mdot
.016 w
.41045 .03998 m
.4101 .04023 L
s
1 .922 0 r
.008 w
.4101 .04023 Mdot
.016 w
.4101 .04023 m
.4097 .04058 L
s
1 .902 0 r
.008 w
.4097 .04058 Mdot
.016 w
.4097 .04058 m
.40925 .04103 L
s
1 .882 0 r
.008 w
.40925 .04103 Mdot
.016 w
.40925 .04103 m
.40879 .04158 L
s
1 .863 0 r
.008 w
.40879 .04158 Mdot
.016 w
.40879 .04158 m
.40833 .04216 L
s
1 .843 0 r
.008 w
.40833 .04216 Mdot
.016 w
.40833 .04216 m
.40789 .04283 L
s
1 .824 0 r
.008 w
.40789 .04283 Mdot
.016 w
.40789 .04283 m
.40746 .04355 L
s
1 .804 0 r
.008 w
.40746 .04355 Mdot
.016 w
.40746 .04355 m
.40704 .04428 L
s
1 .784 0 r
.008 w
.40704 .04428 Mdot
.016 w
.40704 .04428 m
.40667 .04494 L
s
1 .765 0 r
.008 w
.40667 .04494 Mdot
.016 w
.40667 .04494 m
.40636 .04554 L
s
1 .745 0 r
.008 w
.40636 .04554 Mdot
.016 w
.40636 .04554 m
.40615 .04603 L
s
1 .725 0 r
.008 w
.40615 .04603 Mdot
.016 w
.40615 .04603 m
.40606 .04638 L
s
1 .706 0 r
.008 w
.40606 .04638 Mdot
.016 w
.40606 .04638 m
.40609 .04654 L
s
1 .686 0 r
.008 w
.40609 .04654 Mdot
.016 w
.40609 .04654 m
.4062 .04649 L
s
1 .667 0 r
.008 w
.4062 .04649 Mdot
.016 w
.4062 .04649 m
.40633 .04626 L
s
1 .647 0 r
.008 w
.40633 .04626 Mdot
.016 w
.40633 .04626 m
.40644 .04588 L
s
1 .627 0 r
.008 w
.40644 .04588 Mdot
.016 w
.40644 .04588 m
.4065 .04542 L
s
1 .608 0 r
.008 w
.4065 .04542 Mdot
.016 w
.4065 .04542 m
.40645 .04492 L
s
1 .588 0 r
.008 w
.40645 .04492 Mdot
.016 w
.40645 .04492 m
.40625 .04441 L
s
1 .569 0 r
.008 w
.40625 .04441 Mdot
.016 w
.40625 .04441 m
.40597 .04393 L
s
1 .549 0 r
.008 w
.40597 .04393 Mdot
.016 w
.40597 .04393 m
.4055 .04346 L
s
1 .529 0 r
.008 w
.4055 .04346 Mdot
.016 w
.4055 .04346 m
.40479 .043 L
s
1 .51 0 r
.008 w
.40479 .043 Mdot
.016 w
.40479 .043 m
.40385 .04257 L
s
1 .49 0 r
.008 w
.40385 .04257 Mdot
.016 w
.40385 .04257 m
.40274 .04215 L
s
1 .471 0 r
.008 w
.40274 .04215 Mdot
.016 w
.40274 .04215 m
.40159 .04177 L
s
1 .451 0 r
.008 w
.40159 .04177 Mdot
.016 w
.40159 .04177 m
.4004 .04144 L
s
1 .431 0 r
.008 w
.4004 .04144 Mdot
.016 w
.4004 .04144 m
.39897 .04115 L
s
1 .412 0 r
.008 w
.39897 .04115 Mdot
.016 w
.39897 .04115 m
.39724 .04091 L
s
1 .392 0 r
.008 w
.39724 .04091 Mdot
.016 w
.39724 .04091 m
.39573 .0407 L
s
1 .373 0 r
.008 w
.39573 .0407 Mdot
.016 w
.39573 .0407 m
.39406 .04054 L
s
1 .353 0 r
.008 w
.39406 .04054 Mdot
.016 w
.39406 .04054 m
.39257 .04039 L
s
1 .333 0 r
.008 w
.39257 .04039 Mdot
.016 w
.39257 .04039 m
.39104 .04021 L
s
1 .314 0 r
.008 w
.39104 .04021 Mdot
.016 w
.39104 .04021 m
.38964 .04 L
s
1 .294 0 r
.008 w
.38964 .04 Mdot
.016 w
.38964 .04 m
.38852 .03976 L
s
1 .275 0 r
.008 w
.38852 .03976 Mdot
.016 w
.38852 .03976 m
.38751 .0395 L
s
1 .255 0 r
.008 w
.38751 .0395 Mdot
.016 w
.38751 .0395 m
.38661 .0392 L
s
1 .235 0 r
.008 w
.38661 .0392 Mdot
.016 w
.38661 .0392 m
.38587 .03886 L
s
1 .216 0 r
.008 w
.38587 .03886 Mdot
.016 w
.38587 .03886 m
.38532 .03849 L
s
1 .196 0 r
.008 w
.38532 .03849 Mdot
.016 w
.38532 .03849 m
.38496 .0381 L
s
1 .176 0 r
.008 w
.38496 .0381 Mdot
.016 w
.38496 .0381 m
.38477 .03768 L
s
1 .157 0 r
.008 w
.38477 .03768 Mdot
.016 w
.38477 .03768 m
.38473 .03726 L
s
1 .137 0 r
.008 w
.38473 .03726 Mdot
.016 w
.38473 .03726 m
.38477 .03685 L
s
1 .118 0 r
.008 w
.38477 .03685 Mdot
.016 w
.38477 .03685 m
.38486 .03643 L
s
1 .098 0 r
.008 w
.38486 .03643 Mdot
.016 w
.38486 .03643 m
.38496 .036 L
s
1 .078 0 r
.008 w
.38496 .036 Mdot
.016 w
.38496 .036 m
.38505 .03559 L
s
1 .059 0 r
.008 w
.38505 .03559 Mdot
.016 w
.38505 .03559 m
.38508 .03523 L
s
1 .039 0 r
.008 w
.38508 .03523 Mdot
.016 w
.38508 .03523 m
.38504 .03495 L
s
1 .02 0 r
.008 w
.38504 .03495 Mdot
.016 w
.38504 .03495 m
.38497 .03476 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo17aP0Woo83g_47oo1P00Mgoo001YOol4?Nl2O6001W`0O61l`7dP?Nmo`09o
8003Ol1oh3g_01XmkaEoo`D0079oo`00Igoo1Sg_0WaP00Yl07aPO<1m87e0OH1mX7gPOb1oh1`mkaUo
o`@006ioo`00IGoo23g_17aP00Il`7dPOD1mP7fPON02Ob0L?NlMOol4001ZOol006Aoo`Tmk`AlH008
O<1m87e0OH1mX7gPOZ1oh1`mkb5oo`<006Moo`00HWoo3Cg_1Ge000AmP7fPON1nX1dmkbAoo`<006Ao
o`00H7oo4cg_17hP23g_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2
001OOol005aooa8mk`Qoo`HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000goo2Sg_J7oo0P00
E7oo001AOol20003Ool9?Nm]Ool2001BOol0051oo`04001oogooOol;?Nm_Ool00`00Oomoo`1?Ool0
04moo`04001oogooOol<?Nm`Ool00`00Oomoo`1>Ool004eoo`8000=oo``mkg9oo`8004ioo`00Bgoo
0P001Goo2Cg_Mgoo0P00C7oo0019Ool20004Ool;?NmjOol2001:Ool004Qoo`03001oogoo009oo`dm
kgaoo`03001oogoo04Moo`00AWoo0P0017oo3Sg_OGoo0P00Agoo0015Ool01000Oomoogoo43g_P7oo
00<007ooOol0A7oo0014Ool00`00Oomoo`0??Nn4Ool00`00Oomoo`13Ool004=oo`03001oocg_00lm
khIoo`03001oogoo049oo`00@Goo0P0000=oocg_?Nl03Cg_RGoo0P00@Woo0010Ool00`00Oomoo`0@
?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007ooOol02Sg_
UWoo00<007ooOol0?7oo000lOol20002Ool:?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_00/m
kiYoo`03001oogoo03Yoo`00>Woo00<007oo?Nl02cg_W7oo0P00>Woo000iOol00`00Oolmk`0:?NnP
Ool00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<007oo
Ool02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Aoo`04
001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00<Goo
00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00Oomo
o`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo2Sg_
/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03001o
ogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0:goo
000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMoo`03
001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomoo`05
Ool5?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`00:7oo
00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000WOol00`00Oomoo`06Ool5?No2Ool00`00Oomo
o`0VOol002Ioo`03001oogoo00Ioo`Lmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Woo23g_
`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001o
ogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Woo1cg_b7oo00<007ooOol08Woo
000ROol00`00Oomoo`06Ool8?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03
001oogoo025oo`008Goo00<007ooOol01Woo23g_bgoo00<007ooOol087oo000POol00`00Oomoo`06
Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo
00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`06Ool6?NoBOol00`00Oomo
o`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01goo1cg_
dgoo00<007ooOol077oo000MOol00`00Oomoo`06Ool8?NoCOol00`00Oomoo`0LOol001aoo`03001o
ogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo
000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03
001oogoo01Yoo`006Woo00<007ooOol01Woo2Cg_f7oo00<007ooOol06Goo000JOol00`00Oomoo`06
Ool8?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Ioo`Pmkm]oo`03001oogoo01Qoo`006Goo
00<007ooOol01Woo1cg_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomo
o`0GOol001Qoo`03001oogoo00Eoo`Lmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo23g_
ggoo00<007ooOol05goo000GOol00`00Oomoo`05Ool8?NoPOol00`00Oomoo`0FOol001Moo`03001o
ogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol05Goo
000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05
Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo
00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomo
o`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_
jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001o
ogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo
000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03
001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07
Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo
00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomo
o`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_
kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo
000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03
001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:
Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo
00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomo
o`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol037oo
000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0mknUo
o`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00Oomo
o`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001oogoo
00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH?NoV
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoT
Ool00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007oo
Ool067oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool0
00aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo00<0
07ooOol02goo000=Ool00`00Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo01]o
o`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo
00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoM
Ool00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<007oo
Ool077oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<Ool0
00eoo`03001oogoo01ioo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo00<0
07ooOol03Goo000>Ool00`00Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol0
0`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001o
ogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00mo
o`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0
019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000B
Ool00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03
001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00
Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo
0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_
Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo
00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03
001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00
Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007oo
Ool06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo
01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0K
Ool001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo
000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`00
7goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021o
o`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<0
07ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomo
o`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0
cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uo
o`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool0
0`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<0
07ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001o
ogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomo
o`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0
<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007oo
Ool0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo
0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[
Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo
000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00
?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049o
o`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0
04Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019
Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomo
o`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001g
Ool2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol0
05]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069o
o`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@0
06eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo
3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
08aoo`<00003Ool0000000<008]oo`00SGoo00<007ooOol00Woo00<007ooOol0Rgoo002:Ool50003
Ool00`00Oomoo`2;Ool008Yoo`04001oogoo0004Ool00`00Oomoo`2;Ool008]oo`03001oo`0000Ao
o`03001oogoo08]oo`00S7oo0P000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(42)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
1 .968 0 r
.008 w
.37434 .03896 Mdot
.016 w
.37434 .03896 m
.37418 .03895 L
s
1 .935 0 r
.008 w
.37418 .03895 Mdot
.016 w
.37418 .03895 m
.37393 .03894 L
s
1 .903 0 r
.008 w
.37393 .03894 Mdot
.016 w
.37393 .03894 m
.37363 .03889 L
s
1 .871 0 r
.008 w
.37363 .03889 Mdot
.016 w
.37363 .03889 m
.3733 .0388 L
s
1 .839 0 r
.008 w
.3733 .0388 Mdot
.016 w
.3733 .0388 m
.37294 .03868 L
s
1 .806 0 r
.008 w
.37294 .03868 Mdot
.016 w
.37294 .03868 m
.37257 .03857 L
s
1 .774 0 r
.008 w
.37257 .03857 Mdot
.016 w
.37257 .03857 m
.37219 .0385 L
s
1 .742 0 r
.008 w
.37219 .0385 Mdot
.016 w
.37219 .0385 m
.3718 .03848 L
s
1 .71 0 r
.008 w
.3718 .03848 Mdot
.016 w
.3718 .03848 m
.37135 .03856 L
s
1 .677 0 r
.008 w
.37135 .03856 Mdot
.016 w
.37135 .03856 m
.37082 .03877 L
s
1 .645 0 r
.008 w
.37082 .03877 Mdot
.016 w
.37082 .03877 m
.37021 .03913 L
s
1 .613 0 r
.008 w
.37021 .03913 Mdot
.016 w
.37021 .03913 m
.36951 .03966 L
s
1 .581 0 r
.008 w
.36951 .03966 Mdot
.016 w
.36951 .03966 m
.3687 .04035 L
s
1 .548 0 r
.008 w
.3687 .04035 Mdot
.016 w
.3687 .04035 m
.36773 .04117 L
s
1 .516 0 r
.008 w
.36773 .04117 Mdot
.016 w
.36773 .04117 m
.3666 .04211 L
s
1 .484 0 r
.008 w
.3666 .04211 Mdot
.016 w
.3666 .04211 m
.36542 .04305 L
s
1 .452 0 r
.008 w
.36542 .04305 Mdot
.016 w
.36542 .04305 m
.36403 .04402 L
s
1 .419 0 r
.008 w
.36403 .04402 Mdot
.016 w
.36403 .04402 m
.36243 .04503 L
s
1 .387 0 r
.008 w
.36243 .04503 Mdot
.016 w
.36243 .04503 m
.36085 .04604 L
s
1 .355 0 r
.008 w
.36085 .04604 Mdot
.016 w
.36085 .04604 m
.35895 .04699 L
s
1 .323 0 r
.008 w
.35895 .04699 Mdot
.016 w
.35895 .04699 m
.35725 .04779 L
s
1 .29 0 r
.008 w
.35725 .04779 Mdot
.016 w
.35725 .04779 m
.35554 .04847 L
s
1 .258 0 r
.008 w
.35554 .04847 Mdot
.016 w
.35554 .04847 m
.35389 .04899 L
s
1 .226 0 r
.008 w
.35389 .04899 Mdot
.016 w
.35389 .04899 m
.35244 .04935 L
s
1 .194 0 r
.008 w
.35244 .04935 Mdot
.016 w
.35244 .04935 m
.35126 .04957 L
s
1 .161 0 r
.008 w
.35126 .04957 Mdot
.016 w
.35126 .04957 m
.35028 .04966 L
s
1 .129 0 r
.008 w
.35028 .04966 Mdot
.016 w
.35028 .04966 m
.34951 .04966 L
s
1 .097 0 r
.008 w
.34951 .04966 Mdot
.016 w
.34951 .04966 m
.34897 .04961 L
s
1 .065 0 r
.008 w
.34897 .04961 Mdot
.016 w
.34897 .04961 m
.34862 .04954 L
s
1 .032 0 r
.008 w
.34862 .04954 Mdot
.016 w
.34862 .04954 m
.34842 .04947 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol4OT000gj0Ol0mk`0T?NlEOol5001b
Ool006Moo`03?Nmm`7g0009m`003OP1nP7o002HmkaUoo`@006ioo`00IGoo00<mkge0OD000We000Em
H7fPOP1nP7o002Hmkaeoo`@006Yoo`00Hgoo1Ga000Mlh7dPOF1mX7h0OX1o`00V?NlQOol3001WOol0
069oo`04?Nml@7a0O202O4001GcPOB1mH7fPOP00:3g_97oo0`00I7oo001POol3?Nl2O4001g`PO41l
@7cPOB1mH7fP01<mk`Moo`Pmkbioo`<0065oo`00GWoo1Cg_1Ga000=lh7dP?Nl01Cg_00=oocg_?Nl0
2Sg_2Goo13g_=Goo0P00Ggoo001LOolB?Nl5Ool00cg_Oomoo`06?Nm5Ool2001MOol005Yoo`03000m
kcg_00/mke]oo`8005]oo`00F7oo00<003g_?Nl02Cg_HGoo0P00FGoo001EOol3000:?NmUOol3001F
Ool005=oo`8000=oo`XmkfQoo`8005Aoo`00DGoo0P000goo2Cg_KGoo0P00DWoo001@Ool01000Oomo
ogoo2cg_Kgoo00<007ooOol0Cgoo001?Ool01000Oomoogoo33g_L7oo00<007ooOol0CWoo001=Ool2
0003Ool<?NmbOol2001>Ool004]oo`8000Eoo`TmkgMoo`8004aoo`00BGoo0P0017oo2cg_NWoo0P00
BWoo0018Ool00`00Oomoo`02Ool=?NmlOol00`00Oomoo`17Ool004Ioo`8000Aoo`hmkgeoo`8004Mo
o`00AGoo00@007ooOomooa0mkh1oo`03001oogoo04Aoo`00A7oo00<007ooOol03cg_Q7oo00<007oo
Ool0@goo0013Ool00`00Oolmk`0??Nn6Ool00`00Oomoo`12Ool0045oo`800003Oolmkcg_00dmkhUo
o`80049oo`00@7oo00<007ooOol043g_Rgoo00<007ooOol0?goo000oOol00`00Oomoo`0:?NnCOol2
000oOol003ioo`03001oogoo00XmkiIoo`03001oogoo03aoo`00?7oo0P000Woo2Sg_V7oo00<007oo
Ool0>goo000kOol00`00Oolmk`0;?NnJOol00`00Oomoo`0jOol003Yoo`03001oocg_00/mkiaoo`80
03Yoo`00>Goo00<007oo?Nl02Sg_X7oo00<007ooOol0=goo000gOol200000goo?Nlmk`0:?NnQOol0
0`00Oomoo`0fOol003Ioo`03001oogoo00TmkjIoo`03001oogoo03Eoo`00=Goo00<007ooOol02Sg_
Ygoo00<007ooOol0=7oo000dOol01000Oomoogoo2Cg_ZGoo00<007ooOol0<goo000bOol20003Ool:
?NnZOol00`00Oomoo`0bOol0035oo`03001oogoo009oo`/mkj]oo`03001oogoo035oo`00<7oo00<0
07ooOol00Woo33g_[7oo00<007ooOol0<7oo000`Ool00`00Oomoo`02Ool;?Nn^Ool00`00Oomoo`0_
Ool002moo`03001oogoo009oo`Xmkk5oo`03001oogoo02ioo`00;Woo00<007ooOol00goo2Sg_/Woo
00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool:?NncOol00`00Oomoo`0/Ool002aoo`03001oogoo
00Aoo`XmkkEoo`03001oogoo02]oo`00;7oo00<007ooOol00goo2Sg_]Woo00<007ooOol0:goo000[
Ool00`00Oomoo`04Ool:?NngOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`Dmkkioo`03001o
ogoo02Uoo`00:Goo00<007ooOol01Goo1Cg__goo00<007ooOol0:7oo000XOol00`00Oomoo`05Ool5
?No1Ool00`00Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`009goo00<0
07ooOol01Woo1Cg_`Woo00<007ooOol09Woo000VOol00`00Oomoo`06Ool7?No2Ool00`00Oomoo`0U
Ool002Eoo`03001oogoo00Ioo`Pmkl=oo`03001oogoo02Aoo`0097oo00<007ooOol01Woo23g_aGoo
00<007ooOol08goo000TOol00`00Oomoo`05Ool8?No6Ool00`00Oomoo`0SOol002=oo`03001oogoo
00Ioo`LmklQoo`03001oogoo029oo`008Woo00<007ooOol01Woo23g_bGoo00<007ooOol08Goo000R
Ool00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0025oo`03001oogoo00Ioo`Pmkl]oo`03001o
ogoo021oo`0087oo00<007ooOol01Woo23g_cGoo00<007ooOol07goo000POol00`00Oomoo`05Ool7
?No?Ool00`00Oomoo`0OOol001moo`03001oogoo00Ioo`Hmkm5oo`03001oogoo01ioo`007goo00<0
07ooOol01Woo1Sg_dWoo00<007ooOol07Goo000NOol00`00Oomoo`06Ool7?NoBOol00`00Oomoo`0M
Ool001eoo`03001oogoo00Moo`Lmkm=oo`03001oogoo01aoo`007Goo00<007ooOol01Woo23g_dgoo
00<007ooOol077oo000LOol00`00Oomoo`06Ool8?NoEOol00`00Oomoo`0KOol001aoo`03001oogoo
00Eoo`TmkmEoo`03001oogoo01]oo`006goo00<007ooOol01Woo2Cg_eWoo00<007ooOol06Woo000K
Ool00`00Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Ioo`TmkmQoo`03001o
ogoo01Uoo`006Woo00<007ooOol01Woo23g_fGoo00<007ooOol06Goo000IOol00`00Oomoo`06Ool8
?NoKOol00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lmkmaoo`03001oogoo01Qoo`0067oo00<0
07ooOol01Goo23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`05Ool7?NoOOol00`00Oomoo`0G
Ool001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol01Goo23g_h7oo
00<007ooOol05Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo
00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<007ooOol01Goo1Sg_i7oo00<007ooOol05Goo000E
Ool00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001o
ogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00Oomoo`06Ool6
?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<0
07ooOol01Goo1cg_igoo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0B
Ool001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo
00<007ooOol04Woo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo
00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Cg_k7oo00<007ooOol04Goo000A
Ool00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03001o
ogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00Oomoo`07Ool6
?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<0
07ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol02Goo1Sg_kWoo
00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo
00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?
Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Pmkneoo`03001o
ogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0<Ool:
?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo00eoo`003Woo00<0
07ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<
Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo
00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo
00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl00cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo00<007ooOol027oo3cg_jWoo00<007ooOol037oo
000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa4mknQoo`03
001oogoo00aoo`0037oo00<007ooOol027oo4cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00IooaLmknIoo`03001oogoo00]o
o`0037oo00<007ooOol01Goo63g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08OolE?NoVOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;
Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol06Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol7?NoTOol0
0`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol0
67oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000eo
o`03001oogoo01Moo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_ggoo00<007oo
Ool037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pm
kmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00ao
o`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol9?NoLOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol0
7Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomoo`0<Ool000io
o`03001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007oo
Ool03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo
00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>
Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo
000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001oogoo00ioo`00
47oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011o
o`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol0
0`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<0
07ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0019oo`03001o
ogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000COol00`00Oomo
o`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo00<007ooOol0
mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03001oogoo0?=o
o`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00Oomoo`3bOol0
0`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<0
07ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo0>moo`03001o
ogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]Ool00`00Oomo
o`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo00<007ooOol0
5goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03001oogoo01Mo
o`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00Oomoo`0HOol0
01Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000K
Ool00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`0077oo
00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001eoo`03
001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000NOol00`00
Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`007goo00<007oo
Ool0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021oo`03001oogoo
0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol00`00Oomoo`3G
Ool00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<007ooOol0dgoo
00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001oogoo0=5oo`03
001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomoo`3?Ool00`00
Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0bgoo00<007oo
Ool09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Moo`03001oogoo
02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomoo`0Z
Ool002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<007ooOol0;7oo
000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00
;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0035o
o`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2cOol0
0`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007ooOol0/Goo00<0
07ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo0:eoo`03001o
ogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000jOol003]oo`03
001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo000mOol00`00
Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0Vgoo00<007oo
Ool0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049oo`00A7oo00<0
07ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool004Ioo`8008mo
o`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=oo`8004eoo`00
CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomoo`1>Ool0051o
o`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Ioo`8006moo`80
05Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<005moo`00H7oo
0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Ioo`00J7oo1000
Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00;goo1000MGoo
001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002<Ool300000goo00000002002<Ool008eoo`04001oogoo002?
Ool008Yoo`D0009oo`03001oogoo08aoo`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00Rgoo
00<007oo00000Woo00@007ooOol008aoo`00S7oo0P000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(43)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
1 .933 0 r
.008 w
.34919 .049 Mdot
.016 w
.34919 .049 m
.34909 .04914 L
s
1 .867 0 r
.008 w
.34909 .04914 Mdot
.016 w
.34909 .04914 m
.34884 .04939 L
s
1 .8 0 r
.008 w
.34884 .04939 Mdot
.016 w
.34884 .04939 m
.3484 .04977 L
s
1 .733 0 r
.008 w
.3484 .04977 Mdot
.016 w
.3484 .04977 m
.34778 .05027 L
s
1 .667 0 r
.008 w
.34778 .05027 Mdot
.016 w
.34778 .05027 m
.34704 .05085 L
s
1 .6 0 r
.008 w
.34704 .05085 Mdot
.016 w
.34704 .05085 m
.34622 .0515 L
s
1 .533 0 r
.008 w
.34622 .0515 Mdot
.016 w
.34622 .0515 m
.34538 .05218 L
s
1 .467 0 r
.008 w
.34538 .05218 Mdot
.016 w
.34538 .05218 m
.34454 .05282 L
s
1 .4 0 r
.008 w
.34454 .05282 Mdot
.016 w
.34454 .05282 m
.34387 .05344 L
s
1 .333 0 r
.008 w
.34387 .05344 Mdot
.016 w
.34387 .05344 m
.34311 .05405 L
s
1 .267 0 r
.008 w
.34311 .05405 Mdot
.016 w
.34311 .05405 m
.34239 .05464 L
s
1 .2 0 r
.008 w
.34239 .05464 Mdot
.016 w
.34239 .05464 m
.34177 .05516 L
s
1 .133 0 r
.008 w
.34177 .05516 Mdot
.016 w
.34177 .05516 m
.34133 .05557 L
s
1 .067 0 r
.008 w
.34133 .05557 Mdot
.016 w
.34133 .05557 m
.34111 .05581 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOol4OV000gmP?Nlmk`0[?NlQOol3001WOol0069oo`Am
0003OL1oH3g_02`mkbAoo`<006Aoo`00H7oo00@mkgb0O81l@09lP003OL1oH3g_01Hmk`Moo`Pmkbio
o`<0065oo`00GWoo0cg_0Wb000El@7b0O81m`7mP00Pmk`03Oolmkcg_00Xmk`Uoo`@mkcEoo`8005mo
o`00G7oo1Cg_1Gb000=m`3g_?Nl01Cg_1Goo00<mkgooOol01Sg_AGoo0P00GGoo001JOol00`00?Nlm
k`04?Nl5O802?NmKOol2001KOol005Qoo`03000mkcg_00Tmkf5oo`8005Uoo`00EGoo0`002Sg_IGoo
0`00EWoo001COol20003Ool:?NmXOol2001DOol0055oo`8000=oo`Tmkfeoo`80059oo`00D7oo00@0
07ooOomoo`/mkfmoo`03001oogoo04moo`00Cgoo00@007ooOomoo``mkg1oo`03001oogoo04ioo`00
CGoo0P000goo33g_LWoo0P00CWoo001;Ool20005Ool9?NmgOol2001<Ool004Uoo`8000Aoo`/mkgYo
o`8004Yoo`00B7oo00<007ooOol00Woo3Cg_O7oo00<007ooOol0Agoo0016Ool20004Ool>?NmmOol2
0017Ool004Eoo`04001oogooOol@?Nn0Ool00`00Oomoo`14Ool004Aoo`03001oogoo00lmkhAoo`03
001oogoo04=oo`00@goo00<007oo?Nl03cg_QWoo00<007ooOol0@Woo0011Ool200000goo?Nlmk`0=
?Nn9Ool20012Ool0041oo`03001oogoo010mkh]oo`03001oogoo03moo`00?goo00<007ooOol02Sg_
Tgoo0P00?goo000nOol00`00Oomoo`0:?NnFOol00`00Oomoo`0lOol003aoo`80009oo`XmkiQoo`03
001oogoo03]oo`00>goo00<007oo?Nl02cg_VWoo00<007ooOol0>Woo000jOol00`00Oolmk`0;?NnL
Ool2000jOol003Uoo`03001oocg_00Xmkj1oo`03001oogoo03Moo`00=goo0P0000=oocg_?Nl02Sg_
XGoo00<007ooOol0=Woo000fOol00`00Oomoo`09?NnVOol00`00Oomoo`0eOol003Eoo`03001oogoo
00XmkjMoo`03001oogoo03Aoo`00=7oo00@007ooOomoo`TmkjUoo`03001oogoo03=oo`00<Woo0P00
0goo2Sg_ZWoo00<007ooOol0<Woo000aOol00`00Oomoo`02Ool;?Nn[Ool00`00Oomoo`0aOol0031o
o`03001oogoo009oo``mkjaoo`03001oogoo031oo`00<7oo00<007ooOol00Woo2cg_[Woo00<007oo
Ool0;goo000_Ool00`00Oomoo`02Ool:?NnaOol00`00Oomoo`0^Ool002ioo`03001oogoo00=oo`Xm
kk9oo`03001oogoo02eoo`00;Goo00<007ooOol017oo2Sg_/goo00<007ooOol0;7oo000/Ool00`00
Oomoo`04Ool:?NneOol00`00Oomoo`0[Ool002aoo`03001oogoo00=oo`XmkkIoo`03001oogoo02]o
o`00:goo00<007ooOol017oo2Sg_]goo00<007ooOol0:Woo000ZOol00`00Oomoo`04Ool5?NnnOol0
0`00Oomoo`0YOol002Uoo`03001oogoo00Eoo`Dmkkmoo`03001oogoo02Qoo`00:7oo00<007ooOol0
1Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1Ool00`00Oomoo`0WOol002Mo
o`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007ooOol01Woo1cg_`Woo00<007oo
Ool09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol002Aoo`03001oogoo00Ioo`Pm
klEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<007ooOol08goo000SOol00`00
Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Ioo`PmklUoo`03001oogoo025o
o`008Woo00<007ooOol01Goo2Cg_bGoo00<007ooOol08Goo000QOol00`00Oomoo`06Ool8?No;Ool0
0`00Oomoo`0POol0021oo`03001oogoo00Ioo`Pmkleoo`03001oogoo01moo`0087oo00<007ooOol0
1Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoAOol00`00Oomoo`0NOol001mo
o`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007ooOol01Woo1cg_dWoo00<007oo
Ool07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol001eoo`03001oogoo00Ioo`Pm
km=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<007ooOol06goo000LOol00`00
Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Ioo`TmkmIoo`03001oogoo01Yo
o`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol00`00Oomoo`06Ool9?NoHOol0
0`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo01Uoo`006Goo00<007ooOol0
1Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoLOol00`00Oomoo`0HOol001Qo
o`03001oogoo00Eoo`Pmkmioo`03001oogoo01Moo`0067oo00<007ooOol01Goo1cg_ggoo00<007oo
Ool05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol001Moo`03001oogoo00Eoo`Pm
kn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<007ooOol05Woo000FOol00`00
Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eoo`HmknAoo`03001oogoo01Eo
o`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol0
0`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`0057oo00<007ooOol0
1Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Ao
o`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007ooOol01Woo1Sg_jGoo00<007oo
Ool04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=oo`03001oogoo00Ioo`Hm
knUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00
Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Ioo`Dmknaoo`03001oogoo015o
o`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool5?No]Ool0
0`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo011oo`004Goo00<007ooOol0
1goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007oo
Ool03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hm
knioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00io
o`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool8?No]Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo00eoo`003Woo00<007ooOol0
37oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000io
o`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hm
knIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00
Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pmk`03Oolmkcg_00<mknMo
o`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<007ooOol037oo000=Ool0
0`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`lmknYoo`03001oogoo
00aoo`003Goo00<007ooOol027oo43g_jGoo00<007ooOol037oo000=Ool00`00Oomoo`08OolA?NoX
Ool00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<mknQoo`03001oogoo00]oo`0037oo00<007oo
Ool01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`06OolG?NoVOol00`00Oomo
o`0;Ool000aoo`03001oogoo00EooaPmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo5Cg_
iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo
1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;Ool6?NoUOol00`00Oomo
o`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001oogoo00]oo`0037oo00<007ooOol067oo1cg_
i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9?NoROol00`00Oomoo`0;Ool000aoo`03001o
ogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_hGoo00<007ooOol02goo
000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;Ool000eoo`03001oogoo01]oo`Lmkmmoo`03
001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0K
Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo
00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomo
o`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo2Cg_
g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Woo2Cg_fWoo00<007ooOol037oo
000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=Ool000ioo`03001oogoo01ioo`Dmkmaoo`03
001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00
Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<007ooOol0oGoo00<007oo
Ool03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo
00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomoo`3lOol00`00Oomoo`0>
Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo
000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`00
4Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0015o
o`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<007ooOol047oo000BOol0
0`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001oogoo015oo`004goo00<0
07ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001=oo`03001o
ogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol04Woo000DOol00`00Oomo
o`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`005Goo00<007ooOol0
lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5o
o`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000FOol00`00Oomoo`3_Ool0
0`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo00<007ooOol0kGoo00<0
07ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03001oogoo0>]oo`03001o
ogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00Oomoo`3ZOol00`00Oomo
o`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007ooOol0j7oo00<007ooOol0
67oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo0>Eoo`03001oogoo01Yo
o`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol0
01aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo00<007ooOol077oo000M
Ool00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo
00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03
001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo000POol00`00
Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo021oo`008Woo00<007oo
Ool0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo
0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo000UOol00`00Oomoo`3A
Ool00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009Woo00<007ooOol0cgoo
00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qoo`03001oogoo0<]oo`03
001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol00`00Oomoo`37Ool00`00
Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<007ooOol0aGoo00<007oo
Ool0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001oogoo0<5oo`03001oogoo
02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]
Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0^goo00<007ooOol0;goo
000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=oo`00=7oo00<007ooOol0
/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Eoo`03001oogoo0;5o
o`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool0
0`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000k
Ool00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03001oogoo03]oo`00?Goo
00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041oo`03001oogoo09]oo`03
001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Ao
o`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<007ooOol0A7oo0016Ool2
002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo001<Ool20023Ool2001=
Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0OGoo00<007ooOol0CWoo
001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo0P00EGoo001FOol2001_
Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001NOol2001NOol3001OOol0
061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3001?Ool3001VOol006Qo
o`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001aOol007=oo`D002moo`@0
07Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`000Woo0P00SGoo002=Ool01000Oomoo`000Woo
00<007ooOol0RWoo002:Ool50003Ool00`00Oomoo`2;Ool008Yoo`04001oogoo0005Ool00`00Oomo
o`2:Ool008]oo`03001oo`00009oo`04001oogoo002<Ool008aoo`8000=oo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(44)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
1 .971 0 r
.008 w
.34194 .05548 Mdot
.016 w
.34194 .05548 m
.34181 .05556 L
s
1 .941 0 r
.008 w
.34181 .05556 Mdot
.016 w
.34181 .05556 m
.34147 .05573 L
s
1 .912 0 r
.008 w
.34147 .05573 Mdot
.016 w
.34147 .05573 m
.34091 .05598 L
s
1 .882 0 r
.008 w
.34091 .05598 Mdot
.016 w
.34091 .05598 m
.34011 .05631 L
s
1 .853 0 r
.008 w
.34011 .05631 Mdot
.016 w
.34011 .05631 m
.33904 .05672 L
s
1 .824 0 r
.008 w
.33904 .05672 Mdot
.016 w
.33904 .05672 m
.33789 .05721 L
s
1 .794 0 r
.008 w
.33789 .05721 Mdot
.016 w
.33789 .05721 m
.3364 .05781 L
s
1 .765 0 r
.008 w
.3364 .05781 Mdot
.016 w
.3364 .05781 m
.33504 .05849 L
s
1 .735 0 r
.008 w
.33504 .05849 Mdot
.016 w
.33504 .05849 m
.33356 .05929 L
s
1 .706 0 r
.008 w
.33356 .05929 Mdot
.016 w
.33356 .05929 m
.33186 .0602 L
s
1 .676 0 r
.008 w
.33186 .0602 Mdot
.016 w
.33186 .0602 m
.33023 .06121 L
s
1 .647 0 r
.008 w
.33023 .06121 Mdot
.016 w
.33023 .06121 m
.32853 .0623 L
s
1 .618 0 r
.008 w
.32853 .0623 Mdot
.016 w
.32853 .0623 m
.32675 .06341 L
s
1 .588 0 r
.008 w
.32675 .06341 Mdot
.016 w
.32675 .06341 m
.32495 .06449 L
s
1 .559 0 r
.008 w
.32495 .06449 Mdot
.016 w
.32495 .06449 m
.32324 .06548 L
s
1 .529 0 r
.008 w
.32324 .06548 Mdot
.016 w
.32324 .06548 m
.3215 .06646 L
s
1 .5 0 r
.008 w
.3215 .06646 Mdot
.016 w
.3215 .06646 m
.31979 .06736 L
s
1 .471 0 r
.008 w
.31979 .06736 Mdot
.016 w
.31979 .06736 m
.31839 .06819 L
s
1 .441 0 r
.008 w
.31839 .06819 Mdot
.016 w
.31839 .06819 m
.31694 .06889 L
s
1 .412 0 r
.008 w
.31694 .06889 Mdot
.016 w
.31694 .06889 m
.31559 .06951 L
s
1 .382 0 r
.008 w
.31559 .06951 Mdot
.016 w
.31559 .06951 m
.31452 .07004 L
s
1 .353 0 r
.008 w
.31452 .07004 Mdot
.016 w
.31452 .07004 m
.31358 .07046 L
s
1 .324 0 r
.008 w
.31358 .07046 Mdot
.016 w
.31358 .07046 m
.31276 .0708 L
s
1 .294 0 r
.008 w
.31276 .0708 Mdot
.016 w
.31276 .0708 m
.31209 .07105 L
s
1 .265 0 r
.008 w
.31209 .07105 Mdot
.016 w
.31209 .07105 m
.31157 .07125 L
s
1 .235 0 r
.008 w
.31157 .07125 Mdot
.016 w
.31157 .07125 m
.31123 .07143 L
s
1 .206 0 r
.008 w
.31123 .07143 Mdot
.016 w
.31123 .07143 m
.31106 .07159 L
s
1 .176 0 r
.008 w
.31106 .07159 Mdot
.016 w
.31106 .07159 m
.31104 .07175 L
s
1 .147 0 r
.008 w
.31104 .07175 Mdot
.016 w
.31104 .07175 m
.31112 .0719 L
s
1 .118 0 r
.008 w
.31112 .0719 Mdot
.016 w
.31112 .0719 m
.31125 .07208 L
s
1 .088 0 r
.008 w
.31125 .07208 Mdot
.016 w
.31125 .07208 m
.31139 .07228 L
s
1 .059 0 r
.008 w
.31139 .07228 Mdot
.016 w
.31139 .07228 m
.3115 .07248 L
s
1 .029 0 r
.008 w
.3115 .07248 Mdot
.016 w
.3115 .07248 m
.31155 .07266 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo17l000=o@7o0?Nl063g_1goo23g_;Woo0`00HGoo001NOol4OX0017jPO^1o@7o02Sg_00=oocg_
?Nl02Sg_2Goo13g_=Goo0P00Ggoo001LOol2OJ02OP001WhPOV1nX7kPOd1o`0Pmk`Eoo`03?Nmoogoo
00HmkdEoo`8005eoo`00FWoo00<007fPOJ000WfP00Mmh7hPOV1nX7kPOd1o`002?NmKOol2001KOol0
05Qoo`03001m87dP00=m809mX004OR1nH7jPO^1QOol2001IOol005Eoo`<00004?Nmm87dPO002OB00
17fPON1n87iPIGoo0`00EWoo001COol20003Ool013g_OB1m87`00WdP0WgP0Sg_J7oo0P00E7oo001A
Ool20003Ool3?Nl5OB000cg_Oomoo`1[Ool2001BOol0051oo`04001oogooOol;?Nm_Ool00`00Oomo
o`1?Ool004moo`04001oogooOol<?Nm`Ool00`00Oomoo`1>Ool004eoo`8000=oo``mkg9oo`8004io
o`00Bgoo0P001Goo2Cg_Mgoo0P00C7oo0019Ool20004Ool;?NmjOol2001:Ool004Qoo`03001oogoo
009oo`dmkgaoo`03001oogoo04Moo`00AWoo0P0017oo3Sg_OGoo0P00Agoo0015Ool01000Oomoogoo
43g_P7oo00<007ooOol0A7oo0014Ool00`00Oomoo`0??Nn4Ool00`00Oomoo`13Ool004=oo`03001o
ocg_00lmkhIoo`03001oogoo049oo`00@Goo0P0000=oocg_?Nl03Cg_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
Ool02Sg_UWoo00<007ooOol0?7oo000lOol20002Ool:?NnHOol00`00Oomoo`0kOol003]oo`03001o
ocg_00/mkiYoo`03001oogoo03Yoo`00>Woo00<007oo?Nl02cg_W7oo0P00>Woo000iOol00`00Oolm
k`0:?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo
00<007ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol0
03Aoo`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039o
o`00<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool0
0`00Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol0
0Woo2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eo
o`03001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007oo
Ool0:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`Xm
kkMoo`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00
Oomoo`05Ool5?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Mo
o`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000WOol00`00Oomoo`06Ool5?No2Ool0
0`00Oomoo`0VOol002Ioo`03001oogoo00Ioo`Lmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol0
1Woo23g_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Ao
o`03001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Woo1cg_b7oo00<007oo
Ool08Woo000ROol00`00Oomoo`06Ool8?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`Tm
klUoo`03001oogoo025oo`008Goo00<007ooOol01Woo23g_bgoo00<007ooOol087oo000POol00`00
Oomoo`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01mo
o`007goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`06Ool6?NoBOol0
0`00Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol0
1goo1cg_dgoo00<007ooOol077oo000MOol00`00Oomoo`06Ool8?NoCOol00`00Oomoo`0LOol001ao
o`03001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007oo
Ool06goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`Tm
kmMoo`03001oogoo01Yoo`006Woo00<007ooOol01Woo2Cg_f7oo00<007ooOol06Goo000JOol00`00
Oomoo`06Ool8?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Ioo`Pmkm]oo`03001oogoo01Qo
o`006Goo00<007ooOol01Woo1cg_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol0
0`00Oomoo`0GOol001Qoo`03001oogoo00Eoo`Lmkmmoo`03001oogoo01Moo`0067oo00<007ooOol0
17oo23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`05Ool8?NoPOol00`00Oomoo`0FOol001Mo
o`03001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007oo
Ool05Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`Hm
knEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00
Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=o
o`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol0
0`00Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol0
1Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019o
o`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007oo
Ool04Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dm
kneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00mo
o`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol0
27oo1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pm
knaoo`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00
Oomoo`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eo
o`003Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eo
o`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007oo
Ool037oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03
001oogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<0
07ooOol037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
oa0mknUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool0
0`00Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03
001oogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05
OolH?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo
00<007ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0I
Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo
00<007ooOol067oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomo
o`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_
h7oo00<007ooOol02goo000=Ool00`00Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo
000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo
00<007ooOol077oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomo
o`0<Ool000eoo`03001oogoo01ioo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_
fGoo00<007ooOol03Goo000>Ool00`00Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001o
ogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomo
o`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0
oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eo
o`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol0
0`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<0
07ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001o
ogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomo
o`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol0
4Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015o
o`004goo00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol0
01Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000D
Ool00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo
00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03
001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00
Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007oo
Ool0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo
0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3Y
Ool00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo
00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03
001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00
Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007oo
Ool077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo
01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0N
Ool0021oo`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo
000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`00
8goo00<007ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Ao
o`03001oogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol0
0`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<0
07ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001o
ogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomo
o`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0
`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;mo
o`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol0
0`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<0
07ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo
00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03
001oogoo0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00
Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007oo
Ool0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo
03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uo
o`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomo
o`13Ool004Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;
Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol0
0`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001B
Ool2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3
001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1P
Ool0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@0
03moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uo
o`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol008aoo`<000=oo`<008]oo`00SGoo00<007ooOol00goo00<007ooOol0RWoo002:Ool50000
0goo00000003002;Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002;Ool00`00Ool00003
Ool00`00Ool0002<Ool008aoo`8000Aoo`8008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(45)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
1 .977 0 r
.008 w
.31177 .07271 Mdot
.016 w
.31177 .07271 m
.31153 .07287 L
s
1 .955 0 r
.008 w
.31153 .07287 Mdot
.016 w
.31153 .07287 m
.31115 .0731 L
s
1 .932 0 r
.008 w
.31115 .0731 Mdot
.016 w
.31115 .0731 m
.31067 .07339 L
s
1 .909 0 r
.008 w
.31067 .07339 Mdot
.016 w
.31067 .07339 m
.31011 .07372 L
s
1 .886 0 r
.008 w
.31011 .07372 Mdot
.016 w
.31011 .07372 m
.30952 .07406 L
s
1 .864 0 r
.008 w
.30952 .07406 Mdot
.016 w
.30952 .07406 m
.30888 .07444 L
s
1 .841 0 r
.008 w
.30888 .07444 Mdot
.016 w
.30888 .07444 m
.30818 .07486 L
s
1 .818 0 r
.008 w
.30818 .07486 Mdot
.016 w
.30818 .07486 m
.30745 .07534 L
s
1 .795 0 r
.008 w
.30745 .07534 Mdot
.016 w
.30745 .07534 m
.30666 .07587 L
s
1 .773 0 r
.008 w
.30666 .07587 Mdot
.016 w
.30666 .07587 m
.30582 .07645 L
s
1 .75 0 r
.008 w
.30582 .07645 Mdot
.016 w
.30582 .07645 m
.30495 .07707 L
s
1 .727 0 r
.008 w
.30495 .07707 Mdot
.016 w
.30495 .07707 m
.30412 .07768 L
s
1 .705 0 r
.008 w
.30412 .07768 Mdot
.016 w
.30412 .07768 m
.30339 .07827 L
s
1 .682 0 r
.008 w
.30339 .07827 Mdot
.016 w
.30339 .07827 m
.3028 .07882 L
s
1 .659 0 r
.008 w
.3028 .07882 Mdot
.016 w
.3028 .07882 m
.30233 .07932 L
s
1 .636 0 r
.008 w
.30233 .07932 Mdot
.016 w
.30233 .07932 m
.30196 .07975 L
s
1 .614 0 r
.008 w
.30196 .07975 Mdot
.016 w
.30196 .07975 m
.30159 .08015 L
s
1 .591 0 r
.008 w
.30159 .08015 Mdot
.016 w
.30159 .08015 m
.30118 .08053 L
s
1 .568 0 r
.008 w
.30118 .08053 Mdot
.016 w
.30118 .08053 m
.30068 .0809 L
s
1 .545 0 r
.008 w
.30068 .0809 Mdot
.016 w
.30068 .0809 m
.30007 .08125 L
s
1 .523 0 r
.008 w
.30007 .08125 Mdot
.016 w
.30007 .08125 m
.29937 .08154 L
s
1 .5 0 r
.008 w
.29937 .08154 Mdot
.016 w
.29937 .08154 m
.29863 .08174 L
s
1 .477 0 r
.008 w
.29863 .08174 Mdot
.016 w
.29863 .08174 m
.29786 .08185 L
s
1 .455 0 r
.008 w
.29786 .08185 Mdot
.016 w
.29786 .08185 m
.29713 .08187 L
s
1 .432 0 r
.008 w
.29713 .08187 Mdot
.016 w
.29713 .08187 m
.29647 .08181 L
s
1 .409 0 r
.008 w
.29647 .08181 Mdot
.016 w
.29647 .08181 m
.29589 .08169 L
s
1 .386 0 r
.008 w
.29589 .08169 Mdot
.016 w
.29589 .08169 m
.29532 .08157 L
s
1 .364 0 r
.008 w
.29532 .08157 Mdot
.016 w
.29532 .08157 m
.29472 .08146 L
s
1 .341 0 r
.008 w
.29472 .08146 Mdot
.016 w
.29472 .08146 m
.29408 .0814 L
s
1 .318 0 r
.008 w
.29408 .0814 Mdot
.016 w
.29408 .0814 m
.29346 .08138 L
s
1 .295 0 r
.008 w
.29346 .08138 Mdot
.016 w
.29346 .08138 m
.29292 .08141 L
s
1 .273 0 r
.008 w
.29292 .08141 Mdot
.016 w
.29292 .08141 m
.29247 .08148 L
s
1 .25 0 r
.008 w
.29247 .08148 Mdot
.016 w
.29247 .08148 m
.29212 .08159 L
s
1 .227 0 r
.008 w
.29212 .08159 Mdot
.016 w
.29212 .08159 m
.29185 .08174 L
s
1 .205 0 r
.008 w
.29185 .08174 Mdot
.016 w
.29185 .08174 m
.29165 .08192 L
s
1 .182 0 r
.008 w
.29165 .08192 Mdot
.016 w
.29165 .08192 m
.29151 .08213 L
s
1 .159 0 r
.008 w
.29151 .08213 Mdot
.016 w
.29151 .08213 m
.29138 .08238 L
s
1 .136 0 r
.008 w
.29138 .08238 Mdot
.016 w
.29138 .08238 m
.29121 .08259 L
s
1 .114 0 r
.008 w
.29121 .08259 Mdot
.016 w
.29121 .08259 m
.29098 .08284 L
s
1 .091 0 r
.008 w
.29098 .08284 Mdot
.016 w
.29098 .08284 m
.29074 .08309 L
s
1 .068 0 r
.008 w
.29074 .08309 Mdot
.016 w
.29074 .08309 m
.29052 .0833 L
s
1 .045 0 r
.008 w
.29052 .0833 Mdot
.016 w
.29052 .0833 m
.29034 .08348 L
s
1 .023 0 r
.008 w
.29034 .08348 Mdot
.016 w
.29034 .08348 m
.29022 .08358 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00O^1nh002On07?NmQOol2001IOol005Eoo`<000Anh003Od0mkcg_00<mkfEoo`<005Ioo`00Dgoo
0P000Woo17iP0WkP1Cg_J7oo0P00E7oo001AOol20005O4001Ge0OL1n@7kPOd000Sg_KGoo0P00DWoo
001@Ool00`00Oomoo`02O4001W`0O41l@7e0OL1n@09o@08mkfmoo`03001oogoo04moo`00Cgoo00@0
07ooOomoo`9l@006O01l@7a0OD1m`7i013g_L7oo00<007ooOol0CWoo001=Ool20003Ool00cg_O41l
@003O4000ge0OL1n@003?NmbOol2001>Ool004]oo`8000Eoo`TmkgMoo`8004aoo`00BGoo0P0017oo
2cg_NWoo0P00BWoo0018Ool00`00Oomoo`02Ool=?NmlOol00`00Oomoo`17Ool004Ioo`8000Aoo`hm
kgeoo`8004Moo`00AGoo00@007ooOomooa0mkh1oo`03001oogoo04Aoo`00A7oo00<007ooOol03cg_
Q7oo00<007ooOol0@goo0013Ool00`00Oolmk`0??Nn6Ool00`00Oomoo`12Ool0045oo`800003Oolm
kcg_00dmkhUoo`80049oo`00@7oo00<007ooOol043g_Rgoo00<007ooOol0?goo000oOol00`00Oomo
o`0:?NnCOol2000oOol003ioo`03001oogoo00XmkiIoo`03001oogoo03aoo`00?7oo0P000Woo2Sg_
V7oo00<007ooOol0>goo000kOol00`00Oolmk`0;?NnJOol00`00Oomoo`0jOol003Yoo`03001oocg_
00/mkiaoo`8003Yoo`00>Goo00<007oo?Nl02Sg_X7oo00<007ooOol0=goo000gOol200000goo?Nlm
k`0:?NnQOol00`00Oomoo`0fOol003Ioo`03001oogoo00TmkjIoo`03001oogoo03Eoo`00=Goo00<0
07ooOol02Sg_Ygoo00<007ooOol0=7oo000dOol01000Oomoogoo2Cg_ZGoo00<007ooOol0<goo000b
Ool20003Ool:?NnZOol00`00Oomoo`0bOol0035oo`03001oogoo009oo`/mkj]oo`03001oogoo035o
o`00<7oo00<007ooOol00Woo33g_[7oo00<007ooOol0<7oo000`Ool00`00Oomoo`02Ool;?Nn^Ool0
0`00Oomoo`0_Ool002moo`03001oogoo009oo`Xmkk5oo`03001oogoo02ioo`00;Woo00<007ooOol0
0goo2Sg_/Woo00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool:?NncOol00`00Oomoo`0/Ool002ao
o`03001oogoo00Aoo`XmkkEoo`03001oogoo02]oo`00;7oo00<007ooOol00goo2Sg_]Woo00<007oo
Ool0:goo000[Ool00`00Oomoo`04Ool:?NngOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`Dm
kkioo`03001oogoo02Uoo`00:Goo00<007ooOol01Goo1Cg__goo00<007ooOol0:7oo000XOol00`00
Oomoo`05Ool5?No1Ool00`00Oomoo`0WOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Mo
o`009goo00<007ooOol01Woo1Cg_`Woo00<007ooOol09Woo000VOol00`00Oomoo`06Ool7?No2Ool0
0`00Oomoo`0UOol002Eoo`03001oogoo00Ioo`Pmkl=oo`03001oogoo02Aoo`0097oo00<007ooOol0
1Woo23g_aGoo00<007ooOol08goo000TOol00`00Oomoo`05Ool8?No6Ool00`00Oomoo`0SOol002=o
o`03001oogoo00Ioo`LmklQoo`03001oogoo029oo`008Woo00<007ooOol01Woo23g_bGoo00<007oo
Ool08Goo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0025oo`03001oogoo00Ioo`Pm
kl]oo`03001oogoo021oo`0087oo00<007ooOol01Woo23g_cGoo00<007ooOol07goo000POol00`00
Oomoo`05Ool7?No?Ool00`00Oomoo`0OOol001moo`03001oogoo00Ioo`Hmkm5oo`03001oogoo01io
o`007goo00<007ooOol01Woo1Sg_dWoo00<007ooOol07Goo000NOol00`00Oomoo`06Ool7?NoBOol0
0`00Oomoo`0MOol001eoo`03001oogoo00Moo`Lmkm=oo`03001oogoo01aoo`007Goo00<007ooOol0
1Woo23g_dgoo00<007ooOol077oo000LOol00`00Oomoo`06Ool8?NoEOol00`00Oomoo`0KOol001ao
o`03001oogoo00Eoo`TmkmEoo`03001oogoo01]oo`006goo00<007ooOol01Woo2Cg_eWoo00<007oo
Ool06Woo000KOol00`00Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Ioo`Tm
kmQoo`03001oogoo01Uoo`006Woo00<007ooOol01Woo23g_fGoo00<007ooOol06Goo000IOol00`00
Oomoo`06Ool8?NoKOol00`00Oomoo`0HOol001Uoo`03001oogoo00Ioo`Lmkmaoo`03001oogoo01Qo
o`0067oo00<007ooOol01Goo23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`05Ool7?NoOOol0
0`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol0
1Goo23g_h7oo00<007ooOol05Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Io
o`03001oogoo00Eoo`Pmkn9oo`03001oogoo01Eoo`005Woo00<007ooOol01Goo1Sg_i7oo00<007oo
Ool05Goo000EOol00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`Lm
knEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00
Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=o
o`0057oo00<007ooOol01Goo1cg_igoo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol0
0`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol0
1Woo1Sg_jGoo00<007ooOol04Woo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019o
o`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Cg_k7oo00<007oo
Ool04Goo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dm
kneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00
Oomoo`07Ool6?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00mo
o`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol0
2Goo1Sg_kWoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool8?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`Pm
kneoo`03001oogoo00eoo`003Woo00<007ooOol02Woo33g_jGoo00<007ooOol03Goo000>Ool00`00
Oomoo`0<Ool:?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo00eo
o`003Woo00<007ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol0
3Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eo
o`03001oogoo00eoo`dmknMoo`03001oogoo00aoo`003Goo00<007ooOol037oo23g_00=oocg_?Nl0
0cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0;Ool7?Nl3Ool5?NoWOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Uoo`dmkn]oo`03001oogoo00aoo`003Goo00<007ooOol027oo3cg_jWoo00<0
07ooOol037oo000=Ool00`00Oomoo`08Ool@?NoYOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
oa4mknQoo`03001oogoo00aoo`0037oo00<007ooOol027oo4cg_j7oo00<007ooOol02goo000<Ool0
0`00Oomoo`07Ool;?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00IooaLmknIoo`03
001oogoo00]oo`0037oo00<007ooOol01Goo63g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08
OolE?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03
001oogoo00]oo`0037oo00<007ooOol06Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0H
Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Tmkn9oo`03001oogoo00]oo`0037oo
00<007ooOol067oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomo
o`0;Ool000eoo`03001oogoo01Moo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol06goo1cg_
ggoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001o
ogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo
000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo
00<007ooOol07Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0NOol9?NoJOol00`00Oomo
o`0<Ool000ioo`03001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_
g7oo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol0
0`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0011oo`03001oogoo0?aoo`03001o
ogoo00ioo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000AOol00`00Oomoo`3jOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Uoo`03001oogoo011o
o`004Goo00<007ooOol0nGoo00<007ooOol047oo000BOol00`00Oomoo`3hOol00`00Oomoo`0@Ool0
019oo`03001oogoo0?Moo`03001oogoo015oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000C
Ool00`00Oomoo`3fOol00`00Oomoo`0AOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000DOol00`00Oomoo`3dOol00`00Oomoo`0BOol001Aoo`03
001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000EOol00`00
Oomoo`3bOol00`00Oomoo`0COol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Ioo`03001oogoo
0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000GOol00`00Oomoo`3]
Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`0067oo00<007ooOol0jgoo
00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Uoo`03001oogoo0>Yoo`03
001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo000JOol00`00Oomoo`3XOol00`00
Oomoo`0HOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`006goo00<007ooOol0iGoo00<007oo
Ool06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001aoo`03001oogoo0>=oo`03001oogoo
01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol00`00Oomoo`3QOol00`00Oomoo`0L
Ool001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo
000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001moo`03001oogoo0=eoo`03001oogoo01ioo`00
7goo00<007ooOol0gGoo00<007ooOol07Woo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0021o
o`03001oogoo0=]oo`03001oogoo01moo`008Goo00<007ooOol0fGoo00<007ooOol087oo000ROol0
0`00Oomoo`3GOol00`00Oomoo`0QOol002=oo`03001oogoo0=Eoo`03001oogoo029oo`0097oo00<0
07ooOol0dgoo00<007ooOol08goo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Eoo`03001o
ogoo0=5oo`03001oogoo02Aoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000VOol00`00Oomo
o`3?Ool00`00Oomoo`0UOol002Moo`03001oogoo0<eoo`03001oogoo02Ioo`00:7oo00<007ooOol0
bgoo00<007ooOol09goo000YOol00`00Oomoo`39Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Mo
o`03001oogoo02Uoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool0
0`00Oomoo`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;Goo00<007ooOol0`Goo00<0
07ooOol0;7oo000^Ool00`00Oomoo`2oOol00`00Oomoo`0]Ool002ioo`03001oogoo0;moo`03001o
ogoo02eoo`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomo
o`0_Ool0035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00
Oomoo`2cOol00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Goo00<007oo
Ool0/Goo00<007ooOol0=7oo000fOol00`00Oomoo`2_Ool00`00Oomoo`0eOol003Moo`03001oogoo
0:eoo`03001oogoo03Ioo`00>7oo00<007ooOol0Zgoo00<007ooOol0=goo000iOol2002YOol2000j
Ool003]oo`03001oogoo0:Eoo`03001oogoo03Yoo`00?7oo00<007ooOol0Xgoo00<007ooOol0>goo
000mOol00`00Oomoo`2QOol00`00Oomoo`0lOol003ioo`8009moo`8003moo`00@7oo00<007ooOol0
Vgoo00<007ooOol0?goo0011Ool2002IOol20012Ool004=oo`03001oogoo09Eoo`03001oogoo049o
o`00A7oo00<007ooOol0Tgoo00<007ooOol0@goo0015Ool00`00Oomoo`2AOol00`00Oomoo`14Ool0
04Ioo`8008moo`8004Moo`00B7oo0P00Rgoo0P00BGoo001:Ool20027Ool2001;Ool004aoo`8008=o
o`8004eoo`00CWoo00<007ooOol0Ogoo00<007ooOol0CGoo001?Ool00`00Oomoo`1mOol00`00Oomo
o`1>Ool0051oo`8007]oo`80055oo`00DWoo0P00Mgoo0P00Dgoo001DOol2001cOol2001EOol005Io
o`8006moo`8005Moo`00F7oo0`00JGoo0`00FGoo001KOol3001SOol3001LOol005ioo`8005ioo`<0
05moo`00H7oo0P00Fgoo00<007ooOol0H7oo001ROol3001EOol3001SOol006Eoo`<004moo`<006Io
o`00J7oo1000Agoo1000JGoo001/Ool4000oOol4001]Ool0071oo`<003Qoo`@0075oo`00Lgoo1@00
;goo1000MGoo001hOol7000QOol7001iOol007moo`h000Eoo`h0081oo`00SGoo1@00SWoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002<Ool30002Ool2002=Ool008eoo`04001oogoo
0002Ool00`00Oomoo`2:Ool008Yoo`D000Aoo`03001oogoo08Yoo`00RWoo00@007ooOol000=oo`80
08eoo`00Rgoo00<007oo00000goo00<007ooOol0S7oo002<Ool20003Ool3002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(46)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
1 .978 0 r
.008 w
.29343 .08516 Mdot
.016 w
.29343 .08516 m
.29334 .08517 L
s
1 .956 0 r
.008 w
.29334 .08517 Mdot
.016 w
.29334 .08517 m
.29311 .08522 L
s
1 .933 0 r
.008 w
.29311 .08522 Mdot
.016 w
.29311 .08522 m
.29269 .0853 L
s
1 .911 0 r
.008 w
.29269 .0853 Mdot
.016 w
.29269 .0853 m
.29208 .08545 L
s
1 .889 0 r
.008 w
.29208 .08545 Mdot
.016 w
.29208 .08545 m
.29122 .08572 L
s
1 .867 0 r
.008 w
.29122 .08572 Mdot
.016 w
.29122 .08572 m
.29008 .08615 L
s
1 .844 0 r
.008 w
.29008 .08615 Mdot
.016 w
.29008 .08615 m
.28879 .08672 L
s
1 .822 0 r
.008 w
.28879 .08672 Mdot
.016 w
.28879 .08672 m
.2872 .08753 L
s
1 .8 0 r
.008 w
.2872 .08753 Mdot
.016 w
.2872 .08753 m
.28527 .08854 L
s
1 .778 0 r
.008 w
.28527 .08854 Mdot
.016 w
.28527 .08854 m
.28312 .08975 L
s
1 .756 0 r
.008 w
.28312 .08975 Mdot
.016 w
.28312 .08975 m
.28111 .09101 L
s
1 .733 0 r
.008 w
.28111 .09101 Mdot
.016 w
.28111 .09101 m
.27888 .09235 L
s
1 .711 0 r
.008 w
.27888 .09235 Mdot
.016 w
.27888 .09235 m
.2764 .09374 L
s
1 .689 0 r
.008 w
.2764 .09374 Mdot
.016 w
.2764 .09374 m
.27416 .09507 L
s
1 .667 0 r
.008 w
.27416 .09507 Mdot
.016 w
.27416 .09507 m
.27183 .09635 L
s
1 .644 0 r
.008 w
.27183 .09635 Mdot
.016 w
.27183 .09635 m
.26986 .09748 L
s
1 .622 0 r
.008 w
.26986 .09748 Mdot
.016 w
.26986 .09748 m
.26809 .09852 L
s
1 .6 0 r
.008 w
.26809 .09852 Mdot
.016 w
.26809 .09852 m
.26662 .09946 L
s
1 .578 0 r
.008 w
.26662 .09946 Mdot
.016 w
.26662 .09946 m
.26542 .1003 L
s
1 .556 0 r
.008 w
.26542 .1003 Mdot
.016 w
.26542 .1003 m
.26435 .101 L
s
1 .533 0 r
.008 w
.26435 .101 Mdot
.016 w
.26435 .101 m
.26347 .1016 L
s
1 .511 0 r
.008 w
.26347 .1016 Mdot
.016 w
.26347 .1016 m
.26274 .10209 L
s
1 .489 0 r
.008 w
.26274 .10209 Mdot
.016 w
.26274 .10209 m
.26213 .10248 L
s
1 .467 0 r
.008 w
.26213 .10248 Mdot
.016 w
.26213 .10248 m
.26156 .10281 L
s
1 .444 0 r
.008 w
.26156 .10281 Mdot
.016 w
.26156 .10281 m
.26098 .1031 L
s
1 .422 0 r
.008 w
.26098 .1031 Mdot
.016 w
.26098 .1031 m
.26036 .10339 L
s
1 .4 0 r
.008 w
.26036 .10339 Mdot
.016 w
.26036 .10339 m
.25962 .10373 L
s
1 .378 0 r
.008 w
.25962 .10373 Mdot
.016 w
.25962 .10373 m
.2587 .10417 L
s
1 .356 0 r
.008 w
.2587 .10417 Mdot
.016 w
.2587 .10417 m
.25764 .10472 L
s
1 .333 0 r
.008 w
.25764 .10472 Mdot
.016 w
.25764 .10472 m
.25642 .10541 L
s
1 .311 0 r
.008 w
.25642 .10541 Mdot
.016 w
.25642 .10541 m
.25496 .10625 L
s
1 .289 0 r
.008 w
.25496 .10625 Mdot
.016 w
.25496 .10625 m
.25321 .10727 L
s
1 .267 0 r
.008 w
.25321 .10727 Mdot
.016 w
.25321 .10727 m
.25137 .1084 L
s
1 .244 0 r
.008 w
.25137 .1084 Mdot
.016 w
.25137 .1084 m
.24944 .10966 L
s
1 .222 0 r
.008 w
.24944 .10966 Mdot
.016 w
.24944 .10966 m
.24746 .11098 L
s
1 .2 0 r
.008 w
.24746 .11098 Mdot
.016 w
.24746 .11098 m
.24571 .11227 L
s
1 .178 0 r
.008 w
.24571 .11227 Mdot
.016 w
.24571 .11227 m
.24401 .1135 L
s
1 .156 0 r
.008 w
.24401 .1135 Mdot
.016 w
.24401 .1135 m
.2426 .11465 L
s
1 .133 0 r
.008 w
.2426 .11465 Mdot
.016 w
.2426 .11465 m
.24124 .11569 L
s
1 .111 0 r
.008 w
.24124 .11569 Mdot
.016 w
.24124 .11569 m
.24013 .11656 L
s
1 .089 0 r
.008 w
.24013 .11656 Mdot
.016 w
.24013 .11656 m
.23919 .11729 L
s
1 .067 0 r
.008 w
.23919 .11729 Mdot
.016 w
.23919 .11729 m
.23846 .11786 L
s
1 .044 0 r
.008 w
.23846 .11786 Mdot
.016 w
.23846 .11786 m
.23797 .11827 L
s
1 .022 0 r
.008 w
.23797 .11827 Mdot
.016 w
.23797 .11827 m
.23768 .11853 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`04001oogkPO^03Od000gmP?Nlmk`05?Nm_Ool00`00
Oomoo`1?Ool004moo`04001oogk0O/02O^0017l0Ob1oH7oP1Sg_L7oo00<007ooOol0CWoo001=Ool2
0002OV03O/02O^000glPOf1oh005?NmbOol2001>Ool004]oo`800003OomnH7iP009nH006OZ1n`7k0
O`1o87mP0cg_Mgoo0P00C7oo0019Ool200000gooOP1n0002OP0017hPOV1nH7k00Wl000Ao83g_?Nlm
kgYoo`8004Yoo`00B7oo00@007ooO>1lh09m8005OF1m`7hPOV1nX007?NmlOol00`00Oomoo`17Ool0
04Ioo`800003Oomlh7cP009lh004OB1mH7g0OR02OZ07?NmmOol20017Ool004Eoo`03001oogbP00=l
X006O<1lh7cPOF1m`7hP23g_P7oo00<007ooOol0A7oo0014Ool00`00OomlH003O6001Wb0O<1lh7dP
OF1m`0HmkhAoo`03001oogoo04=oo`00@goo00D007ooO41l@7`P009l@004O81l`7dPOB07?Nn6Ool0
0`00Oomoo`12Ool0045oo`800005Oolmkga0O01l8002O4000gb0O<0mk`06?Nn9Ool20012Ool0041o
o`03001oogoo008mk`03O41l07a0009l@003O80mkcg_00Hmkh]oo`03001oogoo03moo`00?goo00<0
07ooOol00cg_1Ga00Sg_Tgoo0P00?goo000nOol00`00Oomoo`0:?NnFOol00`00Oomoo`0lOol003ao
o`80009oo`XmkiQoo`03001oogoo03]oo`00>goo00<007oo?Nl02cg_VWoo00<007ooOol0>Woo000j
Ool00`00Oolmk`0;?NnLOol2000jOol003Uoo`03001oocg_00Xmkj1oo`03001oogoo03Moo`00=goo
0P0000=oocg_?Nl02Sg_XGoo00<007ooOol0=Woo000fOol00`00Oomoo`09?NnVOol00`00Oomoo`0e
Ool003Eoo`03001oogoo00XmkjMoo`03001oogoo03Aoo`00=7oo00@007ooOomoo`TmkjUoo`03001o
ogoo03=oo`00<Woo0P000goo2Sg_ZWoo00<007ooOol0<Woo000aOol00`00Oomoo`02Ool;?Nn[Ool0
0`00Oomoo`0aOol0031oo`03001oogoo009oo``mkjaoo`03001oogoo031oo`00<7oo00<007ooOol0
0Woo2cg_[Woo00<007ooOol0;goo000_Ool00`00Oomoo`02Ool:?NnaOol00`00Oomoo`0^Ool002io
o`03001oogoo00=oo`Xmkk9oo`03001oogoo02eoo`00;Goo00<007ooOol017oo2Sg_/goo00<007oo
Ool0;7oo000/Ool00`00Oomoo`04Ool:?NneOol00`00Oomoo`0[Ool002aoo`03001oogoo00=oo`Xm
kkIoo`03001oogoo02]oo`00:goo00<007ooOol017oo2Sg_]goo00<007ooOol0:Woo000ZOol00`00
Oomoo`04Ool5?NnnOol00`00Oomoo`0YOol002Uoo`03001oogoo00Eoo`Dmkkmoo`03001oogoo02Qo
o`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool5?No1Ool0
0`00Oomoo`0WOol002Moo`03001oogoo00Ioo`Dmkl9oo`03001oogoo02Ioo`009Woo00<007ooOol0
1Woo1cg_`Woo00<007ooOol09Goo000UOol00`00Oomoo`06Ool8?No3Ool00`00Oomoo`0TOol002Ao
o`03001oogoo00Ioo`PmklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<007oo
Ool08goo000SOol00`00Oomoo`06Ool7?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Ioo`Pm
klUoo`03001oogoo025oo`008Woo00<007ooOol01Goo2Cg_bGoo00<007ooOol08Goo000QOol00`00
Oomoo`06Ool8?No;Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`Pmkleoo`03001oogoo01mo
o`0087oo00<007ooOol01Goo1cg_cgoo00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoAOol0
0`00Oomoo`0NOol001moo`03001oogoo00Ioo`Hmkm9oo`03001oogoo01eoo`007Woo00<007ooOol0
1Woo1cg_dWoo00<007ooOol07Goo000MOol00`00Oomoo`07Ool7?NoCOol00`00Oomoo`0LOol001eo
o`03001oogoo00Ioo`Pmkm=oo`03001oogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<007oo
Ool06goo000LOol00`00Oomoo`05Ool9?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Ioo`Tm
kmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol00`00
Oomoo`06Ool9?NoHOol00`00Oomoo`0IOol001Yoo`03001oogoo00Ioo`PmkmUoo`03001oogoo01Uo
o`006Goo00<007ooOol01Woo23g_fgoo00<007ooOol067oo000IOol00`00Oomoo`06Ool7?NoLOol0
0`00Oomoo`0HOol001Qoo`03001oogoo00Eoo`Pmkmioo`03001oogoo01Moo`0067oo00<007ooOol0
1Goo1cg_ggoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol001Mo
o`03001oogoo00Eoo`Pmkn1oo`03001oogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<007oo
Ool05Woo000FOol00`00Oomoo`05Ool8?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eoo`Hm
knAoo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol00`00
Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Ao
o`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoWOol0
0`00Oomoo`0COol001Aoo`03001oogoo00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007ooOol0
1Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=o
o`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<007oo
Ool04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Ioo`Dm
knaoo`03001oogoo015oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo011o
o`004Goo00<007ooOol01goo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol0
27oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool000mo
o`03001oogoo00Uoo`Hmknioo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lm
kneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool00`00
Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo00eo
o`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol0
3Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eo
o`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pm
k`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
o`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<007ooOol037oo000=Ool0
0`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<mknQoo`03001oogoo
00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`06
OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03001oogoo00]oo`0037oo
00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl00goo?Nlmk`0<
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;
Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001oogoo00]oo`0037oo
00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9?NoROol00`00Oomo
o`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_
hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;Ool000eoo`03001o
ogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo
000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo
00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJOol00`00Oomo
o`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Woo2Cg_
fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=Ool000ioo`03001o
ogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool0
0`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomo
o`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]o
o`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<0
07ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001o
ogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol0
4Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=o
o`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00
Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007oo
Ool0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo
021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0R
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qo
o`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<0
07ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001o
ogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomo
o`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0
^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=o
o`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000g
Ool00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo
0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03
001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041o
o`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol0
0`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<0
07ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo
001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0
OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo
0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001N
Ool2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3
001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001a
Ool007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D0
08ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`0000Aoo`00000008eo
o`00SGoo00@007ooOol0009oo`03001oogoo08Yoo`00RWoo1@0000Eoo`00Oomoo`0008aoo`00RWoo
00@007ooOol0009oo`<008eoo`00Rgoo00<007oo00000goo00<007ooOol0S7oo002<Ool20003Ool3
002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(47)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
1 .944 0 r
.008 w
.23839 .11792 Mdot
.016 w
.23839 .11792 m
.23815 .11804 L
s
1 .889 0 r
.008 w
.23815 .11804 Mdot
.016 w
.23815 .11804 m
.23776 .11828 L
s
1 .833 0 r
.008 w
.23776 .11828 Mdot
.016 w
.23776 .11828 m
.23722 .11868 L
s
1 .778 0 r
.008 w
.23722 .11868 Mdot
.016 w
.23722 .11868 m
.23655 .11924 L
s
1 .722 0 r
.008 w
.23655 .11924 Mdot
.016 w
.23655 .11924 m
.23577 .11995 L
s
1 .667 0 r
.008 w
.23577 .11995 Mdot
.016 w
.23577 .11995 m
.23492 .1208 L
s
1 .611 0 r
.008 w
.23492 .1208 Mdot
.016 w
.23492 .1208 m
.23406 .12172 L
s
1 .556 0 r
.008 w
.23406 .12172 Mdot
.016 w
.23406 .12172 m
.23319 .12275 L
s
1 .5 0 r
.008 w
.23319 .12275 Mdot
.016 w
.23319 .12275 m
.23229 .12379 L
s
1 .444 0 r
.008 w
.23229 .12379 Mdot
.016 w
.23229 .12379 m
.2314 .12486 L
s
1 .389 0 r
.008 w
.2314 .12486 Mdot
.016 w
.2314 .12486 m
.23056 .1259 L
s
1 .333 0 r
.008 w
.23056 .1259 Mdot
.016 w
.23056 .1259 m
.22984 .12688 L
s
1 .278 0 r
.008 w
.22984 .12688 Mdot
.016 w
.22984 .12688 m
.22927 .12772 L
s
1 .222 0 r
.008 w
.22927 .12772 Mdot
.016 w
.22927 .12772 m
.22885 .12843 L
s
1 .167 0 r
.008 w
.22885 .12843 Mdot
.016 w
.22885 .12843 m
.22858 .12899 L
s
1 .111 0 r
.008 w
.22858 .12899 Mdot
.016 w
.22858 .12899 m
.22842 .12939 L
s
1 .056 0 r
.008 w
.22842 .12939 Mdot
.016 w
.22842 .12939 m
.22837 .12963 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03001nX7jP009nX003O^0mkcg_00XmkhIoo`03001oogoo049oo`00@Goo0P0017g000=mh7kP
?Nl02Cg_RGoo0P00@Woo0010Ool00`00Oomoo`04O@000ggPO^0mk`09?Nn;Ool00`00Oomoo`0oOol0
03moo`03001oogoo009lX005O61lX7bPON1nh003?NnCOol2000oOol003ioo`04001oogoo?Nl2O:00
17`PO:1lX7gP0cg_UWoo00<007ooOol0?7oo000lOol20002Ool2?Nl2O:000g`PO:1lX003?NnHOol0
0`00Oomoo`0kOol003]oo`03001oocg_00@mk`ElX08mkiYoo`03001oogoo03Yoo`00>Woo00<007oo
?Nl02cg_W7oo0P00>Woo000iOol00`00Oolmk`0:?NnPOol00`00Oomoo`0gOol003Moo`800003Oolm
kcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<007ooOol02Cg_YWoo00<007ooOol0=Goo000eOol0
0`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Aoo`04001oogooOol9?NnYOol00`00Oomoo`0cOol0
039oo`8000=oo`XmkjYoo`03001oogoo039oo`00<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0
<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjio
o`03001oogoo02moo`00;goo00<007ooOol00Woo2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomo
o`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00
;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00
Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMoo`03001oogoo02Yoo`00:Woo00<007ooOol017oo
1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomoo`05Ool5?NnoOol00`00Oomoo`0XOol002Qoo`03
001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`00:7oo00<007ooOol01Goo1Cg_`Goo00<007ooOol0
9goo000WOol00`00Oomoo`06Ool5?No2Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Ioo`Lmkl9o
o`03001oogoo02Eoo`009Goo00<007ooOol01Woo23g_`goo00<007ooOol097oo000TOol00`00Oomo
o`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`PmklIoo`03001oogoo02=oo`00
8goo00<007ooOol01Woo1cg_b7oo00<007ooOol08Woo000ROol00`00Oomoo`06Ool8?No9Ool00`00
Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Goo00<007ooOol01Woo
23g_bgoo00<007ooOol087oo000POol00`00Oomoo`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03
001oogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo00<007ooOol01Woo1Sg_dGoo00<007ooOol0
7Woo000OOol00`00Oomoo`06Ool6?NoBOol00`00Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9o
o`03001oogoo01eoo`007Goo00<007ooOol01goo1cg_dgoo00<007ooOol077oo000MOol00`00Oomo
o`06Ool8?NoCOol00`00Oomoo`0LOol001aoo`03001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`00
77oo00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo000KOol00`00Oomoo`06Ool9?NoFOol00`00
Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03001oogoo01Yoo`006Woo00<007ooOol01Woo
2Cg_f7oo00<007ooOol06Goo000JOol00`00Oomoo`06Ool8?NoIOol00`00Oomoo`0IOol001Uoo`03
001oogoo00Ioo`Pmkm]oo`03001oogoo01Qoo`006Goo00<007ooOol01Woo1cg_g7oo00<007ooOol0
67oo000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomoo`0GOol001Qoo`03001oogoo00Eoo`Lmkmmo
o`03001oogoo01Moo`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo000GOol00`00Oomo
o`05Ool8?NoPOol00`00Oomoo`0FOol001Moo`03001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`00
5Woo00<007ooOol01Goo23g_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00
Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo
1cg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03
001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol0
4goo000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUo
o`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomo
o`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`00
4Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00
Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo
1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03
001oogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol0
3goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknio
o`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomo
o`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`00
3goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003Woo00<007ooOol02Woo
23g_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03
001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2cg_igoo00<007ooOol0
3Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIo
o`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomo
o`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`00
3Goo00<007ooOol03Goo3Cg_igoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlm
k`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00ao
o`003Goo00<007ooOol02Goo3Cg_jgoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool??NoZOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0mknUoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo4Cg_j7oo00<007ooOol037oo000<Ool00`00Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000ao
o`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001oogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo
00<007ooOol02goo000<Ool00`00Oomoo`05OolH?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo
00QooaDmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo
00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo
01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol067oo2Cg_hWoo00<007ooOol02goo000<
Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`0KOol7
?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03001oogoo00aoo`003Goo00<0
07ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<
Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo
00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo
01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<007ooOol077oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`TmkmYoo`03001o
ogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomoo`0NOol5
?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0
ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?eo
o`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol0
0`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`0047oo00<007ooOol0o7oo00<0
07ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001o
ogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00moo`004Goo00<007ooOol0nGoo00<007ooOol0
47oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0019oo`03001oogoo0?Qoo`03001oogoo011o
o`004Woo00<007ooOol0mgoo00<007ooOol04Goo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0
01=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo00<007ooOol0mGoo00<007ooOol04Woo000C
Ool00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03001oogoo0?Aoo`03001oogoo019oo`0057oo
00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Eoo`03
001oogoo0?9oo`03001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00
Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Woo00<007oo
Ool0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Moo`03001oogoo
0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo00<007ooOol05Woo000HOol00`00Oomoo`3[
Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03001oogoo01Moo`006Goo00<007ooOol0jWoo
00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03
001oogoo01Qoo`006Woo00<007ooOol0igoo00<007ooOol06Goo000KOol00`00Oomoo`3UOol00`00
Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo01Yoo`0077oo00<007ooOol0hgoo00<007oo
Ool06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0KOol001eoo`03001oogoo0>5oo`03001oogoo
01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo000NOol00`00Oomoo`3OOol00`00Oomoo`0M
Ool001ioo`03001oogoo0=moo`03001oogoo01eoo`007goo00<007ooOol0gGoo00<007ooOol07Woo
000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03001oogoo01moo`00
87oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00Oomoo`0POol0029o
o`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007ooOol08Woo000TOol0
0`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo02=oo`009Goo00<0
07ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0UOol002Ioo`03001o
ogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo000XOol00`00Oomo
o`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00:Woo00<007ooOol0
agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]oo`03001oogoo0<Eo
o`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool00`00Oomoo`31Ool0
0`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<007ooOol0_goo00<0
07ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001oogoo0;]oo`03001o
ogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2000cOol003Aoo`03
001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0=7oo000eOol00`00
Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eoo`00=goo00<007oo
Ool0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol003Uoo`800:Uoo`80
03Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2SOol00`00Oomoo`0k
Ool003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo0010Ool00`00Oomo
o`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0UGoo00<007ooOol0
@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095oo`03001oogoo04Ao
o`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`8004]oo`00C7oo0P00
Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001oogoo07eoo`03001o
ogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00
EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0P00GWoo
0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00
IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo1000LGoo001cOol5
000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=Ool5002>Ool00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008aoo`<000=oo`03001oogoo08]oo`00SGoo
00<007ooOol00Woo00<007ooOol0Rgoo002:Ool50003Ool00`00Oomoo`2;Ool008Yoo`04001oogoo
0005Ool00`00Oomoo`2:Ool008]oo`03001oo`00009oo`04001oogoo002<Ool008aoo`80009oo`@0
08aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(48)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
1 .992 0 r
.008 w
.22906 .12906 Mdot
.016 w
.22906 .12906 m
.22885 .12915 L
s
1 .984 0 r
.008 w
.22885 .12915 Mdot
.016 w
.22885 .12915 m
.22844 .12937 L
s
1 .976 0 r
.008 w
.22844 .12937 Mdot
.016 w
.22844 .12937 m
.22779 .12972 L
s
1 .968 0 r
.008 w
.22779 .12972 Mdot
.016 w
.22779 .12972 m
.22688 .13023 L
s
1 .96 0 r
.008 w
.22688 .13023 Mdot
.016 w
.22688 .13023 m
.22569 .13088 L
s
1 .952 0 r
.008 w
.22569 .13088 Mdot
.016 w
.22569 .13088 m
.22436 .13162 L
s
1 .944 0 r
.008 w
.22436 .13162 Mdot
.016 w
.22436 .13162 m
.22275 .13246 L
s
1 .937 0 r
.008 w
.22275 .13246 Mdot
.016 w
.22275 .13246 m
.22086 .13338 L
s
1 .929 0 r
.008 w
.22086 .13338 Mdot
.016 w
.22086 .13338 m
.21891 .13435 L
s
1 .921 0 r
.008 w
.21891 .13435 Mdot
.016 w
.21891 .13435 m
.21686 .13543 L
s
1 .913 0 r
.008 w
.21686 .13543 Mdot
.016 w
.21686 .13543 m
.21452 .13671 L
s
1 .905 0 r
.008 w
.21452 .13671 Mdot
.016 w
.21452 .13671 m
.21235 .13796 L
s
1 .897 0 r
.008 w
.21235 .13796 Mdot
.016 w
.21235 .13796 m
.21003 .13931 L
s
1 .889 0 r
.008 w
.21003 .13931 Mdot
.016 w
.21003 .13931 m
.20779 .14071 L
s
1 .881 0 r
.008 w
.20779 .14071 Mdot
.016 w
.20779 .14071 m
.20588 .14215 L
s
1 .873 0 r
.008 w
.20588 .14215 Mdot
.016 w
.20588 .14215 m
.20405 .14356 L
s
1 .865 0 r
.008 w
.20405 .14356 Mdot
.016 w
.20405 .14356 m
.2024 .14489 L
s
1 .857 0 r
.008 w
.2024 .14489 Mdot
.016 w
.2024 .14489 m
.20106 .14598 L
s
1 .849 0 r
.008 w
.20106 .14598 Mdot
.016 w
.20106 .14598 m
.19991 .14708 L
s
1 .841 0 r
.008 w
.19991 .14708 Mdot
.016 w
.19991 .14708 m
.19898 .1481 L
s
1 .833 0 r
.008 w
.19898 .1481 Mdot
.016 w
.19898 .1481 m
.1983 .14889 L
s
1 .825 0 r
.008 w
.1983 .14889 Mdot
.016 w
.1983 .14889 m
.19782 .1496 L
s
1 .817 0 r
.008 w
.19782 .1496 Mdot
.016 w
.19782 .1496 m
.1975 .15022 L
s
1 .81 0 r
.008 w
.1975 .15022 Mdot
.016 w
.1975 .15022 m
.1973 .1507 L
s
1 .802 0 r
.008 w
.1973 .1507 Mdot
.016 w
.1973 .1507 m
.19716 .15105 L
s
1 .794 0 r
.008 w
.19716 .15105 Mdot
.016 w
.19716 .15105 m
.19703 .15137 L
s
1 .786 0 r
.008 w
.19703 .15137 Mdot
.016 w
.19703 .15137 m
.19684 .15174 L
s
1 .778 0 r
.008 w
.19684 .15174 Mdot
.016 w
.19684 .15174 m
.19655 .15222 L
s
1 .77 0 r
.008 w
.19655 .15222 Mdot
.016 w
.19655 .15222 m
.19617 .15286 L
s
1 .762 0 r
.008 w
.19617 .15286 Mdot
.016 w
.19617 .15286 m
.19568 .1537 L
s
1 .754 0 r
.008 w
.19568 .1537 Mdot
.016 w
.19568 .1537 m
.19508 .15473 L
s
1 .746 0 r
.008 w
.19508 .15473 Mdot
.016 w
.19508 .15473 m
.1944 .15592 L
s
1 .738 0 r
.008 w
.1944 .15592 Mdot
.016 w
.1944 .15592 m
.19372 .15704 L
s
1 .73 0 r
.008 w
.19372 .15704 Mdot
.016 w
.19372 .15704 m
.19302 .15831 L
s
1 .722 0 r
.008 w
.19302 .15831 Mdot
.016 w
.19302 .15831 m
.19234 .1596 L
s
1 .714 0 r
.008 w
.19234 .1596 Mdot
.016 w
.19234 .1596 m
.19175 .1607 L
s
1 .706 0 r
.008 w
.19175 .1607 Mdot
.016 w
.19175 .1607 m
.19119 .16178 L
s
1 .698 0 r
.008 w
.19119 .16178 Mdot
.016 w
.19119 .16178 m
.19073 .16269 L
s
1 .69 0 r
.008 w
.19073 .16269 Mdot
.016 w
.19073 .16269 m
.19039 .16347 L
s
1 .683 0 r
.008 w
.19039 .16347 Mdot
.016 w
.19039 .16347 m
.19016 .16411 L
s
1 .675 0 r
.008 w
.19016 .16411 Mdot
.016 w
.19016 .16411 m
.18996 .16466 L
s
1 .667 0 r
.008 w
.18996 .16466 Mdot
.016 w
.18996 .16466 m
.18976 .1652 L
s
1 .659 0 r
.008 w
.18976 .1652 Mdot
.016 w
.18976 .1652 m
.18949 .16578 L
s
1 .651 0 r
.008 w
.18949 .16578 Mdot
.016 w
.18949 .16578 m
.18909 .16649 L
s
1 .643 0 r
.008 w
.18909 .16649 Mdot
.016 w
.18909 .16649 m
.18847 .16746 L
s
1 .635 0 r
.008 w
.18847 .16746 Mdot
.016 w
.18847 .16746 m
.18759 .1687 L
s
1 .627 0 r
.008 w
.18759 .1687 Mdot
.016 w
.18759 .1687 m
.18653 .17005 L
s
1 .619 0 r
.008 w
.18653 .17005 Mdot
.016 w
.18653 .17005 m
.18524 .17179 L
s
1 .611 0 r
.008 w
.18524 .17179 Mdot
.016 w
.18524 .17179 m
.18368 .17374 L
s
1 .603 0 r
.008 w
.18368 .17374 Mdot
.016 w
.18368 .17374 m
.18189 .17608 L
s
1 .595 0 r
.008 w
.18189 .17608 Mdot
.016 w
.18189 .17608 m
.17999 .17855 L
s
1 .587 0 r
.008 w
.17999 .17855 Mdot
.016 w
.17999 .17855 m
.17822 .18135 L
s
1 .579 0 r
.008 w
.17822 .18135 Mdot
.016 w
.17822 .18135 m
.17634 .18394 L
s
1 .571 0 r
.008 w
.17634 .18394 Mdot
.016 w
.17634 .18394 m
.17433 .18684 L
s
1 .563 0 r
.008 w
.17433 .18684 Mdot
.016 w
.17433 .18684 m
.17238 .18976 L
s
1 .556 0 r
.008 w
.17238 .18976 Mdot
.016 w
.17238 .18976 m
.17052 .19262 L
s
1 .548 0 r
.008 w
.17052 .19262 Mdot
.016 w
.17052 .19262 m
.16866 .19565 L
s
1 .54 0 r
.008 w
.16866 .19565 Mdot
.016 w
.16866 .19565 m
.16697 .19826 L
s
1 .532 0 r
.008 w
.16697 .19826 Mdot
.016 w
.16697 .19826 m
.16528 .20104 L
s
1 .524 0 r
.008 w
.16528 .20104 Mdot
.016 w
.16528 .20104 m
.16374 .20363 L
s
1 .516 0 r
.008 w
.16374 .20363 Mdot
.016 w
.16374 .20363 m
.16221 .2062 L
s
1 .508 0 r
.008 w
.16221 .2062 Mdot
.016 w
.16221 .2062 m
.16073 .20863 L
s
1 .5 0 r
.008 w
.16073 .20863 Mdot
.016 w
.16073 .20863 m
.15939 .2111 L
s
1 .492 0 r
.008 w
.15939 .2111 Mdot
.016 w
.15939 .2111 m
.15805 .21325 L
s
1 .484 0 r
.008 w
.15805 .21325 Mdot
.016 w
.15805 .21325 m
.15673 .21542 L
s
1 .476 0 r
.008 w
.15673 .21542 Mdot
.016 w
.15673 .21542 m
.1555 .21748 L
s
1 .468 0 r
.008 w
.1555 .21748 Mdot
.016 w
.1555 .21748 m
.15438 .21939 L
s
1 .46 0 r
.008 w
.15438 .21939 Mdot
.016 w
.15438 .21939 m
.15332 .22121 L
s
1 .452 0 r
.008 w
.15332 .22121 Mdot
.016 w
.15332 .22121 m
.15232 .22291 L
s
1 .444 0 r
.008 w
.15232 .22291 Mdot
.016 w
.15232 .22291 m
.15144 .22432 L
s
1 .437 0 r
.008 w
.15144 .22432 Mdot
.016 w
.15144 .22432 m
.15065 .22565 L
s
1 .429 0 r
.008 w
.15065 .22565 Mdot
.016 w
.15065 .22565 m
.14997 .22686 L
s
1 .421 0 r
.008 w
.14997 .22686 Mdot
.016 w
.14997 .22686 m
.14944 .22793 L
s
1 .413 0 r
.008 w
.14944 .22793 Mdot
.016 w
.14944 .22793 m
.14902 .2288 L
s
1 .405 0 r
.008 w
.14902 .2288 Mdot
.016 w
.14902 .2288 m
.14873 .22951 L
s
1 .397 0 r
.008 w
.14873 .22951 Mdot
.016 w
.14873 .22951 m
.14854 .23005 L
s
1 .389 0 r
.008 w
.14854 .23005 Mdot
.016 w
.14854 .23005 m
.14845 .23039 L
s
1 .381 0 r
.008 w
.14845 .23039 Mdot
.016 w
.14845 .23039 m
.14841 .23058 L
s
1 .373 0 r
.008 w
.14841 .23058 Mdot
.016 w
.14841 .23058 m
.1484 .23066 L
s
1 .365 0 r
.008 w
.1484 .23066 Mdot
.016 w
.1484 .23066 m
.14838 .23065 L
s
1 .357 0 r
.008 w
.14838 .23065 Mdot
.016 w
.14838 .23065 m
.14835 .23061 L
s
1 .349 0 r
.008 w
.14835 .23061 Mdot
.016 w
.14835 .23061 m
.14828 .23058 L
s
1 .341 0 r
.008 w
.14828 .23058 Mdot
.016 w
.14828 .23058 m
.14815 .23059 L
s
1 .333 0 r
.008 w
.14815 .23059 Mdot
.016 w
.14815 .23059 m
.14793 .23066 L
s
1 .325 0 r
.008 w
.14793 .23066 Mdot
.016 w
.14793 .23066 m
.14762 .23082 L
s
1 .317 0 r
.008 w
.14762 .23082 Mdot
.016 w
.14762 .23082 m
.1472 .23112 L
s
1 .31 0 r
.008 w
.1472 .23112 Mdot
.016 w
.1472 .23112 m
.14666 .23158 L
s
1 .302 0 r
.008 w
.14666 .23158 Mdot
.016 w
.14666 .23158 m
.14598 .23229 L
s
1 .294 0 r
.008 w
.14598 .23229 Mdot
.016 w
.14598 .23229 m
.1452 .23318 L
s
1 .286 0 r
.008 w
.1452 .23318 Mdot
.016 w
.1452 .23318 m
.1443 .2343 L
s
1 .278 0 r
.008 w
.1443 .2343 Mdot
.016 w
.1443 .2343 m
.14327 .23568 L
s
1 .27 0 r
.008 w
.14327 .23568 Mdot
.016 w
.14327 .23568 m
.1421 .23736 L
s
1 .262 0 r
.008 w
.1421 .23736 Mdot
.016 w
.1421 .23736 m
.14084 .23934 L
s
1 .254 0 r
.008 w
.14084 .23934 Mdot
.016 w
.14084 .23934 m
.1396 .24124 L
s
1 .246 0 r
.008 w
.1396 .24124 Mdot
.016 w
.1396 .24124 m
.1383 .24355 L
s
1 .238 0 r
.008 w
.1383 .24355 Mdot
.016 w
.1383 .24355 m
.13697 .24604 L
s
1 .23 0 r
.008 w
.13697 .24604 Mdot
.016 w
.13697 .24604 m
.13562 .24853 L
s
1 .222 0 r
.008 w
.13562 .24853 Mdot
.016 w
.13562 .24853 m
.13419 .25132 L
s
1 .214 0 r
.008 w
.13419 .25132 Mdot
.016 w
.13419 .25132 m
.13266 .25432 L
s
1 .206 0 r
.008 w
.13266 .25432 Mdot
.016 w
.13266 .25432 m
.13111 .25715 L
s
1 .198 0 r
.008 w
.13111 .25715 Mdot
.016 w
.13111 .25715 m
.12943 .26037 L
s
1 .19 0 r
.008 w
.12943 .26037 Mdot
.016 w
.12943 .26037 m
.12775 .26341 L
s
1 .183 0 r
.008 w
.12775 .26341 Mdot
.016 w
.12775 .26341 m
.12611 .26661 L
s
1 .175 0 r
.008 w
.12611 .26661 Mdot
.016 w
.12611 .26661 m
.12443 .26959 L
s
1 .167 0 r
.008 w
.12443 .26959 Mdot
.016 w
.12443 .26959 m
.1227 .27278 L
s
1 .159 0 r
.008 w
.1227 .27278 Mdot
.016 w
.1227 .27278 m
.12116 .27551 L
s
1 .151 0 r
.008 w
.12116 .27551 Mdot
.016 w
.12116 .27551 m
.11929 .27848 L
s
1 .143 0 r
.008 w
.11929 .27848 Mdot
.016 w
.11929 .27848 m
.1176 .28136 L
s
1 .135 0 r
.008 w
.1176 .28136 Mdot
.016 w
.1176 .28136 m
.1157 .2844 L
s
1 .127 0 r
.008 w
.1157 .2844 Mdot
.016 w
.1157 .2844 m
.11388 .2875 L
s
1 .119 0 r
.008 w
.11388 .2875 Mdot
.016 w
.11388 .2875 m
.11193 .29021 L
s
1 .111 0 r
.008 w
.11193 .29021 Mdot
.016 w
.11193 .29021 m
.10991 .29314 L
s
1 .103 0 r
.008 w
.10991 .29314 Mdot
.016 w
.10991 .29314 m
.10795 .29621 L
s
1 .095 0 r
.008 w
.10795 .29621 Mdot
.016 w
.10795 .29621 m
.10646 .29873 L
s
1 .087 0 r
.008 w
.10646 .29873 Mdot
.016 w
.10646 .29873 m
.10485 .30145 L
s
1 .079 0 r
.008 w
.10485 .30145 Mdot
.016 w
.10485 .30145 m
.10339 .30379 L
s
1 .071 0 r
.008 w
.10339 .30379 Mdot
.016 w
.10339 .30379 m
.10193 .30613 L
s
1 .063 0 r
.008 w
.10193 .30613 Mdot
.016 w
.10193 .30613 m
.10084 .30803 L
s
1 .056 0 r
.008 w
.10084 .30803 Mdot
.016 w
.10084 .30803 m
.09987 .30979 L
s
1 .048 0 r
.008 w
.09987 .30979 Mdot
.016 w
.09987 .30979 m
.09902 .31139 L
s
1 .04 0 r
.008 w
.09902 .31139 Mdot
.016 w
.09902 .31139 m
.09837 .31268 L
s
1 .032 0 r
.008 w
.09837 .31268 Mdot
.016 w
.09837 .31268 m
.09791 .31372 L
s
1 .024 0 r
.008 w
.09791 .31372 Mdot
.016 w
.09791 .31372 m
.09764 .31448 L
s
1 .016 0 r
.008 w
.09764 .31448 Mdot
.016 w
.09764 .31448 m
.09754 .31494 L
s
1 .008 0 r
.008 w
.09754 .31494 Mdot
.016 w
.09754 .31494 m
.09756 .31517 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`02Ol0>?Nn;Ool00`00Oomoo`0oOol003moo`04001oognPOj03Ol000goP?Nlmk`03?NnCOol2
000oOol003ioo`03001oP7n000AoX09o`0@mkiIoo`03001oogoo03aoo`00?7oo0P001Gn00WnP00=o
`7oP?Nl00Sg_V7oo00<007ooOol0>goo000kOol00`00OomoP005Oh02Oj02On02?NnJOol00`00Oomo
o`0jOol003Yoo`03001oH7mP00=oH0=oP09oX0<mkiaoo`8003Yoo`00>Goo00@007m0O`1o009o@004
Of1oP7n0Oh03?NnPOol00`00Oomoo`0gOol003Moo`800003Oomo07l0009o0003Od1oH3g_00Dmkj5o
o`03001oogoo03Ioo`00=Woo00@007ooOomnh09n`004O^1o07l0Of02?NnVOol00`00Oomoo`0eOol0
03Eoo`04001oogoo?Nl4O/000gl0Od0mk`02?NnWOol00`00Oomoo`0dOol003Aoo`04001oogooOol4
OZ02O/03?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`EnP003O/0mkcg_008mkjYoo`03001oogoo
039oo`00<Goo00<007ooOol00Woo00<mkgiPOV000WiP00=nP7kP?Nl00cg_Zgoo00<007ooOol0<Goo
000`Ool00`00Oomoo`02Ool00cg_OV1nH003OV000gj0?Nlmk`03?Nn/Ool00`00Oomoo`0`Ool0031o
o`03001oogoo009oo`03?Nmn@7i000=nH003OX0mkcg_008mkjioo`03001oogoo02moo`00;goo00<0
07ooOol00Woo00<mkgi0OT000Wi00WiP0cg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool6
OT0017iP?Nlmkcg_/Woo00<007ooOol0;Goo000]Ool00`00Oomoo`04Ool2OR03OT000giP?Nlmk`02
?NncOol00`00Oomoo`0/Ool002aoo`03001oogoo00Aoo`An809n@0@mkkEoo`03001oogoo02]oo`00
;7oo00<007ooOol00goo1WhP13g_]Woo00<007ooOol0:goo000[Ool00`00Oomoo`04Ool2OP03OR00
0gi0?Nlmk`02?NngOol00`00Oomoo`0ZOol002Yoo`03001oogoo00Aoo`An009n8;eoo`03001oogoo
02Uoo`00:Goo00<007ooOol017oo1Wh0_goo00<007ooOol0:7oo000XOol00`00Oomoo`04Ool5ON00
0gh0OR1oo`2oOol00`00Oomoo`0WOol002Qoo`03001oogoo00Aoo`Emh003?Nmoogoo0;moo`03001o
ogoo02Moo`009goo00<007ooOol017oo17g00WgP00<mkgooOol0`7oo00<007ooOol09Woo000VOol0
0`00Oomoo`05Ool4OL02ON02?No2Ool00`00Oomoo`0UOol002Eoo`03001oogoo00Eoo`AmX003OL1m
h3g_008mkl=oo`03001oogoo02Aoo`0097oo00<007ooOol01Woo00ImP7e0OD1mP7g0ON02?No5Ool0
0`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`Am8004OD1m`3g_?No6Ool00`00Oomoo`0SOol002=o
o`03001oogoo00Eoo`Am0004OB1m@7g0?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Eoo`03
O@1lh7cP009m0004OB1mH3g_?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`Alh003O@1m
87f0008mklUoo`03001oogoo025oo`008Goo00<007ooOol01Goo1WcP00=m83g_?Nl0bgoo00<007oo
Ool087oo000POol00`00Oomoo`06Ool5O>000gd0?Nlmk`3=Ool00`00Oomoo`0OOol0021oo`03001o
ogoo00Eoo`El`003O@0mkgoo0<ioo`03001oogoo01moo`007goo00<007ooOol01Woo1Gc000<mkgoo
Ool0cgoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool00gc0O:1lX003O<000cg_Oomoo`3@Ool0
0`00Oomoo`0MOol001ioo`03001oogoo00Ioo`AlX09l`003?Nmoogoo0=1oo`03001oogoo01eoo`00
7Goo00<007ooOol01Woo1WbP0Sg_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool00gbPO81l
P003O:03?NoCOol00`00Oomoo`0LOol001aoo`03001oogoo00Ioo`AlP004O:1l`3g_?NoEOol00`00
Oomoo`0KOol001aoo`03001oogoo00Eoo`IlP0<mkmEoo`03001oogoo01]oo`006goo00<007ooOol0
1Woo0WaP0gb000AlX3g_?NlmkmIoo`03001oogoo01Yoo`006goo00<007ooOol01Goo17aP0Wb00cg_
egoo00<007ooOol06Woo000JOol00`00Oomoo`05Ool6O604?NoHOol00`00Oomoo`0IOol001Yoo`03
001oogoo00Eoo`ElH004O80mkcg_?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`03O61l
@7a000=lH0<mkm]oo`03001oogoo01Qoo`006Goo00<007ooOol01Goo17a000AlH3g_?Nlmkmaoo`03
001oogoo01Qoo`0067oo00<007ooOol01Goo1Wa00Sg_gWoo00<007ooOol05goo000HOol00`00Oomo
o`04Ool4O202O402?NoOOol00`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`Al8004O41lH3g_?NoO
Ool00`00Oomoo`0GOol001Moo`03001oogoo00Eoo`05O21l07`PO21l@003?NoPOol00`00Oomoo`0F
Ool001Moo`03001oogoo00Aoo`03?Nml87`0009l8003O40mkcg_0>5oo`03001oogoo01Ioo`005Woo
00<007ooOol01Goo00<mkg`PO0000W`P0cg_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool0
0cg_O21l8002O2000cg_Oomoo`3ROol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05
Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo
00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomo
o`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Sg_
jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001o
ogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo
000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03
001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07
Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo
00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomo
o`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_
kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo
000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03
001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:
Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo
00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomo
o`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_
iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol037oo
000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo
00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0mknUo
o`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00Oomo
o`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001oogoo
00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH?NoV
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoT
Ool00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007oo
Ool067oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool0
00aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol05goo2cg_h7oo00<0
07ooOol02goo000=Ool00`00Oomoo`0KOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo01]o
o`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool0
0`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo
00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol8?NoM
Ool00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Tmkmaoo`03001oogoo00aoo`003Goo00<007oo
Ool077oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`0MOol:?NoJOol00`00Oomoo`0<Ool0
00eoo`03001oogoo01ioo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol07Woo23g_fGoo00<0
07ooOol03Goo000>Ool00`00Oomoo`0NOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo0?mo
o`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol0
0`00Oomoo`0=Ool000moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<0
07ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001oogoo0?eoo`03001o
ogoo00ioo`0047oo00<007ooOol0o7oo00<007ooOol03Woo000@Ool00`00Oomoo`3kOol00`00Oomo
o`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol0
3goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0015oo`03001oogoo0?Yoo`03001oogoo00mo
o`004Goo00<007ooOol0nGoo00<007ooOol047oo000AOol00`00Oomoo`3iOol00`00Oomoo`0@Ool0
019oo`03001oogoo0?Qoo`03001oogoo011oo`004Woo00<007ooOol0mgoo00<007ooOol04Goo000B
Ool00`00Oomoo`3gOol00`00Oomoo`0AOol001=oo`03001oogoo0?Ioo`03001oogoo015oo`004goo
00<007ooOol0mGoo00<007ooOol04Woo000COol00`00Oomoo`3eOol00`00Oomoo`0BOol001Aoo`03
001oogoo0?Aoo`03001oogoo019oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00
Oomoo`3cOol00`00Oomoo`0COol001Eoo`03001oogoo0?9oo`03001oogoo01=oo`005Goo00<007oo
Ool0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol001Eoo`03001oogoo
0?5oo`03001oogoo01Aoo`005Woo00<007ooOol0kgoo00<007ooOol05Goo000FOol00`00Oomoo`3_
Ool00`00Oomoo`0EOol001Moo`03001oogoo0>eoo`03001oogoo01Ioo`005goo00<007ooOol0kGoo
00<007ooOol05Woo000HOol00`00Oomoo`3[Ool00`00Oomoo`0GOol001Qoo`03001oogoo0>]oo`03
001oogoo01Moo`006Goo00<007ooOol0jWoo00<007ooOol05goo000IOol00`00Oomoo`3YOol00`00
Oomoo`0HOol001Yoo`03001oogoo0>Qoo`03001oogoo01Qoo`006Woo00<007ooOol0igoo00<007oo
Ool06Goo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001]oo`03001oogoo0>Eoo`03001oogoo
01Yoo`0077oo00<007ooOol0hgoo00<007ooOol06goo000LOol00`00Oomoo`3SOol00`00Oomoo`0K
Ool001eoo`03001oogoo0>5oo`03001oogoo01aoo`007Goo00<007ooOol0hGoo00<007ooOol077oo
000NOol00`00Oomoo`3OOol00`00Oomoo`0MOol001ioo`03001oogoo0=moo`03001oogoo01eoo`00
7goo00<007ooOol0gGoo00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021o
o`03001oogoo0=]oo`03001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol0
0`00Oomoo`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<0
07ooOol0eGoo00<007ooOol08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001o
ogoo0==oo`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomo
o`3?Ool00`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0
cGoo00<007ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uo
o`03001oogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool0
0`00Oomoo`0YOol002]oo`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<0
07ooOol0:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001o
ogoo02eoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomo
o`0^Ool0031oo`03001oogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0
<7oo000bOol2002gOol2000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007oo
Ool0/Goo00<007ooOol0=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo
0:moo`03001oogoo03Eoo`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[
Ool00`00Oomoo`0gOol003Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo
000lOol00`00Oomoo`2SOol00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00
?Woo0P00Wgoo0P00?goo0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049o
o`00@goo00<007ooOol0UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool0
04Eoo`03001oogoo095oo`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019
Ool004Yoo`8008Moo`8004]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomo
o`1=Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001g
Ool2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol0
05]oo`<006=oo`<005aoo`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069o
o`<005Eoo`<006=oo`00IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@0
06eoo`00L7oo0`00>7oo1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo
3P001Goo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
08aoo`<0009oo`8008eoo`00SGoo00@007ooOol0009oo`03001oogoo08Yoo`00RWoo1@0000Eoo`00
Oomoo`0008aoo`00RWoo00@007ooOol000=oo`8008eoo`00Rgoo00<007oo00000Woo00@007ooOol0
08aoo`00S7oo0P000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(49)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
1 .982 0 r
.008 w
.09798 .31453 Mdot
.016 w
.09798 .31453 m
.0979 .31469 L
s
1 .965 0 r
.008 w
.0979 .31469 Mdot
.016 w
.0979 .31469 m
.09779 .31495 L
s
1 .947 0 r
.008 w
.09779 .31495 Mdot
.016 w
.09779 .31495 m
.09766 .31535 L
s
1 .93 0 r
.008 w
.09766 .31535 Mdot
.016 w
.09766 .31535 m
.09753 .31589 L
s
1 .912 0 r
.008 w
.09753 .31589 Mdot
.016 w
.09753 .31589 m
.09741 .31658 L
s
1 .895 0 r
.008 w
.09741 .31658 Mdot
.016 w
.09741 .31658 m
.09731 .3174 L
s
1 .877 0 r
.008 w
.09731 .3174 Mdot
.016 w
.09731 .3174 m
.09723 .31833 L
s
1 .86 0 r
.008 w
.09723 .31833 Mdot
.016 w
.09723 .31833 m
.0972 .31935 L
s
1 .842 0 r
.008 w
.0972 .31935 Mdot
.016 w
.0972 .31935 m
.09719 .32035 L
s
1 .825 0 r
.008 w
.09719 .32035 Mdot
.016 w
.09719 .32035 m
.09721 .32137 L
s
1 .807 0 r
.008 w
.09721 .32137 Mdot
.016 w
.09721 .32137 m
.09726 .32237 L
s
1 .789 0 r
.008 w
.09726 .32237 Mdot
.016 w
.09726 .32237 m
.09731 .32333 L
s
1 .772 0 r
.008 w
.09731 .32333 Mdot
.016 w
.09731 .32333 m
.0974 .32416 L
s
1 .754 0 r
.008 w
.0974 .32416 Mdot
.016 w
.0974 .32416 m
.09752 .32482 L
s
1 .737 0 r
.008 w
.09752 .32482 Mdot
.016 w
.09752 .32482 m
.09766 .32524 L
s
1 .719 0 r
.008 w
.09766 .32524 Mdot
.016 w
.09766 .32524 m
.09782 .32549 L
s
1 .702 0 r
.008 w
.09782 .32549 Mdot
.016 w
.09782 .32549 m
.09799 .32563 L
s
1 .684 0 r
.008 w
.09799 .32563 Mdot
.016 w
.09799 .32563 m
.09815 .32567 L
s
1 .667 0 r
.008 w
.09815 .32567 Mdot
.016 w
.09815 .32567 m
.09827 .32567 L
s
1 .649 0 r
.008 w
.09827 .32567 Mdot
.016 w
.09827 .32567 m
.09831 .32572 L
s
1 .632 0 r
.008 w
.09831 .32572 Mdot
.016 w
.09831 .32572 m
.09825 .32591 L
s
1 .614 0 r
.008 w
.09825 .32591 Mdot
.016 w
.09825 .32591 m
.0981 .32641 L
s
1 .596 0 r
.008 w
.0981 .32641 Mdot
.016 w
.0981 .32641 m
.09786 .32728 L
s
1 .579 0 r
.008 w
.09786 .32728 Mdot
.016 w
.09786 .32728 m
.09755 .32856 L
s
1 .561 0 r
.008 w
.09755 .32856 Mdot
.016 w
.09755 .32856 m
.09719 .33026 L
s
1 .544 0 r
.008 w
.09719 .33026 Mdot
.016 w
.09719 .33026 m
.09677 .33237 L
s
1 .526 0 r
.008 w
.09677 .33237 Mdot
.016 w
.09677 .33237 m
.09628 .33455 L
s
1 .509 0 r
.008 w
.09628 .33455 Mdot
.016 w
.09628 .33455 m
.0957 .33698 L
s
1 .491 0 r
.008 w
.0957 .33698 Mdot
.016 w
.0957 .33698 m
.09501 .33993 L
s
1 .474 0 r
.008 w
.09501 .33993 Mdot
.016 w
.09501 .33993 m
.09421 .343 L
s
1 .456 0 r
.008 w
.09421 .343 Mdot
.016 w
.09421 .343 m
.09334 .34641 L
s
1 .439 0 r
.008 w
.09334 .34641 Mdot
.016 w
.09334 .34641 m
.09239 .34975 L
s
1 .421 0 r
.008 w
.09239 .34975 Mdot
.016 w
.09239 .34975 m
.09139 .3533 L
s
1 .404 0 r
.008 w
.09139 .3533 Mdot
.016 w
.09139 .3533 m
.09042 .35679 L
s
1 .386 0 r
.008 w
.09042 .35679 Mdot
.016 w
.09042 .35679 m
.08946 .35992 L
s
1 .368 0 r
.008 w
.08946 .35992 Mdot
.016 w
.08946 .35992 m
.08854 .36335 L
s
1 .351 0 r
.008 w
.08854 .36335 Mdot
.016 w
.08854 .36335 m
.08773 .36647 L
s
1 .333 0 r
.008 w
.08773 .36647 Mdot
.016 w
.08773 .36647 m
.08695 .36967 L
s
1 .316 0 r
.008 w
.08695 .36967 Mdot
.016 w
.08695 .36967 m
.08629 .37266 L
s
1 .298 0 r
.008 w
.08629 .37266 Mdot
.016 w
.08629 .37266 m
.08569 .3758 L
s
1 .281 0 r
.008 w
.08569 .3758 Mdot
.016 w
.08569 .3758 m
.08518 .37848 L
s
1 .263 0 r
.008 w
.08518 .37848 Mdot
.016 w
.08518 .37848 m
.08478 .3813 L
s
1 .246 0 r
.008 w
.08478 .3813 Mdot
.016 w
.08478 .3813 m
.08449 .38393 L
s
1 .228 0 r
.008 w
.08449 .38393 Mdot
.016 w
.08449 .38393 m
.08431 .38664 L
s
1 .211 0 r
.008 w
.08431 .38664 Mdot
.016 w
.08431 .38664 m
.08422 .38925 L
s
1 .193 0 r
.008 w
.08422 .38925 Mdot
.016 w
.08422 .38925 m
.08422 .39138 L
s
1 .175 0 r
.008 w
.08422 .39138 Mdot
.016 w
.08422 .39138 m
.08425 .3934 L
s
1 .158 0 r
.008 w
.08425 .3934 Mdot
.016 w
.08425 .3934 m
.08431 .3953 L
s
1 .14 0 r
.008 w
.08431 .3953 Mdot
.016 w
.08431 .3953 m
.08436 .39701 L
s
1 .123 0 r
.008 w
.08436 .39701 Mdot
.016 w
.08436 .39701 m
.08439 .39849 L
s
1 .105 0 r
.008 w
.08439 .39849 Mdot
.016 w
.08439 .39849 m
.08439 .39964 L
s
1 .088 0 r
.008 w
.08439 .39964 Mdot
.016 w
.08439 .39964 m
.08438 .40059 L
s
1 .07 0 r
.008 w
.08438 .40059 Mdot
.016 w
.08438 .40059 m
.08437 .40133 L
s
1 .053 0 r
.008 w
.08437 .40133 Mdot
.016 w
.08437 .40133 m
.08437 .40187 L
s
1 .035 0 r
.008 w
.08437 .40187 Mdot
.016 w
.08437 .40187 m
.08436 .40224 L
s
1 .018 0 r
.008 w
.08436 .40224 Mdot
.016 w
.08436 .40224 m
.08436 .40243 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool4Oh000gnP?Nlmk`02?NoPOol00`00Oomo
o`0FOol001Moo`03001oogoo00Aoo`Ao@004Oj0mkcg_?NoQOol00`00Oomoo`0FOol001Ioo`03001o
ogoo00Eoo`Ao0004Oj0mkcg_?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eoo`03O^1n@7i0
009n@003?Nmoogoo0>9oo`03001oogoo01Eoo`005Goo00<007ooOol01Woo1GhP00<mkgooOol0hgoo
00<007ooOol057oo000EOol00`00Oomoo`05Ool00cg_OP1n0002OP000ghP?Nmoo`3TOol00`00Oomo
o`0DOol001Eoo`03001oogoo00Eoo`03?Nmmh7gP009mh003OR0mkgoo0>Aoo`03001oogoo01Aoo`00
57oo00<007ooOol01Woo00HmkggPOL1m`7gPOR3WOol00`00Oomoo`0COol001Aoo`03001oogoo00Io
o`03?Nmm`7g0009m`003?Nmoogoo0>Eoo`03001oogoo01=oo`0057oo00<007ooOol01Goo00<mkgg0
OL0017g0igoo00<007ooOol04goo000COol00`00Oomoo`06Ool01Sg_OJ1mP7f0OJ1m`>Uoo`03001o
ogoo019oo`004goo00<007ooOol01Woo00<mkgf0OH000Wf000=mh7ooOol0igoo00<007ooOol04Woo
000COol00`00Oomoo`06Ool4OF02OH3YOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`AmH003
OH1oogoo0>Uoo`03001oogoo015oo`004Woo00<007ooOol01goo17e000=mX7ooOol0jGoo00<007oo
Ool04Goo000BOol00`00Oomoo`06Ool00cg_OD1m@002OD3/Ool00`00Oomoo`0AOol0015oo`03001o
ogoo00Moo`Am809m@>aoo`03001oogoo011oo`004Goo00<007ooOol01goo17d000=m@7ooOol0jgoo
00<007ooOol047oo000AOol00`00Oomoo`07Ool4O>000ge0?Nmoo`3[Ool00`00Oomoo`0@Ool0015o
o`03001oogoo00Moo`Alh08mkneoo`03001oogoo00moo`0047oo00<007ooOol027oo17c000<mkgoo
Ool0k7oo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4O:000cg_Oomoo`3/Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Qoo`AlP003?Nmoogoo0>aoo`03001oogoo00moo`0047oo00<007ooOol0
27oo17a000<mkgooOol0k7oo00<007ooOol03goo000?Ool00`00Oomoo`09Ool017a0O01l07a00Sg_
kWoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4O003?No]Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Al00<mkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo00Al@7`0O01l@0<m
kneoo`03001oogoo00ioo`003goo00<007ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool00`00
Oomoo`0:Ool8?No]Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo00eo
o`003Woo00<007ooOol037oo2Sg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol0
0`00Oomoo`0=Ool000ioo`03001oogoo00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol0
3Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eo
o`03001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Sg_iWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0=Ool=?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`Pm
k`03Oolmkcg_00<mknMoo`03001oogoo00aoo`003Goo00<007ooOol02goo1cg_0goo1Cg_igoo00<0
07ooOol037oo000=Ool00`00Oomoo`09Ool=?No[Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
o`lmknYoo`03001oogoo00aoo`003Goo00<007ooOol027oo43g_jGoo00<007ooOol037oo000=Ool0
0`00Oomoo`08OolA?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qooa<mknQoo`03001oogoo
00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`06
OolG?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00EooaPmknIoo`03001oogoo00]oo`0037oo
00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl00goo?Nlmk`0<
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001oogoo00]oo`00
37oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5?Nl;
Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001oogoo00]oo`0037oo
00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9?NoROol00`00Oomo
o`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol067oo2Sg_
hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;Ool000eoo`03001o
ogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo
000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0L
Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`003Goo
00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJOol00`00Oomo
o`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Woo2Cg_
fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=Ool000ioo`03001o
ogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool0
0`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`003goo00<0
07ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000moo`03001o
ogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool00`00Oomo
o`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0
ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]o
o`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomoo`3iOol0
0`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0n7oo00<0
07ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Moo`03001o
ogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol00`00Oomo
o`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<007ooOol0
4Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=o
o`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomoo`0DOol0
01Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol057oo000F
Ool00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005goo
00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Qoo`03
001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000IOol00`00
Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo00<007oo
Ool0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03001oogoo
0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00Oomoo`3S
Ool00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007ooOol0hGoo
00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03
001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00
Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007oo
Ool07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03001oogoo
021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0R
Ool002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007ooOol08goo
000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`00
9Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0VOol002Qo
o`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo000ZOol0
0`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00:goo00<0
07ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eoo`03001o
ogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool00`00Oomo
o`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<007ooOol0
^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Moo`8003=o
o`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol0
03Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0=Goo000g
Ool00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Moo`00>Goo
0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo0:=oo`03
001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000oOol0041o
o`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomoo`2EOol0
0`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0TGoo00<0
07ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo0P00Bgoo
001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<007ooOol0
OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo0P00Lgoo
0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00G7oo001N
Ool2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo001UOol3
001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000hOol4001a
Ool007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool008eoo`D0
08ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`0000Aoo`00000008eo
o`00SGoo00<007ooOol00Woo00<007ooOol0Rgoo002:Ool50002Ool3002<Ool008Yoo`04001oogoo
0002Ool01000Oomoo`00S7oo002;Ool00`00Ool00002Ool01000Oomoo`00S7oo002<Ool20003Ool3
002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(50)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
1 .982 0 r
.008 w
.09214 .41345 Mdot
.016 w
.09214 .41345 m
.09231 .41353 L
s
1 .964 0 r
.008 w
.09231 .41353 Mdot
.016 w
.09231 .41353 m
.09256 .41373 L
s
1 .945 0 r
.008 w
.09256 .41373 Mdot
.016 w
.09256 .41373 m
.0929 .41405 L
s
1 .927 0 r
.008 w
.0929 .41405 Mdot
.016 w
.0929 .41405 m
.09331 .41451 L
s
1 .909 0 r
.008 w
.09331 .41451 Mdot
.016 w
.09331 .41451 m
.09377 .41504 L
s
1 .891 0 r
.008 w
.09377 .41504 Mdot
.016 w
.09377 .41504 m
.09425 .41573 L
s
1 .873 0 r
.008 w
.09425 .41573 Mdot
.016 w
.09425 .41573 m
.09475 .41655 L
s
1 .855 0 r
.008 w
.09475 .41655 Mdot
.016 w
.09475 .41655 m
.09525 .41742 L
s
1 .836 0 r
.008 w
.09525 .41742 Mdot
.016 w
.09525 .41742 m
.09572 .41847 L
s
1 .818 0 r
.008 w
.09572 .41847 Mdot
.016 w
.09572 .41847 m
.09614 .41974 L
s
1 .8 0 r
.008 w
.09614 .41974 Mdot
.016 w
.09614 .41974 m
.09651 .42109 L
s
1 .782 0 r
.008 w
.09651 .42109 Mdot
.016 w
.09651 .42109 m
.09684 .42263 L
s
1 .764 0 r
.008 w
.09684 .42263 Mdot
.016 w
.09684 .42263 m
.0971 .42436 L
s
1 .745 0 r
.008 w
.0971 .42436 Mdot
.016 w
.0971 .42436 m
.09727 .42624 L
s
1 .727 0 r
.008 w
.09727 .42624 Mdot
.016 w
.09727 .42624 m
.09735 .42835 L
s
1 .709 0 r
.008 w
.09735 .42835 Mdot
.016 w
.09735 .42835 m
.09737 .43041 L
s
1 .691 0 r
.008 w
.09737 .43041 Mdot
.016 w
.09737 .43041 m
.0973 .43272 L
s
1 .673 0 r
.008 w
.0973 .43272 Mdot
.016 w
.0973 .43272 m
.09714 .43512 L
s
1 .655 0 r
.008 w
.09714 .43512 Mdot
.016 w
.09714 .43512 m
.09689 .43776 L
s
1 .636 0 r
.008 w
.09689 .43776 Mdot
.016 w
.09689 .43776 m
.09652 .44048 L
s
1 .618 0 r
.008 w
.09652 .44048 Mdot
.016 w
.09652 .44048 m
.09603 .44292 L
s
1 .6 0 r
.008 w
.09603 .44292 Mdot
.016 w
.09603 .44292 m
.09543 .44553 L
s
1 .582 0 r
.008 w
.09543 .44553 Mdot
.016 w
.09543 .44553 m
.09467 .44837 L
s
1 .564 0 r
.008 w
.09467 .44837 Mdot
.016 w
.09467 .44837 m
.09375 .45099 L
s
1 .545 0 r
.008 w
.09375 .45099 Mdot
.016 w
.09375 .45099 m
.09278 .45354 L
s
1 .527 0 r
.008 w
.09278 .45354 Mdot
.016 w
.09278 .45354 m
.09162 .45593 L
s
1 .509 0 r
.008 w
.09162 .45593 Mdot
.016 w
.09162 .45593 m
.09025 .4581 L
s
1 .491 0 r
.008 w
.09025 .4581 Mdot
.016 w
.09025 .4581 m
.08883 .46012 L
s
1 .473 0 r
.008 w
.08883 .46012 Mdot
.016 w
.08883 .46012 m
.08743 .46194 L
s
1 .455 0 r
.008 w
.08743 .46194 Mdot
.016 w
.08743 .46194 m
.0858 .4637 L
s
1 .436 0 r
.008 w
.0858 .4637 Mdot
.016 w
.0858 .4637 m
.08431 .46532 L
s
1 .418 0 r
.008 w
.08431 .46532 Mdot
.016 w
.08431 .46532 m
.08281 .46687 L
s
1 .4 0 r
.008 w
.08281 .46687 Mdot
.016 w
.08281 .46687 m
.08128 .46828 L
s
1 .382 0 r
.008 w
.08128 .46828 Mdot
.016 w
.08128 .46828 m
.07987 .46962 L
s
1 .364 0 r
.008 w
.07987 .46962 Mdot
.016 w
.07987 .46962 m
.07869 .47086 L
s
1 .345 0 r
.008 w
.07869 .47086 Mdot
.016 w
.07869 .47086 m
.07772 .47196 L
s
1 .327 0 r
.008 w
.07772 .47196 Mdot
.016 w
.07772 .47196 m
.07681 .47293 L
s
1 .309 0 r
.008 w
.07681 .47293 Mdot
.016 w
.07681 .47293 m
.07597 .47373 L
s
1 .291 0 r
.008 w
.07597 .47373 Mdot
.016 w
.07597 .47373 m
.07524 .47445 L
s
1 .273 0 r
.008 w
.07524 .47445 Mdot
.016 w
.07524 .47445 m
.07467 .4751 L
s
1 .255 0 r
.008 w
.07467 .4751 Mdot
.016 w
.07467 .4751 m
.07422 .47571 L
s
1 .236 0 r
.008 w
.07422 .47571 Mdot
.016 w
.07422 .47571 m
.07385 .47629 L
s
1 .218 0 r
.008 w
.07385 .47629 Mdot
.016 w
.07385 .47629 m
.07354 .47681 L
s
1 .2 0 r
.008 w
.07354 .47681 Mdot
.016 w
.07354 .47681 m
.07328 .47727 L
s
1 .182 0 r
.008 w
.07328 .47727 Mdot
.016 w
.07328 .47727 m
.07309 .47764 L
s
1 .164 0 r
.008 w
.07309 .47764 Mdot
.016 w
.07309 .47764 m
.07297 .47789 L
s
1 .145 0 r
.008 w
.07297 .47789 Mdot
.016 w
.07297 .47789 m
.0728 .47806 L
s
1 .127 0 r
.008 w
.0728 .47806 Mdot
.016 w
.0728 .47806 m
.07255 .47816 L
s
1 .109 0 r
.008 w
.07255 .47816 Mdot
.016 w
.07255 .47816 m
.07231 .47826 L
s
1 .091 0 r
.008 w
.07231 .47826 Mdot
.016 w
.07231 .47826 m
.07211 .47839 L
s
1 .073 0 r
.008 w
.07211 .47839 Mdot
.016 w
.07211 .47839 m
.07194 .47856 L
s
1 .055 0 r
.008 w
.07194 .47856 Mdot
.016 w
.07194 .47856 m
.07183 .47879 L
s
1 .036 0 r
.008 w
.07183 .47879 Mdot
.016 w
.07183 .47879 m
.07176 .479 L
s
1 .018 0 r
.008 w
.07176 .479 Mdot
.016 w
.07176 .479 m
.07173 .47922 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo13g_00=oP3g_?Nl0kGoo
00<007ooOol03Woo000?Ool00`00Oomoo`09Ool3?Nl3Oh000cg_Oomoo`3[Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Uoo`8mk`03Oh1o@7m0009o@003?Nmoogoo0>Yoo`03001oogoo00ioo`003Woo
00<007ooOol02Woo0Sg_00=oP7lPOb000WlP00=oP7ooOol0jgoo00<007ooOol03Goo000>Ool00`00
Oomoo`0:Ool3?Nl4O^05?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`03?Nmn`7k0009n
`0DmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo17jP1cg_igoo00<007ooOol03Goo000>
Ool00`00Oomoo`0=Ool4OX08?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`AnH0TmknIo
o`03001oogoo00aoo`003Goo00<007ooOol03Woo17iP2Cg_iWoo00<007ooOol037oo000=Ool00`00
Oomoo`0=Ool00cg_OT1n@002OT09?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`An8003
OT0mkcg_00LmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo17h000=n@3g_?Nl01Sg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`0<Ool01WgPOL1m`7gPOP1n@08mk`03Oolmkcg_00<mknMo
o`03001oogoo00aoo`003Goo00<007ooOol02goo00<mkgfPOJ000Wg000=n07i0Ool00Woo1Cg_igoo
00<007ooOol037oo000=Ool00`00Oomoo`09Ool2?Nl2OF02OJ02OL05?No[Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Qoo`8mk`AmH09mX003OP0mkcg_00@mknYoo`03001oogoo00aoo`003Goo00<0
07ooOol027oo00<mkgdPOB000WdP0WeP00=mh3g_?Nl01Sg_jGoo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool4O<000gdPOF0mk`0:?NoXOol00`00Oomoo`0<Ool000aoo`03001oogoo00Qoo`9l@004
O21l@7a0OB0=?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`04?Nml@7a0O002O4000gdP
?Nlmk`02?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`8mk`9l@004O01l@7a0
OB0??NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`<mk`El@10mknIoo`03001oogoo00]o
o`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl00goo
?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08
Ool5?Nl;Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`HmknAoo`03001oogoo00]o
o`0037oo00<007ooOol067oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`0HOol9?NoROol0
0`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol0
67oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`0GOol;?NoPOol00`00Oomoo`0;Ool000eo
o`03001oogoo01]oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007oo
Ool037oo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pm
kmioo`03001oogoo00aoo`003Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00
Oomoo`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00ao
o`003Goo00<007ooOol077oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJOol0
0`00Oomoo`0<Ool000eoo`03001oogoo01eoo`XmkmYoo`03001oogoo00aoo`003Goo00<007ooOol0
7Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0NOol8?NoIOol00`00Oomoo`0=Ool000io
o`03001oogoo01ioo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo
000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000moo`03001oogoo0?ioo`03001oogoo00eoo`00
3goo00<007ooOol0oGoo00<007ooOol03Woo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool000mo
o`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@Ool0
0`00Oomoo`3lOol00`00Oomoo`0>Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo00<0
07ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001o
ogoo0?]oo`03001oogoo00moo`004Goo00<007ooOol0nWoo00<007ooOol03goo000AOol00`00Oomo
o`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Woo00<007ooOol0
n7oo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo0?Mo
o`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3eOol0
0`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0m7oo00<0
07ooOol04Woo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001o
ogoo01=oo`005Goo00<007ooOol0lWoo00<007ooOol04goo000EOol00`00Oomoo`3aOol00`00Oomo
o`0DOol001Eoo`03001oogoo0?5oo`03001oogoo01Aoo`005Goo00<007ooOol0lGoo00<007ooOol0
57oo000FOol00`00Oomoo`3_Ool00`00Oomoo`0EOol001Ioo`03001oogoo0>moo`03001oogoo01Eo
o`005goo00<007ooOol0kGoo00<007ooOol05Woo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo0>]oo`03001oogoo01Moo`0067oo00<007ooOol0jgoo00<007ooOol05goo000I
Ool00`00Oomoo`3ZOol00`00Oomoo`0GOol001Uoo`03001oogoo0>Uoo`03001oogoo01Qoo`006Woo
00<007ooOol0j7oo00<007ooOol067oo000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001]oo`03
001oogoo0>Eoo`03001oogoo01Yoo`006goo00<007ooOol0iGoo00<007ooOol06Woo000LOol00`00
Oomoo`3SOol00`00Oomoo`0KOol001aoo`03001oogoo0>=oo`03001oogoo01]oo`007Goo00<007oo
Ool0hGoo00<007ooOol077oo000MOol00`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo
0=moo`03001oogoo01eoo`007Woo00<007ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3M
Ool00`00Oomoo`0NOol001moo`03001oogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo
00<007ooOol07goo000POol00`00Oomoo`3KOol00`00Oomoo`0OOol0025oo`03001oogoo0=Uoo`03
001oogoo021oo`008Woo00<007ooOol0egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00
Oomoo`0ROol002Aoo`03001oogoo0==oo`03001oogoo02=oo`0097oo00<007ooOol0dgoo00<007oo
Ool08goo000UOol00`00Oomoo`3AOol00`00Oomoo`0TOol002Ioo`03001oogoo0<moo`03001oogoo
02Eoo`009Woo00<007ooOol0cgoo00<007ooOol09Goo000WOol00`00Oomoo`3=Ool00`00Oomoo`0V
Ool002Qoo`03001oogoo0<]oo`03001oogoo02Moo`00:Goo00<007ooOol0bGoo00<007ooOol0:7oo
000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002Yoo`03001oogoo0<Moo`03001oogoo02Uoo`00
:goo00<007ooOol0aGoo00<007ooOol0:Woo000/Ool00`00Oomoo`33Ool00`00Oomoo`0[Ool002eo
o`03001oogoo0<5oo`03001oogoo02aoo`00;Woo00<007ooOol0_goo00<007ooOol0;Goo000^Ool0
0`00Oomoo`2oOol00`00Oomoo`0]Ool002moo`03001oogoo0;eoo`03001oogoo02ioo`00<7oo00<0
07ooOol0^goo00<007ooOol0;goo000aOol00`00Oomoo`2iOol00`00Oomoo`0`Ool0039oo`800;Mo
o`8003=oo`00=7oo00<007ooOol0/goo00<007ooOol0<goo000eOol00`00Oomoo`2aOol00`00Oomo
o`0dOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo00<007ooOol0
=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03001oogoo03Mo
o`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003aoo`03001oogoo
0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2002OOol2000o
Ool0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013Ool00`00Oomo
o`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo00<007ooOol0
TGoo00<007ooOol0A7oo0016Ool2002?Ool20017Ool004Qoo`8008]oo`8004Uoo`00BWoo0P00Qgoo
0P00Bgoo001<Ool20023Ool2001=Ool004ioo`03001oogoo07moo`03001oogoo04eoo`00Cgoo00<0
07ooOol0OGoo00<007ooOol0CWoo001@Ool2001kOol2001AOol0059oo`8007Moo`8005=oo`00E7oo
0P00Lgoo0P00EGoo001FOol2001_Ool2001GOol005Qoo`<006Uoo`<005Uoo`00Fgoo0`00Hgoo0`00
G7oo001NOol2001NOol3001OOol0061oo`8005]oo`03001oogoo061oo`00HWoo0`00EGoo0`00Hgoo
001UOol3001?Ool3001VOol006Qoo`@004Moo`@006Uoo`00K7oo1000?goo1000KGoo001`Ool3000h
Ool4001aOol007=oo`D002moo`@007Eoo`00N7oo1`008Goo1`00NGoo001oOol>0005Ool>0020Ool0
08eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo0P0017oo0P00
SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00SGoo00@007ooOol0009oo`03001oogoo
08Yoo`00Rgoo0P000goo00@007ooOol008aoo`00Rgoo00<007ooOol00Woo00@007ooOol008aoo`00
Rgoo0`000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(51)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
1 .995 0 r
.008 w
.07165 .48585 Mdot
.016 w
.07165 .48585 m
.07162 .48609 L
s
1 .99 0 r
.008 w
.07162 .48609 Mdot
.016 w
.07162 .48609 m
.07158 .48647 L
s
1 .985 0 r
.008 w
.07158 .48647 Mdot
.016 w
.07158 .48647 m
.07156 .48693 L
s
1 .98 0 r
.008 w
.07156 .48693 Mdot
.016 w
.07156 .48693 m
.07155 .48745 L
s
1 .975 0 r
.008 w
.07155 .48745 Mdot
.016 w
.07155 .48745 m
.07154 .488 L
s
1 .97 0 r
.008 w
.07154 .488 Mdot
.016 w
.07154 .488 m
.07152 .48858 L
s
1 .965 0 r
.008 w
.07152 .48858 Mdot
.016 w
.07152 .48858 m
.07148 .48922 L
s
1 .96 0 r
.008 w
.07148 .48922 Mdot
.016 w
.07148 .48922 m
.07143 .48991 L
s
1 .955 0 r
.008 w
.07143 .48991 Mdot
.016 w
.07143 .48991 m
.07136 .4907 L
s
1 .949 0 r
.008 w
.07136 .4907 Mdot
.016 w
.07136 .4907 m
.0713 .49154 L
s
1 .944 0 r
.008 w
.0713 .49154 Mdot
.016 w
.0713 .49154 m
.07126 .49242 L
s
1 .939 0 r
.008 w
.07126 .49242 Mdot
.016 w
.07126 .49242 m
.07123 .49336 L
s
1 .934 0 r
.008 w
.07123 .49336 Mdot
.016 w
.07123 .49336 m
.07121 .49435 L
s
1 .929 0 r
.008 w
.07121 .49435 Mdot
.016 w
.07121 .49435 m
.07118 .4954 L
s
1 .924 0 r
.008 w
.07118 .4954 Mdot
.016 w
.07118 .4954 m
.07111 .49655 L
s
1 .919 0 r
.008 w
.07111 .49655 Mdot
.016 w
.07111 .49655 m
.07099 .4978 L
s
1 .914 0 r
.008 w
.07099 .4978 Mdot
.016 w
.07099 .4978 m
.07082 .49924 L
s
1 .909 0 r
.008 w
.07082 .49924 Mdot
.016 w
.07082 .49924 m
.07061 .50095 L
s
1 .904 0 r
.008 w
.07061 .50095 Mdot
.016 w
.07061 .50095 m
.07034 .503 L
s
1 .899 0 r
.008 w
.07034 .503 Mdot
.016 w
.07034 .503 m
.07002 .50526 L
s
1 .894 0 r
.008 w
.07002 .50526 Mdot
.016 w
.07002 .50526 m
.06967 .50788 L
s
1 .889 0 r
.008 w
.06967 .50788 Mdot
.016 w
.06967 .50788 m
.0693 .51074 L
s
1 .884 0 r
.008 w
.0693 .51074 Mdot
.016 w
.0693 .51074 m
.06895 .51333 L
s
1 .879 0 r
.008 w
.06895 .51333 Mdot
.016 w
.06895 .51333 m
.0686 .51592 L
s
1 .874 0 r
.008 w
.0686 .51592 Mdot
.016 w
.0686 .51592 m
.06828 .5187 L
s
1 .869 0 r
.008 w
.06828 .5187 Mdot
.016 w
.06828 .5187 m
.06799 .52133 L
s
1 .864 0 r
.008 w
.06799 .52133 Mdot
.016 w
.06799 .52133 m
.06776 .52417 L
s
1 .859 0 r
.008 w
.06776 .52417 Mdot
.016 w
.06776 .52417 m
.06761 .52656 L
s
1 .854 0 r
.008 w
.06761 .52656 Mdot
.016 w
.06761 .52656 m
.06756 .52898 L
s
1 .848 0 r
.008 w
.06756 .52898 Mdot
.016 w
.06756 .52898 m
.06766 .53133 L
s
1 .843 0 r
.008 w
.06766 .53133 Mdot
.016 w
.06766 .53133 m
.06787 .53346 L
s
1 .838 0 r
.008 w
.06787 .53346 Mdot
.016 w
.06787 .53346 m
.0682 .53547 L
s
1 .833 0 r
.008 w
.0682 .53547 Mdot
.016 w
.0682 .53547 m
.0686 .53722 L
s
1 .828 0 r
.008 w
.0686 .53722 Mdot
.016 w
.0686 .53722 m
.06905 .53879 L
s
1 .823 0 r
.008 w
.06905 .53879 Mdot
.016 w
.06905 .53879 m
.06952 .54017 L
s
1 .818 0 r
.008 w
.06952 .54017 Mdot
.016 w
.06952 .54017 m
.06998 .54139 L
s
1 .813 0 r
.008 w
.06998 .54139 Mdot
.016 w
.06998 .54139 m
.07039 .54243 L
s
1 .808 0 r
.008 w
.07039 .54243 Mdot
.016 w
.07039 .54243 m
.07076 .54328 L
s
1 .803 0 r
.008 w
.07076 .54328 Mdot
.016 w
.07076 .54328 m
.07109 .54398 L
s
1 .798 0 r
.008 w
.07109 .54398 Mdot
.016 w
.07109 .54398 m
.07138 .54457 L
s
1 .793 0 r
.008 w
.07138 .54457 Mdot
.016 w
.07138 .54457 m
.07165 .54505 L
s
1 .788 0 r
.008 w
.07165 .54505 Mdot
.016 w
.07165 .54505 m
.07189 .54543 L
s
1 .783 0 r
.008 w
.07189 .54543 Mdot
.016 w
.07189 .54543 m
.07212 .54573 L
s
1 .778 0 r
.008 w
.07212 .54573 Mdot
.016 w
.07212 .54573 m
.07234 .54595 L
s
1 .773 0 r
.008 w
.07234 .54595 Mdot
.016 w
.07234 .54595 m
.07258 .54613 L
s
1 .768 0 r
.008 w
.07258 .54613 Mdot
.016 w
.07258 .54613 m
.07283 .54627 L
s
1 .763 0 r
.008 w
.07283 .54627 Mdot
.016 w
.07283 .54627 m
.07311 .54637 L
s
1 .758 0 r
.008 w
.07311 .54637 Mdot
.016 w
.07311 .54637 m
.07339 .54643 L
s
1 .753 0 r
.008 w
.07339 .54643 Mdot
.016 w
.07339 .54643 m
.07364 .54646 L
s
1 .747 0 r
.008 w
.07364 .54646 Mdot
.016 w
.07364 .54646 m
.0739 .54653 L
s
1 .742 0 r
.008 w
.0739 .54653 Mdot
.016 w
.0739 .54653 m
.07413 .54666 L
s
1 .737 0 r
.008 w
.07413 .54666 Mdot
.016 w
.07413 .54666 m
.07431 .54687 L
s
1 .732 0 r
.008 w
.07431 .54687 Mdot
.016 w
.07431 .54687 m
.07438 .54716 L
s
1 .727 0 r
.008 w
.07438 .54716 Mdot
.016 w
.07438 .54716 m
.07433 .54757 L
s
1 .722 0 r
.008 w
.07433 .54757 Mdot
.016 w
.07433 .54757 m
.07416 .5481 L
s
1 .717 0 r
.008 w
.07416 .5481 Mdot
.016 w
.07416 .5481 m
.07388 .54878 L
s
1 .712 0 r
.008 w
.07388 .54878 Mdot
.016 w
.07388 .54878 m
.07354 .54965 L
s
1 .707 0 r
.008 w
.07354 .54965 Mdot
.016 w
.07354 .54965 m
.07319 .55075 L
s
1 .702 0 r
.008 w
.07319 .55075 Mdot
.016 w
.07319 .55075 m
.07287 .552 L
s
1 .697 0 r
.008 w
.07287 .552 Mdot
.016 w
.07287 .552 m
.07261 .55354 L
s
1 .692 0 r
.008 w
.07261 .55354 Mdot
.016 w
.07261 .55354 m
.07243 .5553 L
s
1 .687 0 r
.008 w
.07243 .5553 Mdot
.016 w
.07243 .5553 m
.07236 .55721 L
s
1 .682 0 r
.008 w
.07236 .55721 Mdot
.016 w
.07236 .55721 m
.07241 .55936 L
s
1 .677 0 r
.008 w
.07241 .55936 Mdot
.016 w
.07241 .55936 m
.07257 .56167 L
s
1 .672 0 r
.008 w
.07257 .56167 Mdot
.016 w
.07257 .56167 m
.07285 .56394 L
s
1 .667 0 r
.008 w
.07285 .56394 Mdot
.016 w
.07285 .56394 m
.07322 .56639 L
s
1 .662 0 r
.008 w
.07322 .56639 Mdot
.016 w
.07322 .56639 m
.0737 .5688 L
s
1 .657 0 r
.008 w
.0737 .5688 Mdot
.016 w
.0737 .5688 m
.07429 .57131 L
s
1 .652 0 r
.008 w
.07429 .57131 Mdot
.016 w
.07429 .57131 m
.0749 .5736 L
s
1 .646 0 r
.008 w
.0749 .5736 Mdot
.016 w
.0749 .5736 m
.07551 .5759 L
s
1 .641 0 r
.008 w
.07551 .5759 Mdot
.016 w
.07551 .5759 m
.07611 .57816 L
s
1 .636 0 r
.008 w
.07611 .57816 Mdot
.016 w
.07611 .57816 m
.07664 .58006 L
s
1 .631 0 r
.008 w
.07664 .58006 Mdot
.016 w
.07664 .58006 m
.07708 .5819 L
s
1 .626 0 r
.008 w
.07708 .5819 Mdot
.016 w
.07708 .5819 m
.07743 .58356 L
s
1 .621 0 r
.008 w
.07743 .58356 Mdot
.016 w
.07743 .58356 m
.07771 .58496 L
s
1 .616 0 r
.008 w
.07771 .58496 Mdot
.016 w
.07771 .58496 m
.07791 .58617 L
s
1 .611 0 r
.008 w
.07791 .58617 Mdot
.016 w
.07791 .58617 m
.07806 .58722 L
s
1 .606 0 r
.008 w
.07806 .58722 Mdot
.016 w
.07806 .58722 m
.07817 .58792 L
s
1 .601 0 r
.008 w
.07817 .58792 Mdot
.016 w
.07817 .58792 m
.07825 .58848 L
s
1 .596 0 r
.008 w
.07825 .58848 Mdot
.016 w
.07825 .58848 m
.07832 .58882 L
s
1 .591 0 r
.008 w
.07832 .58882 Mdot
.016 w
.07832 .58882 m
.07835 .58898 L
s
1 .586 0 r
.008 w
.07835 .58898 Mdot
.016 w
.07835 .58898 m
.07834 .58898 L
s
1 .581 0 r
.008 w
.07834 .58898 Mdot
.016 w
.07834 .58898 m
.0783 .58891 L
s
1 .576 0 r
.008 w
.0783 .58891 Mdot
.016 w
.0783 .58891 m
.07826 .58884 L
s
1 .571 0 r
.008 w
.07826 .58884 Mdot
.016 w
.07826 .58884 m
.07824 .58885 L
s
1 .566 0 r
.008 w
.07824 .58885 Mdot
.016 w
.07824 .58885 m
.07824 .58893 L
s
1 .561 0 r
.008 w
.07824 .58893 Mdot
.016 w
.07824 .58893 m
.07828 .58908 L
s
1 .556 0 r
.008 w
.07828 .58908 Mdot
.016 w
.07828 .58908 m
.07833 .58929 L
s
1 .551 0 r
.008 w
.07833 .58929 Mdot
.016 w
.07833 .58929 m
.07839 .58953 L
s
1 .545 0 r
.008 w
.07839 .58953 Mdot
.016 w
.07839 .58953 m
.07844 .58981 L
s
1 .54 0 r
.008 w
.07844 .58981 Mdot
.016 w
.07844 .58981 m
.07848 .5901 L
s
1 .535 0 r
.008 w
.07848 .5901 Mdot
.016 w
.07848 .5901 m
.0785 .59041 L
s
1 .53 0 r
.008 w
.0785 .59041 Mdot
.016 w
.0785 .59041 m
.07852 .59073 L
s
1 .525 0 r
.008 w
.07852 .59073 Mdot
.016 w
.07852 .59073 m
.07851 .59111 L
s
1 .52 0 r
.008 w
.07851 .59111 Mdot
.016 w
.07851 .59111 m
.07847 .59163 L
s
1 .515 0 r
.008 w
.07847 .59163 Mdot
.016 w
.07847 .59163 m
.07842 .59233 L
s
1 .51 0 r
.008 w
.07842 .59233 Mdot
.016 w
.07842 .59233 m
.07833 .5931 L
s
1 .505 0 r
.008 w
.07833 .5931 Mdot
.016 w
.07833 .5931 m
.07821 .59408 L
s
1 .5 0 r
.008 w
.07821 .59408 Mdot
.016 w
.07821 .59408 m
.07809 .5952 L
s
1 .495 0 r
.008 w
.07809 .5952 Mdot
.016 w
.07809 .5952 m
.07796 .59651 L
s
1 .49 0 r
.008 w
.07796 .59651 Mdot
.016 w
.07796 .59651 m
.07784 .59793 L
s
1 .485 0 r
.008 w
.07784 .59793 Mdot
.016 w
.07784 .59793 m
.07777 .59963 L
s
1 .48 0 r
.008 w
.07777 .59963 Mdot
.016 w
.07777 .59963 m
.07776 .60155 L
s
1 .475 0 r
.008 w
.07776 .60155 Mdot
.016 w
.07776 .60155 m
.07781 .60375 L
s
1 .47 0 r
.008 w
.07781 .60375 Mdot
.016 w
.07781 .60375 m
.07793 .60628 L
s
1 .465 0 r
.008 w
.07793 .60628 Mdot
.016 w
.07793 .60628 m
.07814 .60881 L
s
1 .46 0 r
.008 w
.07814 .60881 Mdot
.016 w
.07814 .60881 m
.07843 .61163 L
s
1 .455 0 r
.008 w
.07843 .61163 Mdot
.016 w
.07843 .61163 m
.0788 .61462 L
s
1 .449 0 r
.008 w
.0788 .61462 Mdot
.016 w
.0788 .61462 m
.07925 .61783 L
s
1 .444 0 r
.008 w
.07925 .61783 Mdot
.016 w
.07925 .61783 m
.07979 .62082 L
s
1 .439 0 r
.008 w
.07979 .62082 Mdot
.016 w
.07979 .62082 m
.08041 .62387 L
s
1 .434 0 r
.008 w
.08041 .62387 Mdot
.016 w
.08041 .62387 m
.08108 .62704 L
s
1 .429 0 r
.008 w
.08108 .62704 Mdot
.016 w
.08108 .62704 m
.08178 .63003 L
s
1 .424 0 r
.008 w
.08178 .63003 Mdot
.016 w
.08178 .63003 m
.08248 .63318 L
s
1 .419 0 r
.008 w
.08248 .63318 Mdot
.016 w
.08248 .63318 m
.08315 .63611 L
s
1 .414 0 r
.008 w
.08315 .63611 Mdot
.016 w
.08315 .63611 m
.08376 .63906 L
s
1 .409 0 r
.008 w
.08376 .63906 Mdot
.016 w
.08376 .63906 m
.08434 .64167 L
s
1 .404 0 r
.008 w
.08434 .64167 Mdot
.016 w
.08434 .64167 m
.08491 .64416 L
s
1 .399 0 r
.008 w
.08491 .64416 Mdot
.016 w
.08491 .64416 m
.08543 .64628 L
s
1 .394 0 r
.008 w
.08543 .64628 Mdot
.016 w
.08543 .64628 m
.08591 .64815 L
s
1 .389 0 r
.008 w
.08591 .64815 Mdot
.016 w
.08591 .64815 m
.08636 .64981 L
s
1 .384 0 r
.008 w
.08636 .64981 Mdot
.016 w
.08636 .64981 m
.08676 .65126 L
s
1 .379 0 r
.008 w
.08676 .65126 Mdot
.016 w
.08676 .65126 m
.08711 .65257 L
s
1 .374 0 r
.008 w
.08711 .65257 Mdot
.016 w
.08711 .65257 m
.08742 .65383 L
s
1 .369 0 r
.008 w
.08742 .65383 Mdot
.016 w
.08742 .65383 m
.08771 .65503 L
s
1 .364 0 r
.008 w
.08771 .65503 Mdot
.016 w
.08771 .65503 m
.08799 .65618 L
s
1 .359 0 r
.008 w
.08799 .65618 Mdot
.016 w
.08799 .65618 m
.08828 .6573 L
s
1 .354 0 r
.008 w
.08828 .6573 Mdot
.016 w
.08828 .6573 m
.08859 .65838 L
s
1 .348 0 r
.008 w
.08859 .65838 Mdot
.016 w
.08859 .65838 m
.08894 .65933 L
s
1 .343 0 r
.008 w
.08894 .65933 Mdot
.016 w
.08894 .65933 m
.08931 .66025 L
s
1 .338 0 r
.008 w
.08931 .66025 Mdot
.016 w
.08931 .66025 m
.08968 .66107 L
s
1 .333 0 r
.008 w
.08968 .66107 Mdot
.016 w
.08968 .66107 m
.09001 .66184 L
s
1 .328 0 r
.008 w
.09001 .66184 Mdot
.016 w
.09001 .66184 m
.09029 .66248 L
s
1 .323 0 r
.008 w
.09029 .66248 Mdot
.016 w
.09029 .66248 m
.09054 .66304 L
s
1 .318 0 r
.008 w
.09054 .66304 Mdot
.016 w
.09054 .66304 m
.09076 .66354 L
s
1 .313 0 r
.008 w
.09076 .66354 Mdot
.016 w
.09076 .66354 m
.09097 .66395 L
s
1 .308 0 r
.008 w
.09097 .66395 Mdot
.016 w
.09097 .66395 m
.09117 .66432 L
s
1 .303 0 r
.008 w
.09117 .66432 Mdot
.016 w
.09117 .66432 m
.09138 .66475 L
s
1 .298 0 r
.008 w
.09138 .66475 Mdot
.016 w
.09138 .66475 m
.09159 .66527 L
s
1 .293 0 r
.008 w
.09159 .66527 Mdot
.016 w
.09159 .66527 m
.09179 .66589 L
s
1 .288 0 r
.008 w
.09179 .66589 Mdot
.016 w
.09179 .66589 m
.09197 .66678 L
s
1 .283 0 r
.008 w
.09197 .66678 Mdot
.016 w
.09197 .66678 m
.09214 .66795 L
s
1 .278 0 r
.008 w
.09214 .66795 Mdot
.016 w
.09214 .66795 m
.0923 .66935 L
s
1 .273 0 r
.008 w
.0923 .66935 Mdot
.016 w
.0923 .66935 m
.09245 .67086 L
s
1 .268 0 r
.008 w
.09245 .67086 Mdot
.016 w
.09245 .67086 m
.09261 .67253 L
s
1 .263 0 r
.008 w
.09261 .67253 Mdot
.016 w
.09261 .67253 m
.09277 .6743 L
s
1 .258 0 r
.008 w
.09277 .6743 Mdot
.016 w
.09277 .6743 m
.09292 .67602 L
s
1 .253 0 r
.008 w
.09292 .67602 Mdot
.016 w
.09292 .67602 m
.09304 .67788 L
s
1 .247 0 r
.008 w
.09304 .67788 Mdot
.016 w
.09304 .67788 m
.09315 .67959 L
s
1 .242 0 r
.008 w
.09315 .67959 Mdot
.016 w
.09315 .67959 m
.09324 .68133 L
s
1 .237 0 r
.008 w
.09324 .68133 Mdot
.016 w
.09324 .68133 m
.09332 .68307 L
s
1 .232 0 r
.008 w
.09332 .68307 Mdot
.016 w
.09332 .68307 m
.09339 .68482 L
s
1 .227 0 r
.008 w
.09339 .68482 Mdot
.016 w
.09339 .68482 m
.09346 .68663 L
s
1 .222 0 r
.008 w
.09346 .68663 Mdot
.016 w
.09346 .68663 m
.09354 .68845 L
s
1 .217 0 r
.008 w
.09354 .68845 Mdot
.016 w
.09354 .68845 m
.09365 .69013 L
s
1 .212 0 r
.008 w
.09365 .69013 Mdot
.016 w
.09365 .69013 m
.09381 .69194 L
s
1 .207 0 r
.008 w
.09381 .69194 Mdot
.016 w
.09381 .69194 m
.09407 .69386 L
s
1 .202 0 r
.008 w
.09407 .69386 Mdot
.016 w
.09407 .69386 m
.09444 .69573 L
s
1 .197 0 r
.008 w
.09444 .69573 Mdot
.016 w
.09444 .69573 m
.0949 .6977 L
s
1 .192 0 r
.008 w
.0949 .6977 Mdot
.016 w
.0949 .6977 m
.09547 .69968 L
s
1 .187 0 r
.008 w
.09547 .69968 Mdot
.016 w
.09547 .69968 m
.09616 .70149 L
s
1 .182 0 r
.008 w
.09616 .70149 Mdot
.016 w
.09616 .70149 m
.09695 .7032 L
s
1 .177 0 r
.008 w
.09695 .7032 Mdot
.016 w
.09695 .7032 m
.0979 .70474 L
s
1 .172 0 r
.008 w
.0979 .70474 Mdot
.016 w
.0979 .70474 m
.09861 .7058 L
s
1 .167 0 r
.008 w
.09861 .7058 Mdot
.016 w
.09861 .7058 m
.09944 .7068 L
s
1 .162 0 r
.008 w
.09944 .7068 Mdot
.016 w
.09944 .7068 m
.10029 .7076 L
s
1 .157 0 r
.008 w
.10029 .7076 Mdot
.016 w
.10029 .7076 m
.10098 .70821 L
s
1 .152 0 r
.008 w
.10098 .70821 Mdot
.016 w
.10098 .70821 m
.10162 .70868 L
s
1 .146 0 r
.008 w
.10162 .70868 Mdot
.016 w
.10162 .70868 m
.10222 .70906 L
s
1 .141 0 r
.008 w
.10222 .70906 Mdot
.016 w
.10222 .70906 m
.10274 .70935 L
s
1 .136 0 r
.008 w
.10274 .70935 Mdot
.016 w
.10274 .70935 m
.10315 .7096 L
s
1 .131 0 r
.008 w
.10315 .7096 Mdot
.016 w
.10315 .7096 m
.10343 .70984 L
s
1 .126 0 r
.008 w
.10343 .70984 Mdot
.016 w
.10343 .70984 m
.10358 .71016 L
s
1 .121 0 r
.008 w
.10358 .71016 Mdot
.016 w
.10358 .71016 m
.10362 .71058 L
s
1 .116 0 r
.008 w
.10362 .71058 Mdot
.016 w
.10362 .71058 m
.10358 .71115 L
s
1 .111 0 r
.008 w
.10358 .71115 Mdot
.016 w
.10358 .71115 m
.1035 .7119 L
s
1 .106 0 r
.008 w
.1035 .7119 Mdot
.016 w
.1035 .7119 m
.10341 .71285 L
s
1 .101 0 r
.008 w
.10341 .71285 Mdot
.016 w
.10341 .71285 m
.10332 .71394 L
s
1 .096 0 r
.008 w
.10332 .71394 Mdot
.016 w
.10332 .71394 m
.10326 .71514 L
s
1 .091 0 r
.008 w
.10326 .71514 Mdot
.016 w
.10326 .71514 m
.10321 .71643 L
s
1 .086 0 r
.008 w
.10321 .71643 Mdot
.016 w
.10321 .71643 m
.10314 .71777 L
s
1 .081 0 r
.008 w
.10314 .71777 Mdot
.016 w
.10314 .71777 m
.10305 .71921 L
s
1 .076 0 r
.008 w
.10305 .71921 Mdot
.016 w
.10305 .71921 m
.10295 .72077 L
s
1 .071 0 r
.008 w
.10295 .72077 Mdot
.016 w
.10295 .72077 m
.10285 .7226 L
s
1 .066 0 r
.008 w
.10285 .7226 Mdot
.016 w
.10285 .7226 m
.10275 .72427 L
s
1 .061 0 r
.008 w
.10275 .72427 Mdot
.016 w
.10275 .72427 m
.10265 .72614 L
s
1 .056 0 r
.008 w
.10265 .72614 Mdot
.016 w
.10265 .72614 m
.10258 .72808 L
s
1 .051 0 r
.008 w
.10258 .72808 Mdot
.016 w
.10258 .72808 m
.10252 .72993 L
s
1 .045 0 r
.008 w
.10252 .72993 Mdot
.016 w
.10252 .72993 m
.10247 .73164 L
s
1 .04 0 r
.008 w
.10247 .73164 Mdot
.016 w
.10247 .73164 m
.10245 .73319 L
s
1 .035 0 r
.008 w
.10245 .73319 Mdot
.016 w
.10245 .73319 m
.10243 .73444 L
s
1 .03 0 r
.008 w
.10243 .73444 Mdot
.016 w
.10243 .73444 m
.10243 .73553 L
s
1 .025 0 r
.008 w
.10243 .73553 Mdot
.016 w
.10243 .73553 m
.10245 .73645 L
s
1 .02 0 r
.008 w
.10245 .73645 Mdot
.016 w
.10245 .73645 m
.10249 .73723 L
s
1 .015 0 r
.008 w
.10249 .73723 Mdot
.016 w
.10249 .73723 m
.10255 .73787 L
s
1 .01 0 r
.008 w
.10255 .73787 Mdot
.016 w
.10255 .73787 m
.10261 .73833 L
s
1 .005 0 r
.008 w
.10261 .73833 Mdot
.016 w
.10261 .73833 m
.10268 .73861 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo0Sg_17oP4Cg_iWoo00<007ooOol02goo000<Ool00`00Oomo
o`05Ool3?Nl4Ol0A?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`AoX14mknIoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo17nP0Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<
Ool00`00Oomoo`08Ool4Oh02?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Ao
P003?Nmoogoo00Uoo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo17n000<mkgooOol0
2Goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool017n0Of1oH7n03Goo1Sg_i7oo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool4Of0<Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Moo`IoH0]oo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol01goo1GmP37oo2Sg_hGoo
00<007ooOol02goo000<Ool00`00Oomoo`07Ool4Of000gn0Oomoo`0:Ool:?NoQOol00`00Oomoo`0;
Ool000eoo`03001oogoo00Ioo`Ao@0eoo`/mkn1oo`03001oogoo00]oo`003Goo00<007ooOol01Woo
17m04Goo1cg_ggoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool5Od0@Ool8?NoNOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Ioo`03Od1o87lP009o811oo`Pmkmioo`03001oogoo00aoo`003Goo
00<007ooOol01Woo00=o@7lPO`000gl03goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06
Ool00gm0Ob1n`003O/0@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`03Ob1n`7k0
009n`11oo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo00=o87jPOZ000WjP47oo23g_
gGoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4OZ0@Ool9?NoLOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Qoo`AnX11oo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol027oo17jP4Goo
2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4OX0BOol9?NoJOol00`00Oomoo`0<Ool0
00ioo`03001oogoo00Moo`AnP1=oo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol01goo1Gj0
4Woo1Cg_g7oo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool5OX3cOol00`00Oomoo`0=Ool000io
o`03001oogoo00Moo`03OX1nH7iP009nH?=oo`03001oogoo00eoo`003goo00<007ooOol01Woo00=n
P7hPOR000WhPlgoo00<007ooOol03Goo000?Ool00`00Oomoo`07Ool4OP000ghPOomoo`3_Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Moo`Amh003OR1oogoo0>moo`03001oogoo00ioo`003goo00<0
07ooOol01goo17gPlWoo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4ON3bOol00`00Oomoo`0>
Ool0011oo`03001oogoo00Ioo`Am`?9oo`03001oogoo00ioo`0047oo00<007ooOol01Woo17g0lGoo
00<007ooOol03goo000@Ool00`00Oomoo`06Ool4OL3aOol00`00Oomoo`0?Ool0011oo`03001oogoo
00Ioo`Am`?5oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Gg0l7oo00<007ooOol03goo000A
Ool00`00Oomoo`05Ool00gg0OJ1mX002OJ000gg0Oomoo`3]Ool00`00Oomoo`0?Ool0015oo`03001o
ogoo00Eoo`03OL1mX7fP009mX>moo`03001oogoo011oo`004Goo00<007ooOol01Woo17fPkgoo00<0
07ooOol047oo000BOol00`00Oomoo`05Ool5OJ3^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eo
o`ImX>aoo`03001oogoo015oo`004Woo00<007ooOol01Goo00=mX7f0OH000Wf0kGoo00<007ooOol0
4Goo000COol00`00Oomoo`05Ool4OH3]Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`EmP>]o
o`03001oogoo019oo`004goo00<007ooOol01Goo00=mP7ePOF000WePjgoo00<007ooOol04Woo000D
Ool00`00Oomoo`04Ool00gf0OF1mH002OF3[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`03
OH1m@7e000=m@>Uoo`03001oogoo01=oo`0057oo00<007ooOol01Goo00=m@7dPOB000WdPjGoo00<0
07ooOol04goo000EOol00`00Oomoo`04Ool00ge0O@1m0002O@3YOol00`00Oomoo`0COol001Eoo`03
001oogoo00Aoo`03OD1m07d0009m0>Qoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo17d0j7oo
00<007ooOol057oo000EOol00`00Oomoo`05Ool4O>3XOol00`00Oomoo`0DOol001Ioo`03001oogoo
00Aoo`Alh>Moo`03001oogoo01Eoo`005Woo00<007ooOol017oo0WcP00=l`7cPOol0iWoo00<007oo
Ool05Goo000GOol00`00Oomoo`03Ool017cPO<1l`7c0iWoo00<007ooOol05Woo000GOol00`00Oomo
o`03Ool5O<3UOol00`00Oomoo`0FOol001Qoo`03001oogoo009oo`Il`>=oo`03001oogoo01Moo`00
67oo00<007ooOol00Woo00=lh7bPO:000WbPi7oo00<007ooOol05goo000IOol00`00Oomoo`02Ool5
O:3SOol00`00Oomoo`0GOol001Uoo`03001oogoo009oo`03O:1lP7aP00=lH>5oo`03001oogoo01Qo
o`006Woo00H007ooOomoogbPO804O63QOol00`00Oomoo`0HOol001Yoo`06001oogooOomlX7b017a0
h7oo00<007ooOol06Goo000KOol01@00OomoogooO80017a0ggoo00<007ooOol06Woo000KOol00`00
Oomoo`02Ool4O23OOol00`00Oomoo`0JOol001aoo`04001oogooOol4O23NOol00`00Oomoo`0KOol0
01aoo`04001oogooOol4O23NOol00`00Oomoo`0KOol001eoo`03001oogoo00Al0=eoo`03001oogoo
01aoo`007Goo00<007ooOol017`0gGoo00<007ooOol077oo000NOol00`00Ooml0003O03LOol00`00
Oomoo`0MOol001ioo`03001oog`000=l0=aoo`03001oogoo01eoo`007goo00<007`0O0000W`0fgoo
00<007ooOol07Woo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol0021oo`03001oogoo0=]oo`03
001oogoo01moo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomoo`3IOol00`00
Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008goo00<007ooOol0eGoo00<007oo
Ool08Woo000TOol00`00Oomoo`3COol00`00Oomoo`0SOol002Aoo`03001oogoo0==oo`03001oogoo
02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool00`00Oomoo`0U
Ool002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<007ooOol09Woo
000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001oogoo02Qoo`00
:Woo00<007ooOol0agoo00<007ooOol0:Goo000ZOol00`00Oomoo`37Ool00`00Oomoo`0YOol002]o
o`03001oogoo0<Eoo`03001oogoo02Yoo`00;7oo00<007ooOol0`goo00<007ooOol0:goo000]Ool0
0`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eoo`00;Woo00<0
07ooOol0_goo00<007ooOol0;Goo000_Ool00`00Oomoo`2mOol00`00Oomoo`0^Ool0031oo`03001o
ogoo0;]oo`03001oogoo02moo`00<Goo00<007ooOol0^Goo00<007ooOol0<7oo000bOol2002gOol2
000cOol003Aoo`03001oogoo0;=oo`03001oogoo03=oo`00=Goo00<007ooOol0/Goo00<007ooOol0
=7oo000eOol00`00Oomoo`2aOol00`00Oomoo`0dOol003Ioo`03001oogoo0:moo`03001oogoo03Eo
o`00=goo00<007ooOol0[Goo00<007ooOol0=Woo000hOol00`00Oomoo`2[Ool00`00Oomoo`0gOol0
03Uoo`800:Uoo`8003Yoo`00>goo00<007ooOol0YGoo00<007ooOol0>Woo000lOol00`00Oomoo`2S
Ool00`00Oomoo`0kOol003eoo`03001oogoo0:5oo`03001oogoo03aoo`00?Woo0P00Wgoo0P00?goo
0010Ool00`00Oomoo`2KOol00`00Oomoo`0oOol0045oo`8009Uoo`80049oo`00@goo00<007ooOol0
UGoo00<007ooOol0@Woo0014Ool00`00Oomoo`2COol00`00Oomoo`13Ool004Eoo`03001oogoo095o
o`03001oogoo04Aoo`00AWoo0P00Sgoo0P00Agoo0018Ool2002;Ool20019Ool004Yoo`8008Moo`80
04]oo`00C7oo0P00Pgoo0P00CGoo001>Ool00`00Oomoo`1oOol00`00Oomoo`1=Ool004moo`03001o
ogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo0P00DGoo001BOol2001gOol2001COol005Aoo`80
07=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001HOol3001YOol3001IOol005]oo`<006=oo`<005ao
o`00GWoo0P00GWoo0`00Ggoo001POol2001KOol00`00Oomoo`1POol0069oo`<005Eoo`<006=oo`00
IGoo0`00Cgoo0`00IWoo001XOol40017Ool4001YOol006aoo`@003moo`@006eoo`00L7oo0`00>7oo
1000LGoo001cOol5000_Ool4001eOol007Qoo`L0025oo`L007Uoo`00Ogoo3P001Goo3P00P7oo002=
Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000=oo`D008]o
o`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00SGoo00<007ooOol00Woo00<007ooOol0Rgoo
002;Ool20005Ool00`00Oomoo`2;Ool008]oo`03001oogoo00Aoo`03001oogoo08]oo`00Rgoo0`00
0goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(52)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
1 .997 0 r
.008 w
.10263 .73756 Mdot
.016 w
.10263 .73756 m
.10266 .73763 L
s
1 .994 0 r
.008 w
.10266 .73763 Mdot
.016 w
.10266 .73763 m
.10272 .73776 L
s
1 .992 0 r
.008 w
.10272 .73776 Mdot
.016 w
.10272 .73776 m
.10281 .73796 L
s
1 .989 0 r
.008 w
.10281 .73796 Mdot
.016 w
.10281 .73796 m
.10297 .7383 L
s
1 .986 0 r
.008 w
.10297 .7383 Mdot
.016 w
.10297 .7383 m
.10324 .73878 L
s
1 .983 0 r
.008 w
.10324 .73878 Mdot
.016 w
.10324 .73878 m
.10361 .7394 L
s
1 .981 0 r
.008 w
.10361 .7394 Mdot
.016 w
.10361 .7394 m
.10409 .74017 L
s
1 .978 0 r
.008 w
.10409 .74017 Mdot
.016 w
.10409 .74017 m
.10471 .74108 L
s
1 .975 0 r
.008 w
.10471 .74108 Mdot
.016 w
.10471 .74108 m
.10545 .74216 L
s
1 .972 0 r
.008 w
.10545 .74216 Mdot
.016 w
.10545 .74216 m
.1063 .74329 L
s
1 .969 0 r
.008 w
.1063 .74329 Mdot
.016 w
.1063 .74329 m
.10723 .74454 L
s
1 .967 0 r
.008 w
.10723 .74454 Mdot
.016 w
.10723 .74454 m
.10813 .74588 L
s
1 .964 0 r
.008 w
.10813 .74588 Mdot
.016 w
.10813 .74588 m
.10904 .74726 L
s
1 .961 0 r
.008 w
.10904 .74726 Mdot
.016 w
.10904 .74726 m
.10992 .74866 L
s
1 .958 0 r
.008 w
.10992 .74866 Mdot
.016 w
.10992 .74866 m
.11073 .74999 L
s
1 .955 0 r
.008 w
.11073 .74999 Mdot
.016 w
.11073 .74999 m
.11151 .75129 L
s
1 .953 0 r
.008 w
.11151 .75129 Mdot
.016 w
.11151 .75129 m
.11225 .75253 L
s
1 .95 0 r
.008 w
.11225 .75253 Mdot
.016 w
.11225 .75253 m
.11298 .75367 L
s
1 .947 0 r
.008 w
.11298 .75367 Mdot
.016 w
.11298 .75367 m
.11372 .75474 L
s
1 .944 0 r
.008 w
.11372 .75474 Mdot
.016 w
.11372 .75474 m
.11451 .75578 L
s
1 .942 0 r
.008 w
.11451 .75578 Mdot
.016 w
.11451 .75578 m
.1154 .75693 L
s
1 .939 0 r
.008 w
.1154 .75693 Mdot
.016 w
.1154 .75693 m
.11633 .75806 L
s
1 .936 0 r
.008 w
.11633 .75806 Mdot
.016 w
.11633 .75806 m
.11737 .75939 L
s
1 .933 0 r
.008 w
.11737 .75939 Mdot
.016 w
.11737 .75939 m
.11855 .76088 L
s
1 .93 0 r
.008 w
.11855 .76088 Mdot
.016 w
.11855 .76088 m
.11978 .76242 L
s
1 .928 0 r
.008 w
.11978 .76242 Mdot
.016 w
.11978 .76242 m
.12121 .76408 L
s
1 .925 0 r
.008 w
.12121 .76408 Mdot
.016 w
.12121 .76408 m
.1228 .76589 L
s
1 .922 0 r
.008 w
.1228 .76589 Mdot
.016 w
.1228 .76589 m
.12452 .76777 L
s
1 .919 0 r
.008 w
.12452 .76777 Mdot
.016 w
.12452 .76777 m
.1263 .76947 L
s
1 .916 0 r
.008 w
.1263 .76947 Mdot
.016 w
.1263 .76947 m
.12808 .77123 L
s
1 .914 0 r
.008 w
.12808 .77123 Mdot
.016 w
.12808 .77123 m
.12968 .77267 L
s
1 .911 0 r
.008 w
.12968 .77267 Mdot
.016 w
.12968 .77267 m
.13121 .77395 L
s
1 .908 0 r
.008 w
.13121 .77395 Mdot
.016 w
.13121 .77395 m
.13241 .77503 L
s
1 .905 0 r
.008 w
.13241 .77503 Mdot
.016 w
.13241 .77503 m
.13338 .77583 L
s
1 .903 0 r
.008 w
.13338 .77583 Mdot
.016 w
.13338 .77583 m
.13402 .77633 L
s
1 .9 0 r
.008 w
.13402 .77633 Mdot
.016 w
.13402 .77633 m
.13432 .77656 L
s
1 .897 0 r
.008 w
.13432 .77656 Mdot
.016 w
.13432 .77656 m
.13431 .77657 L
s
1 .894 0 r
.008 w
.13431 .77657 Mdot
.016 w
.13431 .77657 m
.13413 .77643 L
s
1 .891 0 r
.008 w
.13413 .77643 Mdot
.016 w
.13413 .77643 m
.13387 .77621 L
s
1 .889 0 r
.008 w
.13387 .77621 Mdot
.016 w
.13387 .77621 m
.13361 .77596 L
s
1 .886 0 r
.008 w
.13361 .77596 Mdot
.016 w
.13361 .77596 m
.13336 .77578 L
s
1 .883 0 r
.008 w
.13336 .77578 Mdot
.016 w
.13336 .77578 m
.13319 .77575 L
s
1 .88 0 r
.008 w
.13319 .77575 Mdot
.016 w
.13319 .77575 m
.13309 .77592 L
s
1 .877 0 r
.008 w
.13309 .77592 Mdot
.016 w
.13309 .77592 m
.13308 .77631 L
s
1 .875 0 r
.008 w
.13308 .77631 Mdot
.016 w
.13308 .77631 m
.13322 .77685 L
s
1 .872 0 r
.008 w
.13322 .77685 Mdot
.016 w
.13322 .77685 m
.13362 .77754 L
s
1 .869 0 r
.008 w
.13362 .77754 Mdot
.016 w
.13362 .77754 m
.13443 .77838 L
s
1 .866 0 r
.008 w
.13443 .77838 Mdot
.016 w
.13443 .77838 m
.13532 .77923 L
s
1 .864 0 r
.008 w
.13532 .77923 Mdot
.016 w
.13532 .77923 m
.13666 .78017 L
s
1 .861 0 r
.008 w
.13666 .78017 Mdot
.016 w
.13666 .78017 m
.13819 .78117 L
s
1 .858 0 r
.008 w
.13819 .78117 Mdot
.016 w
.13819 .78117 m
.13996 .78221 L
s
1 .855 0 r
.008 w
.13996 .78221 Mdot
.016 w
.13996 .78221 m
.14183 .78327 L
s
1 .852 0 r
.008 w
.14183 .78327 Mdot
.016 w
.14183 .78327 m
.14384 .78428 L
s
1 .85 0 r
.008 w
.14384 .78428 Mdot
.016 w
.14384 .78428 m
.1458 .78524 L
s
1 .847 0 r
.008 w
.1458 .78524 Mdot
.016 w
.1458 .78524 m
.14777 .78611 L
s
1 .844 0 r
.008 w
.14777 .78611 Mdot
.016 w
.14777 .78611 m
.14977 .78688 L
s
1 .841 0 r
.008 w
.14977 .78688 Mdot
.016 w
.14977 .78688 m
.15167 .78753 L
s
1 .838 0 r
.008 w
.15167 .78753 Mdot
.016 w
.15167 .78753 m
.15346 .78806 L
s
1 .836 0 r
.008 w
.15346 .78806 Mdot
.016 w
.15346 .78806 m
.15507 .7885 L
s
1 .833 0 r
.008 w
.15507 .7885 Mdot
.016 w
.15507 .7885 m
.15643 .78887 L
s
1 .83 0 r
.008 w
.15643 .78887 Mdot
.016 w
.15643 .78887 m
.15753 .78917 L
s
1 .827 0 r
.008 w
.15753 .78917 Mdot
.016 w
.15753 .78917 m
.15846 .78948 L
s
1 .825 0 r
.008 w
.15846 .78948 Mdot
.016 w
.15846 .78948 m
.15907 .78972 L
s
1 .822 0 r
.008 w
.15907 .78972 Mdot
.016 w
.15907 .78972 m
.15956 .79003 L
s
1 .819 0 r
.008 w
.15956 .79003 Mdot
.016 w
.15956 .79003 m
.15993 .79039 L
s
1 .816 0 r
.008 w
.15993 .79039 Mdot
.016 w
.15993 .79039 m
.16021 .79082 L
s
1 .813 0 r
.008 w
.16021 .79082 Mdot
.016 w
.16021 .79082 m
.16042 .79137 L
s
1 .811 0 r
.008 w
.16042 .79137 Mdot
.016 w
.16042 .79137 m
.16064 .79204 L
s
1 .808 0 r
.008 w
.16064 .79204 Mdot
.016 w
.16064 .79204 m
.16086 .79291 L
s
1 .805 0 r
.008 w
.16086 .79291 Mdot
.016 w
.16086 .79291 m
.16112 .79387 L
s
1 .802 0 r
.008 w
.16112 .79387 Mdot
.016 w
.16112 .79387 m
.16142 .79513 L
s
1 .799 0 r
.008 w
.16142 .79513 Mdot
.016 w
.16142 .79513 m
.16186 .79664 L
s
1 .797 0 r
.008 w
.16186 .79664 Mdot
.016 w
.16186 .79664 m
.16247 .79832 L
s
1 .794 0 r
.008 w
.16247 .79832 Mdot
.016 w
.16247 .79832 m
.16328 .80016 L
s
1 .791 0 r
.008 w
.16328 .80016 Mdot
.016 w
.16328 .80016 m
.16432 .80225 L
s
1 .788 0 r
.008 w
.16432 .80225 Mdot
.016 w
.16432 .80225 m
.16555 .80458 L
s
1 .786 0 r
.008 w
.16555 .80458 Mdot
.016 w
.16555 .80458 m
.16689 .80697 L
s
1 .783 0 r
.008 w
.16689 .80697 Mdot
.016 w
.16689 .80697 m
.16837 .80939 L
s
1 .78 0 r
.008 w
.16837 .80939 Mdot
.016 w
.16837 .80939 m
.17 .81197 L
s
1 .777 0 r
.008 w
.17 .81197 Mdot
.016 w
.17 .81197 m
.17169 .81451 L
s
1 .774 0 r
.008 w
.17169 .81451 Mdot
.016 w
.17169 .81451 m
.17352 .81712 L
s
1 .772 0 r
.008 w
.17352 .81712 Mdot
.016 w
.17352 .81712 m
.17552 .81974 L
s
1 .769 0 r
.008 w
.17552 .81974 Mdot
.016 w
.17552 .81974 m
.17765 .82228 L
s
1 .766 0 r
.008 w
.17765 .82228 Mdot
.016 w
.17765 .82228 m
.17993 .82475 L
s
1 .763 0 r
.008 w
.17993 .82475 Mdot
.016 w
.17993 .82475 m
.18217 .82711 L
s
1 .76 0 r
.008 w
.18217 .82711 Mdot
.016 w
.18217 .82711 m
.18442 .82929 L
s
1 .758 0 r
.008 w
.18442 .82929 Mdot
.016 w
.18442 .82929 m
.18647 .83125 L
s
1 .755 0 r
.008 w
.18647 .83125 Mdot
.016 w
.18647 .83125 m
.18831 .83284 L
s
1 .752 0 r
.008 w
.18831 .83284 Mdot
.016 w
.18831 .83284 m
.18994 .83424 L
s
1 .749 0 r
.008 w
.18994 .83424 Mdot
.016 w
.18994 .83424 m
.19128 .83532 L
s
1 .747 0 r
.008 w
.19128 .83532 Mdot
.016 w
.19128 .83532 m
.19242 .8362 L
s
1 .744 0 r
.008 w
.19242 .8362 Mdot
.016 w
.19242 .8362 m
.19334 .8369 L
s
1 .741 0 r
.008 w
.19334 .8369 Mdot
.016 w
.19334 .8369 m
.19412 .83748 L
s
1 .738 0 r
.008 w
.19412 .83748 Mdot
.016 w
.19412 .83748 m
.19483 .83802 L
s
1 .735 0 r
.008 w
.19483 .83802 Mdot
.016 w
.19483 .83802 m
.19553 .83861 L
s
1 .733 0 r
.008 w
.19553 .83861 Mdot
.016 w
.19553 .83861 m
.19627 .83929 L
s
1 .73 0 r
.008 w
.19627 .83929 Mdot
.016 w
.19627 .83929 m
.19704 .84007 L
s
1 .727 0 r
.008 w
.19704 .84007 Mdot
.016 w
.19704 .84007 m
.19793 .84101 L
s
1 .724 0 r
.008 w
.19793 .84101 Mdot
.016 w
.19793 .84101 m
.19892 .84207 L
s
1 .721 0 r
.008 w
.19892 .84207 Mdot
.016 w
.19892 .84207 m
.20013 .84333 L
s
1 .719 0 r
.008 w
.20013 .84333 Mdot
.016 w
.20013 .84333 m
.20161 .84482 L
s
1 .716 0 r
.008 w
.20161 .84482 Mdot
.016 w
.20161 .84482 m
.2033 .84657 L
s
1 .713 0 r
.008 w
.2033 .84657 Mdot
.016 w
.2033 .84657 m
.20522 .84841 L
s
1 .71 0 r
.008 w
.20522 .84841 Mdot
.016 w
.20522 .84841 m
.20719 .85034 L
s
1 .708 0 r
.008 w
.20719 .85034 Mdot
.016 w
.20719 .85034 m
.20925 .85223 L
s
1 .705 0 r
.008 w
.20925 .85223 Mdot
.016 w
.20925 .85223 m
.21133 .8542 L
s
1 .702 0 r
.008 w
.21133 .8542 Mdot
.016 w
.21133 .8542 m
.21313 .85571 L
s
1 .699 0 r
.008 w
.21313 .85571 Mdot
.016 w
.21313 .85571 m
.21488 .85723 L
s
1 .696 0 r
.008 w
.21488 .85723 Mdot
.016 w
.21488 .85723 m
.21639 .85857 L
s
1 .694 0 r
.008 w
.21639 .85857 Mdot
.016 w
.21639 .85857 m
.2177 .85968 L
s
1 .691 0 r
.008 w
.2177 .85968 Mdot
.016 w
.2177 .85968 m
.21874 .86058 L
s
1 .688 0 r
.008 w
.21874 .86058 Mdot
.016 w
.21874 .86058 m
.21956 .86133 L
s
1 .685 0 r
.008 w
.21956 .86133 Mdot
.016 w
.21956 .86133 m
.22016 .86188 L
s
1 .682 0 r
.008 w
.22016 .86188 Mdot
.016 w
.22016 .86188 m
.22055 .86228 L
s
1 .68 0 r
.008 w
.22055 .86228 Mdot
.016 w
.22055 .86228 m
.22078 .86258 L
s
1 .677 0 r
.008 w
.22078 .86258 Mdot
.016 w
.22078 .86258 m
.22089 .8628 L
s
1 .674 0 r
.008 w
.22089 .8628 Mdot
.016 w
.22089 .8628 m
.22093 .863 L
s
1 .671 0 r
.008 w
.22093 .863 Mdot
.016 w
.22093 .863 m
.22097 .86321 L
s
1 .669 0 r
.008 w
.22097 .86321 Mdot
.016 w
.22097 .86321 m
.22107 .86346 L
s
1 .666 0 r
.008 w
.22107 .86346 Mdot
.016 w
.22107 .86346 m
.22128 .86378 L
s
1 .663 0 r
.008 w
.22128 .86378 Mdot
.016 w
.22128 .86378 m
.22161 .86416 L
s
1 .66 0 r
.008 w
.22161 .86416 Mdot
.016 w
.22161 .86416 m
.22209 .8646 L
s
1 .657 0 r
.008 w
.22209 .8646 Mdot
.016 w
.22209 .8646 m
.22271 .86508 L
s
1 .655 0 r
.008 w
.22271 .86508 Mdot
.016 w
.22271 .86508 m
.22343 .86559 L
s
1 .652 0 r
.008 w
.22343 .86559 Mdot
.016 w
.22343 .86559 m
.22418 .86611 L
s
1 .649 0 r
.008 w
.22418 .86611 Mdot
.016 w
.22418 .86611 m
.22495 .86654 L
s
1 .646 0 r
.008 w
.22495 .86654 Mdot
.016 w
.22495 .86654 m
.22572 .86698 L
s
1 .643 0 r
.008 w
.22572 .86698 Mdot
.016 w
.22572 .86698 m
.22644 .86734 L
s
1 .641 0 r
.008 w
.22644 .86734 Mdot
.016 w
.22644 .86734 m
.22704 .86761 L
s
1 .638 0 r
.008 w
.22704 .86761 Mdot
.016 w
.22704 .86761 m
.22753 .86778 L
s
1 .635 0 r
.008 w
.22753 .86778 Mdot
.016 w
.22753 .86778 m
.22788 .86787 L
s
1 .632 0 r
.008 w
.22788 .86787 Mdot
.016 w
.22788 .86787 m
.22811 .86791 L
s
1 .63 0 r
.008 w
.22811 .86791 Mdot
.016 w
.22811 .86791 m
.22823 .86791 L
s
1 .627 0 r
.008 w
.22823 .86791 Mdot
.016 w
.22823 .86791 m
.22828 .86791 L
s
1 .624 0 r
.008 w
.22828 .86791 Mdot
.016 w
.22828 .86791 m
.22833 .86796 L
s
1 .621 0 r
.008 w
.22833 .86796 Mdot
.016 w
.22833 .86796 m
.22848 .86812 L
s
1 .618 0 r
.008 w
.22848 .86812 Mdot
.016 w
.22848 .86812 m
.2288 .86843 L
s
1 .616 0 r
.008 w
.2288 .86843 Mdot
.016 w
.2288 .86843 m
.22934 .86891 L
s
1 .613 0 r
.008 w
.22934 .86891 Mdot
.016 w
.22934 .86891 m
.23013 .86957 L
s
1 .61 0 r
.008 w
.23013 .86957 Mdot
.016 w
.23013 .86957 m
.23117 .8704 L
s
1 .607 0 r
.008 w
.23117 .8704 Mdot
.016 w
.23117 .8704 m
.23242 .87144 L
s
1 .604 0 r
.008 w
.23242 .87144 Mdot
.016 w
.23242 .87144 m
.23397 .87264 L
s
1 .602 0 r
.008 w
.23397 .87264 Mdot
.016 w
.23397 .87264 m
.23579 .87403 L
s
1 .599 0 r
.008 w
.23579 .87403 Mdot
.016 w
.23579 .87403 m
.2377 .87554 L
s
1 .596 0 r
.008 w
.2377 .87554 Mdot
.016 w
.2377 .87554 m
.23976 .87712 L
s
1 .593 0 r
.008 w
.23976 .87712 Mdot
.016 w
.23976 .87712 m
.24184 .87872 L
s
1 .591 0 r
.008 w
.24184 .87872 Mdot
.016 w
.24184 .87872 m
.24387 .8802 L
s
1 .588 0 r
.008 w
.24387 .8802 Mdot
.016 w
.24387 .8802 m
.24574 .8815 L
s
1 .585 0 r
.008 w
.24574 .8815 Mdot
.016 w
.24574 .8815 m
.24752 .88286 L
s
1 .582 0 r
.008 w
.24752 .88286 Mdot
.016 w
.24752 .88286 m
.24918 .88419 L
s
1 .579 0 r
.008 w
.24918 .88419 Mdot
.016 w
.24918 .88419 m
.25059 .88545 L
s
1 .577 0 r
.008 w
.25059 .88545 Mdot
.016 w
.25059 .88545 m
.25188 .88667 L
s
1 .574 0 r
.008 w
.25188 .88667 Mdot
.016 w
.25188 .88667 m
.25292 .88775 L
s
1 .571 0 r
.008 w
.25292 .88775 Mdot
.016 w
.25292 .88775 m
.25389 .88875 L
s
1 .568 0 r
.008 w
.25389 .88875 Mdot
.016 w
.25389 .88875 m
.25454 .88965 L
s
1 .565 0 r
.008 w
.25454 .88965 Mdot
.016 w
.25454 .88965 m
.25513 .89044 L
s
1 .563 0 r
.008 w
.25513 .89044 Mdot
.016 w
.25513 .89044 m
.25566 .89109 L
s
1 .56 0 r
.008 w
.25566 .89109 Mdot
.016 w
.25566 .89109 m
.25604 .8918 L
s
1 .557 0 r
.008 w
.25604 .8918 Mdot
.016 w
.25604 .8918 m
.25644 .89253 L
s
1 .554 0 r
.008 w
.25644 .89253 Mdot
.016 w
.25644 .89253 m
.25686 .89332 L
s
1 .552 0 r
.008 w
.25686 .89332 Mdot
.016 w
.25686 .89332 m
.25737 .89418 L
s
1 .549 0 r
.008 w
.25737 .89418 Mdot
.016 w
.25737 .89418 m
.25793 .89499 L
s
1 .546 0 r
.008 w
.25793 .89499 Mdot
.016 w
.25793 .89499 m
.25865 .89585 L
s
1 .543 0 r
.008 w
.25865 .89585 Mdot
.016 w
.25865 .89585 m
.25952 .8967 L
s
1 .54 0 r
.008 w
.25952 .8967 Mdot
.016 w
.25952 .8967 m
.26064 .89751 L
s
1 .538 0 r
.008 w
.26064 .89751 Mdot
.016 w
.26064 .89751 m
.26166 .89829 L
s
1 .535 0 r
.008 w
.26166 .89829 Mdot
.016 w
.26166 .89829 m
.26298 .8991 L
s
1 .532 0 r
.008 w
.26298 .8991 Mdot
.016 w
.26298 .8991 m
.26445 .89995 L
s
1 .529 0 r
.008 w
.26445 .89995 Mdot
.016 w
.26445 .89995 m
.26613 .90089 L
s
1 .526 0 r
.008 w
.26613 .90089 Mdot
.016 w
.26613 .90089 m
.26807 .90194 L
s
1 .524 0 r
.008 w
.26807 .90194 Mdot
.016 w
.26807 .90194 m
.27026 .90308 L
s
1 .521 0 r
.008 w
.27026 .90308 Mdot
.016 w
.27026 .90308 m
.27261 .90425 L
s
1 .518 0 r
.008 w
.27261 .90425 Mdot
.016 w
.27261 .90425 m
.27497 .90535 L
s
1 .515 0 r
.008 w
.27497 .90535 Mdot
.016 w
.27497 .90535 m
.27731 .90641 L
s
1 .513 0 r
.008 w
.27731 .90641 Mdot
.016 w
.27731 .90641 m
.27963 .9074 L
s
1 .51 0 r
.008 w
.27963 .9074 Mdot
.016 w
.27963 .9074 m
.28169 .90833 L
s
1 .507 0 r
.008 w
.28169 .90833 Mdot
.016 w
.28169 .90833 m
.28357 .90914 L
s
1 .504 0 r
.008 w
.28357 .90914 Mdot
.016 w
.28357 .90914 m
.28502 .90983 L
s
1 .501 0 r
.008 w
.28502 .90983 Mdot
.016 w
.28502 .90983 m
.2862 .91045 L
s
1 .499 0 r
.008 w
.2862 .91045 Mdot
.016 w
.2862 .91045 m
.28716 .91097 L
s
1 .496 0 r
.008 w
.28716 .91097 Mdot
.016 w
.28716 .91097 m
.28791 .91133 L
s
1 .493 0 r
.008 w
.28791 .91133 Mdot
.016 w
.28791 .91133 m
.28844 .91151 L
s
1 .49 0 r
.008 w
.28844 .91151 Mdot
.016 w
.28844 .91151 m
.28882 .91152 L
s
1 .487 0 r
.008 w
.28882 .91152 Mdot
.016 w
.28882 .91152 m
.28907 .91136 L
s
1 .485 0 r
.008 w
.28907 .91136 Mdot
.016 w
.28907 .91136 m
.28928 .91109 L
s
1 .482 0 r
.008 w
.28928 .91109 Mdot
.016 w
.28928 .91109 m
.28958 .91076 L
s
1 .479 0 r
.008 w
.28958 .91076 Mdot
.016 w
.28958 .91076 m
.29005 .91043 L
s
1 .476 0 r
.008 w
.29005 .91043 Mdot
.016 w
.29005 .91043 m
.29068 .91015 L
s
1 .474 0 r
.008 w
.29068 .91015 Mdot
.016 w
.29068 .91015 m
.29154 .90991 L
s
1 .471 0 r
.008 w
.29154 .90991 Mdot
.016 w
.29154 .90991 m
.29252 .90971 L
s
1 .468 0 r
.008 w
.29252 .90971 Mdot
.016 w
.29252 .90971 m
.29367 .90955 L
s
1 .465 0 r
.008 w
.29367 .90955 Mdot
.016 w
.29367 .90955 m
.29491 .90936 L
s
1 .462 0 r
.008 w
.29491 .90936 Mdot
.016 w
.29491 .90936 m
.29619 .90915 L
s
1 .46 0 r
.008 w
.29619 .90915 Mdot
.016 w
.29619 .90915 m
.29738 .90891 L
s
1 .457 0 r
.008 w
.29738 .90891 Mdot
.016 w
.29738 .90891 m
.29838 .90864 L
s
1 .454 0 r
.008 w
.29838 .90864 Mdot
.016 w
.29838 .90864 m
.29914 .90833 L
s
1 .451 0 r
.008 w
.29914 .90833 Mdot
.016 w
.29914 .90833 m
.29964 .908 L
s
1 .448 0 r
.008 w
.29964 .908 Mdot
.016 w
.29964 .908 m
.29994 .9077 L
s
1 .446 0 r
.008 w
.29994 .9077 Mdot
.016 w
.29994 .9077 m
.30008 .90749 L
s
1 .443 0 r
.008 w
.30008 .90749 Mdot
.016 w
.30008 .90749 m
.30008 .90739 L
s
1 .44 0 r
.008 w
.30008 .90739 Mdot
.016 w
.30008 .90739 m
.29994 .90736 L
s
1 .437 0 r
.008 w
.29994 .90736 Mdot
.016 w
.29994 .90736 m
.29986 .90744 L
s
1 .435 0 r
.008 w
.29986 .90744 Mdot
.016 w
.29986 .90744 m
.29989 .90768 L
s
1 .432 0 r
.008 w
.29989 .90768 Mdot
.016 w
.29989 .90768 m
.30014 .90803 L
s
1 .429 0 r
.008 w
.30014 .90803 Mdot
.016 w
.30014 .90803 m
.30065 .90855 L
s
1 .426 0 r
.008 w
.30065 .90855 Mdot
.016 w
.30065 .90855 m
.30153 .90936 L
s
1 .423 0 r
.008 w
.30153 .90936 Mdot
.016 w
.30153 .90936 m
.3028 .91042 L
s
1 .421 0 r
.008 w
.3028 .91042 Mdot
.016 w
.3028 .91042 m
.30455 .9117 L
s
1 .418 0 r
.008 w
.30455 .9117 Mdot
.016 w
.30455 .9117 m
.30663 .91313 L
s
1 .415 0 r
.008 w
.30663 .91313 Mdot
.016 w
.30663 .91313 m
.30922 .91467 L
s
1 .412 0 r
.008 w
.30922 .91467 Mdot
.016 w
.30922 .91467 m
.31199 .91634 L
s
1 .409 0 r
.008 w
.31199 .91634 Mdot
.016 w
.31199 .91634 m
.31519 .9181 L
s
1 .407 0 r
.008 w
.31519 .9181 Mdot
.016 w
.31519 .9181 m
.31838 .91987 L
s
1 .404 0 r
.008 w
.31838 .91987 Mdot
.016 w
.31838 .91987 m
.32183 .9216 L
s
1 .401 0 r
.008 w
.32183 .9216 Mdot
.016 w
.32183 .9216 m
.32519 .92327 L
s
1 .398 0 r
.008 w
.32519 .92327 Mdot
.016 w
.32519 .92327 m
.32863 .92483 L
s
1 .396 0 r
.008 w
.32863 .92483 Mdot
.016 w
.32863 .92483 m
.33204 .9262 L
s
1 .393 0 r
.008 w
.33204 .9262 Mdot
.016 w
.33204 .9262 m
.33545 .92749 L
s
1 .39 0 r
.008 w
.33545 .92749 Mdot
.016 w
.33545 .92749 m
.33855 .92862 L
s
1 .387 0 r
.008 w
.33855 .92862 Mdot
.016 w
.33855 .92862 m
.34169 .92965 L
s
1 .384 0 r
.008 w
.34169 .92965 Mdot
.016 w
.34169 .92965 m
.34475 .93058 L
s
1 .382 0 r
.008 w
.34475 .93058 Mdot
.016 w
.34475 .93058 m
.34774 .93143 L
s
1 .379 0 r
.008 w
.34774 .93143 Mdot
.016 w
.34774 .93143 m
.35061 .93223 L
s
1 .376 0 r
.008 w
.35061 .93223 Mdot
.016 w
.35061 .93223 m
.35341 .93297 L
s
1 .373 0 r
.008 w
.35341 .93297 Mdot
.016 w
.35341 .93297 m
.35611 .93368 L
s
1 .37 0 r
.008 w
.35611 .93368 Mdot
.016 w
.35611 .93368 m
.35882 .93439 L
s
1 .368 0 r
.008 w
.35882 .93439 Mdot
.016 w
.35882 .93439 m
.36149 .93508 L
s
1 .365 0 r
.008 w
.36149 .93508 Mdot
.016 w
.36149 .93508 m
.36403 .93581 L
s
1 .362 0 r
.008 w
.36403 .93581 Mdot
.016 w
.36403 .93581 m
.36656 .93657 L
s
1 .359 0 r
.008 w
.36656 .93657 Mdot
.016 w
.36656 .93657 m
.36905 .93738 L
s
1 .357 0 r
.008 w
.36905 .93738 Mdot
.016 w
.36905 .93738 m
.37135 .93822 L
s
1 .354 0 r
.008 w
.37135 .93822 Mdot
.016 w
.37135 .93822 m
.37348 .93906 L
s
1 .351 0 r
.008 w
.37348 .93906 Mdot
.016 w
.37348 .93906 m
.37536 .93983 L
s
1 .348 0 r
.008 w
.37536 .93983 Mdot
.016 w
.37536 .93983 m
.37692 .94053 L
s
1 .345 0 r
.008 w
.37692 .94053 Mdot
.016 w
.37692 .94053 m
.37818 .94111 L
s
1 .343 0 r
.008 w
.37818 .94111 Mdot
.016 w
.37818 .94111 m
.37918 .94157 L
s
1 .34 0 r
.008 w
.37918 .94157 Mdot
.016 w
.37918 .94157 m
.37992 .94185 L
s
1 .337 0 r
.008 w
.37992 .94185 Mdot
.016 w
.37992 .94185 m
.38049 .94198 L
s
1 .334 0 r
.008 w
.38049 .94198 Mdot
.016 w
.38049 .94198 m
.38093 .94196 L
s
1 .331 0 r
.008 w
.38093 .94196 Mdot
.016 w
.38093 .94196 m
.38132 .94176 L
s
1 .329 0 r
.008 w
.38132 .94176 Mdot
.016 w
.38132 .94176 m
.38176 .94138 L
s
1 .326 0 r
.008 w
.38176 .94138 Mdot
.016 w
.38176 .94138 m
.38234 .94083 L
s
1 .323 0 r
.008 w
.38234 .94083 Mdot
.016 w
.38234 .94083 m
.3831 .94016 L
s
1 .32 0 r
.008 w
.3831 .94016 Mdot
.016 w
.3831 .94016 m
.384 .93937 L
s
1 .318 0 r
.008 w
.384 .93937 Mdot
.016 w
.384 .93937 m
.38514 .93847 L
s
1 .315 0 r
.008 w
.38514 .93847 Mdot
.016 w
.38514 .93847 m
.38639 .93749 L
s
1 .312 0 r
.008 w
.38639 .93749 Mdot
.016 w
.38639 .93749 m
.38775 .93649 L
s
1 .309 0 r
.008 w
.38775 .93649 Mdot
.016 w
.38775 .93649 m
.38919 .93553 L
s
1 .306 0 r
.008 w
.38919 .93553 Mdot
.016 w
.38919 .93553 m
.39067 .93454 L
s
1 .304 0 r
.008 w
.39067 .93454 Mdot
.016 w
.39067 .93454 m
.39208 .93391 L
s
1 .301 0 r
.008 w
.39208 .93391 Mdot
.016 w
.39208 .93391 m
.39333 .93323 L
s
1 .298 0 r
.008 w
.39333 .93323 Mdot
.016 w
.39333 .93323 m
.39431 .93275 L
s
1 .295 0 r
.008 w
.39431 .93275 Mdot
.016 w
.39431 .93275 m
.39501 .93247 L
s
1 .292 0 r
.008 w
.39501 .93247 Mdot
.016 w
.39501 .93247 m
.39543 .93243 L
s
1 .29 0 r
.008 w
.39543 .93243 Mdot
.016 w
.39543 .93243 m
.39559 .9326 L
s
1 .287 0 r
.008 w
.39559 .9326 Mdot
.016 w
.39559 .9326 m
.39548 .93295 L
s
1 .284 0 r
.008 w
.39548 .93295 Mdot
.016 w
.39548 .93295 m
.39519 .93344 L
s
1 .281 0 r
.008 w
.39519 .93344 Mdot
.016 w
.39519 .93344 m
.39485 .93408 L
s
1 .279 0 r
.008 w
.39485 .93408 Mdot
.016 w
.39485 .93408 m
.39454 .93483 L
s
1 .276 0 r
.008 w
.39454 .93483 Mdot
.016 w
.39454 .93483 m
.39434 .93556 L
s
1 .273 0 r
.008 w
.39434 .93556 Mdot
.016 w
.39434 .93556 m
.39432 .93621 L
s
1 .27 0 r
.008 w
.39432 .93621 Mdot
.016 w
.39432 .93621 m
.39453 .93676 L
s
1 .267 0 r
.008 w
.39453 .93676 Mdot
.016 w
.39453 .93676 m
.39498 .93727 L
s
1 .265 0 r
.008 w
.39498 .93727 Mdot
.016 w
.39498 .93727 m
.39564 .93772 L
s
1 .262 0 r
.008 w
.39564 .93772 Mdot
.016 w
.39564 .93772 m
.39649 .93809 L
s
1 .259 0 r
.008 w
.39649 .93809 Mdot
.016 w
.39649 .93809 m
.39735 .93845 L
s
1 .256 0 r
.008 w
.39735 .93845 Mdot
.016 w
.39735 .93845 m
.39822 .93886 L
s
1 .253 0 r
.008 w
.39822 .93886 Mdot
.016 w
.39822 .93886 m
.399 .93927 L
s
1 .251 0 r
.008 w
.399 .93927 Mdot
.016 w
.399 .93927 m
.39964 .93967 L
s
1 .248 0 r
.008 w
.39964 .93967 Mdot
.016 w
.39964 .93967 m
.40006 .94008 L
s
1 .245 0 r
.008 w
.40006 .94008 Mdot
.016 w
.40006 .94008 m
.40026 .94049 L
s
1 .242 0 r
.008 w
.40026 .94049 Mdot
.016 w
.40026 .94049 m
.40026 .94075 L
s
1 .24 0 r
.008 w
.40026 .94075 Mdot
.016 w
.40026 .94075 m
.40011 .94091 L
s
1 .237 0 r
.008 w
.40011 .94091 Mdot
.016 w
.40011 .94091 m
.39982 .94089 L
s
1 .234 0 r
.008 w
.39982 .94089 Mdot
.016 w
.39982 .94089 m
.39945 .94071 L
s
1 .231 0 r
.008 w
.39945 .94071 Mdot
.016 w
.39945 .94071 m
.39886 .94035 L
s
1 .228 0 r
.008 w
.39886 .94035 Mdot
.016 w
.39886 .94035 m
.39838 .93966 L
s
1 .226 0 r
.008 w
.39838 .93966 Mdot
.016 w
.39838 .93966 m
.39781 .9388 L
s
1 .223 0 r
.008 w
.39781 .9388 Mdot
.016 w
.39781 .9388 m
.39728 .93792 L
s
1 .22 0 r
.008 w
.39728 .93792 Mdot
.016 w
.39728 .93792 m
.39682 .9367 L
s
1 .217 0 r
.008 w
.39682 .9367 Mdot
.016 w
.39682 .9367 m
.39651 .9354 L
s
1 .214 0 r
.008 w
.39651 .9354 Mdot
.016 w
.39651 .9354 m
.39635 .93391 L
s
1 .212 0 r
.008 w
.39635 .93391 Mdot
.016 w
.39635 .93391 m
.39631 .93258 L
s
1 .209 0 r
.008 w
.39631 .93258 Mdot
.016 w
.39631 .93258 m
.39634 .93132 L
s
1 .206 0 r
.008 w
.39634 .93132 Mdot
.016 w
.39634 .93132 m
.39639 .9303 L
s
1 .203 0 r
.008 w
.39639 .9303 Mdot
.016 w
.39639 .9303 m
.39643 .92954 L
s
1 .201 0 r
.008 w
.39643 .92954 Mdot
.016 w
.39643 .92954 m
.39639 .92906 L
s
1 .198 0 r
.008 w
.39639 .92906 Mdot
.016 w
.39639 .92906 m
.39623 .9288 L
s
1 .195 0 r
.008 w
.39623 .9288 Mdot
.016 w
.39623 .9288 m
.39594 .9288 L
s
1 .192 0 r
.008 w
.39594 .9288 Mdot
.016 w
.39594 .9288 m
.39558 .9291 L
s
1 .189 0 r
.008 w
.39558 .9291 Mdot
.016 w
.39558 .9291 m
.39518 .92963 L
s
1 .187 0 r
.008 w
.39518 .92963 Mdot
.016 w
.39518 .92963 m
.3948 .93032 L
s
1 .184 0 r
.008 w
.3948 .93032 Mdot
.016 w
.3948 .93032 m
.39446 .93114 L
s
1 .181 0 r
.008 w
.39446 .93114 Mdot
.016 w
.39446 .93114 m
.39423 .93211 L
s
1 .178 0 r
.008 w
.39423 .93211 Mdot
.016 w
.39423 .93211 m
.39411 .93317 L
s
1 .175 0 r
.008 w
.39411 .93317 Mdot
.016 w
.39411 .93317 m
.39413 .93435 L
s
1 .173 0 r
.008 w
.39413 .93435 Mdot
.016 w
.39413 .93435 m
.39431 .93559 L
s
1 .17 0 r
.008 w
.39431 .93559 Mdot
.016 w
.39431 .93559 m
.39467 .93689 L
s
1 .167 0 r
.008 w
.39467 .93689 Mdot
.016 w
.39467 .93689 m
.39524 .9383 L
s
1 .164 0 r
.008 w
.39524 .9383 Mdot
.016 w
.39524 .9383 m
.39602 .93978 L
s
1 .162 0 r
.008 w
.39602 .93978 Mdot
.016 w
.39602 .93978 m
.39699 .94131 L
s
1 .159 0 r
.008 w
.39699 .94131 Mdot
.016 w
.39699 .94131 m
.39818 .94286 L
s
1 .156 0 r
.008 w
.39818 .94286 Mdot
.016 w
.39818 .94286 m
.39961 .94439 L
s
1 .153 0 r
.008 w
.39961 .94439 Mdot
.016 w
.39961 .94439 m
.40123 .94594 L
s
1 .15 0 r
.008 w
.40123 .94594 Mdot
.016 w
.40123 .94594 m
.40309 .94748 L
s
1 .148 0 r
.008 w
.40309 .94748 Mdot
.016 w
.40309 .94748 m
.40509 .94898 L
s
1 .145 0 r
.008 w
.40509 .94898 Mdot
.016 w
.40509 .94898 m
.40734 .95049 L
s
1 .142 0 r
.008 w
.40734 .95049 Mdot
.016 w
.40734 .95049 m
.40986 .95191 L
s
1 .139 0 r
.008 w
.40986 .95191 Mdot
.016 w
.40986 .95191 m
.41241 .95317 L
s
1 .136 0 r
.008 w
.41241 .95317 Mdot
.016 w
.41241 .95317 m
.41515 .95433 L
s
1 .134 0 r
.008 w
.41515 .95433 Mdot
.016 w
.41515 .95433 m
.41805 .95544 L
s
1 .131 0 r
.008 w
.41805 .95544 Mdot
.016 w
.41805 .95544 m
.42099 .95652 L
s
1 .128 0 r
.008 w
.42099 .95652 Mdot
.016 w
.42099 .95652 m
.42394 .95753 L
s
1 .125 0 r
.008 w
.42394 .95753 Mdot
.016 w
.42394 .95753 m
.42675 .95851 L
s
1 .123 0 r
.008 w
.42675 .95851 Mdot
.016 w
.42675 .95851 m
.42957 .95943 L
s
1 .12 0 r
.008 w
.42957 .95943 Mdot
.016 w
.42957 .95943 m
.43222 .96028 L
s
1 .117 0 r
.008 w
.43222 .96028 Mdot
.016 w
.43222 .96028 m
.43474 .96105 L
s
1 .114 0 r
.008 w
.43474 .96105 Mdot
.016 w
.43474 .96105 m
.43688 .96172 L
s
1 .111 0 r
.008 w
.43688 .96172 Mdot
.016 w
.43688 .96172 m
.43881 .96225 L
s
1 .109 0 r
.008 w
.43881 .96225 Mdot
.016 w
.43881 .96225 m
.44052 .96263 L
s
1 .106 0 r
.008 w
.44052 .96263 Mdot
.016 w
.44052 .96263 m
.442 .96293 L
s
1 .103 0 r
.008 w
.442 .96293 Mdot
.016 w
.442 .96293 m
.44333 .9632 L
s
1 .1 0 r
.008 w
.44333 .9632 Mdot
.016 w
.44333 .9632 m
.44454 .96349 L
s
1 .097 0 r
.008 w
.44454 .96349 Mdot
.016 w
.44454 .96349 m
.44575 .96379 L
s
1 .095 0 r
.008 w
.44575 .96379 Mdot
.016 w
.44575 .96379 m
.4468 .96406 L
s
1 .092 0 r
.008 w
.4468 .96406 Mdot
.016 w
.4468 .96406 m
.44799 .96429 L
s
1 .089 0 r
.008 w
.44799 .96429 Mdot
.016 w
.44799 .96429 m
.44926 .96447 L
s
1 .086 0 r
.008 w
.44926 .96447 Mdot
.016 w
.44926 .96447 m
.45057 .96452 L
s
1 .084 0 r
.008 w
.45057 .96452 Mdot
.016 w
.45057 .96452 m
.45199 .96446 L
s
1 .081 0 r
.008 w
.45199 .96446 Mdot
.016 w
.45199 .96446 m
.45351 .96429 L
s
1 .078 0 r
.008 w
.45351 .96429 Mdot
.016 w
.45351 .96429 m
.45502 .96409 L
s
1 .075 0 r
.008 w
.45502 .96409 Mdot
.016 w
.45502 .96409 m
.45655 .96394 L
s
1 .072 0 r
.008 w
.45655 .96394 Mdot
.016 w
.45655 .96394 m
.45806 .96391 L
s
1 .07 0 r
.008 w
.45806 .96391 Mdot
.016 w
.45806 .96391 m
.45957 .96399 L
s
1 .067 0 r
.008 w
.45957 .96399 Mdot
.016 w
.45957 .96399 m
.46103 .96415 L
s
1 .064 0 r
.008 w
.46103 .96415 Mdot
.016 w
.46103 .96415 m
.46253 .96425 L
s
1 .061 0 r
.008 w
.46253 .96425 Mdot
.016 w
.46253 .96425 m
.46407 .96433 L
s
1 .058 0 r
.008 w
.46407 .96433 Mdot
.016 w
.46407 .96433 m
.46568 .96443 L
s
1 .056 0 r
.008 w
.46568 .96443 Mdot
.016 w
.46568 .96443 m
.46738 .96455 L
s
1 .053 0 r
.008 w
.46738 .96455 Mdot
.016 w
.46738 .96455 m
.46915 .96468 L
s
1 .05 0 r
.008 w
.46915 .96468 Mdot
.016 w
.46915 .96468 m
.47098 .96483 L
s
1 .047 0 r
.008 w
.47098 .96483 Mdot
.016 w
.47098 .96483 m
.47301 .96504 L
s
1 .045 0 r
.008 w
.47301 .96504 Mdot
.016 w
.47301 .96504 m
.47515 .9653 L
s
1 .042 0 r
.008 w
.47515 .9653 Mdot
.016 w
.47515 .9653 m
.47741 .96557 L
s
1 .039 0 r
.008 w
.47741 .96557 Mdot
.016 w
.47741 .96557 m
.47972 .96578 L
s
1 .036 0 r
.008 w
.47972 .96578 Mdot
.016 w
.47972 .96578 m
.48213 .96588 L
s
1 .033 0 r
.008 w
.48213 .96588 Mdot
.016 w
.48213 .96588 m
.48457 .96583 L
s
1 .031 0 r
.008 w
.48457 .96583 Mdot
.016 w
.48457 .96583 m
.48707 .96566 L
s
1 .028 0 r
.008 w
.48707 .96566 Mdot
.016 w
.48707 .96566 m
.48989 .96543 L
s
1 .025 0 r
.008 w
.48989 .96543 Mdot
.016 w
.48989 .96543 m
.49223 .96524 L
s
1 .022 0 r
.008 w
.49223 .96524 Mdot
.016 w
.49223 .96524 m
.49468 .96506 L
s
1 .019 0 r
.008 w
.49468 .96506 Mdot
.016 w
.49468 .96506 m
.49698 .96491 L
s
1 .017 0 r
.008 w
.49698 .96491 Mdot
.016 w
.49698 .96491 m
.49903 .96482 L
s
1 .014 0 r
.008 w
.49903 .96482 Mdot
.016 w
.49903 .96482 m
.50067 .96478 L
s
1 .011 0 r
.008 w
.50067 .96478 Mdot
.016 w
.50067 .96478 m
.50191 .96478 L
s
1 .008 0 r
.008 w
.50191 .96478 Mdot
.016 w
.50191 .96478 m
.50268 .96479 L
s
1 .006 0 r
.008 w
.50268 .96479 Mdot
.016 w
.50268 .96479 m
.50317 .96478 L
s
1 .003 0 r
.008 w
.50317 .96478 Mdot
.016 w
.50317 .96478 m
.5034 .96476 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4
?Nl=Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`@mk`eoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo13g_3Goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo13g_4goo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_lgoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool5?NocOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Dmko5oo`03001oogoo00io
o`003goo00<007ooOol01goo1Cg_lGoo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4?NobOol0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`@mko9oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo13g_lWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool4?NoaOol00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`@mko5oo`03001oogoo00moo`0047oo00<007ooOol01Woo13g_lGoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Dm
ko1oo`03001oogoo00moo`004Goo00<007ooOol01Woo13g_kgoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool4?No_Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool4?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`05Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`Dm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`05Ool4?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`@mknQoo`03001oogoo01Ao
o`005Woo00<007ooOol017oo13g_igoo00<007ooOol05Goo000FOol00`00Oomoo`04Ool4?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo00=oo`@mknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0goo1Cg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo00=oo`@mknAoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Cg_hgoo00<007oo
Ool05goo000IOol00`00Oomoo`02Ool6?NoQOol00`00Oomoo`0HOol001Yoo`04001oogooOol6?NoQ
Ool00`00Oomoo`0HOol001Yoo`04001oogooOol6?NoPOol00`00Oomoo`0IOol001]oo`04001oogoo
Ool5?NoOOol00`00Oomoo`0JOol001]oo`03001oogoo009oo`@mkmmoo`03001oogoo01Yoo`0077oo
00@007ooOomoo`@mkmioo`03001oogoo01]oo`0077oo00@007ooOomoo`@mkmioo`03001oogoo01]o
o`007Goo00<007ooOol013g_gGoo00<007ooOol077oo000MOol00`00Oomoo`04On3MOol00`00Oomo
o`0LOol001ioo`03001oogoP009oh003Ol1oh7oo0=Yoo`03001oogoo01eoo`007Woo00@007ooOn1o
h0=o`=]oo`03001oogoo01eoo`007goo00<007oPOl0017o0fGoo00<007ooOol07Woo000OOol00`00
On1o`005Ol3HOol00`00Oomoo`0NOol0021oo`03001oh7o000=o`003Oj1oogoo0=Eoo`03001oogoo
01moo`0087oo00<007ooOl000Wo00gnPeWoo00<007ooOol07goo000QOol00`00Ol1o`005Oj3DOol0
0`00Oomoo`0POol0029oo`03001o`7nP00EoX=9oo`03001oogoo025oo`008goo00<007ooOj001GnP
d7oo00<007ooOol08Woo000TOol01000Oj1oX7nP17n0cWoo00<007ooOol08goo000TOol01000Oj1o
X7nP1GmPcGoo00<007ooOol08goo000UOol00`00Oj1oX007Of3:Ool00`00Oomoo`0TOol002Ioo`03
001oX7mP00MoH<Qoo`03001oogoo02Eoo`009Woo00<007ooOf0017mP1gm0a7oo00<007ooOol09Goo
000WOol00`00OomoH003Of03Od04Ob33Ool00`00Oomoo`0VOol002Qoo`03001oogoo009oH0=o@0Ao
8<9oo`03001oogoo02Moo`00:Goo00@007ooOomoo`=o@0Eo8<1oo`03001oogoo02Qoo`00:Woo00<0
07ooOol00goo1GlP_goo00<007ooOol0:Goo000ZOol00`00Oomoo`03Ool4Ob000gl0Ob1oo`2mOol0
0`00Oomoo`0YOol002]oo`03001oogoo009oo`=o80=o0003Ob1oogoo0;Yoo`03001oogoo02Yoo`00
;7oo00<007ooOol00Woo00=o87l0O`000gl0^goo00<007ooOol0:goo000]Ool00`00Oomoo`02Ool6
O`2iOol00`00Oomoo`0/Ool002ioo`05001oogooOomo8005O`2hOol00`00Oomoo`0]Ool002ioo`03
001oogoo009oo`Io0;Moo`03001oogoo02eoo`00;goo00@007ooOomoo`Mo0;Eoo`03001oogoo02io
o`00<7oo00<007ooOol00Woo1Wl0/goo00<007ooOol0;goo000aOol00`00Oomoo`02Ool2O`05O^2`
Ool00`00Oomoo`0`Ool0039oo`8000=oo`03O`1nh7kP00=nh003O/1oogoo0:]oo`8003=oo`00=7oo
00@007ooOomoo`Anh0=n`:]oo`03001oogoo03=oo`00=Goo00<007ooOol00gkP1Gk0ZGoo00<007oo
Ool0=7oo000eOol01000Oomoogoo0WkP1Wk0Z7oo00<007ooOol0=7oo000fOol01000Oomoogoo0WkP
1Wk0YWoo00<007ooOol0=Goo000gOol00`00Oomoo`03Ool6O/2TOol00`00Oomoo`0fOol003Qoo`03
001oogoo00=oo`9n`0=nX003OX1oogoo0:1oo`03001oogoo03Moo`00>Goo0P0017oo00=n`7jPOZ00
0Wj00WiPWWoo0P00>Woo000kOol01`00OomoogooO/1nX7j000EnH9aoo`03001oogoo03Yoo`00?7oo
00H007ooOomn`7jPOX06OV2JOol00`00Oomoo`0kOol003eoo`03001oogoo009nX0AnH0An@9Moo`03
001oogoo03aoo`00?Woo0P000Woo17iP1Gi0U7oo0P00?goo0010Ool00`00Oomoo`02Ool00giPOT1n
@004OT2BOol00`00Oomoo`0oOol0045oo`80009oo`03OV1n@7i000En@8moo`80049oo`00@goo00<0
07ooOol017i017hPSGoo00<007ooOol0@Woo0014Ool00`00Oomoo`03OT05OR2;Ool00`00Oomoo`13
Ool004Eoo`05001oogooOomn@006OR000gh0Oomoo`26Ool00`00Oomoo`14Ool004Ioo`800004Oomn
@7hPOR06OP25Ool20017Ool004Qoo`80009n80Qn0003ON1oogoo009m`7aoo`8004Uoo`00BWoo00<0
07hPOP001Wh000=mh7g0OL001GfPN7oo0P00Bgoo001<Ool6OP02ON02OL06OJ1eOol2001=Ool004io
o`04001n07h0OP02ON02OL07OJ000gf0Oomoo`1`Ool00`00Oomoo`1=Ool004moo`05001n07h0OP1m
h002OL06OJ03OH000gooOH1oo`1]Ool00`00Oomoo`1>Ool0051oo`800003Oommh7gP009mh0AmX0Mm
P003OommP7oo06Qoo`80055oo`00DWoo0P001Woo00=mX7f0OH0027f000=oogf0Ool0Hgoo0P00Dgoo
001DOol20004Ool2OJ0<OH08Ool4O:000gc0Oomoo`1BOol2001EOol005Ioo`8000Aoo`UmP0QmH09o
o`03OB1lX7bP009lX003O<1oogoo051oo`8005Moo`00F7oo0`0017oo1Wf027eP00=m@7dPOB0017bP
00=l`7ooOol0CGoo0`00FGoo001KOol30004Ool3OH07OF02OD02OB000gbPO81lP002O8000gcPOomo
o`19Ool3001LOol005ioo`8000Eoo`MmH0=m@003OB1lX7b000AlP4Qoo`<005moo`00H7oo0P001Woo
17eP17e000=lX7b0O8001Gb0AGoo00<007ooOol0H7oo001ROol30006Ool00gePOD1m@002OD000gbP
O81lP006O8000gooO61oo`0nOol3001SOol006Eoo`<000Uoo`QlP0=lH003OomlH7oo03Qoo`<006Io
o`00J7oo10001Woo1Wb01gaP3Woo0W`097oo1000JGoo001/Ool40004Ool4O806O605O407O202Ool6
O00MOol4001]Ool0071oo`<000=oo`=lP0ElH0El@0Il80Ul01Uoo`@0075oo`00Lgoo1@0000=oogaP
O6000gaP1Ga01W`P2G`05Goo1000MGoo001hOol40002O605O406O209O00>Ool7001iOol007moo`L0
00=l80Il00=oo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo002;Ool20003Ool4002<Ool008Yoo`04001oogoo0002Ool00`00Oomoo`2=Ool008eoo`05001o
ogooOol0002>Ool008]oo`8000Eoo`03001oogoo08]oo`00Rgoo00<007ooOol00Woo00@007ooOol0
08aoo`00Rgoo0`000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(53)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
1 .997 0 r
.008 w
.50259 .95646 Mdot
.016 w
.50259 .95646 m
.50249 .95652 L
s
1 .993 0 r
.008 w
.50249 .95652 Mdot
.016 w
.50249 .95652 m
.50229 .95668 L
s
1 .99 0 r
.008 w
.50229 .95668 Mdot
.016 w
.50229 .95668 m
.50194 .95681 L
s
1 .986 0 r
.008 w
.50194 .95681 Mdot
.016 w
.50194 .95681 m
.50141 .95684 L
s
1 .983 0 r
.008 w
.50141 .95684 Mdot
.016 w
.50141 .95684 m
.50068 .95683 L
s
1 .979 0 r
.008 w
.50068 .95683 Mdot
.016 w
.50068 .95683 m
.49969 .95681 L
s
1 .976 0 r
.008 w
.49969 .95681 Mdot
.016 w
.49969 .95681 m
.49843 .95679 L
s
1 .972 0 r
.008 w
.49843 .95679 Mdot
.016 w
.49843 .95679 m
.49695 .95681 L
s
1 .969 0 r
.008 w
.49695 .95681 Mdot
.016 w
.49695 .95681 m
.49526 .9569 L
s
1 .965 0 r
.008 w
.49526 .9569 Mdot
.016 w
.49526 .9569 m
.49344 .95708 L
s
1 .962 0 r
.008 w
.49344 .95708 Mdot
.016 w
.49344 .95708 m
.49134 .95728 L
s
1 .958 0 r
.008 w
.49134 .95728 Mdot
.016 w
.49134 .95728 m
.48889 .95747 L
s
1 .955 0 r
.008 w
.48889 .95747 Mdot
.016 w
.48889 .95747 m
.48663 .95761 L
s
1 .952 0 r
.008 w
.48663 .95761 Mdot
.016 w
.48663 .95761 m
.48413 .95778 L
s
1 .948 0 r
.008 w
.48413 .95778 Mdot
.016 w
.48413 .95778 m
.48152 .95795 L
s
1 .945 0 r
.008 w
.48152 .95795 Mdot
.016 w
.48152 .95795 m
.47884 .95807 L
s
1 .941 0 r
.008 w
.47884 .95807 Mdot
.016 w
.47884 .95807 m
.47611 .95828 L
s
1 .938 0 r
.008 w
.47611 .95828 Mdot
.016 w
.47611 .95828 m
.4733 .95855 L
s
1 .934 0 r
.008 w
.4733 .95855 Mdot
.016 w
.4733 .95855 m
.47056 .9589 L
s
1 .931 0 r
.008 w
.47056 .9589 Mdot
.016 w
.47056 .9589 m
.46778 .95922 L
s
1 .927 0 r
.008 w
.46778 .95922 Mdot
.016 w
.46778 .95922 m
.46498 .95964 L
s
1 .924 0 r
.008 w
.46498 .95964 Mdot
.016 w
.46498 .95964 m
.46226 .95991 L
s
1 .92 0 r
.008 w
.46226 .95991 Mdot
.016 w
.46226 .95991 m
.45944 .96008 L
s
1 .917 0 r
.008 w
.45944 .96008 Mdot
.016 w
.45944 .96008 m
.45664 .96013 L
s
1 .913 0 r
.008 w
.45664 .96013 Mdot
.016 w
.45664 .96013 m
.45387 .96016 L
s
1 .91 0 r
.008 w
.45387 .96016 Mdot
.016 w
.45387 .96016 m
.45114 .96019 L
s
1 .907 0 r
.008 w
.45114 .96019 Mdot
.016 w
.45114 .96019 m
.44841 .96023 L
s
1 .903 0 r
.008 w
.44841 .96023 Mdot
.016 w
.44841 .96023 m
.44583 .96029 L
s
1 .9 0 r
.008 w
.44583 .96029 Mdot
.016 w
.44583 .96029 m
.44322 .96036 L
s
1 .896 0 r
.008 w
.44322 .96036 Mdot
.016 w
.44322 .96036 m
.44088 .96042 L
s
1 .893 0 r
.008 w
.44088 .96042 Mdot
.016 w
.44088 .96042 m
.43852 .96035 L
s
1 .889 0 r
.008 w
.43852 .96035 Mdot
.016 w
.43852 .96035 m
.43608 .96014 L
s
1 .886 0 r
.008 w
.43608 .96014 Mdot
.016 w
.43608 .96014 m
.43402 .95978 L
s
1 .882 0 r
.008 w
.43402 .95978 Mdot
.016 w
.43402 .95978 m
.43194 .95929 L
s
1 .879 0 r
.008 w
.43194 .95929 Mdot
.016 w
.43194 .95929 m
.42991 .95871 L
s
1 .875 0 r
.008 w
.42991 .95871 Mdot
.016 w
.42991 .95871 m
.42783 .95804 L
s
1 .872 0 r
.008 w
.42783 .95804 Mdot
.016 w
.42783 .95804 m
.42576 .95732 L
s
1 .869 0 r
.008 w
.42576 .95732 Mdot
.016 w
.42576 .95732 m
.42371 .9566 L
s
1 .865 0 r
.008 w
.42371 .9566 Mdot
.016 w
.42371 .9566 m
.42162 .95585 L
s
1 .862 0 r
.008 w
.42162 .95585 Mdot
.016 w
.42162 .95585 m
.41945 .95509 L
s
1 .858 0 r
.008 w
.41945 .95509 Mdot
.016 w
.41945 .95509 m
.41719 .9543 L
s
1 .855 0 r
.008 w
.41719 .9543 Mdot
.016 w
.41719 .9543 m
.41493 .95347 L
s
1 .851 0 r
.008 w
.41493 .95347 Mdot
.016 w
.41493 .95347 m
.4125 .95257 L
s
1 .848 0 r
.008 w
.4125 .95257 Mdot
.016 w
.4125 .95257 m
.40984 .95161 L
s
1 .844 0 r
.008 w
.40984 .95161 Mdot
.016 w
.40984 .95161 m
.4071 .95063 L
s
1 .841 0 r
.008 w
.4071 .95063 Mdot
.016 w
.4071 .95063 m
.40424 .94967 L
s
1 .837 0 r
.008 w
.40424 .94967 Mdot
.016 w
.40424 .94967 m
.4013 .9487 L
s
1 .834 0 r
.008 w
.4013 .9487 Mdot
.016 w
.4013 .9487 m
.39819 .94774 L
s
1 .83 0 r
.008 w
.39819 .94774 Mdot
.016 w
.39819 .94774 m
.39505 .94678 L
s
1 .827 0 r
.008 w
.39505 .94678 Mdot
.016 w
.39505 .94678 m
.39194 .94579 L
s
1 .824 0 r
.008 w
.39194 .94579 Mdot
.016 w
.39194 .94579 m
.38871 .94476 L
s
1 .82 0 r
.008 w
.38871 .94476 Mdot
.016 w
.38871 .94476 m
.38559 .94368 L
s
1 .817 0 r
.008 w
.38559 .94368 Mdot
.016 w
.38559 .94368 m
.38241 .94258 L
s
1 .813 0 r
.008 w
.38241 .94258 Mdot
.016 w
.38241 .94258 m
.37931 .94142 L
s
1 .81 0 r
.008 w
.37931 .94142 Mdot
.016 w
.37931 .94142 m
.37623 .94026 L
s
1 .806 0 r
.008 w
.37623 .94026 Mdot
.016 w
.37623 .94026 m
.37304 .93911 L
s
1 .803 0 r
.008 w
.37304 .93911 Mdot
.016 w
.37304 .93911 m
.36996 .938 L
s
1 .799 0 r
.008 w
.36996 .938 Mdot
.016 w
.36996 .938 m
.36688 .937 L
s
1 .796 0 r
.008 w
.36688 .937 Mdot
.016 w
.36688 .937 m
.36385 .93605 L
s
1 .792 0 r
.008 w
.36385 .93605 Mdot
.016 w
.36385 .93605 m
.36079 .93514 L
s
1 .789 0 r
.008 w
.36079 .93514 Mdot
.016 w
.36079 .93514 m
.35785 .93423 L
s
1 .785 0 r
.008 w
.35785 .93423 Mdot
.016 w
.35785 .93423 m
.35495 .9333 L
s
1 .782 0 r
.008 w
.35495 .9333 Mdot
.016 w
.35495 .9333 m
.35189 .93231 L
s
1 .779 0 r
.008 w
.35189 .93231 Mdot
.016 w
.35189 .93231 m
.34877 .93127 L
s
1 .775 0 r
.008 w
.34877 .93127 Mdot
.016 w
.34877 .93127 m
.34579 .93019 L
s
1 .772 0 r
.008 w
.34579 .93019 Mdot
.016 w
.34579 .93019 m
.34267 .92907 L
s
1 .768 0 r
.008 w
.34267 .92907 Mdot
.016 w
.34267 .92907 m
.33945 .92796 L
s
1 .765 0 r
.008 w
.33945 .92796 Mdot
.016 w
.33945 .92796 m
.33649 .92692 L
s
1 .761 0 r
.008 w
.33649 .92692 Mdot
.016 w
.33649 .92692 m
.33362 .9259 L
s
1 .758 0 r
.008 w
.33362 .9259 Mdot
.016 w
.33362 .9259 m
.3307 .92492 L
s
1 .754 0 r
.008 w
.3307 .92492 Mdot
.016 w
.3307 .92492 m
.32817 .92401 L
s
1 .751 0 r
.008 w
.32817 .92401 Mdot
.016 w
.32817 .92401 m
.32549 .92315 L
s
1 .747 0 r
.008 w
.32549 .92315 Mdot
.016 w
.32549 .92315 m
.32341 .92241 L
s
1 .744 0 r
.008 w
.32341 .92241 Mdot
.016 w
.32341 .92241 m
.32153 .92178 L
s
1 .74 0 r
.008 w
.32153 .92178 Mdot
.016 w
.32153 .92178 m
.31982 .92131 L
s
1 .737 0 r
.008 w
.31982 .92131 Mdot
.016 w
.31982 .92131 m
.31837 .92099 L
s
1 .734 0 r
.008 w
.31837 .92099 Mdot
.016 w
.31837 .92099 m
.31722 .92082 L
s
1 .73 0 r
.008 w
.31722 .92082 Mdot
.016 w
.31722 .92082 m
.31637 .92076 L
s
1 .727 0 r
.008 w
.31637 .92076 Mdot
.016 w
.31637 .92076 m
.31571 .92073 L
s
1 .723 0 r
.008 w
.31571 .92073 Mdot
.016 w
.31571 .92073 m
.31513 .92065 L
s
1 .72 0 r
.008 w
.31513 .92065 Mdot
.016 w
.31513 .92065 m
.31451 .92043 L
s
1 .716 0 r
.008 w
.31451 .92043 Mdot
.016 w
.31451 .92043 m
.3138 .92006 L
s
1 .713 0 r
.008 w
.3138 .92006 Mdot
.016 w
.3138 .92006 m
.31296 .91952 L
s
1 .709 0 r
.008 w
.31296 .91952 Mdot
.016 w
.31296 .91952 m
.31191 .91878 L
s
1 .706 0 r
.008 w
.31191 .91878 Mdot
.016 w
.31191 .91878 m
.31058 .9179 L
s
1 .702 0 r
.008 w
.31058 .9179 Mdot
.016 w
.31058 .9179 m
.3092 .91696 L
s
1 .699 0 r
.008 w
.3092 .91696 Mdot
.016 w
.3092 .91696 m
.30772 .91596 L
s
1 .696 0 r
.008 w
.30772 .91596 Mdot
.016 w
.30772 .91596 m
.30625 .91493 L
s
1 .692 0 r
.008 w
.30625 .91493 Mdot
.016 w
.30625 .91493 m
.30487 .91393 L
s
1 .689 0 r
.008 w
.30487 .91393 Mdot
.016 w
.30487 .91393 m
.30353 .913 L
s
1 .685 0 r
.008 w
.30353 .913 Mdot
.016 w
.30353 .913 m
.30223 .9122 L
s
1 .682 0 r
.008 w
.30223 .9122 Mdot
.016 w
.30223 .9122 m
.30114 .91154 L
s
1 .678 0 r
.008 w
.30114 .91154 Mdot
.016 w
.30114 .91154 m
.30026 .91106 L
s
1 .675 0 r
.008 w
.30026 .91106 Mdot
.016 w
.30026 .91106 m
.29958 .91077 L
s
1 .671 0 r
.008 w
.29958 .91077 Mdot
.016 w
.29958 .91077 m
.29912 .91063 L
s
1 .668 0 r
.008 w
.29912 .91063 Mdot
.016 w
.29912 .91063 m
.29888 .91058 L
s
1 .664 0 r
.008 w
.29888 .91058 Mdot
.016 w
.29888 .91058 m
.29883 .91057 L
s
1 .661 0 r
.008 w
.29883 .91057 Mdot
.016 w
.29883 .91057 m
.29892 .91053 L
s
1 .657 0 r
.008 w
.29892 .91053 Mdot
.016 w
.29892 .91053 m
.29908 .91037 L
s
1 .654 0 r
.008 w
.29908 .91037 Mdot
.016 w
.29908 .91037 m
.29925 .91004 L
s
1 .651 0 r
.008 w
.29925 .91004 Mdot
.016 w
.29925 .91004 m
.29938 .90958 L
s
1 .647 0 r
.008 w
.29938 .90958 Mdot
.016 w
.29938 .90958 m
.29944 .90902 L
s
1 .644 0 r
.008 w
.29944 .90902 Mdot
.016 w
.29944 .90902 m
.29944 .90838 L
s
1 .64 0 r
.008 w
.29944 .90838 Mdot
.016 w
.29944 .90838 m
.29941 .90776 L
s
1 .637 0 r
.008 w
.29941 .90776 Mdot
.016 w
.29941 .90776 m
.2994 .90726 L
s
1 .633 0 r
.008 w
.2994 .90726 Mdot
.016 w
.2994 .90726 m
.29959 .90688 L
s
1 .63 0 r
.008 w
.29959 .90688 Mdot
.016 w
.29959 .90688 m
.29976 .90666 L
s
1 .626 0 r
.008 w
.29976 .90666 Mdot
.016 w
.29976 .90666 m
.29997 .9066 L
s
1 .623 0 r
.008 w
.29997 .9066 Mdot
.016 w
.29997 .9066 m
.30013 .90672 L
s
1 .619 0 r
.008 w
.30013 .90672 Mdot
.016 w
.30013 .90672 m
.30025 .90703 L
s
1 .616 0 r
.008 w
.30025 .90703 Mdot
.016 w
.30025 .90703 m
.30024 .90745 L
s
1 .612 0 r
.008 w
.30024 .90745 Mdot
.016 w
.30024 .90745 m
.30004 .90794 L
s
1 .609 0 r
.008 w
.30004 .90794 Mdot
.016 w
.30004 .90794 m
.29958 .90843 L
s
1 .606 0 r
.008 w
.29958 .90843 Mdot
.016 w
.29958 .90843 m
.29883 .90897 L
s
1 .602 0 r
.008 w
.29883 .90897 Mdot
.016 w
.29883 .90897 m
.29777 .90944 L
s
1 .599 0 r
.008 w
.29777 .90944 Mdot
.016 w
.29777 .90944 m
.29638 .90975 L
s
1 .595 0 r
.008 w
.29638 .90975 Mdot
.016 w
.29638 .90975 m
.29477 .90982 L
s
1 .592 0 r
.008 w
.29477 .90982 Mdot
.016 w
.29477 .90982 m
.29279 .90961 L
s
1 .588 0 r
.008 w
.29279 .90961 Mdot
.016 w
.29279 .90961 m
.29063 .90909 L
s
1 .585 0 r
.008 w
.29063 .90909 Mdot
.016 w
.29063 .90909 m
.28826 .90839 L
s
1 .581 0 r
.008 w
.28826 .90839 Mdot
.016 w
.28826 .90839 m
.28555 .90748 L
s
1 .578 0 r
.008 w
.28555 .90748 Mdot
.016 w
.28555 .90748 m
.28271 .90645 L
s
1 .574 0 r
.008 w
.28271 .90645 Mdot
.016 w
.28271 .90645 m
.2798 .90545 L
s
1 .571 0 r
.008 w
.2798 .90545 Mdot
.016 w
.2798 .90545 m
.27725 .90445 L
s
1 .567 0 r
.008 w
.27725 .90445 Mdot
.016 w
.27725 .90445 m
.27461 .90353 L
s
1 .564 0 r
.008 w
.27461 .90353 Mdot
.016 w
.27461 .90353 m
.27226 .90279 L
s
1 .561 0 r
.008 w
.27226 .90279 Mdot
.016 w
.27226 .90279 m
.27015 .90212 L
s
1 .557 0 r
.008 w
.27015 .90212 Mdot
.016 w
.27015 .90212 m
.26837 .90155 L
s
1 .554 0 r
.008 w
.26837 .90155 Mdot
.016 w
.26837 .90155 m
.26687 .90105 L
s
1 .55 0 r
.008 w
.26687 .90105 Mdot
.016 w
.26687 .90105 m
.26558 .90057 L
s
1 .547 0 r
.008 w
.26558 .90057 Mdot
.016 w
.26558 .90057 m
.26458 .90011 L
s
1 .543 0 r
.008 w
.26458 .90011 Mdot
.016 w
.26458 .90011 m
.26372 .89966 L
s
1 .54 0 r
.008 w
.26372 .89966 Mdot
.016 w
.26372 .89966 m
.26296 .89922 L
s
1 .536 0 r
.008 w
.26296 .89922 Mdot
.016 w
.26296 .89922 m
.26244 .89882 L
s
1 .533 0 r
.008 w
.26244 .89882 Mdot
.016 w
.26244 .89882 m
.26199 .89839 L
s
1 .529 0 r
.008 w
.26199 .89839 Mdot
.016 w
.26199 .89839 m
.26163 .89795 L
s
1 .526 0 r
.008 w
.26163 .89795 Mdot
.016 w
.26163 .89795 m
.26137 .89757 L
s
1 .522 0 r
.008 w
.26137 .89757 Mdot
.016 w
.26137 .89757 m
.2612 .89721 L
s
1 .519 0 r
.008 w
.2612 .89721 Mdot
.016 w
.2612 .89721 m
.26106 .89684 L
s
1 .516 0 r
.008 w
.26106 .89684 Mdot
.016 w
.26106 .89684 m
.26091 .89649 L
s
1 .512 0 r
.008 w
.26091 .89649 Mdot
.016 w
.26091 .89649 m
.2607 .89617 L
s
1 .509 0 r
.008 w
.2607 .89617 Mdot
.016 w
.2607 .89617 m
.26048 .89592 L
s
1 .505 0 r
.008 w
.26048 .89592 Mdot
.016 w
.26048 .89592 m
.26014 .8957 L
s
1 .502 0 r
.008 w
.26014 .8957 Mdot
.016 w
.26014 .8957 m
.2597 .8955 L
s
1 .498 0 r
.008 w
.2597 .8955 Mdot
.016 w
.2597 .8955 m
.25914 .89527 L
s
1 .495 0 r
.008 w
.25914 .89527 Mdot
.016 w
.25914 .89527 m
.25842 .89497 L
s
1 .491 0 r
.008 w
.25842 .89497 Mdot
.016 w
.25842 .89497 m
.25751 .89452 L
s
1 .488 0 r
.008 w
.25751 .89452 Mdot
.016 w
.25751 .89452 m
.25644 .89391 L
s
1 .484 0 r
.008 w
.25644 .89391 Mdot
.016 w
.25644 .89391 m
.25521 .89309 L
s
1 .481 0 r
.008 w
.25521 .89309 Mdot
.016 w
.25521 .89309 m
.25388 .8921 L
s
1 .478 0 r
.008 w
.25388 .8921 Mdot
.016 w
.25388 .8921 m
.25238 .89091 L
s
1 .474 0 r
.008 w
.25238 .89091 Mdot
.016 w
.25238 .89091 m
.25069 .88954 L
s
1 .471 0 r
.008 w
.25069 .88954 Mdot
.016 w
.25069 .88954 m
.24885 .88806 L
s
1 .467 0 r
.008 w
.24885 .88806 Mdot
.016 w
.24885 .88806 m
.24701 .88652 L
s
1 .464 0 r
.008 w
.24701 .88652 Mdot
.016 w
.24701 .88652 m
.24516 .88495 L
s
1 .46 0 r
.008 w
.24516 .88495 Mdot
.016 w
.24516 .88495 m
.24341 .88338 L
s
1 .457 0 r
.008 w
.24341 .88338 Mdot
.016 w
.24341 .88338 m
.24186 .88188 L
s
1 .453 0 r
.008 w
.24186 .88188 Mdot
.016 w
.24186 .88188 m
.24052 .8806 L
s
1 .45 0 r
.008 w
.24052 .8806 Mdot
.016 w
.24052 .8806 m
.23942 .87953 L
s
1 .446 0 r
.008 w
.23942 .87953 Mdot
.016 w
.23942 .87953 m
.23851 .87868 L
s
1 .443 0 r
.008 w
.23851 .87868 Mdot
.016 w
.23851 .87868 m
.23773 .87795 L
s
1 .439 0 r
.008 w
.23773 .87795 Mdot
.016 w
.23773 .87795 m
.23709 .87739 L
s
1 .436 0 r
.008 w
.23709 .87739 Mdot
.016 w
.23709 .87739 m
.23648 .87686 L
s
1 .433 0 r
.008 w
.23648 .87686 Mdot
.016 w
.23648 .87686 m
.23581 .87626 L
s
1 .429 0 r
.008 w
.23581 .87626 Mdot
.016 w
.23581 .87626 m
.23517 .87567 L
s
1 .426 0 r
.008 w
.23517 .87567 Mdot
.016 w
.23517 .87567 m
.23457 .87512 L
s
1 .422 0 r
.008 w
.23457 .87512 Mdot
.016 w
.23457 .87512 m
.23384 .87443 L
s
1 .419 0 r
.008 w
.23384 .87443 Mdot
.016 w
.23384 .87443 m
.23299 .87362 L
s
1 .415 0 r
.008 w
.23299 .87362 Mdot
.016 w
.23299 .87362 m
.23196 .87264 L
s
1 .412 0 r
.008 w
.23196 .87264 Mdot
.016 w
.23196 .87264 m
.2307 .87151 L
s
1 .408 0 r
.008 w
.2307 .87151 Mdot
.016 w
.2307 .87151 m
.22925 .87018 L
s
1 .405 0 r
.008 w
.22925 .87018 Mdot
.016 w
.22925 .87018 m
.22766 .86876 L
s
1 .401 0 r
.008 w
.22766 .86876 Mdot
.016 w
.22766 .86876 m
.22587 .86718 L
s
1 .398 0 r
.008 w
.22587 .86718 Mdot
.016 w
.22587 .86718 m
.22392 .86545 L
s
1 .394 0 r
.008 w
.22392 .86545 Mdot
.016 w
.22392 .86545 m
.22186 .86357 L
s
1 .391 0 r
.008 w
.22186 .86357 Mdot
.016 w
.22186 .86357 m
.21973 .86164 L
s
1 .388 0 r
.008 w
.21973 .86164 Mdot
.016 w
.21973 .86164 m
.21754 .85963 L
s
1 .384 0 r
.008 w
.21754 .85963 Mdot
.016 w
.21754 .85963 m
.21542 .85765 L
s
1 .381 0 r
.008 w
.21542 .85765 Mdot
.016 w
.21542 .85765 m
.21329 .85564 L
s
1 .377 0 r
.008 w
.21329 .85564 Mdot
.016 w
.21329 .85564 m
.21114 .85366 L
s
1 .374 0 r
.008 w
.21114 .85366 Mdot
.016 w
.21114 .85366 m
.20909 .85187 L
s
1 .37 0 r
.008 w
.20909 .85187 Mdot
.016 w
.20909 .85187 m
.20708 .85009 L
s
1 .367 0 r
.008 w
.20708 .85009 Mdot
.016 w
.20708 .85009 m
.20513 .84827 L
s
1 .363 0 r
.008 w
.20513 .84827 Mdot
.016 w
.20513 .84827 m
.20328 .84657 L
s
1 .36 0 r
.008 w
.20328 .84657 Mdot
.016 w
.20328 .84657 m
.20151 .84481 L
s
1 .356 0 r
.008 w
.20151 .84481 Mdot
.016 w
.20151 .84481 m
.19986 .84298 L
s
1 .353 0 r
.008 w
.19986 .84298 Mdot
.016 w
.19986 .84298 m
.19832 .84122 L
s
1 .349 0 r
.008 w
.19832 .84122 Mdot
.016 w
.19832 .84122 m
.19685 .83944 L
s
1 .346 0 r
.008 w
.19685 .83944 Mdot
.016 w
.19685 .83944 m
.19546 .83767 L
s
1 .343 0 r
.008 w
.19546 .83767 Mdot
.016 w
.19546 .83767 m
.19418 .83603 L
s
1 .339 0 r
.008 w
.19418 .83603 Mdot
.016 w
.19418 .83603 m
.19298 .83446 L
s
1 .336 0 r
.008 w
.19298 .83446 Mdot
.016 w
.19298 .83446 m
.19186 .83315 L
s
1 .332 0 r
.008 w
.19186 .83315 Mdot
.016 w
.19186 .83315 m
.19084 .83187 L
s
1 .329 0 r
.008 w
.19084 .83187 Mdot
.016 w
.19084 .83187 m
.18986 .83078 L
s
1 .325 0 r
.008 w
.18986 .83078 Mdot
.016 w
.18986 .83078 m
.18891 .82972 L
s
1 .322 0 r
.008 w
.18891 .82972 Mdot
.016 w
.18891 .82972 m
.18794 .82867 L
s
1 .318 0 r
.008 w
.18794 .82867 Mdot
.016 w
.18794 .82867 m
.18695 .8277 L
s
1 .315 0 r
.008 w
.18695 .8277 Mdot
.016 w
.18695 .8277 m
.18589 .82679 L
s
1 .311 0 r
.008 w
.18589 .82679 Mdot
.016 w
.18589 .82679 m
.18474 .82594 L
s
1 .308 0 r
.008 w
.18474 .82594 Mdot
.016 w
.18474 .82594 m
.18351 .82511 L
s
1 .304 0 r
.008 w
.18351 .82511 Mdot
.016 w
.18351 .82511 m
.18218 .82425 L
s
1 .301 0 r
.008 w
.18218 .82425 Mdot
.016 w
.18218 .82425 m
.18077 .82334 L
s
1 .298 0 r
.008 w
.18077 .82334 Mdot
.016 w
.18077 .82334 m
.17939 .82231 L
s
1 .294 0 r
.008 w
.17939 .82231 Mdot
.016 w
.17939 .82231 m
.17788 .82124 L
s
1 .291 0 r
.008 w
.17788 .82124 Mdot
.016 w
.17788 .82124 m
.17632 .81987 L
s
1 .287 0 r
.008 w
.17632 .81987 Mdot
.016 w
.17632 .81987 m
.1747 .81841 L
s
1 .284 0 r
.008 w
.1747 .81841 Mdot
.016 w
.1747 .81841 m
.17295 .81674 L
s
1 .28 0 r
.008 w
.17295 .81674 Mdot
.016 w
.17295 .81674 m
.17122 .81498 L
s
1 .277 0 r
.008 w
.17122 .81498 Mdot
.016 w
.17122 .81498 m
.16942 .81306 L
s
1 .273 0 r
.008 w
.16942 .81306 Mdot
.016 w
.16942 .81306 m
.16759 .81102 L
s
1 .27 0 r
.008 w
.16759 .81102 Mdot
.016 w
.16759 .81102 m
.16584 .80899 L
s
1 .266 0 r
.008 w
.16584 .80899 Mdot
.016 w
.16584 .80899 m
.16415 .80702 L
s
1 .263 0 r
.008 w
.16415 .80702 Mdot
.016 w
.16415 .80702 m
.16253 .80501 L
s
1 .26 0 r
.008 w
.16253 .80501 Mdot
.016 w
.16253 .80501 m
.16095 .80295 L
s
1 .256 0 r
.008 w
.16095 .80295 Mdot
.016 w
.16095 .80295 m
.15934 .80089 L
s
1 .253 0 r
.008 w
.15934 .80089 Mdot
.016 w
.15934 .80089 m
.15787 .79888 L
s
1 .249 0 r
.008 w
.15787 .79888 Mdot
.016 w
.15787 .79888 m
.15637 .79684 L
s
1 .246 0 r
.008 w
.15637 .79684 Mdot
.016 w
.15637 .79684 m
.15488 .79485 L
s
1 .242 0 r
.008 w
.15488 .79485 Mdot
.016 w
.15488 .79485 m
.15341 .79296 L
s
1 .239 0 r
.008 w
.15341 .79296 Mdot
.016 w
.15341 .79296 m
.15208 .79124 L
s
1 .235 0 r
.008 w
.15208 .79124 Mdot
.016 w
.15208 .79124 m
.15085 .78967 L
s
1 .232 0 r
.008 w
.15085 .78967 Mdot
.016 w
.15085 .78967 m
.14976 .78825 L
s
1 .228 0 r
.008 w
.14976 .78825 Mdot
.016 w
.14976 .78825 m
.1487 .78697 L
s
1 .225 0 r
.008 w
.1487 .78697 Mdot
.016 w
.1487 .78697 m
.14762 .78577 L
s
1 .221 0 r
.008 w
.14762 .78577 Mdot
.016 w
.14762 .78577 m
.14645 .78464 L
s
1 .218 0 r
.008 w
.14645 .78464 Mdot
.016 w
.14645 .78464 m
.14544 .78356 L
s
1 .215 0 r
.008 w
.14544 .78356 Mdot
.016 w
.14544 .78356 m
.14418 .78248 L
s
1 .211 0 r
.008 w
.14418 .78248 Mdot
.016 w
.14418 .78248 m
.1427 .78133 L
s
1 .208 0 r
.008 w
.1427 .78133 Mdot
.016 w
.1427 .78133 m
.14111 .78003 L
s
1 .204 0 r
.008 w
.14111 .78003 Mdot
.016 w
.14111 .78003 m
.13927 .77875 L
s
1 .201 0 r
.008 w
.13927 .77875 Mdot
.016 w
.13927 .77875 m
.13745 .77733 L
s
1 .197 0 r
.008 w
.13745 .77733 Mdot
.016 w
.13745 .77733 m
.13538 .77575 L
s
1 .194 0 r
.008 w
.13538 .77575 Mdot
.016 w
.13538 .77575 m
.13329 .77402 L
s
1 .19 0 r
.008 w
.13329 .77402 Mdot
.016 w
.13329 .77402 m
.13142 .77214 L
s
1 .187 0 r
.008 w
.13142 .77214 Mdot
.016 w
.13142 .77214 m
.12947 .77015 L
s
1 .183 0 r
.008 w
.12947 .77015 Mdot
.016 w
.12947 .77015 m
.12732 .76803 L
s
1 .18 0 r
.008 w
.12732 .76803 Mdot
.016 w
.12732 .76803 m
.1252 .76585 L
s
1 .176 0 r
.008 w
.1252 .76585 Mdot
.016 w
.1252 .76585 m
.12307 .76362 L
s
1 .173 0 r
.008 w
.12307 .76362 Mdot
.016 w
.12307 .76362 m
.12106 .76139 L
s
1 .17 0 r
.008 w
.12106 .76139 Mdot
.016 w
.12106 .76139 m
.11902 .75918 L
s
1 .166 0 r
.008 w
.11902 .75918 Mdot
.016 w
.11902 .75918 m
.11715 .75715 L
s
1 .163 0 r
.008 w
.11715 .75715 Mdot
.016 w
.11715 .75715 m
.11537 .75522 L
s
1 .159 0 r
.008 w
.11537 .75522 Mdot
.016 w
.11537 .75522 m
.11365 .75348 L
s
1 .156 0 r
.008 w
.11365 .75348 Mdot
.016 w
.11365 .75348 m
.11213 .75187 L
s
1 .152 0 r
.008 w
.11213 .75187 Mdot
.016 w
.11213 .75187 m
.1107 .75043 L
s
1 .149 0 r
.008 w
.1107 .75043 Mdot
.016 w
.1107 .75043 m
.10935 .74914 L
s
1 .145 0 r
.008 w
.10935 .74914 Mdot
.016 w
.10935 .74914 m
.10813 .74798 L
s
1 .142 0 r
.008 w
.10813 .74798 Mdot
.016 w
.10813 .74798 m
.10714 .74694 L
s
1 .138 0 r
.008 w
.10714 .74694 Mdot
.016 w
.10714 .74694 m
.1063 .74598 L
s
1 .135 0 r
.008 w
.1063 .74598 Mdot
.016 w
.1063 .74598 m
.10565 .74515 L
s
1 .131 0 r
.008 w
.10565 .74515 Mdot
.016 w
.10565 .74515 m
.10519 .7445 L
s
1 .128 0 r
.008 w
.10519 .7445 Mdot
.016 w
.10519 .7445 m
.10495 .74402 L
s
1 .125 0 r
.008 w
.10495 .74402 Mdot
.016 w
.10495 .74402 m
.10488 .74368 L
s
1 .121 0 r
.008 w
.10488 .74368 Mdot
.016 w
.10488 .74368 m
.10495 .74344 L
s
1 .118 0 r
.008 w
.10495 .74344 Mdot
.016 w
.10495 .74344 m
.10509 .74324 L
s
1 .114 0 r
.008 w
.10509 .74324 Mdot
.016 w
.10509 .74324 m
.10527 .74308 L
s
1 .111 0 r
.008 w
.10527 .74308 Mdot
.016 w
.10527 .74308 m
.10545 .74293 L
s
1 .107 0 r
.008 w
.10545 .74293 Mdot
.016 w
.10545 .74293 m
.10562 .74278 L
s
1 .104 0 r
.008 w
.10562 .74278 Mdot
.016 w
.10562 .74278 m
.10577 .74262 L
s
1 .1 0 r
.008 w
.10577 .74262 Mdot
.016 w
.10577 .74262 m
.10587 .74244 L
s
1 .097 0 r
.008 w
.10587 .74244 Mdot
.016 w
.10587 .74244 m
.10592 .7423 L
s
1 .093 0 r
.008 w
.10592 .7423 Mdot
.016 w
.10592 .7423 m
.10591 .74221 L
s
1 .09 0 r
.008 w
.10591 .74221 Mdot
.016 w
.10591 .74221 m
.10585 .74216 L
s
1 .087 0 r
.008 w
.10585 .74216 Mdot
.016 w
.10585 .74216 m
.10572 .74207 L
s
1 .083 0 r
.008 w
.10572 .74207 Mdot
.016 w
.10572 .74207 m
.10551 .74191 L
s
1 .08 0 r
.008 w
.10551 .74191 Mdot
.016 w
.10551 .74191 m
.10525 .74164 L
s
1 .076 0 r
.008 w
.10525 .74164 Mdot
.016 w
.10525 .74164 m
.10495 .74124 L
s
1 .073 0 r
.008 w
.10495 .74124 Mdot
.016 w
.10495 .74124 m
.10464 .74068 L
s
1 .069 0 r
.008 w
.10464 .74068 Mdot
.016 w
.10464 .74068 m
.10433 .7399 L
s
1 .066 0 r
.008 w
.10433 .7399 Mdot
.016 w
.10433 .7399 m
.10408 .73915 L
s
1 .062 0 r
.008 w
.10408 .73915 Mdot
.016 w
.10408 .73915 m
.10383 .73826 L
s
1 .059 0 r
.008 w
.10383 .73826 Mdot
.016 w
.10383 .73826 m
.1036 .73731 L
s
1 .055 0 r
.008 w
.1036 .73731 Mdot
.016 w
.1036 .73731 m
.10337 .73628 L
s
1 .052 0 r
.008 w
.10337 .73628 Mdot
.016 w
.10337 .73628 m
.10315 .73509 L
s
1 .048 0 r
.008 w
.10315 .73509 Mdot
.016 w
.10315 .73509 m
.10291 .73365 L
s
1 .045 0 r
.008 w
.10291 .73365 Mdot
.016 w
.10291 .73365 m
.10269 .73194 L
s
1 .042 0 r
.008 w
.10269 .73194 Mdot
.016 w
.10269 .73194 m
.10249 .73001 L
s
1 .038 0 r
.008 w
.10249 .73001 Mdot
.016 w
.10249 .73001 m
.10228 .72806 L
s
1 .035 0 r
.008 w
.10228 .72806 Mdot
.016 w
.10228 .72806 m
.10206 .72613 L
s
1 .031 0 r
.008 w
.10206 .72613 Mdot
.016 w
.10206 .72613 m
.10181 .72429 L
s
1 .028 0 r
.008 w
.10181 .72429 Mdot
.016 w
.10181 .72429 m
.10153 .72261 L
s
1 .024 0 r
.008 w
.10153 .72261 Mdot
.016 w
.10153 .72261 m
.10121 .72112 L
s
1 .021 0 r
.008 w
.10121 .72112 Mdot
.016 w
.10121 .72112 m
.10085 .71987 L
s
1 .017 0 r
.008 w
.10085 .71987 Mdot
.016 w
.10085 .71987 m
.1005 .71884 L
s
1 .014 0 r
.008 w
.1005 .71884 Mdot
.016 w
.1005 .71884 m
.10019 .71802 L
s
1 .01 0 r
.008 w
.10019 .71802 Mdot
.016 w
.10019 .71802 m
.09994 .71738 L
s
1 .007 0 r
.008 w
.09994 .71738 Mdot
.016 w
.09994 .71738 m
.09975 .71688 L
s
1 .003 0 r
.008 w
.09975 .71688 Mdot
.016 w
.09975 .71688 m
.09962 .71651 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4
?Nl=Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`@mk`eoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo13g_3Goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo13g_4goo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_lgoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool5?NocOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Dmko5oo`03001oogoo00io
o`003goo00<007ooOol01goo1Cg_lGoo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4?NobOol0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`@mko9oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo13g_lWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool4?NoaOol00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`@mko5oo`03001oogoo00moo`0047oo00<007ooOol01Woo13g_lGoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Dm
ko1oo`03001oogoo00moo`004Goo00<007ooOol01Woo13g_kgoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool4?No_Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool4?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`05Ool5?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`Dm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`05Ool4?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`@mknQoo`03001oogoo01Ao
o`005Woo00<007ooOol017oo13g_igoo00<007ooOol05Goo000FOol00`00Oomoo`04Ool4?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo00=oo`@mknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0goo1Cg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo00=oo`@mknAoo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Cg_hgoo00<007oo
Ool05goo000IOol00`00Oomoo`02Ool6?NoQOol00`00Oomoo`0HOol001Yoo`04001oogooOol6?NoQ
Ool00`00Oomoo`0HOol001Yoo`05001oogooOolmk`04O0000cg_Oomoo`3NOol00`00Oomoo`0IOol0
01]oo`04001oogooOol5O03OOol00`00Oomoo`0JOol001]oo`04001oogooOol5O03OOol00`00Oomo
o`0JOol001aoo`03001oogoo00El0=ioo`03001oogoo01]oo`0077oo00<007ooOol01G`0gWoo00<0
07ooOol06goo000MOol00`00Oomoo`04O03MOol00`00Oomoo`0LOol001eoo`03001oogoo00Al0=eo
o`03001oogoo01aoo`007Woo00<007ooO2000g`P00=l@7ooOol0fGoo00<007ooOol07Goo000NOol0
0`00Ooml8003O2000ga0Oomoo`3IOol00`00Oomoo`0MOol001moo`03001l87`P009l8003O41lP7oo
0=Qoo`03001oogoo01ioo`007goo00<007a0O4000ga00Wb0f7oo00<007ooOol07Woo000POol00`00
O61lH002O602O8000gbPOomoo`3DOol00`00Oomoo`0OOol0021oo`03001lP7b000AlP003O:1oogoo
0=Aoo`03001oogoo01moo`008Goo00<007b0O8000gb00gbPdgoo00<007ooOol087oo000ROol00`00
O:1lX006O:3AOol00`00Oomoo`0QOol002=oo`03001lX7bP00ElX=1oo`03001oogoo029oo`0097oo
00<007bPO:001GbP00=l`7ooOol0bgoo00<007ooOol08goo000TOol00`00?NmlX006O:000gc0Oomo
o`3:Ool00`00Oomoo`0SOol002Eoo`03000mkgbP00AlX0=l`<Yoo`03001oogoo02Aoo`009Woo00<0
03g_O<000WbP1Gc0b7oo00<007ooOol09Goo000VOol00`00Oolmk`08O<03?No4Ool00`00Oomoo`0U
Ool002Moo`03001oocg_00Il`09lh08mkl=oo`03001oogoo02Ioo`00:7oo00D007ooOomoocg_009l
`0Alh003?Nmoogoo0<1oo`03001oogoo02Moo`00:Goo00@007ooOomoo`Ilh08mkl1oo`03001oogoo
02Qoo`00:Woo00<007ooOol01WcP00=m03g_Ool0_Woo00<007ooOol0:Goo000ZOol01000Oomoogoo
1GcP0Wd000<mkgooOol0_7oo00<007ooOol0:Goo000[Ool01000Oomoogoo17cP0gd0_Goo00<007oo
Ool0:Woo000/Ool01000Oomoogoo1gd0^goo00<007ooOol0:goo000]Ool00`00Oomoo`07O@000gdP
Oomoo`2gOol00`00Oomoo`0/Ool002ioo`03001oogoo00Im009m8;Moo`03001oogoo02eoo`00;Woo
00@007ooOomoo`Em00=m8;Ioo`03001oogoo02eoo`00;goo00@007ooOomoo`Am00Am8003OD1oogoo
0;5oo`03001oogoo02ioo`00<7oo00@007ooOomoo`Qm8;9oo`03001oogoo02moo`00<Goo00@007oo
Oomoo`Im809m@;1oo`03001oogoo031oo`00<Woo0P000goo00=m@7dPOB0017e0[Goo0P00<goo000d
Ool01000Oomoogoo1Ge00WePZgoo00<007ooOol0<goo000eOol01@00Oomoogoo?Nl00We017ePZGoo
00<007ooOol0=7oo000eOol01000Oomoogoo0Sg_1WePZ7oo00<007ooOol0=7oo000fOol01000Oomo
ogoo0Sg_1WePYWoo00<007ooOol0=Goo000gOol00`00Oomoo`03Ool6OF2TOol00`00Oomoo`0fOol0
03Qoo`03001oogoo00=oo`AmH09mP:9oo`03001oogoo03Moo`00>Goo0P0017oo0WeP17f000<mkgoo
Ool0W7oo0P00>Woo000kOol01000Oomoogoo27f0W7oo00<007ooOol0>Woo000lOol00`00Oomoo`08
OH000gfPOomoo`2HOol00`00Oomoo`0kOol003eoo`03001oogoo008mk`EmP09mX003?Nmoogoo09Eo
o`03001oogoo03aoo`00?Woo0P000Woo1Gf00WfP00=m`3g_Ool0Tgoo0P00?goo0010Ool00`00Oomo
o`06OJ02OL000cg_Oomoo`2@Ool00`00Oomoo`0oOol0045oo`800003OommX7fP00=mX0=m`003?Nmo
ogoo08eoo`80049oo`00@goo00<007ooOL001gg000<mkgooOol0Rgoo00<007ooOol0@Woo0014Ool0
0`00Oomm`005OL03ON2;Ool00`00Oomoo`13Ool004Eoo`04001oogooOol2OL04ON000gh0OT1oo`27
Ool00`00Oomoo`14Ool004Ioo`800003OolmkggP00Amh005OP1n87hPOomn@023Ool20017Ool004Qo
o`8000Emh003OP1n87hP00=n@003OomnH7iP009nH7]oo`8004Uoo`00BWoo00<007h0OP000gh00WhP
1gi000=nH3g_Ool0Mgoo0P00Bgoo001<Ool6OR07OT000giPOZ0mk`1eOol2001=Ool004ioo`03001n
@7i000Qn@004OV1nX7k0O/1cOol00`00Oomoo`1=Ool004moo`03000mkcg_00Mn@003OV1nX7k0009n
`09nh6moo`03001oogoo04ioo`00D7oo0P000Woo0Sg_1GjP0gk00gkP0gl0JGoo0P00DGoo001BOol2
000017oo?Nlmkgoo1Wk00gkP17l000=ooglPOol0Hgoo0P00Dgoo001DOol200000cg_Oomoo`05O/03
O^07O`000gooOb1oo`05Ool5?NmDOol2001EOol005Ioo`8000Aoo`Enh0Mo00=o8004?Nmo87ooOol6
?NmBOol2001GOol005Qoo`<000Aoo`Uo00Io8003?Nmo@3g_00@mkdmoo`<005Uoo`00Fgoo0`0017oo
1Wl027lP00=o@3g_Od000Sg_C7oo0`00G7oo001NOol20005Ool;Ob04Od02?Nm8Ool3001OOol0061o
o`8000Ioo`Qo80Mo@003?Nmoogoo04=oo`03001oogoo061oo`00HWoo0`001Woo1GlP1gm00gmP47oo
0Wo0;Woo0`00Hgoo001UOol30006Ool9Od06Of0<Ool7Ol02On0UOol3001VOol006Qoo`@000Eoo`Io
@0MoH0EoP0MoX0Io`09oh25oo`@006Uoo`00K7oo10000goo17m01gmP1Gn01gnP1Wo00WoP7Goo1000
KGoo001`Ool30003Ool8Of05Oh07Oj06Ol02On0IOol4001aOol007=oo`D00003OomoH7mP00=oH0Eo
P0MoX09o`0HmkaEoo`@007Eoo`00N7oo1@005Cg_3Woo1`00NGoo001oOol70008?Nl4Ool>0020Ool0
08eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo0P0017oo0P00
SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00SGoo00<007ooOol00Woo00<007ooOol0
Rgoo002;Ool20006Ool00`00Oomoo`2:Ool008]oo`03001oogoo009oo`04001oogoo002<Ool008]o
o`<000=oo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(54)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
1 .983 0 r
.008 w
.10137 .71568 Mdot
.016 w
.10137 .71568 m
.10141 .71572 L
s
1 .967 0 r
.008 w
.10141 .71572 Mdot
.016 w
.10141 .71572 m
.10134 .71584 L
s
1 .95 0 r
.008 w
.10134 .71584 Mdot
.016 w
.10134 .71584 m
.10115 .716 L
s
1 .933 0 r
.008 w
.10115 .716 Mdot
.016 w
.10115 .716 m
.1009 .71611 L
s
1 .917 0 r
.008 w
.1009 .71611 Mdot
.016 w
.1009 .71611 m
.10059 .71604 L
s
1 .9 0 r
.008 w
.10059 .71604 Mdot
.016 w
.10059 .71604 m
.10023 .71572 L
s
1 .883 0 r
.008 w
.10023 .71572 Mdot
.016 w
.10023 .71572 m
.09981 .71521 L
s
1 .867 0 r
.008 w
.09981 .71521 Mdot
.016 w
.09981 .71521 m
.09931 .7146 L
s
1 .85 0 r
.008 w
.09931 .7146 Mdot
.016 w
.09931 .7146 m
.09872 .7137 L
s
1 .833 0 r
.008 w
.09872 .7137 Mdot
.016 w
.09872 .7137 m
.09808 .71253 L
s
1 .817 0 r
.008 w
.09808 .71253 Mdot
.016 w
.09808 .71253 m
.09742 .71106 L
s
1 .8 0 r
.008 w
.09742 .71106 Mdot
.016 w
.09742 .71106 m
.09678 .70934 L
s
1 .783 0 r
.008 w
.09678 .70934 Mdot
.016 w
.09678 .70934 m
.09619 .70738 L
s
1 .767 0 r
.008 w
.09619 .70738 Mdot
.016 w
.09619 .70738 m
.0956 .7054 L
s
1 .75 0 r
.008 w
.0956 .7054 Mdot
.016 w
.0956 .7054 m
.09502 .70309 L
s
1 .733 0 r
.008 w
.09502 .70309 Mdot
.016 w
.09502 .70309 m
.0944 .70033 L
s
1 .717 0 r
.008 w
.0944 .70033 Mdot
.016 w
.0944 .70033 m
.09374 .6974 L
s
1 .7 0 r
.008 w
.09374 .6974 Mdot
.016 w
.09374 .6974 m
.09301 .69411 L
s
1 .683 0 r
.008 w
.09301 .69411 Mdot
.016 w
.09301 .69411 m
.0922 .69057 L
s
1 .667 0 r
.008 w
.0922 .69057 Mdot
.016 w
.0922 .69057 m
.09138 .68654 L
s
1 .65 0 r
.008 w
.09138 .68654 Mdot
.016 w
.09138 .68654 m
.09057 .68243 L
s
1 .633 0 r
.008 w
.09057 .68243 Mdot
.016 w
.09057 .68243 m
.08981 .67796 L
s
1 .617 0 r
.008 w
.08981 .67796 Mdot
.016 w
.08981 .67796 m
.08911 .67415 L
s
1 .6 0 r
.008 w
.08911 .67415 Mdot
.016 w
.08911 .67415 m
.08849 .67019 L
s
1 .583 0 r
.008 w
.08849 .67019 Mdot
.016 w
.08849 .67019 m
.08794 .66687 L
s
1 .567 0 r
.008 w
.08794 .66687 Mdot
.016 w
.08794 .66687 m
.08745 .6639 L
s
1 .55 0 r
.008 w
.08745 .6639 Mdot
.016 w
.08745 .6639 m
.08706 .66102 L
s
1 .533 0 r
.008 w
.08706 .66102 Mdot
.016 w
.08706 .66102 m
.08674 .65837 L
s
1 .517 0 r
.008 w
.08674 .65837 Mdot
.016 w
.08674 .65837 m
.08653 .65629 L
s
1 .5 0 r
.008 w
.08653 .65629 Mdot
.016 w
.08653 .65629 m
.0864 .65502 L
s
1 .483 0 r
.008 w
.0864 .65502 Mdot
.016 w
.0864 .65502 m
.08637 .65434 L
s
1 .467 0 r
.008 w
.08637 .65434 Mdot
.016 w
.08637 .65434 m
.08639 .65394 L
s
1 .45 0 r
.008 w
.08639 .65394 Mdot
.016 w
.08639 .65394 m
.08639 .65354 L
s
1 .433 0 r
.008 w
.08639 .65354 Mdot
.016 w
.08639 .65354 m
.08633 .65307 L
s
1 .417 0 r
.008 w
.08633 .65307 Mdot
.016 w
.08633 .65307 m
.08619 .65246 L
s
1 .4 0 r
.008 w
.08619 .65246 Mdot
.016 w
.08619 .65246 m
.08595 .65134 L
s
1 .383 0 r
.008 w
.08595 .65134 Mdot
.016 w
.08595 .65134 m
.08559 .64948 L
s
1 .367 0 r
.008 w
.08559 .64948 Mdot
.016 w
.08559 .64948 m
.08519 .64715 L
s
1 .35 0 r
.008 w
.08519 .64715 Mdot
.016 w
.08519 .64715 m
.08474 .64448 L
s
1 .333 0 r
.008 w
.08474 .64448 Mdot
.016 w
.08474 .64448 m
.08425 .64164 L
s
1 .317 0 r
.008 w
.08425 .64164 Mdot
.016 w
.08425 .64164 m
.08377 .63869 L
s
1 .3 0 r
.008 w
.08377 .63869 Mdot
.016 w
.08377 .63869 m
.08329 .63575 L
s
1 .283 0 r
.008 w
.08329 .63575 Mdot
.016 w
.08329 .63575 m
.08282 .63287 L
s
1 .267 0 r
.008 w
.08282 .63287 Mdot
.016 w
.08282 .63287 m
.08244 .63028 L
s
1 .25 0 r
.008 w
.08244 .63028 Mdot
.016 w
.08244 .63028 m
.08213 .62796 L
s
1 .233 0 r
.008 w
.08213 .62796 Mdot
.016 w
.08213 .62796 m
.08189 .62603 L
s
1 .217 0 r
.008 w
.08189 .62603 Mdot
.016 w
.08189 .62603 m
.08177 .62454 L
s
1 .2 0 r
.008 w
.08177 .62454 Mdot
.016 w
.08177 .62454 m
.08179 .62346 L
s
1 .183 0 r
.008 w
.08179 .62346 Mdot
.016 w
.08179 .62346 m
.08194 .62282 L
s
1 .167 0 r
.008 w
.08194 .62282 Mdot
.016 w
.08194 .62282 m
.0822 .62255 L
s
1 .15 0 r
.008 w
.0822 .62255 Mdot
.016 w
.0822 .62255 m
.08254 .62256 L
s
1 .133 0 r
.008 w
.08254 .62256 Mdot
.016 w
.08254 .62256 m
.08291 .62275 L
s
1 .117 0 r
.008 w
.08291 .62275 Mdot
.016 w
.08291 .62275 m
.08328 .62308 L
s
1 .1 0 r
.008 w
.08328 .62308 Mdot
.016 w
.08328 .62308 m
.08363 .62348 L
s
1 .083 0 r
.008 w
.08363 .62348 Mdot
.016 w
.08363 .62348 m
.08395 .6239 L
s
1 .067 0 r
.008 w
.08395 .6239 Mdot
.016 w
.08395 .6239 m
.08421 .62429 L
s
1 .05 0 r
.008 w
.08421 .62429 Mdot
.016 w
.08421 .62429 m
.08441 .62463 L
s
1 .033 0 r
.008 w
.08441 .62463 Mdot
.016 w
.08441 .62463 m
.08458 .62489 L
s
1 .017 0 r
.008 w
.08458 .62489 Mdot
.016 w
.08458 .62489 m
.08473 .62507 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Dmk`]oo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Cg_2goo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4
?Nl=Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`@mk`eoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo13g_3Goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol027oo13g_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo13g_4goo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_lgoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool5?NocOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Dmko5oo`03001oogoo00io
o`003goo00<007ooOol01goo1Cg_lGoo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4?NobOol0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`@mko9oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo13g_lWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool4?NoaOol00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`@mko5oo`03001oogoo00moo`0047oo00<007ooOol01Woo0cg_00=lH7ooOol0
kgoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool00cg_O:1lH002O63`Ool00`00Oomoo`0?Ool0
015oo`03001oogoo00Eoo`03?NmlH7aP009l0003O61oogoo0>eoo`03001oogoo00moo`004Goo00<0
07ooOol01Woo00=lH7`0O0000W`000=lH7ooOol0jgoo00<007ooOol047oo000AOol00`00Oomoo`06
Ool00gbPO01l0002O03^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`9lX09l0003OB1oogoo
0>aoo`03001oogoo011oo`004Woo00<007ooOol01Goo17cP0WdPk7oo00<007ooOol04Goo000BOol0
0`00Oomoo`05Ool4O>000gdPOomoo`3[Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`Am8>eo
o`03001oogoo015oo`004goo00<007ooOol01Goo17dP00<mkgooOol0jGoo00<007ooOol04Woo000C
Ool00`00Oomoo`05Ool4OD000cg_Oomoo`3YOol00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`Am
H003OP1oogoo0>Uoo`03001oogoo019oo`0057oo00<007ooOol017oo17eP00=n03g_Ool0j7oo00<0
07ooOol04goo000DOol00`00Oomoo`04Ool4OH000gh0?Nmoo`3XOol00`00Oomoo`0COol001Eoo`03
001oogoo00=oo`Amh003OP0mkgoo0>Qoo`03001oogoo01=oo`005Goo00<007ooOol017oo17hP00<m
kgooOol0iWoo00<007ooOol057oo000EOol00`00Oomoo`04Ool4OR000cg_Oomoo`3VOol00`00Oomo
o`0DOol001Eoo`03001oogoo00Aoo`An@003?Nmoogoo0>Ioo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo17i000=nP7ooOol0iGoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool4OV02OX3VOol0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`AnH003OX1oogoo0>Aoo`03001oogoo01Ioo`005goo
00<007ooOol00goo17j000<mkgooOol0hgoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool4OX00
0cg_Oomoo`3ROol00`00Oomoo`0GOol001Qoo`03001oogoo009oo`AnX003O/1oogoo0>9oo`03001o
ogoo01Moo`006Goo00@007ooOomoo`AnX09n`>=oo`03001oogoo01Moo`006Goo00@007ooOomoo`En
`08mkn5oo`03001oogoo01Qoo`006Woo00D007ooOomoogkP009n`003O^1o@3g_0>5oo`03001oogoo
01Qoo`006Woo00@007ooOomoo`Anh003Od1o`7oo0=moo`03001oogoo01Uoo`006goo00<007ooOol0
17l000=o@7o0Ool0gWoo00<007ooOol06Woo000KOol00`00Oomoo`04Ob000gm0Ol1oo`3NOol00`00
Oomoo`0JOol001aoo`03001oogoo00AoH003Ol1oogoo0=aoo`03001oogoo01]oo`0077oo00<007oo
Ool01Cg_gWoo00<007ooOol06goo000MOol00`00Oomoo`04?NoMOol00`00Oomoo`0LOol001eoo`03
001oogoo00@mkmeoo`03001oogoo01aoo`007Woo00<007oo?Nl013g_fgoo00<007ooOol07Goo000N
Ool00`00Oolmk`04?NoKOol00`00Oomoo`0MOol001moo`03000mkcg_00@mkmUoo`03001oogoo01io
o`007goo00<003g_?Nl01Cg_f7oo00<007ooOol07Woo000POol00`00?Nlmk`05?NoFOol00`00Oomo
o`0OOol0021oo`03000mkcg_00DmkmIoo`03001oogoo01moo`008Goo00<003g_?Nl01Sg_dgoo00<0
07ooOol087oo000ROol00`00?Nlmk`06?NoAOol00`00Oomoo`0QOol002=oo`03001oocg_00Dmkm1o
o`03001oogoo029oo`0097oo00<003g_?Nl01Sg_cGoo00<007ooOol08goo000TOol00`00?Nlmk`07
?No<Ool00`00Oomoo`0SOol002Eoo`03000mkcg_00LmklYoo`03001oogoo02Aoo`009Woo00<003g_
?Nl01cg_b7oo00<007ooOol09Goo000VOol00`00Oolmk`0;?No4Ool00`00Oomoo`0UOol002Moo`03
001oocg_00Xmkl=oo`03001oogoo02Ioo`00:7oo00@007ooOomoo`Pmkl9oo`03001oogoo02Moo`00
:Goo00@007ooOomoo`Pmkl1oo`03001oogoo02Qoo`00:Woo00<007ooOol023g__goo00<007ooOol0
:Goo000ZOol01000Oomoogoo23g__Woo00<007ooOol0:Goo000[Ool00`00Oomoo`02Ool6?NnmOol0
0`00Oomoo`0ZOol002aoo`04001oogooOol7?NnkOol00`00Oomoo`0[Ool002eoo`03001oogoo00Pm
kkUoo`03001oogoo02aoo`00;Woo00<007ooOol023g_]goo00<007ooOol0;Goo000^Ool01000Oomo
ogoo23g_]Woo00<007ooOol0;Goo000_Ool01000Oomoogoo2Cg_/goo00<007ooOol0;Woo000`Ool0
1000Oomoogoo23g_/Woo00<007ooOol0;goo000aOol01000Oomoogoo23g_/7oo00<007ooOol0<7oo
000bOol20003Ool7?Nn]Ool2000cOol003Aoo`04001oogooOol7?Nn[Ool00`00Oomoo`0cOol003Eo
o`04001oogooOol7?NnYOol00`00Oomoo`0dOol003Eoo`04001oogooOol8?NnXOol00`00Oomoo`0d
Ool003Ioo`04001oogooOol8?NnVOol00`00Oomoo`0eOol003Moo`03001oogoo00=oo`HmkjAoo`03
001oogoo03Ioo`00>7oo00<007ooOol00goo1Sg_XWoo00<007ooOol0=goo000iOol20004Ool7?NnN
Ool2000jOol003]oo`04001oogooOol8?NnLOol00`00Oomoo`0jOol003aoo`03001oogoo00TmkiYo
o`03001oogoo03]oo`00?Goo00<007ooOol02Sg_Ugoo00<007ooOol0?7oo000nOol20003Ool8?NnD
Ool2000oOol0041oo`03001oogoo00Tmki9oo`03001oogoo03moo`00@Goo0P0000=oocg_?Nl01cg_
Sgoo0P00@Woo0013Ool00`00Oolmk`08?Nn=Ool00`00Oomoo`12Ool004Aoo`03001oocg_00Pmkh]o
o`03001oogoo04=oo`00AGoo00@007ooOomoo`LmkhUoo`03001oogoo04Aoo`00AWoo0P0000=oocg_
?Nl01cg_QGoo0P00Agoo0018Ool2000;?Nl3Ool2?NmkOol20019Ool004Yoo`03000mkcg_00hmkgQo
o`8004]oo`00C7oo43g_MGoo0P00CGoo001>Ool00`00Oolmk`0<?NmcOol00`00Oomoo`1=Ool004mo
o`03000mkcg_00hmkfmoo`03001oogoo04ioo`00D7oo0P000Woo3cg_JWoo0P00DGoo001BOol20000
0goo?Nlmk`02Ool<?NmVOol2001COol005Aoo`800003?Nmoogoo00lmk`Qoo`DmkeAoo`8005Eoo`00
EWoo0P0017oo43g_0goo1Sg_DWoo0P00Egoo001HOol30004OolF?Nm?Ool3001IOol005]oo`<000Eo
oa8mkdaoo`<005aoo`00GWoo0P001Woo43g_B7oo0`00Ggoo001POol20006Ool@?Nm5Ool00`00Oomo
o`1POol0069oo`<000Moo`hmkd1oo`<006=oo`00IGoo0`001goo3Sg_37oo2Cg_9Goo0`00IWoo001X
Ool40006OolP?NlQOol4001YOol006aoo`@000=ooalmkaeoo`@006eoo`00L7oo0`000goo73g_6Goo
1000LGoo001cOol500000goo?Nlmk`0G?NlEOol4001eOol007Qoo`D001Dmk`ioo`L007Uoo`00Ogoo
1`0023g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool008]oo`8000Eoo`<008]oo`00RWoo00@007ooOol000Eoo`03001oogoo08Yoo`00SGoo00<007oo
Ool01@00Rgoo002;Ool20003Ool01000Oomoo`00S7oo002;Ool00`00Oomoo`03Ool00`00Ool0002<
Ool008]oo`<000Aoo`8008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(55)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
1 .99 0 r
.008 w
.08503 .62555 Mdot
.016 w
.08503 .62555 m
.08495 .62573 L
s
1 .979 0 r
.008 w
.08495 .62573 Mdot
.016 w
.08495 .62573 m
.08478 .62589 L
s
1 .969 0 r
.008 w
.08478 .62589 Mdot
.016 w
.08478 .62589 m
.08451 .62594 L
s
1 .959 0 r
.008 w
.08451 .62594 Mdot
.016 w
.08451 .62594 m
.08413 .62582 L
s
1 .948 0 r
.008 w
.08413 .62582 Mdot
.016 w
.08413 .62582 m
.08366 .62544 L
s
1 .938 0 r
.008 w
.08366 .62544 Mdot
.016 w
.08366 .62544 m
.08311 .62475 L
s
1 .928 0 r
.008 w
.08311 .62475 Mdot
.016 w
.08311 .62475 m
.08251 .62369 L
s
1 .918 0 r
.008 w
.08251 .62369 Mdot
.016 w
.08251 .62369 m
.0819 .62228 L
s
1 .907 0 r
.008 w
.0819 .62228 Mdot
.016 w
.0819 .62228 m
.0813 .62046 L
s
1 .897 0 r
.008 w
.0813 .62046 Mdot
.016 w
.0813 .62046 m
.08068 .61822 L
s
1 .887 0 r
.008 w
.08068 .61822 Mdot
.016 w
.08068 .61822 m
.08006 .61581 L
s
1 .876 0 r
.008 w
.08006 .61581 Mdot
.016 w
.08006 .61581 m
.07948 .61305 L
s
1 .866 0 r
.008 w
.07948 .61305 Mdot
.016 w
.07948 .61305 m
.07896 .60988 L
s
1 .856 0 r
.008 w
.07896 .60988 Mdot
.016 w
.07896 .60988 m
.0785 .60678 L
s
1 .845 0 r
.008 w
.0785 .60678 Mdot
.016 w
.0785 .60678 m
.07811 .60339 L
s
1 .835 0 r
.008 w
.07811 .60339 Mdot
.016 w
.07811 .60339 m
.07777 .59999 L
s
1 .825 0 r
.008 w
.07777 .59999 Mdot
.016 w
.07777 .59999 m
.07747 .59651 L
s
1 .814 0 r
.008 w
.07747 .59651 Mdot
.016 w
.07747 .59651 m
.07719 .59318 L
s
1 .804 0 r
.008 w
.07719 .59318 Mdot
.016 w
.07719 .59318 m
.0769 .58988 L
s
1 .794 0 r
.008 w
.0769 .58988 Mdot
.016 w
.0769 .58988 m
.07658 .58663 L
s
1 .784 0 r
.008 w
.07658 .58663 Mdot
.016 w
.07658 .58663 m
.07619 .58338 L
s
1 .773 0 r
.008 w
.07619 .58338 Mdot
.016 w
.07619 .58338 m
.07574 .58013 L
s
1 .763 0 r
.008 w
.07574 .58013 Mdot
.016 w
.07574 .58013 m
.07525 .57681 L
s
1 .753 0 r
.008 w
.07525 .57681 Mdot
.016 w
.07525 .57681 m
.07473 .57335 L
s
1 .742 0 r
.008 w
.07473 .57335 Mdot
.016 w
.07473 .57335 m
.07417 .56961 L
s
1 .732 0 r
.008 w
.07417 .56961 Mdot
.016 w
.07417 .56961 m
.07356 .56606 L
s
1 .722 0 r
.008 w
.07356 .56606 Mdot
.016 w
.07356 .56606 m
.07291 .56232 L
s
1 .711 0 r
.008 w
.07291 .56232 Mdot
.016 w
.07291 .56232 m
.07227 .55856 L
s
1 .701 0 r
.008 w
.07227 .55856 Mdot
.016 w
.07227 .55856 m
.07162 .55481 L
s
1 .691 0 r
.008 w
.07162 .55481 Mdot
.016 w
.07162 .55481 m
.07097 .5512 L
s
1 .68 0 r
.008 w
.07097 .5512 Mdot
.016 w
.07097 .5512 m
.07035 .54777 L
s
1 .67 0 r
.008 w
.07035 .54777 Mdot
.016 w
.07035 .54777 m
.06975 .54434 L
s
1 .66 0 r
.008 w
.06975 .54434 Mdot
.016 w
.06975 .54434 m
.06919 .54117 L
s
1 .649 0 r
.008 w
.06919 .54117 Mdot
.016 w
.06919 .54117 m
.0687 .53803 L
s
1 .639 0 r
.008 w
.0687 .53803 Mdot
.016 w
.0687 .53803 m
.06832 .53505 L
s
1 .629 0 r
.008 w
.06832 .53505 Mdot
.016 w
.06832 .53505 m
.06803 .53216 L
s
1 .619 0 r
.008 w
.06803 .53216 Mdot
.016 w
.06803 .53216 m
.06784 .52937 L
s
1 .608 0 r
.008 w
.06784 .52937 Mdot
.016 w
.06784 .52937 m
.06776 .52651 L
s
1 .598 0 r
.008 w
.06776 .52651 Mdot
.016 w
.06776 .52651 m
.06779 .52362 L
s
1 .588 0 r
.008 w
.06779 .52362 Mdot
.016 w
.06779 .52362 m
.06794 .52047 L
s
1 .577 0 r
.008 w
.06794 .52047 Mdot
.016 w
.06794 .52047 m
.0682 .51736 L
s
1 .567 0 r
.008 w
.0682 .51736 Mdot
.016 w
.0682 .51736 m
.06856 .514 L
s
1 .557 0 r
.008 w
.06856 .514 Mdot
.016 w
.06856 .514 m
.06903 .51056 L
s
1 .546 0 r
.008 w
.06903 .51056 Mdot
.016 w
.06903 .51056 m
.06956 .50697 L
s
1 .536 0 r
.008 w
.06956 .50697 Mdot
.016 w
.06956 .50697 m
.07017 .50354 L
s
1 .526 0 r
.008 w
.07017 .50354 Mdot
.016 w
.07017 .50354 m
.07076 .50025 L
s
1 .515 0 r
.008 w
.07076 .50025 Mdot
.016 w
.07076 .50025 m
.07136 .49729 L
s
1 .505 0 r
.008 w
.07136 .49729 Mdot
.016 w
.07136 .49729 m
.07193 .49464 L
s
1 .495 0 r
.008 w
.07193 .49464 Mdot
.016 w
.07193 .49464 m
.07245 .49231 L
s
1 .485 0 r
.008 w
.07245 .49231 Mdot
.016 w
.07245 .49231 m
.07291 .49037 L
s
1 .474 0 r
.008 w
.07291 .49037 Mdot
.016 w
.07291 .49037 m
.07331 .48878 L
s
1 .464 0 r
.008 w
.07331 .48878 Mdot
.016 w
.07331 .48878 m
.07365 .48743 L
s
1 .454 0 r
.008 w
.07365 .48743 Mdot
.016 w
.07365 .48743 m
.07394 .48628 L
s
1 .443 0 r
.008 w
.07394 .48628 Mdot
.016 w
.07394 .48628 m
.07416 .4853 L
s
1 .433 0 r
.008 w
.07416 .4853 Mdot
.016 w
.07416 .4853 m
.07431 .48445 L
s
1 .423 0 r
.008 w
.07431 .48445 Mdot
.016 w
.07431 .48445 m
.0744 .4837 L
s
1 .412 0 r
.008 w
.0744 .4837 Mdot
.016 w
.0744 .4837 m
.07444 .483 L
s
1 .402 0 r
.008 w
.07444 .483 Mdot
.016 w
.07444 .483 m
.07444 .48228 L
s
1 .392 0 r
.008 w
.07444 .48228 Mdot
.016 w
.07444 .48228 m
.07445 .48156 L
s
1 .381 0 r
.008 w
.07445 .48156 Mdot
.016 w
.07445 .48156 m
.0745 .48074 L
s
1 .371 0 r
.008 w
.0745 .48074 Mdot
.016 w
.0745 .48074 m
.07459 .47983 L
s
1 .361 0 r
.008 w
.07459 .47983 Mdot
.016 w
.07459 .47983 m
.07473 .47886 L
s
1 .351 0 r
.008 w
.07473 .47886 Mdot
.016 w
.07473 .47886 m
.07494 .47789 L
s
1 .34 0 r
.008 w
.07494 .47789 Mdot
.016 w
.07494 .47789 m
.07522 .47701 L
s
1 .33 0 r
.008 w
.07522 .47701 Mdot
.016 w
.07522 .47701 m
.07553 .47627 L
s
1 .32 0 r
.008 w
.07553 .47627 Mdot
.016 w
.07553 .47627 m
.07584 .47568 L
s
1 .309 0 r
.008 w
.07584 .47568 Mdot
.016 w
.07584 .47568 m
.07613 .47522 L
s
1 .299 0 r
.008 w
.07613 .47522 Mdot
.016 w
.07613 .47522 m
.07641 .47485 L
s
1 .289 0 r
.008 w
.07641 .47485 Mdot
.016 w
.07641 .47485 m
.07666 .47454 L
s
1 .278 0 r
.008 w
.07666 .47454 Mdot
.016 w
.07666 .47454 m
.07686 .47423 L
s
1 .268 0 r
.008 w
.07686 .47423 Mdot
.016 w
.07686 .47423 m
.07701 .47389 L
s
1 .258 0 r
.008 w
.07701 .47389 Mdot
.016 w
.07701 .47389 m
.0771 .47349 L
s
1 .247 0 r
.008 w
.0771 .47349 Mdot
.016 w
.0771 .47349 m
.07716 .47304 L
s
1 .237 0 r
.008 w
.07716 .47304 Mdot
.016 w
.07716 .47304 m
.07723 .47258 L
s
1 .227 0 r
.008 w
.07723 .47258 Mdot
.016 w
.07723 .47258 m
.07731 .47213 L
s
1 .216 0 r
.008 w
.07731 .47213 Mdot
.016 w
.07731 .47213 m
.07742 .47171 L
s
1 .206 0 r
.008 w
.07742 .47171 Mdot
.016 w
.07742 .47171 m
.07753 .4713 L
s
1 .196 0 r
.008 w
.07753 .4713 Mdot
.016 w
.07753 .4713 m
.07763 .47089 L
s
1 .186 0 r
.008 w
.07763 .47089 Mdot
.016 w
.07763 .47089 m
.07775 .47047 L
s
1 .175 0 r
.008 w
.07775 .47047 Mdot
.016 w
.07775 .47047 m
.07792 .47004 L
s
1 .165 0 r
.008 w
.07792 .47004 Mdot
.016 w
.07792 .47004 m
.07814 .46961 L
s
1 .155 0 r
.008 w
.07814 .46961 Mdot
.016 w
.07814 .46961 m
.07842 .4692 L
s
1 .144 0 r
.008 w
.07842 .4692 Mdot
.016 w
.07842 .4692 m
.07875 .46881 L
s
1 .134 0 r
.008 w
.07875 .46881 Mdot
.016 w
.07875 .46881 m
.07912 .46843 L
s
1 .124 0 r
.008 w
.07912 .46843 Mdot
.016 w
.07912 .46843 m
.07954 .46806 L
s
1 .113 0 r
.008 w
.07954 .46806 Mdot
.016 w
.07954 .46806 m
.07998 .4677 L
s
1 .103 0 r
.008 w
.07998 .4677 Mdot
.016 w
.07998 .4677 m
.08044 .46732 L
s
1 .093 0 r
.008 w
.08044 .46732 Mdot
.016 w
.08044 .46732 m
.08085 .46692 L
s
1 .082 0 r
.008 w
.08085 .46692 Mdot
.016 w
.08085 .46692 m
.0812 .46647 L
s
1 .072 0 r
.008 w
.0812 .46647 Mdot
.016 w
.0812 .46647 m
.08148 .46605 L
s
1 .062 0 r
.008 w
.08148 .46605 Mdot
.016 w
.08148 .46605 m
.08177 .46565 L
s
1 .052 0 r
.008 w
.08177 .46565 Mdot
.016 w
.08177 .46565 m
.08204 .4653 L
s
1 .041 0 r
.008 w
.08204 .4653 Mdot
.016 w
.08204 .4653 m
.08231 .46503 L
s
1 .031 0 r
.008 w
.08231 .46503 Mdot
.016 w
.08231 .46503 m
.08256 .46483 L
s
1 .021 0 r
.008 w
.08256 .46483 Mdot
.016 w
.08256 .46483 m
.08278 .46471 L
s
1 .01 0 r
.008 w
.08278 .46471 Mdot
.016 w
.08278 .46471 m
.08295 .46465 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo00<mkga0O4000W`0
23g_jgoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool00cg_O61l@004O008?NoZOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Qoo`03?NmlH7a000Al00TmknUoo`03001oogoo00aoo`003Goo00<0
07ooOol027oo00Am@7aPO41l@09l00/mknQoo`03001oogoo00aoo`0037oo00<007ooOol027oo00<m
kge0O60017a033g_j7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool2?Nl00ge0O:1lX002O:04
?Nl4Ool5?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`<mk`03OD1lh7cP009lh0lmknIo
o`03001oogoo00]oo`0037oo00<007ooOol01Goo13g_17e043g_iWoo00<007ooOol02goo000<Ool0
0`00Oomoo`08Ool00ggPOH1mP002OH0@?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03
ON1mX7fP009mX003?Nmoocg_00dmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo00=mh7g0
OL000Wg000<mkgooOol017oo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5ON0;Ool6
?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`An0003?Nmoogoo00Uoo`HmknEoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo17h03Goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomo
o`08Ool4OP0<Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`03OT1n87hP009n8003
OT1oogoo00Uoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol01goo00=n@7hPOR000WhP37oo
2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool00gi0OR1n8002OR0<Ool:?NoQOol00`00
Oomoo`0;Ool000eoo`03001oogoo00Ioo`An@0eoo`/mkn1oo`03001oogoo00]oo`003Goo00<007oo
Ool01Woo17i04Goo1cg_ggoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool4OV000gj0Oomoo`0>
Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`AnH09nP0moo`Pmkmioo`03001oogoo
00aoo`003Goo00<007ooOol01Woo17iP00=nP3g_Ool03Woo23g_gWoo00<007ooOol037oo000=Ool0
0`00Oomoo`06Ool00cg_OX1nP002OX000cg_Oomoo`0>Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03
001oogoo00Moo`AnP003?Nmoogoo00ioo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo
17jP00<mkgooOol03Woo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool4OZ000gk0Oomo
o`0>Ool9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`AnX09n`0moo`/mkmYoo`03001o
ogoo00aoo`003Goo00<007ooOol01goo1Gk04Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomo
o`08Ool4O/0BOol9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo00Moo`An`1=oo`PmkmUoo`03
001oogoo00eoo`003Woo00<007ooOol01goo17kP00<mkgooOol047oo1Cg_g7oo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool4O^000gl0Oomoo`3aOol00`00Oomoo`0=Ool000ioo`03001oogoo00Mo
o`Anh09o0?9oo`03001oogoo00eoo`003goo00<007ooOol01Woo1Gl0lgoo00<007ooOol03Goo000?
Ool00`00Oomoo`07Ool4O`000cg_Oomoo`3_Ool00`00Oomoo`0>Ool000moo`03001oogoo00Moo`Ao
0003?Nmoogoo0>moo`03001oogoo00ioo`003goo00<007ooOol01goo17lPlWoo00<007ooOol03Woo
000?Ool00`00Oomoo`07Ool4Ob3bOol00`00Oomoo`0>Ool0011oo`03001oogoo00Ioo`Ao@?9oo`03
001oogoo00ioo`0047oo00<007ooOol01Woo17m0lGoo00<007ooOol03goo000@Ool00`00Oomoo`06
Ool4Od000gmPOomoo`3^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`IoH>moo`03001oogoo
00moo`0047oo00<007ooOol01Woo1GmPl7oo00<007ooOol03goo000AOol00`00Oomoo`05Ool01Sg_
Oh1oH7mPOh1oX>moo`03001oogoo00moo`004Goo00<007ooOol01Woo17n000=oX3g_Ool0k7oo00<0
07ooOol047oo000AOol00`00Oomoo`06Ool4Oh000gnPOomoo`3/Ool00`00Oomoo`0@Ool0019oo`03
001oogoo00Eoo`EoX>ioo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool4?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneo
o`03001oogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomo
o`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`00
57oo00<007ooOol017oo1Sg_jGoo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00
Oomoo`0COol001Eoo`03001oogoo00=oo`HmknUoo`03001oogoo01=oo`005Goo00<007ooOol017oo
1Cg_j7oo00<007ooOol057oo000EOol00`00Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03
001oogoo00Aoo`DmknQoo`03001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol0
5Goo000FOol00`00Oomoo`03Ool5?NoWOol00`00Oomoo`0EOol001Moo`03001oogoo00=oo`@mknIo
o`03001oogoo01Ioo`005goo00<007ooOol00goo1Cg_iGoo00<007ooOol05Woo000HOol00`00Oomo
o`02Ool5?NoTOol00`00Oomoo`0GOol001Qoo`03001oogoo009oo`DmknAoo`03001oogoo01Moo`00
6Goo00@007ooOomoo`Hmkn=oo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_hGoo00<007oo
Ool067oo000JOol01000Oomoogoo1Sg_hGoo00<007ooOol067oo000JOol01000Oomoogoo1Sg_h7oo
00<007ooOol06Goo000KOol00`00Oomoo`06?NoOOol00`00Oomoo`0JOol001]oo`03001oogoo00Hm
kmmoo`03001oogoo01Yoo`0077oo00<007ooOol01Cg_gWoo00<007ooOol06goo000LOol00`00Oomo
o`05?NoNOol00`00Oomoo`0KOol001eoo`03001oogoo00@mkmeoo`03001oogoo01aoo`007Goo00<0
07ooOol013g_gGoo00<007ooOol077oo000NOol00`00Oolmk`04?NoKOol00`00Oomoo`0MOol001io
o`03001oocg_00@mkm]oo`03001oogoo01eoo`007goo00<003g_?Nl013g_fGoo00<007ooOol07Woo
000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03000mkcg_00DmkmIoo`03001oogoo
01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000QOol00`00?Nlmk`06?NoCOol00`00
Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025oo`008goo00<007oo?Nl01Cg_d7oo
00<007ooOol08Woo000TOol00`00?Nlmk`06?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_00Lm
klaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00?Nlm
k`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo00<0
07oo?Nl02Sg_`goo00<007ooOol09Woo000XOol01000Oomoogoo23g_`Woo00<007ooOol09goo000Y
Ool01000Oomoogoo23g_`7oo00<007ooOol0:7oo000ZOol00`00Oomoo`08?NnoOol00`00Oomoo`0Y
Ool002Yoo`04001oogooOol8?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo009oo`Hmkkeoo`03
001oogoo02Yoo`00;7oo00@007ooOomoo`Lmkk]oo`03001oogoo02]oo`00;Goo00<007ooOol023g_
^Goo00<007ooOol0;7oo000^Ool00`00Oomoo`08?NngOol00`00Oomoo`0]Ool002ioo`04001oogoo
Ool8?NnfOol00`00Oomoo`0]Ool002moo`04001oogooOol9?NncOol00`00Oomoo`0^Ool0031oo`04
001oogooOol8?NnbOol00`00Oomoo`0_Ool0035oo`04001oogooOol8?Nn`Ool00`00Oomoo`0`Ool0
039oo`8000=oo`Lmkjeoo`8003=oo`00=7oo00@007ooOomoo`Lmkj]oo`03001oogoo03=oo`00=Goo
00@007ooOomoo`LmkjUoo`03001oogoo03Aoo`00=Goo00@007ooOomoo`PmkjQoo`03001oogoo03Ao
o`00=Woo00@007ooOomoo`PmkjIoo`03001oogoo03Eoo`00=goo00<007ooOol00goo1Sg_Y7oo00<0
07ooOol0=Woo000hOol00`00Oomoo`03Ool6?NnROol00`00Oomoo`0gOol003Uoo`8000Aoo`Lmkiio
o`8003Yoo`00>goo00@007ooOomoo`Pmkiaoo`03001oogoo03Yoo`00?7oo00<007ooOol02Cg_VWoo
00<007ooOol0>goo000mOol00`00Oomoo`0:?NnGOol00`00Oomoo`0lOol003ioo`8000=oo`PmkiAo
o`8003moo`00@7oo00<007ooOol02Cg_TWoo00<007ooOol0?goo0011Ool200000goo?Nlmk`07?Nn?
Ool20012Ool004=oo`03001oocg_00Pmkheoo`03001oogoo049oo`00A7oo00<007oo?Nl023g_Rgoo
00<007ooOol0@goo0015Ool01000Oomoogoo1cg_RGoo00<007ooOol0A7oo0016Ool200000goo?Nlm
k`07?Nn5Ool20017Ool004Qoo`8000/mk`=oo`8mkg]oo`8004Uoo`00BWoo00<003g_?Nl03Sg_N7oo
0P00Bgoo001<Ool@?NmeOol2001=Ool004ioo`03001oocg_00`mkg=oo`03001oogoo04eoo`00Cgoo
00<003g_?Nl03Sg_Kgoo00<007ooOol0CWoo001@Ool20002Ool??NmZOol2001AOol0059oo`800003
Oolmkcg_009oo``mkfIoo`8005=oo`00E7oo0P0000<mkgooOol03cg_27oo1Cg_E7oo0P00EGoo001F
Ool20004Ool@?Nl3Ool6?NmBOol2001GOol005Qoo`<000AooaHmkdmoo`<005Uoo`00Fgoo0`001Goo
4Sg_C7oo0`00G7oo001NOol20006Ool@?Nm8Ool3001OOol0061oo`8000Iooa0mkdEoo`03001oogoo
061oo`00HWoo0`001goo3Sg_@7oo0`00Hgoo001UOol30007Ool>?Nl<Ool9?NlUOol3001VOol006Qo
o`@000Ioob0mkb5oo`@006Uoo`00K7oo10000goo7cg_7Goo1000KGoo001`Ool30003OolL?NlIOol4
001aOol007=oo`D00003Oolmkcg_01LmkaEoo`@007Eoo`00N7oo1@005Cg_3Woo1`00NGoo001oOol7
0008?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00Rgoo0P0017oo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00SGoo00<007oo
Ool00goo00<007ooOol0RWoo002;Ool20004Ool2002=Ool008]oo`03001oogoo00=oo`03001oogoo
08aoo`00Rgoo0`000goo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(56)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
1 .983 0 r
.008 w
.08301 .46465 Mdot
.016 w
.08301 .46465 m
.08292 .46484 L
s
1 .966 0 r
.008 w
.08292 .46484 Mdot
.016 w
.08292 .46484 m
.08277 .46511 L
s
1 .949 0 r
.008 w
.08277 .46511 Mdot
.016 w
.08277 .46511 m
.08256 .46546 L
s
1 .932 0 r
.008 w
.08256 .46546 Mdot
.016 w
.08256 .46546 m
.08233 .46583 L
s
1 .915 0 r
.008 w
.08233 .46583 Mdot
.016 w
.08233 .46583 m
.08214 .4662 L
s
1 .898 0 r
.008 w
.08214 .4662 Mdot
.016 w
.08214 .4662 m
.08196 .46658 L
s
1 .881 0 r
.008 w
.08196 .46658 Mdot
.016 w
.08196 .46658 m
.08173 .46697 L
s
1 .864 0 r
.008 w
.08173 .46697 Mdot
.016 w
.08173 .46697 m
.08146 .46741 L
s
1 .847 0 r
.008 w
.08146 .46741 Mdot
.016 w
.08146 .46741 m
.08114 .46785 L
s
1 .831 0 r
.008 w
.08114 .46785 Mdot
.016 w
.08114 .46785 m
.08073 .4684 L
s
1 .814 0 r
.008 w
.08073 .4684 Mdot
.016 w
.08073 .4684 m
.08023 .46902 L
s
1 .797 0 r
.008 w
.08023 .46902 Mdot
.016 w
.08023 .46902 m
.07966 .46972 L
s
1 .78 0 r
.008 w
.07966 .46972 Mdot
.016 w
.07966 .46972 m
.07904 .47051 L
s
1 .763 0 r
.008 w
.07904 .47051 Mdot
.016 w
.07904 .47051 m
.07841 .47138 L
s
1 .746 0 r
.008 w
.07841 .47138 Mdot
.016 w
.07841 .47138 m
.07779 .47232 L
s
1 .729 0 r
.008 w
.07779 .47232 Mdot
.016 w
.07779 .47232 m
.07722 .47333 L
s
1 .712 0 r
.008 w
.07722 .47333 Mdot
.016 w
.07722 .47333 m
.07675 .47428 L
s
1 .695 0 r
.008 w
.07675 .47428 Mdot
.016 w
.07675 .47428 m
.0763 .47525 L
s
1 .678 0 r
.008 w
.0763 .47525 Mdot
.016 w
.0763 .47525 m
.0758 .47627 L
s
1 .661 0 r
.008 w
.0758 .47627 Mdot
.016 w
.0758 .47627 m
.07524 .47743 L
s
1 .644 0 r
.008 w
.07524 .47743 Mdot
.016 w
.07524 .47743 m
.07487 .47845 L
s
1 .627 0 r
.008 w
.07487 .47845 Mdot
.016 w
.07487 .47845 m
.07456 .47934 L
s
1 .61 0 r
.008 w
.07456 .47934 Mdot
.016 w
.07456 .47934 m
.07437 .48004 L
s
1 .593 0 r
.008 w
.07437 .48004 Mdot
.016 w
.07437 .48004 m
.0743 .48055 L
s
1 .576 0 r
.008 w
.0743 .48055 Mdot
.016 w
.0743 .48055 m
.07432 .4809 L
s
1 .559 0 r
.008 w
.07432 .4809 Mdot
.016 w
.07432 .4809 m
.07438 .48114 L
s
1 .542 0 r
.008 w
.07438 .48114 Mdot
.016 w
.07438 .48114 m
.07446 .48131 L
s
1 .525 0 r
.008 w
.07446 .48131 Mdot
.016 w
.07446 .48131 m
.07448 .48146 L
s
1 .508 0 r
.008 w
.07448 .48146 Mdot
.016 w
.07448 .48146 m
.07443 .48169 L
s
1 .492 0 r
.008 w
.07443 .48169 Mdot
.016 w
.07443 .48169 m
.07428 .48205 L
s
1 .475 0 r
.008 w
.07428 .48205 Mdot
.016 w
.07428 .48205 m
.07408 .48252 L
s
1 .458 0 r
.008 w
.07408 .48252 Mdot
.016 w
.07408 .48252 m
.07382 .48307 L
s
1 .441 0 r
.008 w
.07382 .48307 Mdot
.016 w
.07382 .48307 m
.07355 .48368 L
s
1 .424 0 r
.008 w
.07355 .48368 Mdot
.016 w
.07355 .48368 m
.07327 .48437 L
s
1 .407 0 r
.008 w
.07327 .48437 Mdot
.016 w
.07327 .48437 m
.07301 .48509 L
s
1 .39 0 r
.008 w
.07301 .48509 Mdot
.016 w
.07301 .48509 m
.07275 .48578 L
s
1 .373 0 r
.008 w
.07275 .48578 Mdot
.016 w
.07275 .48578 m
.07247 .48647 L
s
1 .356 0 r
.008 w
.07247 .48647 Mdot
.016 w
.07247 .48647 m
.07218 .48714 L
s
1 .339 0 r
.008 w
.07218 .48714 Mdot
.016 w
.07218 .48714 m
.07188 .48772 L
s
1 .322 0 r
.008 w
.07188 .48772 Mdot
.016 w
.07188 .48772 m
.07157 .48816 L
s
1 .305 0 r
.008 w
.07157 .48816 Mdot
.016 w
.07157 .48816 m
.07127 .48845 L
s
1 .288 0 r
.008 w
.07127 .48845 Mdot
.016 w
.07127 .48845 m
.07098 .48863 L
s
1 .271 0 r
.008 w
.07098 .48863 Mdot
.016 w
.07098 .48863 m
.07071 .48875 L
s
1 .254 0 r
.008 w
.07071 .48875 Mdot
.016 w
.07071 .48875 m
.07049 .48885 L
s
1 .237 0 r
.008 w
.07049 .48885 Mdot
.016 w
.07049 .48885 m
.07031 .48898 L
s
1 .22 0 r
.008 w
.07031 .48898 Mdot
.016 w
.07031 .48898 m
.07018 .48919 L
s
1 .203 0 r
.008 w
.07018 .48919 Mdot
.016 w
.07018 .48919 m
.07008 .48944 L
s
1 .186 0 r
.008 w
.07008 .48944 Mdot
.016 w
.07008 .48944 m
.07001 .48983 L
s
1 .169 0 r
.008 w
.07001 .48983 Mdot
.016 w
.07001 .48983 m
.06997 .49028 L
s
1 .153 0 r
.008 w
.06997 .49028 Mdot
.016 w
.06997 .49028 m
.06998 .49075 L
s
1 .136 0 r
.008 w
.06998 .49075 Mdot
.016 w
.06998 .49075 m
.07005 .49118 L
s
1 .119 0 r
.008 w
.07005 .49118 Mdot
.016 w
.07005 .49118 m
.07018 .49163 L
s
1 .102 0 r
.008 w
.07018 .49163 Mdot
.016 w
.07018 .49163 m
.07034 .49206 L
s
1 .085 0 r
.008 w
.07034 .49206 Mdot
.016 w
.07034 .49206 m
.07055 .49246 L
s
1 .068 0 r
.008 w
.07055 .49246 Mdot
.016 w
.07055 .49246 m
.07079 .49279 L
s
1 .051 0 r
.008 w
.07079 .49279 Mdot
.016 w
.07079 .49279 m
.07104 .49301 L
s
1 .034 0 r
.008 w
.07104 .49301 Mdot
.016 w
.07104 .49301 m
.07124 .49313 L
s
1 .017 0 r
.008 w
.07124 .49313 Mdot
.016 w
.07124 .49313 m
.0714 .49318 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo00HmkgnPO`1o07nP
On07?No[Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`8mk`Ao0003On0mkcg_00HmknYoo`03
001oogoo00aoo`003Goo00<007ooOol027oo00Dmkgk0OZ1nX7k0009o00TmknUoo`03001oogoo00ao
o`003Goo00<007ooOol027oo00<mkgjPOZ000WjP00=o07oP?Nl02Cg_j7oo00<007ooOol037oo000<
Ool00`00Oomoo`08Ool00cg_OT1n@002OT02OZ0<?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Moo`8mk`AmX003OZ0mkcg_008mk`Aoo`DmknQoo`03001oogoo00]oo`0037oo00<007ooOol01Woo
0Sg_1Ge000=n`3g_?Nl03Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05Ool3?Nl4O6000ge0
?Nlmk`0>?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`05O61l@7`0O61m@00@?NoVOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`07O61l@7`0O61m@3g_Ool03Sg_iWoo00<007ooOol0
2goo000<Ool00`00Oomoo`08Ool4O602?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`AlH003?Nmoogoo00Uoo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Cg_2goo
1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4?Nl=Ool6?NoTOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_
37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Moo`@mk`eoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol01Woo
13g_3Goo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`06Ool4?NlAOol7?NoOOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol0
1Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool6?Nl?Ool8?NoNOol00`00
Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeoo`03001oogoo00aoo`003Goo00<007oo
Ool01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?Nl@Ool8?NoMOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tmkmaoo`03001oogoo00aoo`003Goo00<0
07ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4?NlAOol:?NoJ
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9oo`TmkmYoo`03001oogoo00aoo`003Woo
00<007ooOol01goo13g_4goo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool5?NlBOol5
?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmko=oo`03001oogoo00eoo`003Woo00<0
07ooOol01goo1Cg_lgoo00<007ooOol03Goo000?Ool00`00Oomoo`06Ool5?NocOol00`00Oomoo`0=
Ool000moo`03001oogoo00Moo`Dmko5oo`03001oogoo00ioo`003goo00<007ooOol01goo1Cg_lGoo
00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4?NobOol00`00Oomoo`0>Ool000moo`03001oogoo
00Moo`@mko9oo`03001oogoo00ioo`0047oo00<007ooOol01Woo13g_lWoo00<007ooOol03Woo000@
Ool00`00Oomoo`06Ool4?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001o
ogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5
?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hmknmoo`03001oogoo00moo`004Goo00<0
07ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool5?No^Ool00`00Oomoo`0@
Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo
00<007ooOol04Goo000BOol00`00Oomoo`06Ool4?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo
00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000C
Ool00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`Dmkn]oo`03001o
ogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007ooOol04goo000DOol00`00Oomoo`04Ool6
?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`HmknUoo`03001oogoo01=oo`005Goo00<0
07ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00Oomoo`04Ool5?NoXOol00`00Oomoo`0D
Ool001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_igoo
00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol00`00Oomoo`0EOol001Moo`03001oogoo
00=oo`@mknIoo`03001oogoo01Ioo`005goo00<007ooOol00goo1Cg_iGoo00<007ooOol05Woo000H
Ool00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qoo`03001oogoo009oo`DmknAoo`03001o
ogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_
hGoo00<007ooOol067oo000JOol01000Oomoogoo1Sg_hGoo00<007ooOol067oo000JOol01000Oomo
ogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoOOol00`00Oomoo`0JOol001]oo`03
001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol01Cg_gWoo00<007ooOol06goo000L
Ool00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001oogoo00@mkmeoo`03001oogoo01ao
o`007Goo00<007ooOol013g_gGoo00<007ooOol077oo000NOol00`00Oolmk`04?NoKOol00`00Oomo
o`0MOol001ioo`03001oocg_00@mkm]oo`03001oogoo01eoo`007goo00<003g_?Nl013g_fGoo00<0
07ooOol07Woo000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03000mkcg_00DmkmIo
o`03001oogoo01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000QOol00`00?Nlmk`06
?NoCOol00`00Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025oo`008goo00<007oo
?Nl01Cg_d7oo00<007ooOol08Woo000TOol00`00?Nlmk`06?No=Ool00`00Oomoo`0SOol002Aoo`03
000mkcg_00Lmklaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000V
Ool00`00?Nlmk`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eo
o`009goo00<007oo?Nl02Sg_`goo00<007ooOol09Woo000XOol01000Oomoogoo23g_`Woo00<007oo
Ool09goo000YOol01000Oomoogoo23g_`7oo00<007ooOol0:7oo000ZOol00`00Oomoo`08?NnoOol0
0`00Oomoo`0YOol002Yoo`04001oogooOol8?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo009o
o`Hmkkeoo`03001oogoo02Yoo`00;7oo00@007ooOomoo`Lmkk]oo`03001oogoo02]oo`00;Goo00<0
07ooOol023g_^Goo00<007ooOol0;7oo000^Ool00`00Oomoo`08?NngOol00`00Oomoo`0]Ool002io
o`04001oogooOol8?NnfOol00`00Oomoo`0]Ool002moo`04001oogooOol9?NncOol00`00Oomoo`0^
Ool0031oo`04001oogooOol8?NnbOol00`00Oomoo`0_Ool0035oo`04001oogooOol8?Nn`Ool00`00
Oomoo`0`Ool0039oo`8000=oo`Lmkjeoo`8003=oo`00=7oo00@007ooOomoo`Lmkj]oo`03001oogoo
03=oo`00=Goo00@007ooOomoo`LmkjUoo`03001oogoo03Aoo`00=Goo00@007ooOomoo`PmkjQoo`03
001oogoo03Aoo`00=Woo00@007ooOomoo`PmkjIoo`03001oogoo03Eoo`00=goo00<007ooOol00goo
1Sg_Y7oo00<007ooOol0=Woo000hOol00`00Oomoo`03Ool6?NnROol00`00Oomoo`0gOol003Uoo`80
00Aoo`Lmkiioo`8003Yoo`00>goo00@007ooOomoo`Pmkiaoo`03001oogoo03Yoo`00?7oo00<007oo
Ool02Cg_VWoo00<007ooOol0>goo000mOol00`00Oomoo`0:?NnGOol00`00Oomoo`0lOol003ioo`80
00=oo`PmkiAoo`8003moo`00@7oo00<007ooOol02Cg_TWoo00<007ooOol0?goo0011Ool200000goo
?Nlmk`07?Nn?Ool20012Ool004=oo`03001oocg_00Pmkheoo`03001oogoo049oo`00A7oo00<007oo
?Nl023g_Rgoo00<007ooOol0@goo0015Ool01000Oomoogoo1cg_RGoo00<007ooOol0A7oo0016Ool2
00000goo?Nlmk`07?Nn5Ool20017Ool004Qoo`8000/mk`=oo`8mkg]oo`8004Uoo`00BWoo00<003g_
?Nl03Sg_N7oo0P00Bgoo001<Ool@?NmeOol2001=Ool004ioo`03001oocg_00`mkg=oo`03001oogoo
04eoo`00Cgoo00<003g_?Nl03Sg_Kgoo00<007ooOol0CWoo001@Ool20002Ool??NmZOol2001AOol0
059oo`800003Oolmkcg_009oo``mkfIoo`8005=oo`00E7oo0P0000<mkgooOol03cg_27oo1Cg_E7oo
0P00EGoo001FOol20004Ool@?Nl3Ool6?NmBOol2001GOol005Qoo`<000AooaHmkdmoo`<005Uoo`00
Fgoo0`001Goo4Sg_C7oo0`00G7oo001NOol20006Ool@?Nm8Ool3001OOol0061oo`8000Iooa0mkdEo
o`03001oogoo061oo`00HWoo0`001goo3Sg_@7oo0`00Hgoo001UOol30007Ool>?Nl<Ool9?NlUOol3
001VOol006Qoo`@000Ioob0mkb5oo`@006Uoo`00K7oo10000goo7cg_7Goo1000KGoo001`Ool30003
OolL?NlIOol4001aOol007=oo`D00003Oolmkcg_01LmkaEoo`@007Eoo`00N7oo1@005Cg_3Woo1`00
NGoo001oOol70008?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00Rgoo0P000goo0`00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00
SGoo00@007ooOol0009oo`03001oogoo08Yoo`00Rgoo0P000goo0`00SGoo002;Ool00`00Oomoo`03
Ool00`00Oomoo`2<Ool008]oo`<000=oo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(57)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
1 .981 0 r
.008 w
.07677 .49733 Mdot
.016 w
.07677 .49733 m
.07671 .49746 L
s
1 .963 0 r
.008 w
.07671 .49746 Mdot
.016 w
.07671 .49746 m
.07662 .49772 L
s
1 .944 0 r
.008 w
.07662 .49772 Mdot
.016 w
.07662 .49772 m
.07647 .49813 L
s
1 .926 0 r
.008 w
.07647 .49813 Mdot
.016 w
.07647 .49813 m
.07621 .4987 L
s
1 .907 0 r
.008 w
.07621 .4987 Mdot
.016 w
.07621 .4987 m
.07584 .4995 L
s
1 .889 0 r
.008 w
.07584 .4995 Mdot
.016 w
.07584 .4995 m
.07534 .50051 L
s
1 .87 0 r
.008 w
.07534 .50051 Mdot
.016 w
.07534 .50051 m
.0747 .50168 L
s
1 .852 0 r
.008 w
.0747 .50168 Mdot
.016 w
.0747 .50168 m
.07411 .50295 L
s
1 .833 0 r
.008 w
.07411 .50295 Mdot
.016 w
.07411 .50295 m
.07337 .50445 L
s
1 .815 0 r
.008 w
.07337 .50445 Mdot
.016 w
.07337 .50445 m
.07257 .50623 L
s
1 .796 0 r
.008 w
.07257 .50623 Mdot
.016 w
.07257 .50623 m
.07174 .50832 L
s
1 .778 0 r
.008 w
.07174 .50832 Mdot
.016 w
.07174 .50832 m
.071 .51032 L
s
1 .759 0 r
.008 w
.071 .51032 Mdot
.016 w
.071 .51032 m
.07017 .51283 L
s
1 .741 0 r
.008 w
.07017 .51283 Mdot
.016 w
.07017 .51283 m
.06945 .515 L
s
1 .722 0 r
.008 w
.06945 .515 Mdot
.016 w
.06945 .515 m
.06879 .5174 L
s
1 .704 0 r
.008 w
.06879 .5174 Mdot
.016 w
.06879 .5174 m
.0682 .52012 L
s
1 .685 0 r
.008 w
.0682 .52012 Mdot
.016 w
.0682 .52012 m
.06772 .52287 L
s
1 .667 0 r
.008 w
.06772 .52287 Mdot
.016 w
.06772 .52287 m
.06738 .52503 L
s
1 .648 0 r
.008 w
.06738 .52503 Mdot
.016 w
.06738 .52503 m
.06719 .52754 L
s
1 .63 0 r
.008 w
.06719 .52754 Mdot
.016 w
.06719 .52754 m
.06715 .53013 L
s
1 .611 0 r
.008 w
.06715 .53013 Mdot
.016 w
.06715 .53013 m
.06722 .5322 L
s
1 .593 0 r
.008 w
.06722 .5322 Mdot
.016 w
.06722 .5322 m
.06739 .53421 L
s
1 .574 0 r
.008 w
.06739 .53421 Mdot
.016 w
.06739 .53421 m
.06762 .53598 L
s
1 .556 0 r
.008 w
.06762 .53598 Mdot
.016 w
.06762 .53598 m
.06789 .53758 L
s
1 .537 0 r
.008 w
.06789 .53758 Mdot
.016 w
.06789 .53758 m
.06816 .53878 L
s
1 .519 0 r
.008 w
.06816 .53878 Mdot
.016 w
.06816 .53878 m
.06841 .53986 L
s
1 .5 0 r
.008 w
.06841 .53986 Mdot
.016 w
.06841 .53986 m
.06866 .54057 L
s
1 .481 0 r
.008 w
.06866 .54057 Mdot
.016 w
.06866 .54057 m
.06891 .541 L
s
1 .463 0 r
.008 w
.06891 .541 Mdot
.016 w
.06891 .541 m
.06915 .54118 L
s
1 .444 0 r
.008 w
.06915 .54118 Mdot
.016 w
.06915 .54118 m
.06937 .54115 L
s
1 .426 0 r
.008 w
.06937 .54115 Mdot
.016 w
.06937 .54115 m
.06954 .54101 L
s
1 .407 0 r
.008 w
.06954 .54101 Mdot
.016 w
.06954 .54101 m
.06965 .5408 L
s
1 .389 0 r
.008 w
.06965 .5408 Mdot
.016 w
.06965 .5408 m
.06969 .5406 L
s
1 .37 0 r
.008 w
.06969 .5406 Mdot
.016 w
.06969 .5406 m
.06967 .54045 L
s
1 .352 0 r
.008 w
.06967 .54045 Mdot
.016 w
.06967 .54045 m
.06961 .54041 L
s
1 .333 0 r
.008 w
.06961 .54041 Mdot
.016 w
.06961 .54041 m
.06952 .54055 L
s
1 .315 0 r
.008 w
.06952 .54055 Mdot
.016 w
.06952 .54055 m
.06945 .54091 L
s
1 .296 0 r
.008 w
.06945 .54091 Mdot
.016 w
.06945 .54091 m
.06942 .54151 L
s
1 .278 0 r
.008 w
.06942 .54151 Mdot
.016 w
.06942 .54151 m
.06946 .54233 L
s
1 .259 0 r
.008 w
.06946 .54233 Mdot
.016 w
.06946 .54233 m
.0696 .54336 L
s
1 .241 0 r
.008 w
.0696 .54336 Mdot
.016 w
.0696 .54336 m
.06981 .5446 L
s
1 .222 0 r
.008 w
.06981 .5446 Mdot
.016 w
.06981 .5446 m
.07009 .5459 L
s
1 .204 0 r
.008 w
.07009 .5459 Mdot
.016 w
.07009 .5459 m
.07045 .54735 L
s
1 .185 0 r
.008 w
.07045 .54735 Mdot
.016 w
.07045 .54735 m
.07085 .54889 L
s
1 .167 0 r
.008 w
.07085 .54889 Mdot
.016 w
.07085 .54889 m
.07127 .55046 L
s
1 .148 0 r
.008 w
.07127 .55046 Mdot
.016 w
.07127 .55046 m
.07173 .55195 L
s
1 .13 0 r
.008 w
.07173 .55195 Mdot
.016 w
.07173 .55195 m
.0722 .55336 L
s
1 .111 0 r
.008 w
.0722 .55336 Mdot
.016 w
.0722 .55336 m
.07267 .55461 L
s
1 .093 0 r
.008 w
.07267 .55461 Mdot
.016 w
.07267 .55461 m
.07309 .55564 L
s
1 .074 0 r
.008 w
.07309 .55564 Mdot
.016 w
.07309 .55564 m
.07348 .55646 L
s
1 .056 0 r
.008 w
.07348 .55646 Mdot
.016 w
.07348 .55646 m
.07382 .55708 L
s
1 .037 0 r
.008 w
.07382 .55708 Mdot
.016 w
.07382 .55708 m
.07408 .55749 L
s
1 .019 0 r
.008 w
.07408 .55749 Mdot
.016 w
.07408 .55749 m
.07427 .55772 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo0Sg_17nP00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool0
1Sg_Of1o87lPOf1oP0Ioo`TmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo00<mkglPOb00
0WlP00=oP7ooOol027oo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4O`02Ob0:Ool6
?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Anh003Ob1oP7oo00Yoo`HmknAoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo17kP00=oH7ooOol02Goo1cg_i7oo00<007ooOol02goo000<
Ool00`00Oomoo`07Ool4OZ000gk0Oomoo`0:Ool9?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo
00Moo`AnX003O/1oogoo00Yoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol01goo17j000=n
`7ooOol02Woo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`06Ool4OV000gk0Oomoo`0:Ool;
?NoPOol00`00Oomoo`0;Ool000eoo`03001oogoo00Ioo`9n@003OP1n@7oo011oo`Lmkmmoo`03001o
ogoo00aoo`003Goo00<007ooOol01Woo00En@7h0OP1n03g_011oo`Pmkmioo`03001oogoo00aoo`00
3Goo00<007ooOol01Woo00=n07d0O@000Wd047oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomo
o`06Ool00gh0O<1l`002O<000gh0Oomoo`0=Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Ioo`03OT1lX7bP009lX003?Nmoogoo00ioo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol0
1goo00=lP7aPO6000WaP47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool00gb0O21l
8002O20@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`03O81l87`0009l811oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo00=lP7`PO0000W`P47oo2cg_fWoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool4O20AOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Qoo`Al819oo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo13g_4goo23g_fGoo00<0
07ooOol03Goo000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001o
ogoo00Moo`Dmko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_lgoo00<007ooOol03Goo
000?Ool00`00Oomoo`06Ool5?NocOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Dmko5oo`03
001oogoo00ioo`003goo00<007ooOol01goo1Cg_lGoo00<007ooOol03Woo000?Ool00`00Oomoo`07
Ool4?NobOol00`00Oomoo`0>Ool000moo`03001oogoo00Moo`@mko9oo`03001oogoo00ioo`0047oo
00<007ooOol01Woo13g_lWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool4?NoaOol00`00Oomo
o`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_
l7oo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001o
ogoo00Eoo`Hmknmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo
000AOol00`00Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03
001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`06
Ool4?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo
00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomo
o`0BOol001Aoo`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_
jGoo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001o
ogoo00=oo`HmknUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo
000EOol00`00Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03
001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03
Ool5?NoWOol00`00Oomoo`0EOol001Moo`03001oogoo00=oo`@mknIoo`03001oogoo01Ioo`005goo
00<007ooOol00goo1Cg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomo
o`0GOol001Qoo`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=o
o`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_hGoo00<007ooOol067oo000JOol01000Oomo
ogoo1Sg_hGoo00<007ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol0
0`00Oomoo`06?NoOOol00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`00
77oo00<007ooOol01Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0K
Ool001eoo`03001oogoo00@mkmeoo`03001oogoo01aoo`007Goo00<007ooOol013g_gGoo00<007oo
Ool077oo000NOol00`00Oolmk`04?NoKOol00`00Oomoo`0MOol001ioo`03001oocg_00@mkm]oo`03
001oogoo01eoo`007goo00<003g_?Nl013g_fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05?NoH
Ool00`00Oomoo`0NOol0021oo`03000mkcg_00DmkmIoo`03001oogoo01moo`0087oo00<003g_?Nl0
1Cg_eWoo00<007ooOol07goo000QOol00`00?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03000m
kcg_00Hmkm5oo`03001oogoo025oo`008goo00<007oo?Nl01Cg_d7oo00<007ooOol08Woo000TOol0
0`00?Nlmk`06?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_00Lmklaoo`03001oogoo02=oo`00
9Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00?Nlmk`07?No8Ool00`00Oomoo`0U
Ool002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo00<007oo?Nl02Sg_`goo00<007oo
Ool09Woo000XOol01000Oomoogoo23g_`Woo00<007ooOol09goo000YOol01000Oomoogoo23g_`7oo
00<007ooOol0:7oo000ZOol00`00Oomoo`08?NnoOol00`00Oomoo`0YOol002Yoo`04001oogooOol8
?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo009oo`Hmkkeoo`03001oogoo02Yoo`00;7oo00@0
07ooOomoo`Lmkk]oo`03001oogoo02]oo`00;Goo00<007ooOol023g_^Goo00<007ooOol0;7oo000^
Ool00`00Oomoo`08?NngOol00`00Oomoo`0]Ool002ioo`04001oogooOol8?NnfOol00`00Oomoo`0]
Ool002moo`04001oogooOol9?NncOol00`00Oomoo`0^Ool0031oo`04001oogooOol8?NnbOol00`00
Oomoo`0_Ool0035oo`04001oogooOol8?Nn`Ool00`00Oomoo`0`Ool0039oo`8000=oo`Lmkjeoo`80
03=oo`00=7oo00@007ooOomoo`Lmkj]oo`03001oogoo03=oo`00=Goo00@007ooOomoo`LmkjUoo`03
001oogoo03Aoo`00=Goo00@007ooOomoo`PmkjQoo`03001oogoo03Aoo`00=Woo00@007ooOomoo`Pm
kjIoo`03001oogoo03Eoo`00=goo00<007ooOol00goo1Sg_Y7oo00<007ooOol0=Woo000hOol00`00
Oomoo`03Ool6?NnROol00`00Oomoo`0gOol003Uoo`8000Aoo`Lmkiioo`8003Yoo`00>goo00@007oo
Oomoo`Pmkiaoo`03001oogoo03Yoo`00?7oo00<007ooOol02Cg_VWoo00<007ooOol0>goo000mOol0
0`00Oomoo`0:?NnGOol00`00Oomoo`0lOol003ioo`8000=oo`PmkiAoo`8003moo`00@7oo00<007oo
Ool02Cg_TWoo00<007ooOol0?goo0011Ool200000goo?Nlmk`07?Nn?Ool20012Ool004=oo`03001o
ocg_00Pmkheoo`03001oogoo049oo`00A7oo00<007oo?Nl023g_Rgoo00<007ooOol0@goo0015Ool0
1000Oomoogoo1cg_RGoo00<007ooOol0A7oo0016Ool200000goo?Nlmk`07?Nn5Ool20017Ool004Qo
o`8000/mk`=oo`8mkg]oo`8004Uoo`00BWoo00<003g_?Nl03Sg_N7oo0P00Bgoo001<Ool@?NmeOol2
001=Ool004ioo`03001oocg_00`mkg=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03Sg_Kgoo00<0
07ooOol0CWoo001@Ool20002Ool??NmZOol2001AOol0059oo`800003Oolmkcg_009oo``mkfIoo`80
05=oo`00E7oo0P0000<mkgooOol03cg_27oo1Cg_E7oo0P00EGoo001FOol20004Ool@?Nl3Ool6?NmB
Ool2001GOol005Qoo`<000AooaHmkdmoo`<005Uoo`00Fgoo0`001Goo4Sg_C7oo0`00G7oo001NOol2
0006Ool@?Nm8Ool3001OOol0061oo`8000Iooa0mkdEoo`03001oogoo061oo`00HWoo0`001goo3Sg_
@7oo0`00Hgoo001UOol30007Ool>?Nl<Ool9?NlUOol3001VOol006Qoo`@000Ioob0mkb5oo`@006Uo
o`00K7oo10000goo7cg_7Goo1000KGoo001`Ool30003OolL?NlIOol4001aOol007=oo`D00003Oolm
kcg_01LmkaEoo`@007Eoo`00N7oo1@005Cg_3Woo1`00NGoo001oOol70008?Nl4Ool>0020Ool008eo
o`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo0P001Goo00<007oo
Ool0Rgoo002:Ool01000Oomoo`0017oo00<007ooOol0Rgoo002=Ool00`00Oomoo`02Ool00`00Oomo
o`2;Ool008]oo`8000Ioo`03001oogoo08Yoo`00Rgoo00<007ooOol00Woo00@007ooOol008aoo`00
Rgoo0`000Woo1000S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(58)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
1 .977 0 r
.008 w
.07423 .55704 Mdot
.016 w
.07423 .55704 m
.07422 .55725 L
s
1 .953 0 r
.008 w
.07422 .55725 Mdot
.016 w
.07422 .55725 m
.07419 .55762 L
s
1 .93 0 r
.008 w
.07419 .55762 Mdot
.016 w
.07419 .55762 m
.07414 .55814 L
s
1 .907 0 r
.008 w
.07414 .55814 Mdot
.016 w
.07414 .55814 m
.07407 .55882 L
s
1 .884 0 r
.008 w
.07407 .55882 Mdot
.016 w
.07407 .55882 m
.074 .55967 L
s
1 .86 0 r
.008 w
.074 .55967 Mdot
.016 w
.074 .55967 m
.07394 .56069 L
s
1 .837 0 r
.008 w
.07394 .56069 Mdot
.016 w
.07394 .56069 m
.0739 .56182 L
s
1 .814 0 r
.008 w
.0739 .56182 Mdot
.016 w
.0739 .56182 m
.07391 .56307 L
s
1 .791 0 r
.008 w
.07391 .56307 Mdot
.016 w
.07391 .56307 m
.07395 .56444 L
s
1 .767 0 r
.008 w
.07395 .56444 Mdot
.016 w
.07395 .56444 m
.07405 .56589 L
s
1 .744 0 r
.008 w
.07405 .56589 Mdot
.016 w
.07405 .56589 m
.07418 .56733 L
s
1 .721 0 r
.008 w
.07418 .56733 Mdot
.016 w
.07418 .56733 m
.07435 .56868 L
s
1 .698 0 r
.008 w
.07435 .56868 Mdot
.016 w
.07435 .56868 m
.07454 .56992 L
s
1 .674 0 r
.008 w
.07454 .56992 Mdot
.016 w
.07454 .56992 m
.07473 .57101 L
s
1 .651 0 r
.008 w
.07473 .57101 Mdot
.016 w
.07473 .57101 m
.07493 .57192 L
s
1 .628 0 r
.008 w
.07493 .57192 Mdot
.016 w
.07493 .57192 m
.07517 .57264 L
s
1 .605 0 r
.008 w
.07517 .57264 Mdot
.016 w
.07517 .57264 m
.07544 .5732 L
s
1 .581 0 r
.008 w
.07544 .5732 Mdot
.016 w
.07544 .5732 m
.07574 .57363 L
s
1 .558 0 r
.008 w
.07574 .57363 Mdot
.016 w
.07574 .57363 m
.07605 .57398 L
s
1 .535 0 r
.008 w
.07605 .57398 Mdot
.016 w
.07605 .57398 m
.07633 .5743 L
s
1 .512 0 r
.008 w
.07633 .5743 Mdot
.016 w
.07633 .5743 m
.07656 .57462 L
s
1 .488 0 r
.008 w
.07656 .57462 Mdot
.016 w
.07656 .57462 m
.07672 .57496 L
s
1 .465 0 r
.008 w
.07672 .57496 Mdot
.016 w
.07672 .57496 m
.07681 .57533 L
s
1 .442 0 r
.008 w
.07681 .57533 Mdot
.016 w
.07681 .57533 m
.07685 .57574 L
s
1 .419 0 r
.008 w
.07685 .57574 Mdot
.016 w
.07685 .57574 m
.07687 .57619 L
s
1 .395 0 r
.008 w
.07687 .57619 Mdot
.016 w
.07687 .57619 m
.0769 .57672 L
s
1 .372 0 r
.008 w
.0769 .57672 Mdot
.016 w
.0769 .57672 m
.07697 .57733 L
s
1 .349 0 r
.008 w
.07697 .57733 Mdot
.016 w
.07697 .57733 m
.07711 .57805 L
s
1 .326 0 r
.008 w
.07711 .57805 Mdot
.016 w
.07711 .57805 m
.07732 .57887 L
s
1 .302 0 r
.008 w
.07732 .57887 Mdot
.016 w
.07732 .57887 m
.07756 .57971 L
s
1 .279 0 r
.008 w
.07756 .57971 Mdot
.016 w
.07756 .57971 m
.07783 .58059 L
s
1 .256 0 r
.008 w
.07783 .58059 Mdot
.016 w
.07783 .58059 m
.07811 .58146 L
s
1 .233 0 r
.008 w
.07811 .58146 Mdot
.016 w
.07811 .58146 m
.07837 .5823 L
s
1 .209 0 r
.008 w
.07837 .5823 Mdot
.016 w
.07837 .5823 m
.07869 .58307 L
s
1 .186 0 r
.008 w
.07869 .58307 Mdot
.016 w
.07869 .58307 m
.07903 .58375 L
s
1 .163 0 r
.008 w
.07903 .58375 Mdot
.016 w
.07903 .58375 m
.07941 .58433 L
s
1 .14 0 r
.008 w
.07941 .58433 Mdot
.016 w
.07941 .58433 m
.07978 .58484 L
s
1 .116 0 r
.008 w
.07978 .58484 Mdot
.016 w
.07978 .58484 m
.08017 .58527 L
s
1 .093 0 r
.008 w
.08017 .58527 Mdot
.016 w
.08017 .58527 m
.08052 .58563 L
s
1 .07 0 r
.008 w
.08052 .58563 Mdot
.016 w
.08052 .58563 m
.08081 .58592 L
s
1 .047 0 r
.008 w
.08081 .58592 Mdot
.016 w
.08081 .58592 m
.08101 .58616 L
s
1 .023 0 r
.008 w
.08101 .58616 Mdot
.016 w
.08101 .58616 m
.08112 .58633 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool00cg_On1oh002On0@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Mo
o`03?Nmo@7m0009o@11oo`Tmkmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo00<mkgl0O`00
0Wl047oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool4O^0AOol:?NoJOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Qoo`AnP19oo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol0
1goo00=n@7g0OL000Wg04Woo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool00gi0OB1m
8002OB0BOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`03OT1l`7c0009l`?=oo`03
001oogoo00eoo`003Woo00<007ooOol01goo00=n@7bPO:000W`000=lX7ooOol0l7oo00<007ooOol0
3Goo000?Ool00`00Oomoo`06Ool00cg_O:1l0003O03bOol00`00Oomoo`0=Ool000moo`03001oogoo
00Moo`03O:1l07`0009l0?5oo`03001oogoo00ioo`003goo00<007ooOol01goo0WbP0W`000=lX7oo
Ool0kgoo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4?NobOol00`00Oomoo`0>Ool000moo`03
001oogoo00Moo`@mko9oo`03001oogoo00ioo`0047oo00<007ooOol01Woo13g_lWoo00<007ooOol0
3Woo000@Ool00`00Oomoo`06Ool4?NoaOol00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1o
o`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007ooOol03goo000@Ool00`00Oomo
o`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hmknmoo`03001oogoo00moo`00
4Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool5?No^Ool00`00
Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011oo`004Woo00<007ooOol01Goo
1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool4?No]Ool00`00Oomoo`0AOol001=oo`03
001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<007ooOol0
4Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`Dmkn]o
o`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007ooOol04goo000DOol00`00Oomo
o`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`HmknUoo`03001oogoo01=oo`00
5Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00Oomoo`04Ool5?NoXOol00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Aoo`005Woo00<007ooOol00goo
1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol00`00Oomoo`0EOol001Moo`03
001oogoo00=oo`@mknIoo`03001oogoo01Ioo`005goo00<007ooOol00goo1Cg_iGoo00<007ooOol0
5Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qoo`03001oogoo009oo`DmknAo
o`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo01Moo`006Goo00<007ooOol0
0Woo1Sg_hGoo00<007ooOol067oo000JOol01000Oomoogoo1Sg_hGoo00<007ooOol067oo000JOol0
1000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoOOol00`00Oomoo`0JOol0
01]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol01Cg_gWoo00<007ooOol0
6goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001oogoo00@mkmeoo`03001o
ogoo01aoo`007Goo00<007ooOol013g_gGoo00<007ooOol077oo000NOol00`00Oolmk`04?NoKOol0
0`00Oomoo`0MOol001ioo`03001oocg_00@mkm]oo`03001oogoo01eoo`007goo00<003g_?Nl013g_
fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03000mkcg_
00DmkmIoo`03001oogoo01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000QOol00`00
?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025oo`008goo
00<007oo?Nl01Cg_d7oo00<007ooOol08Woo000TOol00`00?Nlmk`06?No=Ool00`00Oomoo`0SOol0
02Aoo`03000mkcg_00Lmklaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol0
97oo000VOol00`00?Nlmk`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001o
ogoo02Eoo`009goo00<007oo?Nl02Sg_`goo00<007ooOol09Woo000XOol01000Oomoogoo23g_`Woo
00<007ooOol09goo000YOol01000Oomoogoo23g_`7oo00<007ooOol0:7oo000ZOol00`00Oomoo`08
?NnoOol00`00Oomoo`0YOol002Yoo`04001oogooOol8?NnnOol00`00Oomoo`0YOol002]oo`03001o
ogoo009oo`Hmkkeoo`03001oogoo02Yoo`00;7oo00@007ooOomoo`Lmkk]oo`03001oogoo02]oo`00
;Goo00<007ooOol023g_^Goo00<007ooOol0;7oo000^Ool00`00Oomoo`08?NngOol00`00Oomoo`0]
Ool002ioo`04001oogooOol8?NnfOol00`00Oomoo`0]Ool002moo`04001oogooOol9?NncOol00`00
Oomoo`0^Ool0031oo`04001oogooOol8?NnbOol00`00Oomoo`0_Ool0035oo`04001oogooOol8?Nn`
Ool00`00Oomoo`0`Ool0039oo`8000=oo`Lmkjeoo`8003=oo`00=7oo00@007ooOomoo`Lmkj]oo`03
001oogoo03=oo`00=Goo00@007ooOomoo`LmkjUoo`03001oogoo03Aoo`00=Goo00@007ooOomoo`Pm
kjQoo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkjIoo`03001oogoo03Eoo`00=goo00<007oo
Ool00goo1Sg_Y7oo00<007ooOol0=Woo000hOol00`00Oomoo`03Ool6?NnROol00`00Oomoo`0gOol0
03Uoo`8000Aoo`Lmkiioo`8003Yoo`00>goo00@007ooOomoo`Pmkiaoo`03001oogoo03Yoo`00?7oo
00<007ooOol02Cg_VWoo00<007ooOol0>goo000mOol00`00Oomoo`0:?NnGOol00`00Oomoo`0lOol0
03ioo`8000=oo`PmkiAoo`8003moo`00@7oo00<007ooOol02Cg_TWoo00<007ooOol0?goo0011Ool2
00000goo?Nlmk`07?Nn?Ool20012Ool004=oo`03001oocg_00Pmkheoo`03001oogoo049oo`00A7oo
00<007oo?Nl023g_Rgoo00<007ooOol0@goo0015Ool01000Oomoogoo1cg_RGoo00<007ooOol0A7oo
0016Ool200000goo?Nlmk`07?Nn5Ool20017Ool004Qoo`8000/mk`=oo`8mkg]oo`8004Uoo`00BWoo
00<003g_?Nl03Sg_N7oo0P00Bgoo001<Ool@?NmeOol2001=Ool004ioo`03001oocg_00`mkg=oo`03
001oogoo04eoo`00Cgoo00<003g_?Nl03Sg_Kgoo00<007ooOol0CWoo001@Ool20002Ool??NmZOol2
001AOol0059oo`800003Oolmkcg_009oo``mkfIoo`8005=oo`00E7oo0P0000<mkgooOol03cg_27oo
1Cg_E7oo0P00EGoo001FOol20004Ool@?Nl3Ool6?NmBOol2001GOol005Qoo`<000AooaHmkdmoo`<0
05Uoo`00Fgoo0`001Goo4Sg_C7oo0`00G7oo001NOol20006Ool@?Nm8Ool3001OOol0061oo`8000Io
oa0mkdEoo`03001oogoo061oo`00HWoo0`001goo3Sg_@7oo0`00Hgoo001UOol30007Ool>?Nl<Ool9
?NlUOol3001VOol006Qoo`@000Ioob0mkb5oo`@006Uoo`00K7oo10000goo7cg_7Goo1000KGoo001`
Ool30003OolL?NlIOol4001aOol007=oo`D00003Oolmkcg_01LmkaEoo`@007Eoo`00N7oo1@005Cg_
3Woo1`00NGoo001oOol70008?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00Rgoo0P0017oo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol0
08aoo`00SGoo00@007ooOol0009oo`03001oogoo08Yoo`00Rgoo0P0017oo0P00SGoo002;Ool00`00
Oomoo`02Ool01000Oomoo`00S7oo002;Ool30003Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(59)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
1 .938 0 r
.008 w
.08089 .58586 Mdot
.016 w
.08089 .58586 m
.08099 .58607 L
s
1 .875 0 r
.008 w
.08099 .58607 Mdot
.016 w
.08099 .58607 m
.08113 .58644 L
s
1 .813 0 r
.008 w
.08113 .58644 Mdot
.016 w
.08113 .58644 m
.0813 .58699 L
s
1 .75 0 r
.008 w
.0813 .58699 Mdot
.016 w
.0813 .58699 m
.08147 .5877 L
s
1 .688 0 r
.008 w
.08147 .5877 Mdot
.016 w
.08147 .5877 m
.08166 .58856 L
s
1 .625 0 r
.008 w
.08166 .58856 Mdot
.016 w
.08166 .58856 m
.08185 .5896 L
s
1 .563 0 r
.008 w
.08185 .5896 Mdot
.016 w
.08185 .5896 m
.08204 .59073 L
s
1 .5 0 r
.008 w
.08204 .59073 Mdot
.016 w
.08204 .59073 m
.08223 .59195 L
s
1 .438 0 r
.008 w
.08223 .59195 Mdot
.016 w
.08223 .59195 m
.0824 .59319 L
s
1 .375 0 r
.008 w
.0824 .59319 Mdot
.016 w
.0824 .59319 m
.08257 .59438 L
s
1 .313 0 r
.008 w
.08257 .59438 Mdot
.016 w
.08257 .59438 m
.08273 .59546 L
s
1 .25 0 r
.008 w
.08273 .59546 Mdot
.016 w
.08273 .59546 m
.08288 .59634 L
s
1 .188 0 r
.008 w
.08288 .59634 Mdot
.016 w
.08288 .59634 m
.08299 .59697 L
s
1 .125 0 r
.008 w
.08299 .59697 Mdot
.016 w
.08299 .59697 m
.08306 .59735 L
s
1 .063 0 r
.008 w
.08306 .59735 Mdot
.016 w
.08306 .59735 m
.0831 .5975 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo0Sg_17mPlWoo00<007ooOol03Goo000?Ool0
0`00Oomoo`06Ool2?Nl4OT3bOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`03?NmmH7eP009m
H?5oo`03001oogoo00ioo`003goo00<007ooOol01goo00<mkgc0O6000Wa000=lH7ooOol0kWoo00<0
07ooOol03Woo000?Ool00`00Oomoo`07Ool00cg_O<1l@003O43`Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Moo`03?Nml`7a000=l@?1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo00<mkgc0
O6000Wa000=lH7ooOol0kWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool2?Nl4O63_Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo
1Cg_l7oo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03
001oogoo00Eoo`Hmknmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol0
47oo000AOol00`00Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknio
o`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomo
o`06Ool4?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`00
4goo00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00
Oomoo`0BOol001Aoo`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_jGoo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03
001oogoo00=oo`HmknUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol0
57oo000EOol00`00Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQo
o`03001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomo
o`03Ool5?NoWOol00`00Oomoo`0EOol001Moo`03001oogoo00=oo`@mknIoo`03001oogoo01Ioo`00
5goo00<007ooOol00goo1Cg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00
Oomoo`0GOol001Qoo`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hm
kn=oo`03001oogoo01Moo`006Goo00<007ooOol00Woo1Sg_hGoo00<007ooOol067oo000JOol01000
Oomoogoo1Sg_hGoo00<007ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000K
Ool00`00Oomoo`06?NoOOol00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yo
o`0077oo00<007ooOol01Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomo
o`0KOol001eoo`03001oogoo00@mkmeoo`03001oogoo01aoo`007Goo00<007ooOol013g_gGoo00<0
07ooOol077oo000NOol00`00Oolmk`04?NoKOol00`00Oomoo`0MOol001ioo`03001oocg_00@mkm]o
o`03001oogoo01eoo`007goo00<003g_?Nl013g_fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05
?NoHOol00`00Oomoo`0NOol0021oo`03000mkcg_00DmkmIoo`03001oogoo01moo`0087oo00<003g_
?Nl01Cg_eWoo00<007ooOol07goo000QOol00`00?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03
000mkcg_00Hmkm5oo`03001oogoo025oo`008goo00<007oo?Nl01Cg_d7oo00<007ooOol08Woo000T
Ool00`00?Nlmk`06?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_00Lmklaoo`03001oogoo02=o
o`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00?Nlmk`07?No8Ool00`00Oomo
o`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo00<007oo?Nl02Sg_`goo00<0
07ooOol09Woo000XOol01000Oomoogoo23g_`Woo00<007ooOol09goo000YOol01000Oomoogoo23g_
`7oo00<007ooOol0:7oo000ZOol00`00Oomoo`08?NnoOol00`00Oomoo`0YOol002Yoo`04001oogoo
Ool8?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo009oo`Hmkkeoo`03001oogoo02Yoo`00;7oo
00@007ooOomoo`Lmkk]oo`03001oogoo02]oo`00;Goo00<007ooOol023g_^Goo00<007ooOol0;7oo
000^Ool00`00Oomoo`08?NngOol00`00Oomoo`0]Ool002ioo`04001oogooOol8?NnfOol00`00Oomo
o`0]Ool002moo`04001oogooOol9?NncOol00`00Oomoo`0^Ool0031oo`04001oogooOol8?NnbOol0
0`00Oomoo`0_Ool0035oo`04001oogooOol8?Nn`Ool00`00Oomoo`0`Ool0039oo`8000=oo`Lmkjeo
o`8003=oo`00=7oo00@007ooOomoo`Lmkj]oo`03001oogoo03=oo`00=Goo00@007ooOomoo`LmkjUo
o`03001oogoo03Aoo`00=Goo00@007ooOomoo`PmkjQoo`03001oogoo03Aoo`00=Woo00@007ooOomo
o`PmkjIoo`03001oogoo03Eoo`00=goo00<007ooOol00goo1Sg_Y7oo00<007ooOol0=Woo000hOol0
0`00Oomoo`03Ool6?NnROol00`00Oomoo`0gOol003Uoo`8000Aoo`Lmkiioo`8003Yoo`00>goo00@0
07ooOomoo`Pmkiaoo`03001oogoo03Yoo`00?7oo00<007ooOol02Cg_VWoo00<007ooOol0>goo000m
Ool00`00Oomoo`0:?NnGOol00`00Oomoo`0lOol003ioo`8000=oo`PmkiAoo`8003moo`00@7oo00<0
07ooOol02Cg_TWoo00<007ooOol0?goo0011Ool200000goo?Nlmk`07?Nn?Ool20012Ool004=oo`03
001oocg_00Pmkheoo`03001oogoo049oo`00A7oo00<007oo?Nl023g_Rgoo00<007ooOol0@goo0015
Ool01000Oomoogoo1cg_RGoo00<007ooOol0A7oo0016Ool200000goo?Nlmk`07?Nn5Ool20017Ool0
04Qoo`8000/mk`=oo`8mkg]oo`8004Uoo`00BWoo00<003g_?Nl03Sg_N7oo0P00Bgoo001<Ool@?Nme
Ool2001=Ool004ioo`03001oocg_00`mkg=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03Sg_Kgoo
00<007ooOol0CWoo001@Ool20002Ool??NmZOol2001AOol0059oo`800003Oolmkcg_009oo``mkfIo
o`8005=oo`00E7oo0P0000<mkgooOol03cg_27oo1Cg_E7oo0P00EGoo001FOol20004Ool@?Nl3Ool6
?NmBOol2001GOol005Qoo`<000AooaHmkdmoo`<005Uoo`00Fgoo0`001Goo4Sg_C7oo0`00G7oo001N
Ool20006Ool@?Nm8Ool3001OOol0061oo`8000Iooa0mkdEoo`03001oogoo061oo`00HWoo0`001goo
3Sg_@7oo0`00Hgoo001UOol30007Ool>?Nl<Ool9?NlUOol3001VOol006Qoo`@000Ioob0mkb5oo`@0
06Uoo`00K7oo10000goo7cg_7Goo1000KGoo001`Ool30003OolL?NlIOol4001aOol007=oo`D00003
Oolmkcg_01LmkaEoo`@007Eoo`00N7oo1@005Cg_3Woo1`00NGoo001oOol70008?Nl4Ool>0020Ool0
08eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo0P000goo0`00
SGoo002:Ool01000Oomoo`0017oo00<007ooOol0Rgoo002=Ool01000Oomoogoo0`00S7oo002;Ool2
0003Ool01000Oomoo`00S7oo002;Ool00`00Oomoo`02Ool01000Oomoo`00S7oo002;Ool30003Ool3
002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(60)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
1 .969 0 r
.008 w
.08341 .59316 Mdot
.016 w
.08341 .59316 m
.08332 .59342 L
s
1 .938 0 r
.008 w
.08332 .59342 Mdot
.016 w
.08332 .59342 m
.08319 .59383 L
s
1 .906 0 r
.008 w
.08319 .59383 Mdot
.016 w
.08319 .59383 m
.08301 .59437 L
s
1 .875 0 r
.008 w
.08301 .59437 Mdot
.016 w
.08301 .59437 m
.08276 .59501 L
s
1 .844 0 r
.008 w
.08276 .59501 Mdot
.016 w
.08276 .59501 m
.08244 .59575 L
s
1 .813 0 r
.008 w
.08244 .59575 Mdot
.016 w
.08244 .59575 m
.08205 .59658 L
s
1 .781 0 r
.008 w
.08205 .59658 Mdot
.016 w
.08205 .59658 m
.08161 .59746 L
s
1 .75 0 r
.008 w
.08161 .59746 Mdot
.016 w
.08161 .59746 m
.08116 .59835 L
s
1 .719 0 r
.008 w
.08116 .59835 Mdot
.016 w
.08116 .59835 m
.08073 .59923 L
s
1 .688 0 r
.008 w
.08073 .59923 Mdot
.016 w
.08073 .59923 m
.08032 .60006 L
s
1 .656 0 r
.008 w
.08032 .60006 Mdot
.016 w
.08032 .60006 m
.07996 .60083 L
s
1 .625 0 r
.008 w
.07996 .60083 Mdot
.016 w
.07996 .60083 m
.07964 .60149 L
s
1 .594 0 r
.008 w
.07964 .60149 Mdot
.016 w
.07964 .60149 m
.07935 .60203 L
s
1 .563 0 r
.008 w
.07935 .60203 Mdot
.016 w
.07935 .60203 m
.07912 .60244 L
s
1 .531 0 r
.008 w
.07912 .60244 Mdot
.016 w
.07912 .60244 m
.07892 .60276 L
s
1 .5 0 r
.008 w
.07892 .60276 Mdot
.016 w
.07892 .60276 m
.07876 .60299 L
s
1 .469 0 r
.008 w
.07876 .60299 Mdot
.016 w
.07876 .60299 m
.07865 .60315 L
s
1 .438 0 r
.008 w
.07865 .60315 Mdot
.016 w
.07865 .60315 m
.07859 .60328 L
s
1 .406 0 r
.008 w
.07859 .60328 Mdot
.016 w
.07859 .60328 m
.07858 .60342 L
s
1 .375 0 r
.008 w
.07858 .60342 Mdot
.016 w
.07858 .60342 m
.07861 .60358 L
s
1 .344 0 r
.008 w
.07861 .60358 Mdot
.016 w
.07861 .60358 m
.07869 .60376 L
s
1 .313 0 r
.008 w
.07869 .60376 Mdot
.016 w
.07869 .60376 m
.0788 .60395 L
s
1 .281 0 r
.008 w
.0788 .60395 Mdot
.016 w
.0788 .60395 m
.07893 .60414 L
s
1 .25 0 r
.008 w
.07893 .60414 Mdot
.016 w
.07893 .60414 m
.07907 .60436 L
s
1 .219 0 r
.008 w
.07907 .60436 Mdot
.016 w
.07907 .60436 m
.07918 .60455 L
s
1 .188 0 r
.008 w
.07918 .60455 Mdot
.016 w
.07918 .60455 m
.0793 .60476 L
s
1 .156 0 r
.008 w
.0793 .60476 Mdot
.016 w
.0793 .60476 m
.07943 .60499 L
s
1 .125 0 r
.008 w
.07943 .60499 Mdot
.016 w
.07943 .60499 m
.07955 .60516 L
s
1 .094 0 r
.008 w
.07955 .60516 Mdot
.016 w
.07955 .60516 m
.07971 .60532 L
s
1 .063 0 r
.008 w
.07971 .60532 Mdot
.016 w
.07971 .60532 m
.0799 .60544 L
s
1 .031 0 r
.008 w
.0799 .60544 Mdot
.016 w
.0799 .60544 m
.08007 .60551 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`8mk`Ao`?1oo`03001oogoo
00ioo`003goo00<007ooOol01goo00<mkgl0O`000Wl000=oH7ooOol0kWoo00<007ooOol03Woo000?
Ool00`00Oomoo`07Ool00cg_OV1nH002OV000gmPOomoo`3^Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00Moo`Al`003OT1oH7oo0>moo`03001oogoo00ioo`0047oo00<007ooOol01Woo0Wb000Al07b0
O81oH?1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo0Wb000Al07b0O80mknmoo`03001oogoo
00moo`0047oo00<007ooOol01Woo1Gb0l7oo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5O83`
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`004Goo00<007oo
Ool01Goo1Sg_kgoo00<007ooOol03goo000AOol00`00Oomoo`06Ool6?No]Ool00`00Oomoo`0@Ool0
015oo`03001oogoo00Ioo`Dmknioo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kWoo00<0
07ooOol047oo000BOol00`00Oomoo`05Ool5?No]Ool00`00Oomoo`0AOol0019oo`03001oogoo00Io
o`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo13g_kGoo00<007ooOol04Goo000COol0
0`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001=oo`03001oogoo00Eoo`Dmkn]oo`03001oogoo
019oo`0057oo00<007ooOol017oo1Cg_jgoo00<007ooOol04Woo000DOol00`00Oomoo`04Ool6?NoY
Ool00`00Oomoo`0COol001Aoo`03001oogoo00Aoo`HmknUoo`03001oogoo01=oo`005Goo00<007oo
Ool00goo1Sg_jGoo00<007ooOol04goo000EOol00`00Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol0
01Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Aoo`005Goo00<007ooOol017oo1Cg_j7oo00<0
07ooOol057oo000FOol00`00Oomoo`03Ool5?NoWOol00`00Oomoo`0EOol001Ioo`03001oogoo00=o
o`DmknMoo`03001oogoo01Eoo`005goo00<007ooOol00goo13g_iWoo00<007ooOol05Woo000GOol0
0`00Oomoo`03Ool5?NoUOol00`00Oomoo`0FOol001Qoo`03001oogoo009oo`DmknAoo`03001oogoo
01Moo`0067oo00<007ooOol00Woo1Cg_i7oo00<007ooOol05goo000IOol01000Oomoogoo1Sg_hgoo
00<007ooOol05goo000IOol00`00Oomoo`02Ool6?NoQOol00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?NoQOol00`00Oomoo`0HOol001Yoo`04001oogooOol6?NoPOol00`00Oomoo`0IOol001]oo`03
001oogoo00Hmkmmoo`03001oogoo01Yoo`006goo00<007ooOol01Sg_ggoo00<007ooOol06Woo000L
Ool00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001aoo`03001oogoo00Dmkmioo`03001oogoo01]o
o`007Goo00<007ooOol013g_gGoo00<007ooOol077oo000MOol00`00Oomoo`04?NoMOol00`00Oomo
o`0LOol001ioo`03001oocg_00@mkm]oo`03001oogoo01eoo`007Woo00<007oo?Nl013g_fgoo00<0
07ooOol07Goo000OOol00`00?Nlmk`04?NoIOol00`00Oomoo`0NOol001moo`03000mkcg_00DmkmQo
o`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000POol00`00?Nlmk`05
?NoFOol00`00Oomoo`0OOol0025oo`03000mkcg_00Hmkm=oo`03001oogoo021oo`008Woo00<003g_
?Nl01Sg_dGoo00<007ooOol08Goo000SOol00`00Oolmk`05?No@Ool00`00Oomoo`0ROol002Aoo`03
000mkcg_00Hmkleoo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_c7oo00<007ooOol08goo000U
Ool00`00?Nlmk`07?No:Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmklQoo`03001oogoo02Eo
o`009Woo00<007oo?Nl02cg_a7oo00<007ooOol09Goo000WOol00`00Oolmk`0:?No3Ool00`00Oomo
o`0VOol002Qoo`04001oogooOol8?No2Ool00`00Oomoo`0WOol002Uoo`04001oogooOol8?No0Ool0
0`00Oomoo`0XOol002Yoo`03001oogoo00Pmkkmoo`03001oogoo02Uoo`00:Woo00@007ooOomoo`Pm
kkioo`03001oogoo02Uoo`00:goo00<007ooOol00Woo1Sg__Goo00<007ooOol0:Woo000/Ool01000
Oomoogoo1cg_^goo00<007ooOol0:goo000]Ool00`00Oomoo`08?NniOol00`00Oomoo`0/Ool002io
o`03001oogoo00PmkkMoo`03001oogoo02eoo`00;Woo00@007ooOomoo`PmkkIoo`03001oogoo02eo
o`00;goo00@007ooOomoo`Tmkk=oo`03001oogoo02ioo`00<7oo00@007ooOomoo`Pmkk9oo`03001o
ogoo02moo`00<Goo00@007ooOomoo`Pmkk1oo`03001oogoo031oo`00<Woo0P000goo1cg_[Goo0P00
<goo000dOol01000Oomoogoo1cg_Zgoo00<007ooOol0<goo000eOol01000Oomoogoo1cg_ZGoo00<0
07ooOol0=7oo000eOol01000Oomoogoo23g_Z7oo00<007ooOol0=7oo000fOol01000Oomoogoo23g_
YWoo00<007ooOol0=Goo000gOol00`00Oomoo`03Ool6?NnTOol00`00Oomoo`0fOol003Qoo`03001o
ogoo00=oo`Hmkj9oo`03001oogoo03Moo`00>Goo0P0017oo1cg_WWoo0P00>Woo000kOol01000Oomo
ogoo23g_W7oo00<007ooOol0>Woo000lOol00`00Oomoo`09?NnJOol00`00Oomoo`0kOol003eoo`03
001oogoo00XmkiMoo`03001oogoo03aoo`00?Woo0P000goo23g_U7oo0P00?goo0010Ool00`00Oomo
o`09?NnBOol00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkhmoo`80049oo`00@goo00<007oo
?Nl023g_SGoo00<007ooOol0@Woo0014Ool00`00Oolmk`08?Nn;Ool00`00Oomoo`13Ool004Eoo`04
001oogooOol7?Nn9Ool00`00Oomoo`14Ool004Ioo`800003Oolmkcg_00LmkhEoo`8004Moo`00B7oo
0P002cg_0goo0Sg_Ngoo0P00BGoo001:Ool00`00?Nlmk`0>?NmhOol2001;Ool004aooa0mkgEoo`80
04eoo`00CWoo00<007oo?Nl033g_Lgoo00<007ooOol0CGoo001?Ool00`00?Nlmk`0>?Nm_Ool00`00
Oomoo`1>Ool0051oo`80009oo`lmkfYoo`80055oo`00DWoo0P0000=oocg_?Nl00Woo33g_IWoo0P00
Dgoo001DOol200000cg_Oomoo`0??Nl8Ool5?NmDOol2001EOol005Ioo`8000Aooa0mk`=oo`Hmke9o
o`8005Moo`00F7oo0`0017oo5Sg_Cgoo0`00FGoo001KOol30005OolB?Nm<Ool3001LOol005ioo`80
00Iooa0mkdQoo`<005moo`00H7oo0P001Woo43g_AGoo00<007ooOol0H7oo001ROol30007Ool>?Nm0
Ool3001SOol006Eoo`<000Moo`hmk`aoo`TmkbEoo`<006Ioo`00J7oo10001Woo83g_8Goo1000JGoo
001/Ool40003OolO?NlMOol4001]Ool0071oo`<000=ooa`mkaUoo`@0075oo`00Lgoo1@0000=oocg_
?Nl05cg_5Goo1000MGoo001hOol5000E?Nl>Ool7001iOol007moo`L000Pmk`Aoo`h0081oo`00SGoo
1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool30004Ool2002=Ool0
08Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002:Ool01000Oomoo`000Woo00@007ooOol008ao
o`00RWoo0`000goo00@007ooOol008aoo`00Rgoo00<007ooOol00Woo00@007ooOol008aoo`00Rgoo
0`000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(61)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
1 .988 0 r
.008 w
.08024 .60537 Mdot
.016 w
.08024 .60537 m
.08023 .60563 L
s
1 .976 0 r
.008 w
.08023 .60563 Mdot
.016 w
.08023 .60563 m
.08022 .60606 L
s
1 .964 0 r
.008 w
.08022 .60606 Mdot
.016 w
.08022 .60606 m
.08019 .60666 L
s
1 .952 0 r
.008 w
.08019 .60666 Mdot
.016 w
.08019 .60666 m
.08017 .60743 L
s
1 .94 0 r
.008 w
.08017 .60743 Mdot
.016 w
.08017 .60743 m
.08013 .60836 L
s
1 .929 0 r
.008 w
.08013 .60836 Mdot
.016 w
.08013 .60836 m
.08009 .60943 L
s
1 .917 0 r
.008 w
.08009 .60943 Mdot
.016 w
.08009 .60943 m
.08005 .61051 L
s
1 .905 0 r
.008 w
.08005 .61051 Mdot
.016 w
.08005 .61051 m
.08001 .61163 L
s
1 .893 0 r
.008 w
.08001 .61163 Mdot
.016 w
.08001 .61163 m
.07997 .61277 L
s
1 .881 0 r
.008 w
.07997 .61277 Mdot
.016 w
.07997 .61277 m
.07993 .61393 L
s
1 .869 0 r
.008 w
.07993 .61393 Mdot
.016 w
.07993 .61393 m
.07989 .61494 L
s
1 .857 0 r
.008 w
.07989 .61494 Mdot
.016 w
.07989 .61494 m
.07986 .61579 L
s
1 .845 0 r
.008 w
.07986 .61579 Mdot
.016 w
.07986 .61579 m
.07982 .61643 L
s
1 .833 0 r
.008 w
.07982 .61643 Mdot
.016 w
.07982 .61643 m
.07978 .61685 L
s
1 .821 0 r
.008 w
.07978 .61685 Mdot
.016 w
.07978 .61685 m
.07973 .61708 L
s
1 .81 0 r
.008 w
.07973 .61708 Mdot
.016 w
.07973 .61708 m
.07968 .61718 L
s
1 .798 0 r
.008 w
.07968 .61718 Mdot
.016 w
.07968 .61718 m
.07965 .61719 L
s
1 .786 0 r
.008 w
.07965 .61719 Mdot
.016 w
.07965 .61719 m
.07964 .6172 L
s
1 .774 0 r
.008 w
.07964 .6172 Mdot
.016 w
.07964 .6172 m
.07965 .6173 L
s
1 .762 0 r
.008 w
.07965 .6173 Mdot
.016 w
.07965 .6173 m
.07969 .61758 L
s
1 .75 0 r
.008 w
.07969 .61758 Mdot
.016 w
.07969 .61758 m
.07978 .61808 L
s
1 .738 0 r
.008 w
.07978 .61808 Mdot
.016 w
.07978 .61808 m
.07992 .61885 L
s
1 .726 0 r
.008 w
.07992 .61885 Mdot
.016 w
.07992 .61885 m
.08014 .61996 L
s
1 .714 0 r
.008 w
.08014 .61996 Mdot
.016 w
.08014 .61996 m
.08042 .62146 L
s
1 .702 0 r
.008 w
.08042 .62146 Mdot
.016 w
.08042 .62146 m
.08079 .62324 L
s
1 .69 0 r
.008 w
.08079 .62324 Mdot
.016 w
.08079 .62324 m
.0812 .62539 L
s
1 .679 0 r
.008 w
.0812 .62539 Mdot
.016 w
.0812 .62539 m
.08167 .62796 L
s
1 .667 0 r
.008 w
.08167 .62796 Mdot
.016 w
.08167 .62796 m
.0822 .63078 L
s
1 .655 0 r
.008 w
.0822 .63078 Mdot
.016 w
.0822 .63078 m
.08279 .63416 L
s
1 .643 0 r
.008 w
.08279 .63416 Mdot
.016 w
.08279 .63416 m
.0834 .63768 L
s
1 .631 0 r
.008 w
.0834 .63768 Mdot
.016 w
.0834 .63768 m
.08402 .64106 L
s
1 .619 0 r
.008 w
.08402 .64106 Mdot
.016 w
.08402 .64106 m
.08463 .64502 L
s
1 .607 0 r
.008 w
.08463 .64502 Mdot
.016 w
.08463 .64502 m
.08521 .64932 L
s
1 .595 0 r
.008 w
.08521 .64932 Mdot
.016 w
.08521 .64932 m
.08574 .65298 L
s
1 .583 0 r
.008 w
.08574 .65298 Mdot
.016 w
.08574 .65298 m
.08624 .65714 L
s
1 .571 0 r
.008 w
.08624 .65714 Mdot
.016 w
.08624 .65714 m
.08672 .66159 L
s
1 .56 0 r
.008 w
.08672 .66159 Mdot
.016 w
.08672 .66159 m
.08718 .66513 L
s
1 .548 0 r
.008 w
.08718 .66513 Mdot
.016 w
.08718 .66513 m
.08761 .66906 L
s
1 .536 0 r
.008 w
.08761 .66906 Mdot
.016 w
.08761 .66906 m
.08802 .67262 L
s
1 .524 0 r
.008 w
.08802 .67262 Mdot
.016 w
.08802 .67262 m
.08842 .67609 L
s
1 .512 0 r
.008 w
.08842 .67609 Mdot
.016 w
.08842 .67609 m
.08878 .67898 L
s
1 .5 0 r
.008 w
.08878 .67898 Mdot
.016 w
.08878 .67898 m
.08912 .68163 L
s
1 .488 0 r
.008 w
.08912 .68163 Mdot
.016 w
.08912 .68163 m
.08941 .68384 L
s
1 .476 0 r
.008 w
.08941 .68384 Mdot
.016 w
.08941 .68384 m
.08966 .68546 L
s
1 .464 0 r
.008 w
.08966 .68546 Mdot
.016 w
.08966 .68546 m
.08989 .68679 L
s
1 .452 0 r
.008 w
.08989 .68679 Mdot
.016 w
.08989 .68679 m
.0901 .68784 L
s
1 .44 0 r
.008 w
.0901 .68784 Mdot
.016 w
.0901 .68784 m
.09032 .6886 L
s
1 .429 0 r
.008 w
.09032 .6886 Mdot
.016 w
.09032 .6886 m
.09053 .68914 L
s
1 .417 0 r
.008 w
.09053 .68914 Mdot
.016 w
.09053 .68914 m
.09074 .68955 L
s
1 .405 0 r
.008 w
.09074 .68955 Mdot
.016 w
.09074 .68955 m
.09096 .68996 L
s
1 .393 0 r
.008 w
.09096 .68996 Mdot
.016 w
.09096 .68996 m
.09116 .69043 L
s
1 .381 0 r
.008 w
.09116 .69043 Mdot
.016 w
.09116 .69043 m
.09136 .69098 L
s
1 .369 0 r
.008 w
.09136 .69098 Mdot
.016 w
.09136 .69098 m
.09154 .69163 L
s
1 .357 0 r
.008 w
.09154 .69163 Mdot
.016 w
.09154 .69163 m
.09173 .69243 L
s
1 .345 0 r
.008 w
.09173 .69243 Mdot
.016 w
.09173 .69243 m
.09194 .69336 L
s
1 .333 0 r
.008 w
.09194 .69336 Mdot
.016 w
.09194 .69336 m
.0922 .69449 L
s
1 .321 0 r
.008 w
.0922 .69449 Mdot
.016 w
.0922 .69449 m
.09249 .69573 L
s
1 .31 0 r
.008 w
.09249 .69573 Mdot
.016 w
.09249 .69573 m
.09281 .697 L
s
1 .298 0 r
.008 w
.09281 .697 Mdot
.016 w
.09281 .697 m
.09312 .69828 L
s
1 .286 0 r
.008 w
.09312 .69828 Mdot
.016 w
.09312 .69828 m
.09343 .69958 L
s
1 .274 0 r
.008 w
.09343 .69958 Mdot
.016 w
.09343 .69958 m
.09372 .70079 L
s
1 .262 0 r
.008 w
.09372 .70079 Mdot
.016 w
.09372 .70079 m
.094 .702 L
s
1 .25 0 r
.008 w
.094 .702 Mdot
.016 w
.094 .702 m
.09429 .70329 L
s
1 .238 0 r
.008 w
.09429 .70329 Mdot
.016 w
.09429 .70329 m
.09458 .70475 L
s
1 .226 0 r
.008 w
.09458 .70475 Mdot
.016 w
.09458 .70475 m
.0949 .70639 L
s
1 .214 0 r
.008 w
.0949 .70639 Mdot
.016 w
.0949 .70639 m
.0953 .70832 L
s
1 .202 0 r
.008 w
.0953 .70832 Mdot
.016 w
.0953 .70832 m
.0957 .71005 L
s
1 .19 0 r
.008 w
.0957 .71005 Mdot
.016 w
.0957 .71005 m
.09615 .71226 L
s
1 .179 0 r
.008 w
.09615 .71226 Mdot
.016 w
.09615 .71226 m
.09663 .71473 L
s
1 .167 0 r
.008 w
.09663 .71473 Mdot
.016 w
.09663 .71473 m
.09709 .71705 L
s
1 .155 0 r
.008 w
.09709 .71705 Mdot
.016 w
.09709 .71705 m
.09756 .71962 L
s
1 .143 0 r
.008 w
.09756 .71962 Mdot
.016 w
.09756 .71962 m
.09803 .72234 L
s
1 .131 0 r
.008 w
.09803 .72234 Mdot
.016 w
.09803 .72234 m
.09851 .72501 L
s
1 .119 0 r
.008 w
.09851 .72501 Mdot
.016 w
.09851 .72501 m
.099 .72793 L
s
1 .107 0 r
.008 w
.099 .72793 Mdot
.016 w
.099 .72793 m
.09948 .73007 L
s
1 .095 0 r
.008 w
.09948 .73007 Mdot
.016 w
.09948 .73007 m
.09994 .73227 L
s
1 .083 0 r
.008 w
.09994 .73227 Mdot
.016 w
.09994 .73227 m
.10034 .73422 L
s
1 .071 0 r
.008 w
.10034 .73422 Mdot
.016 w
.10034 .73422 m
.10066 .73581 L
s
1 .06 0 r
.008 w
.10066 .73581 Mdot
.016 w
.10066 .73581 m
.10089 .73704 L
s
1 .048 0 r
.008 w
.10089 .73704 Mdot
.016 w
.10089 .73704 m
.10104 .73791 L
s
1 .036 0 r
.008 w
.10104 .73791 Mdot
.016 w
.10104 .73791 m
.10116 .73846 L
s
1 .024 0 r
.008 w
.10116 .73846 Mdot
.016 w
.10116 .73846 m
.10126 .73871 L
s
1 .012 0 r
.008 w
.10126 .73871 Mdot
.016 w
.10126 .73871 m
.10135 .73879 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo00<mkgo0Ol000Wo000<mkgooOol0kWoo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool00cg_
Oh1oP002Oh000cg_Oomoo`3]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`03?NmoH7mP009o
H?1oo`03001oogoo00moo`0047oo00<007ooOol01Woo00<mkgkPO^000WkPl7oo00<007ooOol03goo
000@Ool00`00Oomoo`06Ool00cg_O/1n`002O/3`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eo
o`03?NmnX7jP009nX003?Nmoogoo0>eoo`03001oogoo00moo`004Goo00<007ooOol01Woo17jP0Sg_
kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool4OX000cg_Oomoo`3/Ool00`00Oomoo`0@Ool0
019oo`03001oogoo00Eoo`AnP003?Nmoogoo0>aoo`03001oogoo011oo`004Woo00<007ooOol01Goo
1Gj0kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool00gj0OV1nH002OV000gj0Oomoo`3ZOol0
0`00Oomoo`0AOol001=oo`03001oogoo00Aoo`03OX1nH7iP009nH>eoo`03001oogoo015oo`004goo
00<007ooOol01Goo17iP00<mkgooOol0jGoo00<007ooOol04Woo000COol00`00Oomoo`05Ool4OT00
0cg_Oomoo`3YOol00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`An@003?Nmoogoo0>Uoo`03001o
ogoo019oo`0057oo00<007ooOol017oo00=n@7hPOR000WhP00<mkgooOol0igoo00<007ooOol04goo
000DOol00`00Oomoo`04Ool00gi0OR1n8002OR000gi0Oomoo`3WOol00`00Oomoo`0COol001Eoo`03
001oogoo00=oo`03OT1n87hP009n8003?Nmoogoo0>Moo`03001oogoo01=oo`005Goo00<007ooOol0
17oo17h000<mkgooOol0iWoo00<007ooOol057oo000EOol00`00Oomoo`04Ool4OP000cg_Oomoo`3V
Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`Amh003?Nmoogoo0>Ioo`03001oogoo01Aoo`00
5Woo00<007ooOol00goo0WgP00=m`7gP?Nl0igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool0
1GgPOL1m`7g0?Nl0igoo00<007ooOol05Goo000GOol00`00Oomoo`02Ool00gg0OF1mH002OF3VOol0
0`00Oomoo`0FOol001Moo`03001oogoo009oo`03OL1m@7e0009m@003OL1oogoo0>=oo`03001oogoo
01Ioo`0067oo00D007ooOomooggP00Am8003?Nmoogoo0>9oo`03001oogoo01Moo`0067oo00<007oo
Ool00Woo00=m07cPO>000WcPi7oo00<007ooOol05goo000IOol01@00OomoogooO@0017c000<mkgoo
Ool0hGoo00<007ooOol05goo000IOol01@00OomoogooO@0017c00Sg_hGoo00<007ooOol067oo000J
Ool01000Oomoogd00WbP00AlP7bP?Nlmkn5oo`03001oogoo01Qoo`006Woo00D007ooOomoogbP00=l
P08mkn1oo`03001oogoo01Uoo`006goo00<007ooOol01Gb000<mkgooOol0gGoo00<007ooOol06Woo
000KOol00`00Oomoo`06O83OOol00`00Oomoo`0JOol001aoo`03001oogbP00AlH003?Nmoogoo0=ao
o`03001oogoo01]oo`0077oo00<007ooOol017aP00<mkgooOol0g7oo00<007ooOol06goo000MOol0
0`00Ooml@003O4000cg_Oomoo`3KOol00`00Oomoo`0LOol001eoo`03001oog`000Al0=eoo`03001o
ogoo01aoo`007Woo00<007`0O0000g`000<mkgooOol0fGoo00<007ooOol07Goo000NOol00`00O01l
0003O0000cg_Oomoo`3IOol00`00Oomoo`0MOol001moo`El008mkmUoo`03001oogoo01ioo`007goo
00<003g_?Nl01Cg_f7oo00<007ooOol07Woo000POol00`00?Nlmk`05?NoFOol00`00Oomoo`0OOol0
021oo`03000mkcg_00DmkmIoo`03001oogoo01moo`008Goo00<003g_?Nl01Sg_dgoo00<007ooOol0
87oo000ROol00`00?Nlmk`06?NoAOol00`00Oomoo`0QOol002=oo`03001oocg_00Dmkm1oo`03001o
ogoo029oo`0097oo00<003g_?Nl01Sg_cGoo00<007ooOol08goo000TOol00`00?Nlmk`07?No<Ool0
0`00Oomoo`0SOol002Eoo`03000mkcg_00LmklYoo`03001oogoo02Aoo`009Woo00<003g_?Nl01cg_
b7oo00<007ooOol09Goo000VOol00`00Oolmk`0;?No4Ool00`00Oomoo`0UOol002Moo`03001oocg_
00Xmkl=oo`03001oogoo02Ioo`00:7oo00@007ooOomoo`Pmkl9oo`03001oogoo02Moo`00:Goo00@0
07ooOomoo`Pmkl1oo`03001oogoo02Qoo`00:Woo00<007ooOol023g__goo00<007ooOol0:Goo000Z
Ool01000Oomoogoo23g__Woo00<007ooOol0:Goo000[Ool00`00Oomoo`02Ool6?NnmOol00`00Oomo
o`0ZOol002aoo`04001oogooOol7?NnkOol00`00Oomoo`0[Ool002eoo`03001oogoo00PmkkUoo`03
001oogoo02aoo`00;Woo00<007ooOol023g_]goo00<007ooOol0;Goo000^Ool01000Oomoogoo23g_
]Woo00<007ooOol0;Goo000_Ool01000Oomoogoo2Cg_/goo00<007ooOol0;Woo000`Ool01000Oomo
ogoo23g_/Woo00<007ooOol0;goo000aOol01000Oomoogoo23g_/7oo00<007ooOol0<7oo000bOol2
0003Ool7?Nn]Ool2000cOol003Aoo`04001oogooOol7?Nn[Ool00`00Oomoo`0cOol003Eoo`04001o
ogooOol7?NnYOol00`00Oomoo`0dOol003Eoo`04001oogooOol8?NnXOol00`00Oomoo`0dOol003Io
o`04001oogooOol8?NnVOol00`00Oomoo`0eOol003Moo`03001oogoo00=oo`HmkjAoo`03001oogoo
03Ioo`00>7oo00<007ooOol00goo1Sg_XWoo00<007ooOol0=goo000iOol20004Ool7?NnNOol2000j
Ool003]oo`04001oogooOol8?NnLOol00`00Oomoo`0jOol003aoo`03001oogoo00TmkiYoo`03001o
ogoo03]oo`00?Goo00<007ooOol02Sg_Ugoo00<007ooOol0?7oo000nOol20003Ool8?NnDOol2000o
Ool0041oo`03001oogoo00Tmki9oo`03001oogoo03moo`00@Goo0P0000=oocg_?Nl01cg_Sgoo0P00
@Woo0013Ool00`00Oolmk`08?Nn=Ool00`00Oomoo`12Ool004Aoo`03001oocg_00Pmkh]oo`03001o
ogoo04=oo`00AGoo00@007ooOomoo`LmkhUoo`03001oogoo04Aoo`00AWoo0P0000=oocg_?Nl01cg_
QGoo0P00Agoo0018Ool2000;?Nl3Ool2?NmkOol20019Ool004Yoo`03000mkcg_00hmkgQoo`8004]o
o`00C7oo43g_MGoo0P00CGoo001>Ool00`00Oolmk`0<?NmcOol00`00Oomoo`1=Ool004moo`03000m
kcg_00hmkfmoo`03001oogoo04ioo`00D7oo0P000Woo3cg_JWoo0P00DGoo001BOol200000goo?Nlm
k`02Ool<?NmVOol2001COol005Aoo`800003?Nmoogoo00lmk`Qoo`DmkeAoo`8005Eoo`00EWoo0P00
17oo43g_0goo1Sg_DWoo0P00Egoo001HOol30004OolF?Nm?Ool3001IOol005]oo`<000Eooa8mkdao
o`<005aoo`00GWoo0P001Woo43g_B7oo0`00Ggoo001POol20006Ool@?Nm5Ool00`00Oomoo`1POol0
069oo`<000Moo`hmkd1oo`<006=oo`00IGoo0`001goo3Sg_37oo2Cg_9Goo0`00IWoo001XOol40006
OolP?NlQOol4001YOol006aoo`@000=ooalmkaeoo`@006eoo`00L7oo0`000goo73g_6Goo1000LGoo
001cOol500000goo?Nlmk`0G?NlEOol4001eOol007Qoo`D001Dmk`ioo`L007Uoo`00Ogoo1`0023g_
17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yo
o`<000=oo`D008]oo`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00RWoo00@007ooOol000Ao
o`03001oogoo08]oo`00RWoo0`001Goo00<007ooOol0Rgoo002;Ool00`00Oomoo`04Ool00`00Oomo
o`2;Ool008]oo`<000=oo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(62)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
1 .982 0 r
.008 w
.11285 .75251 Mdot
.016 w
.11285 .75251 m
.11279 .75235 L
s
1 .964 0 r
.008 w
.11279 .75235 Mdot
.016 w
.11279 .75235 m
.11264 .75215 L
s
1 .946 0 r
.008 w
.11264 .75215 Mdot
.016 w
.11264 .75215 m
.11241 .75193 L
s
1 .929 0 r
.008 w
.11241 .75193 Mdot
.016 w
.11241 .75193 m
.11213 .75169 L
s
1 .911 0 r
.008 w
.11213 .75169 Mdot
.016 w
.11213 .75169 m
.11181 .75143 L
s
1 .893 0 r
.008 w
.11181 .75143 Mdot
.016 w
.11181 .75143 m
.1115 .75118 L
s
1 .875 0 r
.008 w
.1115 .75118 Mdot
.016 w
.1115 .75118 m
.11122 .75098 L
s
1 .857 0 r
.008 w
.11122 .75098 Mdot
.016 w
.11122 .75098 m
.11101 .75091 L
s
1 .839 0 r
.008 w
.11101 .75091 Mdot
.016 w
.11101 .75091 m
.11089 .75101 L
s
1 .821 0 r
.008 w
.11089 .75101 Mdot
.016 w
.11089 .75101 m
.11089 .7513 L
s
1 .804 0 r
.008 w
.11089 .7513 Mdot
.016 w
.11089 .7513 m
.11104 .75182 L
s
1 .786 0 r
.008 w
.11104 .75182 Mdot
.016 w
.11104 .75182 m
.11134 .75253 L
s
1 .768 0 r
.008 w
.11134 .75253 Mdot
.016 w
.11134 .75253 m
.11181 .75347 L
s
1 .75 0 r
.008 w
.11181 .75347 Mdot
.016 w
.11181 .75347 m
.11243 .75442 L
s
1 .732 0 r
.008 w
.11243 .75442 Mdot
.016 w
.11243 .75442 m
.11318 .75551 L
s
1 .714 0 r
.008 w
.11318 .75551 Mdot
.016 w
.11318 .75551 m
.114 .75665 L
s
1 .696 0 r
.008 w
.114 .75665 Mdot
.016 w
.114 .75665 m
.11495 .7578 L
s
1 .679 0 r
.008 w
.11495 .7578 Mdot
.016 w
.11495 .7578 m
.116 .75894 L
s
1 .661 0 r
.008 w
.116 .75894 Mdot
.016 w
.116 .75894 m
.11714 .7601 L
s
1 .643 0 r
.008 w
.11714 .7601 Mdot
.016 w
.11714 .7601 m
.11833 .76125 L
s
1 .625 0 r
.008 w
.11833 .76125 Mdot
.016 w
.11833 .76125 m
.11953 .76233 L
s
1 .607 0 r
.008 w
.11953 .76233 Mdot
.016 w
.11953 .76233 m
.12069 .76332 L
s
1 .589 0 r
.008 w
.12069 .76332 Mdot
.016 w
.12069 .76332 m
.12178 .76418 L
s
1 .571 0 r
.008 w
.12178 .76418 Mdot
.016 w
.12178 .76418 m
.12276 .76491 L
s
1 .554 0 r
.008 w
.12276 .76491 Mdot
.016 w
.12276 .76491 m
.12359 .76552 L
s
1 .536 0 r
.008 w
.12359 .76552 Mdot
.016 w
.12359 .76552 m
.12427 .76598 L
s
1 .518 0 r
.008 w
.12427 .76598 Mdot
.016 w
.12427 .76598 m
.1248 .76632 L
s
1 .5 0 r
.008 w
.1248 .76632 Mdot
.016 w
.1248 .76632 m
.12515 .76657 L
s
1 .482 0 r
.008 w
.12515 .76657 Mdot
.016 w
.12515 .76657 m
.12538 .76681 L
s
1 .464 0 r
.008 w
.12538 .76681 Mdot
.016 w
.12538 .76681 m
.12546 .76706 L
s
1 .446 0 r
.008 w
.12546 .76706 Mdot
.016 w
.12546 .76706 m
.12542 .76728 L
s
1 .429 0 r
.008 w
.12542 .76728 Mdot
.016 w
.12542 .76728 m
.12528 .76749 L
s
1 .411 0 r
.008 w
.12528 .76749 Mdot
.016 w
.12528 .76749 m
.12508 .76765 L
s
1 .393 0 r
.008 w
.12508 .76765 Mdot
.016 w
.12508 .76765 m
.12481 .76777 L
s
1 .375 0 r
.008 w
.12481 .76777 Mdot
.016 w
.12481 .76777 m
.12455 .76787 L
s
1 .357 0 r
.008 w
.12455 .76787 Mdot
.016 w
.12455 .76787 m
.1243 .76798 L
s
1 .339 0 r
.008 w
.1243 .76798 Mdot
.016 w
.1243 .76798 m
.12406 .76809 L
s
1 .321 0 r
.008 w
.12406 .76809 Mdot
.016 w
.12406 .76809 m
.12385 .76821 L
s
1 .304 0 r
.008 w
.12385 .76821 Mdot
.016 w
.12385 .76821 m
.12377 .7684 L
s
1 .286 0 r
.008 w
.12377 .7684 Mdot
.016 w
.12377 .7684 m
.12379 .76863 L
s
1 .268 0 r
.008 w
.12379 .76863 Mdot
.016 w
.12379 .76863 m
.12392 .76886 L
s
1 .25 0 r
.008 w
.12392 .76886 Mdot
.016 w
.12392 .76886 m
.12411 .76905 L
s
1 .232 0 r
.008 w
.12411 .76905 Mdot
.016 w
.12411 .76905 m
.12439 .76919 L
s
1 .214 0 r
.008 w
.12439 .76919 Mdot
.016 w
.12439 .76919 m
.12473 .76929 L
s
1 .196 0 r
.008 w
.12473 .76929 Mdot
.016 w
.12473 .76929 m
.12513 .76935 L
s
1 .179 0 r
.008 w
.12513 .76935 Mdot
.016 w
.12513 .76935 m
.12558 .76937 L
s
1 .161 0 r
.008 w
.12558 .76937 Mdot
.016 w
.12558 .76937 m
.12602 .76938 L
s
1 .143 0 r
.008 w
.12602 .76938 Mdot
.016 w
.12602 .76938 m
.12647 .76936 L
s
1 .125 0 r
.008 w
.12647 .76936 Mdot
.016 w
.12647 .76936 m
.12686 .76933 L
s
1 .107 0 r
.008 w
.12686 .76933 Mdot
.016 w
.12686 .76933 m
.12722 .7693 L
s
1 .089 0 r
.008 w
.12722 .7693 Mdot
.016 w
.12722 .7693 m
.12756 .76932 L
s
1 .071 0 r
.008 w
.12756 .76932 Mdot
.016 w
.12756 .76932 m
.12789 .76937 L
s
1 .054 0 r
.008 w
.12789 .76937 Mdot
.016 w
.12789 .76937 m
.12818 .76944 L
s
1 .036 0 r
.008 w
.12818 .76944 Mdot
.016 w
.12818 .76944 m
.12843 .76949 L
s
1 .018 0 r
.008 w
.12843 .76949 Mdot
.016 w
.12843 .76949 m
.12859 .76948 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Ao
o`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0Woo1Sg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo
01Moo`006Goo00@007ooOomoo`Lmkn5oo`03001oogoo01Qoo`006Woo00<007ooOol01cg_hGoo00<0
07ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoO
Ool00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol0
1Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001o
ocg_00@mkmeoo`03001oogoo01aoo`007Goo00<007oo?Nl013g_gGoo00<007ooOol077oo000NOol0
0`00?Nlmk`04?NoKOol00`00Oomoo`0MOol001ioo`03000mkcg_00@mkm]oo`03001oogoo01eoo`00
7goo1Cg_00=nh3g_Ool0f7oo00<007ooOol07Woo000OOol01000?NlmkgnP0gkP00=oX7ooOol0eWoo
00<007ooOol07Woo000POol00`00?Nmnh004O/000cg_Oomoo`3DOol00`00Oomoo`0OOol0021oo`04
000mkgkPOZ04OX3FOol00`00Oomoo`0OOol0025oo`04001oX7jPOV04OT000cg_Oomoo`3AOol00`00
Oomoo`0POol0029oo`04001nX7iPOR04OB000cg_Oomoo`3?Ool00`00Oomoo`0QOol002=oo`03OZ1n
H7hP009lH003O01lH7aP0=1oo`03001oogoo029oo`0097oo00EnH7hPO61lH7`0009lH08mkleoo`03
001oogoo02=oo`0097oo00<007hPO60017aP0cg_c7oo00<007ooOol08goo000UOol00`00O61lH003
O604?No:Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmklQoo`03001oogoo02Eoo`009Woo00<0
07oo?Nl02cg_a7oo00<007ooOol09Goo000WOol00`00Oolmk`0:?No3Ool00`00Oomoo`0VOol002Qo
o`04001oogooOol8?No2Ool00`00Oomoo`0WOol002Uoo`04001oogooOol8?No0Ool00`00Oomoo`0X
Ool002Yoo`03001oogoo00Pmkkmoo`03001oogoo02Uoo`00:Woo00@007ooOomoo`Pmkkioo`03001o
ogoo02Uoo`00:goo00<007ooOol00Woo1Sg__Goo00<007ooOol0:Woo000/Ool01000Oomoogoo1cg_
^goo00<007ooOol0:goo000]Ool00`00Oomoo`08?NniOol00`00Oomoo`0/Ool002ioo`03001oogoo
00PmkkMoo`03001oogoo02eoo`00;Woo00@007ooOomoo`PmkkIoo`03001oogoo02eoo`00;goo00@0
07ooOomoo`Tmkk=oo`03001oogoo02ioo`00<7oo00@007ooOomoo`Pmkk9oo`03001oogoo02moo`00
<Goo00@007ooOomoo`Pmkk1oo`03001oogoo031oo`00<Woo0P000goo1cg_[Goo0P00<goo000dOol0
1000Oomoogoo1cg_Zgoo00<007ooOol0<goo000eOol01000Oomoogoo1cg_ZGoo00<007ooOol0=7oo
000eOol01000Oomoogoo23g_Z7oo00<007ooOol0=7oo000fOol01000Oomoogoo23g_YWoo00<007oo
Ool0=Goo000gOol00`00Oomoo`03Ool6?NnTOol00`00Oomoo`0fOol003Qoo`03001oogoo00=oo`Hm
kj9oo`03001oogoo03Moo`00>Goo0P0017oo1cg_WWoo0P00>Woo000kOol01000Oomoogoo23g_W7oo
00<007ooOol0>Woo000lOol00`00Oomoo`09?NnJOol00`00Oomoo`0kOol003eoo`03001oogoo00Xm
kiMoo`03001oogoo03aoo`00?Woo0P000goo23g_U7oo0P00?goo0010Ool00`00Oomoo`09?NnBOol0
0`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkhmoo`80049oo`00@goo00<007oo?Nl023g_SGoo
00<007ooOol0@Woo0014Ool00`00Oolmk`08?Nn;Ool00`00Oomoo`13Ool004Eoo`04001oogooOol7
?Nn9Ool00`00Oomoo`14Ool004Ioo`800003Oolmkcg_00LmkhEoo`8004Moo`00B7oo0P002cg_0goo
0Sg_Ngoo0P00BGoo001:Ool00`00?Nlmk`0>?NmhOol2001;Ool004aooa0mkgEoo`8004eoo`00CWoo
00<007oo?Nl033g_Lgoo00<007ooOol0CGoo001?Ool00`00?Nlmk`0>?Nm_Ool00`00Oomoo`1>Ool0
051oo`80009oo`lmkfYoo`80055oo`00DWoo0P0000=oocg_?Nl00Woo33g_IWoo0P00Dgoo001DOol2
00000cg_Oomoo`0??Nl8Ool5?NmDOol2001EOol005Ioo`8000Aooa0mk`=oo`Hmke9oo`8005Moo`00
F7oo0`0017oo5Sg_Cgoo0`00FGoo001KOol30005OolB?Nm<Ool3001LOol005ioo`8000Iooa0mkdQo
o`<005moo`00H7oo0P001Woo43g_AGoo00<007ooOol0H7oo001ROol30007Ool>?Nm0Ool3001SOol0
06Eoo`<000Moo`hmk`aoo`TmkbEoo`<006Ioo`00J7oo10001Woo83g_8Goo1000JGoo001/Ool40003
OolO?NlMOol4001]Ool0071oo`<000=ooa`mkaUoo`@0075oo`00Lgoo1@0000=oocg_?Nl05cg_5Goo
1000MGoo001hOol5000E?Nl>Ool7001iOol007moo`L000Pmk`Aoo`h0081oo`00SGoo1@00SWoo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool30003Ool4002<Ool008Yoo`04001o
ogoo0002Ool00`00Oomoo`2=Ool008Yoo`04001oogoo0003Ool00`00Oomoo`2<Ool008Yoo`<000Eo
o`03001oogoo08]oo`00Rgoo00<007ooOol00Woo00@007ooOol008aoo`00Rgoo0`000goo0P00SGoo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(63)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
1 .986 0 r
.008 w
.12767 .7691 Mdot
.016 w
.12767 .7691 m
.12765 .76931 L
s
1 .971 0 r
.008 w
.12765 .76931 Mdot
.016 w
.12765 .76931 m
.12765 .7696 L
s
1 .957 0 r
.008 w
.12765 .7696 Mdot
.016 w
.12765 .7696 m
.12766 .76995 L
s
1 .943 0 r
.008 w
.12766 .76995 Mdot
.016 w
.12766 .76995 m
.12772 .77037 L
s
1 .929 0 r
.008 w
.12772 .77037 Mdot
.016 w
.12772 .77037 m
.1278 .77086 L
s
1 .914 0 r
.008 w
.1278 .77086 Mdot
.016 w
.1278 .77086 m
.12789 .77141 L
s
1 .9 0 r
.008 w
.12789 .77141 Mdot
.016 w
.12789 .77141 m
.128 .77199 L
s
1 .886 0 r
.008 w
.128 .77199 Mdot
.016 w
.128 .77199 m
.12811 .77254 L
s
1 .871 0 r
.008 w
.12811 .77254 Mdot
.016 w
.12811 .77254 m
.12823 .77308 L
s
1 .857 0 r
.008 w
.12823 .77308 Mdot
.016 w
.12823 .77308 m
.12834 .77359 L
s
1 .843 0 r
.008 w
.12834 .77359 Mdot
.016 w
.12834 .77359 m
.12847 .77405 L
s
1 .829 0 r
.008 w
.12847 .77405 Mdot
.016 w
.12847 .77405 m
.12863 .77446 L
s
1 .814 0 r
.008 w
.12863 .77446 Mdot
.016 w
.12863 .77446 m
.12885 .77482 L
s
1 .8 0 r
.008 w
.12885 .77482 Mdot
.016 w
.12885 .77482 m
.12917 .77511 L
s
1 .786 0 r
.008 w
.12917 .77511 Mdot
.016 w
.12917 .77511 m
.1296 .77533 L
s
1 .771 0 r
.008 w
.1296 .77533 Mdot
.016 w
.1296 .77533 m
.13017 .77553 L
s
1 .757 0 r
.008 w
.13017 .77553 Mdot
.016 w
.13017 .77553 m
.13088 .77567 L
s
1 .743 0 r
.008 w
.13088 .77567 Mdot
.016 w
.13088 .77567 m
.13166 .77575 L
s
1 .729 0 r
.008 w
.13166 .77575 Mdot
.016 w
.13166 .77575 m
.13253 .77578 L
s
1 .714 0 r
.008 w
.13253 .77578 Mdot
.016 w
.13253 .77578 m
.13341 .77581 L
s
1 .7 0 r
.008 w
.13341 .77581 Mdot
.016 w
.13341 .77581 m
.13428 .77587 L
s
1 .686 0 r
.008 w
.13428 .77587 Mdot
.016 w
.13428 .77587 m
.13509 .77594 L
s
1 .671 0 r
.008 w
.13509 .77594 Mdot
.016 w
.13509 .77594 m
.13581 .77601 L
s
1 .657 0 r
.008 w
.13581 .77601 Mdot
.016 w
.13581 .77601 m
.13638 .77607 L
s
1 .643 0 r
.008 w
.13638 .77607 Mdot
.016 w
.13638 .77607 m
.13671 .77613 L
s
1 .629 0 r
.008 w
.13671 .77613 Mdot
.016 w
.13671 .77613 m
.13701 .77617 L
s
1 .614 0 r
.008 w
.13701 .77617 Mdot
.016 w
.13701 .77617 m
.13721 .77621 L
s
1 .6 0 r
.008 w
.13721 .77621 Mdot
.016 w
.13721 .77621 m
.13728 .77623 L
s
1 .586 0 r
.008 w
.13728 .77623 Mdot
.016 w
.13728 .77623 m
.13723 .77623 L
s
1 .571 0 r
.008 w
.13723 .77623 Mdot
.016 w
.13723 .77623 m
.13706 .77619 L
s
1 .557 0 r
.008 w
.13706 .77619 Mdot
.016 w
.13706 .77619 m
.1368 .77614 L
s
1 .543 0 r
.008 w
.1368 .77614 Mdot
.016 w
.1368 .77614 m
.13649 .7761 L
s
1 .529 0 r
.008 w
.13649 .7761 Mdot
.016 w
.13649 .7761 m
.13616 .77605 L
s
1 .514 0 r
.008 w
.13616 .77605 Mdot
.016 w
.13616 .77605 m
.1358 .77598 L
s
1 .5 0 r
.008 w
.1358 .77598 Mdot
.016 w
.1358 .77598 m
.13542 .77587 L
s
1 .486 0 r
.008 w
.13542 .77587 Mdot
.016 w
.13542 .77587 m
.13503 .77573 L
s
1 .471 0 r
.008 w
.13503 .77573 Mdot
.016 w
.13503 .77573 m
.13463 .77557 L
s
1 .457 0 r
.008 w
.13463 .77557 Mdot
.016 w
.13463 .77557 m
.13425 .77545 L
s
1 .443 0 r
.008 w
.13425 .77545 Mdot
.016 w
.13425 .77545 m
.13395 .77541 L
s
1 .429 0 r
.008 w
.13395 .77541 Mdot
.016 w
.13395 .77541 m
.13376 .77549 L
s
1 .414 0 r
.008 w
.13376 .77549 Mdot
.016 w
.13376 .77549 m
.13371 .77574 L
s
1 .4 0 r
.008 w
.13371 .77574 Mdot
.016 w
.13371 .77574 m
.13381 .77615 L
s
1 .386 0 r
.008 w
.13381 .77615 Mdot
.016 w
.13381 .77615 m
.13405 .77674 L
s
1 .371 0 r
.008 w
.13405 .77674 Mdot
.016 w
.13405 .77674 m
.13443 .77748 L
s
1 .357 0 r
.008 w
.13443 .77748 Mdot
.016 w
.13443 .77748 m
.13497 .77836 L
s
1 .343 0 r
.008 w
.13497 .77836 Mdot
.016 w
.13497 .77836 m
.13557 .77933 L
s
1 .329 0 r
.008 w
.13557 .77933 Mdot
.016 w
.13557 .77933 m
.13613 .7803 L
s
1 .314 0 r
.008 w
.13613 .7803 Mdot
.016 w
.13613 .7803 m
.13687 .78131 L
s
1 .3 0 r
.008 w
.13687 .78131 Mdot
.016 w
.13687 .78131 m
.13775 .78237 L
s
1 .286 0 r
.008 w
.13775 .78237 Mdot
.016 w
.13775 .78237 m
.13869 .78341 L
s
1 .271 0 r
.008 w
.13869 .78341 Mdot
.016 w
.13869 .78341 m
.13972 .78447 L
s
1 .257 0 r
.008 w
.13972 .78447 Mdot
.016 w
.13972 .78447 m
.14082 .78555 L
s
1 .243 0 r
.008 w
.14082 .78555 Mdot
.016 w
.14082 .78555 m
.14197 .78665 L
s
1 .229 0 r
.008 w
.14197 .78665 Mdot
.016 w
.14197 .78665 m
.14319 .78777 L
s
1 .214 0 r
.008 w
.14319 .78777 Mdot
.016 w
.14319 .78777 m
.14447 .78894 L
s
1 .2 0 r
.008 w
.14447 .78894 Mdot
.016 w
.14447 .78894 m
.14575 .79011 L
s
1 .186 0 r
.008 w
.14575 .79011 Mdot
.016 w
.14575 .79011 m
.14707 .79134 L
s
1 .171 0 r
.008 w
.14707 .79134 Mdot
.016 w
.14707 .79134 m
.14856 .79273 L
s
1 .157 0 r
.008 w
.14856 .79273 Mdot
.016 w
.14856 .79273 m
.14979 .79393 L
s
1 .143 0 r
.008 w
.14979 .79393 Mdot
.016 w
.14979 .79393 m
.15118 .79531 L
s
1 .129 0 r
.008 w
.15118 .79531 Mdot
.016 w
.15118 .79531 m
.15249 .79666 L
s
1 .114 0 r
.008 w
.15249 .79666 Mdot
.016 w
.15249 .79666 m
.15373 .79801 L
s
1 .1 0 r
.008 w
.15373 .79801 Mdot
.016 w
.15373 .79801 m
.15482 .79928 L
s
1 .086 0 r
.008 w
.15482 .79928 Mdot
.016 w
.15482 .79928 m
.15568 .80039 L
s
1 .071 0 r
.008 w
.15568 .80039 Mdot
.016 w
.15568 .80039 m
.15633 .8013 L
s
1 .057 0 r
.008 w
.15633 .8013 Mdot
.016 w
.15633 .8013 m
.15679 .80201 L
s
1 .043 0 r
.008 w
.15679 .80201 Mdot
.016 w
.15679 .80201 m
.15705 .80251 L
s
1 .029 0 r
.008 w
.15705 .80251 Mdot
.016 w
.15705 .80251 m
.15713 .80282 L
s
1 .014 0 r
.008 w
.15713 .80282 Mdot
.016 w
.15713 .80282 m
.15705 .80297 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(64)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
1 .994 0 r
.008 w
.15535 .80208 Mdot
.016 w
.15535 .80208 m
.15559 .80237 L
s
1 .988 0 r
.008 w
.15559 .80237 Mdot
.016 w
.15559 .80237 m
.1561 .80288 L
s
1 .982 0 r
.008 w
.1561 .80288 Mdot
.016 w
.1561 .80288 m
.15691 .8037 L
s
1 .976 0 r
.008 w
.15691 .8037 Mdot
.016 w
.15691 .8037 m
.15798 .80479 L
s
1 .97 0 r
.008 w
.15798 .80479 Mdot
.016 w
.15798 .80479 m
.15938 .80618 L
s
1 .964 0 r
.008 w
.15938 .80618 Mdot
.016 w
.15938 .80618 m
.16112 .80789 L
s
1 .959 0 r
.008 w
.16112 .80789 Mdot
.016 w
.16112 .80789 m
.16317 .8099 L
s
1 .953 0 r
.008 w
.16317 .8099 Mdot
.016 w
.16317 .8099 m
.16546 .81195 L
s
1 .947 0 r
.008 w
.16546 .81195 Mdot
.016 w
.16546 .81195 m
.16797 .81423 L
s
1 .941 0 r
.008 w
.16797 .81423 Mdot
.016 w
.16797 .81423 m
.17076 .81691 L
s
1 .935 0 r
.008 w
.17076 .81691 Mdot
.016 w
.17076 .81691 m
.1735 .81942 L
s
1 .929 0 r
.008 w
.1735 .81942 Mdot
.016 w
.1735 .81942 m
.17641 .82212 L
s
1 .923 0 r
.008 w
.17641 .82212 Mdot
.016 w
.17641 .82212 m
.17935 .82489 L
s
1 .917 0 r
.008 w
.17935 .82489 Mdot
.016 w
.17935 .82489 m
.18233 .82766 L
s
1 .911 0 r
.008 w
.18233 .82766 Mdot
.016 w
.18233 .82766 m
.18523 .83049 L
s
1 .905 0 r
.008 w
.18523 .83049 Mdot
.016 w
.18523 .83049 m
.18817 .83326 L
s
1 .899 0 r
.008 w
.18817 .83326 Mdot
.016 w
.18817 .83326 m
.19115 .83613 L
s
1 .893 0 r
.008 w
.19115 .83613 Mdot
.016 w
.19115 .83613 m
.1942 .83905 L
s
1 .888 0 r
.008 w
.1942 .83905 Mdot
.016 w
.1942 .83905 m
.19732 .84209 L
s
1 .882 0 r
.008 w
.19732 .84209 Mdot
.016 w
.19732 .84209 m
.2006 .8455 L
s
1 .876 0 r
.008 w
.2006 .8455 Mdot
.016 w
.2006 .8455 m
.20366 .84842 L
s
1 .87 0 r
.008 w
.20366 .84842 Mdot
.016 w
.20366 .84842 m
.20695 .85184 L
s
1 .864 0 r
.008 w
.20695 .85184 Mdot
.016 w
.20695 .85184 m
.21033 .85531 L
s
1 .858 0 r
.008 w
.21033 .85531 Mdot
.016 w
.21033 .85531 m
.21368 .85865 L
s
1 .852 0 r
.008 w
.21368 .85865 Mdot
.016 w
.21368 .85865 m
.21698 .86199 L
s
1 .846 0 r
.008 w
.21698 .86199 Mdot
.016 w
.21698 .86199 m
.22024 .86528 L
s
1 .84 0 r
.008 w
.22024 .86528 Mdot
.016 w
.22024 .86528 m
.22326 .86835 L
s
1 .834 0 r
.008 w
.22326 .86835 Mdot
.016 w
.22326 .86835 m
.22615 .87123 L
s
1 .828 0 r
.008 w
.22615 .87123 Mdot
.016 w
.22615 .87123 m
.22874 .8738 L
s
1 .822 0 r
.008 w
.22874 .8738 Mdot
.016 w
.22874 .8738 m
.23109 .87611 L
s
1 .817 0 r
.008 w
.23109 .87611 Mdot
.016 w
.23109 .87611 m
.23311 .87794 L
s
1 .811 0 r
.008 w
.23311 .87794 Mdot
.016 w
.23311 .87794 m
.23483 .87942 L
s
1 .805 0 r
.008 w
.23483 .87942 Mdot
.016 w
.23483 .87942 m
.23622 .88052 L
s
1 .799 0 r
.008 w
.23622 .88052 Mdot
.016 w
.23622 .88052 m
.23741 .88127 L
s
1 .793 0 r
.008 w
.23741 .88127 Mdot
.016 w
.23741 .88127 m
.23818 .8817 L
s
1 .787 0 r
.008 w
.23818 .8817 Mdot
.016 w
.23818 .8817 m
.23881 .88195 L
s
1 .781 0 r
.008 w
.23881 .88195 Mdot
.016 w
.23881 .88195 m
.23924 .88203 L
s
1 .775 0 r
.008 w
.23924 .88203 Mdot
.016 w
.23924 .88203 m
.23948 .88201 L
s
1 .769 0 r
.008 w
.23948 .88201 Mdot
.016 w
.23948 .88201 m
.23964 .88195 L
s
1 .763 0 r
.008 w
.23964 .88195 Mdot
.016 w
.23964 .88195 m
.2397 .88185 L
s
1 .757 0 r
.008 w
.2397 .88185 Mdot
.016 w
.2397 .88185 m
.23973 .88177 L
s
1 .751 0 r
.008 w
.23973 .88177 Mdot
.016 w
.23973 .88177 m
.23976 .88173 L
s
1 .746 0 r
.008 w
.23976 .88173 Mdot
.016 w
.23976 .88173 m
.23986 .88184 L
s
1 .74 0 r
.008 w
.23986 .88184 Mdot
.016 w
.23986 .88184 m
.24003 .88206 L
s
1 .734 0 r
.008 w
.24003 .88206 Mdot
.016 w
.24003 .88206 m
.24032 .88242 L
s
1 .728 0 r
.008 w
.24032 .88242 Mdot
.016 w
.24032 .88242 m
.24076 .88292 L
s
1 .722 0 r
.008 w
.24076 .88292 Mdot
.016 w
.24076 .88292 m
.24137 .88358 L
s
1 .716 0 r
.008 w
.24137 .88358 Mdot
.016 w
.24137 .88358 m
.24214 .88434 L
s
1 .71 0 r
.008 w
.24214 .88434 Mdot
.016 w
.24214 .88434 m
.24306 .88512 L
s
1 .704 0 r
.008 w
.24306 .88512 Mdot
.016 w
.24306 .88512 m
.2441 .88589 L
s
1 .698 0 r
.008 w
.2441 .88589 Mdot
.016 w
.2441 .88589 m
.24535 .88666 L
s
1 .692 0 r
.008 w
.24535 .88666 Mdot
.016 w
.24535 .88666 m
.24673 .88743 L
s
1 .686 0 r
.008 w
.24673 .88743 Mdot
.016 w
.24673 .88743 m
.24825 .88822 L
s
1 .68 0 r
.008 w
.24825 .88822 Mdot
.016 w
.24825 .88822 m
.24985 .889 L
s
1 .675 0 r
.008 w
.24985 .889 Mdot
.016 w
.24985 .889 m
.25144 .88978 L
s
1 .669 0 r
.008 w
.25144 .88978 Mdot
.016 w
.25144 .88978 m
.253 .89052 L
s
1 .663 0 r
.008 w
.253 .89052 Mdot
.016 w
.253 .89052 m
.2544 .89115 L
s
1 .657 0 r
.008 w
.2544 .89115 Mdot
.016 w
.2544 .89115 m
.25558 .89159 L
s
1 .651 0 r
.008 w
.25558 .89159 Mdot
.016 w
.25558 .89159 m
.25653 .89189 L
s
1 .645 0 r
.008 w
.25653 .89189 Mdot
.016 w
.25653 .89189 m
.25729 .89213 L
s
1 .639 0 r
.008 w
.25729 .89213 Mdot
.016 w
.25729 .89213 m
.25788 .89231 L
s
1 .633 0 r
.008 w
.25788 .89231 Mdot
.016 w
.25788 .89231 m
.2583 .89241 L
s
1 .627 0 r
.008 w
.2583 .89241 Mdot
.016 w
.2583 .89241 m
.25859 .89245 L
s
1 .621 0 r
.008 w
.25859 .89245 Mdot
.016 w
.25859 .89245 m
.25875 .89244 L
s
1 .615 0 r
.008 w
.25875 .89244 Mdot
.016 w
.25875 .89244 m
.25876 .89241 L
s
1 .609 0 r
.008 w
.25876 .89241 Mdot
.016 w
.25876 .89241 m
.25865 .8924 L
s
1 .604 0 r
.008 w
.25865 .8924 Mdot
.016 w
.25865 .8924 m
.25844 .89238 L
s
1 .598 0 r
.008 w
.25844 .89238 Mdot
.016 w
.25844 .89238 m
.25816 .89235 L
s
1 .592 0 r
.008 w
.25816 .89235 Mdot
.016 w
.25816 .89235 m
.25783 .8923 L
s
1 .586 0 r
.008 w
.25783 .8923 Mdot
.016 w
.25783 .8923 m
.25752 .89229 L
s
1 .58 0 r
.008 w
.25752 .89229 Mdot
.016 w
.25752 .89229 m
.25724 .89229 L
s
1 .574 0 r
.008 w
.25724 .89229 Mdot
.016 w
.25724 .89229 m
.25698 .89239 L
s
1 .568 0 r
.008 w
.25698 .89239 Mdot
.016 w
.25698 .89239 m
.25673 .89254 L
s
1 .562 0 r
.008 w
.25673 .89254 Mdot
.016 w
.25673 .89254 m
.25647 .89276 L
s
1 .556 0 r
.008 w
.25647 .89276 Mdot
.016 w
.25647 .89276 m
.25632 .89299 L
s
1 .55 0 r
.008 w
.25632 .89299 Mdot
.016 w
.25632 .89299 m
.25611 .89316 L
s
1 .544 0 r
.008 w
.25611 .89316 Mdot
.016 w
.25611 .89316 m
.25593 .89339 L
s
1 .538 0 r
.008 w
.25593 .89339 Mdot
.016 w
.25593 .89339 m
.25584 .89368 L
s
1 .533 0 r
.008 w
.25584 .89368 Mdot
.016 w
.25584 .89368 m
.25595 .89412 L
s
1 .527 0 r
.008 w
.25595 .89412 Mdot
.016 w
.25595 .89412 m
.25625 .89465 L
s
1 .521 0 r
.008 w
.25625 .89465 Mdot
.016 w
.25625 .89465 m
.25683 .89536 L
s
1 .515 0 r
.008 w
.25683 .89536 Mdot
.016 w
.25683 .89536 m
.25772 .89622 L
s
1 .509 0 r
.008 w
.25772 .89622 Mdot
.016 w
.25772 .89622 m
.2589 .8972 L
s
1 .503 0 r
.008 w
.2589 .8972 Mdot
.016 w
.2589 .8972 m
.26037 .89823 L
s
1 .497 0 r
.008 w
.26037 .89823 Mdot
.016 w
.26037 .89823 m
.26206 .89926 L
s
1 .491 0 r
.008 w
.26206 .89926 Mdot
.016 w
.26206 .89926 m
.26402 .90037 L
s
1 .485 0 r
.008 w
.26402 .90037 Mdot
.016 w
.26402 .90037 m
.26621 .90153 L
s
1 .479 0 r
.008 w
.26621 .90153 Mdot
.016 w
.26621 .90153 m
.26868 .90279 L
s
1 .473 0 r
.008 w
.26868 .90279 Mdot
.016 w
.26868 .90279 m
.27126 .90412 L
s
1 .467 0 r
.008 w
.27126 .90412 Mdot
.016 w
.27126 .90412 m
.27389 .90543 L
s
1 .462 0 r
.008 w
.27389 .90543 Mdot
.016 w
.27389 .90543 m
.27665 .90673 L
s
1 .456 0 r
.008 w
.27665 .90673 Mdot
.016 w
.27665 .90673 m
.27935 .90801 L
s
1 .45 0 r
.008 w
.27935 .90801 Mdot
.016 w
.27935 .90801 m
.28222 .90923 L
s
1 .444 0 r
.008 w
.28222 .90923 Mdot
.016 w
.28222 .90923 m
.28483 .91044 L
s
1 .438 0 r
.008 w
.28483 .91044 Mdot
.016 w
.28483 .91044 m
.28751 .91162 L
s
1 .432 0 r
.008 w
.28751 .91162 Mdot
.016 w
.28751 .91162 m
.29018 .91275 L
s
1 .426 0 r
.008 w
.29018 .91275 Mdot
.016 w
.29018 .91275 m
.29281 .91387 L
s
1 .42 0 r
.008 w
.29281 .91387 Mdot
.016 w
.29281 .91387 m
.29543 .91495 L
s
1 .414 0 r
.008 w
.29543 .91495 Mdot
.016 w
.29543 .91495 m
.29807 .916 L
s
1 .408 0 r
.008 w
.29807 .916 Mdot
.016 w
.29807 .916 m
.30077 .91701 L
s
1 .402 0 r
.008 w
.30077 .91701 Mdot
.016 w
.30077 .91701 m
.30358 .91798 L
s
1 .396 0 r
.008 w
.30358 .91798 Mdot
.016 w
.30358 .91798 m
.30657 .91892 L
s
1 .391 0 r
.008 w
.30657 .91892 Mdot
.016 w
.30657 .91892 m
.3096 .91985 L
s
1 .385 0 r
.008 w
.3096 .91985 Mdot
.016 w
.3096 .91985 m
.31282 .92077 L
s
1 .379 0 r
.008 w
.31282 .92077 Mdot
.016 w
.31282 .92077 m
.31626 .9217 L
s
1 .373 0 r
.008 w
.31626 .9217 Mdot
.016 w
.31626 .9217 m
.31951 .92265 L
s
1 .367 0 r
.008 w
.31951 .92265 Mdot
.016 w
.31951 .92265 m
.32283 .92362 L
s
1 .361 0 r
.008 w
.32283 .92362 Mdot
.016 w
.32283 .92362 m
.3262 .92461 L
s
1 .355 0 r
.008 w
.3262 .92461 Mdot
.016 w
.3262 .92461 m
.32964 .92558 L
s
1 .349 0 r
.008 w
.32964 .92558 Mdot
.016 w
.32964 .92558 m
.3327 .92657 L
s
1 .343 0 r
.008 w
.3327 .92657 Mdot
.016 w
.3327 .92657 m
.33573 .92753 L
s
1 .337 0 r
.008 w
.33573 .92753 Mdot
.016 w
.33573 .92753 m
.33854 .92842 L
s
1 .331 0 r
.008 w
.33854 .92842 Mdot
.016 w
.33854 .92842 m
.34106 .92922 L
s
1 .325 0 r
.008 w
.34106 .92922 Mdot
.016 w
.34106 .92922 m
.3433 .92995 L
s
1 .32 0 r
.008 w
.3433 .92995 Mdot
.016 w
.3433 .92995 m
.34524 .9306 L
s
1 .314 0 r
.008 w
.34524 .9306 Mdot
.016 w
.34524 .9306 m
.34683 .93116 L
s
1 .308 0 r
.008 w
.34683 .93116 Mdot
.016 w
.34683 .93116 m
.34824 .93164 L
s
1 .302 0 r
.008 w
.34824 .93164 Mdot
.016 w
.34824 .93164 m
.34944 .93205 L
s
1 .296 0 r
.008 w
.34944 .93205 Mdot
.016 w
.34944 .93205 m
.35061 .93243 L
s
1 .29 0 r
.008 w
.35061 .93243 Mdot
.016 w
.35061 .93243 m
.35179 .93281 L
s
1 .284 0 r
.008 w
.35179 .93281 Mdot
.016 w
.35179 .93281 m
.35304 .93321 L
s
1 .278 0 r
.008 w
.35304 .93321 Mdot
.016 w
.35304 .93321 m
.35441 .93369 L
s
1 .272 0 r
.008 w
.35441 .93369 Mdot
.016 w
.35441 .93369 m
.35591 .93427 L
s
1 .266 0 r
.008 w
.35591 .93427 Mdot
.016 w
.35591 .93427 m
.35762 .93491 L
s
1 .26 0 r
.008 w
.35762 .93491 Mdot
.016 w
.35762 .93491 m
.35961 .93565 L
s
1 .254 0 r
.008 w
.35961 .93565 Mdot
.016 w
.35961 .93565 m
.36176 .9365 L
s
1 .249 0 r
.008 w
.36176 .9365 Mdot
.016 w
.36176 .9365 m
.36423 .93746 L
s
1 .243 0 r
.008 w
.36423 .93746 Mdot
.016 w
.36423 .93746 m
.36704 .93848 L
s
1 .237 0 r
.008 w
.36704 .93848 Mdot
.016 w
.36704 .93848 m
.37006 .93952 L
s
1 .231 0 r
.008 w
.37006 .93952 Mdot
.016 w
.37006 .93952 m
.37344 .94062 L
s
1 .225 0 r
.008 w
.37344 .94062 Mdot
.016 w
.37344 .94062 m
.37676 .94172 L
s
1 .219 0 r
.008 w
.37676 .94172 Mdot
.016 w
.37676 .94172 m
.38041 .94286 L
s
1 .213 0 r
.008 w
.38041 .94286 Mdot
.016 w
.38041 .94286 m
.38387 .94408 L
s
1 .207 0 r
.008 w
.38387 .94408 Mdot
.016 w
.38387 .94408 m
.38739 .94528 L
s
1 .201 0 r
.008 w
.38739 .94528 Mdot
.016 w
.38739 .94528 m
.39106 .94659 L
s
1 .195 0 r
.008 w
.39106 .94659 Mdot
.016 w
.39106 .94659 m
.39465 .94799 L
s
1 .189 0 r
.008 w
.39465 .94799 Mdot
.016 w
.39465 .94799 m
.39834 .94931 L
s
1 .183 0 r
.008 w
.39834 .94931 Mdot
.016 w
.39834 .94931 m
.4021 .95072 L
s
1 .178 0 r
.008 w
.4021 .95072 Mdot
.016 w
.4021 .95072 m
.40596 .9521 L
s
1 .172 0 r
.008 w
.40596 .9521 Mdot
.016 w
.40596 .9521 m
.40979 .95358 L
s
1 .166 0 r
.008 w
.40979 .95358 Mdot
.016 w
.40979 .95358 m
.41368 .95498 L
s
1 .16 0 r
.008 w
.41368 .95498 Mdot
.016 w
.41368 .95498 m
.41775 .95658 L
s
1 .154 0 r
.008 w
.41775 .95658 Mdot
.016 w
.41775 .95658 m
.42171 .95798 L
s
1 .148 0 r
.008 w
.42171 .95798 Mdot
.016 w
.42171 .95798 m
.42588 .9594 L
s
1 .142 0 r
.008 w
.42588 .9594 Mdot
.016 w
.42588 .9594 m
.42994 .96081 L
s
1 .136 0 r
.008 w
.42994 .96081 Mdot
.016 w
.42994 .96081 m
.4341 .96215 L
s
1 .13 0 r
.008 w
.4341 .96215 Mdot
.016 w
.4341 .96215 m
.43809 .96336 L
s
1 .124 0 r
.008 w
.43809 .96336 Mdot
.016 w
.43809 .96336 m
.44216 .9644 L
s
1 .118 0 r
.008 w
.44216 .9644 Mdot
.016 w
.44216 .9644 m
.44593 .96523 L
s
1 .112 0 r
.008 w
.44593 .96523 Mdot
.016 w
.44593 .96523 m
.44962 .96592 L
s
1 .107 0 r
.008 w
.44962 .96592 Mdot
.016 w
.44962 .96592 m
.45306 .96654 L
s
1 .101 0 r
.008 w
.45306 .96654 Mdot
.016 w
.45306 .96654 m
.45626 .96707 L
s
1 .095 0 r
.008 w
.45626 .96707 Mdot
.016 w
.45626 .96707 m
.45936 .96751 L
s
1 .089 0 r
.008 w
.45936 .96751 Mdot
.016 w
.45936 .96751 m
.46194 .96784 L
s
1 .083 0 r
.008 w
.46194 .96784 Mdot
.016 w
.46194 .96784 m
.46436 .96805 L
s
1 .077 0 r
.008 w
.46436 .96805 Mdot
.016 w
.46436 .96805 m
.46651 .96813 L
s
1 .071 0 r
.008 w
.46651 .96813 Mdot
.016 w
.46651 .96813 m
.46843 .96809 L
s
1 .065 0 r
.008 w
.46843 .96809 Mdot
.016 w
.46843 .96809 m
.47003 .96796 L
s
1 .059 0 r
.008 w
.47003 .96796 Mdot
.016 w
.47003 .96796 m
.47148 .96775 L
s
1 .053 0 r
.008 w
.47148 .96775 Mdot
.016 w
.47148 .96775 m
.47252 .96754 L
s
1 .047 0 r
.008 w
.47252 .96754 Mdot
.016 w
.47252 .96754 m
.47339 .96736 L
s
1 .041 0 r
.008 w
.47339 .96736 Mdot
.016 w
.47339 .96736 m
.47407 .96725 L
s
1 .036 0 r
.008 w
.47407 .96725 Mdot
.016 w
.47407 .96725 m
.47462 .96716 L
s
1 .03 0 r
.008 w
.47462 .96716 Mdot
.016 w
.47462 .96716 m
.47502 .96706 L
s
1 .024 0 r
.008 w
.47502 .96706 Mdot
.016 w
.47502 .96706 m
.47533 .96694 L
s
1 .018 0 r
.008 w
.47533 .96694 Mdot
.016 w
.47533 .96694 m
.47558 .96681 L
s
1 .012 0 r
.008 w
.47558 .96681 Mdot
.016 w
.47558 .96681 m
.47577 .96668 L
s
1 .006 0 r
.008 w
.47577 .96668 Mdot
.016 w
.47577 .96668 m
.47587 .96656 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(65)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
1 .99 0 r
.008 w
.47195 .96642 Mdot
.016 w
.47195 .96642 m
.47207 .96647 L
s
1 .981 0 r
.008 w
.47207 .96647 Mdot
.016 w
.47207 .96647 m
.47225 .96653 L
s
1 .971 0 r
.008 w
.47225 .96653 Mdot
.016 w
.47225 .96653 m
.47249 .96658 L
s
1 .961 0 r
.008 w
.47249 .96658 Mdot
.016 w
.47249 .96658 m
.47282 .96662 L
s
1 .951 0 r
.008 w
.47282 .96662 Mdot
.016 w
.47282 .96662 m
.4732 .96665 L
s
1 .942 0 r
.008 w
.4732 .96665 Mdot
.016 w
.4732 .96665 m
.47357 .96668 L
s
1 .932 0 r
.008 w
.47357 .96668 Mdot
.016 w
.47357 .96668 m
.47387 .96671 L
s
1 .922 0 r
.008 w
.47387 .96671 Mdot
.016 w
.47387 .96671 m
.47418 .96674 L
s
1 .913 0 r
.008 w
.47418 .96674 Mdot
.016 w
.47418 .96674 m
.47445 .96678 L
s
1 .903 0 r
.008 w
.47445 .96678 Mdot
.016 w
.47445 .96678 m
.47466 .96684 L
s
1 .893 0 r
.008 w
.47466 .96684 Mdot
.016 w
.47466 .96684 m
.47484 .96691 L
s
1 .883 0 r
.008 w
.47484 .96691 Mdot
.016 w
.47484 .96691 m
.47505 .96699 L
s
1 .874 0 r
.008 w
.47505 .96699 Mdot
.016 w
.47505 .96699 m
.47528 .96708 L
s
1 .864 0 r
.008 w
.47528 .96708 Mdot
.016 w
.47528 .96708 m
.47556 .96718 L
s
1 .854 0 r
.008 w
.47556 .96718 Mdot
.016 w
.47556 .96718 m
.47589 .96726 L
s
1 .845 0 r
.008 w
.47589 .96726 Mdot
.016 w
.47589 .96726 m
.47632 .96729 L
s
1 .835 0 r
.008 w
.47632 .96729 Mdot
.016 w
.47632 .96729 m
.47686 .9673 L
s
1 .825 0 r
.008 w
.47686 .9673 Mdot
.016 w
.47686 .9673 m
.47753 .96728 L
s
1 .816 0 r
.008 w
.47753 .96728 Mdot
.016 w
.47753 .96728 m
.47833 .96722 L
s
1 .806 0 r
.008 w
.47833 .96722 Mdot
.016 w
.47833 .96722 m
.47933 .96712 L
s
1 .796 0 r
.008 w
.47933 .96712 Mdot
.016 w
.47933 .96712 m
.48051 .96696 L
s
1 .786 0 r
.008 w
.48051 .96696 Mdot
.016 w
.48051 .96696 m
.48186 .96674 L
s
1 .777 0 r
.008 w
.48186 .96674 Mdot
.016 w
.48186 .96674 m
.48336 .96647 L
s
1 .767 0 r
.008 w
.48336 .96647 Mdot
.016 w
.48336 .96647 m
.48492 .96619 L
s
1 .757 0 r
.008 w
.48492 .96619 Mdot
.016 w
.48492 .96619 m
.48659 .9659 L
s
1 .748 0 r
.008 w
.48659 .9659 Mdot
.016 w
.48659 .9659 m
.48836 .96562 L
s
1 .738 0 r
.008 w
.48836 .96562 Mdot
.016 w
.48836 .96562 m
.49029 .96537 L
s
1 .728 0 r
.008 w
.49029 .96537 Mdot
.016 w
.49029 .96537 m
.4923 .96514 L
s
1 .718 0 r
.008 w
.4923 .96514 Mdot
.016 w
.4923 .96514 m
.49462 .96494 L
s
1 .709 0 r
.008 w
.49462 .96494 Mdot
.016 w
.49462 .96494 m
.49666 .96476 L
s
1 .699 0 r
.008 w
.49666 .96476 Mdot
.016 w
.49666 .96476 m
.49906 .96458 L
s
1 .689 0 r
.008 w
.49906 .96458 Mdot
.016 w
.49906 .96458 m
.50152 .96437 L
s
1 .68 0 r
.008 w
.50152 .96437 Mdot
.016 w
.50152 .96437 m
.5042 .96414 L
s
1 .67 0 r
.008 w
.5042 .96414 Mdot
.016 w
.5042 .96414 m
.50704 .96387 L
s
1 .66 0 r
.008 w
.50704 .96387 Mdot
.016 w
.50704 .96387 m
.51014 .96356 L
s
1 .65 0 r
.008 w
.51014 .96356 Mdot
.016 w
.51014 .96356 m
.51325 .96321 L
s
1 .641 0 r
.008 w
.51325 .96321 Mdot
.016 w
.51325 .96321 m
.51633 .96281 L
s
1 .631 0 r
.008 w
.51633 .96281 Mdot
.016 w
.51633 .96281 m
.51937 .96239 L
s
1 .621 0 r
.008 w
.51937 .96239 Mdot
.016 w
.51937 .96239 m
.52254 .96197 L
s
1 .612 0 r
.008 w
.52254 .96197 Mdot
.016 w
.52254 .96197 m
.52553 .96153 L
s
1 .602 0 r
.008 w
.52553 .96153 Mdot
.016 w
.52553 .96153 m
.52849 .96108 L
s
1 .592 0 r
.008 w
.52849 .96108 Mdot
.016 w
.52849 .96108 m
.53145 .96065 L
s
1 .583 0 r
.008 w
.53145 .96065 Mdot
.016 w
.53145 .96065 m
.53408 .96026 L
s
1 .573 0 r
.008 w
.53408 .96026 Mdot
.016 w
.53408 .96026 m
.53675 .95988 L
s
1 .563 0 r
.008 w
.53675 .95988 Mdot
.016 w
.53675 .95988 m
.53936 .95954 L
s
1 .553 0 r
.008 w
.53936 .95954 Mdot
.016 w
.53936 .95954 m
.54193 .9592 L
s
1 .544 0 r
.008 w
.54193 .9592 Mdot
.016 w
.54193 .9592 m
.54446 .95881 L
s
1 .534 0 r
.008 w
.54446 .95881 Mdot
.016 w
.54446 .95881 m
.54697 .95833 L
s
1 .524 0 r
.008 w
.54697 .95833 Mdot
.016 w
.54697 .95833 m
.54942 .95771 L
s
1 .515 0 r
.008 w
.54942 .95771 Mdot
.016 w
.54942 .95771 m
.55186 .95699 L
s
1 .505 0 r
.008 w
.55186 .95699 Mdot
.016 w
.55186 .95699 m
.5542 .95616 L
s
1 .495 0 r
.008 w
.5542 .95616 Mdot
.016 w
.5542 .95616 m
.55642 .95535 L
s
1 .485 0 r
.008 w
.55642 .95535 Mdot
.016 w
.55642 .95535 m
.55861 .95452 L
s
1 .476 0 r
.008 w
.55861 .95452 Mdot
.016 w
.55861 .95452 m
.56061 .95377 L
s
1 .466 0 r
.008 w
.56061 .95377 Mdot
.016 w
.56061 .95377 m
.56253 .95318 L
s
1 .456 0 r
.008 w
.56253 .95318 Mdot
.016 w
.56253 .95318 m
.56431 .95266 L
s
1 .447 0 r
.008 w
.56431 .95266 Mdot
.016 w
.56431 .95266 m
.56578 .95223 L
s
1 .437 0 r
.008 w
.56578 .95223 Mdot
.016 w
.56578 .95223 m
.56703 .95191 L
s
1 .427 0 r
.008 w
.56703 .95191 Mdot
.016 w
.56703 .95191 m
.5681 .9517 L
s
1 .417 0 r
.008 w
.5681 .9517 Mdot
.016 w
.5681 .9517 m
.56904 .95162 L
s
1 .408 0 r
.008 w
.56904 .95162 Mdot
.016 w
.56904 .95162 m
.56995 .95172 L
s
1 .398 0 r
.008 w
.56995 .95172 Mdot
.016 w
.56995 .95172 m
.57096 .95196 L
s
1 .388 0 r
.008 w
.57096 .95196 Mdot
.016 w
.57096 .95196 m
.57224 .95231 L
s
1 .379 0 r
.008 w
.57224 .95231 Mdot
.016 w
.57224 .95231 m
.57357 .95271 L
s
1 .369 0 r
.008 w
.57357 .95271 Mdot
.016 w
.57357 .95271 m
.5753 .95306 L
s
1 .359 0 r
.008 w
.5753 .95306 Mdot
.016 w
.5753 .95306 m
.5773 .95334 L
s
1 .35 0 r
.008 w
.5773 .95334 Mdot
.016 w
.5773 .95334 m
.57958 .95346 L
s
1 .34 0 r
.008 w
.57958 .95346 Mdot
.016 w
.57958 .95346 m
.58223 .9534 L
s
1 .33 0 r
.008 w
.58223 .9534 Mdot
.016 w
.58223 .9534 m
.58508 .95318 L
s
1 .32 0 r
.008 w
.58508 .95318 Mdot
.016 w
.58508 .95318 m
.5882 .95288 L
s
1 .311 0 r
.008 w
.5882 .95288 Mdot
.016 w
.5882 .95288 m
.59162 .95243 L
s
1 .301 0 r
.008 w
.59162 .95243 Mdot
.016 w
.59162 .95243 m
.59497 .95189 L
s
1 .291 0 r
.008 w
.59497 .95189 Mdot
.016 w
.59497 .95189 m
.5989 .9515 L
s
1 .282 0 r
.008 w
.5989 .9515 Mdot
.016 w
.5989 .9515 m
.60247 .9509 L
s
1 .272 0 r
.008 w
.60247 .9509 Mdot
.016 w
.60247 .9509 m
.60608 .95027 L
s
1 .262 0 r
.008 w
.60608 .95027 Mdot
.016 w
.60608 .95027 m
.60962 .94961 L
s
1 .252 0 r
.008 w
.60962 .94961 Mdot
.016 w
.60962 .94961 m
.61297 .94889 L
s
1 .243 0 r
.008 w
.61297 .94889 Mdot
.016 w
.61297 .94889 m
.6162 .94817 L
s
1 .233 0 r
.008 w
.6162 .94817 Mdot
.016 w
.6162 .94817 m
.61933 .94737 L
s
1 .223 0 r
.008 w
.61933 .94737 Mdot
.016 w
.61933 .94737 m
.62235 .9465 L
s
1 .214 0 r
.008 w
.62235 .9465 Mdot
.016 w
.62235 .9465 m
.62532 .94563 L
s
1 .204 0 r
.008 w
.62532 .94563 Mdot
.016 w
.62532 .94563 m
.62823 .94477 L
s
1 .194 0 r
.008 w
.62823 .94477 Mdot
.016 w
.62823 .94477 m
.63098 .94396 L
s
1 .184 0 r
.008 w
.63098 .94396 Mdot
.016 w
.63098 .94396 m
.63357 .94317 L
s
1 .175 0 r
.008 w
.63357 .94317 Mdot
.016 w
.63357 .94317 m
.63594 .94249 L
s
1 .165 0 r
.008 w
.63594 .94249 Mdot
.016 w
.63594 .94249 m
.63806 .9418 L
s
1 .155 0 r
.008 w
.63806 .9418 Mdot
.016 w
.63806 .9418 m
.63995 .94114 L
s
1 .146 0 r
.008 w
.63995 .94114 Mdot
.016 w
.63995 .94114 m
.64159 .94054 L
s
1 .136 0 r
.008 w
.64159 .94054 Mdot
.016 w
.64159 .94054 m
.64309 .94005 L
s
1 .126 0 r
.008 w
.64309 .94005 Mdot
.016 w
.64309 .94005 m
.64445 .93964 L
s
1 .117 0 r
.008 w
.64445 .93964 Mdot
.016 w
.64445 .93964 m
.64572 .93927 L
s
1 .107 0 r
.008 w
.64572 .93927 Mdot
.016 w
.64572 .93927 m
.64691 .9389 L
s
1 .097 0 r
.008 w
.64691 .9389 Mdot
.016 w
.64691 .9389 m
.64802 .93854 L
s
1 .087 0 r
.008 w
.64802 .93854 Mdot
.016 w
.64802 .93854 m
.64901 .93828 L
s
1 .078 0 r
.008 w
.64901 .93828 Mdot
.016 w
.64901 .93828 m
.64981 .93814 L
s
1 .068 0 r
.008 w
.64981 .93814 Mdot
.016 w
.64981 .93814 m
.65052 .93802 L
s
1 .058 0 r
.008 w
.65052 .93802 Mdot
.016 w
.65052 .93802 m
.65112 .93797 L
s
1 .049 0 r
.008 w
.65112 .93797 Mdot
.016 w
.65112 .93797 m
.65163 .93793 L
s
1 .039 0 r
.008 w
.65163 .93793 Mdot
.016 w
.65163 .93793 m
.6521 .93782 L
s
1 .029 0 r
.008 w
.6521 .93782 Mdot
.016 w
.6521 .93782 m
.65252 .93767 L
s
1 .019 0 r
.008 w
.65252 .93767 Mdot
.016 w
.65252 .93767 m
.65286 .93753 L
s
1 .01 0 r
.008 w
.65286 .93753 Mdot
.016 w
.65286 .93753 m
.65303 .93745 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Ao
o`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0Woo1Sg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo
01Moo`006Goo00@007ooOomoo`Lmkn5oo`03001oogoo01Qoo`006Woo00<007ooOol01cg_hGoo00<0
07ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoO
Ool00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol0
1Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001o
ocg_00@mkmeoo`03001oogoo01aoo`007Goo00<007oo?Nl013g_gGoo00<007ooOol077oo000NOol0
0`00?Nlmk`04?NoKOol00`00Oomoo`0MOol001ioo`03000mkcg_00@mkm]oo`03001oogoo01eoo`00
7goo1cg_fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03
000mkcg_00DmkmIoo`03001oogoo01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000Q
Ool00`00?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025o
o`008goo23g_d7oo00<007ooOol08Woo000TOol9?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_
00Lmklaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00
?Nlmk`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo
00<007oo?Nl02Sg_`goo00<007ooOol09Woo000XOol00`00Oolmk`09?No2Ool00`00Oomoo`0WOol0
02Uoo`03001oocg_00Tmkl1oo`03001oogoo02Qoo`00:Woo00<007oo?Nl023g__goo00<007ooOol0
:Goo000ZOol00`00Oomoo`09?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo00Pmkkeoo`03001o
ogoo02Yoo`00;7oo00<007oo?Nl023g_^goo00<007ooOol0:goo000]Ool00`00Oolmk`08?NniOol0
0`00Oomoo`0/Ool002ioo`03001oogoo00PmkkMoo`03001oogoo02eoo`00;Woo00@007ooOomoo`Pm
kkIoo`03001oogoo02eoo`00;goo00@007ooOomoo`Tmkk=oo`03001oogoo02ioo`00<7oo00@007oo
Oomoo`Pmkk9oo`03001oogoo02moo`00<Goo00@007ooOomoo`Pmkk1oo`03001oogoo031oo`00<Woo
0P000goo1cg_[Goo0P00<goo000dOol01000Oomoogoo1cg_Zgoo00<007ooOol0<goo000eOol01000
Oomoogoo1cg_ZGoo00<007ooOol0=7oo000eOol01000Oomoogoo23g_Z7oo00<007ooOol0=7oo000f
Ool01000Oomoogoo23g_YWoo00<007ooOol0=Goo000gOol00`00Oomoo`02Ool7?NnTOol00`00Oomo
o`0fOol003Qoo`03001oogoo009oo`Lmkj9oo`03001oogoo03Moo`00>Goo0P000goo23g_WWoo0P00
>Woo000kOol01000Oomoogoo23g_W7oo00<007ooOol0>Woo000lOol00`00Oomoo`09?NnJOol00`00
Oomoo`0kOol003eoo`03001oogoo00XmkiMoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_U7oo0P00
?goo0010Ool00`00Oomoo`09?NnBOol00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkhmoo`80
049oo`00@goo00<007oo?Nl02Cg_S7oo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?Nn;Ool00`00
Oomoo`13Ool004Eoo`03000mkcg_00PmkhUoo`03001oogoo04Aoo`00AWoo0P002Sg_QGoo0P00Agoo
0018Ool2000;?Nl3Ool2?NmkOol20019Ool004Yooa4mkgQoo`8004]oo`00C7oo43g_MGoo0P00CGoo
001>Ool00`00?Nlmk`0<?NmcOol00`00Oomoo`1=Ool004moo`03000mkcg_00hmkfmoo`03001oogoo
04ioo`00D7oo0P000Woo3cg_JWoo0P00DGoo001BOol200000goo?Nlmk`0>?NmVOol2001COol005Ao
o`800003?Nmoocg_00lmk`Qoo`DmkeAoo`8005Eoo`00EWoo0P0017oo43g_0goo1Sg_@Goo0Wb03goo
0P00Egoo001HOol30004OolF?NlnOol2O:0017aPO21l87`00W`P2Goo0`00FGoo001KOol30003OolD
?NlkOol2O>0017bPO81lP7aP0W`P00=l07`PO2001Woo0`00G7oo001NOol20004OolB?NleOol2O@02
Ool2O<02O:02O80017aPO21l87`00W`P0goo0`00Ggoo001POol20006Ool@?NlWOol2ON09Ool2O@03
O>02O<02O:02O8000gaPO21l8003O202Ool00`00Oomoo`1POol0069oo`<000Ioo`lmkb9oo`9n0003
OL1mX7f0009mH09m@0Am80=m00=lh0=l`003O:1lP7b000=lP09oo`<006=oo`00IGoo0`001Woo3cg_
37oo2Cg_17oo0WiP0goo00In07gPON1m`7fPOH02OF02OD04OB03O@03O>04O<0017bPO<1oogoo0`00
IWoo001XOol40005OolK?Nl2O^04?Nl3Ool3OT02OR02OP02ON000gg0OJ1mP002OF02OD05OB02O@06
O>000goo00000002001YOol006aoo`@000=ooaPmk`9n`0=nX09nP0=nH0=n@09n809n009mh003OL1m
X7f0009mH09m@0Im8004O@1m87ooOol4001]Ool0071oo`<000=oo`lmk`04Ol1oH7lPO`02O^02O/03
OZ02OX03OV03OT03OR000gh0ON1mh003ON0:Ool4001aOol007=oo`D00003Oolmkcg_00Xmk`04Ol1o
H7lPO`02O^02O/03OZ02OX03OV03OT04OR000gh0OR1oo`08Ool4001eOol007Qoo`@000Tmk`04Ol1o
H7lPO`02O^02O/03OZ02OX06OV08Ool7001iOol007ioo`Lmk`04Ol1oH7lPO`05O^04Ool>0020Ool0
08eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo0`0017oo0P00
SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00RWoo00@007ooOol000Eoo`03001oogoo
08Yoo`00RWoo0`0017oo0P00SGoo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008]oo`<000=o
o`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(66)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
1 .889 0 r
.008 w
.65255 .93648 Mdot
.016 w
.65255 .93648 m
.65233 .9367 L
s
1 .778 0 r
.008 w
.65233 .9367 Mdot
.016 w
.65233 .9367 m
.65194 .93702 L
s
1 .667 0 r
.008 w
.65194 .93702 Mdot
.016 w
.65194 .93702 m
.65141 .93749 L
s
1 .556 0 r
.008 w
.65141 .93749 Mdot
.016 w
.65141 .93749 m
.65081 .93805 L
s
1 .444 0 r
.008 w
.65081 .93805 Mdot
.016 w
.65081 .93805 m
.65026 .93855 L
s
1 .333 0 r
.008 w
.65026 .93855 Mdot
.016 w
.65026 .93855 m
.64982 .93884 L
s
1 .222 0 r
.008 w
.64982 .93884 Mdot
.016 w
.64982 .93884 m
.64951 .93899 L
s
1 .111 0 r
.008 w
.64951 .93899 Mdot
.016 w
.64951 .93899 m
.64925 .93908 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Ao
o`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0Woo1Sg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo
01Moo`006Goo00@007ooOomoo`Lmkn5oo`03001oogoo01Qoo`006Woo00<007ooOol01cg_hGoo00<0
07ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoO
Ool00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol0
1Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001o
ocg_00@mkmeoo`03001oogoo01aoo`007Goo00<007oo?Nl013g_gGoo00<007ooOol077oo000NOol0
0`00?Nlmk`04?NoKOol00`00Oomoo`0MOol001ioo`03000mkcg_00@mkm]oo`03001oogoo01eoo`00
7goo1cg_fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03
000mkcg_00DmkmIoo`03001oogoo01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000Q
Ool00`00?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025o
o`008goo23g_d7oo00<007ooOol08Woo000TOol9?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_
00Lmklaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00
?Nlmk`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo
00<007oo?Nl02Sg_`goo00<007ooOol09Woo000XOol00`00Oolmk`09?No2Ool00`00Oomoo`0WOol0
02Uoo`03001oocg_00Tmkl1oo`03001oogoo02Qoo`00:Woo00<007oo?Nl023g__goo00<007ooOol0
:Goo000ZOol00`00Oomoo`09?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo00Pmkkeoo`03001o
ogoo02Yoo`00;7oo00<007oo?Nl023g_^goo00<007ooOol0:goo000]Ool00`00Oolmk`08?NniOol0
0`00Oomoo`0/Ool002ioo`03001oogoo00PmkkMoo`03001oogoo02eoo`00;Woo00@007ooOomoo`Pm
kkIoo`03001oogoo02eoo`00;goo00@007ooOomoo`Tmkk=oo`03001oogoo02ioo`00<7oo00@007oo
Oomoo`Pmkk9oo`03001oogoo02moo`00<Goo00@007ooOomoo`Pmkk1oo`03001oogoo031oo`00<Woo
0P000goo1cg_[Goo0P00<goo000dOol01000Oomoogoo1cg_Zgoo00<007ooOol0<goo000eOol01000
Oomoogoo1cg_ZGoo00<007ooOol0=7oo000eOol01000Oomoogoo23g_Z7oo00<007ooOol0=7oo000f
Ool01000Oomoogoo23g_YWoo00<007ooOol0=Goo000gOol00`00Oomoo`02Ool7?NnTOol00`00Oomo
o`0fOol003Qoo`03001oogoo009oo`Lmkj9oo`03001oogoo03Moo`00>Goo0P000goo23g_WWoo0P00
>Woo000kOol01000Oomoogoo23g_W7oo00<007ooOol0>Woo000lOol00`00Oomoo`09?NnJOol00`00
Oomoo`0kOol003eoo`03001oogoo00XmkiMoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_U7oo0P00
?goo0010Ool00`00Oomoo`09?NnBOol00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkhmoo`80
049oo`00@goo00<007oo?Nl02Cg_S7oo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?Nn;Ool00`00
Oomoo`13Ool004Eoo`03000mkcg_00PmkhUoo`03001oogoo04Aoo`00AWoo0P002Sg_QGoo0P00Agoo
0018Ool2000;?Nl3Ool2?NmkOol20019Ool004Yooa4mkgQoo`8004]oo`00C7oo43g_MGoo0P00CGoo
001>Ool00`00?Nlmk`0<?NmcOol00`00Oomoo`1=Ool004moo`03000mkcg_00hmkfmoo`03001oogoo
04ioo`00D7oo0P000Woo3cg_JWoo0P00DGoo001BOol200000goo?Nlmk`0>?NmVOol2001COol005Ao
o`800003?Nmoocg_00lmk`Qoo`DmkeAoo`8005Eoo`00EWoo0P0017oo43g_0goo1Sg_DWoo0P00Egoo
001HOol30004OolF?Nm0Ool00cg_OR1n8003OR09Ool3001IOol005]oo`<000=ooa@mkceoo`@mk`03
OR1lH7cP009n80Ioo`<005aoo`00GWoo0P0017oo4Sg_>Goo1cg_00=n87aPO>000WhP0goo0`00Ggoo
001POol20006Ool@?NlbOol<?Nl5OR02Ool00`00Oomoo`1POol0069oo`<000Ioo`lmkb9ooa/mk`=o
o`<006=oo`00IGoo0`001Woo3cg_37oo2Cg_2Goo6Cg_0goo0`00IWoo001XOol40005OolQ?Nl3OolL
?Nl2Ool4001YOol006aoo`@000=oocTmk`=oo`@006eoo`00L7oo0`000goo:Sg_2goo1000LGoo001c
Ool500000goo?Nlmk`0R?Nl:Ool4001eOol007Qoo`@001/mk`Uoo`L007Uoo`00OWoo43g_17oo3P00
P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yoo`<000=o
o`<008eoo`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008Yoo`04001oogoo0002Ool01000
Oomoo`00S7oo002:Ool30003Ool3002=Ool008]oo`03001oogoo00=oo`03001oogoo08aoo`00Rgoo
0`000goo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(67)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
1 .984 0 r
.008 w
.65242 .94241 Mdot
.016 w
.65242 .94241 m
.6526 .94236 L
s
1 .967 0 r
.008 w
.6526 .94236 Mdot
.016 w
.6526 .94236 m
.65289 .94221 L
s
1 .951 0 r
.008 w
.65289 .94221 Mdot
.016 w
.65289 .94221 m
.65335 .94184 L
s
1 .934 0 r
.008 w
.65335 .94184 Mdot
.016 w
.65335 .94184 m
.65393 .9413 L
s
1 .918 0 r
.008 w
.65393 .9413 Mdot
.016 w
.65393 .9413 m
.65455 .94071 L
s
1 .902 0 r
.008 w
.65455 .94071 Mdot
.016 w
.65455 .94071 m
.65512 .94016 L
s
1 .885 0 r
.008 w
.65512 .94016 Mdot
.016 w
.65512 .94016 m
.65568 .93956 L
s
1 .869 0 r
.008 w
.65568 .93956 Mdot
.016 w
.65568 .93956 m
.65617 .93901 L
s
1 .852 0 r
.008 w
.65617 .93901 Mdot
.016 w
.65617 .93901 m
.65657 .93857 L
s
1 .836 0 r
.008 w
.65657 .93857 Mdot
.016 w
.65657 .93857 m
.65691 .93822 L
s
1 .82 0 r
.008 w
.65691 .93822 Mdot
.016 w
.65691 .93822 m
.6572 .93796 L
s
1 .803 0 r
.008 w
.6572 .93796 Mdot
.016 w
.6572 .93796 m
.6574 .9378 L
s
1 .787 0 r
.008 w
.6574 .9378 Mdot
.016 w
.6574 .9378 m
.65753 .93778 L
s
1 .77 0 r
.008 w
.65753 .93778 Mdot
.016 w
.65753 .93778 m
.65761 .93784 L
s
1 .754 0 r
.008 w
.65761 .93784 Mdot
.016 w
.65761 .93784 m
.65771 .9379 L
s
1 .738 0 r
.008 w
.65771 .9379 Mdot
.016 w
.65771 .9379 m
.65777 .93794 L
s
1 .721 0 r
.008 w
.65777 .93794 Mdot
.016 w
.65777 .93794 m
.65779 .93798 L
s
1 .705 0 r
.008 w
.65779 .93798 Mdot
.016 w
.65779 .93798 m
.6578 .938 L
s
1 .689 0 r
.008 w
.6578 .938 Mdot
.016 w
.6578 .938 m
.65788 .93792 L
s
1 .672 0 r
.008 w
.65788 .93792 Mdot
.016 w
.65788 .93792 m
.65807 .93777 L
s
1 .656 0 r
.008 w
.65807 .93777 Mdot
.016 w
.65807 .93777 m
.65841 .93759 L
s
1 .639 0 r
.008 w
.65841 .93759 Mdot
.016 w
.65841 .93759 m
.65886 .93739 L
s
1 .623 0 r
.008 w
.65886 .93739 Mdot
.016 w
.65886 .93739 m
.65945 .93717 L
s
1 .607 0 r
.008 w
.65945 .93717 Mdot
.016 w
.65945 .93717 m
.66008 .93692 L
s
1 .59 0 r
.008 w
.66008 .93692 Mdot
.016 w
.66008 .93692 m
.66076 .93667 L
s
1 .574 0 r
.008 w
.66076 .93667 Mdot
.016 w
.66076 .93667 m
.66141 .9364 L
s
1 .557 0 r
.008 w
.66141 .9364 Mdot
.016 w
.66141 .9364 m
.66204 .93613 L
s
1 .541 0 r
.008 w
.66204 .93613 Mdot
.016 w
.66204 .93613 m
.66263 .93585 L
s
1 .525 0 r
.008 w
.66263 .93585 Mdot
.016 w
.66263 .93585 m
.66318 .93561 L
s
1 .508 0 r
.008 w
.66318 .93561 Mdot
.016 w
.66318 .93561 m
.66366 .93547 L
s
1 .492 0 r
.008 w
.66366 .93547 Mdot
.016 w
.66366 .93547 m
.664 .93544 L
s
1 .475 0 r
.008 w
.664 .93544 Mdot
.016 w
.664 .93544 m
.66412 .93553 L
s
1 .459 0 r
.008 w
.66412 .93553 Mdot
.016 w
.66412 .93553 m
.66403 .93574 L
s
1 .443 0 r
.008 w
.66403 .93574 Mdot
.016 w
.66403 .93574 m
.66378 .93601 L
s
1 .426 0 r
.008 w
.66378 .93601 Mdot
.016 w
.66378 .93601 m
.66345 .9363 L
s
1 .41 0 r
.008 w
.66345 .9363 Mdot
.016 w
.66345 .9363 m
.66308 .93653 L
s
1 .393 0 r
.008 w
.66308 .93653 Mdot
.016 w
.66308 .93653 m
.66279 .93665 L
s
1 .377 0 r
.008 w
.66279 .93665 Mdot
.016 w
.66279 .93665 m
.66245 .93671 L
s
1 .361 0 r
.008 w
.66245 .93671 Mdot
.016 w
.66245 .93671 m
.66202 .93685 L
s
1 .344 0 r
.008 w
.66202 .93685 Mdot
.016 w
.66202 .93685 m
.6615 .93712 L
s
1 .328 0 r
.008 w
.6615 .93712 Mdot
.016 w
.6615 .93712 m
.66091 .93751 L
s
1 .311 0 r
.008 w
.66091 .93751 Mdot
.016 w
.66091 .93751 m
.66025 .93799 L
s
1 .295 0 r
.008 w
.66025 .93799 Mdot
.016 w
.66025 .93799 m
.65946 .93872 L
s
1 .279 0 r
.008 w
.65946 .93872 Mdot
.016 w
.65946 .93872 m
.65862 .93933 L
s
1 .262 0 r
.008 w
.65862 .93933 Mdot
.016 w
.65862 .93933 m
.65785 .93987 L
s
1 .246 0 r
.008 w
.65785 .93987 Mdot
.016 w
.65785 .93987 m
.65732 .94025 L
s
1 .23 0 r
.008 w
.65732 .94025 Mdot
.016 w
.65732 .94025 m
.657 .94048 L
s
1 .213 0 r
.008 w
.657 .94048 Mdot
.016 w
.657 .94048 m
.65683 .94055 L
s
1 .197 0 r
.008 w
.65683 .94055 Mdot
.016 w
.65683 .94055 m
.65675 .94055 L
s
1 .18 0 r
.008 w
.65675 .94055 Mdot
.016 w
.65675 .94055 m
.65665 .94049 L
s
1 .164 0 r
.008 w
.65665 .94049 Mdot
.016 w
.65665 .94049 m
.65638 .94055 L
s
1 .148 0 r
.008 w
.65638 .94055 Mdot
.016 w
.65638 .94055 m
.65623 .94049 L
s
1 .131 0 r
.008 w
.65623 .94049 Mdot
.016 w
.65623 .94049 m
.65614 .94036 L
s
1 .115 0 r
.008 w
.65614 .94036 Mdot
.016 w
.65614 .94036 m
.65624 .9401 L
s
1 .098 0 r
.008 w
.65624 .9401 Mdot
.016 w
.65624 .9401 m
.65666 .93965 L
s
1 .082 0 r
.008 w
.65666 .93965 Mdot
.016 w
.65666 .93965 m
.6573 .93912 L
s
1 .066 0 r
.008 w
.6573 .93912 Mdot
.016 w
.6573 .93912 m
.65807 .93856 L
s
1 .049 0 r
.008 w
.65807 .93856 Mdot
.016 w
.65807 .93856 m
.65882 .93804 L
s
1 .033 0 r
.008 w
.65882 .93804 Mdot
.016 w
.65882 .93804 m
.65949 .93758 L
s
1 .016 0 r
.008 w
.65949 .93758 Mdot
.016 w
.65949 .93758 m
.65987 .93732 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo23g_kGoo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`@mk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool4?NlAOol7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool4?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`@mka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01goo1Cg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_jGoo00<007oo
Ool04goo000DOol00`00Oomoo`04Ool6?NoYOol00`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hm
knUoo`03001oogoo01=oo`005Goo00<007ooOol017oo1Cg_j7oo00<007ooOol057oo000EOol00`00
Oomoo`04Ool5?NoXOol00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmknQoo`03001oogoo01Ao
o`005Woo00<007ooOol00goo1Cg_igoo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoWOol0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmknIoo`03001oogoo01Ioo`005goo00<007ooOol0
0Woo1Sg_iGoo00<007ooOol05Woo000HOol00`00Oomoo`02Ool5?NoTOol00`00Oomoo`0GOol001Qo
o`03001oogoo009oo`DmknAoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkn=oo`03001oogoo
01Moo`006Goo00@007ooOomoo`Lmkn5oo`03001oogoo01Qoo`006Woo00<007ooOol01cg_hGoo00<0
07ooOol067oo000JOol01000Oomoogoo1Sg_h7oo00<007ooOol06Goo000KOol00`00Oomoo`06?NoO
Ool00`00Oomoo`0JOol001]oo`03001oogoo00Hmkmmoo`03001oogoo01Yoo`0077oo00<007ooOol0
1Cg_gWoo00<007ooOol06goo000LOol00`00Oomoo`05?NoNOol00`00Oomoo`0KOol001eoo`03001o
ocg_00@mkmeoo`03001oogoo01aoo`007Goo00<007oo?Nl013g_gGoo00<007ooOol077oo000NOol0
0`00?Nlmk`04?NoKOol00`00Oomoo`0MOol001ioo`03000mkcg_00@mkm]oo`03001oogoo01eoo`00
7goo1cg_fGoo00<007ooOol07Woo000OOol00`00?Nlmk`05?NoHOol00`00Oomoo`0NOol0021oo`03
000mkcg_00DmkmIoo`03001oogoo01moo`0087oo00<003g_?Nl01Cg_eWoo00<007ooOol07goo000Q
Ool00`00?Nlmk`06?NoCOol00`00Oomoo`0POol0029oo`03000mkcg_00Hmkm5oo`03001oogoo025o
o`008goo23g_d7oo00<007ooOol08Woo000TOol9?No=Ool00`00Oomoo`0SOol002Aoo`03000mkcg_
00Lmklaoo`03001oogoo02=oo`009Goo00<003g_?Nl01cg_bWoo00<007ooOol097oo000VOol00`00
?Nlmk`07?No8Ool00`00Oomoo`0UOol002Ioo`03001oocg_00/mklAoo`03001oogoo02Eoo`009goo
00<007oo?Nl02Sg_`goo00<007ooOol09Woo000XOol00`00Oolmk`09?No2Ool00`00Oomoo`0WOol0
02Uoo`03001oocg_00Tmkl1oo`03001oogoo02Qoo`00:Woo00<007oo?Nl023g__goo00<007ooOol0
:Goo000ZOol00`00Oomoo`09?NnnOol00`00Oomoo`0YOol002]oo`03001oogoo00Pmkkeoo`03001o
ogoo02Yoo`00;7oo00<007oo?Nl023g_^goo00<007ooOol0:goo000]Ool00`00Oolmk`08?NniOol0
0`00Oomoo`0/Ool002ioo`03001oogoo00PmkkMoo`03001oogoo02eoo`00;Woo00@007ooOomoo`Pm
kkIoo`03001oogoo02eoo`00;goo00@007ooOomoo`Tmkk=oo`03001oogoo02ioo`00<7oo00@007oo
Oomoo`Pmkk9oo`03001oogoo02moo`00<Goo00@007ooOomoo`Pmkk1oo`03001oogoo031oo`00<Woo
0P000goo1cg_[Goo0P00<goo000dOol01000Oomoogoo1cg_Zgoo00<007ooOol0<goo000eOol01000
Oomoogoo1cg_ZGoo00<007ooOol0=7oo000eOol01000Oomoogoo23g_Z7oo00<007ooOol0=7oo000f
Ool01000Oomoogoo23g_YWoo00<007ooOol0=Goo000gOol00`00Oomoo`02Ool7?NnTOol00`00Oomo
o`0fOol003Qoo`03001oogoo009oo`Lmkj9oo`03001oogoo03Moo`00>Goo0P000goo23g_WWoo0P00
>Woo000kOol01000Oomoogoo23g_W7oo00<007ooOol0>Woo000lOol00`00Oomoo`09?NnJOol00`00
Oomoo`0kOol003eoo`03001oogoo00XmkiMoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_U7oo0P00
?goo0010Ool00`00Oomoo`09?NnBOol00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkhmoo`80
049oo`00@goo00<007oo?Nl02Cg_S7oo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?Nn;Ool00`00
Oomoo`13Ool004Eoo`03000mkcg_00PmkhUoo`03001oogoo04Aoo`00AWoo0P002Sg_QGoo0P00Agoo
0018Ool2000;?Nl3Ool2?NmkOol20019Ool004Yooa4mkgQoo`8004]oo`00C7oo43g_MGoo0P00CGoo
001>Ool00`00?Nlmk`0<?NmcOol00`00Oomoo`1=Ool004moo`03000mkcg_00hmkfmoo`03001oogoo
04ioo`00D7oo0P000Woo3cg_JWoo0P00DGoo001BOol200000goo?Nlmk`0>?NmVOol2001COol005Ao
o`800003?Nmoocg_00lmk`Qoo`DmkdIoo`9n80aoo`8005Eoo`00EWoo0P0017oo43g_0goo1Sg_AGoo
0Wd00WfP2Goo0P00Egoo001HOol30004OolF?Nm0Ool3?Nl2O2001G`0O21l87ePOR001Goo0`00FGoo
001KOol30003OolD?NlmOol5?Nl017n0O21l87`00W`P00Am07ooOomoo`<005aoo`00GWoo0P0017oo
4Sg_>Goo23g_00=oP7`PO2000g`P00AmH000000005moo`00H7oo0P001Woo43g_<Woo3Cg_00=oP7`P
O2000g`P00=mH7ooOol0H7oo001ROol30006Ool??NlROolK?Nl00gn0O61lH002O6000`00Oomoo`1Q
Ool006Eoo`<000Ioo`lmk`aoo`Tmk`UooaTmk`=oo`<006Ioo`00J7oo10001Goo8Cg_0goo73g_0Woo
1000JGoo001/Ool40003Ooli?Nl3Ool4001]Ool0071oo`<000=oobXmk`]oo`@0075oo`00Lgoo1@00
00=oocg_?Nl08Sg_2Woo1000MGoo001hOol4000K?Nl9Ool7001iOol007iooa0mk`Aoo`h0081oo`00
SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool30005Ool00`00
Oomoo`2;Ool008Yoo`04001oogoo0004Ool00`00Oomoo`2;Ool008Yoo`04001oogoo0004Ool00`00
Oomoo`2;Ool008Yoo`<000Ioo`03001oogoo08Yoo`00Rgoo00<007ooOol00Woo00@007ooOol008ao
o`00Rgoo0`000Woo1000S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(68)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
1 .968 0 r
.008 w
.65756 .93928 Mdot
.016 w
.65756 .93928 m
.65768 .93911 L
s
1 .935 0 r
.008 w
.65768 .93911 Mdot
.016 w
.65768 .93911 m
.65766 .93891 L
s
1 .903 0 r
.008 w
.65766 .93891 Mdot
.016 w
.65766 .93891 m
.65741 .93878 L
s
1 .871 0 r
.008 w
.65741 .93878 Mdot
.016 w
.65741 .93878 m
.65695 .93866 L
s
1 .839 0 r
.008 w
.65695 .93866 Mdot
.016 w
.65695 .93866 m
.65635 .9385 L
s
1 .806 0 r
.008 w
.65635 .9385 Mdot
.016 w
.65635 .9385 m
.65577 .93835 L
s
1 .774 0 r
.008 w
.65577 .93835 Mdot
.016 w
.65577 .93835 m
.65534 .93807 L
s
1 .742 0 r
.008 w
.65534 .93807 Mdot
.016 w
.65534 .93807 m
.65524 .93746 L
s
1 .71 0 r
.008 w
.65524 .93746 Mdot
.016 w
.65524 .93746 m
.65519 .93714 L
s
1 .677 0 r
.008 w
.65519 .93714 Mdot
.016 w
.65519 .93714 m
.65533 .93689 L
s
1 .645 0 r
.008 w
.65533 .93689 Mdot
.016 w
.65533 .93689 m
.65561 .93672 L
s
1 .613 0 r
.008 w
.65561 .93672 Mdot
.016 w
.65561 .93672 m
.65603 .93664 L
s
1 .581 0 r
.008 w
.65603 .93664 Mdot
.016 w
.65603 .93664 m
.65642 .93666 L
s
1 .548 0 r
.008 w
.65642 .93666 Mdot
.016 w
.65642 .93666 m
.65679 .93675 L
s
1 .516 0 r
.008 w
.65679 .93675 Mdot
.016 w
.65679 .93675 m
.65708 .93687 L
s
1 .484 0 r
.008 w
.65708 .93687 Mdot
.016 w
.65708 .93687 m
.65729 .93699 L
s
1 .452 0 r
.008 w
.65729 .93699 Mdot
.016 w
.65729 .93699 m
.65742 .93713 L
s
1 .419 0 r
.008 w
.65742 .93713 Mdot
.016 w
.65742 .93713 m
.65742 .93734 L
s
1 .387 0 r
.008 w
.65742 .93734 Mdot
.016 w
.65742 .93734 m
.65731 .93761 L
s
1 .355 0 r
.008 w
.65731 .93761 Mdot
.016 w
.65731 .93761 m
.65704 .93796 L
s
1 .323 0 r
.008 w
.65704 .93796 Mdot
.016 w
.65704 .93796 m
.65661 .93837 L
s
1 .29 0 r
.008 w
.65661 .93837 Mdot
.016 w
.65661 .93837 m
.656 .93884 L
s
1 .258 0 r
.008 w
.656 .93884 Mdot
.016 w
.656 .93884 m
.65526 .93932 L
s
1 .226 0 r
.008 w
.65526 .93932 Mdot
.016 w
.65526 .93932 m
.65436 .93979 L
s
1 .194 0 r
.008 w
.65436 .93979 Mdot
.016 w
.65436 .93979 m
.65357 .9401 L
s
1 .161 0 r
.008 w
.65357 .9401 Mdot
.016 w
.65357 .9401 m
.65279 .94037 L
s
1 .129 0 r
.008 w
.65279 .94037 Mdot
.016 w
.65279 .94037 m
.65206 .94059 L
s
1 .097 0 r
.008 w
.65206 .94059 Mdot
.016 w
.65206 .94059 m
.65149 .94075 L
s
1 .065 0 r
.008 w
.65149 .94075 Mdot
.016 w
.65149 .94075 m
.65107 .94087 L
s
1 .032 0 r
.008 w
.65107 .94087 Mdot
.016 w
.65107 .94087 m
.65081 .94096 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(69)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
1 .982 0 r
.008 w
.65815 .93795 Mdot
.016 w
.65815 .93795 m
.65842 .93778 L
s
1 .965 0 r
.008 w
.65842 .93778 Mdot
.016 w
.65842 .93778 m
.65882 .93757 L
s
1 .947 0 r
.008 w
.65882 .93757 Mdot
.016 w
.65882 .93757 m
.65937 .93729 L
s
1 .93 0 r
.008 w
.65937 .93729 Mdot
.016 w
.65937 .93729 m
.66003 .93699 L
s
1 .912 0 r
.008 w
.66003 .93699 Mdot
.016 w
.66003 .93699 m
.6609 .93663 L
s
1 .895 0 r
.008 w
.6609 .93663 Mdot
.016 w
.6609 .93663 m
.66168 .93633 L
s
1 .877 0 r
.008 w
.66168 .93633 Mdot
.016 w
.66168 .93633 m
.66262 .93599 L
s
1 .86 0 r
.008 w
.66262 .93599 Mdot
.016 w
.66262 .93599 m
.66354 .93567 L
s
1 .842 0 r
.008 w
.66354 .93567 Mdot
.016 w
.66354 .93567 m
.66439 .9354 L
s
1 .825 0 r
.008 w
.66439 .9354 Mdot
.016 w
.66439 .9354 m
.6651 .93517 L
s
1 .807 0 r
.008 w
.6651 .93517 Mdot
.016 w
.6651 .93517 m
.66567 .93497 L
s
1 .789 0 r
.008 w
.66567 .93497 Mdot
.016 w
.66567 .93497 m
.66609 .93479 L
s
1 .772 0 r
.008 w
.66609 .93479 Mdot
.016 w
.66609 .93479 m
.66629 .9347 L
s
1 .754 0 r
.008 w
.66629 .9347 Mdot
.016 w
.66629 .9347 m
.6662 .93475 L
s
1 .737 0 r
.008 w
.6662 .93475 Mdot
.016 w
.6662 .93475 m
.66587 .93491 L
s
1 .719 0 r
.008 w
.66587 .93491 Mdot
.016 w
.66587 .93491 m
.66534 .93516 L
s
1 .702 0 r
.008 w
.66534 .93516 Mdot
.016 w
.66534 .93516 m
.66472 .93545 L
s
1 .684 0 r
.008 w
.66472 .93545 Mdot
.016 w
.66472 .93545 m
.66399 .93578 L
s
1 .667 0 r
.008 w
.66399 .93578 Mdot
.016 w
.66399 .93578 m
.66325 .9361 L
s
1 .649 0 r
.008 w
.66325 .9361 Mdot
.016 w
.66325 .9361 m
.66263 .93638 L
s
1 .632 0 r
.008 w
.66263 .93638 Mdot
.016 w
.66263 .93638 m
.66224 .93658 L
s
1 .614 0 r
.008 w
.66224 .93658 Mdot
.016 w
.66224 .93658 m
.66208 .93672 L
s
1 .596 0 r
.008 w
.66208 .93672 Mdot
.016 w
.66208 .93672 m
.66217 .9368 L
s
1 .579 0 r
.008 w
.66217 .9368 Mdot
.016 w
.66217 .9368 m
.66252 .9368 L
s
1 .561 0 r
.008 w
.66252 .9368 Mdot
.016 w
.66252 .9368 m
.66303 .9368 L
s
1 .544 0 r
.008 w
.66303 .9368 Mdot
.016 w
.66303 .9368 m
.66365 .93678 L
s
1 .526 0 r
.008 w
.66365 .93678 Mdot
.016 w
.66365 .93678 m
.66455 .93665 L
s
1 .509 0 r
.008 w
.66455 .93665 Mdot
.016 w
.66455 .93665 m
.66586 .93616 L
s
1 .491 0 r
.008 w
.66586 .93616 Mdot
.016 w
.66586 .93616 m
.66717 .93589 L
s
1 .474 0 r
.008 w
.66717 .93589 Mdot
.016 w
.66717 .93589 m
.66864 .93552 L
s
1 .456 0 r
.008 w
.66864 .93552 Mdot
.016 w
.66864 .93552 m
.67024 .93503 L
s
1 .439 0 r
.008 w
.67024 .93503 Mdot
.016 w
.67024 .93503 m
.67195 .93442 L
s
1 .421 0 r
.008 w
.67195 .93442 Mdot
.016 w
.67195 .93442 m
.67371 .93372 L
s
1 .404 0 r
.008 w
.67371 .93372 Mdot
.016 w
.67371 .93372 m
.67554 .93293 L
s
1 .386 0 r
.008 w
.67554 .93293 Mdot
.016 w
.67554 .93293 m
.67739 .93208 L
s
1 .368 0 r
.008 w
.67739 .93208 Mdot
.016 w
.67739 .93208 m
.6792 .93114 L
s
1 .351 0 r
.008 w
.6792 .93114 Mdot
.016 w
.6792 .93114 m
.68087 .93013 L
s
1 .333 0 r
.008 w
.68087 .93013 Mdot
.016 w
.68087 .93013 m
.68249 .92903 L
s
1 .316 0 r
.008 w
.68249 .92903 Mdot
.016 w
.68249 .92903 m
.68402 .92792 L
s
1 .298 0 r
.008 w
.68402 .92792 Mdot
.016 w
.68402 .92792 m
.68543 .92674 L
s
1 .281 0 r
.008 w
.68543 .92674 Mdot
.016 w
.68543 .92674 m
.68665 .92563 L
s
1 .263 0 r
.008 w
.68665 .92563 Mdot
.016 w
.68665 .92563 m
.68765 .92465 L
s
1 .246 0 r
.008 w
.68765 .92465 Mdot
.016 w
.68765 .92465 m
.68842 .92381 L
s
1 .228 0 r
.008 w
.68842 .92381 Mdot
.016 w
.68842 .92381 m
.68896 .92313 L
s
1 .211 0 r
.008 w
.68896 .92313 Mdot
.016 w
.68896 .92313 m
.68924 .92265 L
s
1 .193 0 r
.008 w
.68924 .92265 Mdot
.016 w
.68924 .92265 m
.68928 .9224 L
s
1 .175 0 r
.008 w
.68928 .9224 Mdot
.016 w
.68928 .9224 m
.68908 .92237 L
s
1 .158 0 r
.008 w
.68908 .92237 Mdot
.016 w
.68908 .92237 m
.68867 .92252 L
s
1 .14 0 r
.008 w
.68867 .92252 Mdot
.016 w
.68867 .92252 m
.68809 .92282 L
s
1 .123 0 r
.008 w
.68809 .92282 Mdot
.016 w
.68809 .92282 m
.68746 .92323 L
s
1 .105 0 r
.008 w
.68746 .92323 Mdot
.016 w
.68746 .92323 m
.68677 .92378 L
s
1 .088 0 r
.008 w
.68677 .92378 Mdot
.016 w
.68677 .92378 m
.68608 .92445 L
s
1 .07 0 r
.008 w
.68608 .92445 Mdot
.016 w
.68608 .92445 m
.68552 .92503 L
s
1 .053 0 r
.008 w
.68552 .92503 Mdot
.016 w
.68552 .92503 m
.68505 .92562 L
s
1 .035 0 r
.008 w
.68505 .92562 Mdot
.016 w
.68505 .92562 m
.68476 .92602 L
s
1 .018 0 r
.008 w
.68476 .92602 Mdot
.016 w
.68476 .92602 m
.6847 .92617 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(70)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
1 .98 0 r
.008 w
.68712 .92334 Mdot
.016 w
.68712 .92334 m
.68721 .92337 L
s
1 .961 0 r
.008 w
.68721 .92337 Mdot
.016 w
.68721 .92337 m
.68721 .92354 L
s
1 .941 0 r
.008 w
.68721 .92354 Mdot
.016 w
.68721 .92354 m
.68712 .92383 L
s
1 .922 0 r
.008 w
.68712 .92383 Mdot
.016 w
.68712 .92383 m
.687 .92422 L
s
1 .902 0 r
.008 w
.687 .92422 Mdot
.016 w
.687 .92422 m
.68695 .92464 L
s
1 .882 0 r
.008 w
.68695 .92464 Mdot
.016 w
.68695 .92464 m
.68701 .925 L
s
1 .863 0 r
.008 w
.68701 .925 Mdot
.016 w
.68701 .925 m
.6872 .92525 L
s
1 .843 0 r
.008 w
.6872 .92525 Mdot
.016 w
.6872 .92525 m
.68749 .9254 L
s
1 .824 0 r
.008 w
.68749 .9254 Mdot
.016 w
.68749 .9254 m
.6878 .92542 L
s
1 .804 0 r
.008 w
.6878 .92542 Mdot
.016 w
.6878 .92542 m
.6881 .92543 L
s
1 .784 0 r
.008 w
.6881 .92543 Mdot
.016 w
.6881 .92543 m
.68836 .9255 L
s
1 .765 0 r
.008 w
.68836 .9255 Mdot
.016 w
.68836 .9255 m
.68851 .92567 L
s
1 .745 0 r
.008 w
.68851 .92567 Mdot
.016 w
.68851 .92567 m
.68863 .92588 L
s
1 .725 0 r
.008 w
.68863 .92588 Mdot
.016 w
.68863 .92588 m
.68876 .92608 L
s
1 .706 0 r
.008 w
.68876 .92608 Mdot
.016 w
.68876 .92608 m
.68899 .92621 L
s
1 .686 0 r
.008 w
.68899 .92621 Mdot
.016 w
.68899 .92621 m
.68942 .92619 L
s
1 .667 0 r
.008 w
.68942 .92619 Mdot
.016 w
.68942 .92619 m
.69007 .92599 L
s
1 .647 0 r
.008 w
.69007 .92599 Mdot
.016 w
.69007 .92599 m
.69097 .92561 L
s
1 .627 0 r
.008 w
.69097 .92561 Mdot
.016 w
.69097 .92561 m
.69183 .9252 L
s
1 .608 0 r
.008 w
.69183 .9252 Mdot
.016 w
.69183 .9252 m
.69285 .9247 L
s
1 .588 0 r
.008 w
.69285 .9247 Mdot
.016 w
.69285 .9247 m
.69387 .92413 L
s
1 .569 0 r
.008 w
.69387 .92413 Mdot
.016 w
.69387 .92413 m
.69478 .92353 L
s
1 .549 0 r
.008 w
.69478 .92353 Mdot
.016 w
.69478 .92353 m
.69576 .92295 L
s
1 .529 0 r
.008 w
.69576 .92295 Mdot
.016 w
.69576 .92295 m
.69663 .92235 L
s
1 .51 0 r
.008 w
.69663 .92235 Mdot
.016 w
.69663 .92235 m
.69739 .92175 L
s
1 .49 0 r
.008 w
.69739 .92175 Mdot
.016 w
.69739 .92175 m
.69799 .92118 L
s
1 .471 0 r
.008 w
.69799 .92118 Mdot
.016 w
.69799 .92118 m
.69838 .92072 L
s
1 .451 0 r
.008 w
.69838 .92072 Mdot
.016 w
.69838 .92072 m
.69854 .92037 L
s
1 .431 0 r
.008 w
.69854 .92037 Mdot
.016 w
.69854 .92037 m
.69842 .92016 L
s
1 .412 0 r
.008 w
.69842 .92016 Mdot
.016 w
.69842 .92016 m
.69801 .92015 L
s
1 .392 0 r
.008 w
.69801 .92015 Mdot
.016 w
.69801 .92015 m
.69731 .92033 L
s
1 .373 0 r
.008 w
.69731 .92033 Mdot
.016 w
.69731 .92033 m
.69645 .92063 L
s
1 .353 0 r
.008 w
.69645 .92063 Mdot
.016 w
.69645 .92063 m
.69561 .92095 L
s
1 .333 0 r
.008 w
.69561 .92095 Mdot
.016 w
.69561 .92095 m
.6948 .92125 L
s
1 .314 0 r
.008 w
.6948 .92125 Mdot
.016 w
.6948 .92125 m
.69429 .92137 L
s
1 .294 0 r
.008 w
.69429 .92137 Mdot
.016 w
.69429 .92137 m
.69364 .92163 L
s
1 .275 0 r
.008 w
.69364 .92163 Mdot
.016 w
.69364 .92163 m
.69302 .92186 L
s
1 .255 0 r
.008 w
.69302 .92186 Mdot
.016 w
.69302 .92186 m
.69245 .92213 L
s
1 .235 0 r
.008 w
.69245 .92213 Mdot
.016 w
.69245 .92213 m
.6919 .92246 L
s
1 .216 0 r
.008 w
.6919 .92246 Mdot
.016 w
.6919 .92246 m
.6914 .92291 L
s
1 .196 0 r
.008 w
.6914 .92291 Mdot
.016 w
.6914 .92291 m
.6909 .92343 L
s
1 .176 0 r
.008 w
.6909 .92343 Mdot
.016 w
.6909 .92343 m
.69039 .92398 L
s
1 .157 0 r
.008 w
.69039 .92398 Mdot
.016 w
.69039 .92398 m
.68988 .92451 L
s
1 .137 0 r
.008 w
.68988 .92451 Mdot
.016 w
.68988 .92451 m
.6894 .92494 L
s
1 .118 0 r
.008 w
.6894 .92494 Mdot
.016 w
.6894 .92494 m
.68891 .92533 L
s
1 .098 0 r
.008 w
.68891 .92533 Mdot
.016 w
.68891 .92533 m
.68852 .92558 L
s
1 .078 0 r
.008 w
.68852 .92558 Mdot
.016 w
.68852 .92558 m
.68812 .92581 L
s
1 .059 0 r
.008 w
.68812 .92581 Mdot
.016 w
.68812 .92581 m
.68778 .92593 L
s
1 .039 0 r
.008 w
.68778 .92593 Mdot
.016 w
.68778 .92593 m
.6875 .92598 L
s
1 .02 0 r
.008 w
.6875 .92598 Mdot
.016 w
.6875 .92598 m
.68731 .92601 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(71)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
1 .996 0 r
.008 w
.66726 .93047 Mdot
.016 w
.66726 .93047 m
.66721 .93054 L
s
1 .992 0 r
.008 w
.66721 .93054 Mdot
.016 w
.66721 .93054 m
.66727 .93057 L
s
1 .988 0 r
.008 w
.66727 .93057 Mdot
.016 w
.66727 .93057 m
.66741 .93058 L
s
1 .984 0 r
.008 w
.66741 .93058 Mdot
.016 w
.66741 .93058 m
.66757 .93065 L
s
1 .98 0 r
.008 w
.66757 .93065 Mdot
.016 w
.66757 .93065 m
.66763 .93083 L
s
1 .976 0 r
.008 w
.66763 .93083 Mdot
.016 w
.66763 .93083 m
.66757 .93112 L
s
1 .972 0 r
.008 w
.66757 .93112 Mdot
.016 w
.66757 .93112 m
.66733 .93151 L
s
1 .967 0 r
.008 w
.66733 .93151 Mdot
.016 w
.66733 .93151 m
.66696 .93193 L
s
1 .963 0 r
.008 w
.66696 .93193 Mdot
.016 w
.66696 .93193 m
.66646 .93238 L
s
1 .959 0 r
.008 w
.66646 .93238 Mdot
.016 w
.66646 .93238 m
.66589 .93284 L
s
1 .955 0 r
.008 w
.66589 .93284 Mdot
.016 w
.66589 .93284 m
.66515 .93328 L
s
1 .951 0 r
.008 w
.66515 .93328 Mdot
.016 w
.66515 .93328 m
.66457 .9336 L
s
1 .947 0 r
.008 w
.66457 .9336 Mdot
.016 w
.66457 .9336 m
.66399 .93384 L
s
1 .943 0 r
.008 w
.66399 .93384 Mdot
.016 w
.66399 .93384 m
.66341 .93401 L
s
1 .939 0 r
.008 w
.66341 .93401 Mdot
.016 w
.66341 .93401 m
.66282 .93409 L
s
1 .935 0 r
.008 w
.66282 .93409 Mdot
.016 w
.66282 .93409 m
.66231 .93409 L
s
1 .931 0 r
.008 w
.66231 .93409 Mdot
.016 w
.66231 .93409 m
.66188 .93406 L
s
1 .927 0 r
.008 w
.66188 .93406 Mdot
.016 w
.66188 .93406 m
.66148 .93395 L
s
1 .923 0 r
.008 w
.66148 .93395 Mdot
.016 w
.66148 .93395 m
.66125 .93414 L
s
1 .919 0 r
.008 w
.66125 .93414 Mdot
.016 w
.66125 .93414 m
.66102 .9339 L
s
1 .915 0 r
.008 w
.66102 .9339 Mdot
.016 w
.66102 .9339 m
.66088 .93358 L
s
1 .911 0 r
.008 w
.66088 .93358 Mdot
.016 w
.66088 .93358 m
.66072 .93326 L
s
1 .907 0 r
.008 w
.66072 .93326 Mdot
.016 w
.66072 .93326 m
.66038 .9329 L
s
1 .902 0 r
.008 w
.66038 .9329 Mdot
.016 w
.66038 .9329 m
.65997 .93262 L
s
1 .898 0 r
.008 w
.65997 .93262 Mdot
.016 w
.65997 .93262 m
.65955 .93242 L
s
1 .894 0 r
.008 w
.65955 .93242 Mdot
.016 w
.65955 .93242 m
.65908 .93222 L
s
1 .89 0 r
.008 w
.65908 .93222 Mdot
.016 w
.65908 .93222 m
.65866 .93208 L
s
1 .886 0 r
.008 w
.65866 .93208 Mdot
.016 w
.65866 .93208 m
.65832 .93194 L
s
1 .882 0 r
.008 w
.65832 .93194 Mdot
.016 w
.65832 .93194 m
.65824 .93191 L
s
1 .878 0 r
.008 w
.65824 .93191 Mdot
.016 w
.65824 .93191 m
.65835 .93192 L
s
1 .874 0 r
.008 w
.65835 .93192 Mdot
.016 w
.65835 .93192 m
.6587 .93202 L
s
1 .87 0 r
.008 w
.6587 .93202 Mdot
.016 w
.6587 .93202 m
.65924 .93219 L
s
1 .866 0 r
.008 w
.65924 .93219 Mdot
.016 w
.65924 .93219 m
.6599 .93239 L
s
1 .862 0 r
.008 w
.6599 .93239 Mdot
.016 w
.6599 .93239 m
.66057 .93259 L
s
1 .858 0 r
.008 w
.66057 .93259 Mdot
.016 w
.66057 .93259 m
.66125 .93277 L
s
1 .854 0 r
.008 w
.66125 .93277 Mdot
.016 w
.66125 .93277 m
.66193 .93288 L
s
1 .85 0 r
.008 w
.66193 .93288 Mdot
.016 w
.66193 .93288 m
.66271 .93295 L
s
1 .846 0 r
.008 w
.66271 .93295 Mdot
.016 w
.66271 .93295 m
.66352 .93293 L
s
1 .841 0 r
.008 w
.66352 .93293 Mdot
.016 w
.66352 .93293 m
.66433 .93289 L
s
1 .837 0 r
.008 w
.66433 .93289 Mdot
.016 w
.66433 .93289 m
.66508 .93284 L
s
1 .833 0 r
.008 w
.66508 .93284 Mdot
.016 w
.66508 .93284 m
.66576 .93272 L
s
1 .829 0 r
.008 w
.66576 .93272 Mdot
.016 w
.66576 .93272 m
.66634 .93247 L
s
1 .825 0 r
.008 w
.66634 .93247 Mdot
.016 w
.66634 .93247 m
.66684 .93211 L
s
1 .821 0 r
.008 w
.66684 .93211 Mdot
.016 w
.66684 .93211 m
.66729 .93169 L
s
1 .817 0 r
.008 w
.66729 .93169 Mdot
.016 w
.66729 .93169 m
.66769 .93125 L
s
1 .813 0 r
.008 w
.66769 .93125 Mdot
.016 w
.66769 .93125 m
.66807 .93085 L
s
1 .809 0 r
.008 w
.66807 .93085 Mdot
.016 w
.66807 .93085 m
.66851 .93051 L
s
1 .805 0 r
.008 w
.66851 .93051 Mdot
.016 w
.66851 .93051 m
.66909 .9303 L
s
1 .801 0 r
.008 w
.66909 .9303 Mdot
.016 w
.66909 .9303 m
.66985 .93021 L
s
1 .797 0 r
.008 w
.66985 .93021 Mdot
.016 w
.66985 .93021 m
.67071 .9302 L
s
1 .793 0 r
.008 w
.67071 .9302 Mdot
.016 w
.67071 .9302 m
.67163 .93021 L
s
1 .789 0 r
.008 w
.67163 .93021 Mdot
.016 w
.67163 .93021 m
.67273 .93019 L
s
1 .785 0 r
.008 w
.67273 .93019 Mdot
.016 w
.67273 .93019 m
.67398 .93009 L
s
1 .78 0 r
.008 w
.67398 .93009 Mdot
.016 w
.67398 .93009 m
.67538 .92989 L
s
1 .776 0 r
.008 w
.67538 .92989 Mdot
.016 w
.67538 .92989 m
.67688 .92957 L
s
1 .772 0 r
.008 w
.67688 .92957 Mdot
.016 w
.67688 .92957 m
.67848 .9292 L
s
1 .768 0 r
.008 w
.67848 .9292 Mdot
.016 w
.67848 .9292 m
.68014 .92873 L
s
1 .764 0 r
.008 w
.68014 .92873 Mdot
.016 w
.68014 .92873 m
.68186 .92821 L
s
1 .76 0 r
.008 w
.68186 .92821 Mdot
.016 w
.68186 .92821 m
.68359 .92764 L
s
1 .756 0 r
.008 w
.68359 .92764 Mdot
.016 w
.68359 .92764 m
.68533 .92703 L
s
1 .752 0 r
.008 w
.68533 .92703 Mdot
.016 w
.68533 .92703 m
.68709 .92636 L
s
1 .748 0 r
.008 w
.68709 .92636 Mdot
.016 w
.68709 .92636 m
.68869 .9256 L
s
1 .744 0 r
.008 w
.68869 .9256 Mdot
.016 w
.68869 .9256 m
.69041 .92475 L
s
1 .74 0 r
.008 w
.69041 .92475 Mdot
.016 w
.69041 .92475 m
.69213 .92381 L
s
1 .736 0 r
.008 w
.69213 .92381 Mdot
.016 w
.69213 .92381 m
.69393 .92278 L
s
1 .732 0 r
.008 w
.69393 .92278 Mdot
.016 w
.69393 .92278 m
.69577 .92165 L
s
1 .728 0 r
.008 w
.69577 .92165 Mdot
.016 w
.69577 .92165 m
.69764 .92039 L
s
1 .724 0 r
.008 w
.69764 .92039 Mdot
.016 w
.69764 .92039 m
.69954 .91899 L
s
1 .72 0 r
.008 w
.69954 .91899 Mdot
.016 w
.69954 .91899 m
.70148 .91743 L
s
1 .715 0 r
.008 w
.70148 .91743 Mdot
.016 w
.70148 .91743 m
.70346 .91571 L
s
1 .711 0 r
.008 w
.70346 .91571 Mdot
.016 w
.70346 .91571 m
.70546 .91388 L
s
1 .707 0 r
.008 w
.70546 .91388 Mdot
.016 w
.70546 .91388 m
.70746 .91195 L
s
1 .703 0 r
.008 w
.70746 .91195 Mdot
.016 w
.70746 .91195 m
.70946 .90996 L
s
1 .699 0 r
.008 w
.70946 .90996 Mdot
.016 w
.70946 .90996 m
.71144 .90794 L
s
1 .695 0 r
.008 w
.71144 .90794 Mdot
.016 w
.71144 .90794 m
.71342 .90593 L
s
1 .691 0 r
.008 w
.71342 .90593 Mdot
.016 w
.71342 .90593 m
.71557 .90366 L
s
1 .687 0 r
.008 w
.71557 .90366 Mdot
.016 w
.71557 .90366 m
.71726 .90193 L
s
1 .683 0 r
.008 w
.71726 .90193 Mdot
.016 w
.71726 .90193 m
.71893 .90007 L
s
1 .679 0 r
.008 w
.71893 .90007 Mdot
.016 w
.71893 .90007 m
.72039 .89847 L
s
1 .675 0 r
.008 w
.72039 .89847 Mdot
.016 w
.72039 .89847 m
.72161 .89712 L
s
1 .671 0 r
.008 w
.72161 .89712 Mdot
.016 w
.72161 .89712 m
.72259 .89609 L
s
1 .667 0 r
.008 w
.72259 .89609 Mdot
.016 w
.72259 .89609 m
.72335 .89539 L
s
1 .663 0 r
.008 w
.72335 .89539 Mdot
.016 w
.72335 .89539 m
.7239 .89497 L
s
1 .659 0 r
.008 w
.7239 .89497 Mdot
.016 w
.7239 .89497 m
.72425 .89477 L
s
1 .654 0 r
.008 w
.72425 .89477 Mdot
.016 w
.72425 .89477 m
.72443 .89473 L
s
1 .65 0 r
.008 w
.72443 .89473 Mdot
.016 w
.72443 .89473 m
.72448 .89481 L
s
1 .646 0 r
.008 w
.72448 .89481 Mdot
.016 w
.72448 .89481 m
.72441 .89494 L
s
1 .642 0 r
.008 w
.72441 .89494 Mdot
.016 w
.72441 .89494 m
.72423 .89509 L
s
1 .638 0 r
.008 w
.72423 .89509 Mdot
.016 w
.72423 .89509 m
.72397 .89522 L
s
1 .634 0 r
.008 w
.72397 .89522 Mdot
.016 w
.72397 .89522 m
.72368 .89522 L
s
1 .63 0 r
.008 w
.72368 .89522 Mdot
.016 w
.72368 .89522 m
.72336 .89511 L
s
1 .626 0 r
.008 w
.72336 .89511 Mdot
.016 w
.72336 .89511 m
.72304 .89486 L
s
1 .622 0 r
.008 w
.72304 .89486 Mdot
.016 w
.72304 .89486 m
.72275 .8945 L
s
1 .618 0 r
.008 w
.72275 .8945 Mdot
.016 w
.72275 .8945 m
.72247 .89401 L
s
1 .614 0 r
.008 w
.72247 .89401 Mdot
.016 w
.72247 .89401 m
.72222 .89338 L
s
1 .61 0 r
.008 w
.72222 .89338 Mdot
.016 w
.72222 .89338 m
.72198 .89267 L
s
1 .606 0 r
.008 w
.72198 .89267 Mdot
.016 w
.72198 .89267 m
.72173 .89199 L
s
1 .602 0 r
.008 w
.72173 .89199 Mdot
.016 w
.72173 .89199 m
.72146 .89143 L
s
1 .598 0 r
.008 w
.72146 .89143 Mdot
.016 w
.72146 .89143 m
.72114 .89099 L
s
1 .593 0 r
.008 w
.72114 .89099 Mdot
.016 w
.72114 .89099 m
.72078 .89072 L
s
1 .589 0 r
.008 w
.72078 .89072 Mdot
.016 w
.72078 .89072 m
.72042 .89067 L
s
1 .585 0 r
.008 w
.72042 .89067 Mdot
.016 w
.72042 .89067 m
.72009 .89087 L
s
1 .581 0 r
.008 w
.72009 .89087 Mdot
.016 w
.72009 .89087 m
.71981 .89128 L
s
1 .577 0 r
.008 w
.71981 .89128 Mdot
.016 w
.71981 .89128 m
.71959 .89167 L
s
1 .573 0 r
.008 w
.71959 .89167 Mdot
.016 w
.71959 .89167 m
.71941 .89243 L
s
1 .569 0 r
.008 w
.71941 .89243 Mdot
.016 w
.71941 .89243 m
.71923 .89325 L
s
1 .565 0 r
.008 w
.71923 .89325 Mdot
.016 w
.71923 .89325 m
.71902 .89435 L
s
1 .561 0 r
.008 w
.71902 .89435 Mdot
.016 w
.71902 .89435 m
.71874 .89538 L
s
1 .557 0 r
.008 w
.71874 .89538 Mdot
.016 w
.71874 .89538 m
.71836 .89641 L
s
1 .553 0 r
.008 w
.71836 .89641 Mdot
.016 w
.71836 .89641 m
.71784 .89766 L
s
1 .549 0 r
.008 w
.71784 .89766 Mdot
.016 w
.71784 .89766 m
.71721 .89877 L
s
1 .545 0 r
.008 w
.71721 .89877 Mdot
.016 w
.71721 .89877 m
.71643 .89993 L
s
1 .541 0 r
.008 w
.71643 .89993 Mdot
.016 w
.71643 .89993 m
.7155 .90113 L
s
1 .537 0 r
.008 w
.7155 .90113 Mdot
.016 w
.7155 .90113 m
.71446 .9022 L
s
1 .533 0 r
.008 w
.71446 .9022 Mdot
.016 w
.71446 .9022 m
.71326 .90328 L
s
1 .528 0 r
.008 w
.71326 .90328 Mdot
.016 w
.71326 .90328 m
.71191 .90429 L
s
1 .524 0 r
.008 w
.71191 .90429 Mdot
.016 w
.71191 .90429 m
.71051 .90522 L
s
1 .52 0 r
.008 w
.71051 .90522 Mdot
.016 w
.71051 .90522 m
.70897 .90609 L
s
1 .516 0 r
.008 w
.70897 .90609 Mdot
.016 w
.70897 .90609 m
.70744 .90698 L
s
1 .512 0 r
.008 w
.70744 .90698 Mdot
.016 w
.70744 .90698 m
.70583 .90787 L
s
1 .508 0 r
.008 w
.70583 .90787 Mdot
.016 w
.70583 .90787 m
.70429 .90876 L
s
1 .504 0 r
.008 w
.70429 .90876 Mdot
.016 w
.70429 .90876 m
.70279 .90969 L
s
1 .5 0 r
.008 w
.70279 .90969 Mdot
.016 w
.70279 .90969 m
.70133 .91073 L
s
1 .496 0 r
.008 w
.70133 .91073 Mdot
.016 w
.70133 .91073 m
.69987 .9119 L
s
1 .492 0 r
.008 w
.69987 .9119 Mdot
.016 w
.69987 .9119 m
.69834 .91318 L
s
1 .488 0 r
.008 w
.69834 .91318 Mdot
.016 w
.69834 .91318 m
.69678 .91453 L
s
1 .484 0 r
.008 w
.69678 .91453 Mdot
.016 w
.69678 .91453 m
.69513 .91596 L
s
1 .48 0 r
.008 w
.69513 .91596 Mdot
.016 w
.69513 .91596 m
.69334 .91737 L
s
1 .476 0 r
.008 w
.69334 .91737 Mdot
.016 w
.69334 .91737 m
.69159 .9189 L
s
1 .472 0 r
.008 w
.69159 .9189 Mdot
.016 w
.69159 .9189 m
.68969 .92051 L
s
1 .467 0 r
.008 w
.68969 .92051 Mdot
.016 w
.68969 .92051 m
.68765 .9222 L
s
1 .463 0 r
.008 w
.68765 .9222 Mdot
.016 w
.68765 .9222 m
.68554 .92388 L
s
1 .459 0 r
.008 w
.68554 .92388 Mdot
.016 w
.68554 .92388 m
.68344 .92545 L
s
1 .455 0 r
.008 w
.68344 .92545 Mdot
.016 w
.68344 .92545 m
.68134 .92689 L
s
1 .451 0 r
.008 w
.68134 .92689 Mdot
.016 w
.68134 .92689 m
.6793 .92817 L
s
1 .447 0 r
.008 w
.6793 .92817 Mdot
.016 w
.6793 .92817 m
.67746 .92925 L
s
1 .443 0 r
.008 w
.67746 .92925 Mdot
.016 w
.67746 .92925 m
.67572 .93013 L
s
1 .439 0 r
.008 w
.67572 .93013 Mdot
.016 w
.67572 .93013 m
.67418 .93077 L
s
1 .435 0 r
.008 w
.67418 .93077 Mdot
.016 w
.67418 .93077 m
.67286 .93122 L
s
1 .431 0 r
.008 w
.67286 .93122 Mdot
.016 w
.67286 .93122 m
.67184 .93157 L
s
1 .427 0 r
.008 w
.67184 .93157 Mdot
.016 w
.67184 .93157 m
.67088 .9319 L
s
1 .423 0 r
.008 w
.67088 .9319 Mdot
.016 w
.67088 .9319 m
.67005 .93221 L
s
1 .419 0 r
.008 w
.67005 .93221 Mdot
.016 w
.67005 .93221 m
.66925 .93249 L
s
1 .415 0 r
.008 w
.66925 .93249 Mdot
.016 w
.66925 .93249 m
.66837 .93283 L
s
1 .411 0 r
.008 w
.66837 .93283 Mdot
.016 w
.66837 .93283 m
.66739 .93325 L
s
1 .407 0 r
.008 w
.66739 .93325 Mdot
.016 w
.66739 .93325 m
.6663 .93375 L
s
1 .402 0 r
.008 w
.6663 .93375 Mdot
.016 w
.6663 .93375 m
.66495 .93425 L
s
1 .398 0 r
.008 w
.66495 .93425 Mdot
.016 w
.66495 .93425 m
.66326 .93484 L
s
1 .394 0 r
.008 w
.66326 .93484 Mdot
.016 w
.66326 .93484 m
.6612 .93553 L
s
1 .39 0 r
.008 w
.6612 .93553 Mdot
.016 w
.6612 .93553 m
.65894 .93632 L
s
1 .386 0 r
.008 w
.65894 .93632 Mdot
.016 w
.65894 .93632 m
.65598 .93726 L
s
1 .382 0 r
.008 w
.65598 .93726 Mdot
.016 w
.65598 .93726 m
.65306 .93823 L
s
1 .378 0 r
.008 w
.65306 .93823 Mdot
.016 w
.65306 .93823 m
.64948 .93927 L
s
1 .374 0 r
.008 w
.64948 .93927 Mdot
.016 w
.64948 .93927 m
.64585 .9403 L
s
1 .37 0 r
.008 w
.64585 .9403 Mdot
.016 w
.64585 .9403 m
.6418 .94127 L
s
1 .366 0 r
.008 w
.6418 .94127 Mdot
.016 w
.6418 .94127 m
.63809 .94224 L
s
1 .362 0 r
.008 w
.63809 .94224 Mdot
.016 w
.63809 .94224 m
.63415 .94322 L
s
1 .358 0 r
.008 w
.63415 .94322 Mdot
.016 w
.63415 .94322 m
.63044 .94412 L
s
1 .354 0 r
.008 w
.63044 .94412 Mdot
.016 w
.63044 .94412 m
.6265 .94496 L
s
1 .35 0 r
.008 w
.6265 .94496 Mdot
.016 w
.6265 .94496 m
.62301 .94572 L
s
1 .346 0 r
.008 w
.62301 .94572 Mdot
.016 w
.62301 .94572 m
.61935 .94646 L
s
1 .341 0 r
.008 w
.61935 .94646 Mdot
.016 w
.61935 .94646 m
.61592 .94709 L
s
1 .337 0 r
.008 w
.61592 .94709 Mdot
.016 w
.61592 .94709 m
.6128 .94765 L
s
1 .333 0 r
.008 w
.6128 .94765 Mdot
.016 w
.6128 .94765 m
.60952 .94807 L
s
1 .329 0 r
.008 w
.60952 .94807 Mdot
.016 w
.60952 .94807 m
.60637 .94836 L
s
1 .325 0 r
.008 w
.60637 .94836 Mdot
.016 w
.60637 .94836 m
.60325 .94849 L
s
1 .321 0 r
.008 w
.60325 .94849 Mdot
.016 w
.60325 .94849 m
.60011 .94859 L
s
1 .317 0 r
.008 w
.60011 .94859 Mdot
.016 w
.60011 .94859 m
.59719 .94869 L
s
1 .313 0 r
.008 w
.59719 .94869 Mdot
.016 w
.59719 .94869 m
.59405 .94881 L
s
1 .309 0 r
.008 w
.59405 .94881 Mdot
.016 w
.59405 .94881 m
.59111 .94889 L
s
1 .305 0 r
.008 w
.59111 .94889 Mdot
.016 w
.59111 .94889 m
.5879 .94902 L
s
1 .301 0 r
.008 w
.5879 .94902 Mdot
.016 w
.5879 .94902 m
.58464 .94924 L
s
1 .297 0 r
.008 w
.58464 .94924 Mdot
.016 w
.58464 .94924 m
.58097 .94959 L
s
1 .293 0 r
.008 w
.58097 .94959 Mdot
.016 w
.58097 .94959 m
.57748 .95001 L
s
1 .289 0 r
.008 w
.57748 .95001 Mdot
.016 w
.57748 .95001 m
.5737 .95052 L
s
1 .285 0 r
.008 w
.5737 .95052 Mdot
.016 w
.5737 .95052 m
.56945 .9511 L
s
1 .28 0 r
.008 w
.56945 .9511 Mdot
.016 w
.56945 .9511 m
.56576 .95172 L
s
1 .276 0 r
.008 w
.56576 .95172 Mdot
.016 w
.56576 .95172 m
.56162 .95249 L
s
1 .272 0 r
.008 w
.56162 .95249 Mdot
.016 w
.56162 .95249 m
.55779 .95335 L
s
1 .268 0 r
.008 w
.55779 .95335 Mdot
.016 w
.55779 .95335 m
.55372 .95426 L
s
1 .264 0 r
.008 w
.55372 .95426 Mdot
.016 w
.55372 .95426 m
.54998 .9551 L
s
1 .26 0 r
.008 w
.54998 .9551 Mdot
.016 w
.54998 .9551 m
.54616 .95584 L
s
1 .256 0 r
.008 w
.54616 .95584 Mdot
.016 w
.54616 .95584 m
.54233 .95646 L
s
1 .252 0 r
.008 w
.54233 .95646 Mdot
.016 w
.54233 .95646 m
.53887 .95694 L
s
1 .248 0 r
.008 w
.53887 .95694 Mdot
.016 w
.53887 .95694 m
.53545 .95732 L
s
1 .244 0 r
.008 w
.53545 .95732 Mdot
.016 w
.53545 .95732 m
.53219 .9576 L
s
1 .24 0 r
.008 w
.53219 .9576 Mdot
.016 w
.53219 .9576 m
.5292 .95782 L
s
1 .236 0 r
.008 w
.5292 .95782 Mdot
.016 w
.5292 .95782 m
.52645 .95805 L
s
1 .232 0 r
.008 w
.52645 .95805 Mdot
.016 w
.52645 .95805 m
.52404 .95835 L
s
1 .228 0 r
.008 w
.52404 .95835 Mdot
.016 w
.52404 .95835 m
.52211 .95874 L
s
1 .224 0 r
.008 w
.52211 .95874 Mdot
.016 w
.52211 .95874 m
.52016 .95917 L
s
1 .22 0 r
.008 w
.52016 .95917 Mdot
.016 w
.52016 .95917 m
.51855 .95962 L
s
1 .215 0 r
.008 w
.51855 .95962 Mdot
.016 w
.51855 .95962 m
.51704 .96007 L
s
1 .211 0 r
.008 w
.51704 .96007 Mdot
.016 w
.51704 .96007 m
.51571 .9605 L
s
1 .207 0 r
.008 w
.51571 .9605 Mdot
.016 w
.51571 .9605 m
.51459 .96086 L
s
1 .203 0 r
.008 w
.51459 .96086 Mdot
.016 w
.51459 .96086 m
.51368 .96116 L
s
1 .199 0 r
.008 w
.51368 .96116 Mdot
.016 w
.51368 .96116 m
.51301 .96136 L
s
1 .195 0 r
.008 w
.51301 .96136 Mdot
.016 w
.51301 .96136 m
.51253 .96141 L
s
1 .191 0 r
.008 w
.51253 .96141 Mdot
.016 w
.51253 .96141 m
.51222 .96136 L
s
1 .187 0 r
.008 w
.51222 .96136 Mdot
.016 w
.51222 .96136 m
.51206 .96122 L
s
1 .183 0 r
.008 w
.51206 .96122 Mdot
.016 w
.51206 .96122 m
.512 .96097 L
s
1 .179 0 r
.008 w
.512 .96097 Mdot
.016 w
.512 .96097 m
.51195 .96064 L
s
1 .175 0 r
.008 w
.51195 .96064 Mdot
.016 w
.51195 .96064 m
.51185 .9602 L
s
1 .171 0 r
.008 w
.51185 .9602 Mdot
.016 w
.51185 .9602 m
.5117 .95967 L
s
1 .167 0 r
.008 w
.5117 .95967 Mdot
.016 w
.5117 .95967 m
.51149 .95912 L
s
1 .163 0 r
.008 w
.51149 .95912 Mdot
.016 w
.51149 .95912 m
.51123 .95861 L
s
1 .159 0 r
.008 w
.51123 .95861 Mdot
.016 w
.51123 .95861 m
.51094 .9582 L
s
1 .154 0 r
.008 w
.51094 .9582 Mdot
.016 w
.51094 .9582 m
.51063 .95796 L
s
1 .15 0 r
.008 w
.51063 .95796 Mdot
.016 w
.51063 .95796 m
.51033 .9579 L
s
1 .146 0 r
.008 w
.51033 .9579 Mdot
.016 w
.51033 .9579 m
.51002 .95799 L
s
1 .142 0 r
.008 w
.51002 .95799 Mdot
.016 w
.51002 .95799 m
.50971 .95819 L
s
1 .138 0 r
.008 w
.50971 .95819 Mdot
.016 w
.50971 .95819 m
.50939 .95846 L
s
1 .134 0 r
.008 w
.50939 .95846 Mdot
.016 w
.50939 .95846 m
.50909 .95873 L
s
1 .13 0 r
.008 w
.50909 .95873 Mdot
.016 w
.50909 .95873 m
.50875 .95897 L
s
1 .126 0 r
.008 w
.50875 .95897 Mdot
.016 w
.50875 .95897 m
.50843 .95916 L
s
1 .122 0 r
.008 w
.50843 .95916 Mdot
.016 w
.50843 .95916 m
.50814 .95932 L
s
1 .118 0 r
.008 w
.50814 .95932 Mdot
.016 w
.50814 .95932 m
.50784 .95947 L
s
1 .114 0 r
.008 w
.50784 .95947 Mdot
.016 w
.50784 .95947 m
.50752 .95957 L
s
1 .11 0 r
.008 w
.50752 .95957 Mdot
.016 w
.50752 .95957 m
.50722 .95962 L
s
1 .106 0 r
.008 w
.50722 .95962 Mdot
.016 w
.50722 .95962 m
.50688 .95963 L
s
1 .102 0 r
.008 w
.50688 .95963 Mdot
.016 w
.50688 .95963 m
.50645 .95959 L
s
1 .098 0 r
.008 w
.50645 .95959 Mdot
.016 w
.50645 .95959 m
.50588 .95951 L
s
1 .093 0 r
.008 w
.50588 .95951 Mdot
.016 w
.50588 .95951 m
.50517 .95937 L
s
1 .089 0 r
.008 w
.50517 .95937 Mdot
.016 w
.50517 .95937 m
.50437 .95918 L
s
1 .085 0 r
.008 w
.50437 .95918 Mdot
.016 w
.50437 .95918 m
.5034 .95895 L
s
1 .081 0 r
.008 w
.5034 .95895 Mdot
.016 w
.5034 .95895 m
.50229 .95869 L
s
1 .077 0 r
.008 w
.50229 .95869 Mdot
.016 w
.50229 .95869 m
.50111 .95839 L
s
1 .073 0 r
.008 w
.50111 .95839 Mdot
.016 w
.50111 .95839 m
.4999 .95806 L
s
1 .069 0 r
.008 w
.4999 .95806 Mdot
.016 w
.4999 .95806 m
.49874 .95772 L
s
1 .065 0 r
.008 w
.49874 .95772 Mdot
.016 w
.49874 .95772 m
.49762 .95736 L
s
1 .061 0 r
.008 w
.49762 .95736 Mdot
.016 w
.49762 .95736 m
.49655 .95698 L
s
1 .057 0 r
.008 w
.49655 .95698 Mdot
.016 w
.49655 .95698 m
.49569 .95665 L
s
1 .053 0 r
.008 w
.49569 .95665 Mdot
.016 w
.49569 .95665 m
.49489 .95633 L
s
1 .049 0 r
.008 w
.49489 .95633 Mdot
.016 w
.49489 .95633 m
.49424 .95598 L
s
1 .045 0 r
.008 w
.49424 .95598 Mdot
.016 w
.49424 .95598 m
.4938 .95565 L
s
1 .041 0 r
.008 w
.4938 .95565 Mdot
.016 w
.4938 .95565 m
.49359 .95539 L
s
1 .037 0 r
.008 w
.49359 .95539 Mdot
.016 w
.49359 .95539 m
.49363 .95523 L
s
1 .033 0 r
.008 w
.49363 .95523 Mdot
.016 w
.49363 .95523 m
.49388 .9552 L
s
1 .028 0 r
.008 w
.49388 .9552 Mdot
.016 w
.49388 .9552 m
.49428 .95523 L
s
1 .024 0 r
.008 w
.49428 .95523 Mdot
.016 w
.49428 .95523 m
.4948 .95533 L
s
1 .02 0 r
.008 w
.4948 .95533 Mdot
.016 w
.4948 .95533 m
.49533 .95547 L
s
1 .016 0 r
.008 w
.49533 .95547 Mdot
.016 w
.49533 .95547 m
.49578 .95564 L
s
1 .012 0 r
.008 w
.49578 .95564 Mdot
.016 w
.49578 .95564 m
.49609 .9558 L
s
1 .008 0 r
.008 w
.49609 .9558 Mdot
.016 w
.49609 .9558 m
.49625 .95585 L
s
1 .004 0 r
.008 w
.49625 .95585 Mdot
.016 w
.49625 .95585 m
.49628 .95589 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(72)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
1 .997 0 r
.008 w
.4968 .95772 Mdot
.016 w
.4968 .95772 m
.49682 .95764 L
s
1 .994 0 r
.008 w
.49682 .95764 Mdot
.016 w
.49682 .95764 m
.497 .95755 L
s
1 .991 0 r
.008 w
.497 .95755 Mdot
.016 w
.497 .95755 m
.49732 .95754 L
s
1 .987 0 r
.008 w
.49732 .95754 Mdot
.016 w
.49732 .95754 m
.49775 .95761 L
s
1 .984 0 r
.008 w
.49775 .95761 Mdot
.016 w
.49775 .95761 m
.49817 .95768 L
s
1 .981 0 r
.008 w
.49817 .95768 Mdot
.016 w
.49817 .95768 m
.4985 .95781 L
s
1 .978 0 r
.008 w
.4985 .95781 Mdot
.016 w
.4985 .95781 m
.49853 .95802 L
s
1 .975 0 r
.008 w
.49853 .95802 Mdot
.016 w
.49853 .95802 m
.49818 .9583 L
s
1 .972 0 r
.008 w
.49818 .9583 Mdot
.016 w
.49818 .9583 m
.49744 .95864 L
s
1 .968 0 r
.008 w
.49744 .95864 Mdot
.016 w
.49744 .95864 m
.4964 .9591 L
s
1 .965 0 r
.008 w
.4964 .9591 Mdot
.016 w
.4964 .9591 m
.49502 .95965 L
s
1 .962 0 r
.008 w
.49502 .95965 Mdot
.016 w
.49502 .95965 m
.49344 .9603 L
s
1 .959 0 r
.008 w
.49344 .9603 Mdot
.016 w
.49344 .9603 m
.49156 .96084 L
s
1 .956 0 r
.008 w
.49156 .96084 Mdot
.016 w
.49156 .96084 m
.48951 .96139 L
s
1 .953 0 r
.008 w
.48951 .96139 Mdot
.016 w
.48951 .96139 m
.48741 .96196 L
s
1 .95 0 r
.008 w
.48741 .96196 Mdot
.016 w
.48741 .96196 m
.48504 .96251 L
s
1 .946 0 r
.008 w
.48504 .96251 Mdot
.016 w
.48504 .96251 m
.48234 .96291 L
s
1 .943 0 r
.008 w
.48234 .96291 Mdot
.016 w
.48234 .96291 m
.47988 .96326 L
s
1 .94 0 r
.008 w
.47988 .96326 Mdot
.016 w
.47988 .96326 m
.47752 .96358 L
s
1 .937 0 r
.008 w
.47752 .96358 Mdot
.016 w
.47752 .96358 m
.47529 .96389 L
s
1 .934 0 r
.008 w
.47529 .96389 Mdot
.016 w
.47529 .96389 m
.47335 .96422 L
s
1 .931 0 r
.008 w
.47335 .96422 Mdot
.016 w
.47335 .96422 m
.47179 .96458 L
s
1 .927 0 r
.008 w
.47179 .96458 Mdot
.016 w
.47179 .96458 m
.47064 .96498 L
s
1 .924 0 r
.008 w
.47064 .96498 Mdot
.016 w
.47064 .96498 m
.46972 .96532 L
s
1 .921 0 r
.008 w
.46972 .96532 Mdot
.016 w
.46972 .96532 m
.46896 .96559 L
s
1 .918 0 r
.008 w
.46896 .96559 Mdot
.016 w
.46896 .96559 m
.46829 .96577 L
s
1 .915 0 r
.008 w
.46829 .96577 Mdot
.016 w
.46829 .96577 m
.46766 .96583 L
s
1 .912 0 r
.008 w
.46766 .96583 Mdot
.016 w
.46766 .96583 m
.467 .96574 L
s
1 .909 0 r
.008 w
.467 .96574 Mdot
.016 w
.467 .96574 m
.46627 .96551 L
s
1 .905 0 r
.008 w
.46627 .96551 Mdot
.016 w
.46627 .96551 m
.46544 .96516 L
s
1 .902 0 r
.008 w
.46544 .96516 Mdot
.016 w
.46544 .96516 m
.46464 .9647 L
s
1 .899 0 r
.008 w
.46464 .9647 Mdot
.016 w
.46464 .9647 m
.46373 .96413 L
s
1 .896 0 r
.008 w
.46373 .96413 Mdot
.016 w
.46373 .96413 m
.46277 .96349 L
s
1 .893 0 r
.008 w
.46277 .96349 Mdot
.016 w
.46277 .96349 m
.46171 .96279 L
s
1 .89 0 r
.008 w
.46171 .96279 Mdot
.016 w
.46171 .96279 m
.46057 .96208 L
s
1 .886 0 r
.008 w
.46057 .96208 Mdot
.016 w
.46057 .96208 m
.45927 .96139 L
s
1 .883 0 r
.008 w
.45927 .96139 Mdot
.016 w
.45927 .96139 m
.45783 .96071 L
s
1 .88 0 r
.008 w
.45783 .96071 Mdot
.016 w
.45783 .96071 m
.45627 .96 L
s
1 .877 0 r
.008 w
.45627 .96 Mdot
.016 w
.45627 .96 m
.45474 .95942 L
s
1 .874 0 r
.008 w
.45474 .95942 Mdot
.016 w
.45474 .95942 m
.45316 .95884 L
s
1 .871 0 r
.008 w
.45316 .95884 Mdot
.016 w
.45316 .95884 m
.45168 .95837 L
s
1 .868 0 r
.008 w
.45168 .95837 Mdot
.016 w
.45168 .95837 m
.45033 .95807 L
s
1 .864 0 r
.008 w
.45033 .95807 Mdot
.016 w
.45033 .95807 m
.44914 .95793 L
s
1 .861 0 r
.008 w
.44914 .95793 Mdot
.016 w
.44914 .95793 m
.44806 .95793 L
s
1 .858 0 r
.008 w
.44806 .95793 Mdot
.016 w
.44806 .95793 m
.44703 .95797 L
s
1 .855 0 r
.008 w
.44703 .95797 Mdot
.016 w
.44703 .95797 m
.44593 .95796 L
s
1 .852 0 r
.008 w
.44593 .95796 Mdot
.016 w
.44593 .95796 m
.44477 .95788 L
s
1 .849 0 r
.008 w
.44477 .95788 Mdot
.016 w
.44477 .95788 m
.44346 .95772 L
s
1 .845 0 r
.008 w
.44346 .95772 Mdot
.016 w
.44346 .95772 m
.44185 .95749 L
s
1 .842 0 r
.008 w
.44185 .95749 Mdot
.016 w
.44185 .95749 m
.44027 .95723 L
s
1 .839 0 r
.008 w
.44027 .95723 Mdot
.016 w
.44027 .95723 m
.43843 .9569 L
s
1 .836 0 r
.008 w
.43843 .9569 Mdot
.016 w
.43843 .9569 m
.4363 .95653 L
s
1 .833 0 r
.008 w
.4363 .95653 Mdot
.016 w
.4363 .95653 m
.43394 .95602 L
s
1 .83 0 r
.008 w
.43394 .95602 Mdot
.016 w
.43394 .95602 m
.4316 .95542 L
s
1 .826 0 r
.008 w
.4316 .95542 Mdot
.016 w
.4316 .95542 m
.42907 .95473 L
s
1 .823 0 r
.008 w
.42907 .95473 Mdot
.016 w
.42907 .95473 m
.42626 .9539 L
s
1 .82 0 r
.008 w
.42626 .9539 Mdot
.016 w
.42626 .9539 m
.42289 .95309 L
s
1 .817 0 r
.008 w
.42289 .95309 Mdot
.016 w
.42289 .95309 m
.41986 .95218 L
s
1 .814 0 r
.008 w
.41986 .95218 Mdot
.016 w
.41986 .95218 m
.41636 .95115 L
s
1 .811 0 r
.008 w
.41636 .95115 Mdot
.016 w
.41636 .95115 m
.41291 .95019 L
s
1 .808 0 r
.008 w
.41291 .95019 Mdot
.016 w
.41291 .95019 m
.4092 .94919 L
s
1 .804 0 r
.008 w
.4092 .94919 Mdot
.016 w
.4092 .94919 m
.40526 .94821 L
s
1 .801 0 r
.008 w
.40526 .94821 Mdot
.016 w
.40526 .94821 m
.40175 .9472 L
s
1 .798 0 r
.008 w
.40175 .9472 Mdot
.016 w
.40175 .9472 m
.39779 .94622 L
s
1 .795 0 r
.008 w
.39779 .94622 Mdot
.016 w
.39779 .94622 m
.39402 .94515 L
s
1 .792 0 r
.008 w
.39402 .94515 Mdot
.016 w
.39402 .94515 m
.38991 .94397 L
s
1 .789 0 r
.008 w
.38991 .94397 Mdot
.016 w
.38991 .94397 m
.38574 .94269 L
s
1 .785 0 r
.008 w
.38574 .94269 Mdot
.016 w
.38574 .94269 m
.38198 .94138 L
s
1 .782 0 r
.008 w
.38198 .94138 Mdot
.016 w
.38198 .94138 m
.37798 .93999 L
s
1 .779 0 r
.008 w
.37798 .93999 Mdot
.016 w
.37798 .93999 m
.37405 .93854 L
s
1 .776 0 r
.008 w
.37405 .93854 Mdot
.016 w
.37405 .93854 m
.36999 .93712 L
s
1 .773 0 r
.008 w
.36999 .93712 Mdot
.016 w
.36999 .93712 m
.3664 .93568 L
s
1 .77 0 r
.008 w
.3664 .93568 Mdot
.016 w
.3664 .93568 m
.36266 .93423 L
s
1 .767 0 r
.008 w
.36266 .93423 Mdot
.016 w
.36266 .93423 m
.35895 .93284 L
s
1 .763 0 r
.008 w
.35895 .93284 Mdot
.016 w
.35895 .93284 m
.35535 .93144 L
s
1 .76 0 r
.008 w
.35535 .93144 Mdot
.016 w
.35535 .93144 m
.35181 .93006 L
s
1 .757 0 r
.008 w
.35181 .93006 Mdot
.016 w
.35181 .93006 m
.34811 .92867 L
s
1 .754 0 r
.008 w
.34811 .92867 Mdot
.016 w
.34811 .92867 m
.34452 .92731 L
s
1 .751 0 r
.008 w
.34452 .92731 Mdot
.016 w
.34452 .92731 m
.34113 .92598 L
s
1 .748 0 r
.008 w
.34113 .92598 Mdot
.016 w
.34113 .92598 m
.33751 .92465 L
s
1 .744 0 r
.008 w
.33751 .92465 Mdot
.016 w
.33751 .92465 m
.33396 .92337 L
s
1 .741 0 r
.008 w
.33396 .92337 Mdot
.016 w
.33396 .92337 m
.33016 .92216 L
s
1 .738 0 r
.008 w
.33016 .92216 Mdot
.016 w
.33016 .92216 m
.32675 .92099 L
s
1 .735 0 r
.008 w
.32675 .92099 Mdot
.016 w
.32675 .92099 m
.32316 .91988 L
s
1 .732 0 r
.008 w
.32316 .91988 Mdot
.016 w
.32316 .91988 m
.31946 .91882 L
s
1 .729 0 r
.008 w
.31946 .91882 Mdot
.016 w
.31946 .91882 m
.31611 .91781 L
s
1 .726 0 r
.008 w
.31611 .91781 Mdot
.016 w
.31611 .91781 m
.31286 .91683 L
s
1 .722 0 r
.008 w
.31286 .91683 Mdot
.016 w
.31286 .91683 m
.30948 .91586 L
s
1 .719 0 r
.008 w
.30948 .91586 Mdot
.016 w
.30948 .91586 m
.30623 .91486 L
s
1 .716 0 r
.008 w
.30623 .91486 Mdot
.016 w
.30623 .91486 m
.30289 .91386 L
s
1 .713 0 r
.008 w
.30289 .91386 Mdot
.016 w
.30289 .91386 m
.29969 .91282 L
s
1 .71 0 r
.008 w
.29969 .91282 Mdot
.016 w
.29969 .91282 m
.29639 .9117 L
s
1 .707 0 r
.008 w
.29639 .9117 Mdot
.016 w
.29639 .9117 m
.29311 .9105 L
s
1 .703 0 r
.008 w
.29311 .9105 Mdot
.016 w
.29311 .9105 m
.29022 .90921 L
s
1 .7 0 r
.008 w
.29022 .90921 Mdot
.016 w
.29022 .90921 m
.28712 .90785 L
s
1 .697 0 r
.008 w
.28712 .90785 Mdot
.016 w
.28712 .90785 m
.28418 .90652 L
s
1 .694 0 r
.008 w
.28418 .90652 Mdot
.016 w
.28418 .90652 m
.2812 .90514 L
s
1 .691 0 r
.008 w
.2812 .90514 Mdot
.016 w
.2812 .90514 m
.27837 .90376 L
s
1 .688 0 r
.008 w
.27837 .90376 Mdot
.016 w
.27837 .90376 m
.27567 .90242 L
s
1 .685 0 r
.008 w
.27567 .90242 Mdot
.016 w
.27567 .90242 m
.27293 .90109 L
s
1 .681 0 r
.008 w
.27293 .90109 Mdot
.016 w
.27293 .90109 m
.27039 .89978 L
s
1 .678 0 r
.008 w
.27039 .89978 Mdot
.016 w
.27039 .89978 m
.26783 .89848 L
s
1 .675 0 r
.008 w
.26783 .89848 Mdot
.016 w
.26783 .89848 m
.26554 .8972 L
s
1 .672 0 r
.008 w
.26554 .8972 Mdot
.016 w
.26554 .8972 m
.26334 .89598 L
s
1 .669 0 r
.008 w
.26334 .89598 Mdot
.016 w
.26334 .89598 m
.26132 .89481 L
s
1 .666 0 r
.008 w
.26132 .89481 Mdot
.016 w
.26132 .89481 m
.25954 .8937 L
s
1 .662 0 r
.008 w
.25954 .8937 Mdot
.016 w
.25954 .8937 m
.25799 .89264 L
s
1 .659 0 r
.008 w
.25799 .89264 Mdot
.016 w
.25799 .89264 m
.25671 .89171 L
s
1 .656 0 r
.008 w
.25671 .89171 Mdot
.016 w
.25671 .89171 m
.25569 .89081 L
s
1 .653 0 r
.008 w
.25569 .89081 Mdot
.016 w
.25569 .89081 m
.25489 .89001 L
s
1 .65 0 r
.008 w
.25489 .89001 Mdot
.016 w
.25489 .89001 m
.25434 .88931 L
s
1 .647 0 r
.008 w
.25434 .88931 Mdot
.016 w
.25434 .88931 m
.254 .88875 L
s
1 .644 0 r
.008 w
.254 .88875 Mdot
.016 w
.254 .88875 m
.25383 .8883 L
s
1 .64 0 r
.008 w
.25383 .8883 Mdot
.016 w
.25383 .8883 m
.25374 .8879 L
s
1 .637 0 r
.008 w
.25374 .8879 Mdot
.016 w
.25374 .8879 m
.25367 .88758 L
s
1 .634 0 r
.008 w
.25367 .88758 Mdot
.016 w
.25367 .88758 m
.25351 .88726 L
s
1 .631 0 r
.008 w
.25351 .88726 Mdot
.016 w
.25351 .88726 m
.2532 .88694 L
s
1 .628 0 r
.008 w
.2532 .88694 Mdot
.016 w
.2532 .88694 m
.25268 .88659 L
s
1 .625 0 r
.008 w
.25268 .88659 Mdot
.016 w
.25268 .88659 m
.25194 .88618 L
s
1 .621 0 r
.008 w
.25194 .88618 Mdot
.016 w
.25194 .88618 m
.25088 .88553 L
s
1 .618 0 r
.008 w
.25088 .88553 Mdot
.016 w
.25088 .88553 m
.24946 .88461 L
s
1 .615 0 r
.008 w
.24946 .88461 Mdot
.016 w
.24946 .88461 m
.24763 .88338 L
s
1 .612 0 r
.008 w
.24763 .88338 Mdot
.016 w
.24763 .88338 m
.24546 .88188 L
s
1 .609 0 r
.008 w
.24546 .88188 Mdot
.016 w
.24546 .88188 m
.243 .88009 L
s
1 .606 0 r
.008 w
.243 .88009 Mdot
.016 w
.243 .88009 m
.24014 .87792 L
s
1 .603 0 r
.008 w
.24014 .87792 Mdot
.016 w
.24014 .87792 m
.23704 .87557 L
s
1 .599 0 r
.008 w
.23704 .87557 Mdot
.016 w
.23704 .87557 m
.23376 .87299 L
s
1 .596 0 r
.008 w
.23376 .87299 Mdot
.016 w
.23376 .87299 m
.23027 .87017 L
s
1 .593 0 r
.008 w
.23027 .87017 Mdot
.016 w
.23027 .87017 m
.2269 .86741 L
s
1 .59 0 r
.008 w
.2269 .86741 Mdot
.016 w
.2269 .86741 m
.22342 .86447 L
s
1 .587 0 r
.008 w
.22342 .86447 Mdot
.016 w
.22342 .86447 m
.22008 .86148 L
s
1 .584 0 r
.008 w
.22008 .86148 Mdot
.016 w
.22008 .86148 m
.21679 .85882 L
s
1 .58 0 r
.008 w
.21679 .85882 Mdot
.016 w
.21679 .85882 m
.21358 .85599 L
s
1 .577 0 r
.008 w
.21358 .85599 Mdot
.016 w
.21358 .85599 m
.21055 .85318 L
s
1 .574 0 r
.008 w
.21055 .85318 Mdot
.016 w
.21055 .85318 m
.20758 .85041 L
s
1 .571 0 r
.008 w
.20758 .85041 Mdot
.016 w
.20758 .85041 m
.20474 .84765 L
s
1 .568 0 r
.008 w
.20474 .84765 Mdot
.016 w
.20474 .84765 m
.20196 .84507 L
s
1 .565 0 r
.008 w
.20196 .84507 Mdot
.016 w
.20196 .84507 m
.19926 .84244 L
s
1 .562 0 r
.008 w
.19926 .84244 Mdot
.016 w
.19926 .84244 m
.19661 .83993 L
s
1 .558 0 r
.008 w
.19661 .83993 Mdot
.016 w
.19661 .83993 m
.19399 .83738 L
s
1 .555 0 r
.008 w
.19399 .83738 Mdot
.016 w
.19399 .83738 m
.19131 .83471 L
s
1 .552 0 r
.008 w
.19131 .83471 Mdot
.016 w
.19131 .83471 m
.18869 .8321 L
s
1 .549 0 r
.008 w
.18869 .8321 Mdot
.016 w
.18869 .8321 m
.18614 .82958 L
s
1 .546 0 r
.008 w
.18614 .82958 Mdot
.016 w
.18614 .82958 m
.18368 .82699 L
s
1 .543 0 r
.008 w
.18368 .82699 Mdot
.016 w
.18368 .82699 m
.18136 .82445 L
s
1 .539 0 r
.008 w
.18136 .82445 Mdot
.016 w
.18136 .82445 m
.17913 .82212 L
s
1 .536 0 r
.008 w
.17913 .82212 Mdot
.016 w
.17913 .82212 m
.17715 .81985 L
s
1 .533 0 r
.008 w
.17715 .81985 Mdot
.016 w
.17715 .81985 m
.17523 .81774 L
s
1 .53 0 r
.008 w
.17523 .81774 Mdot
.016 w
.17523 .81774 m
.17373 .81587 L
s
1 .527 0 r
.008 w
.17373 .81587 Mdot
.016 w
.17373 .81587 m
.17241 .81411 L
s
1 .524 0 r
.008 w
.17241 .81411 Mdot
.016 w
.17241 .81411 m
.1713 .8125 L
s
1 .521 0 r
.008 w
.1713 .8125 Mdot
.016 w
.1713 .8125 m
.17041 .81112 L
s
1 .517 0 r
.008 w
.17041 .81112 Mdot
.016 w
.17041 .81112 m
.16965 .80986 L
s
1 .514 0 r
.008 w
.16965 .80986 Mdot
.016 w
.16965 .80986 m
.16899 .80871 L
s
1 .511 0 r
.008 w
.16899 .80871 Mdot
.016 w
.16899 .80871 m
.1683 .80763 L
s
1 .508 0 r
.008 w
.1683 .80763 Mdot
.016 w
.1683 .80763 m
.16751 .80659 L
s
1 .505 0 r
.008 w
.16751 .80659 Mdot
.016 w
.16751 .80659 m
.16656 .80551 L
s
1 .502 0 r
.008 w
.16656 .80551 Mdot
.016 w
.16656 .80551 m
.16536 .80434 L
s
1 .498 0 r
.008 w
.16536 .80434 Mdot
.016 w
.16536 .80434 m
.16393 .80302 L
s
1 .495 0 r
.008 w
.16393 .80302 Mdot
.016 w
.16393 .80302 m
.16216 .80149 L
s
1 .492 0 r
.008 w
.16216 .80149 Mdot
.016 w
.16216 .80149 m
.16001 .79969 L
s
1 .489 0 r
.008 w
.16001 .79969 Mdot
.016 w
.16001 .79969 m
.15801 .79778 L
s
1 .486 0 r
.008 w
.15801 .79778 Mdot
.016 w
.15801 .79778 m
.15564 .79561 L
s
1 .483 0 r
.008 w
.15564 .79561 Mdot
.016 w
.15564 .79561 m
.1529 .79337 L
s
1 .479 0 r
.008 w
.1529 .79337 Mdot
.016 w
.1529 .79337 m
.15054 .79107 L
s
1 .476 0 r
.008 w
.15054 .79107 Mdot
.016 w
.15054 .79107 m
.1479 .7886 L
s
1 .473 0 r
.008 w
.1479 .7886 Mdot
.016 w
.1479 .7886 m
.1451 .78602 L
s
1 .47 0 r
.008 w
.1451 .78602 Mdot
.016 w
.1451 .78602 m
.1427 .78364 L
s
1 .467 0 r
.008 w
.1427 .78364 Mdot
.016 w
.1427 .78364 m
.14006 .7811 L
s
1 .464 0 r
.008 w
.14006 .7811 Mdot
.016 w
.14006 .7811 m
.13736 .77845 L
s
1 .461 0 r
.008 w
.13736 .77845 Mdot
.016 w
.13736 .77845 m
.13506 .77581 L
s
1 .457 0 r
.008 w
.13506 .77581 Mdot
.016 w
.13506 .77581 m
.13267 .77323 L
s
1 .454 0 r
.008 w
.13267 .77323 Mdot
.016 w
.13267 .77323 m
.13026 .77062 L
s
1 .451 0 r
.008 w
.13026 .77062 Mdot
.016 w
.13026 .77062 m
.12824 .76828 L
s
1 .448 0 r
.008 w
.12824 .76828 Mdot
.016 w
.12824 .76828 m
.12613 .76593 L
s
1 .445 0 r
.008 w
.12613 .76593 Mdot
.016 w
.12613 .76593 m
.12404 .76363 L
s
1 .442 0 r
.008 w
.12404 .76363 Mdot
.016 w
.12404 .76363 m
.12207 .76139 L
s
1 .438 0 r
.008 w
.12207 .76139 Mdot
.016 w
.12207 .76139 m
.12011 .75921 L
s
1 .435 0 r
.008 w
.12011 .75921 Mdot
.016 w
.12011 .75921 m
.11823 .75705 L
s
1 .432 0 r
.008 w
.11823 .75705 Mdot
.016 w
.11823 .75705 m
.11656 .75521 L
s
1 .429 0 r
.008 w
.11656 .75521 Mdot
.016 w
.11656 .75521 m
.11496 .7535 L
s
1 .426 0 r
.008 w
.11496 .7535 Mdot
.016 w
.11496 .7535 m
.1135 .75193 L
s
1 .423 0 r
.008 w
.1135 .75193 Mdot
.016 w
.1135 .75193 m
.11222 .75054 L
s
1 .42 0 r
.008 w
.11222 .75054 Mdot
.016 w
.11222 .75054 m
.11123 .74938 L
s
1 .416 0 r
.008 w
.11123 .74938 Mdot
.016 w
.11123 .74938 m
.11031 .74835 L
s
1 .413 0 r
.008 w
.11031 .74835 Mdot
.016 w
.11031 .74835 m
.10955 .74742 L
s
1 .41 0 r
.008 w
.10955 .74742 Mdot
.016 w
.10955 .74742 m
.10885 .74644 L
s
1 .407 0 r
.008 w
.10885 .74644 Mdot
.016 w
.10885 .74644 m
.10818 .74535 L
s
1 .404 0 r
.008 w
.10818 .74535 Mdot
.016 w
.10818 .74535 m
.10753 .74415 L
s
1 .401 0 r
.008 w
.10753 .74415 Mdot
.016 w
.10753 .74415 m
.1069 .74283 L
s
1 .397 0 r
.008 w
.1069 .74283 Mdot
.016 w
.1069 .74283 m
.10629 .74137 L
s
1 .394 0 r
.008 w
.10629 .74137 Mdot
.016 w
.10629 .74137 m
.10574 .73994 L
s
1 .391 0 r
.008 w
.10574 .73994 Mdot
.016 w
.10574 .73994 m
.10529 .73838 L
s
1 .388 0 r
.008 w
.10529 .73838 Mdot
.016 w
.10529 .73838 m
.10489 .73687 L
s
1 .385 0 r
.008 w
.10489 .73687 Mdot
.016 w
.10489 .73687 m
.10456 .73547 L
s
1 .382 0 r
.008 w
.10456 .73547 Mdot
.016 w
.10456 .73547 m
.10426 .73418 L
s
1 .379 0 r
.008 w
.10426 .73418 Mdot
.016 w
.10426 .73418 m
.10396 .7328 L
s
1 .375 0 r
.008 w
.10396 .7328 Mdot
.016 w
.10396 .7328 m
.10367 .73155 L
s
1 .372 0 r
.008 w
.10367 .73155 Mdot
.016 w
.10367 .73155 m
.10338 .73033 L
s
1 .369 0 r
.008 w
.10338 .73033 Mdot
.016 w
.10338 .73033 m
.1031 .72913 L
s
1 .366 0 r
.008 w
.1031 .72913 Mdot
.016 w
.1031 .72913 m
.1028 .72791 L
s
1 .363 0 r
.008 w
.1028 .72791 Mdot
.016 w
.1028 .72791 m
.10246 .72664 L
s
1 .36 0 r
.008 w
.10246 .72664 Mdot
.016 w
.10246 .72664 m
.10207 .72527 L
s
1 .356 0 r
.008 w
.10207 .72527 Mdot
.016 w
.10207 .72527 m
.10161 .72367 L
s
1 .353 0 r
.008 w
.10161 .72367 Mdot
.016 w
.10161 .72367 m
.10108 .72182 L
s
1 .35 0 r
.008 w
.10108 .72182 Mdot
.016 w
.10108 .72182 m
.10045 .7197 L
s
1 .347 0 r
.008 w
.10045 .7197 Mdot
.016 w
.10045 .7197 m
.09977 .71765 L
s
1 .344 0 r
.008 w
.09977 .71765 Mdot
.016 w
.09977 .71765 m
.09902 .71521 L
s
1 .341 0 r
.008 w
.09902 .71521 Mdot
.016 w
.09902 .71521 m
.0982 .71255 L
s
1 .338 0 r
.008 w
.0982 .71255 Mdot
.016 w
.0982 .71255 m
.09736 .70966 L
s
1 .334 0 r
.008 w
.09736 .70966 Mdot
.016 w
.09736 .70966 m
.09655 .70657 L
s
1 .331 0 r
.008 w
.09655 .70657 Mdot
.016 w
.09655 .70657 m
.09579 .70357 L
s
1 .328 0 r
.008 w
.09579 .70357 Mdot
.016 w
.09579 .70357 m
.09512 .70064 L
s
1 .325 0 r
.008 w
.09512 .70064 Mdot
.016 w
.09512 .70064 m
.09458 .69762 L
s
1 .322 0 r
.008 w
.09458 .69762 Mdot
.016 w
.09458 .69762 m
.09418 .69489 L
s
1 .319 0 r
.008 w
.09418 .69489 Mdot
.016 w
.09418 .69489 m
.09391 .6924 L
s
1 .315 0 r
.008 w
.09391 .6924 Mdot
.016 w
.09391 .6924 m
.09373 .68999 L
s
1 .312 0 r
.008 w
.09373 .68999 Mdot
.016 w
.09373 .68999 m
.0936 .68772 L
s
1 .309 0 r
.008 w
.0936 .68772 Mdot
.016 w
.0936 .68772 m
.09346 .68559 L
s
1 .306 0 r
.008 w
.09346 .68559 Mdot
.016 w
.09346 .68559 m
.0933 .68358 L
s
1 .303 0 r
.008 w
.0933 .68358 Mdot
.016 w
.0933 .68358 m
.0931 .68159 L
s
1 .3 0 r
.008 w
.0931 .68159 Mdot
.016 w
.0931 .68159 m
.09286 .67972 L
s
1 .297 0 r
.008 w
.09286 .67972 Mdot
.016 w
.09286 .67972 m
.09259 .67783 L
s
1 .293 0 r
.008 w
.09259 .67783 Mdot
.016 w
.09259 .67783 m
.09229 .67594 L
s
1 .29 0 r
.008 w
.09229 .67594 Mdot
.016 w
.09229 .67594 m
.09195 .67399 L
s
1 .287 0 r
.008 w
.09195 .67399 Mdot
.016 w
.09195 .67399 m
.09158 .67208 L
s
1 .284 0 r
.008 w
.09158 .67208 Mdot
.016 w
.09158 .67208 m
.09113 .66995 L
s
1 .281 0 r
.008 w
.09113 .66995 Mdot
.016 w
.09113 .66995 m
.09059 .66768 L
s
1 .278 0 r
.008 w
.09059 .66768 Mdot
.016 w
.09059 .66768 m
.08999 .66506 L
s
1 .274 0 r
.008 w
.08999 .66506 Mdot
.016 w
.08999 .66506 m
.0893 .66243 L
s
1 .271 0 r
.008 w
.0893 .66243 Mdot
.016 w
.0893 .66243 m
.08854 .65941 L
s
1 .268 0 r
.008 w
.08854 .65941 Mdot
.016 w
.08854 .65941 m
.08772 .65617 L
s
1 .265 0 r
.008 w
.08772 .65617 Mdot
.016 w
.08772 .65617 m
.08688 .65277 L
s
1 .262 0 r
.008 w
.08688 .65277 Mdot
.016 w
.08688 .65277 m
.08604 .64933 L
s
1 .259 0 r
.008 w
.08604 .64933 Mdot
.016 w
.08604 .64933 m
.08526 .64545 L
s
1 .256 0 r
.008 w
.08526 .64545 Mdot
.016 w
.08526 .64545 m
.08457 .642 L
s
1 .252 0 r
.008 w
.08457 .642 Mdot
.016 w
.08457 .642 m
.08395 .63837 L
s
1 .249 0 r
.008 w
.08395 .63837 Mdot
.016 w
.08395 .63837 m
.08338 .63465 L
s
1 .246 0 r
.008 w
.08338 .63465 Mdot
.016 w
.08338 .63465 m
.08288 .63157 L
s
1 .243 0 r
.008 w
.08288 .63157 Mdot
.016 w
.08288 .63157 m
.08242 .62851 L
s
1 .24 0 r
.008 w
.08242 .62851 Mdot
.016 w
.08242 .62851 m
.08202 .62575 L
s
1 .237 0 r
.008 w
.08202 .62575 Mdot
.016 w
.08202 .62575 m
.08169 .62341 L
s
1 .233 0 r
.008 w
.08169 .62341 Mdot
.016 w
.08169 .62341 m
.08141 .62137 L
s
1 .23 0 r
.008 w
.08141 .62137 Mdot
.016 w
.08141 .62137 m
.0812 .61985 L
s
1 .227 0 r
.008 w
.0812 .61985 Mdot
.016 w
.0812 .61985 m
.08104 .6187 L
s
1 .224 0 r
.008 w
.08104 .6187 Mdot
.016 w
.08104 .6187 m
.08095 .61787 L
s
1 .221 0 r
.008 w
.08095 .61787 Mdot
.016 w
.08095 .61787 m
.08091 .61734 L
s
1 .218 0 r
.008 w
.08091 .61734 Mdot
.016 w
.08091 .61734 m
.08096 .61705 L
s
1 .215 0 r
.008 w
.08096 .61705 Mdot
.016 w
.08096 .61705 m
.08098 .61694 L
s
1 .211 0 r
.008 w
.08098 .61694 Mdot
.016 w
.08098 .61694 m
.08103 .61696 L
s
1 .208 0 r
.008 w
.08103 .61696 Mdot
.016 w
.08103 .61696 m
.08107 .61707 L
s
1 .205 0 r
.008 w
.08107 .61707 Mdot
.016 w
.08107 .61707 m
.08111 .61718 L
s
1 .202 0 r
.008 w
.08111 .61718 Mdot
.016 w
.08111 .61718 m
.08113 .61726 L
s
1 .199 0 r
.008 w
.08113 .61726 Mdot
.016 w
.08113 .61726 m
.08116 .61726 L
s
1 .196 0 r
.008 w
.08116 .61726 Mdot
.016 w
.08116 .61726 m
.08121 .61712 L
s
1 .192 0 r
.008 w
.08121 .61712 Mdot
.016 w
.08121 .61712 m
.08127 .61679 L
s
1 .189 0 r
.008 w
.08127 .61679 Mdot
.016 w
.08127 .61679 m
.08132 .61627 L
s
1 .186 0 r
.008 w
.08132 .61627 Mdot
.016 w
.08132 .61627 m
.08133 .61555 L
s
1 .183 0 r
.008 w
.08133 .61555 Mdot
.016 w
.08133 .61555 m
.08128 .61457 L
s
1 .18 0 r
.008 w
.08128 .61457 Mdot
.016 w
.08128 .61457 m
.08115 .61342 L
s
1 .177 0 r
.008 w
.08115 .61342 Mdot
.016 w
.08115 .61342 m
.08092 .61192 L
s
1 .174 0 r
.008 w
.08092 .61192 Mdot
.016 w
.08092 .61192 m
.08057 .61011 L
s
1 .17 0 r
.008 w
.08057 .61011 Mdot
.016 w
.08057 .61011 m
.08023 .60791 L
s
1 .167 0 r
.008 w
.08023 .60791 Mdot
.016 w
.08023 .60791 m
.0798 .60545 L
s
1 .164 0 r
.008 w
.0798 .60545 Mdot
.016 w
.0798 .60545 m
.07933 .60251 L
s
1 .161 0 r
.008 w
.07933 .60251 Mdot
.016 w
.07933 .60251 m
.07886 .5995 L
s
1 .158 0 r
.008 w
.07886 .5995 Mdot
.016 w
.07886 .5995 m
.07837 .59602 L
s
1 .155 0 r
.008 w
.07837 .59602 Mdot
.016 w
.07837 .59602 m
.07787 .59239 L
s
1 .151 0 r
.008 w
.07787 .59239 Mdot
.016 w
.07787 .59239 m
.07735 .58851 L
s
1 .148 0 r
.008 w
.07735 .58851 Mdot
.016 w
.07735 .58851 m
.07681 .5844 L
s
1 .145 0 r
.008 w
.07681 .5844 Mdot
.016 w
.07681 .5844 m
.07625 .58024 L
s
1 .142 0 r
.008 w
.07625 .58024 Mdot
.016 w
.07625 .58024 m
.07565 .57636 L
s
1 .139 0 r
.008 w
.07565 .57636 Mdot
.016 w
.07565 .57636 m
.07504 .57231 L
s
1 .136 0 r
.008 w
.07504 .57231 Mdot
.016 w
.07504 .57231 m
.07446 .56842 L
s
1 .132 0 r
.008 w
.07446 .56842 Mdot
.016 w
.07446 .56842 m
.07392 .56517 L
s
1 .129 0 r
.008 w
.07392 .56517 Mdot
.016 w
.07392 .56517 m
.07342 .56219 L
s
1 .126 0 r
.008 w
.07342 .56219 Mdot
.016 w
.07342 .56219 m
.07297 .55967 L
s
1 .123 0 r
.008 w
.07297 .55967 Mdot
.016 w
.07297 .55967 m
.07258 .5575 L
s
1 .12 0 r
.008 w
.07258 .5575 Mdot
.016 w
.07258 .5575 m
.07226 .55595 L
s
1 .117 0 r
.008 w
.07226 .55595 Mdot
.016 w
.07226 .55595 m
.07201 .55478 L
s
1 .114 0 r
.008 w
.07201 .55478 Mdot
.016 w
.07201 .55478 m
.07184 .55398 L
s
1 .11 0 r
.008 w
.07184 .55398 Mdot
.016 w
.07184 .55398 m
.07174 .55348 L
s
1 .107 0 r
.008 w
.07174 .55348 Mdot
.016 w
.07174 .55348 m
.07169 .5532 L
s
1 .104 0 r
.008 w
.07169 .5532 Mdot
.016 w
.07169 .5532 m
.07169 .55301 L
s
1 .101 0 r
.008 w
.07169 .55301 Mdot
.016 w
.07169 .55301 m
.07169 .55273 L
s
1 .098 0 r
.008 w
.07169 .55273 Mdot
.016 w
.07169 .55273 m
.07168 .55229 L
s
1 .095 0 r
.008 w
.07168 .55229 Mdot
.016 w
.07168 .55229 m
.07162 .55166 L
s
1 .091 0 r
.008 w
.07162 .55166 Mdot
.016 w
.07162 .55166 m
.07149 .55088 L
s
1 .088 0 r
.008 w
.07149 .55088 Mdot
.016 w
.07149 .55088 m
.07129 .54972 L
s
1 .085 0 r
.008 w
.07129 .54972 Mdot
.016 w
.07129 .54972 m
.071 .54819 L
s
1 .082 0 r
.008 w
.071 .54819 Mdot
.016 w
.071 .54819 m
.07064 .54611 L
s
1 .079 0 r
.008 w
.07064 .54611 Mdot
.016 w
.07064 .54611 m
.07023 .54363 L
s
1 .076 0 r
.008 w
.07023 .54363 Mdot
.016 w
.07023 .54363 m
.06981 .54098 L
s
1 .073 0 r
.008 w
.06981 .54098 Mdot
.016 w
.06981 .54098 m
.0694 .53787 L
s
1 .069 0 r
.008 w
.0694 .53787 Mdot
.016 w
.0694 .53787 m
.06902 .53487 L
s
1 .066 0 r
.008 w
.06902 .53487 Mdot
.016 w
.06902 .53487 m
.06871 .5311 L
s
1 .063 0 r
.008 w
.06871 .5311 Mdot
.016 w
.06871 .5311 m
.06848 .52791 L
s
1 .06 0 r
.008 w
.06848 .52791 Mdot
.016 w
.06848 .52791 m
.06832 .5245 L
s
1 .057 0 r
.008 w
.06832 .5245 Mdot
.016 w
.06832 .5245 m
.06827 .52082 L
s
1 .054 0 r
.008 w
.06827 .52082 Mdot
.016 w
.06827 .52082 m
.06832 .5171 L
s
1 .05 0 r
.008 w
.06832 .5171 Mdot
.016 w
.06832 .5171 m
.06849 .51301 L
s
1 .047 0 r
.008 w
.06849 .51301 Mdot
.016 w
.06849 .51301 m
.06876 .50935 L
s
1 .044 0 r
.008 w
.06876 .50935 Mdot
.016 w
.06876 .50935 m
.06916 .50551 L
s
1 .041 0 r
.008 w
.06916 .50551 Mdot
.016 w
.06916 .50551 m
.06961 .50175 L
s
1 .038 0 r
.008 w
.06961 .50175 Mdot
.016 w
.06961 .50175 m
.07013 .49817 L
s
1 .035 0 r
.008 w
.07013 .49817 Mdot
.016 w
.07013 .49817 m
.07072 .49488 L
s
1 .032 0 r
.008 w
.07072 .49488 Mdot
.016 w
.07072 .49488 m
.07126 .49175 L
s
1 .028 0 r
.008 w
.07126 .49175 Mdot
.016 w
.07126 .49175 m
.07183 .48913 L
s
1 .025 0 r
.008 w
.07183 .48913 Mdot
.016 w
.07183 .48913 m
.07235 .48676 L
s
1 .022 0 r
.008 w
.07235 .48676 Mdot
.016 w
.07235 .48676 m
.07281 .48476 L
s
1 .019 0 r
.008 w
.07281 .48476 Mdot
.016 w
.07281 .48476 m
.07321 .48326 L
s
1 .016 0 r
.008 w
.07321 .48326 Mdot
.016 w
.07321 .48326 m
.07355 .4821 L
s
1 .013 0 r
.008 w
.07355 .4821 Mdot
.016 w
.07355 .4821 m
.07384 .4813 L
s
1 .009 0 r
.008 w
.07384 .4813 Mdot
.016 w
.07384 .4813 m
.07409 .48082 L
s
1 .006 0 r
.008 w
.07409 .48082 Mdot
.016 w
.07409 .48082 m
.07431 .48059 L
s
1 .003 0 r
.008 w
.07431 .48059 Mdot
.016 w
.07431 .48059 m
.07448 .48054 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(73)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
1 .978 0 r
.008 w
.07435 .48155 Mdot
.016 w
.07435 .48155 m
.07458 .48158 L
s
1 .956 0 r
.008 w
.07458 .48158 Mdot
.016 w
.07458 .48158 m
.07492 .48155 L
s
1 .933 0 r
.008 w
.07492 .48155 Mdot
.016 w
.07492 .48155 m
.07538 .48145 L
s
1 .911 0 r
.008 w
.07538 .48145 Mdot
.016 w
.07538 .48145 m
.07593 .48127 L
s
1 .889 0 r
.008 w
.07593 .48127 Mdot
.016 w
.07593 .48127 m
.07657 .48102 L
s
1 .867 0 r
.008 w
.07657 .48102 Mdot
.016 w
.07657 .48102 m
.07718 .4807 L
s
1 .844 0 r
.008 w
.07718 .4807 Mdot
.016 w
.07718 .4807 m
.07792 .48032 L
s
1 .822 0 r
.008 w
.07792 .48032 Mdot
.016 w
.07792 .48032 m
.07862 .4799 L
s
1 .8 0 r
.008 w
.07862 .4799 Mdot
.016 w
.07862 .4799 m
.07934 .47945 L
s
1 .778 0 r
.008 w
.07934 .47945 Mdot
.016 w
.07934 .47945 m
.08003 .47898 L
s
1 .756 0 r
.008 w
.08003 .47898 Mdot
.016 w
.08003 .47898 m
.0807 .47848 L
s
1 .733 0 r
.008 w
.0807 .47848 Mdot
.016 w
.0807 .47848 m
.08128 .47797 L
s
1 .711 0 r
.008 w
.08128 .47797 Mdot
.016 w
.08128 .47797 m
.08184 .47742 L
s
1 .689 0 r
.008 w
.08184 .47742 Mdot
.016 w
.08184 .47742 m
.08239 .47683 L
s
1 .667 0 r
.008 w
.08239 .47683 Mdot
.016 w
.08239 .47683 m
.08293 .4762 L
s
1 .644 0 r
.008 w
.08293 .4762 Mdot
.016 w
.08293 .4762 m
.08351 .47553 L
s
1 .622 0 r
.008 w
.08351 .47553 Mdot
.016 w
.08351 .47553 m
.08415 .47482 L
s
1 .6 0 r
.008 w
.08415 .47482 Mdot
.016 w
.08415 .47482 m
.08483 .47403 L
s
1 .578 0 r
.008 w
.08483 .47403 Mdot
.016 w
.08483 .47403 m
.08562 .47313 L
s
1 .556 0 r
.008 w
.08562 .47313 Mdot
.016 w
.08562 .47313 m
.08652 .47209 L
s
1 .533 0 r
.008 w
.08652 .47209 Mdot
.016 w
.08652 .47209 m
.08749 .47089 L
s
1 .511 0 r
.008 w
.08749 .47089 Mdot
.016 w
.08749 .47089 m
.08843 .46949 L
s
1 .489 0 r
.008 w
.08843 .46949 Mdot
.016 w
.08843 .46949 m
.08931 .46785 L
s
1 .467 0 r
.008 w
.08931 .46785 Mdot
.016 w
.08931 .46785 m
.09021 .46608 L
s
1 .444 0 r
.008 w
.09021 .46608 Mdot
.016 w
.09021 .46608 m
.0911 .46415 L
s
1 .422 0 r
.008 w
.0911 .46415 Mdot
.016 w
.0911 .46415 m
.09194 .46213 L
s
1 .4 0 r
.008 w
.09194 .46213 Mdot
.016 w
.09194 .46213 m
.09264 .45995 L
s
1 .378 0 r
.008 w
.09264 .45995 Mdot
.016 w
.09264 .45995 m
.09327 .45776 L
s
1 .356 0 r
.008 w
.09327 .45776 Mdot
.016 w
.09327 .45776 m
.09378 .45526 L
s
1 .333 0 r
.008 w
.09378 .45526 Mdot
.016 w
.09378 .45526 m
.09426 .45297 L
s
1 .311 0 r
.008 w
.09426 .45297 Mdot
.016 w
.09426 .45297 m
.09469 .45043 L
s
1 .289 0 r
.008 w
.09469 .45043 Mdot
.016 w
.09469 .45043 m
.09504 .44776 L
s
1 .267 0 r
.008 w
.09504 .44776 Mdot
.016 w
.09504 .44776 m
.09535 .44532 L
s
1 .244 0 r
.008 w
.09535 .44532 Mdot
.016 w
.09535 .44532 m
.09563 .4426 L
s
1 .222 0 r
.008 w
.09563 .4426 Mdot
.016 w
.09563 .4426 m
.09588 .44048 L
s
1 .2 0 r
.008 w
.09588 .44048 Mdot
.016 w
.09588 .44048 m
.09613 .43828 L
s
1 .178 0 r
.008 w
.09613 .43828 Mdot
.016 w
.09613 .43828 m
.09635 .4363 L
s
1 .156 0 r
.008 w
.09635 .4363 Mdot
.016 w
.09635 .4363 m
.09655 .43462 L
s
1 .133 0 r
.008 w
.09655 .43462 Mdot
.016 w
.09655 .43462 m
.09672 .43303 L
s
1 .111 0 r
.008 w
.09672 .43303 Mdot
.016 w
.09672 .43303 m
.09687 .43189 L
s
1 .089 0 r
.008 w
.09687 .43189 Mdot
.016 w
.09687 .43189 m
.09697 .43094 L
s
1 .067 0 r
.008 w
.09697 .43094 Mdot
.016 w
.09697 .43094 m
.09703 .43016 L
s
1 .044 0 r
.008 w
.09703 .43016 Mdot
.016 w
.09703 .43016 m
.09706 .4297 L
s
1 .022 0 r
.008 w
.09706 .4297 Mdot
.016 w
.09706 .4297 m
.09705 .42939 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(74)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
1 .957 0 r
.008 w
.09692 .43021 Mdot
.016 w
.09692 .43021 m
.09695 .42998 L
s
1 .913 0 r
.008 w
.09695 .42998 Mdot
.016 w
.09695 .42998 m
.09704 .42958 L
s
1 .87 0 r
.008 w
.09704 .42958 Mdot
.016 w
.09704 .42958 m
.09714 .42897 L
s
1 .826 0 r
.008 w
.09714 .42897 Mdot
.016 w
.09714 .42897 m
.09722 .42814 L
s
1 .783 0 r
.008 w
.09722 .42814 Mdot
.016 w
.09722 .42814 m
.09727 .42705 L
s
1 .739 0 r
.008 w
.09727 .42705 Mdot
.016 w
.09727 .42705 m
.09727 .42593 L
s
1 .696 0 r
.008 w
.09727 .42593 Mdot
.016 w
.09727 .42593 m
.0972 .42454 L
s
1 .652 0 r
.008 w
.0972 .42454 Mdot
.016 w
.0972 .42454 m
.097 .4229 L
s
1 .609 0 r
.008 w
.097 .4229 Mdot
.016 w
.097 .4229 m
.09664 .42119 L
s
1 .565 0 r
.008 w
.09664 .42119 Mdot
.016 w
.09664 .42119 m
.09614 .41958 L
s
1 .522 0 r
.008 w
.09614 .41958 Mdot
.016 w
.09614 .41958 m
.09554 .41776 L
s
1 .478 0 r
.008 w
.09554 .41776 Mdot
.016 w
.09554 .41776 m
.09485 .41587 L
s
1 .435 0 r
.008 w
.09485 .41587 Mdot
.016 w
.09485 .41587 m
.09412 .41422 L
s
1 .391 0 r
.008 w
.09412 .41422 Mdot
.016 w
.09412 .41422 m
.09346 .41261 L
s
1 .348 0 r
.008 w
.09346 .41261 Mdot
.016 w
.09346 .41261 m
.09276 .41123 L
s
1 .304 0 r
.008 w
.09276 .41123 Mdot
.016 w
.09276 .41123 m
.09203 .40999 L
s
1 .261 0 r
.008 w
.09203 .40999 Mdot
.016 w
.09203 .40999 m
.09128 .40895 L
s
1 .217 0 r
.008 w
.09128 .40895 Mdot
.016 w
.09128 .40895 m
.09068 .40819 L
s
1 .174 0 r
.008 w
.09068 .40819 Mdot
.016 w
.09068 .40819 m
.09015 .4076 L
s
1 .13 0 r
.008 w
.09015 .4076 Mdot
.016 w
.09015 .4076 m
.0897 .40709 L
s
1 .087 0 r
.008 w
.0897 .40709 Mdot
.016 w
.0897 .40709 m
.08942 .4068 L
s
1 .043 0 r
.008 w
.08942 .4068 Mdot
.016 w
.08942 .4068 m
.08923 .4066 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(75)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
1 .967 0 r
.008 w
.08975 .39498 Mdot
.016 w
.08975 .39498 m
.08961 .39518 L
s
1 .933 0 r
.008 w
.08961 .39518 Mdot
.016 w
.08961 .39518 m
.08934 .39554 L
s
1 .9 0 r
.008 w
.08934 .39554 Mdot
.016 w
.08934 .39554 m
.08886 .39608 L
s
1 .867 0 r
.008 w
.08886 .39608 Mdot
.016 w
.08886 .39608 m
.08826 .39677 L
s
1 .833 0 r
.008 w
.08826 .39677 Mdot
.016 w
.08826 .39677 m
.08773 .39761 L
s
1 .8 0 r
.008 w
.08773 .39761 Mdot
.016 w
.08773 .39761 m
.08727 .39849 L
s
1 .767 0 r
.008 w
.08727 .39849 Mdot
.016 w
.08727 .39849 m
.08683 .39941 L
s
1 .733 0 r
.008 w
.08683 .39941 Mdot
.016 w
.08683 .39941 m
.08638 .4003 L
s
1 .7 0 r
.008 w
.08638 .4003 Mdot
.016 w
.08638 .4003 m
.08589 .40118 L
s
1 .667 0 r
.008 w
.08589 .40118 Mdot
.016 w
.08589 .40118 m
.0854 .40219 L
s
1 .633 0 r
.008 w
.0854 .40219 Mdot
.016 w
.0854 .40219 m
.0849 .40323 L
s
1 .6 0 r
.008 w
.0849 .40323 Mdot
.016 w
.0849 .40323 m
.0845 .40411 L
s
1 .567 0 r
.008 w
.0845 .40411 Mdot
.016 w
.0845 .40411 m
.08428 .40475 L
s
1 .533 0 r
.008 w
.08428 .40475 Mdot
.016 w
.08428 .40475 m
.08419 .40534 L
s
1 .5 0 r
.008 w
.08419 .40534 Mdot
.016 w
.08419 .40534 m
.08415 .40588 L
s
1 .467 0 r
.008 w
.08415 .40588 Mdot
.016 w
.08415 .40588 m
.08416 .40637 L
s
1 .433 0 r
.008 w
.08416 .40637 Mdot
.016 w
.08416 .40637 m
.08423 .40683 L
s
1 .4 0 r
.008 w
.08423 .40683 Mdot
.016 w
.08423 .40683 m
.08427 .40727 L
s
1 .367 0 r
.008 w
.08427 .40727 Mdot
.016 w
.08427 .40727 m
.08427 .40775 L
s
1 .333 0 r
.008 w
.08427 .40775 Mdot
.016 w
.08427 .40775 m
.08426 .40826 L
s
1 .3 0 r
.008 w
.08426 .40826 Mdot
.016 w
.08426 .40826 m
.08425 .40874 L
s
1 .267 0 r
.008 w
.08425 .40874 Mdot
.016 w
.08425 .40874 m
.08424 .40916 L
s
1 .233 0 r
.008 w
.08424 .40916 Mdot
.016 w
.08424 .40916 m
.08423 .40949 L
s
1 .2 0 r
.008 w
.08423 .40949 Mdot
.016 w
.08423 .40949 m
.08423 .4098 L
s
1 .167 0 r
.008 w
.08423 .4098 Mdot
.016 w
.08423 .4098 m
.08422 .41019 L
s
1 .133 0 r
.008 w
.08422 .41019 Mdot
.016 w
.08422 .41019 m
.08421 .41061 L
s
1 .1 0 r
.008 w
.08421 .41061 Mdot
.016 w
.08421 .41061 m
.0842 .41099 L
s
1 .067 0 r
.008 w
.0842 .41099 Mdot
.016 w
.0842 .41099 m
.0842 .41127 L
s
1 .033 0 r
.008 w
.0842 .41127 Mdot
.016 w
.0842 .41127 m
.08419 .41145 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(76)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
1 .982 0 r
.008 w
.10432 .42244 Mdot
.016 w
.10432 .42244 m
.10407 .42238 L
s
1 .964 0 r
.008 w
.10407 .42238 Mdot
.016 w
.10407 .42238 m
.10367 .42241 L
s
1 .946 0 r
.008 w
.10367 .42241 Mdot
.016 w
.10367 .42241 m
.10313 .42255 L
s
1 .929 0 r
.008 w
.10313 .42255 Mdot
.016 w
.10313 .42255 m
.10246 .42285 L
s
1 .911 0 r
.008 w
.10246 .42285 Mdot
.016 w
.10246 .42285 m
.10176 .42337 L
s
1 .893 0 r
.008 w
.10176 .42337 Mdot
.016 w
.10176 .42337 m
.10104 .42414 L
s
1 .875 0 r
.008 w
.10104 .42414 Mdot
.016 w
.10104 .42414 m
.10027 .42515 L
s
1 .857 0 r
.008 w
.10027 .42515 Mdot
.016 w
.10027 .42515 m
.09947 .42643 L
s
1 .839 0 r
.008 w
.09947 .42643 Mdot
.016 w
.09947 .42643 m
.09872 .42786 L
s
1 .821 0 r
.008 w
.09872 .42786 Mdot
.016 w
.09872 .42786 m
.09813 .4295 L
s
1 .804 0 r
.008 w
.09813 .4295 Mdot
.016 w
.09813 .4295 m
.09764 .4314 L
s
1 .786 0 r
.008 w
.09764 .4314 Mdot
.016 w
.09764 .4314 m
.09726 .43343 L
s
1 .768 0 r
.008 w
.09726 .43343 Mdot
.016 w
.09726 .43343 m
.09697 .43562 L
s
1 .75 0 r
.008 w
.09697 .43562 Mdot
.016 w
.09697 .43562 m
.09675 .43789 L
s
1 .732 0 r
.008 w
.09675 .43789 Mdot
.016 w
.09675 .43789 m
.09658 .44015 L
s
1 .714 0 r
.008 w
.09658 .44015 Mdot
.016 w
.09658 .44015 m
.09639 .44246 L
s
1 .696 0 r
.008 w
.09639 .44246 Mdot
.016 w
.09639 .44246 m
.09616 .4445 L
s
1 .679 0 r
.008 w
.09616 .4445 Mdot
.016 w
.09616 .4445 m
.09585 .44653 L
s
1 .661 0 r
.008 w
.09585 .44653 Mdot
.016 w
.09585 .44653 m
.09544 .44851 L
s
1 .643 0 r
.008 w
.09544 .44851 Mdot
.016 w
.09544 .44851 m
.09487 .4503 L
s
1 .625 0 r
.008 w
.09487 .4503 Mdot
.016 w
.09487 .4503 m
.09413 .45198 L
s
1 .607 0 r
.008 w
.09413 .45198 Mdot
.016 w
.09413 .45198 m
.09318 .45366 L
s
1 .589 0 r
.008 w
.09318 .45366 Mdot
.016 w
.09318 .45366 m
.09189 .45538 L
s
1 .571 0 r
.008 w
.09189 .45538 Mdot
.016 w
.09189 .45538 m
.09085 .45705 L
s
1 .554 0 r
.008 w
.09085 .45705 Mdot
.016 w
.09085 .45705 m
.08931 .45885 L
s
1 .536 0 r
.008 w
.08931 .45885 Mdot
.016 w
.08931 .45885 m
.08757 .46078 L
s
1 .518 0 r
.008 w
.08757 .46078 Mdot
.016 w
.08757 .46078 m
.08591 .46266 L
s
1 .5 0 r
.008 w
.08591 .46266 Mdot
.016 w
.08591 .46266 m
.08444 .46468 L
s
1 .482 0 r
.008 w
.08444 .46468 Mdot
.016 w
.08444 .46468 m
.08284 .46677 L
s
1 .464 0 r
.008 w
.08284 .46677 Mdot
.016 w
.08284 .46677 m
.08096 .46875 L
s
1 .446 0 r
.008 w
.08096 .46875 Mdot
.016 w
.08096 .46875 m
.07916 .47074 L
s
1 .429 0 r
.008 w
.07916 .47074 Mdot
.016 w
.07916 .47074 m
.07764 .47278 L
s
1 .411 0 r
.008 w
.07764 .47278 Mdot
.016 w
.07764 .47278 m
.07636 .47463 L
s
1 .393 0 r
.008 w
.07636 .47463 Mdot
.016 w
.07636 .47463 m
.07512 .47649 L
s
1 .375 0 r
.008 w
.07512 .47649 Mdot
.016 w
.07512 .47649 m
.0739 .47835 L
s
1 .357 0 r
.008 w
.0739 .47835 Mdot
.016 w
.0739 .47835 m
.07303 .47995 L
s
1 .339 0 r
.008 w
.07303 .47995 Mdot
.016 w
.07303 .47995 m
.07233 .4814 L
s
1 .321 0 r
.008 w
.07233 .4814 Mdot
.016 w
.07233 .4814 m
.07181 .48268 L
s
1 .304 0 r
.008 w
.07181 .48268 Mdot
.016 w
.07181 .48268 m
.07151 .48379 L
s
1 .286 0 r
.008 w
.07151 .48379 Mdot
.016 w
.07151 .48379 m
.07136 .48476 L
s
1 .268 0 r
.008 w
.07136 .48476 Mdot
.016 w
.07136 .48476 m
.0713 .48562 L
s
1 .25 0 r
.008 w
.0713 .48562 Mdot
.016 w
.0713 .48562 m
.07132 .48642 L
s
1 .232 0 r
.008 w
.07132 .48642 Mdot
.016 w
.07132 .48642 m
.07139 .48719 L
s
1 .214 0 r
.008 w
.07139 .48719 Mdot
.016 w
.07139 .48719 m
.07144 .48798 L
s
1 .196 0 r
.008 w
.07144 .48798 Mdot
.016 w
.07144 .48798 m
.07147 .48877 L
s
1 .179 0 r
.008 w
.07147 .48877 Mdot
.016 w
.07147 .48877 m
.07148 .48954 L
s
1 .161 0 r
.008 w
.07148 .48954 Mdot
.016 w
.07148 .48954 m
.07149 .49026 L
s
1 .143 0 r
.008 w
.07149 .49026 Mdot
.016 w
.07149 .49026 m
.07149 .4909 L
s
1 .125 0 r
.008 w
.07149 .4909 Mdot
.016 w
.07149 .4909 m
.07147 .49142 L
s
1 .107 0 r
.008 w
.07147 .49142 Mdot
.016 w
.07147 .49142 m
.07146 .49187 L
s
1 .089 0 r
.008 w
.07146 .49187 Mdot
.016 w
.07146 .49187 m
.07145 .49224 L
s
1 .071 0 r
.008 w
.07145 .49224 Mdot
.016 w
.07145 .49224 m
.07143 .49256 L
s
1 .054 0 r
.008 w
.07143 .49256 Mdot
.016 w
.07143 .49256 m
.07143 .49284 L
s
1 .036 0 r
.008 w
.07143 .49284 Mdot
.016 w
.07143 .49284 m
.07143 .49306 L
s
1 .018 0 r
.008 w
.07143 .49306 Mdot
.016 w
.07143 .49306 m
.07146 .49316 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(77)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
1 .99 0 r
.008 w
.07141 .49248 Mdot
.016 w
.07141 .49248 m
.07125 .49262 L
s
1 .98 0 r
.008 w
.07125 .49262 Mdot
.016 w
.07125 .49262 m
.07104 .49301 L
s
1 .97 0 r
.008 w
.07104 .49301 Mdot
.016 w
.07104 .49301 m
.07078 .49372 L
s
1 .96 0 r
.008 w
.07078 .49372 Mdot
.016 w
.07078 .49372 m
.07048 .49483 L
s
1 .95 0 r
.008 w
.07048 .49483 Mdot
.016 w
.07048 .49483 m
.07015 .49639 L
s
1 .94 0 r
.008 w
.07015 .49639 Mdot
.016 w
.07015 .49639 m
.06979 .49834 L
s
1 .93 0 r
.008 w
.06979 .49834 Mdot
.016 w
.06979 .49834 m
.0694 .50063 L
s
1 .92 0 r
.008 w
.0694 .50063 Mdot
.016 w
.0694 .50063 m
.069 .50351 L
s
1 .91 0 r
.008 w
.069 .50351 Mdot
.016 w
.069 .50351 m
.06859 .50695 L
s
1 .9 0 r
.008 w
.06859 .50695 Mdot
.016 w
.06859 .50695 m
.0682 .50995 L
s
1 .89 0 r
.008 w
.0682 .50995 Mdot
.016 w
.0682 .50995 m
.06786 .51393 L
s
1 .88 0 r
.008 w
.06786 .51393 Mdot
.016 w
.06786 .51393 m
.0676 .51768 L
s
1 .87 0 r
.008 w
.0676 .51768 Mdot
.016 w
.0676 .51768 m
.06745 .52187 L
s
1 .86 0 r
.008 w
.06745 .52187 Mdot
.016 w
.06745 .52187 m
.0674 .52606 L
s
1 .85 0 r
.008 w
.0674 .52606 Mdot
.016 w
.0674 .52606 m
.06747 .53023 L
s
1 .84 0 r
.008 w
.06747 .53023 Mdot
.016 w
.06747 .53023 m
.06763 .53403 L
s
1 .83 0 r
.008 w
.06763 .53403 Mdot
.016 w
.06763 .53403 m
.06788 .53796 L
s
1 .82 0 r
.008 w
.06788 .53796 Mdot
.016 w
.06788 .53796 m
.06822 .54175 L
s
1 .81 0 r
.008 w
.06822 .54175 Mdot
.016 w
.06822 .54175 m
.06861 .54516 L
s
1 .8 0 r
.008 w
.06861 .54516 Mdot
.016 w
.06861 .54516 m
.06909 .54846 L
s
1 .79 0 r
.008 w
.06909 .54846 Mdot
.016 w
.06909 .54846 m
.06964 .55167 L
s
1 .78 0 r
.008 w
.06964 .55167 Mdot
.016 w
.06964 .55167 m
.07026 .55485 L
s
1 .77 0 r
.008 w
.07026 .55485 Mdot
.016 w
.07026 .55485 m
.07091 .55778 L
s
1 .76 0 r
.008 w
.07091 .55778 Mdot
.016 w
.07091 .55778 m
.07159 .56097 L
s
1 .75 0 r
.008 w
.07159 .56097 Mdot
.016 w
.07159 .56097 m
.0723 .56391 L
s
1 .74 0 r
.008 w
.0723 .56391 Mdot
.016 w
.0723 .56391 m
.07296 .56719 L
s
1 .73 0 r
.008 w
.07296 .56719 Mdot
.016 w
.07296 .56719 m
.07362 .57038 L
s
1 .72 0 r
.008 w
.07362 .57038 Mdot
.016 w
.07362 .57038 m
.07426 .57406 L
s
1 .71 0 r
.008 w
.07426 .57406 Mdot
.016 w
.07426 .57406 m
.07488 .57754 L
s
1 .7 0 r
.008 w
.07488 .57754 Mdot
.016 w
.07488 .57754 m
.07545 .58089 L
s
1 .69 0 r
.008 w
.07545 .58089 Mdot
.016 w
.07545 .58089 m
.076 .585 L
s
1 .68 0 r
.008 w
.076 .585 Mdot
.016 w
.076 .585 m
.07651 .5887 L
s
1 .67 0 r
.008 w
.07651 .5887 Mdot
.016 w
.07651 .5887 m
.07697 .5933 L
s
1 .66 0 r
.008 w
.07697 .5933 Mdot
.016 w
.07697 .5933 m
.0774 .59701 L
s
1 .65 0 r
.008 w
.0774 .59701 Mdot
.016 w
.0774 .59701 m
.07783 .60155 L
s
1 .64 0 r
.008 w
.07783 .60155 Mdot
.016 w
.07783 .60155 m
.07826 .60599 L
s
1 .63 0 r
.008 w
.07826 .60599 Mdot
.016 w
.07826 .60599 m
.0787 .6101 L
s
1 .62 0 r
.008 w
.0787 .6101 Mdot
.016 w
.0787 .6101 m
.07915 .61448 L
s
1 .61 0 r
.008 w
.07915 .61448 Mdot
.016 w
.07915 .61448 m
.07966 .61886 L
s
1 .6 0 r
.008 w
.07966 .61886 Mdot
.016 w
.07966 .61886 m
.08024 .6233 L
s
1 .59 0 r
.008 w
.08024 .6233 Mdot
.016 w
.08024 .6233 m
.08089 .62776 L
s
1 .58 0 r
.008 w
.08089 .62776 Mdot
.016 w
.08089 .62776 m
.0816 .63217 L
s
1 .57 0 r
.008 w
.0816 .63217 Mdot
.016 w
.0816 .63217 m
.08226 .63655 L
s
1 .56 0 r
.008 w
.08226 .63655 Mdot
.016 w
.08226 .63655 m
.08301 .64105 L
s
1 .55 0 r
.008 w
.08301 .64105 Mdot
.016 w
.08301 .64105 m
.08373 .64581 L
s
1 .54 0 r
.008 w
.08373 .64581 Mdot
.016 w
.08373 .64581 m
.08447 .65005 L
s
1 .53 0 r
.008 w
.08447 .65005 Mdot
.016 w
.08447 .65005 m
.08519 .65492 L
s
1 .52 0 r
.008 w
.08519 .65492 Mdot
.016 w
.08519 .65492 m
.08587 .65885 L
s
1 .51 0 r
.008 w
.08587 .65885 Mdot
.016 w
.08587 .65885 m
.08652 .66347 L
s
1 .5 0 r
.008 w
.08652 .66347 Mdot
.016 w
.08652 .66347 m
.08715 .66742 L
s
1 .49 0 r
.008 w
.08715 .66742 Mdot
.016 w
.08715 .66742 m
.08769 .6714 L
s
1 .48 0 r
.008 w
.08769 .6714 Mdot
.016 w
.08769 .6714 m
.08818 .67481 L
s
1 .47 0 r
.008 w
.08818 .67481 Mdot
.016 w
.08818 .67481 m
.0886 .67793 L
s
1 .46 0 r
.008 w
.0886 .67793 Mdot
.016 w
.0886 .67793 m
.08895 .68097 L
s
1 .45 0 r
.008 w
.08895 .68097 Mdot
.016 w
.08895 .68097 m
.08925 .6836 L
s
1 .44 0 r
.008 w
.08925 .6836 Mdot
.016 w
.08925 .6836 m
.08952 .68599 L
s
1 .43 0 r
.008 w
.08952 .68599 Mdot
.016 w
.08952 .68599 m
.08977 .6881 L
s
1 .42 0 r
.008 w
.08977 .6881 Mdot
.016 w
.08977 .6881 m
.09003 .68977 L
s
1 .41 0 r
.008 w
.09003 .68977 Mdot
.016 w
.09003 .68977 m
.0903 .69125 L
s
1 .4 0 r
.008 w
.0903 .69125 Mdot
.016 w
.0903 .69125 m
.09059 .6925 L
s
1 .39 0 r
.008 w
.09059 .6925 Mdot
.016 w
.09059 .6925 m
.0909 .69353 L
s
1 .38 0 r
.008 w
.0909 .69353 Mdot
.016 w
.0909 .69353 m
.09122 .69441 L
s
1 .37 0 r
.008 w
.09122 .69441 Mdot
.016 w
.09122 .69441 m
.09153 .69504 L
s
1 .36 0 r
.008 w
.09153 .69504 Mdot
.016 w
.09153 .69504 m
.09183 .69566 L
s
1 .35 0 r
.008 w
.09183 .69566 Mdot
.016 w
.09183 .69566 m
.09209 .69616 L
s
1 .34 0 r
.008 w
.09209 .69616 Mdot
.016 w
.09209 .69616 m
.0923 .6965 L
s
1 .33 0 r
.008 w
.0923 .6965 Mdot
.016 w
.0923 .6965 m
.09249 .69667 L
s
1 .32 0 r
.008 w
.09249 .69667 Mdot
.016 w
.09249 .69667 m
.09267 .69667 L
s
1 .31 0 r
.008 w
.09267 .69667 Mdot
.016 w
.09267 .69667 m
.09284 .69655 L
s
1 .3 0 r
.008 w
.09284 .69655 Mdot
.016 w
.09284 .69655 m
.09299 .69636 L
s
1 .29 0 r
.008 w
.09299 .69636 Mdot
.016 w
.09299 .69636 m
.0931 .69616 L
s
1 .28 0 r
.008 w
.0931 .69616 Mdot
.016 w
.0931 .69616 m
.09317 .69599 L
s
1 .27 0 r
.008 w
.09317 .69599 Mdot
.016 w
.09317 .69599 m
.09319 .69591 L
s
1 .26 0 r
.008 w
.09319 .69591 Mdot
.016 w
.09319 .69591 m
.09317 .69598 L
s
1 .25 0 r
.008 w
.09317 .69598 Mdot
.016 w
.09317 .69598 m
.09312 .69624 L
s
1 .24 0 r
.008 w
.09312 .69624 Mdot
.016 w
.09312 .69624 m
.09306 .69672 L
s
1 .23 0 r
.008 w
.09306 .69672 Mdot
.016 w
.09306 .69672 m
.093 .69741 L
s
1 .22 0 r
.008 w
.093 .69741 Mdot
.016 w
.093 .69741 m
.09298 .69831 L
s
1 .21 0 r
.008 w
.09298 .69831 Mdot
.016 w
.09298 .69831 m
.09302 .69942 L
s
1 .2 0 r
.008 w
.09302 .69942 Mdot
.016 w
.09302 .69942 m
.09312 .70076 L
s
1 .19 0 r
.008 w
.09312 .70076 Mdot
.016 w
.09312 .70076 m
.0933 .70236 L
s
1 .18 0 r
.008 w
.0933 .70236 Mdot
.016 w
.0933 .70236 m
.09359 .70432 L
s
1 .17 0 r
.008 w
.09359 .70432 Mdot
.016 w
.09359 .70432 m
.09402 .70668 L
s
1 .16 0 r
.008 w
.09402 .70668 Mdot
.016 w
.09402 .70668 m
.09455 .70937 L
s
1 .15 0 r
.008 w
.09455 .70937 Mdot
.016 w
.09455 .70937 m
.09519 .71215 L
s
1 .14 0 r
.008 w
.09519 .71215 Mdot
.016 w
.09519 .71215 m
.09592 .71527 L
s
1 .13 0 r
.008 w
.09592 .71527 Mdot
.016 w
.09592 .71527 m
.09674 .71853 L
s
1 .12 0 r
.008 w
.09674 .71853 Mdot
.016 w
.09674 .71853 m
.09757 .72173 L
s
1 .11 0 r
.008 w
.09757 .72173 Mdot
.016 w
.09757 .72173 m
.09842 .72507 L
s
1 .1 0 r
.008 w
.09842 .72507 Mdot
.016 w
.09842 .72507 m
.09925 .7279 L
s
1 .09 0 r
.008 w
.09925 .7279 Mdot
.016 w
.09925 .7279 m
.1 .73068 L
s
1 .08 0 r
.008 w
.1 .73068 Mdot
.016 w
.1 .73068 m
.10072 .73338 L
s
1 .07 0 r
.008 w
.10072 .73338 Mdot
.016 w
.10072 .73338 m
.10131 .73547 L
s
1 .06 0 r
.008 w
.10131 .73547 Mdot
.016 w
.10131 .73547 m
.10187 .73738 L
s
1 .05 0 r
.008 w
.10187 .73738 Mdot
.016 w
.10187 .73738 m
.10225 .73902 L
s
1 .04 0 r
.008 w
.10225 .73902 Mdot
.016 w
.10225 .73902 m
.10258 .74031 L
s
1 .03 0 r
.008 w
.10258 .74031 Mdot
.016 w
.10258 .74031 m
.1028 .74118 L
s
1 .02 0 r
.008 w
.1028 .74118 Mdot
.016 w
.1028 .74118 m
.10292 .74169 L
s
1 .01 0 r
.008 w
.10292 .74169 Mdot
.016 w
.10292 .74169 m
.10295 .74191 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(78)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
1 .985 0 r
.008 w
.10208 .74482 Mdot
.016 w
.10208 .74482 m
.10222 .74488 L
s
1 .971 0 r
.008 w
.10222 .74488 Mdot
.016 w
.10222 .74488 m
.10255 .74516 L
s
1 .956 0 r
.008 w
.10255 .74516 Mdot
.016 w
.10255 .74516 m
.10309 .74572 L
s
1 .941 0 r
.008 w
.10309 .74572 Mdot
.016 w
.10309 .74572 m
.10387 .74658 L
s
1 .926 0 r
.008 w
.10387 .74658 Mdot
.016 w
.10387 .74658 m
.10491 .74778 L
s
1 .912 0 r
.008 w
.10491 .74778 Mdot
.016 w
.10491 .74778 m
.1061 .7493 L
s
1 .897 0 r
.008 w
.1061 .7493 Mdot
.016 w
.1061 .7493 m
.10765 .75113 L
s
1 .882 0 r
.008 w
.10765 .75113 Mdot
.016 w
.10765 .75113 m
.10928 .753 L
s
1 .868 0 r
.008 w
.10928 .753 Mdot
.016 w
.10928 .753 m
.11123 .7553 L
s
1 .853 0 r
.008 w
.11123 .7553 Mdot
.016 w
.11123 .7553 m
.11329 .75773 L
s
1 .838 0 r
.008 w
.11329 .75773 Mdot
.016 w
.11329 .75773 m
.11555 .76039 L
s
1 .824 0 r
.008 w
.11555 .76039 Mdot
.016 w
.11555 .76039 m
.1181 .76312 L
s
1 .809 0 r
.008 w
.1181 .76312 Mdot
.016 w
.1181 .76312 m
.12056 .76596 L
s
1 .794 0 r
.008 w
.12056 .76596 Mdot
.016 w
.12056 .76596 m
.12299 .76857 L
s
1 .779 0 r
.008 w
.12299 .76857 Mdot
.016 w
.12299 .76857 m
.12546 .77127 L
s
1 .765 0 r
.008 w
.12546 .77127 Mdot
.016 w
.12546 .77127 m
.1279 .77388 L
s
1 .75 0 r
.008 w
.1279 .77388 Mdot
.016 w
.1279 .77388 m
.13033 .77635 L
s
1 .735 0 r
.008 w
.13033 .77635 Mdot
.016 w
.13033 .77635 m
.13281 .77889 L
s
1 .721 0 r
.008 w
.13281 .77889 Mdot
.016 w
.13281 .77889 m
.13527 .78131 L
s
1 .706 0 r
.008 w
.13527 .78131 Mdot
.016 w
.13527 .78131 m
.13794 .78386 L
s
1 .691 0 r
.008 w
.13794 .78386 Mdot
.016 w
.13794 .78386 m
.1405 .78639 L
s
1 .676 0 r
.008 w
.1405 .78639 Mdot
.016 w
.1405 .78639 m
.14329 .78912 L
s
1 .662 0 r
.008 w
.14329 .78912 Mdot
.016 w
.14329 .78912 m
.14612 .79175 L
s
1 .647 0 r
.008 w
.14612 .79175 Mdot
.016 w
.14612 .79175 m
.14897 .79464 L
s
1 .632 0 r
.008 w
.14897 .79464 Mdot
.016 w
.14897 .79464 m
.15184 .79737 L
s
1 .618 0 r
.008 w
.15184 .79737 Mdot
.016 w
.15184 .79737 m
.15482 .80036 L
s
1 .603 0 r
.008 w
.15482 .80036 Mdot
.016 w
.15482 .80036 m
.15782 .80329 L
s
1 .588 0 r
.008 w
.15782 .80329 Mdot
.016 w
.15782 .80329 m
.16092 .80639 L
s
1 .574 0 r
.008 w
.16092 .80639 Mdot
.016 w
.16092 .80639 m
.16378 .80931 L
s
1 .559 0 r
.008 w
.16378 .80931 Mdot
.016 w
.16378 .80931 m
.16678 .81246 L
s
1 .544 0 r
.008 w
.16678 .81246 Mdot
.016 w
.16678 .81246 m
.16984 .81542 L
s
1 .529 0 r
.008 w
.16984 .81542 Mdot
.016 w
.16984 .81542 m
.17281 .81849 L
s
1 .515 0 r
.008 w
.17281 .81849 Mdot
.016 w
.17281 .81849 m
.17586 .82149 L
s
1 .5 0 r
.008 w
.17586 .82149 Mdot
.016 w
.17586 .82149 m
.17901 .82471 L
s
1 .485 0 r
.008 w
.17901 .82471 Mdot
.016 w
.17901 .82471 m
.18199 .82764 L
s
1 .471 0 r
.008 w
.18199 .82764 Mdot
.016 w
.18199 .82764 m
.1853 .83088 L
s
1 .456 0 r
.008 w
.1853 .83088 Mdot
.016 w
.1853 .83088 m
.18853 .83433 L
s
1 .441 0 r
.008 w
.18853 .83433 Mdot
.016 w
.18853 .83433 m
.19195 .83758 L
s
1 .426 0 r
.008 w
.19195 .83758 Mdot
.016 w
.19195 .83758 m
.19552 .84112 L
s
1 .412 0 r
.008 w
.19552 .84112 Mdot
.016 w
.19552 .84112 m
.19943 .84496 L
s
1 .397 0 r
.008 w
.19943 .84496 Mdot
.016 w
.19943 .84496 m
.20307 .84836 L
s
1 .382 0 r
.008 w
.20307 .84836 Mdot
.016 w
.20307 .84836 m
.20682 .852 L
s
1 .368 0 r
.008 w
.20682 .852 Mdot
.016 w
.20682 .852 m
.21074 .85586 L
s
1 .353 0 r
.008 w
.21074 .85586 Mdot
.016 w
.21074 .85586 m
.21449 .85935 L
s
1 .338 0 r
.008 w
.21449 .85935 Mdot
.016 w
.21449 .85935 m
.21837 .86294 L
s
1 .324 0 r
.008 w
.21837 .86294 Mdot
.016 w
.21837 .86294 m
.22202 .86695 L
s
1 .309 0 r
.008 w
.22202 .86695 Mdot
.016 w
.22202 .86695 m
.22571 .8702 L
s
1 .294 0 r
.008 w
.22571 .8702 Mdot
.016 w
.22571 .8702 m
.22917 .8736 L
s
1 .279 0 r
.008 w
.22917 .8736 Mdot
.016 w
.22917 .8736 m
.23245 .87699 L
s
1 .265 0 r
.008 w
.23245 .87699 Mdot
.016 w
.23245 .87699 m
.23554 .88004 L
s
1 .25 0 r
.008 w
.23554 .88004 Mdot
.016 w
.23554 .88004 m
.23847 .88299 L
s
1 .235 0 r
.008 w
.23847 .88299 Mdot
.016 w
.23847 .88299 m
.241 .88538 L
s
1 .221 0 r
.008 w
.241 .88538 Mdot
.016 w
.241 .88538 m
.24336 .88756 L
s
1 .206 0 r
.008 w
.24336 .88756 Mdot
.016 w
.24336 .88756 m
.24531 .88926 L
s
1 .191 0 r
.008 w
.24531 .88926 Mdot
.016 w
.24531 .88926 m
.24703 .89065 L
s
1 .176 0 r
.008 w
.24703 .89065 Mdot
.016 w
.24703 .89065 m
.24845 .89173 L
s
1 .162 0 r
.008 w
.24845 .89173 Mdot
.016 w
.24845 .89173 m
.2496 .89252 L
s
1 .147 0 r
.008 w
.2496 .89252 Mdot
.016 w
.2496 .89252 m
.25049 .89302 L
s
1 .132 0 r
.008 w
.25049 .89302 Mdot
.016 w
.25049 .89302 m
.25114 .89325 L
s
1 .118 0 r
.008 w
.25114 .89325 Mdot
.016 w
.25114 .89325 m
.25156 .89325 L
s
1 .103 0 r
.008 w
.25156 .89325 Mdot
.016 w
.25156 .89325 m
.25181 .89304 L
s
1 .088 0 r
.008 w
.25181 .89304 Mdot
.016 w
.25181 .89304 m
.25193 .89269 L
s
1 .074 0 r
.008 w
.25193 .89269 Mdot
.016 w
.25193 .89269 m
.25193 .89225 L
s
1 .059 0 r
.008 w
.25193 .89225 Mdot
.016 w
.25193 .89225 m
.25186 .89181 L
s
1 .044 0 r
.008 w
.25186 .89181 Mdot
.016 w
.25186 .89181 m
.25176 .89144 L
s
1 .029 0 r
.008 w
.25176 .89144 Mdot
.016 w
.25176 .89144 m
.25167 .89116 L
s
1 .015 0 r
.008 w
.25167 .89116 Mdot
.016 w
.25167 .89116 m
.25158 .89098 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(79)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
1 .938 0 r
.008 w
.25127 .89093 Mdot
.016 w
.25127 .89093 m
.25146 .89103 L
s
1 .875 0 r
.008 w
.25146 .89103 Mdot
.016 w
.25146 .89103 m
.25175 .89119 L
s
1 .813 0 r
.008 w
.25175 .89119 Mdot
.016 w
.25175 .89119 m
.25215 .89143 L
s
1 .75 0 r
.008 w
.25215 .89143 Mdot
.016 w
.25215 .89143 m
.25268 .89176 L
s
1 .688 0 r
.008 w
.25268 .89176 Mdot
.016 w
.25268 .89176 m
.25333 .89213 L
s
1 .625 0 r
.008 w
.25333 .89213 Mdot
.016 w
.25333 .89213 m
.25403 .89253 L
s
1 .563 0 r
.008 w
.25403 .89253 Mdot
.016 w
.25403 .89253 m
.25474 .89294 L
s
1 .5 0 r
.008 w
.25474 .89294 Mdot
.016 w
.25474 .89294 m
.25547 .89335 L
s
1 .438 0 r
.008 w
.25547 .89335 Mdot
.016 w
.25547 .89335 m
.25617 .89373 L
s
1 .375 0 r
.008 w
.25617 .89373 Mdot
.016 w
.25617 .89373 m
.25686 .8941 L
s
1 .313 0 r
.008 w
.25686 .8941 Mdot
.016 w
.25686 .8941 m
.25747 .89444 L
s
1 .25 0 r
.008 w
.25747 .89444 Mdot
.016 w
.25747 .89444 m
.25801 .89473 L
s
1 .188 0 r
.008 w
.25801 .89473 Mdot
.016 w
.25801 .89473 m
.25846 .89497 L
s
1 .125 0 r
.008 w
.25846 .89497 Mdot
.016 w
.25846 .89497 m
.25881 .89515 L
s
1 .063 0 r
.008 w
.25881 .89515 Mdot
.016 w
.25881 .89515 m
.25906 .89527 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(80)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
1 .983 0 r
.008 w
.25987 .89024 Mdot
.016 w
.25987 .89024 m
.25966 .8904 L
s
1 .966 0 r
.008 w
.25966 .8904 Mdot
.016 w
.25966 .8904 m
.25953 .89057 L
s
1 .948 0 r
.008 w
.25953 .89057 Mdot
.016 w
.25953 .89057 m
.25937 .89078 L
s
1 .931 0 r
.008 w
.25937 .89078 Mdot
.016 w
.25937 .89078 m
.25921 .89105 L
s
1 .914 0 r
.008 w
.25921 .89105 Mdot
.016 w
.25921 .89105 m
.25906 .89138 L
s
1 .897 0 r
.008 w
.25906 .89138 Mdot
.016 w
.25906 .89138 m
.25896 .89181 L
s
1 .879 0 r
.008 w
.25896 .89181 Mdot
.016 w
.25896 .89181 m
.2589 .89232 L
s
1 .862 0 r
.008 w
.2589 .89232 Mdot
.016 w
.2589 .89232 m
.25895 .89294 L
s
1 .845 0 r
.008 w
.25895 .89294 Mdot
.016 w
.25895 .89294 m
.25916 .89366 L
s
1 .828 0 r
.008 w
.25916 .89366 Mdot
.016 w
.25916 .89366 m
.25952 .89444 L
s
1 .81 0 r
.008 w
.25952 .89444 Mdot
.016 w
.25952 .89444 m
.26017 .89538 L
s
1 .793 0 r
.008 w
.26017 .89538 Mdot
.016 w
.26017 .89538 m
.26111 .89646 L
s
1 .776 0 r
.008 w
.26111 .89646 Mdot
.016 w
.26111 .89646 m
.26243 .89766 L
s
1 .759 0 r
.008 w
.26243 .89766 Mdot
.016 w
.26243 .89766 m
.26419 .89901 L
s
1 .741 0 r
.008 w
.26419 .89901 Mdot
.016 w
.26419 .89901 m
.26647 .90051 L
s
1 .724 0 r
.008 w
.26647 .90051 Mdot
.016 w
.26647 .90051 m
.26912 .90215 L
s
1 .707 0 r
.008 w
.26912 .90215 Mdot
.016 w
.26912 .90215 m
.27223 .9039 L
s
1 .69 0 r
.008 w
.27223 .9039 Mdot
.016 w
.27223 .9039 m
.27572 .90568 L
s
1 .672 0 r
.008 w
.27572 .90568 Mdot
.016 w
.27572 .90568 m
.27961 .90753 L
s
1 .655 0 r
.008 w
.27961 .90753 Mdot
.016 w
.27961 .90753 m
.28376 .90938 L
s
1 .638 0 r
.008 w
.28376 .90938 Mdot
.016 w
.28376 .90938 m
.2881 .91123 L
s
1 .621 0 r
.008 w
.2881 .91123 Mdot
.016 w
.2881 .91123 m
.29294 .91307 L
s
1 .603 0 r
.008 w
.29294 .91307 Mdot
.016 w
.29294 .91307 m
.29777 .91495 L
s
1 .586 0 r
.008 w
.29777 .91495 Mdot
.016 w
.29777 .91495 m
.30286 .9168 L
s
1 .569 0 r
.008 w
.30286 .9168 Mdot
.016 w
.30286 .9168 m
.30825 .91866 L
s
1 .552 0 r
.008 w
.30825 .91866 Mdot
.016 w
.30825 .91866 m
.31339 .92049 L
s
1 .534 0 r
.008 w
.31339 .92049 Mdot
.016 w
.31339 .92049 m
.31875 .92236 L
s
1 .517 0 r
.008 w
.31875 .92236 Mdot
.016 w
.31875 .92236 m
.32402 .92419 L
s
1 .5 0 r
.008 w
.32402 .92419 Mdot
.016 w
.32402 .92419 m
.32933 .92599 L
s
1 .483 0 r
.008 w
.32933 .92599 Mdot
.016 w
.32933 .92599 m
.33439 .92783 L
s
1 .466 0 r
.008 w
.33439 .92783 Mdot
.016 w
.33439 .92783 m
.33904 .92965 L
s
1 .448 0 r
.008 w
.33904 .92965 Mdot
.016 w
.33904 .92965 m
.34355 .93144 L
s
1 .431 0 r
.008 w
.34355 .93144 Mdot
.016 w
.34355 .93144 m
.34753 .93313 L
s
1 .414 0 r
.008 w
.34753 .93313 Mdot
.016 w
.34753 .93313 m
.35119 .93472 L
s
1 .397 0 r
.008 w
.35119 .93472 Mdot
.016 w
.35119 .93472 m
.35482 .93606 L
s
1 .379 0 r
.008 w
.35482 .93606 Mdot
.016 w
.35482 .93606 m
.3578 .93729 L
s
1 .362 0 r
.008 w
.3578 .93729 Mdot
.016 w
.3578 .93729 m
.36042 .93829 L
s
1 .345 0 r
.008 w
.36042 .93829 Mdot
.016 w
.36042 .93829 m
.3629 .93915 L
s
1 .328 0 r
.008 w
.3629 .93915 Mdot
.016 w
.3629 .93915 m
.36524 .93989 L
s
1 .31 0 r
.008 w
.36524 .93989 Mdot
.016 w
.36524 .93989 m
.36746 .94054 L
s
1 .293 0 r
.008 w
.36746 .94054 Mdot
.016 w
.36746 .94054 m
.36957 .9411 L
s
1 .276 0 r
.008 w
.36957 .9411 Mdot
.016 w
.36957 .9411 m
.37146 .9416 L
s
1 .259 0 r
.008 w
.37146 .9416 Mdot
.016 w
.37146 .9416 m
.37346 .94209 L
s
1 .241 0 r
.008 w
.37346 .94209 Mdot
.016 w
.37346 .94209 m
.3756 .94258 L
s
1 .224 0 r
.008 w
.3756 .94258 Mdot
.016 w
.3756 .94258 m
.37782 .94308 L
s
1 .207 0 r
.008 w
.37782 .94308 Mdot
.016 w
.37782 .94308 m
.38008 .94362 L
s
1 .19 0 r
.008 w
.38008 .94362 Mdot
.016 w
.38008 .94362 m
.38238 .94419 L
s
1 .172 0 r
.008 w
.38238 .94419 Mdot
.016 w
.38238 .94419 m
.38469 .94483 L
s
1 .155 0 r
.008 w
.38469 .94483 Mdot
.016 w
.38469 .94483 m
.38691 .94552 L
s
1 .138 0 r
.008 w
.38691 .94552 Mdot
.016 w
.38691 .94552 m
.38884 .94623 L
s
1 .121 0 r
.008 w
.38884 .94623 Mdot
.016 w
.38884 .94623 m
.39051 .94685 L
s
1 .103 0 r
.008 w
.39051 .94685 Mdot
.016 w
.39051 .94685 m
.3919 .94743 L
s
1 .086 0 r
.008 w
.3919 .94743 Mdot
.016 w
.3919 .94743 m
.39301 .94795 L
s
1 .069 0 r
.008 w
.39301 .94795 Mdot
.016 w
.39301 .94795 m
.3939 .94836 L
s
1 .052 0 r
.008 w
.3939 .94836 Mdot
.016 w
.3939 .94836 m
.39451 .94866 L
s
1 .034 0 r
.008 w
.39451 .94866 Mdot
.016 w
.39451 .94866 m
.39491 .94884 L
s
1 .017 0 r
.008 w
.39491 .94884 Mdot
.016 w
.39491 .94884 m
.3951 .94887 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(81)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
1 .994 0 r
.008 w
.3928 .94554 Mdot
.016 w
.3928 .94554 m
.39282 .94566 L
s
1 .987 0 r
.008 w
.39282 .94566 Mdot
.016 w
.39282 .94566 m
.39305 .94584 L
s
1 .981 0 r
.008 w
.39305 .94584 Mdot
.016 w
.39305 .94584 m
.39353 .94614 L
s
1 .974 0 r
.008 w
.39353 .94614 Mdot
.016 w
.39353 .94614 m
.39433 .94661 L
s
1 .968 0 r
.008 w
.39433 .94661 Mdot
.016 w
.39433 .94661 m
.3955 .94725 L
s
1 .962 0 r
.008 w
.3955 .94725 Mdot
.016 w
.3955 .94725 m
.39708 .94807 L
s
1 .955 0 r
.008 w
.39708 .94807 Mdot
.016 w
.39708 .94807 m
.39918 .94908 L
s
1 .949 0 r
.008 w
.39918 .94908 Mdot
.016 w
.39918 .94908 m
.40186 .95025 L
s
1 .942 0 r
.008 w
.40186 .95025 Mdot
.016 w
.40186 .95025 m
.40469 .95156 L
s
1 .936 0 r
.008 w
.40469 .95156 Mdot
.016 w
.40469 .95156 m
.40827 .953 L
s
1 .929 0 r
.008 w
.40827 .953 Mdot
.016 w
.40827 .953 m
.41221 .95455 L
s
1 .923 0 r
.008 w
.41221 .95455 Mdot
.016 w
.41221 .95455 m
.4167 .95607 L
s
1 .917 0 r
.008 w
.4167 .95607 Mdot
.016 w
.4167 .95607 m
.42162 .9577 L
s
1 .91 0 r
.008 w
.42162 .9577 Mdot
.016 w
.42162 .9577 m
.42624 .95922 L
s
1 .904 0 r
.008 w
.42624 .95922 Mdot
.016 w
.42624 .95922 m
.43109 .96069 L
s
1 .897 0 r
.008 w
.43109 .96069 Mdot
.016 w
.43109 .96069 m
.43619 .96209 L
s
1 .891 0 r
.008 w
.43619 .96209 Mdot
.016 w
.43619 .96209 m
.44068 .96333 L
s
1 .885 0 r
.008 w
.44068 .96333 Mdot
.016 w
.44068 .96333 m
.44519 .96444 L
s
1 .878 0 r
.008 w
.44519 .96444 Mdot
.016 w
.44519 .96444 m
.44911 .96539 L
s
1 .872 0 r
.008 w
.44911 .96539 Mdot
.016 w
.44911 .96539 m
.45276 .96617 L
s
1 .865 0 r
.008 w
.45276 .96617 Mdot
.016 w
.45276 .96617 m
.4562 .9668 L
s
1 .859 0 r
.008 w
.4562 .9668 Mdot
.016 w
.4562 .9668 m
.45876 .96729 L
s
1 .853 0 r
.008 w
.45876 .96729 Mdot
.016 w
.45876 .96729 m
.46102 .96766 L
s
1 .846 0 r
.008 w
.46102 .96766 Mdot
.016 w
.46102 .96766 m
.46297 .96793 L
s
1 .84 0 r
.008 w
.46297 .96793 Mdot
.016 w
.46297 .96793 m
.46459 .96812 L
s
1 .833 0 r
.008 w
.46459 .96812 Mdot
.016 w
.46459 .96812 m
.46591 .96824 L
s
1 .827 0 r
.008 w
.46591 .96824 Mdot
.016 w
.46591 .96824 m
.46707 .96827 L
s
1 .821 0 r
.008 w
.46707 .96827 Mdot
.016 w
.46707 .96827 m
.46797 .96821 L
s
1 .814 0 r
.008 w
.46797 .96821 Mdot
.016 w
.46797 .96821 m
.46876 .96808 L
s
1 .808 0 r
.008 w
.46876 .96808 Mdot
.016 w
.46876 .96808 m
.46954 .96791 L
s
1 .801 0 r
.008 w
.46954 .96791 Mdot
.016 w
.46954 .96791 m
.4703 .96773 L
s
1 .795 0 r
.008 w
.4703 .96773 Mdot
.016 w
.4703 .96773 m
.47102 .96756 L
s
1 .788 0 r
.008 w
.47102 .96756 Mdot
.016 w
.47102 .96756 m
.47171 .96741 L
s
1 .782 0 r
.008 w
.47171 .96741 Mdot
.016 w
.47171 .96741 m
.47238 .96727 L
s
1 .776 0 r
.008 w
.47238 .96727 Mdot
.016 w
.47238 .96727 m
.47306 .96713 L
s
1 .769 0 r
.008 w
.47306 .96713 Mdot
.016 w
.47306 .96713 m
.4737 .96698 L
s
1 .763 0 r
.008 w
.4737 .96698 Mdot
.016 w
.4737 .96698 m
.47431 .96683 L
s
1 .756 0 r
.008 w
.47431 .96683 Mdot
.016 w
.47431 .96683 m
.47491 .96672 L
s
1 .75 0 r
.008 w
.47491 .96672 Mdot
.016 w
.47491 .96672 m
.47555 .96667 L
s
1 .744 0 r
.008 w
.47555 .96667 Mdot
.016 w
.47555 .96667 m
.47623 .96665 L
s
1 .737 0 r
.008 w
.47623 .96665 Mdot
.016 w
.47623 .96665 m
.47704 .96663 L
s
1 .731 0 r
.008 w
.47704 .96663 Mdot
.016 w
.47704 .96663 m
.47801 .96657 L
s
1 .724 0 r
.008 w
.47801 .96657 Mdot
.016 w
.47801 .96657 m
.47923 .96648 L
s
1 .718 0 r
.008 w
.47923 .96648 Mdot
.016 w
.47923 .96648 m
.48065 .96628 L
s
1 .712 0 r
.008 w
.48065 .96628 Mdot
.016 w
.48065 .96628 m
.48216 .96594 L
s
1 .705 0 r
.008 w
.48216 .96594 Mdot
.016 w
.48216 .96594 m
.48399 .96546 L
s
1 .699 0 r
.008 w
.48399 .96546 Mdot
.016 w
.48399 .96546 m
.48607 .96485 L
s
1 .692 0 r
.008 w
.48607 .96485 Mdot
.016 w
.48607 .96485 m
.48836 .96416 L
s
1 .686 0 r
.008 w
.48836 .96416 Mdot
.016 w
.48836 .96416 m
.49075 .96343 L
s
1 .679 0 r
.008 w
.49075 .96343 Mdot
.016 w
.49075 .96343 m
.49311 .96268 L
s
1 .673 0 r
.008 w
.49311 .96268 Mdot
.016 w
.49311 .96268 m
.49536 .96191 L
s
1 .667 0 r
.008 w
.49536 .96191 Mdot
.016 w
.49536 .96191 m
.49745 .96127 L
s
1 .66 0 r
.008 w
.49745 .96127 Mdot
.016 w
.49745 .96127 m
.49921 .96066 L
s
1 .654 0 r
.008 w
.49921 .96066 Mdot
.016 w
.49921 .96066 m
.50064 .96011 L
s
1 .647 0 r
.008 w
.50064 .96011 Mdot
.016 w
.50064 .96011 m
.50167 .95958 L
s
1 .641 0 r
.008 w
.50167 .95958 Mdot
.016 w
.50167 .95958 m
.50241 .95913 L
s
1 .635 0 r
.008 w
.50241 .95913 Mdot
.016 w
.50241 .95913 m
.50284 .95874 L
s
1 .628 0 r
.008 w
.50284 .95874 Mdot
.016 w
.50284 .95874 m
.50307 .95851 L
s
1 .622 0 r
.008 w
.50307 .95851 Mdot
.016 w
.50307 .95851 m
.50325 .95838 L
s
1 .615 0 r
.008 w
.50325 .95838 Mdot
.016 w
.50325 .95838 m
.50345 .95836 L
s
1 .609 0 r
.008 w
.50345 .95836 Mdot
.016 w
.50345 .95836 m
.50371 .95841 L
s
1 .603 0 r
.008 w
.50371 .95841 Mdot
.016 w
.50371 .95841 m
.50414 .95854 L
s
1 .596 0 r
.008 w
.50414 .95854 Mdot
.016 w
.50414 .95854 m
.5048 .95875 L
s
1 .59 0 r
.008 w
.5048 .95875 Mdot
.016 w
.5048 .95875 m
.50582 .95906 L
s
1 .583 0 r
.008 w
.50582 .95906 Mdot
.016 w
.50582 .95906 m
.50712 .95938 L
s
1 .577 0 r
.008 w
.50712 .95938 Mdot
.016 w
.50712 .95938 m
.50889 .95978 L
s
1 .571 0 r
.008 w
.50889 .95978 Mdot
.016 w
.50889 .95978 m
.51084 .96019 L
s
1 .564 0 r
.008 w
.51084 .96019 Mdot
.016 w
.51084 .96019 m
.51322 .96058 L
s
1 .558 0 r
.008 w
.51322 .96058 Mdot
.016 w
.51322 .96058 m
.51621 .96107 L
s
1 .551 0 r
.008 w
.51621 .96107 Mdot
.016 w
.51621 .96107 m
.51915 .96145 L
s
1 .545 0 r
.008 w
.51915 .96145 Mdot
.016 w
.51915 .96145 m
.52243 .96174 L
s
1 .538 0 r
.008 w
.52243 .96174 Mdot
.016 w
.52243 .96174 m
.52588 .96189 L
s
1 .532 0 r
.008 w
.52588 .96189 Mdot
.016 w
.52588 .96189 m
.52941 .96188 L
s
1 .526 0 r
.008 w
.52941 .96188 Mdot
.016 w
.52941 .96188 m
.53313 .96174 L
s
1 .519 0 r
.008 w
.53313 .96174 Mdot
.016 w
.53313 .96174 m
.53676 .9615 L
s
1 .513 0 r
.008 w
.53676 .9615 Mdot
.016 w
.53676 .9615 m
.54057 .96107 L
s
1 .506 0 r
.008 w
.54057 .96107 Mdot
.016 w
.54057 .96107 m
.54439 .96047 L
s
1 .5 0 r
.008 w
.54439 .96047 Mdot
.016 w
.54439 .96047 m
.54832 .95974 L
s
1 .494 0 r
.008 w
.54832 .95974 Mdot
.016 w
.54832 .95974 m
.5524 .95892 L
s
1 .487 0 r
.008 w
.5524 .95892 Mdot
.016 w
.5524 .95892 m
.55669 .95804 L
s
1 .481 0 r
.008 w
.55669 .95804 Mdot
.016 w
.55669 .95804 m
.56105 .95716 L
s
1 .474 0 r
.008 w
.56105 .95716 Mdot
.016 w
.56105 .95716 m
.56552 .95633 L
s
1 .468 0 r
.008 w
.56552 .95633 Mdot
.016 w
.56552 .95633 m
.57004 .95561 L
s
1 .462 0 r
.008 w
.57004 .95561 Mdot
.016 w
.57004 .95561 m
.57449 .955 L
s
1 .455 0 r
.008 w
.57449 .955 Mdot
.016 w
.57449 .955 m
.57883 .95446 L
s
1 .449 0 r
.008 w
.57883 .95446 Mdot
.016 w
.57883 .95446 m
.58311 .95399 L
s
1 .442 0 r
.008 w
.58311 .95399 Mdot
.016 w
.58311 .95399 m
.58732 .95358 L
s
1 .436 0 r
.008 w
.58732 .95358 Mdot
.016 w
.58732 .95358 m
.59149 .95319 L
s
1 .429 0 r
.008 w
.59149 .95319 Mdot
.016 w
.59149 .95319 m
.59543 .95281 L
s
1 .423 0 r
.008 w
.59543 .95281 Mdot
.016 w
.59543 .95281 m
.59943 .95243 L
s
1 .417 0 r
.008 w
.59943 .95243 Mdot
.016 w
.59943 .95243 m
.60314 .95204 L
s
1 .41 0 r
.008 w
.60314 .95204 Mdot
.016 w
.60314 .95204 m
.60679 .95162 L
s
1 .404 0 r
.008 w
.60679 .95162 Mdot
.016 w
.60679 .95162 m
.61047 .95114 L
s
1 .397 0 r
.008 w
.61047 .95114 Mdot
.016 w
.61047 .95114 m
.61406 .95057 L
s
1 .391 0 r
.008 w
.61406 .95057 Mdot
.016 w
.61406 .95057 m
.61761 .94989 L
s
1 .385 0 r
.008 w
.61761 .94989 Mdot
.016 w
.61761 .94989 m
.6212 .94909 L
s
1 .378 0 r
.008 w
.6212 .94909 Mdot
.016 w
.6212 .94909 m
.6246 .94813 L
s
1 .372 0 r
.008 w
.6246 .94813 Mdot
.016 w
.6246 .94813 m
.62791 .94709 L
s
1 .365 0 r
.008 w
.62791 .94709 Mdot
.016 w
.62791 .94709 m
.63109 .94599 L
s
1 .359 0 r
.008 w
.63109 .94599 Mdot
.016 w
.63109 .94599 m
.63408 .94486 L
s
1 .353 0 r
.008 w
.63408 .94486 Mdot
.016 w
.63408 .94486 m
.63696 .94372 L
s
1 .346 0 r
.008 w
.63696 .94372 Mdot
.016 w
.63696 .94372 m
.63958 .94267 L
s
1 .34 0 r
.008 w
.63958 .94267 Mdot
.016 w
.63958 .94267 m
.64193 .94172 L
s
1 .333 0 r
.008 w
.64193 .94172 Mdot
.016 w
.64193 .94172 m
.64393 .94093 L
s
1 .327 0 r
.008 w
.64393 .94093 Mdot
.016 w
.64393 .94093 m
.64555 .94028 L
s
1 .321 0 r
.008 w
.64555 .94028 Mdot
.016 w
.64555 .94028 m
.64674 .93982 L
s
1 .314 0 r
.008 w
.64674 .93982 Mdot
.016 w
.64674 .93982 m
.64761 .93956 L
s
1 .308 0 r
.008 w
.64761 .93956 Mdot
.016 w
.64761 .93956 m
.64821 .93947 L
s
1 .301 0 r
.008 w
.64821 .93947 Mdot
.016 w
.64821 .93947 m
.64856 .93954 L
s
1 .295 0 r
.008 w
.64856 .93954 Mdot
.016 w
.64856 .93954 m
.64884 .9396 L
s
1 .288 0 r
.008 w
.64884 .9396 Mdot
.016 w
.64884 .9396 m
.64911 .9397 L
s
1 .282 0 r
.008 w
.64911 .9397 Mdot
.016 w
.64911 .9397 m
.64939 .93978 L
s
1 .276 0 r
.008 w
.64939 .93978 Mdot
.016 w
.64939 .93978 m
.64974 .93978 L
s
1 .269 0 r
.008 w
.64974 .93978 Mdot
.016 w
.64974 .93978 m
.65014 .93969 L
s
1 .263 0 r
.008 w
.65014 .93969 Mdot
.016 w
.65014 .93969 m
.65051 .93959 L
s
1 .256 0 r
.008 w
.65051 .93959 Mdot
.016 w
.65051 .93959 m
.65101 .93934 L
s
1 .25 0 r
.008 w
.65101 .93934 Mdot
.016 w
.65101 .93934 m
.65145 .93901 L
s
1 .244 0 r
.008 w
.65145 .93901 Mdot
.016 w
.65145 .93901 m
.65202 .93847 L
s
1 .237 0 r
.008 w
.65202 .93847 Mdot
.016 w
.65202 .93847 m
.65265 .9378 L
s
1 .231 0 r
.008 w
.65265 .9378 Mdot
.016 w
.65265 .9378 m
.65331 .93703 L
s
1 .224 0 r
.008 w
.65331 .93703 Mdot
.016 w
.65331 .93703 m
.654 .93621 L
s
1 .218 0 r
.008 w
.654 .93621 Mdot
.016 w
.654 .93621 m
.65468 .93538 L
s
1 .212 0 r
.008 w
.65468 .93538 Mdot
.016 w
.65468 .93538 m
.65538 .93456 L
s
1 .205 0 r
.008 w
.65538 .93456 Mdot
.016 w
.65538 .93456 m
.65606 .93376 L
s
1 .199 0 r
.008 w
.65606 .93376 Mdot
.016 w
.65606 .93376 m
.65664 .93303 L
s
1 .192 0 r
.008 w
.65664 .93303 Mdot
.016 w
.65664 .93303 m
.65709 .93236 L
s
1 .186 0 r
.008 w
.65709 .93236 Mdot
.016 w
.65709 .93236 m
.65733 .93191 L
s
1 .179 0 r
.008 w
.65733 .93191 Mdot
.016 w
.65733 .93191 m
.65755 .93153 L
s
1 .173 0 r
.008 w
.65755 .93153 Mdot
.016 w
.65755 .93153 m
.65774 .93127 L
s
1 .167 0 r
.008 w
.65774 .93127 Mdot
.016 w
.65774 .93127 m
.658 .93108 L
s
1 .16 0 r
.008 w
.658 .93108 Mdot
.016 w
.658 .93108 m
.65826 .93108 L
s
1 .154 0 r
.008 w
.65826 .93108 Mdot
.016 w
.65826 .93108 m
.65861 .93119 L
s
1 .147 0 r
.008 w
.65861 .93119 Mdot
.016 w
.65861 .93119 m
.65899 .93142 L
s
1 .141 0 r
.008 w
.65899 .93142 Mdot
.016 w
.65899 .93142 m
.65941 .93173 L
s
1 .135 0 r
.008 w
.65941 .93173 Mdot
.016 w
.65941 .93173 m
.65987 .93206 L
s
1 .128 0 r
.008 w
.65987 .93206 Mdot
.016 w
.65987 .93206 m
.66034 .93239 L
s
1 .122 0 r
.008 w
.66034 .93239 Mdot
.016 w
.66034 .93239 m
.66082 .93268 L
s
1 .115 0 r
.008 w
.66082 .93268 Mdot
.016 w
.66082 .93268 m
.66138 .93295 L
s
1 .109 0 r
.008 w
.66138 .93295 Mdot
.016 w
.66138 .93295 m
.66206 .93326 L
s
1 .103 0 r
.008 w
.66206 .93326 Mdot
.016 w
.66206 .93326 m
.6629 .93352 L
s
1 .096 0 r
.008 w
.6629 .93352 Mdot
.016 w
.6629 .93352 m
.66385 .93372 L
s
1 .09 0 r
.008 w
.66385 .93372 Mdot
.016 w
.66385 .93372 m
.66486 .93381 L
s
1 .083 0 r
.008 w
.66486 .93381 Mdot
.016 w
.66486 .93381 m
.66586 .93385 L
s
1 .077 0 r
.008 w
.66586 .93385 Mdot
.016 w
.66586 .93385 m
.66685 .93382 L
s
1 .071 0 r
.008 w
.66685 .93382 Mdot
.016 w
.66685 .93382 m
.66778 .93373 L
s
1 .064 0 r
.008 w
.66778 .93373 Mdot
.016 w
.66778 .93373 m
.66864 .93361 L
s
1 .058 0 r
.008 w
.66864 .93361 Mdot
.016 w
.66864 .93361 m
.66937 .93351 L
s
1 .051 0 r
.008 w
.66937 .93351 Mdot
.016 w
.66937 .93351 m
.67 .93345 L
s
1 .045 0 r
.008 w
.67 .93345 Mdot
.016 w
.67 .93345 m
.67046 .93346 L
s
1 .038 0 r
.008 w
.67046 .93346 Mdot
.016 w
.67046 .93346 m
.67091 .93354 L
s
1 .032 0 r
.008 w
.67091 .93354 Mdot
.016 w
.67091 .93354 m
.67133 .93365 L
s
1 .026 0 r
.008 w
.67133 .93365 Mdot
.016 w
.67133 .93365 m
.6717 .93377 L
s
1 .019 0 r
.008 w
.6717 .93377 Mdot
.016 w
.6717 .93377 m
.67197 .93385 L
s
1 .013 0 r
.008 w
.67197 .93385 Mdot
.016 w
.67197 .93385 m
.67217 .93391 L
s
1 .006 0 r
.008 w
.67217 .93391 Mdot
.016 w
.67217 .93391 m
.67231 .93392 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(82)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
1 .996 0 r
.008 w
.6724 .93382 Mdot
.016 w
.6724 .93382 m
.67248 .9338 L
s
1 .992 0 r
.008 w
.67248 .9338 Mdot
.016 w
.67248 .9338 m
.67269 .93381 L
s
1 .989 0 r
.008 w
.67269 .93381 Mdot
.016 w
.67269 .93381 m
.67295 .93383 L
s
1 .985 0 r
.008 w
.67295 .93383 Mdot
.016 w
.67295 .93383 m
.67328 .93385 L
s
1 .981 0 r
.008 w
.67328 .93385 Mdot
.016 w
.67328 .93385 m
.67366 .93383 L
s
1 .977 0 r
.008 w
.67366 .93383 Mdot
.016 w
.67366 .93383 m
.67414 .93377 L
s
1 .974 0 r
.008 w
.67414 .93377 Mdot
.016 w
.67414 .93377 m
.67467 .93363 L
s
1 .97 0 r
.008 w
.67467 .93363 Mdot
.016 w
.67467 .93363 m
.67527 .93342 L
s
1 .966 0 r
.008 w
.67527 .93342 Mdot
.016 w
.67527 .93342 m
.67593 .93315 L
s
1 .962 0 r
.008 w
.67593 .93315 Mdot
.016 w
.67593 .93315 m
.6767 .93282 L
s
1 .959 0 r
.008 w
.6767 .93282 Mdot
.016 w
.6767 .93282 m
.67757 .93242 L
s
1 .955 0 r
.008 w
.67757 .93242 Mdot
.016 w
.67757 .93242 m
.67854 .93196 L
s
1 .951 0 r
.008 w
.67854 .93196 Mdot
.016 w
.67854 .93196 m
.67961 .9314 L
s
1 .947 0 r
.008 w
.67961 .9314 Mdot
.016 w
.67961 .9314 m
.68079 .93074 L
s
1 .944 0 r
.008 w
.68079 .93074 Mdot
.016 w
.68079 .93074 m
.68205 .92998 L
s
1 .94 0 r
.008 w
.68205 .92998 Mdot
.016 w
.68205 .92998 m
.68339 .92909 L
s
1 .936 0 r
.008 w
.68339 .92909 Mdot
.016 w
.68339 .92909 m
.68494 .92806 L
s
1 .932 0 r
.008 w
.68494 .92806 Mdot
.016 w
.68494 .92806 m
.68666 .9269 L
s
1 .929 0 r
.008 w
.68666 .9269 Mdot
.016 w
.68666 .9269 m
.68859 .92563 L
s
1 .925 0 r
.008 w
.68859 .92563 Mdot
.016 w
.68859 .92563 m
.69072 .92425 L
s
1 .921 0 r
.008 w
.69072 .92425 Mdot
.016 w
.69072 .92425 m
.69309 .92281 L
s
1 .917 0 r
.008 w
.69309 .92281 Mdot
.016 w
.69309 .92281 m
.69558 .92123 L
s
1 .914 0 r
.008 w
.69558 .92123 Mdot
.016 w
.69558 .92123 m
.69824 .91961 L
s
1 .91 0 r
.008 w
.69824 .91961 Mdot
.016 w
.69824 .91961 m
.70102 .91793 L
s
1 .906 0 r
.008 w
.70102 .91793 Mdot
.016 w
.70102 .91793 m
.70364 .91623 L
s
1 .902 0 r
.008 w
.70364 .91623 Mdot
.016 w
.70364 .91623 m
.70632 .91449 L
s
1 .898 0 r
.008 w
.70632 .91449 Mdot
.016 w
.70632 .91449 m
.70905 .9127 L
s
1 .895 0 r
.008 w
.70905 .9127 Mdot
.016 w
.70905 .9127 m
.71186 .91088 L
s
1 .891 0 r
.008 w
.71186 .91088 Mdot
.016 w
.71186 .91088 m
.71459 .90913 L
s
1 .887 0 r
.008 w
.71459 .90913 Mdot
.016 w
.71459 .90913 m
.71726 .90739 L
s
1 .883 0 r
.008 w
.71726 .90739 Mdot
.016 w
.71726 .90739 m
.71992 .90566 L
s
1 .88 0 r
.008 w
.71992 .90566 Mdot
.016 w
.71992 .90566 m
.72256 .90391 L
s
1 .876 0 r
.008 w
.72256 .90391 Mdot
.016 w
.72256 .90391 m
.7251 .90223 L
s
1 .872 0 r
.008 w
.7251 .90223 Mdot
.016 w
.7251 .90223 m
.72746 .90062 L
s
1 .868 0 r
.008 w
.72746 .90062 Mdot
.016 w
.72746 .90062 m
.72932 .8993 L
s
1 .865 0 r
.008 w
.72932 .8993 Mdot
.016 w
.72932 .8993 m
.73122 .89795 L
s
1 .861 0 r
.008 w
.73122 .89795 Mdot
.016 w
.73122 .89795 m
.73297 .89677 L
s
1 .857 0 r
.008 w
.73297 .89677 Mdot
.016 w
.73297 .89677 m
.73451 .89569 L
s
1 .853 0 r
.008 w
.73451 .89569 Mdot
.016 w
.73451 .89569 m
.73591 .8947 L
s
1 .85 0 r
.008 w
.73591 .8947 Mdot
.016 w
.73591 .8947 m
.73712 .89383 L
s
1 .846 0 r
.008 w
.73712 .89383 Mdot
.016 w
.73712 .89383 m
.73813 .89308 L
s
1 .842 0 r
.008 w
.73813 .89308 Mdot
.016 w
.73813 .89308 m
.73897 .89242 L
s
1 .838 0 r
.008 w
.73897 .89242 Mdot
.016 w
.73897 .89242 m
.73966 .89185 L
s
1 .835 0 r
.008 w
.73966 .89185 Mdot
.016 w
.73966 .89185 m
.74023 .89134 L
s
1 .831 0 r
.008 w
.74023 .89134 Mdot
.016 w
.74023 .89134 m
.74073 .89085 L
s
1 .827 0 r
.008 w
.74073 .89085 Mdot
.016 w
.74073 .89085 m
.74122 .89035 L
s
1 .823 0 r
.008 w
.74122 .89035 Mdot
.016 w
.74122 .89035 m
.74177 .88978 L
s
1 .82 0 r
.008 w
.74177 .88978 Mdot
.016 w
.74177 .88978 m
.74238 .88911 L
s
1 .816 0 r
.008 w
.74238 .88911 Mdot
.016 w
.74238 .88911 m
.74303 .88835 L
s
1 .812 0 r
.008 w
.74303 .88835 Mdot
.016 w
.74303 .88835 m
.74371 .88752 L
s
1 .808 0 r
.008 w
.74371 .88752 Mdot
.016 w
.74371 .88752 m
.7444 .88667 L
s
1 .805 0 r
.008 w
.7444 .88667 Mdot
.016 w
.7444 .88667 m
.74505 .88583 L
s
1 .801 0 r
.008 w
.74505 .88583 Mdot
.016 w
.74505 .88583 m
.74563 .88502 L
s
1 .797 0 r
.008 w
.74563 .88502 Mdot
.016 w
.74563 .88502 m
.74615 .8843 L
s
1 .793 0 r
.008 w
.74615 .8843 Mdot
.016 w
.74615 .8843 m
.74655 .88367 L
s
1 .789 0 r
.008 w
.74655 .88367 Mdot
.016 w
.74655 .88367 m
.74683 .88314 L
s
1 .786 0 r
.008 w
.74683 .88314 Mdot
.016 w
.74683 .88314 m
.74696 .88274 L
s
1 .782 0 r
.008 w
.74696 .88274 Mdot
.016 w
.74696 .88274 m
.74697 .88244 L
s
1 .778 0 r
.008 w
.74697 .88244 Mdot
.016 w
.74697 .88244 m
.74687 .88224 L
s
1 .774 0 r
.008 w
.74687 .88224 Mdot
.016 w
.74687 .88224 m
.7467 .88213 L
s
1 .771 0 r
.008 w
.7467 .88213 Mdot
.016 w
.7467 .88213 m
.74649 .8821 L
s
1 .767 0 r
.008 w
.74649 .8821 Mdot
.016 w
.74649 .8821 m
.74633 .88213 L
s
1 .763 0 r
.008 w
.74633 .88213 Mdot
.016 w
.74633 .88213 m
.74622 .88221 L
s
1 .759 0 r
.008 w
.74622 .88221 Mdot
.016 w
.74622 .88221 m
.7462 .88232 L
s
1 .756 0 r
.008 w
.7462 .88232 Mdot
.016 w
.7462 .88232 m
.74634 .88243 L
s
1 .752 0 r
.008 w
.74634 .88243 Mdot
.016 w
.74634 .88243 m
.74669 .88248 L
s
1 .748 0 r
.008 w
.74669 .88248 Mdot
.016 w
.74669 .88248 m
.74724 .88245 L
s
1 .744 0 r
.008 w
.74724 .88245 Mdot
.016 w
.74724 .88245 m
.74796 .88235 L
s
1 .741 0 r
.008 w
.74796 .88235 Mdot
.016 w
.74796 .88235 m
.74892 .88214 L
s
1 .737 0 r
.008 w
.74892 .88214 Mdot
.016 w
.74892 .88214 m
.75009 .88182 L
s
1 .733 0 r
.008 w
.75009 .88182 Mdot
.016 w
.75009 .88182 m
.75147 .88133 L
s
1 .729 0 r
.008 w
.75147 .88133 Mdot
.016 w
.75147 .88133 m
.75304 .88066 L
s
1 .726 0 r
.008 w
.75304 .88066 Mdot
.016 w
.75304 .88066 m
.75481 .87982 L
s
1 .722 0 r
.008 w
.75481 .87982 Mdot
.016 w
.75481 .87982 m
.75672 .87883 L
s
1 .718 0 r
.008 w
.75672 .87883 Mdot
.016 w
.75672 .87883 m
.75878 .8777 L
s
1 .714 0 r
.008 w
.75878 .8777 Mdot
.016 w
.75878 .8777 m
.76091 .87646 L
s
1 .711 0 r
.008 w
.76091 .87646 Mdot
.016 w
.76091 .87646 m
.76314 .87511 L
s
1 .707 0 r
.008 w
.76314 .87511 Mdot
.016 w
.76314 .87511 m
.76545 .87363 L
s
1 .703 0 r
.008 w
.76545 .87363 Mdot
.016 w
.76545 .87363 m
.76785 .87203 L
s
1 .699 0 r
.008 w
.76785 .87203 Mdot
.016 w
.76785 .87203 m
.77021 .87033 L
s
1 .695 0 r
.008 w
.77021 .87033 Mdot
.016 w
.77021 .87033 m
.77261 .86852 L
s
1 .692 0 r
.008 w
.77261 .86852 Mdot
.016 w
.77261 .86852 m
.77503 .86668 L
s
1 .688 0 r
.008 w
.77503 .86668 Mdot
.016 w
.77503 .86668 m
.77745 .86481 L
s
1 .684 0 r
.008 w
.77745 .86481 Mdot
.016 w
.77745 .86481 m
.77973 .86296 L
s
1 .68 0 r
.008 w
.77973 .86296 Mdot
.016 w
.77973 .86296 m
.78192 .86118 L
s
1 .677 0 r
.008 w
.78192 .86118 Mdot
.016 w
.78192 .86118 m
.78391 .85962 L
s
1 .673 0 r
.008 w
.78391 .85962 Mdot
.016 w
.78391 .85962 m
.78563 .85816 L
s
1 .669 0 r
.008 w
.78563 .85816 Mdot
.016 w
.78563 .85816 m
.78705 .85692 L
s
1 .665 0 r
.008 w
.78705 .85692 Mdot
.016 w
.78705 .85692 m
.78815 .85588 L
s
1 .662 0 r
.008 w
.78815 .85588 Mdot
.016 w
.78815 .85588 m
.78896 .85506 L
s
1 .658 0 r
.008 w
.78896 .85506 Mdot
.016 w
.78896 .85506 m
.78949 .85445 L
s
1 .654 0 r
.008 w
.78949 .85445 Mdot
.016 w
.78949 .85445 m
.7898 .85401 L
s
1 .65 0 r
.008 w
.7898 .85401 Mdot
.016 w
.7898 .85401 m
.78995 .85371 L
s
1 .647 0 r
.008 w
.78995 .85371 Mdot
.016 w
.78995 .85371 m
.79003 .85351 L
s
1 .643 0 r
.008 w
.79003 .85351 Mdot
.016 w
.79003 .85351 m
.79001 .85335 L
s
1 .639 0 r
.008 w
.79001 .85335 Mdot
.016 w
.79001 .85335 m
.78993 .85315 L
s
1 .635 0 r
.008 w
.78993 .85315 Mdot
.016 w
.78993 .85315 m
.7899 .8528 L
s
1 .632 0 r
.008 w
.7899 .8528 Mdot
.016 w
.7899 .8528 m
.78996 .85227 L
s
1 .628 0 r
.008 w
.78996 .85227 Mdot
.016 w
.78996 .85227 m
.79011 .85148 L
s
1 .624 0 r
.008 w
.79011 .85148 Mdot
.016 w
.79011 .85148 m
.79042 .85043 L
s
1 .62 0 r
.008 w
.79042 .85043 Mdot
.016 w
.79042 .85043 m
.79088 .84911 L
s
1 .617 0 r
.008 w
.79088 .84911 Mdot
.016 w
.79088 .84911 m
.7915 .84767 L
s
1 .613 0 r
.008 w
.7915 .84767 Mdot
.016 w
.7915 .84767 m
.7922 .84607 L
s
1 .609 0 r
.008 w
.7922 .84607 Mdot
.016 w
.7922 .84607 m
.7929 .84447 L
s
1 .605 0 r
.008 w
.7929 .84447 Mdot
.016 w
.7929 .84447 m
.7935 .84295 L
s
1 .602 0 r
.008 w
.7935 .84295 Mdot
.016 w
.7935 .84295 m
.79394 .84166 L
s
1 .598 0 r
.008 w
.79394 .84166 Mdot
.016 w
.79394 .84166 m
.79419 .84071 L
s
1 .594 0 r
.008 w
.79419 .84071 Mdot
.016 w
.79419 .84071 m
.79426 .84015 L
s
1 .59 0 r
.008 w
.79426 .84015 Mdot
.016 w
.79426 .84015 m
.7942 .84001 L
s
1 .586 0 r
.008 w
.7942 .84001 Mdot
.016 w
.7942 .84001 m
.7941 .84026 L
s
1 .583 0 r
.008 w
.7941 .84026 Mdot
.016 w
.7941 .84026 m
.79401 .84078 L
s
1 .579 0 r
.008 w
.79401 .84078 Mdot
.016 w
.79401 .84078 m
.79407 .84143 L
s
1 .575 0 r
.008 w
.79407 .84143 Mdot
.016 w
.79407 .84143 m
.79436 .84216 L
s
1 .571 0 r
.008 w
.79436 .84216 Mdot
.016 w
.79436 .84216 m
.79484 .84266 L
s
1 .568 0 r
.008 w
.79484 .84266 Mdot
.016 w
.79484 .84266 m
.79558 .84318 L
s
1 .564 0 r
.008 w
.79558 .84318 Mdot
.016 w
.79558 .84318 m
.79657 .84354 L
s
1 .56 0 r
.008 w
.79657 .84354 Mdot
.016 w
.79657 .84354 m
.79779 .84367 L
s
1 .556 0 r
.008 w
.79779 .84367 Mdot
.016 w
.79779 .84367 m
.79933 .84354 L
s
1 .553 0 r
.008 w
.79933 .84354 Mdot
.016 w
.79933 .84354 m
.80117 .84308 L
s
1 .549 0 r
.008 w
.80117 .84308 Mdot
.016 w
.80117 .84308 m
.80328 .8422 L
s
1 .545 0 r
.008 w
.80328 .8422 Mdot
.016 w
.80328 .8422 m
.80571 .84089 L
s
1 .541 0 r
.008 w
.80571 .84089 Mdot
.016 w
.80571 .84089 m
.80829 .83927 L
s
1 .538 0 r
.008 w
.80829 .83927 Mdot
.016 w
.80829 .83927 m
.81103 .83732 L
s
1 .534 0 r
.008 w
.81103 .83732 Mdot
.016 w
.81103 .83732 m
.81381 .83514 L
s
1 .53 0 r
.008 w
.81381 .83514 Mdot
.016 w
.81381 .83514 m
.81662 .83272 L
s
1 .526 0 r
.008 w
.81662 .83272 Mdot
.016 w
.81662 .83272 m
.81948 .83024 L
s
1 .523 0 r
.008 w
.81948 .83024 Mdot
.016 w
.81948 .83024 m
.82226 .8278 L
s
1 .519 0 r
.008 w
.82226 .8278 Mdot
.016 w
.82226 .8278 m
.82515 .82526 L
s
1 .515 0 r
.008 w
.82515 .82526 Mdot
.016 w
.82515 .82526 m
.82802 .82275 L
s
1 .511 0 r
.008 w
.82802 .82275 Mdot
.016 w
.82802 .82275 m
.83096 .82026 L
s
1 .508 0 r
.008 w
.83096 .82026 Mdot
.016 w
.83096 .82026 m
.83384 .81787 L
s
1 .504 0 r
.008 w
.83384 .81787 Mdot
.016 w
.83384 .81787 m
.83663 .8155 L
s
1 .5 0 r
.008 w
.83663 .8155 Mdot
.016 w
.83663 .8155 m
.83932 .81328 L
s
1 .496 0 r
.008 w
.83932 .81328 Mdot
.016 w
.83932 .81328 m
.84185 .81121 L
s
1 .492 0 r
.008 w
.84185 .81121 Mdot
.016 w
.84185 .81121 m
.84424 .80931 L
s
1 .489 0 r
.008 w
.84424 .80931 Mdot
.016 w
.84424 .80931 m
.8465 .80754 L
s
1 .485 0 r
.008 w
.8465 .80754 Mdot
.016 w
.8465 .80754 m
.84849 .80594 L
s
1 .481 0 r
.008 w
.84849 .80594 Mdot
.016 w
.84849 .80594 m
.85041 .8044 L
s
1 .477 0 r
.008 w
.85041 .8044 Mdot
.016 w
.85041 .8044 m
.85224 .8028 L
s
1 .474 0 r
.008 w
.85224 .8028 Mdot
.016 w
.85224 .8028 m
.85416 .80109 L
s
1 .47 0 r
.008 w
.85416 .80109 Mdot
.016 w
.85416 .80109 m
.85591 .79922 L
s
1 .466 0 r
.008 w
.85591 .79922 Mdot
.016 w
.85591 .79922 m
.85731 .79743 L
s
1 .462 0 r
.008 w
.85731 .79743 Mdot
.016 w
.85731 .79743 m
.85884 .79536 L
s
1 .459 0 r
.008 w
.85884 .79536 Mdot
.016 w
.85884 .79536 m
.86016 .79331 L
s
1 .455 0 r
.008 w
.86016 .79331 Mdot
.016 w
.86016 .79331 m
.86162 .79097 L
s
1 .451 0 r
.008 w
.86162 .79097 Mdot
.016 w
.86162 .79097 m
.86277 .78887 L
s
1 .447 0 r
.008 w
.86277 .78887 Mdot
.016 w
.86277 .78887 m
.86402 .78663 L
s
1 .444 0 r
.008 w
.86402 .78663 Mdot
.016 w
.86402 .78663 m
.86526 .7843 L
s
1 .44 0 r
.008 w
.86526 .7843 Mdot
.016 w
.86526 .7843 m
.86644 .78192 L
s
1 .436 0 r
.008 w
.86644 .78192 Mdot
.016 w
.86644 .78192 m
.86752 .77948 L
s
1 .432 0 r
.008 w
.86752 .77948 Mdot
.016 w
.86752 .77948 m
.86846 .77708 L
s
1 .429 0 r
.008 w
.86846 .77708 Mdot
.016 w
.86846 .77708 m
.86926 .77468 L
s
1 .425 0 r
.008 w
.86926 .77468 Mdot
.016 w
.86926 .77468 m
.86994 .77208 L
s
1 .421 0 r
.008 w
.86994 .77208 Mdot
.016 w
.86994 .77208 m
.87038 .76986 L
s
1 .417 0 r
.008 w
.87038 .76986 Mdot
.016 w
.87038 .76986 m
.87077 .76756 L
s
1 .414 0 r
.008 w
.87077 .76756 Mdot
.016 w
.87077 .76756 m
.87109 .76558 L
s
1 .41 0 r
.008 w
.87109 .76558 Mdot
.016 w
.87109 .76558 m
.87137 .76367 L
s
1 .406 0 r
.008 w
.87137 .76367 Mdot
.016 w
.87137 .76367 m
.87155 .76194 L
s
1 .402 0 r
.008 w
.87155 .76194 Mdot
.016 w
.87155 .76194 m
.87167 .76049 L
s
1 .398 0 r
.008 w
.87167 .76049 Mdot
.016 w
.87167 .76049 m
.87174 .75926 L
s
1 .395 0 r
.008 w
.87174 .75926 Mdot
.016 w
.87174 .75926 m
.87175 .75824 L
s
1 .391 0 r
.008 w
.87175 .75824 Mdot
.016 w
.87175 .75824 m
.87174 .75741 L
s
1 .387 0 r
.008 w
.87174 .75741 Mdot
.016 w
.87174 .75741 m
.87173 .75675 L
s
1 .383 0 r
.008 w
.87173 .75675 Mdot
.016 w
.87173 .75675 m
.87173 .75623 L
s
1 .38 0 r
.008 w
.87173 .75623 Mdot
.016 w
.87173 .75623 m
.87176 .75594 L
s
1 .376 0 r
.008 w
.87176 .75594 Mdot
.016 w
.87176 .75594 m
.87188 .75581 L
s
1 .372 0 r
.008 w
.87188 .75581 Mdot
.016 w
.87188 .75581 m
.87213 .75569 L
s
1 .368 0 r
.008 w
.87213 .75569 Mdot
.016 w
.87213 .75569 m
.87254 .75542 L
s
1 .365 0 r
.008 w
.87254 .75542 Mdot
.016 w
.87254 .75542 m
.87309 .75484 L
s
1 .361 0 r
.008 w
.87309 .75484 Mdot
.016 w
.87309 .75484 m
.8738 .7539 L
s
1 .357 0 r
.008 w
.8738 .7539 Mdot
.016 w
.8738 .7539 m
.87466 .75257 L
s
1 .353 0 r
.008 w
.87466 .75257 Mdot
.016 w
.87466 .75257 m
.87566 .75083 L
s
1 .35 0 r
.008 w
.87566 .75083 Mdot
.016 w
.87566 .75083 m
.87681 .74871 L
s
1 .346 0 r
.008 w
.87681 .74871 Mdot
.016 w
.87681 .74871 m
.87806 .74627 L
s
1 .342 0 r
.008 w
.87806 .74627 Mdot
.016 w
.87806 .74627 m
.87939 .74349 L
s
1 .338 0 r
.008 w
.87939 .74349 Mdot
.016 w
.87939 .74349 m
.88075 .74056 L
s
1 .335 0 r
.008 w
.88075 .74056 Mdot
.016 w
.88075 .74056 m
.88211 .73735 L
s
1 .331 0 r
.008 w
.88211 .73735 Mdot
.016 w
.88211 .73735 m
.88344 .73403 L
s
1 .327 0 r
.008 w
.88344 .73403 Mdot
.016 w
.88344 .73403 m
.88474 .7305 L
s
1 .323 0 r
.008 w
.88474 .7305 Mdot
.016 w
.88474 .7305 m
.88598 .72694 L
s
1 .32 0 r
.008 w
.88598 .72694 Mdot
.016 w
.88598 .72694 m
.88715 .72328 L
s
1 .316 0 r
.008 w
.88715 .72328 Mdot
.016 w
.88715 .72328 m
.88822 .71964 L
s
1 .312 0 r
.008 w
.88822 .71964 Mdot
.016 w
.88822 .71964 m
.88919 .71608 L
s
1 .308 0 r
.008 w
.88919 .71608 Mdot
.016 w
.88919 .71608 m
.89007 .71276 L
s
1 .305 0 r
.008 w
.89007 .71276 Mdot
.016 w
.89007 .71276 m
.89083 .70962 L
s
1 .301 0 r
.008 w
.89083 .70962 Mdot
.016 w
.89083 .70962 m
.89147 .70688 L
s
1 .297 0 r
.008 w
.89147 .70688 Mdot
.016 w
.89147 .70688 m
.89195 .70446 L
s
1 .293 0 r
.008 w
.89195 .70446 Mdot
.016 w
.89195 .70446 m
.89231 .70239 L
s
1 .289 0 r
.008 w
.89231 .70239 Mdot
.016 w
.89231 .70239 m
.89258 .70065 L
s
1 .286 0 r
.008 w
.89258 .70065 Mdot
.016 w
.89258 .70065 m
.89279 .69921 L
s
1 .282 0 r
.008 w
.89279 .69921 Mdot
.016 w
.89279 .69921 m
.89297 .69803 L
s
1 .278 0 r
.008 w
.89297 .69803 Mdot
.016 w
.89297 .69803 m
.89316 .69713 L
s
1 .274 0 r
.008 w
.89316 .69713 Mdot
.016 w
.89316 .69713 m
.89338 .69639 L
s
1 .271 0 r
.008 w
.89338 .69639 Mdot
.016 w
.89338 .69639 m
.89361 .69582 L
s
1 .267 0 r
.008 w
.89361 .69582 Mdot
.016 w
.89361 .69582 m
.89389 .69525 L
s
1 .263 0 r
.008 w
.89389 .69525 Mdot
.016 w
.89389 .69525 m
.89425 .69463 L
s
1 .259 0 r
.008 w
.89425 .69463 Mdot
.016 w
.89425 .69463 m
.89471 .69381 L
s
1 .256 0 r
.008 w
.89471 .69381 Mdot
.016 w
.89471 .69381 m
.89521 .69299 L
s
1 .252 0 r
.008 w
.89521 .69299 Mdot
.016 w
.89521 .69299 m
.89579 .69183 L
s
1 .248 0 r
.008 w
.89579 .69183 Mdot
.016 w
.89579 .69183 m
.89653 .69028 L
s
1 .244 0 r
.008 w
.89653 .69028 Mdot
.016 w
.89653 .69028 m
.89712 .68872 L
s
1 .241 0 r
.008 w
.89712 .68872 Mdot
.016 w
.89712 .68872 m
.89769 .68697 L
s
1 .237 0 r
.008 w
.89769 .68697 Mdot
.016 w
.89769 .68697 m
.89821 .685 L
s
1 .233 0 r
.008 w
.89821 .685 Mdot
.016 w
.89821 .685 m
.89864 .68283 L
s
1 .229 0 r
.008 w
.89864 .68283 Mdot
.016 w
.89864 .68283 m
.89898 .68054 L
s
1 .226 0 r
.008 w
.89898 .68054 Mdot
.016 w
.89898 .68054 m
.89921 .67824 L
s
1 .222 0 r
.008 w
.89921 .67824 Mdot
.016 w
.89921 .67824 m
.89931 .67612 L
s
1 .218 0 r
.008 w
.89931 .67612 Mdot
.016 w
.89931 .67612 m
.8993 .67415 L
s
1 .214 0 r
.008 w
.8993 .67415 Mdot
.016 w
.8993 .67415 m
.8992 .67246 L
s
1 .211 0 r
.008 w
.8992 .67246 Mdot
.016 w
.8992 .67246 m
.89902 .67114 L
s
1 .207 0 r
.008 w
.89902 .67114 Mdot
.016 w
.89902 .67114 m
.89884 .67016 L
s
1 .203 0 r
.008 w
.89884 .67016 Mdot
.016 w
.89884 .67016 m
.89871 .66945 L
s
1 .199 0 r
.008 w
.89871 .66945 Mdot
.016 w
.89871 .66945 m
.89865 .66901 L
s
1 .195 0 r
.008 w
.89865 .66901 Mdot
.016 w
.89865 .66901 m
.89864 .66886 L
s
1 .192 0 r
.008 w
.89864 .66886 Mdot
.016 w
.89864 .66886 m
.89868 .6689 L
s
1 .188 0 r
.008 w
.89868 .6689 Mdot
.016 w
.89868 .6689 m
.89875 .6691 L
s
1 .184 0 r
.008 w
.89875 .6691 Mdot
.016 w
.89875 .6691 m
.89879 .66946 L
s
1 .18 0 r
.008 w
.89879 .66946 Mdot
.016 w
.89879 .66946 m
.89879 .66998 L
s
1 .177 0 r
.008 w
.89879 .66998 Mdot
.016 w
.89879 .66998 m
.89871 .67068 L
s
1 .173 0 r
.008 w
.89871 .67068 Mdot
.016 w
.89871 .67068 m
.89852 .67147 L
s
1 .169 0 r
.008 w
.89852 .67147 Mdot
.016 w
.89852 .67147 m
.89821 .67232 L
s
1 .165 0 r
.008 w
.89821 .67232 Mdot
.016 w
.89821 .67232 m
.89779 .67309 L
s
1 .162 0 r
.008 w
.89779 .67309 Mdot
.016 w
.89779 .67309 m
.89725 .67369 L
s
1 .158 0 r
.008 w
.89725 .67369 Mdot
.016 w
.89725 .67369 m
.89665 .6741 L
s
1 .154 0 r
.008 w
.89665 .6741 Mdot
.016 w
.89665 .6741 m
.89594 .67436 L
s
1 .15 0 r
.008 w
.89594 .67436 Mdot
.016 w
.89594 .67436 m
.89506 .67453 L
s
1 .147 0 r
.008 w
.89506 .67453 Mdot
.016 w
.89506 .67453 m
.89403 .67467 L
s
1 .143 0 r
.008 w
.89403 .67467 Mdot
.016 w
.89403 .67467 m
.89287 .6748 L
s
1 .139 0 r
.008 w
.89287 .6748 Mdot
.016 w
.89287 .6748 m
.89153 .67497 L
s
1 .135 0 r
.008 w
.89153 .67497 Mdot
.016 w
.89153 .67497 m
.89011 .6751 L
s
1 .132 0 r
.008 w
.89011 .6751 Mdot
.016 w
.89011 .6751 m
.88868 .67511 L
s
1 .128 0 r
.008 w
.88868 .67511 Mdot
.016 w
.88868 .67511 m
.88726 .67496 L
s
1 .124 0 r
.008 w
.88726 .67496 Mdot
.016 w
.88726 .67496 m
.88593 .67469 L
s
1 .12 0 r
.008 w
.88593 .67469 Mdot
.016 w
.88593 .67469 m
.88482 .67435 L
s
1 .117 0 r
.008 w
.88482 .67435 Mdot
.016 w
.88482 .67435 m
.88381 .67396 L
s
1 .113 0 r
.008 w
.88381 .67396 Mdot
.016 w
.88381 .67396 m
.88286 .67362 L
s
1 .109 0 r
.008 w
.88286 .67362 Mdot
.016 w
.88286 .67362 m
.88199 .67334 L
s
1 .105 0 r
.008 w
.88199 .67334 Mdot
.016 w
.88199 .67334 m
.88127 .67312 L
s
1 .102 0 r
.008 w
.88127 .67312 Mdot
.016 w
.88127 .67312 m
.8808 .67291 L
s
1 .098 0 r
.008 w
.8808 .67291 Mdot
.016 w
.8808 .67291 m
.88045 .67274 L
s
1 .094 0 r
.008 w
.88045 .67274 Mdot
.016 w
.88045 .67274 m
.88024 .67265 L
s
1 .09 0 r
.008 w
.88024 .67265 Mdot
.016 w
.88024 .67265 m
.88019 .67265 L
s
1 .086 0 r
.008 w
.88019 .67265 Mdot
.016 w
.88019 .67265 m
.88027 .67279 L
s
1 .083 0 r
.008 w
.88027 .67279 Mdot
.016 w
.88027 .67279 m
.88044 .67314 L
s
1 .079 0 r
.008 w
.88044 .67314 Mdot
.016 w
.88044 .67314 m
.88064 .6738 L
s
1 .075 0 r
.008 w
.88064 .6738 Mdot
.016 w
.88064 .6738 m
.88084 .67485 L
s
1 .071 0 r
.008 w
.88084 .67485 Mdot
.016 w
.88084 .67485 m
.881 .67631 L
s
1 .068 0 r
.008 w
.881 .67631 Mdot
.016 w
.881 .67631 m
.88113 .67822 L
s
1 .064 0 r
.008 w
.88113 .67822 Mdot
.016 w
.88113 .67822 m
.88125 .68056 L
s
1 .06 0 r
.008 w
.88125 .68056 Mdot
.016 w
.88125 .68056 m
.88132 .68314 L
s
1 .056 0 r
.008 w
.88132 .68314 Mdot
.016 w
.88132 .68314 m
.88131 .68613 L
s
1 .053 0 r
.008 w
.88131 .68613 Mdot
.016 w
.88131 .68613 m
.88126 .68925 L
s
1 .049 0 r
.008 w
.88126 .68925 Mdot
.016 w
.88126 .68925 m
.88121 .69265 L
s
1 .045 0 r
.008 w
.88121 .69265 Mdot
.016 w
.88121 .69265 m
.88118 .69572 L
s
1 .041 0 r
.008 w
.88118 .69572 Mdot
.016 w
.88118 .69572 m
.88115 .69878 L
s
1 .038 0 r
.008 w
.88115 .69878 Mdot
.016 w
.88115 .69878 m
.88114 .70173 L
s
1 .034 0 r
.008 w
.88114 .70173 Mdot
.016 w
.88114 .70173 m
.88113 .70434 L
s
1 .03 0 r
.008 w
.88113 .70434 Mdot
.016 w
.88113 .70434 m
.88111 .70657 L
s
1 .026 0 r
.008 w
.88111 .70657 Mdot
.016 w
.88111 .70657 m
.8811 .70848 L
s
1 .023 0 r
.008 w
.8811 .70848 Mdot
.016 w
.8811 .70848 m
.88108 .71004 L
s
1 .019 0 r
.008 w
.88108 .71004 Mdot
.016 w
.88108 .71004 m
.88107 .7112 L
s
1 .015 0 r
.008 w
.88107 .7112 Mdot
.016 w
.88107 .7112 m
.88105 .71204 L
s
1 .011 0 r
.008 w
.88105 .71204 Mdot
.016 w
.88105 .71204 m
.88103 .71264 L
s
1 .008 0 r
.008 w
.88103 .71264 Mdot
.016 w
.88103 .71264 m
.88101 .71301 L
s
1 .004 0 r
.008 w
.88101 .71301 Mdot
.016 w
.88101 .71301 m
.88099 .71322 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(83)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
1 .967 0 r
.008 w
.88107 .71365 Mdot
.016 w
.88107 .71365 m
.88098 .71385 L
s
1 .933 0 r
.008 w
.88098 .71385 Mdot
.016 w
.88098 .71385 m
.88087 .71406 L
s
1 .9 0 r
.008 w
.88087 .71406 Mdot
.016 w
.88087 .71406 m
.88072 .71434 L
s
1 .867 0 r
.008 w
.88072 .71434 Mdot
.016 w
.88072 .71434 m
.88055 .71475 L
s
1 .833 0 r
.008 w
.88055 .71475 Mdot
.016 w
.88055 .71475 m
.88038 .7153 L
s
1 .8 0 r
.008 w
.88038 .7153 Mdot
.016 w
.88038 .7153 m
.88021 .71598 L
s
1 .767 0 r
.008 w
.88021 .71598 Mdot
.016 w
.88021 .71598 m
.88007 .71681 L
s
1 .733 0 r
.008 w
.88007 .71681 Mdot
.016 w
.88007 .71681 m
.87997 .71782 L
s
1 .7 0 r
.008 w
.87997 .71782 Mdot
.016 w
.87997 .71782 m
.87991 .71904 L
s
1 .667 0 r
.008 w
.87991 .71904 Mdot
.016 w
.87991 .71904 m
.87991 .72047 L
s
1 .633 0 r
.008 w
.87991 .72047 Mdot
.016 w
.87991 .72047 m
.88 .72207 L
s
1 .6 0 r
.008 w
.88 .72207 Mdot
.016 w
.88 .72207 m
.88016 .72383 L
s
1 .567 0 r
.008 w
.88016 .72383 Mdot
.016 w
.88016 .72383 m
.88037 .72562 L
s
1 .533 0 r
.008 w
.88037 .72562 Mdot
.016 w
.88037 .72562 m
.88061 .72757 L
s
1 .5 0 r
.008 w
.88061 .72757 Mdot
.016 w
.88061 .72757 m
.88082 .72968 L
s
1 .467 0 r
.008 w
.88082 .72968 Mdot
.016 w
.88082 .72968 m
.88098 .73197 L
s
1 .433 0 r
.008 w
.88098 .73197 Mdot
.016 w
.88098 .73197 m
.88104 .73447 L
s
1 .4 0 r
.008 w
.88104 .73447 Mdot
.016 w
.88104 .73447 m
.88098 .73709 L
s
1 .367 0 r
.008 w
.88098 .73709 Mdot
.016 w
.88098 .73709 m
.88077 .73965 L
s
1 .333 0 r
.008 w
.88077 .73965 Mdot
.016 w
.88077 .73965 m
.88043 .74225 L
s
1 .3 0 r
.008 w
.88043 .74225 Mdot
.016 w
.88043 .74225 m
.87998 .74478 L
s
1 .267 0 r
.008 w
.87998 .74478 Mdot
.016 w
.87998 .74478 m
.87947 .74708 L
s
1 .233 0 r
.008 w
.87947 .74708 Mdot
.016 w
.87947 .74708 m
.87896 .74894 L
s
1 .2 0 r
.008 w
.87896 .74894 Mdot
.016 w
.87896 .74894 m
.87844 .75057 L
s
1 .167 0 r
.008 w
.87844 .75057 Mdot
.016 w
.87844 .75057 m
.87794 .75196 L
s
1 .133 0 r
.008 w
.87794 .75196 Mdot
.016 w
.87794 .75196 m
.8775 .753 L
s
1 .1 0 r
.008 w
.8775 .753 Mdot
.016 w
.8775 .753 m
.87714 .7538 L
s
1 .067 0 r
.008 w
.87714 .7538 Mdot
.016 w
.87714 .7538 m
.87689 .75444 L
s
1 .033 0 r
.008 w
.87689 .75444 Mdot
.016 w
.87689 .75444 m
.87676 .75474 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_dgoo23g_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_dWoo1cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?NoBOol4Oj03?Nl8Ool00`00Oomoo`0HOol001Yoo`04001o
ogooOol6?NoAOol4O^000gmP?Nlmk`08Ool00`00Oomoo`0IOol001]oo`03001oogoo00Hmkm5oo`An
P003Of0mkcg_00Moo`03001oogoo01Yoo`006goo00<007ooOol01Sg_dGoo17i000=oH3g_?Nl01goo
00<007ooOol06Woo000LOol00`00Oolmk`05?NoAOol00ghPON1mh002ON02?Nl6Ool00`00Oomoo`0K
Ool001aoo`03001oogoo00Dmkm5oo`03OR1mX7fP009mX003?Nmoogoo00Eoo`03001oogoo01]oo`00
7Goo00<007oo?Nl013g_dGoo00=n87f0OH000Wf000<mkgooOol017oo00<007ooOol077oo000MOol0
0`00Oolmk`05?No@Ool00ghPOF1mH002OF000cg_Oomoo`04Ool00`00Oomoo`0LOol001ioo`03000m
kcg_00@mkm1oo`Am8003OD1oogoo00Aoo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_cgoo17d0
00=m@7ooOol017oo00<007ooOol07Goo000OOol7?No>Ool01Sg_O<1l@7a0O<1m@0Eoo`03001oogoo
01ioo`007goo00<003g_?Nl01Cg_cGoo00<mkga0O4000Wa000=m@7ooOol00goo00<007ooOol07Woo
000POol00`00?Nlmk`05?No;Ool013g_O41l@7`P0ga017oo00<007ooOol07goo000POol00`00?Nlm
k`06?No:Ool013g_O41l@7`P0Wa01Goo00<007ooOol07goo000QOol9?No9Ool2?Nl3O4000gc0Oomo
o`02Ool00`00Oomoo`0POol0029oo`03000mkcg_00HmklQoo`<mk`03O41oogoo00=oo`03001oogoo
025oo`008goo23g_b7oo13g_17oo00<007ooOol08Woo000TOol9?No5Ool5?Nl3Ool00`00Oomoo`0S
Ool002Aoo`03000mkcg_00LmklAoo`Dmk`=oo`03001oogoo02=oo`009Goo2Sg_`goo13g_0goo00<0
07ooOol097oo000VOol00`00?Nlmk`07?No1Ool6?Nl00goo001oo`0VOol002Ioo`03001oocg_00/m
kkeoo`Dmk`9oo`03001oogoo02Eoo`009goo00<007oo?Nl02Sg__7oo1Sg_00=oo`00Ool09goo000X
Ool00`00Oolmk`09?NnkOol6?Nl00goo001oo`0XOol002Uoo`03001oocg_00TmkkUoo`Hmk`03Ool0
07oo02Uoo`00:Woo00<007oo?Nl023g_^7oo1cg_00<007ooOol0:Goo000ZOol00`00Oomoo`09?Nnf
Ool8?Nl00`00Oomoo`0YOol002]oo`03001oogoo00TmkkAoo`Pmk`03001oogoo02Yoo`00;7oo00<0
07oo?Nl023g_/Woo2Cg_00<007ooOol0:goo000]Ool00`00Oolmk`08?NnaOol8?Nl00`00Oomoo`0/
Ool002ioo`03001oogoo00Pmkjioo`Tmk`03001oogoo02eoo`00;Woo00@007ooOomoo`Pmkjaoo`Lm
k`=oo`03001oogoo02eoo`00;goo00@007ooOomoo`TmkjUoo`Lmk`=oo`03001oogoo02ioo`00<7oo
00@007ooOomoo`PmkjQoo`Lmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo`PmkjEoo`Lmk`Ao
o`03001oogoo031oo`00<Woo0P000Woo23g_XGoo2Cg_0goo0P00<goo000dOol00`00Oomoo`08?NnN
Ool:?Nl3Ool00`00Oomoo`0cOol003Eoo`03001oocg_00Pmkieoo`Tmk`=oo`03001oogoo03Aoo`00
=Goo00@007ooOomoo`Pmkiaoo`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkiYoo`Lm
k`Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<007ooOol0=Woo000h
Ool00`00Oomoo`02Ool7?NnFOol7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki=oo`Pmk`=o
o`8003Yoo`00>goo00<007ooOol02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000lOol00`00Oomoo`09
?Nn>Ool9?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eoo`03001oogoo03ao
o`00?Woo0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3Ool00`00
Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo00<007oo?Nl02Cg_
NWoo1Cg_00=oocg_?Nl01Cg_1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?NmjOol=?Nl4Ool0
0`00Oomoo`13Ool004Eoo`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_
?Nl02Sg_MGoo33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYo
o``mk`9oo`8004]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomo
o`1=Ool004moo`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P000Woo43g_FGoo
00<mkgooOol02Sg_0goo0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>?Nl00goo
0000001COol005Aoo`800003?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool0000005Eoo`00EWoo0P00
17oo43g_0goo1Sg_@Woo43g_0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00Oomoo`1GOol005]o
o`<000=ooa@mkceooa0mk`8005aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001POol20004OolC?NlX
OolN?NmQOol0069oo`<000Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`001Goo5Cg_
1goo2Cg_0goo8Sg_0`00IWoo001XOol40003Oom4?Nl4001YOol006aoo`@000=ooc/mk`03Ool00000
008006eoo`00L7oo0`000goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol0
07Qoo`@001dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000Aoo`8008eoo`00RWoo00@007ooOol0009oo`04
001oogoo002<Ool008Yoo`04001oogoo0004Ool00`00Oomoo`2;Ool008]oo`8000Ioo`03001oogoo
08Yoo`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(84)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
1 .987 0 r
.008 w
.87837 .75257 Mdot
.016 w
.87837 .75257 m
.87828 .75286 L
s
1 .974 0 r
.008 w
.87828 .75286 Mdot
.016 w
.87828 .75286 m
.87801 .75341 L
s
1 .961 0 r
.008 w
.87801 .75341 Mdot
.016 w
.87801 .75341 m
.87754 .75421 L
s
1 .948 0 r
.008 w
.87754 .75421 Mdot
.016 w
.87754 .75421 m
.87688 .75527 L
s
1 .935 0 r
.008 w
.87688 .75527 Mdot
.016 w
.87688 .75527 m
.87604 .75659 L
s
1 .922 0 r
.008 w
.87604 .75659 Mdot
.016 w
.87604 .75659 m
.87505 .75815 L
s
1 .909 0 r
.008 w
.87505 .75815 Mdot
.016 w
.87505 .75815 m
.87401 .75979 L
s
1 .896 0 r
.008 w
.87401 .75979 Mdot
.016 w
.87401 .75979 m
.87288 .76147 L
s
1 .883 0 r
.008 w
.87288 .76147 Mdot
.016 w
.87288 .76147 m
.87172 .7631 L
s
1 .87 0 r
.008 w
.87172 .7631 Mdot
.016 w
.87172 .7631 m
.87054 .76463 L
s
1 .857 0 r
.008 w
.87054 .76463 Mdot
.016 w
.87054 .76463 m
.86939 .76612 L
s
1 .844 0 r
.008 w
.86939 .76612 Mdot
.016 w
.86939 .76612 m
.86836 .76738 L
s
1 .831 0 r
.008 w
.86836 .76738 Mdot
.016 w
.86836 .76738 m
.86747 .76846 L
s
1 .818 0 r
.008 w
.86747 .76846 Mdot
.016 w
.86747 .76846 m
.86677 .76926 L
s
1 .805 0 r
.008 w
.86677 .76926 Mdot
.016 w
.86677 .76926 m
.86628 .76976 L
s
1 .792 0 r
.008 w
.86628 .76976 Mdot
.016 w
.86628 .76976 m
.866 .76997 L
s
1 .779 0 r
.008 w
.866 .76997 Mdot
.016 w
.866 .76997 m
.86594 .76991 L
s
1 .766 0 r
.008 w
.86594 .76991 Mdot
.016 w
.86594 .76991 m
.86605 .7696 L
s
1 .753 0 r
.008 w
.86605 .7696 Mdot
.016 w
.86605 .7696 m
.86629 .76915 L
s
1 .74 0 r
.008 w
.86629 .76915 Mdot
.016 w
.86629 .76915 m
.86661 .76864 L
s
1 .727 0 r
.008 w
.86661 .76864 Mdot
.016 w
.86661 .76864 m
.86691 .76826 L
s
1 .714 0 r
.008 w
.86691 .76826 Mdot
.016 w
.86691 .76826 m
.86721 .76795 L
s
1 .701 0 r
.008 w
.86721 .76795 Mdot
.016 w
.86721 .76795 m
.86747 .76784 L
s
1 .688 0 r
.008 w
.86747 .76784 Mdot
.016 w
.86747 .76784 m
.86764 .76799 L
s
1 .675 0 r
.008 w
.86764 .76799 Mdot
.016 w
.86764 .76799 m
.86772 .76836 L
s
1 .662 0 r
.008 w
.86772 .76836 Mdot
.016 w
.86772 .76836 m
.86776 .76891 L
s
1 .649 0 r
.008 w
.86776 .76891 Mdot
.016 w
.86776 .76891 m
.86774 .76959 L
s
1 .636 0 r
.008 w
.86774 .76959 Mdot
.016 w
.86774 .76959 m
.86767 .77042 L
s
1 .623 0 r
.008 w
.86767 .77042 Mdot
.016 w
.86767 .77042 m
.86757 .77134 L
s
1 .61 0 r
.008 w
.86757 .77134 Mdot
.016 w
.86757 .77134 m
.86746 .77233 L
s
1 .597 0 r
.008 w
.86746 .77233 Mdot
.016 w
.86746 .77233 m
.86733 .77342 L
s
1 .584 0 r
.008 w
.86733 .77342 Mdot
.016 w
.86733 .77342 m
.86718 .77451 L
s
1 .571 0 r
.008 w
.86718 .77451 Mdot
.016 w
.86718 .77451 m
.86701 .77572 L
s
1 .558 0 r
.008 w
.86701 .77572 Mdot
.016 w
.86701 .77572 m
.86689 .77688 L
s
1 .545 0 r
.008 w
.86689 .77688 Mdot
.016 w
.86689 .77688 m
.86683 .77789 L
s
1 .532 0 r
.008 w
.86683 .77789 Mdot
.016 w
.86683 .77789 m
.8668 .77871 L
s
1 .519 0 r
.008 w
.8668 .77871 Mdot
.016 w
.8668 .77871 m
.86676 .77941 L
s
1 .506 0 r
.008 w
.86676 .77941 Mdot
.016 w
.86676 .77941 m
.86669 .78001 L
s
1 .494 0 r
.008 w
.86669 .78001 Mdot
.016 w
.86669 .78001 m
.86656 .78051 L
s
1 .481 0 r
.008 w
.86656 .78051 Mdot
.016 w
.86656 .78051 m
.8664 .7809 L
s
1 .468 0 r
.008 w
.8664 .7809 Mdot
.016 w
.8664 .7809 m
.86622 .78115 L
s
1 .455 0 r
.008 w
.86622 .78115 Mdot
.016 w
.86622 .78115 m
.86607 .78122 L
s
1 .442 0 r
.008 w
.86607 .78122 Mdot
.016 w
.86607 .78122 m
.86594 .78112 L
s
1 .429 0 r
.008 w
.86594 .78112 Mdot
.016 w
.86594 .78112 m
.86589 .78087 L
s
1 .416 0 r
.008 w
.86589 .78087 Mdot
.016 w
.86589 .78087 m
.86585 .78054 L
s
1 .403 0 r
.008 w
.86585 .78054 Mdot
.016 w
.86585 .78054 m
.86584 .78015 L
s
1 .39 0 r
.008 w
.86584 .78015 Mdot
.016 w
.86584 .78015 m
.86586 .77971 L
s
1 .377 0 r
.008 w
.86586 .77971 Mdot
.016 w
.86586 .77971 m
.86592 .7793 L
s
1 .364 0 r
.008 w
.86592 .7793 Mdot
.016 w
.86592 .7793 m
.86599 .77896 L
s
1 .351 0 r
.008 w
.86599 .77896 Mdot
.016 w
.86599 .77896 m
.86609 .77862 L
s
1 .338 0 r
.008 w
.86609 .77862 Mdot
.016 w
.86609 .77862 m
.86622 .77826 L
s
1 .325 0 r
.008 w
.86622 .77826 Mdot
.016 w
.86622 .77826 m
.86634 .77788 L
s
1 .312 0 r
.008 w
.86634 .77788 Mdot
.016 w
.86634 .77788 m
.86644 .77749 L
s
1 .299 0 r
.008 w
.86644 .77749 Mdot
.016 w
.86644 .77749 m
.86651 .77716 L
s
1 .286 0 r
.008 w
.86651 .77716 Mdot
.016 w
.86651 .77716 m
.86655 .7769 L
s
1 .273 0 r
.008 w
.86655 .7769 Mdot
.016 w
.86655 .7769 m
.86655 .77678 L
s
1 .26 0 r
.008 w
.86655 .77678 Mdot
.016 w
.86655 .77678 m
.86651 .77681 L
s
1 .247 0 r
.008 w
.86651 .77681 Mdot
.016 w
.86651 .77681 m
.86635 .77705 L
s
1 .234 0 r
.008 w
.86635 .77705 Mdot
.016 w
.86635 .77705 m
.86609 .77754 L
s
1 .221 0 r
.008 w
.86609 .77754 Mdot
.016 w
.86609 .77754 m
.86572 .77829 L
s
1 .208 0 r
.008 w
.86572 .77829 Mdot
.016 w
.86572 .77829 m
.86526 .77923 L
s
1 .195 0 r
.008 w
.86526 .77923 Mdot
.016 w
.86526 .77923 m
.86472 .7804 L
s
1 .182 0 r
.008 w
.86472 .7804 Mdot
.016 w
.86472 .7804 m
.86408 .7818 L
s
1 .169 0 r
.008 w
.86408 .7818 Mdot
.016 w
.86408 .7818 m
.86333 .78331 L
s
1 .156 0 r
.008 w
.86333 .78331 Mdot
.016 w
.86333 .78331 m
.86243 .78509 L
s
1 .143 0 r
.008 w
.86243 .78509 Mdot
.016 w
.86243 .78509 m
.8614 .78704 L
s
1 .13 0 r
.008 w
.8614 .78704 Mdot
.016 w
.8614 .78704 m
.86027 .78913 L
s
1 .117 0 r
.008 w
.86027 .78913 Mdot
.016 w
.86027 .78913 m
.85908 .79124 L
s
1 .104 0 r
.008 w
.85908 .79124 Mdot
.016 w
.85908 .79124 m
.85799 .79319 L
s
1 .091 0 r
.008 w
.85799 .79319 Mdot
.016 w
.85799 .79319 m
.85693 .79498 L
s
1 .078 0 r
.008 w
.85693 .79498 Mdot
.016 w
.85693 .79498 m
.85597 .79655 L
s
1 .065 0 r
.008 w
.85597 .79655 Mdot
.016 w
.85597 .79655 m
.85512 .79783 L
s
1 .052 0 r
.008 w
.85512 .79783 Mdot
.016 w
.85512 .79783 m
.85444 .79876 L
s
1 .039 0 r
.008 w
.85444 .79876 Mdot
.016 w
.85444 .79876 m
.85391 .79939 L
s
1 .026 0 r
.008 w
.85391 .79939 Mdot
.016 w
.85391 .79939 m
.8535 .79981 L
s
1 .013 0 r
.008 w
.8535 .79981 Mdot
.016 w
.8535 .79981 m
.85322 .80006 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_dgoo23g_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_dWoo1cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?NoBOol7?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?NoAOol7?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00Hmkm5oo`Lmk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_dGoo1cg_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?NoA
Ool7?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Dmkm5oo`Hmk`Moo`03001oogoo01]oo`00
7Goo00<007oo?Nl013g_dGoo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`05?No@Ool6?Nl6
Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mkm1oo`Dmk`Ioo`03001oogoo01eoo`007Woo00<0
03g_?Nl01Cg_cgoo1Cg_1Woo00<007ooOol07Goo000OOol7?No>Ool6?Nl5Ool00`00Oomoo`0NOol0
01moo`03000mkcg_00Dmkleoo`03?Nmo`7o0009o`003?Nmoogoo00=oo`03001oogoo01ioo`0087oo
00<003g_?Nl01Cg_bgoo00HmkgnPOh1oP7nPOl05Ool00`00Oomoo`0OOol0021oo`03000mkcg_00Hm
klYoo`03?NmoH7mP009oP003Ol1oogoo00=oo`03001oogoo01moo`008Goo2Cg_bGoo17mP0Wn017oo
00<007ooOol087oo000ROol00`00?Nlmk`06?No7Ool4OZ02Of001Go0Oomoogoo00008goo000SOol8
?No6Ool00gl0OV1nH002OV000gmPOj1oo`02Ool00`00Oomoo`0ROol002Aoo`TmklAoo`06O`1n87d0
O@1n83g_0goo00<007ooOol08goo000TOol00`00?Nlmk`07?No3Ool4O<000gcP?Nmoo`02Ool00`00
Oomoo`0SOol002Eoo`Xmkl9oo`05O:1lP7b0O:1lh003Ool00`00Oomoo`0TOol002Ioo`03000mkcg_
00Lmkl5oo`AlP004O>0mkgoo000WOol002Ioo`03001oocg_00/mkkaoo`AlH09lP09oo`03001oogoo
02Eoo`009goo00<007oo?Nl02Sg_^goo17a000ElH7b0OL1oo`0002Qoo`00:7oo00<007oo?Nl02Cg_
^goo17a000AlH7bPOol002Uoo`00:Goo00<007oo?Nl02Cg_^Goo1G`P00=lH7oo0000:Woo000ZOol0
0`00Oolmk`08?NnhOol013g_O21l07`00W`P00=lH000Ool0:Woo000ZOol00`00Oomoo`09?NnfOol2
?Nl00g`PO01l0002O2000cg_001oo`0ZOol002]oo`03001oogoo00TmkkAoo`<mk`El8003001oogoo
02Yoo`00;7oo00<007oo?Nl023g_/Woo2Cg_00<007ooOol0:goo000]Ool00`00Oolmk`08?NnaOol8
?Nl00`00Oomoo`0/Ool002ioo`03001oogoo00Pmkjioo`Tmk`03001oogoo02eoo`00;Woo00@007oo
Oomoo`Pmkjaoo`Lmk`=oo`03001oogoo02eoo`00;goo00@007ooOomoo`TmkjUoo`Lmk`=oo`03001o
ogoo02ioo`00<7oo00@007ooOomoo`PmkjQoo`Lmk`=oo`03001oogoo02moo`00<Goo00@007ooOomo
o`PmkjEoo`Lmk`Aoo`03001oogoo031oo`00<Woo0P000Woo23g_XGoo2Cg_0goo0P00<goo000dOol0
0`00Oomoo`08?NnNOol:?Nl3Ool00`00Oomoo`0cOol003Eoo`03001oocg_00Pmkieoo`Tmk`=oo`03
001oogoo03Aoo`00=Goo00@007ooOomoo`Pmkiaoo`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007oo
Oomoo`PmkiYoo`Lmk`Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<0
07ooOol0=Woo000hOol00`00Oomoo`02Ool7?NnFOol7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=o
o`Pmki=oo`Pmk`=oo`8003Yoo`00>goo00<007ooOol02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000l
Ool00`00Oomoo`09?Nn>Ool9?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eo
o`03001oogoo03aoo`00?Woo0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4
Ool;?Nl3Ool00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo
00<007oo?Nl02Cg_NWoo1Cg_00=oocg_?Nl01Cg_1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08
?NmjOol=?Nl4Ool00`00Oomoo`13Ool004Eoo`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Ao
o`00AWoo00<003g_?Nl02Sg_MGoo33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019
Ool004Yooa4mkfYoo``mk`9oo`8004]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;
?Nl3Ool00`00Oomoo`1=Ool004moo`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo
0P000Woo43g_FGoo00<mkgooOol02Sg_0goo0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_
Oomoo`0>?Nl00goo0000001COol005Aoo`800003?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool00000
05Eoo`00EWoo0P0017oo43g_0goo1Sg_@Woo43g_0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00
Oomoo`1GOol005]oo`<000=ooa@mkceooa0mk`8005aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001P
Ool20004OolC?NlXOolN?NmQOol0069oo`<000Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00
IGoo0`001Goo5Cg_1goo2Cg_0goo8Sg_0`00IWoo001XOol40003Oom4?Nl4001YOol006aoo`@000=o
oc/mk`03Ool00000008006eoo`00L7oo0`000goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U
?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000Eoo`<008]oo`00RWoo00@0
07ooOol000Eoo`03001oogoo08Yoo`00RWoo00@007ooOol0009oo`D008]oo`00Rgoo0P000goo00@0
07ooOol008aoo`00RWoo00@007ooOol000=oo`03001oo`0008aoo`00Rgoo0P001Goo0P00S7oo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(85)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
1 .977 0 r
.008 w
.85208 .80052 Mdot
.016 w
.85208 .80052 m
.85195 .80049 L
s
1 .955 0 r
.008 w
.85195 .80049 Mdot
.016 w
.85195 .80049 m
.8518 .80046 L
s
1 .932 0 r
.008 w
.8518 .80046 Mdot
.016 w
.8518 .80046 m
.8515 .80045 L
s
1 .909 0 r
.008 w
.8515 .80045 Mdot
.016 w
.8515 .80045 m
.85105 .80051 L
s
1 .886 0 r
.008 w
.85105 .80051 Mdot
.016 w
.85105 .80051 m
.85047 .80052 L
s
1 .864 0 r
.008 w
.85047 .80052 Mdot
.016 w
.85047 .80052 m
.84977 .80066 L
s
1 .841 0 r
.008 w
.84977 .80066 Mdot
.016 w
.84977 .80066 m
.84892 .80083 L
s
1 .818 0 r
.008 w
.84892 .80083 Mdot
.016 w
.84892 .80083 m
.8479 .80095 L
s
1 .795 0 r
.008 w
.8479 .80095 Mdot
.016 w
.8479 .80095 m
.84685 .80097 L
s
1 .773 0 r
.008 w
.84685 .80097 Mdot
.016 w
.84685 .80097 m
.84583 .80091 L
s
1 .75 0 r
.008 w
.84583 .80091 Mdot
.016 w
.84583 .80091 m
.84492 .80082 L
s
1 .727 0 r
.008 w
.84492 .80082 Mdot
.016 w
.84492 .80082 m
.844 .80072 L
s
1 .705 0 r
.008 w
.844 .80072 Mdot
.016 w
.844 .80072 m
.84313 .80061 L
s
1 .682 0 r
.008 w
.84313 .80061 Mdot
.016 w
.84313 .80061 m
.84251 .80049 L
s
1 .659 0 r
.008 w
.84251 .80049 Mdot
.016 w
.84251 .80049 m
.84208 .8004 L
s
1 .636 0 r
.008 w
.84208 .8004 Mdot
.016 w
.84208 .8004 m
.84173 .80032 L
s
1 .614 0 r
.008 w
.84173 .80032 Mdot
.016 w
.84173 .80032 m
.84151 .80028 L
s
1 .591 0 r
.008 w
.84151 .80028 Mdot
.016 w
.84151 .80028 m
.84149 .80029 L
s
1 .568 0 r
.008 w
.84149 .80029 Mdot
.016 w
.84149 .80029 m
.84159 .80037 L
s
1 .545 0 r
.008 w
.84159 .80037 Mdot
.016 w
.84159 .80037 m
.84192 .80038 L
s
1 .523 0 r
.008 w
.84192 .80038 Mdot
.016 w
.84192 .80038 m
.8424 .80033 L
s
1 .5 0 r
.008 w
.8424 .80033 Mdot
.016 w
.8424 .80033 m
.84301 .80021 L
s
1 .477 0 r
.008 w
.84301 .80021 Mdot
.016 w
.84301 .80021 m
.84366 .80008 L
s
1 .455 0 r
.008 w
.84366 .80008 Mdot
.016 w
.84366 .80008 m
.84437 .79989 L
s
1 .432 0 r
.008 w
.84437 .79989 Mdot
.016 w
.84437 .79989 m
.84509 .79964 L
s
1 .409 0 r
.008 w
.84509 .79964 Mdot
.016 w
.84509 .79964 m
.84591 .79923 L
s
1 .386 0 r
.008 w
.84591 .79923 Mdot
.016 w
.84591 .79923 m
.84668 .7988 L
s
1 .364 0 r
.008 w
.84668 .7988 Mdot
.016 w
.84668 .7988 m
.8475 .79823 L
s
1 .341 0 r
.008 w
.8475 .79823 Mdot
.016 w
.8475 .79823 m
.84821 .79765 L
s
1 .318 0 r
.008 w
.84821 .79765 Mdot
.016 w
.84821 .79765 m
.8489 .79707 L
s
1 .295 0 r
.008 w
.8489 .79707 Mdot
.016 w
.8489 .79707 m
.84949 .79651 L
s
1 .273 0 r
.008 w
.84949 .79651 Mdot
.016 w
.84949 .79651 m
.85 .79598 L
s
1 .25 0 r
.008 w
.85 .79598 Mdot
.016 w
.85 .79598 m
.85046 .79548 L
s
1 .227 0 r
.008 w
.85046 .79548 Mdot
.016 w
.85046 .79548 m
.85084 .79506 L
s
1 .205 0 r
.008 w
.85084 .79506 Mdot
.016 w
.85084 .79506 m
.85119 .7947 L
s
1 .182 0 r
.008 w
.85119 .7947 Mdot
.016 w
.85119 .7947 m
.85151 .79438 L
s
1 .159 0 r
.008 w
.85151 .79438 Mdot
.016 w
.85151 .79438 m
.85182 .79406 L
s
1 .136 0 r
.008 w
.85182 .79406 Mdot
.016 w
.85182 .79406 m
.85209 .79375 L
s
1 .114 0 r
.008 w
.85209 .79375 Mdot
.016 w
.85209 .79375 m
.85224 .79358 L
s
1 .091 0 r
.008 w
.85224 .79358 Mdot
.016 w
.85224 .79358 m
.85228 .79354 L
s
1 .068 0 r
.008 w
.85228 .79354 Mdot
.016 w
.85228 .79354 m
.85228 .79356 L
s
1 .045 0 r
.008 w
.85228 .79356 Mdot
.016 w
.85228 .79356 m
.85232 .7936 L
s
1 .023 0 r
.008 w
.85232 .7936 Mdot
.016 w
.85232 .7936 m
.85238 .79364 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_dgoo23g_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_dWoo1cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?NoBOol7?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?NoAOol7?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00Hmkm5oo`Lmk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_dGoo1cg_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?NoA
Ool7?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Dmkm5oo`Hmk`Moo`03001oogoo01]oo`00
7Goo00<007oo?Nl013g_dGoo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`05?No@Ool6?Nl6
Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mkm1oo`Dmk`Ioo`03001oogoo01eoo`007Woo00<0
03g_?Nl01Cg_cgoo1Cg_1Woo00<007ooOol07Goo000OOol7?No>Ool6?Nl5Ool00`00Oomoo`0NOol0
01moo`03000mkcg_00Dmkleoo`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_bgoo1Sg_
1Goo00<007ooOol07goo000POol00`00?Nlmk`06?No:Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tm
klUoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl01Sg_agoo1cg_0goo00<007ooOol08Goo
000SOol8?No7Ool5?Nl4Ool00`00Oomoo`0ROol002Aoo`TmklEoo`Dmk`=oo`03001oogoo02=oo`00
97oo00<003g_?Nl01cg_`goo1Sg_0goo00<007ooOol08goo000UOol:?No2Ool5?Nl3Ool00`00Oomo
o`0TOol002Ioo`03000mkcg_00Lmkl5oo`Hmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg__7oo
1Sg_0Woo00<007ooOol09Goo000WOol00`00Oolmk`0:?NnjOol017b0O21l87b013g_00=oo`00Ool0
9goo000XOol00`00Oolmk`09?NniOol00gbPO21l0002O203?Nl00goo001oo`0XOol002Uoo`03001o
ocg_00TmkkIoo`05OL1m@7bPO21l0002O202?Nl00goo001oo`0YOol002Yoo`03001oocg_00PmkkIo
o`04OL1m@7bPO802O20017b0?Nlmk`00:goo000ZOol00`00Oomoo`09?NneOol00gg0OD1lX004O802
?Nl00`00Oomoo`0YOol002]oo`03001oogoo00TmkkAoo`03OL1m@7e000=m@003Oj0mk`0002aoo`00
;7oo00<007oo?Nl023g_/Woo2Cg_00<007ooOol0:goo000]Ool00`00Oolmk`08?NnaOol8?Nl00`00
Oomoo`0/Ool002ioo`03001oogoo00Pmkjioo`Tmk`03001oogoo02eoo`00;Woo00@007ooOomoo`Pm
kjaoo`Lmk`=oo`03001oogoo02eoo`00;goo00@007ooOomoo`TmkjUoo`Lmk`=oo`03001oogoo02io
o`00<7oo00@007ooOomoo`PmkjQoo`Lmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo`PmkjEo
o`Lmk`Aoo`03001oogoo031oo`00<Woo0P000Woo23g_XGoo2Cg_0goo0P00<goo000dOol00`00Oomo
o`08?NnNOol:?Nl3Ool00`00Oomoo`0cOol003Eoo`03001oocg_00Pmkieoo`Tmk`=oo`03001oogoo
03Aoo`00=Goo00@007ooOomoo`Pmkiaoo`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`Pm
kiYoo`Lmk`Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<007ooOol0
=Woo000hOol00`00Oomoo`02Ool7?NnFOol7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki=o
o`Pmk`=oo`8003Yoo`00>goo00<007ooOol02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000lOol00`00
Oomoo`09?Nn>Ool9?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eoo`03001o
ogoo03aoo`00?Woo0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3
Ool00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo00<007oo
?Nl02Cg_NWoo1Cg_00=oocg_?Nl01Cg_1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?NmjOol=
?Nl4Ool00`00Oomoo`13Ool004Eoo`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo
00<003g_?Nl02Sg_MGoo33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yo
oa4mkfYoo``mk`9oo`8004]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool0
0`00Oomoo`1=Ool004moo`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P000Woo
43g_FGoo00<mkgooOol02Sg_0goo0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>
?Nl00goo0000001COol005Aoo`800003?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool0000005Eoo`00
EWoo0P0017oo43g_0goo1Sg_@Woo43g_0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00Oomoo`1G
Ool005]oo`<000=ooa@mkceooa0mk`8005aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001POol20004
OolC?NlXOolN?NmQOol0069oo`<000Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`00
1Goo5Cg_1goo2Cg_0goo8Sg_0`00IWoo001XOol40003Oom4?Nl4001YOol006aoo`@000=ooc/mk`03
Ool00000008006eoo`00L7oo0`000goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4
001eOol007Qoo`@001dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]oo`8000Aoo`8008eoo`00RWoo00@007ooOol0
009oo`04001oogoo002<Ool008Yoo`04001oogoo0005Ool00`00Oomoo`2:Ool008]oo`8000Aoo`80
08eoo`00RWoo00@007ooOol000=oo`03001oogoo08aoo`00Rgoo0P0017oo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(86)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
1 .974 0 r
.008 w
.8538 .79278 Mdot
.016 w
.8538 .79278 m
.8537 .79305 L
s
1 .949 0 r
.008 w
.8537 .79305 Mdot
.016 w
.8537 .79305 m
.85349 .79348 L
s
1 .923 0 r
.008 w
.85349 .79348 Mdot
.016 w
.85349 .79348 m
.85317 .79406 L
s
1 .897 0 r
.008 w
.85317 .79406 Mdot
.016 w
.85317 .79406 m
.85274 .79472 L
s
1 .872 0 r
.008 w
.85274 .79472 Mdot
.016 w
.85274 .79472 m
.85225 .7954 L
s
1 .846 0 r
.008 w
.85225 .7954 Mdot
.016 w
.85225 .7954 m
.85175 .79604 L
s
1 .821 0 r
.008 w
.85175 .79604 Mdot
.016 w
.85175 .79604 m
.85128 .79663 L
s
1 .795 0 r
.008 w
.85128 .79663 Mdot
.016 w
.85128 .79663 m
.85083 .79714 L
s
1 .769 0 r
.008 w
.85083 .79714 Mdot
.016 w
.85083 .79714 m
.85048 .7975 L
s
1 .744 0 r
.008 w
.85048 .7975 Mdot
.016 w
.85048 .7975 m
.85018 .79776 L
s
1 .718 0 r
.008 w
.85018 .79776 Mdot
.016 w
.85018 .79776 m
.84993 .79792 L
s
1 .692 0 r
.008 w
.84993 .79792 Mdot
.016 w
.84993 .79792 m
.84979 .7979 L
s
1 .667 0 r
.008 w
.84979 .7979 Mdot
.016 w
.84979 .7979 m
.84976 .79774 L
s
1 .641 0 r
.008 w
.84976 .79774 Mdot
.016 w
.84976 .79774 m
.84985 .79745 L
s
1 .615 0 r
.008 w
.84985 .79745 Mdot
.016 w
.84985 .79745 m
.85015 .79691 L
s
1 .59 0 r
.008 w
.85015 .79691 Mdot
.016 w
.85015 .79691 m
.85062 .79619 L
s
1 .564 0 r
.008 w
.85062 .79619 Mdot
.016 w
.85062 .79619 m
.85129 .79533 L
s
1 .538 0 r
.008 w
.85129 .79533 Mdot
.016 w
.85129 .79533 m
.85212 .79443 L
s
1 .513 0 r
.008 w
.85212 .79443 Mdot
.016 w
.85212 .79443 m
.85312 .79345 L
s
1 .487 0 r
.008 w
.85312 .79345 Mdot
.016 w
.85312 .79345 m
.85427 .79241 L
s
1 .462 0 r
.008 w
.85427 .79241 Mdot
.016 w
.85427 .79241 m
.85557 .79126 L
s
1 .436 0 r
.008 w
.85557 .79126 Mdot
.016 w
.85557 .79126 m
.857 .78994 L
s
1 .41 0 r
.008 w
.857 .78994 Mdot
.016 w
.857 .78994 m
.85859 .78834 L
s
1 .385 0 r
.008 w
.85859 .78834 Mdot
.016 w
.85859 .78834 m
.8603 .78648 L
s
1 .359 0 r
.008 w
.8603 .78648 Mdot
.016 w
.8603 .78648 m
.86208 .78435 L
s
1 .333 0 r
.008 w
.86208 .78435 Mdot
.016 w
.86208 .78435 m
.86386 .78207 L
s
1 .308 0 r
.008 w
.86386 .78207 Mdot
.016 w
.86386 .78207 m
.8657 .7795 L
s
1 .282 0 r
.008 w
.8657 .7795 Mdot
.016 w
.8657 .7795 m
.86746 .77679 L
s
1 .256 0 r
.008 w
.86746 .77679 Mdot
.016 w
.86746 .77679 m
.86907 .77439 L
s
1 .231 0 r
.008 w
.86907 .77439 Mdot
.016 w
.86907 .77439 m
.87049 .77193 L
s
1 .205 0 r
.008 w
.87049 .77193 Mdot
.016 w
.87049 .77193 m
.87167 .76978 L
s
1 .179 0 r
.008 w
.87167 .76978 Mdot
.016 w
.87167 .76978 m
.87269 .7677 L
s
1 .154 0 r
.008 w
.87269 .7677 Mdot
.016 w
.87269 .7677 m
.87349 .76594 L
s
1 .128 0 r
.008 w
.87349 .76594 Mdot
.016 w
.87349 .76594 m
.87409 .7645 L
s
1 .103 0 r
.008 w
.87409 .7645 Mdot
.016 w
.87409 .7645 m
.87452 .76332 L
s
1 .077 0 r
.008 w
.87452 .76332 Mdot
.016 w
.87452 .76332 m
.87482 .76246 L
s
1 .051 0 r
.008 w
.87482 .76246 Mdot
.016 w
.87482 .76246 m
.87503 .76191 L
s
1 .026 0 r
.008 w
.87503 .76191 Mdot
.016 w
.87503 .76191 m
.87517 .76164 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_dgoo23g_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_dWoo1cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?NoBOol7?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?NoAOol7?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00Hmkm5oo`Lmk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_dGoo1cg_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?NoA
Ool7?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Dmkm5oo`Hmk`Moo`03001oogoo01]oo`00
7Goo00<007oo?Nl013g_dGoo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`05?No@Ool6?Nl6
Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mkm1oo`Dmk`Ioo`03001oogoo01eoo`007Woo00<0
03g_?Nl01Cg_cgoo1Cg_1Woo00<007ooOol07Goo000OOol7?No>Ool6?Nl5Ool00`00Oomoo`0NOol0
01moo`03000mkcg_00Dmkleoo`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_bgoo1Sg_
1Goo00<007ooOol07goo000POol00`00?Nlmk`06?No:Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tm
klUoo`03?NmlP7`0009lP003?Nmoogoo009oo`03001oogoo021oo`008Woo00<003g_?Nl01Sg_agoo
00@mkgb0O81l009lP005?NmoogooOol0000SOol002=oo`PmklMoo`04?NmlP7b0O402O803Ool00`00
Oomoo`0ROol002Aoo`TmklEoo`03O>1lP7b000=lP09oo`03001oogoo02=oo`0097oo00<003g_?Nl0
1cg_`goo00<mkgcPO80017b00Woo00<007ooOol08goo000UOol:?No2Ool00gdPO@1lX003O:02Ool0
0`00Oomoo`0TOol002Ioo`03000mkcg_00Lmkl1oo`09OD1m87d0O@1lh7d0?Nmoo`0002Moo`009Woo
00<007oo?Nl02cg_^goo00=mP7e0OD0017d00Woo00<007ooOol09Goo000WOol00`00Oolmk`0:?Nnj
Ool00gg0OH1mP002OD001GdP?Nlmkgoo0000:7oo000XOol00`00Oolmk`09?NniOol00ghPOL1mX002
OH001Ge0?Nlmkgoo0000:Goo000YOol00`00Oolmk`09?NngOol00cg_OR1m`002OJ001Gf0OJ0mkgoo
0000:Woo000ZOol00`00Oolmk`08?NnfOol2?Nl00ghPOL1mX003OJ000cg_001oo`0ZOol002Yoo`03
001oogoo00TmkkEoo`8mk`03OR1n07h0009n008mk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_
]7oo0Sg_17j00Sg_00<007ooOol0:Woo000/Ool00`00Oolmk`08?NnbOol9?Nl00`00Oomoo`0[Ool0
02eoo`03001oocg_00Pmkk5oo`Pmk`03001oogoo02aoo`00;Woo00<007ooOol023g_[Woo2Cg_00<0
07ooOol0;Goo000^Ool01000Oomoogoo23g_[7oo1cg_0goo00<007ooOol0;Goo000_Ool01000Oomo
ogoo2Cg_ZGoo1cg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo23g_Z7oo1cg_0goo00<007oo
Ool0;goo000aOol01000Oomoogoo23g_YGoo1cg_17oo00<007ooOol0<7oo000bOol20002Ool8?NnQ
Ool9?Nl3Ool2000cOol003Aoo`03001oogoo00Pmkiioo`Xmk`=oo`03001oogoo03=oo`00=Goo00<0
07oo?Nl023g_WGoo2Cg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo23g_W7oo2Cg_0goo00<0
07ooOol0=7oo000fOol01000Oomoogoo23g_VWoo1cg_1Goo00<007ooOol0=Goo000gOol00`00Oomo
o`02Ool7?NnHOol6?Nl6Ool00`00Oomoo`0fOol003Qoo`03001oogoo009oo`LmkiIoo`Lmk`Eoo`03
001oogoo03Moo`00>Goo0P000goo23g_Tgoo23g_0goo0P00>Woo000kOol00`00Oomoo`09?Nn@Ool9
?Nl3Ool00`00Oomoo`0jOol003aoo`03001oogoo00Tmkhioo`Tmk`=oo`03001oogoo03]oo`00?Goo
00<007ooOol02Sg_RWoo23g_1Goo00<007ooOol0?7oo000nOol20002Ool9?Nn7Ool9?Nl4Ool2000o
Ool0041oo`03001oogoo00TmkhAoo`/mk`=oo`03001oogoo03moo`00@Goo0P0000=oocg_?Nl01cg_
Pgoo23g_17oo0P00@Woo0013Ool00`00Oolmk`09?NmjOol5?Nl00goo?Nlmk`05?Nl5Ool00`00Oomo
o`12Ool004Aoo`03000mkcg_00PmkgYoo`dmk`Aoo`03001oogoo04=oo`00AGoo00<003g_?Nl02Sg_
Mgoo2cg_1Goo00<007ooOol0A7oo0016Ool00`00?Nlmk`0:?NmeOol<?Nl3Ool20017Ool004Qoo`hm
k`9oo`8mkfaoo`dmk`9oo`8004Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo001<Ool@?NmWOol;?Nl3
Ool2001=Ool004iooa4mkf=oo`/mk`=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03cg_H7oo33g_
0Woo00<007ooOol0CWoo001@Ool20002Ool@?NmIOol00cg_Oomoo`0:?Nl3Ool2001AOol0059oo`80
0003Oolmkcg_010mke9oo`03?Nmoogoo00hmk`03Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_
1goo1Cg_@goo43g_00=oo`000000EGoo001FOol20004Ool@?Nl3Ool6?Nm2Ool@?Nl2001GOol005Qo
o`<000AooaHmkd1ooa4mk`03001oogoo05Moo`00Fgoo0`000goo53g_?Goo43g_0P00G7oo001NOol2
0004OolB?NlhOolD?NmNOol0061oo`8000Aooa<mkbQooahmkf5oo`00HWoo0`0017oo53g_47oo0Sg_
3Goo83g_00<007ooOol0HGoo001UOol30005OolE?Nl7Ool9?Nl3OolR?Nl3001VOol006Qoo`@000=o
od@mk`@006Uoo`00K7oo10000goo>cg_00=oo`0000000P00KGoo001`Ool30003Ool`?Nl5Ool4001a
Ool007=oo`D00003Oolmkcg_02Dmk`Moo`@007Eoo`00N7oo10007Cg_1goo1`00NGoo001nOol@?Nl4
Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Rgoo
0P000goo0`00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00RWoo00@007ooOol0009o
o`04001oogoo002<Ool008]oo`8000=oo`<008eoo`00RWoo00@007ooOol000=oo`03001oogoo08ao
o`00Rgoo0P0017oo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(87)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
1 .947 0 r
.008 w
.87618 .76236 Mdot
.016 w
.87618 .76236 m
.87615 .76215 L
s
1 .895 0 r
.008 w
.87615 .76215 Mdot
.016 w
.87615 .76215 m
.87612 .76183 L
s
1 .842 0 r
.008 w
.87612 .76183 Mdot
.016 w
.87612 .76183 m
.87608 .76138 L
s
1 .789 0 r
.008 w
.87608 .76138 Mdot
.016 w
.87608 .76138 m
.87606 .76081 L
s
1 .737 0 r
.008 w
.87606 .76081 Mdot
.016 w
.87606 .76081 m
.87606 .76011 L
s
1 .684 0 r
.008 w
.87606 .76011 Mdot
.016 w
.87606 .76011 m
.87608 .75932 L
s
1 .632 0 r
.008 w
.87608 .75932 Mdot
.016 w
.87608 .75932 m
.87615 .75843 L
s
1 .579 0 r
.008 w
.87615 .75843 Mdot
.016 w
.87615 .75843 m
.87624 .75747 L
s
1 .526 0 r
.008 w
.87624 .75747 Mdot
.016 w
.87624 .75747 m
.87637 .75647 L
s
1 .474 0 r
.008 w
.87637 .75647 Mdot
.016 w
.87637 .75647 m
.87652 .75548 L
s
1 .421 0 r
.008 w
.87652 .75548 Mdot
.016 w
.87652 .75548 m
.8767 .75455 L
s
1 .368 0 r
.008 w
.8767 .75455 Mdot
.016 w
.8767 .75455 m
.87688 .75368 L
s
1 .316 0 r
.008 w
.87688 .75368 Mdot
.016 w
.87688 .75368 m
.87706 .75292 L
s
1 .263 0 r
.008 w
.87706 .75292 Mdot
.016 w
.87706 .75292 m
.87725 .75229 L
s
1 .211 0 r
.008 w
.87725 .75229 Mdot
.016 w
.87725 .75229 m
.87744 .75179 L
s
1 .158 0 r
.008 w
.87744 .75179 Mdot
.016 w
.87744 .75179 m
.87761 .75142 L
s
1 .105 0 r
.008 w
.87761 .75142 Mdot
.016 w
.87761 .75142 m
.87776 .75116 L
s
1 .053 0 r
.008 w
.87776 .75116 Mdot
.016 w
.87776 .75116 m
.87788 .751 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_dgoo23g_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_dWoo1cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?NoBOol7?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?NoAOol7?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00Hmkm5oo`Lmk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_dGoo1cg_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?NoA
Ool7?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Dmkm5oo`Hmk`Moo`03001oogoo01]oo`00
7Goo00<007oo?Nl013g_dGoo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`05?No@Ool6?Nl6
Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mkm1oo`Dmk`Ioo`03001oogoo01eoo`007Woo00<0
03g_?Nl01Cg_cgoo1Cg_1Woo00<007ooOol07Goo000OOol7?No>Ool6?Nl5Ool00`00Oomoo`0NOol0
01moo`03000mkcg_00Dmkleoo`9m@004O21m@7e0?Nl5Ool00`00Oomoo`0NOol0021oo`03000mkcg_
00Dmkl]oo`04?Nmm@7e0O202OD05Ool00`00Oomoo`0OOol0021oo`03000mkcg_00HmklYoo`04?Nmm
@7e0O<02OD05Ool00`00Oomoo`0OOol0025oo`TmklUoo`03?Nmm@7e000=m@0Aoo`03001oogoo021o
o`008Woo00<003g_?Nl01Sg_agoo0Sg_17eP00DmkgooOomoo`0002=oo`008goo23g_agoo0Sg_17i0
0goo00<007ooOol08Woo000TOol9?No5Ool2?Nl4Ob02Ool00`00Oomoo`0SOol002Aoo`03000mkcg_
00Lmkl=oo`Lmk`9oo`03001oogoo02=oo`009Goo2Sg_`Woo1Cg_0goo00<007ooOol097oo000VOol0
0`00?Nlmk`07?No0Ool7?Nl00goo001oo`0VOol002Ioo`03001oocg_00/mkk]oo`Lmk`9oo`03001o
ogoo02Eoo`009goo00<007oo?Nl02Sg_^Woo23g_00=oo`00Ool09goo000XOol00`00Oolmk`09?Nni
Ool8?Nl00goo001oo`0XOol002Uoo`03001oocg_00TmkkMoo`Pmk`03Ool007oo02Uoo`00:Woo00<0
07oo?Nl023g_]Woo2Cg_00<007ooOol0:Goo000ZOol00`00Oomoo`09?NneOol9?Nl00`00Oomoo`0Y
Ool002]oo`03001oogoo00TmkkAoo`Pmk`03001oogoo02Yoo`00;7oo00<007oo?Nl023g_/Woo2Cg_
00<007ooOol0:goo000]Ool00`00Oolmk`08?NnaOol8?Nl00`00Oomoo`0/Ool002ioo`03001oogoo
00Pmkjioo`Tmk`03001oogoo02eoo`00;Woo00@007ooOomoo`Pmkjaoo`Lmk`=oo`03001oogoo02eo
o`00;goo00@007ooOomoo`TmkjUoo`Lmk`=oo`03001oogoo02ioo`00<7oo00@007ooOomoo`PmkjQo
o`Lmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo`PmkjEoo`Lmk`Aoo`03001oogoo031oo`00
<Woo0P000Woo23g_XGoo2Cg_0goo0P00<goo000dOol00`00Oomoo`08?NnNOol:?Nl3Ool00`00Oomo
o`0cOol003Eoo`03001oocg_00Pmkieoo`Tmk`=oo`03001oogoo03Aoo`00=Goo00@007ooOomoo`Pm
kiaoo`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkiYoo`Lmk`Eoo`03001oogoo03Eo
o`00=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<007ooOol0=Woo000hOol00`00Oomoo`02Ool7
?NnFOol7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki=oo`Pmk`=oo`8003Yoo`00>goo00<0
07ooOol02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000lOol00`00Oomoo`09?Nn>Ool9?Nl3Ool00`00
Oomoo`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_
Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3Ool00`00Oomoo`0oOol0045oo`80
0003Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo00<007oo?Nl02Cg_NWoo1Cg_00=oocg_?Nl0
1Cg_1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?NmjOol=?Nl4Ool00`00Oomoo`13Ool004Eo
o`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl02Sg_MGoo33g_0goo
0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYoo``mk`9oo`8004]oo`00
C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomoo`1=Ool004moo`03000m
kcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P000Woo43g_FGoo00<mkgooOol02Sg_0goo
0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>?Nl00goo0000001COol005Aoo`80
0003?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool0000005Eoo`00EWoo0P0017oo43g_0goo1Sg_@Woo
43g_0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00Oomoo`1GOol005]oo`<000=ooa@mkceooa0m
k`8005aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001POol20004OolC?NlXOolN?NmQOol0069oo`<0
00Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`001Goo5Cg_1goo2Cg_0goo8Sg_0`00
IWoo001XOol40003Oom4?Nl4001YOol006aoo`@000=ooc/mk`03Ool00000008006eoo`00L7oo0`00
0goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L0
07Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol008]oo`8000Eoo`03001oogoo08]oo`00RWoo00@007ooOol000Aoo`03001oogoo08]o
o`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00Rgoo0P001Woo00<007ooOol0RWoo002:Ool0
1000Oomoo`000Woo00@007ooOol008aoo`00Rgoo0P000goo1000S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(88)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
1 .993 0 r
.008 w
.8738 .75155 Mdot
.016 w
.8738 .75155 m
.87388 .75161 L
s
1 .987 0 r
.008 w
.87388 .75161 Mdot
.016 w
.87388 .75161 m
.87405 .7517 L
s
1 .98 0 r
.008 w
.87405 .7517 Mdot
.016 w
.87405 .7517 m
.8743 .75179 L
s
1 .974 0 r
.008 w
.8743 .75179 Mdot
.016 w
.8743 .75179 m
.87461 .75185 L
s
1 .967 0 r
.008 w
.87461 .75185 Mdot
.016 w
.87461 .75185 m
.87496 .75182 L
s
1 .961 0 r
.008 w
.87496 .75182 Mdot
.016 w
.87496 .75182 m
.87532 .75167 L
s
1 .954 0 r
.008 w
.87532 .75167 Mdot
.016 w
.87532 .75167 m
.87572 .75136 L
s
1 .947 0 r
.008 w
.87572 .75136 Mdot
.016 w
.87572 .75136 m
.87617 .7509 L
s
1 .941 0 r
.008 w
.87617 .7509 Mdot
.016 w
.87617 .7509 m
.87664 .75027 L
s
1 .934 0 r
.008 w
.87664 .75027 Mdot
.016 w
.87664 .75027 m
.87712 .74951 L
s
1 .928 0 r
.008 w
.87712 .74951 Mdot
.016 w
.87712 .74951 m
.87759 .74866 L
s
1 .921 0 r
.008 w
.87759 .74866 Mdot
.016 w
.87759 .74866 m
.87801 .74774 L
s
1 .914 0 r
.008 w
.87801 .74774 Mdot
.016 w
.87801 .74774 m
.87839 .74688 L
s
1 .908 0 r
.008 w
.87839 .74688 Mdot
.016 w
.87839 .74688 m
.87871 .74591 L
s
1 .901 0 r
.008 w
.87871 .74591 Mdot
.016 w
.87871 .74591 m
.87898 .74503 L
s
1 .895 0 r
.008 w
.87898 .74503 Mdot
.016 w
.87898 .74503 m
.87923 .7442 L
s
1 .888 0 r
.008 w
.87923 .7442 Mdot
.016 w
.87923 .7442 m
.87944 .74347 L
s
1 .882 0 r
.008 w
.87944 .74347 Mdot
.016 w
.87944 .74347 m
.87962 .74291 L
s
1 .875 0 r
.008 w
.87962 .74291 Mdot
.016 w
.87962 .74291 m
.87978 .74254 L
s
1 .868 0 r
.008 w
.87978 .74254 Mdot
.016 w
.87978 .74254 m
.87992 .74236 L
s
1 .862 0 r
.008 w
.87992 .74236 Mdot
.016 w
.87992 .74236 m
.88006 .74233 L
s
1 .855 0 r
.008 w
.88006 .74233 Mdot
.016 w
.88006 .74233 m
.88021 .74237 L
s
1 .849 0 r
.008 w
.88021 .74237 Mdot
.016 w
.88021 .74237 m
.88037 .74241 L
s
1 .842 0 r
.008 w
.88037 .74241 Mdot
.016 w
.88037 .74241 m
.88057 .74234 L
s
1 .836 0 r
.008 w
.88057 .74234 Mdot
.016 w
.88057 .74234 m
.88082 .74205 L
s
1 .829 0 r
.008 w
.88082 .74205 Mdot
.016 w
.88082 .74205 m
.88115 .74144 L
s
1 .822 0 r
.008 w
.88115 .74144 Mdot
.016 w
.88115 .74144 m
.88155 .74048 L
s
1 .816 0 r
.008 w
.88155 .74048 Mdot
.016 w
.88155 .74048 m
.88204 .73914 L
s
1 .809 0 r
.008 w
.88204 .73914 Mdot
.016 w
.88204 .73914 m
.8826 .73755 L
s
1 .803 0 r
.008 w
.8826 .73755 Mdot
.016 w
.8826 .73755 m
.88321 .73569 L
s
1 .796 0 r
.008 w
.88321 .73569 Mdot
.016 w
.88321 .73569 m
.88389 .73351 L
s
1 .789 0 r
.008 w
.88389 .73351 Mdot
.016 w
.88389 .73351 m
.88461 .73119 L
s
1 .783 0 r
.008 w
.88461 .73119 Mdot
.016 w
.88461 .73119 m
.88537 .72868 L
s
1 .776 0 r
.008 w
.88537 .72868 Mdot
.016 w
.88537 .72868 m
.88614 .72625 L
s
1 .77 0 r
.008 w
.88614 .72625 Mdot
.016 w
.88614 .72625 m
.88688 .72385 L
s
1 .763 0 r
.008 w
.88688 .72385 Mdot
.016 w
.88688 .72385 m
.88765 .72157 L
s
1 .757 0 r
.008 w
.88765 .72157 Mdot
.016 w
.88765 .72157 m
.8883 .71943 L
s
1 .75 0 r
.008 w
.8883 .71943 Mdot
.016 w
.8883 .71943 m
.88893 .71768 L
s
1 .743 0 r
.008 w
.88893 .71768 Mdot
.016 w
.88893 .71768 m
.88946 .71612 L
s
1 .737 0 r
.008 w
.88946 .71612 Mdot
.016 w
.88946 .71612 m
.88989 .71479 L
s
1 .73 0 r
.008 w
.88989 .71479 Mdot
.016 w
.88989 .71479 m
.89021 .71372 L
s
1 .724 0 r
.008 w
.89021 .71372 Mdot
.016 w
.89021 .71372 m
.89044 .71283 L
s
1 .717 0 r
.008 w
.89044 .71283 Mdot
.016 w
.89044 .71283 m
.89058 .71206 L
s
1 .711 0 r
.008 w
.89058 .71206 Mdot
.016 w
.89058 .71206 m
.89065 .71132 L
s
1 .704 0 r
.008 w
.89065 .71132 Mdot
.016 w
.89065 .71132 m
.89065 .71055 L
s
1 .697 0 r
.008 w
.89065 .71055 Mdot
.016 w
.89065 .71055 m
.89062 .7097 L
s
1 .691 0 r
.008 w
.89062 .7097 Mdot
.016 w
.89062 .7097 m
.89055 .7087 L
s
1 .684 0 r
.008 w
.89055 .7087 Mdot
.016 w
.89055 .7087 m
.89048 .70752 L
s
1 .678 0 r
.008 w
.89048 .70752 Mdot
.016 w
.89048 .70752 m
.89041 .70611 L
s
1 .671 0 r
.008 w
.89041 .70611 Mdot
.016 w
.89041 .70611 m
.89035 .70456 L
s
1 .664 0 r
.008 w
.89035 .70456 Mdot
.016 w
.89035 .70456 m
.89029 .70287 L
s
1 .658 0 r
.008 w
.89029 .70287 Mdot
.016 w
.89029 .70287 m
.89024 .70121 L
s
1 .651 0 r
.008 w
.89024 .70121 Mdot
.016 w
.89024 .70121 m
.89021 .69964 L
s
1 .645 0 r
.008 w
.89021 .69964 Mdot
.016 w
.89021 .69964 m
.89018 .69832 L
s
1 .638 0 r
.008 w
.89018 .69832 Mdot
.016 w
.89018 .69832 m
.89015 .69713 L
s
1 .632 0 r
.008 w
.89015 .69713 Mdot
.016 w
.89015 .69713 m
.89013 .69625 L
s
1 .625 0 r
.008 w
.89013 .69625 Mdot
.016 w
.89013 .69625 m
.89012 .6956 L
s
1 .618 0 r
.008 w
.89012 .6956 Mdot
.016 w
.89012 .6956 m
.89012 .69518 L
s
1 .612 0 r
.008 w
.89012 .69518 Mdot
.016 w
.89012 .69518 m
.89014 .69498 L
s
1 .605 0 r
.008 w
.89014 .69498 Mdot
.016 w
.89014 .69498 m
.8902 .695 L
s
1 .599 0 r
.008 w
.8902 .695 Mdot
.016 w
.8902 .695 m
.8903 .6952 L
s
1 .592 0 r
.008 w
.8903 .6952 Mdot
.016 w
.8903 .6952 m
.89039 .69557 L
s
1 .586 0 r
.008 w
.89039 .69557 Mdot
.016 w
.89039 .69557 m
.89044 .69605 L
s
1 .579 0 r
.008 w
.89044 .69605 Mdot
.016 w
.89044 .69605 m
.89045 .69659 L
s
1 .572 0 r
.008 w
.89045 .69659 Mdot
.016 w
.89045 .69659 m
.89039 .69714 L
s
1 .566 0 r
.008 w
.89039 .69714 Mdot
.016 w
.89039 .69714 m
.89024 .69761 L
s
1 .559 0 r
.008 w
.89024 .69761 Mdot
.016 w
.89024 .69761 m
.88997 .69795 L
s
1 .553 0 r
.008 w
.88997 .69795 Mdot
.016 w
.88997 .69795 m
.88958 .69812 L
s
1 .546 0 r
.008 w
.88958 .69812 Mdot
.016 w
.88958 .69812 m
.88907 .69815 L
s
1 .539 0 r
.008 w
.88907 .69815 Mdot
.016 w
.88907 .69815 m
.88846 .69813 L
s
1 .533 0 r
.008 w
.88846 .69813 Mdot
.016 w
.88846 .69813 m
.88779 .6981 L
s
1 .526 0 r
.008 w
.88779 .6981 Mdot
.016 w
.88779 .6981 m
.88707 .69811 L
s
1 .52 0 r
.008 w
.88707 .69811 Mdot
.016 w
.88707 .69811 m
.88632 .69821 L
s
1 .513 0 r
.008 w
.88632 .69821 Mdot
.016 w
.88632 .69821 m
.8855 .6984 L
s
1 .507 0 r
.008 w
.8855 .6984 Mdot
.016 w
.8855 .6984 m
.88462 .69869 L
s
1 .5 0 r
.008 w
.88462 .69869 Mdot
.016 w
.88462 .69869 m
.88369 .69904 L
s
1 .493 0 r
.008 w
.88369 .69904 Mdot
.016 w
.88369 .69904 m
.88274 .69942 L
s
1 .487 0 r
.008 w
.88274 .69942 Mdot
.016 w
.88274 .69942 m
.88182 .69983 L
s
1 .48 0 r
.008 w
.88182 .69983 Mdot
.016 w
.88182 .69983 m
.88091 .70025 L
s
1 .474 0 r
.008 w
.88091 .70025 Mdot
.016 w
.88091 .70025 m
.87998 .70068 L
s
1 .467 0 r
.008 w
.87998 .70068 Mdot
.016 w
.87998 .70068 m
.87907 .70116 L
s
1 .461 0 r
.008 w
.87907 .70116 Mdot
.016 w
.87907 .70116 m
.87815 .7017 L
s
1 .454 0 r
.008 w
.87815 .7017 Mdot
.016 w
.87815 .7017 m
.87727 .7023 L
s
1 .447 0 r
.008 w
.87727 .7023 Mdot
.016 w
.87727 .7023 m
.87634 .70295 L
s
1 .441 0 r
.008 w
.87634 .70295 Mdot
.016 w
.87634 .70295 m
.87532 .70363 L
s
1 .434 0 r
.008 w
.87532 .70363 Mdot
.016 w
.87532 .70363 m
.87419 .70433 L
s
1 .428 0 r
.008 w
.87419 .70433 Mdot
.016 w
.87419 .70433 m
.87302 .70506 L
s
1 .421 0 r
.008 w
.87302 .70506 Mdot
.016 w
.87302 .70506 m
.87183 .7058 L
s
1 .414 0 r
.008 w
.87183 .7058 Mdot
.016 w
.87183 .7058 m
.8706 .70662 L
s
1 .408 0 r
.008 w
.8706 .70662 Mdot
.016 w
.8706 .70662 m
.86934 .70751 L
s
1 .401 0 r
.008 w
.86934 .70751 Mdot
.016 w
.86934 .70751 m
.86822 .70848 L
s
1 .395 0 r
.008 w
.86822 .70848 Mdot
.016 w
.86822 .70848 m
.86712 .7095 L
s
1 .388 0 r
.008 w
.86712 .7095 Mdot
.016 w
.86712 .7095 m
.8661 .71058 L
s
1 .382 0 r
.008 w
.8661 .71058 Mdot
.016 w
.8661 .71058 m
.86516 .71166 L
s
1 .375 0 r
.008 w
.86516 .71166 Mdot
.016 w
.86516 .71166 m
.86437 .71268 L
s
1 .368 0 r
.008 w
.86437 .71268 Mdot
.016 w
.86437 .71268 m
.86363 .71356 L
s
1 .362 0 r
.008 w
.86363 .71356 Mdot
.016 w
.86363 .71356 m
.86294 .71431 L
s
1 .355 0 r
.008 w
.86294 .71431 Mdot
.016 w
.86294 .71431 m
.86231 .7149 L
s
1 .349 0 r
.008 w
.86231 .7149 Mdot
.016 w
.86231 .7149 m
.86176 .71535 L
s
1 .342 0 r
.008 w
.86176 .71535 Mdot
.016 w
.86176 .71535 m
.86127 .71566 L
s
1 .336 0 r
.008 w
.86127 .71566 Mdot
.016 w
.86127 .71566 m
.86083 .71589 L
s
1 .329 0 r
.008 w
.86083 .71589 Mdot
.016 w
.86083 .71589 m
.86039 .71605 L
s
1 .322 0 r
.008 w
.86039 .71605 Mdot
.016 w
.86039 .71605 m
.85988 .71617 L
s
1 .316 0 r
.008 w
.85988 .71617 Mdot
.016 w
.85988 .71617 m
.85927 .71626 L
s
1 .309 0 r
.008 w
.85927 .71626 Mdot
.016 w
.85927 .71626 m
.85853 .71636 L
s
1 .303 0 r
.008 w
.85853 .71636 Mdot
.016 w
.85853 .71636 m
.85761 .71646 L
s
1 .296 0 r
.008 w
.85761 .71646 Mdot
.016 w
.85761 .71646 m
.85666 .71659 L
s
1 .289 0 r
.008 w
.85666 .71659 Mdot
.016 w
.85666 .71659 m
.85549 .71677 L
s
1 .283 0 r
.008 w
.85549 .71677 Mdot
.016 w
.85549 .71677 m
.85423 .71701 L
s
1 .276 0 r
.008 w
.85423 .71701 Mdot
.016 w
.85423 .71701 m
.85307 .71729 L
s
1 .27 0 r
.008 w
.85307 .71729 Mdot
.016 w
.85307 .71729 m
.85189 .7176 L
s
1 .263 0 r
.008 w
.85189 .7176 Mdot
.016 w
.85189 .7176 m
.85074 .71792 L
s
1 .257 0 r
.008 w
.85074 .71792 Mdot
.016 w
.85074 .71792 m
.84968 .71823 L
s
1 .25 0 r
.008 w
.84968 .71823 Mdot
.016 w
.84968 .71823 m
.84877 .7185 L
s
1 .243 0 r
.008 w
.84877 .7185 Mdot
.016 w
.84877 .7185 m
.84796 .7187 L
s
1 .237 0 r
.008 w
.84796 .7187 Mdot
.016 w
.84796 .7187 m
.84728 .7188 L
s
1 .23 0 r
.008 w
.84728 .7188 Mdot
.016 w
.84728 .7188 m
.84675 .71881 L
s
1 .224 0 r
.008 w
.84675 .71881 Mdot
.016 w
.84675 .71881 m
.84643 .71875 L
s
1 .217 0 r
.008 w
.84643 .71875 Mdot
.016 w
.84643 .71875 m
.84633 .71861 L
s
1 .211 0 r
.008 w
.84633 .71861 Mdot
.016 w
.84633 .71861 m
.84644 .71844 L
s
1 .204 0 r
.008 w
.84644 .71844 Mdot
.016 w
.84644 .71844 m
.84667 .71833 L
s
1 .197 0 r
.008 w
.84667 .71833 Mdot
.016 w
.84667 .71833 m
.84697 .71832 L
s
1 .191 0 r
.008 w
.84697 .71832 Mdot
.016 w
.84697 .71832 m
.84725 .7185 L
s
1 .184 0 r
.008 w
.84725 .7185 Mdot
.016 w
.84725 .7185 m
.84746 .7189 L
s
1 .178 0 r
.008 w
.84746 .7189 Mdot
.016 w
.84746 .7189 m
.84758 .71951 L
s
1 .171 0 r
.008 w
.84758 .71951 Mdot
.016 w
.84758 .71951 m
.84756 .72042 L
s
1 .164 0 r
.008 w
.84756 .72042 Mdot
.016 w
.84756 .72042 m
.8474 .72162 L
s
1 .158 0 r
.008 w
.8474 .72162 Mdot
.016 w
.8474 .72162 m
.84714 .72303 L
s
1 .151 0 r
.008 w
.84714 .72303 Mdot
.016 w
.84714 .72303 m
.84679 .72472 L
s
1 .145 0 r
.008 w
.84679 .72472 Mdot
.016 w
.84679 .72472 m
.84634 .72664 L
s
1 .138 0 r
.008 w
.84634 .72664 Mdot
.016 w
.84634 .72664 m
.84585 .72861 L
s
1 .132 0 r
.008 w
.84585 .72861 Mdot
.016 w
.84585 .72861 m
.84524 .7308 L
s
1 .125 0 r
.008 w
.84524 .7308 Mdot
.016 w
.84524 .7308 m
.8446 .73287 L
s
1 .118 0 r
.008 w
.8446 .73287 Mdot
.016 w
.8446 .73287 m
.84391 .73494 L
s
1 .112 0 r
.008 w
.84391 .73494 Mdot
.016 w
.84391 .73494 m
.84322 .73687 L
s
1 .105 0 r
.008 w
.84322 .73687 Mdot
.016 w
.84322 .73687 m
.84259 .73858 L
s
1 .099 0 r
.008 w
.84259 .73858 Mdot
.016 w
.84259 .73858 m
.84207 .74008 L
s
1 .092 0 r
.008 w
.84207 .74008 Mdot
.016 w
.84207 .74008 m
.8417 .74133 L
s
1 .086 0 r
.008 w
.8417 .74133 Mdot
.016 w
.8417 .74133 m
.84147 .74228 L
s
1 .079 0 r
.008 w
.84147 .74228 Mdot
.016 w
.84147 .74228 m
.84136 .74304 L
s
1 .072 0 r
.008 w
.84136 .74304 Mdot
.016 w
.84136 .74304 m
.84137 .74363 L
s
1 .066 0 r
.008 w
.84137 .74363 Mdot
.016 w
.84137 .74363 m
.84146 .74407 L
s
1 .059 0 r
.008 w
.84146 .74407 Mdot
.016 w
.84146 .74407 m
.84159 .7444 L
s
1 .053 0 r
.008 w
.84159 .7444 Mdot
.016 w
.84159 .7444 m
.84175 .74465 L
s
1 .046 0 r
.008 w
.84175 .74465 Mdot
.016 w
.84175 .74465 m
.84192 .74486 L
s
1 .039 0 r
.008 w
.84192 .74486 Mdot
.016 w
.84192 .74486 m
.84212 .74501 L
s
1 .033 0 r
.008 w
.84212 .74501 Mdot
.016 w
.84212 .74501 m
.84234 .74512 L
s
1 .026 0 r
.008 w
.84234 .74512 Mdot
.016 w
.84234 .74512 m
.84257 .74522 L
s
1 .02 0 r
.008 w
.84257 .74522 Mdot
.016 w
.84257 .74522 m
.84279 .74532 L
s
1 .013 0 r
.008 w
.84279 .74532 Mdot
.016 w
.84279 .74532 m
.84297 .74542 L
s
1 .007 0 r
.008 w
.84297 .74542 Mdot
.016 w
.84297 .74542 m
.84311 .74552 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo0Sg_17i00Sg_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo
0Wg00ggP00=n83g_?Nl027oo00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo17g00WgP00=n
83g_?Nl027oo00<007ooOol05goo000IOol01000Oomoogoo1Sg_d7oo1GfP0Wg000Amh7hP?Nlmk`Qo
o`03001oogoo01Moo`006Goo00@007ooOomoo`Lmklioo`AmP09mX005OL1mh7gPOR0mk`08Ool00`00
Oomoo`0HOol001Yoo`03001oogoo00Lmkleoo`AmH003OH1mX7fP009mh09nP003?Nmoogoo00Ioo`03
001oogoo01Qoo`006Woo00@007ooOomoo`HmklUoo`9l`0=m009m8004OF1mP7fPOJ04OZ08Ool00`00
Oomoo`0IOol001]oo`03001oogoo00HmklQoo`AlX008O>1m07dPOB1mH7f0OJ0mk`AnX0Moo`03001o
ogoo01Yoo`006goo00<007ooOol01Sg_b7oo17b000Qlh7d0OB1m87ePOH0mkgl017k000=o07ooOol0
17oo00<007ooOol06Woo000LOol00`00Oolmk`05?No8Ool4O8001GcPO@1m87dPOF000Sg_00=o07kP
O^000WkP1Woo00<007ooOol06goo000LOol00`00Oomoo`05?No8Ool4O6000gcPO@1oo`02Ool2?Nl0
0gl0O^1nh002O^06Ool00`00Oomoo`0KOol001eoo`03001oocg_00@mklMoo`ElH0Eoo`03?Nmo87l0
00=o0003Ob1oogoo00=oo`03001oogoo01aoo`007Goo00<007oo?Nl01Cg_aWoo1GaP1Goo00<mkglP
O`000gl01Woo00<007ooOol077oo000NOol00`00?Nlmk`04?No6Ool4O4000gaPOomoo`03Ool00gm0
Ob1o0003O`05Ool00`00Oomoo`0MOol001ioo`03000mkcg_00DmklEoo`05O41l87`PO41lH005Ool0
0gm0Ob1o8002Ob06Ool00`00Oomoo`0MOol001moo`LmklEoo`04O21l07`0O205Ool00gnPOd1o8003
Ob05Ool00`00Oomoo`0NOol001moo`03000mkcg_00DmklAoo`04O21l07`0O205Ool00gnPOd1o@003
Od05Ool00`00Oomoo`0NOol0021oo`03000mkcg_00Dmkl=oo`04O41l87`PO404Ool00cg_Oj1oP003
Oh05Ool00`00Oomoo`0OOol0021oo`03000mkcg_00HmklYoo`03?NmoX7nP00=oX0Eoo`03001oogoo
01moo`008Goo2Cg_bGoo00<mkgo0Ol000Wo000<mkgooOol00Woo00<007ooOol087oo000ROol00`00
?Nlmk`06?No7Ool7?Nl3Ool00`00Oomoo`0QOol002=oo`PmklMoo`Hmk`=oo`03001oogoo029oo`00
97oo2Cg_aGoo1Sg_0Woo00<007ooOol08goo000TOol00`00?Nlmk`07?No3Ool7?Nl2Ool00`00Oomo
o`0SOol002Eoo`Xmkl9oo`Dmk`=oo`03001oogoo02Aoo`009Woo00<003g_?Nl01cg_`7oo1cg_00=o
o`00Ool09Woo000VOol00`00Oolmk`0;?NnkOol7?Nl2Ool00`00Oomoo`0UOol002Moo`03001oocg_
00XmkkYoo`Pmk`03Ool007oo02Moo`00:7oo00<007oo?Nl02Cg_^Goo23g_00=oo`00Ool0:7oo000Y
Ool00`00Oolmk`09?NngOol8?Nl00goo001oo`0YOol002Yoo`03001oocg_00PmkkIoo`Tmk`03001o
ogoo02Uoo`00:Woo00<007ooOol02Cg_]Goo2Cg_00<007ooOol0:Goo000[Ool00`00Oomoo`09?Nnd
Ool8?Nl00`00Oomoo`0ZOol002aoo`03001oocg_00Pmkk9oo`Tmk`03001oogoo02]oo`00;Goo00<0
07oo?Nl023g_/Goo23g_00<007ooOol0;7oo000^Ool00`00Oomoo`08?Nn^Ool9?Nl00`00Oomoo`0]
Ool002ioo`04001oogooOol8?Nn/Ool7?Nl3Ool00`00Oomoo`0]Ool002moo`04001oogooOol9?NnY
Ool7?Nl3Ool00`00Oomoo`0^Ool0031oo`04001oogooOol8?NnXOol7?Nl3Ool00`00Oomoo`0_Ool0
035oo`04001oogooOol8?NnUOol7?Nl4Ool00`00Oomoo`0`Ool0039oo`80009oo`Pmkj5oo`Tmk`=o
o`8003=oo`00=7oo00<007ooOol023g_WWoo2Sg_0goo00<007ooOol0<goo000eOol00`00Oolmk`08
?NnMOol9?Nl3Ool00`00Oomoo`0dOol003Eoo`04001oogooOol8?NnLOol9?Nl3Ool00`00Oomoo`0d
Ool003Ioo`04001oogooOol8?NnJOol7?Nl5Ool00`00Oomoo`0eOol003Moo`03001oogoo009oo`Lm
kiQoo`Hmk`Ioo`03001oogoo03Ioo`00>7oo00<007ooOol00Woo1cg_UWoo1cg_1Goo00<007ooOol0
=goo000iOol20003Ool8?NnCOol8?Nl3Ool2000jOol003]oo`03001oogoo00Tmki1oo`Tmk`=oo`03
001oogoo03Yoo`00?7oo00<007ooOol02Cg_SWoo2Cg_0goo00<007ooOol0>goo000mOol00`00Oomo
o`0:?Nn:Ool8?Nl5Ool00`00Oomoo`0lOol003ioo`80009oo`TmkhMoo`Tmk`Aoo`8003moo`00@7oo
00<007ooOol02Cg_Q7oo2cg_0goo00<007ooOol0?goo0011Ool200000goo?Nlmk`07?Nn3Ool8?Nl4
Ool20012Ool004=oo`03001oocg_00TmkgYoo`Dmk`03Oolmkcg_00Dmk`Eoo`03001oogoo049oo`00
A7oo00<003g_?Nl023g_NWoo3Cg_17oo00<007ooOol0@goo0015Ool00`00?Nlmk`0:?NmgOol;?Nl5
Ool00`00Oomoo`14Ool004Ioo`03000mkcg_00XmkgEoo``mk`=oo`8004Moo`00B7oo3Sg_0Woo0Sg_
K7oo3Cg_0Woo0P00BGoo001:OolA?NmZOol<?Nl2Ool2001;Ool004aooa0mkfMoo`/mk`=oo`8004eo
o`00CWoo4Cg_Hgoo2cg_0goo00<007ooOol0CGoo001?Ool00`00?Nlmk`0??NmPOol<?Nl2Ool00`00
Oomoo`1>Ool0051oo`80009ooa0mkeUoo`03?Nmoogoo00Xmk`=oo`80055oo`00DWoo0P0000=oocg_
?Nl043g_DWoo00<mkgooOol03Sg_00=oo`000000Dgoo001DOol200000cg_Oolmk`0@?Nl7Ool5?Nm3
Ool@?Nl00goo0000001EOol005Ioo`8000Aooa0mk`=oo`Hmkd9ooa0mk`8005Moo`00F7oo0`0017oo
5Sg_@7oo4Cg_00<007ooOol0Egoo001KOol30003OolD?NlmOol@?Nl2001LOol005ioo`8000Aooa8m
kcQooa@mkeioo`00H7oo0P0017oo4cg_:7oo7Sg_HGoo001ROol30004OolD?Nl@Ool2?Nl=OolP?Nl0
0`00Oomoo`1QOol006Eoo`<000EooaDmk`Moo`Tmk`=oob8mk`<006Ioo`00J7oo10000gooA3g_1000
JGoo001/Ool40003Oolk?Nl00goo00000002001]Ool0071oo`<000=ooc0mk`Eoo`@0075oo`00Lgoo
1@0000=oocg_?Nl09Cg_1goo1000MGoo001hOol4000M?Nl7Ool7001iOol007iooa0mk`Aoo`h0081o
o`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002;Ool20004Ool2
002=Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002:Ool01000Oomoo`000Woo00@007oo
Ool008aoo`00Rgoo0P0017oo0P00SGoo002:Ool01000Oomoo`000Woo00@007ooOol008aoo`00Rgoo
0P0017oo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(89)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
1 .982 0 r
.008 w
.84345 .74496 Mdot
.016 w
.84345 .74496 m
.84334 .7452 L
s
1 .964 0 r
.008 w
.84334 .7452 Mdot
.016 w
.84334 .7452 m
.84315 .74565 L
s
1 .946 0 r
.008 w
.84315 .74565 Mdot
.016 w
.84315 .74565 m
.84284 .74634 L
s
1 .929 0 r
.008 w
.84284 .74634 Mdot
.016 w
.84284 .74634 m
.8424 .7473 L
s
1 .911 0 r
.008 w
.8424 .7473 Mdot
.016 w
.8424 .7473 m
.84184 .74852 L
s
1 .893 0 r
.008 w
.84184 .74852 Mdot
.016 w
.84184 .74852 m
.84115 .75003 L
s
1 .875 0 r
.008 w
.84115 .75003 Mdot
.016 w
.84115 .75003 m
.84038 .75174 L
s
1 .857 0 r
.008 w
.84038 .75174 Mdot
.016 w
.84038 .75174 m
.83951 .75371 L
s
1 .839 0 r
.008 w
.83951 .75371 Mdot
.016 w
.83951 .75371 m
.83855 .75597 L
s
1 .821 0 r
.008 w
.83855 .75597 Mdot
.016 w
.83855 .75597 m
.83754 .75847 L
s
1 .804 0 r
.008 w
.83754 .75847 Mdot
.016 w
.83754 .75847 m
.83652 .76095 L
s
1 .786 0 r
.008 w
.83652 .76095 Mdot
.016 w
.83652 .76095 m
.83549 .76356 L
s
1 .768 0 r
.008 w
.83549 .76356 Mdot
.016 w
.83549 .76356 m
.83448 .76615 L
s
1 .75 0 r
.008 w
.83448 .76615 Mdot
.016 w
.83448 .76615 m
.83354 .76847 L
s
1 .732 0 r
.008 w
.83354 .76847 Mdot
.016 w
.83354 .76847 m
.83271 .7705 L
s
1 .714 0 r
.008 w
.83271 .7705 Mdot
.016 w
.83271 .7705 m
.832 .77235 L
s
1 .696 0 r
.008 w
.832 .77235 Mdot
.016 w
.832 .77235 m
.83142 .77396 L
s
1 .679 0 r
.008 w
.83142 .77396 Mdot
.016 w
.83142 .77396 m
.83099 .77527 L
s
1 .661 0 r
.008 w
.83099 .77527 Mdot
.016 w
.83099 .77527 m
.83071 .77622 L
s
1 .643 0 r
.008 w
.83071 .77622 Mdot
.016 w
.83071 .77622 m
.83057 .77695 L
s
1 .625 0 r
.008 w
.83057 .77695 Mdot
.016 w
.83057 .77695 m
.83057 .77749 L
s
1 .607 0 r
.008 w
.83057 .77749 Mdot
.016 w
.83057 .77749 m
.83067 .77786 L
s
1 .589 0 r
.008 w
.83067 .77786 Mdot
.016 w
.83067 .77786 m
.83081 .77809 L
s
1 .571 0 r
.008 w
.83081 .77809 Mdot
.016 w
.83081 .77809 m
.83093 .77824 L
s
1 .554 0 r
.008 w
.83093 .77824 Mdot
.016 w
.83093 .77824 m
.83104 .77835 L
s
1 .536 0 r
.008 w
.83104 .77835 Mdot
.016 w
.83104 .77835 m
.83112 .77843 L
s
1 .518 0 r
.008 w
.83112 .77843 Mdot
.016 w
.83112 .77843 m
.83114 .77849 L
s
1 .5 0 r
.008 w
.83114 .77849 Mdot
.016 w
.83114 .77849 m
.83109 .77852 L
s
1 .482 0 r
.008 w
.83109 .77852 Mdot
.016 w
.83109 .77852 m
.83098 .77855 L
s
1 .464 0 r
.008 w
.83098 .77855 Mdot
.016 w
.83098 .77855 m
.83081 .77866 L
s
1 .446 0 r
.008 w
.83081 .77866 Mdot
.016 w
.83081 .77866 m
.83054 .77889 L
s
1 .429 0 r
.008 w
.83054 .77889 Mdot
.016 w
.83054 .77889 m
.8301 .77925 L
s
1 .411 0 r
.008 w
.8301 .77925 Mdot
.016 w
.8301 .77925 m
.82956 .77976 L
s
1 .393 0 r
.008 w
.82956 .77976 Mdot
.016 w
.82956 .77976 m
.8289 .7804 L
s
1 .375 0 r
.008 w
.8289 .7804 Mdot
.016 w
.8289 .7804 m
.82818 .78119 L
s
1 .357 0 r
.008 w
.82818 .78119 Mdot
.016 w
.82818 .78119 m
.82738 .78217 L
s
1 .339 0 r
.008 w
.82738 .78217 Mdot
.016 w
.82738 .78217 m
.82656 .78333 L
s
1 .321 0 r
.008 w
.82656 .78333 Mdot
.016 w
.82656 .78333 m
.82573 .78469 L
s
1 .304 0 r
.008 w
.82573 .78469 Mdot
.016 w
.82573 .78469 m
.82488 .78618 L
s
1 .286 0 r
.008 w
.82488 .78618 Mdot
.016 w
.82488 .78618 m
.82418 .78794 L
s
1 .268 0 r
.008 w
.82418 .78794 Mdot
.016 w
.82418 .78794 m
.82343 .78999 L
s
1 .25 0 r
.008 w
.82343 .78999 Mdot
.016 w
.82343 .78999 m
.82266 .79229 L
s
1 .232 0 r
.008 w
.82266 .79229 Mdot
.016 w
.82266 .79229 m
.82182 .79484 L
s
1 .214 0 r
.008 w
.82182 .79484 Mdot
.016 w
.82182 .79484 m
.82096 .79751 L
s
1 .196 0 r
.008 w
.82096 .79751 Mdot
.016 w
.82096 .79751 m
.82006 .80023 L
s
1 .179 0 r
.008 w
.82006 .80023 Mdot
.016 w
.82006 .80023 m
.8191 .80262 L
s
1 .161 0 r
.008 w
.8191 .80262 Mdot
.016 w
.8191 .80262 m
.81829 .80515 L
s
1 .143 0 r
.008 w
.81829 .80515 Mdot
.016 w
.81829 .80515 m
.81754 .80708 L
s
1 .125 0 r
.008 w
.81754 .80708 Mdot
.016 w
.81754 .80708 m
.81694 .809 L
s
1 .107 0 r
.008 w
.81694 .809 Mdot
.016 w
.81694 .809 m
.81642 .81067 L
s
1 .089 0 r
.008 w
.81642 .81067 Mdot
.016 w
.81642 .81067 m
.81597 .81207 L
s
1 .071 0 r
.008 w
.81597 .81207 Mdot
.016 w
.81597 .81207 m
.81561 .81323 L
s
1 .054 0 r
.008 w
.81561 .81323 Mdot
.016 w
.81561 .81323 m
.8153 .81411 L
s
1 .036 0 r
.008 w
.8153 .81411 Mdot
.016 w
.8153 .81411 m
.81508 .81472 L
s
1 .018 0 r
.008 w
.81508 .81472 Mdot
.016 w
.81508 .81472 m
.81497 .81507 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?No:Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00HmklQooa0mk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_b7oo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?No8
Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00DmklQoo`Hmk`=oo`Hmk`Moo`03001oogoo
01]oo`007Goo00<007oo?Nl013g_agoo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolm
k`05?No6Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mklIoo`Dmk`Eoo`Dm
k`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_aGoo00EoX7mPOf1oX3g_00Eoo`Dmk`Ioo`03
001oogoo01eoo`007goo1cg_aGoo17mP1Goo1Sg_1Goo00<007ooOol07Woo000OOol00`00?Nlmk`05
?No3Ool4Od02Of04Ool6?Nl5Ool00`00Oomoo`0NOol0021oo`03000mkcg_00Dmkl9oo`Ao@003Of1o
ogoo009oo`Hmk`Eoo`03001oogoo01moo`0087oo00<003g_?Nl01Sg_`7oo1GlP00=oX7ooOol00Woo
1Sg_1Goo00<007ooOol07goo000QOol9?NnoOol01Gl0O^1nh7l0Ob001Goo1Sg_17oo00<007ooOol0
87oo000ROol00`00?Nlmk`06?NnnOol4O^000glPOomoo`02Ool7?Nl3Ool00`00Oomoo`0QOol002=o
o`Pmkkeoo`An`09nh0Aoo`Hmk`=oo`03001oogoo029oo`0097oo2Cg_^goo00EnX7fPOJ1nX7kP00Eo
o`Hmk`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo17fP00=o07ooOol00Woo1cg_0Woo
00<007ooOol08goo000UOol:?NnhOol4OD02OJ04Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000m
kcg_00LmkkIoo`Am8003OD1mX7oo00=oo`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo
17cP00=m@7jPOol00Woo1cg_0Woo00<007ooOol09Goo000WOol00`00Oolmk`0:?NnbOol4O>0017e0
Oomoogoo23g_00=oo`00Ool09goo000XOol00`00Oolmk`09?NnaOol4O<02O>02Ool8?Nl00goo001o
o`0XOol002Uoo`03001oocg_00Tmkk1oo`AlX003O>1oogoo00Pmk`03Ool007oo02Uoo`00:Woo00<0
07oo?Nl023g_/7oo17bP00=lh7oo?Nl023g_00<007ooOol0:Goo000ZOol00`00Oomoo`09?Nn^Ool4
O602O:000goo?Nlmk`07?Nl00`00Oomoo`0YOol002]oo`03001oogoo00Tmkjeoo`Al@003O:1oogoo
00Pmk`03001oogoo02Yoo`00;7oo00<007oo?Nl023g_[7oo1G`000=lX3g_?Nl01cg_00<007ooOol0
:goo000]Ool00`00Oolmk`08?Nn[Ool5O0000goo?Nlmk`06?Nl00`00Oomoo`0/Ool002ioo`03001o
ogoo00PmkjYoo`El00Pmk`03001oogoo02eoo`00;Woo00@007ooOomoo`PmkjUoo`El00Dmk`=oo`03
001oogoo02eoo`00;goo00@007ooOomoo`TmkjUoo`Lmk`=oo`03001oogoo02ioo`00<7oo00@007oo
Oomoo`PmkjQoo`Lmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo`PmkjEoo`Lmk`Aoo`03001o
ogoo031oo`00<Woo0P000Woo23g_XGoo2Cg_0goo0P00<goo000dOol00`00Oomoo`08?NnNOol:?Nl3
Ool00`00Oomoo`0cOol003Eoo`03001oocg_00Pmkieoo`Tmk`=oo`03001oogoo03Aoo`00=Goo00@0
07ooOomoo`Pmkiaoo`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkiYoo`Lmk`Eoo`03
001oogoo03Eoo`00=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<007ooOol0=Woo000hOol00`00
Oomoo`02Ool7?NnFOol7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki=oo`Pmk`=oo`8003Yo
o`00>goo00<007ooOol02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000lOol00`00Oomoo`09?Nn>Ool9
?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eoo`03001oogoo03aoo`00?Woo
0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3Ool00`00Oomoo`0o
Ool0045oo`800003Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo00<007oo?Nl02Cg_NWoo1Cg_
00=oocg_?Nl01Cg_1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?NmjOol=?Nl4Ool00`00Oomo
o`13Ool004Eoo`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl02Sg_
MGoo33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYoo``mk`9o
o`8004]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomoo`1=Ool0
04moo`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P000Woo43g_FGoo00<mkgoo
Ool02Sg_0goo0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>?Nl00goo0000001C
Ool005Aoo`800003?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool0000005Eoo`00EWoo0P0017oo43g_
0goo1Sg_@Woo43g_0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00Oomoo`1GOol005]oo`<000=o
oa@mkceooa0mk`8005aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001POol20004OolC?NlXOolN?NmQ
Ool0069oo`<000Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`001Goo5Cg_1goo2Cg_
0goo8Sg_0`00IWoo001XOol40003Oom4?Nl4001YOol006aoo`@000=ooc/mk`03Ool00000008006eo
o`00L7oo0`000goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@0
01dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol008]oo`8000=oo`<008eoo`00RWoo00@007ooOol000Aoo`03001oogoo
08]oo`00RWoo00@007ooOol000=oo`<008aoo`00Rgoo0P000goo00@007ooOol008aoo`00RWoo00@0
07ooOol0009oo`04001oogoo002<Ool008]oo`8000Aoo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(90)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
1 .958 0 r
.008 w
.81384 .81451 Mdot
.016 w
.81384 .81451 m
.8138 .81459 L
s
1 .917 0 r
.008 w
.8138 .81459 Mdot
.016 w
.8138 .81459 m
.81371 .81481 L
s
1 .875 0 r
.008 w
.81371 .81481 Mdot
.016 w
.81371 .81481 m
.81362 .81521 L
s
1 .833 0 r
.008 w
.81362 .81521 Mdot
.016 w
.81362 .81521 m
.81347 .81588 L
s
1 .792 0 r
.008 w
.81347 .81588 Mdot
.016 w
.81347 .81588 m
.8133 .81671 L
s
1 .75 0 r
.008 w
.8133 .81671 Mdot
.016 w
.8133 .81671 m
.81308 .81777 L
s
1 .708 0 r
.008 w
.81308 .81777 Mdot
.016 w
.81308 .81777 m
.81285 .81913 L
s
1 .667 0 r
.008 w
.81285 .81913 Mdot
.016 w
.81285 .81913 m
.81262 .82023 L
s
1 .625 0 r
.008 w
.81262 .82023 Mdot
.016 w
.81262 .82023 m
.81239 .8218 L
s
1 .583 0 r
.008 w
.81239 .8218 Mdot
.016 w
.81239 .8218 m
.81214 .8233 L
s
1 .542 0 r
.008 w
.81214 .8233 Mdot
.016 w
.81214 .8233 m
.81188 .82458 L
s
1 .5 0 r
.008 w
.81188 .82458 Mdot
.016 w
.81188 .82458 m
.81159 .82623 L
s
1 .458 0 r
.008 w
.81159 .82623 Mdot
.016 w
.81159 .82623 m
.81126 .82774 L
s
1 .417 0 r
.008 w
.81126 .82774 Mdot
.016 w
.81126 .82774 m
.81091 .82923 L
s
1 .375 0 r
.008 w
.81091 .82923 Mdot
.016 w
.81091 .82923 m
.81055 .83062 L
s
1 .333 0 r
.008 w
.81055 .83062 Mdot
.016 w
.81055 .83062 m
.81021 .83185 L
s
1 .292 0 r
.008 w
.81021 .83185 Mdot
.016 w
.81021 .83185 m
.80989 .83285 L
s
1 .25 0 r
.008 w
.80989 .83285 Mdot
.016 w
.80989 .83285 m
.8096 .83361 L
s
1 .208 0 r
.008 w
.8096 .83361 Mdot
.016 w
.8096 .83361 m
.80937 .83419 L
s
1 .167 0 r
.008 w
.80937 .83419 Mdot
.016 w
.80937 .83419 m
.80916 .83461 L
s
1 .125 0 r
.008 w
.80916 .83461 Mdot
.016 w
.80916 .83461 m
.80899 .83491 L
s
1 .083 0 r
.008 w
.80899 .83491 Mdot
.016 w
.80899 .83491 m
.80887 .83513 L
s
1 .042 0 r
.008 w
.80887 .83513 Mdot
.016 w
.80887 .83513 m
.80878 .83529 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?No:Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00HmklQooa0mk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_b7oo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?No8
Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00DmklQoo`Hmk`=oo`Hmk`Moo`03001oogoo
01]oo`007Goo00<007oo?Nl013g_agoo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolm
k`05?No6Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mklIoo`Dmk`Eoo`Dm
k`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_aGoo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo
000OOol7?No5Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Dmkl=oo`Dmk`Eo
o`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_`Woo1Cg_17oo1Sg_1Goo00<007ooOol0
7goo000POol00`00?Nlmk`06?No0Ool5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tmkkmoo`Dm
k`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl01Sg__Woo1Cg_17oo1cg_0goo00<007oo
Ool08Goo000SOol8?NnmOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`Tmkk]oo`Dmk`Eoo`Hm
k`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo
000UOol:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Ao
o`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo
000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5o
o`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0
:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tm
kjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007oo
Ool0:Woo000/Ool00`00Oolmk`08?Nn/Ool4Od000cg_Oolmk`08?Nl00`00Oomoo`0[Ool002eoo`03
001oocg_00Pmkj]oo`AnX003?Nmoocg_00Lmk`03001oogoo02aoo`00;Woo00<007ooOol023g_ZWoo
00An@7g0OL1n@0Tmk`03001oogoo02eoo`00;Woo00@007ooOomoo`PmkjUoo`Am`0Hmk`=oo`03001o
ogoo02eoo`00;goo00@007ooOomoo`TmkjIoo`AmH09m`0@mk`=oo`03001oogoo02ioo`00<7oo00@0
07ooOomoo`PmkjIoo`Al`003OL0mkcg_008mk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo`Pm
kjEoo`05O<1l87c0O<1n@002?Nl4Ool00`00Oomoo`0`Ool0039oo`80009oo`Pmkj5oo`<mk`04O<1l
87c0O<02?Nl3Ool2000cOol003Aoo`03001oogoo00Pmkiioo`Dmk`Al`005?NmoogooOol0000eOol0
03Eoo`03001oocg_00Pmkieoo`Dmk`Al`0=oo`03001oogoo03Aoo`00=Goo00@007ooOomoo`Pmkiao
o`Tmk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkiYoo`Lmk`Eoo`03001oogoo03Eoo`00
=goo00<007ooOol00Woo1cg_V7oo1Sg_1Woo00<007ooOol0=Woo000hOol00`00Oomoo`02Ool7?NnF
Ool7?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki=oo`Pmk`=oo`8003Yoo`00>goo00<007oo
Ool02Cg_T7oo2Cg_0goo00<007ooOol0>Woo000lOol00`00Oomoo`09?Nn>Ool9?Nl3Ool00`00Oomo
o`0kOol003eoo`03001oogoo00XmkhYoo`Pmk`Eoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_Qgoo
2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3Ool00`00Oomoo`0oOol0045oo`800003
Oolmkcg_00Lmkh=oo`Pmk`Aoo`80049oo`00@goo00<007oo?Nl02Cg_NWoo1Cg_00=oocg_?Nl01Cg_
1Goo00<007ooOol0@Woo0014Ool00`00?Nlmk`08?NmjOol=?Nl4Ool00`00Oomoo`13Ool004Eoo`03
000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl02Sg_MGoo33g_0goo0P00
Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYoo``mk`9oo`8004]oo`00C7oo
43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomoo`1=Ool004moo`03000mkcg_
00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P000Woo43g_FGoo00<mkgooOol02Sg_0goo0P00
DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>?Nl00goo0000001COol005Aoo`800003
?Nmoocg_010mk`Moo`Dmkd=ooa0mk`03Ool0000005Eoo`00EWoo0P0017oo43g_0goo1Sg_@Woo43g_
0P00Egoo001HOol30004OolF?Nm0OolA?Nl00`00Oomoo`1GOol005]oo`<000=ooa@mkceooa0mk`80
05aoo`00GWoo0P0017oo4Sg_>7oo53g_GWoo001POol20004OolC?NlXOolN?NmQOol0069oo`<000Ao
oa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`001Goo5Cg_1goo2Cg_0goo8Sg_0`00IWoo
001XOol40003Oom4?Nl4001YOol006aoo`@000=ooc/mk`03Ool00000008006eoo`00L7oo0`000goo
<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L007Uo
o`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol008Yoo`<000Aoo`8008eoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00Rgoo
0`000Woo00@007ooOol008aoo`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008Yoo`04001o
ogoo0002Ool01000Oomoo`00S7oo002;Ool30003Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(91)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
1 .992 0 r
.008 w
.80909 .83492 Mdot
.016 w
.80909 .83492 m
.80898 .83489 L
s
1 .985 0 r
.008 w
.80898 .83489 Mdot
.016 w
.80898 .83489 m
.80878 .83493 L
s
1 .977 0 r
.008 w
.80878 .83493 Mdot
.016 w
.80878 .83493 m
.80846 .83504 L
s
1 .97 0 r
.008 w
.80846 .83504 Mdot
.016 w
.80846 .83504 m
.80798 .83523 L
s
1 .962 0 r
.008 w
.80798 .83523 Mdot
.016 w
.80798 .83523 m
.80728 .83554 L
s
1 .955 0 r
.008 w
.80728 .83554 Mdot
.016 w
.80728 .83554 m
.80647 .83598 L
s
1 .947 0 r
.008 w
.80647 .83598 Mdot
.016 w
.80647 .83598 m
.80541 .83658 L
s
1 .94 0 r
.008 w
.80541 .83658 Mdot
.016 w
.80541 .83658 m
.80412 .83733 L
s
1 .932 0 r
.008 w
.80412 .83733 Mdot
.016 w
.80412 .83733 m
.80272 .83821 L
s
1 .925 0 r
.008 w
.80272 .83821 Mdot
.016 w
.80272 .83821 m
.80112 .83923 L
s
1 .917 0 r
.008 w
.80112 .83923 Mdot
.016 w
.80112 .83923 m
.79932 .84031 L
s
1 .91 0 r
.008 w
.79932 .84031 Mdot
.016 w
.79932 .84031 m
.79746 .84151 L
s
1 .902 0 r
.008 w
.79746 .84151 Mdot
.016 w
.79746 .84151 m
.79551 .84269 L
s
1 .895 0 r
.008 w
.79551 .84269 Mdot
.016 w
.79551 .84269 m
.79362 .84393 L
s
1 .887 0 r
.008 w
.79362 .84393 Mdot
.016 w
.79362 .84393 m
.79172 .84512 L
s
1 .88 0 r
.008 w
.79172 .84512 Mdot
.016 w
.79172 .84512 m
.78992 .84619 L
s
1 .872 0 r
.008 w
.78992 .84619 Mdot
.016 w
.78992 .84619 m
.78836 .84714 L
s
1 .865 0 r
.008 w
.78836 .84714 Mdot
.016 w
.78836 .84714 m
.78693 .84795 L
s
1 .857 0 r
.008 w
.78693 .84795 Mdot
.016 w
.78693 .84795 m
.7857 .84862 L
s
1 .85 0 r
.008 w
.7857 .84862 Mdot
.016 w
.7857 .84862 m
.78471 .84915 L
s
1 .842 0 r
.008 w
.78471 .84915 Mdot
.016 w
.78471 .84915 m
.784 .84954 L
s
1 .835 0 r
.008 w
.784 .84954 Mdot
.016 w
.784 .84954 m
.78345 .84979 L
s
1 .827 0 r
.008 w
.78345 .84979 Mdot
.016 w
.78345 .84979 m
.78309 .84988 L
s
1 .82 0 r
.008 w
.78309 .84988 Mdot
.016 w
.78309 .84988 m
.7829 .84984 L
s
1 .812 0 r
.008 w
.7829 .84984 Mdot
.016 w
.7829 .84984 m
.78282 .8497 L
s
1 .805 0 r
.008 w
.78282 .8497 Mdot
.016 w
.78282 .8497 m
.78279 .84956 L
s
1 .797 0 r
.008 w
.78279 .84956 Mdot
.016 w
.78279 .84956 m
.78274 .84949 L
s
1 .789 0 r
.008 w
.78274 .84949 Mdot
.016 w
.78274 .84949 m
.78267 .84952 L
s
1 .782 0 r
.008 w
.78267 .84952 Mdot
.016 w
.78267 .84952 m
.78252 .84968 L
s
1 .774 0 r
.008 w
.78252 .84968 Mdot
.016 w
.78252 .84968 m
.7823 .84996 L
s
1 .767 0 r
.008 w
.7823 .84996 Mdot
.016 w
.7823 .84996 m
.78199 .85033 L
s
1 .759 0 r
.008 w
.78199 .85033 Mdot
.016 w
.78199 .85033 m
.78163 .85081 L
s
1 .752 0 r
.008 w
.78163 .85081 Mdot
.016 w
.78163 .85081 m
.78115 .8514 L
s
1 .744 0 r
.008 w
.78115 .8514 Mdot
.016 w
.78115 .8514 m
.7806 .85207 L
s
1 .737 0 r
.008 w
.7806 .85207 Mdot
.016 w
.7806 .85207 m
.77998 .8528 L
s
1 .729 0 r
.008 w
.77998 .8528 Mdot
.016 w
.77998 .8528 m
.77932 .85361 L
s
1 .722 0 r
.008 w
.77932 .85361 Mdot
.016 w
.77932 .85361 m
.77867 .85447 L
s
1 .714 0 r
.008 w
.77867 .85447 Mdot
.016 w
.77867 .85447 m
.77799 .85539 L
s
1 .707 0 r
.008 w
.77799 .85539 Mdot
.016 w
.77799 .85539 m
.77723 .85638 L
s
1 .699 0 r
.008 w
.77723 .85638 Mdot
.016 w
.77723 .85638 m
.77643 .85742 L
s
1 .692 0 r
.008 w
.77643 .85742 Mdot
.016 w
.77643 .85742 m
.77557 .8585 L
s
1 .684 0 r
.008 w
.77557 .8585 Mdot
.016 w
.77557 .8585 m
.77459 .8596 L
s
1 .677 0 r
.008 w
.77459 .8596 Mdot
.016 w
.77459 .8596 m
.77362 .86079 L
s
1 .669 0 r
.008 w
.77362 .86079 Mdot
.016 w
.77362 .86079 m
.77249 .86208 L
s
1 .662 0 r
.008 w
.77249 .86208 Mdot
.016 w
.77249 .86208 m
.77119 .8635 L
s
1 .654 0 r
.008 w
.77119 .8635 Mdot
.016 w
.77119 .8635 m
.7697 .86507 L
s
1 .647 0 r
.008 w
.7697 .86507 Mdot
.016 w
.7697 .86507 m
.76818 .86668 L
s
1 .639 0 r
.008 w
.76818 .86668 Mdot
.016 w
.76818 .86668 m
.76647 .86839 L
s
1 .632 0 r
.008 w
.76647 .86839 Mdot
.016 w
.76647 .86839 m
.76459 .87015 L
s
1 .624 0 r
.008 w
.76459 .87015 Mdot
.016 w
.76459 .87015 m
.76277 .87183 L
s
1 .617 0 r
.008 w
.76277 .87183 Mdot
.016 w
.76277 .87183 m
.76105 .87336 L
s
1 .609 0 r
.008 w
.76105 .87336 Mdot
.016 w
.76105 .87336 m
.75941 .87474 L
s
1 .602 0 r
.008 w
.75941 .87474 Mdot
.016 w
.75941 .87474 m
.75786 .87597 L
s
1 .594 0 r
.008 w
.75786 .87597 Mdot
.016 w
.75786 .87597 m
.75649 .87702 L
s
1 .586 0 r
.008 w
.75649 .87702 Mdot
.016 w
.75649 .87702 m
.75514 .87797 L
s
1 .579 0 r
.008 w
.75514 .87797 Mdot
.016 w
.75514 .87797 m
.75393 .87883 L
s
1 .571 0 r
.008 w
.75393 .87883 Mdot
.016 w
.75393 .87883 m
.75276 .8796 L
s
1 .564 0 r
.008 w
.75276 .8796 Mdot
.016 w
.75276 .8796 m
.75167 .88029 L
s
1 .556 0 r
.008 w
.75167 .88029 Mdot
.016 w
.75167 .88029 m
.75064 .88093 L
s
1 .549 0 r
.008 w
.75064 .88093 Mdot
.016 w
.75064 .88093 m
.74961 .88151 L
s
1 .541 0 r
.008 w
.74961 .88151 Mdot
.016 w
.74961 .88151 m
.74863 .88214 L
s
1 .534 0 r
.008 w
.74863 .88214 Mdot
.016 w
.74863 .88214 m
.74758 .88283 L
s
1 .526 0 r
.008 w
.74758 .88283 Mdot
.016 w
.74758 .88283 m
.74646 .88357 L
s
1 .519 0 r
.008 w
.74646 .88357 Mdot
.016 w
.74646 .88357 m
.74527 .8844 L
s
1 .511 0 r
.008 w
.74527 .8844 Mdot
.016 w
.74527 .8844 m
.74408 .88525 L
s
1 .504 0 r
.008 w
.74408 .88525 Mdot
.016 w
.74408 .88525 m
.7428 .88618 L
s
1 .496 0 r
.008 w
.7428 .88618 Mdot
.016 w
.7428 .88618 m
.74143 .88717 L
s
1 .489 0 r
.008 w
.74143 .88717 Mdot
.016 w
.74143 .88717 m
.74004 .88816 L
s
1 .481 0 r
.008 w
.74004 .88816 Mdot
.016 w
.74004 .88816 m
.73868 .88914 L
s
1 .474 0 r
.008 w
.73868 .88914 Mdot
.016 w
.73868 .88914 m
.73734 .89005 L
s
1 .466 0 r
.008 w
.73734 .89005 Mdot
.016 w
.73734 .89005 m
.73614 .89083 L
s
1 .459 0 r
.008 w
.73614 .89083 Mdot
.016 w
.73614 .89083 m
.73504 .89149 L
s
1 .451 0 r
.008 w
.73504 .89149 Mdot
.016 w
.73504 .89149 m
.73402 .89206 L
s
1 .444 0 r
.008 w
.73402 .89206 Mdot
.016 w
.73402 .89206 m
.73304 .89261 L
s
1 .436 0 r
.008 w
.73304 .89261 Mdot
.016 w
.73304 .89261 m
.73211 .89318 L
s
1 .429 0 r
.008 w
.73211 .89318 Mdot
.016 w
.73211 .89318 m
.73119 .89378 L
s
1 .421 0 r
.008 w
.73119 .89378 Mdot
.016 w
.73119 .89378 m
.73031 .89441 L
s
1 .414 0 r
.008 w
.73031 .89441 Mdot
.016 w
.73031 .89441 m
.72936 .8951 L
s
1 .406 0 r
.008 w
.72936 .8951 Mdot
.016 w
.72936 .8951 m
.72831 .89591 L
s
1 .398 0 r
.008 w
.72831 .89591 Mdot
.016 w
.72831 .89591 m
.72711 .89689 L
s
1 .391 0 r
.008 w
.72711 .89689 Mdot
.016 w
.72711 .89689 m
.72573 .89806 L
s
1 .383 0 r
.008 w
.72573 .89806 Mdot
.016 w
.72573 .89806 m
.72414 .89944 L
s
1 .376 0 r
.008 w
.72414 .89944 Mdot
.016 w
.72414 .89944 m
.72231 .90105 L
s
1 .368 0 r
.008 w
.72231 .90105 Mdot
.016 w
.72231 .90105 m
.72057 .90267 L
s
1 .361 0 r
.008 w
.72057 .90267 Mdot
.016 w
.72057 .90267 m
.71854 .90438 L
s
1 .353 0 r
.008 w
.71854 .90438 Mdot
.016 w
.71854 .90438 m
.71632 .9063 L
s
1 .346 0 r
.008 w
.71632 .9063 Mdot
.016 w
.71632 .9063 m
.71417 .90839 L
s
1 .338 0 r
.008 w
.71417 .90839 Mdot
.016 w
.71417 .90839 m
.71165 .91053 L
s
1 .331 0 r
.008 w
.71165 .91053 Mdot
.016 w
.71165 .91053 m
.70943 .91243 L
s
1 .323 0 r
.008 w
.70943 .91243 Mdot
.016 w
.70943 .91243 m
.70716 .91434 L
s
1 .316 0 r
.008 w
.70716 .91434 Mdot
.016 w
.70716 .91434 m
.7049 .91615 L
s
1 .308 0 r
.008 w
.7049 .91615 Mdot
.016 w
.7049 .91615 m
.70285 .91771 L
s
1 .301 0 r
.008 w
.70285 .91771 Mdot
.016 w
.70285 .91771 m
.70094 .91913 L
s
1 .293 0 r
.008 w
.70094 .91913 Mdot
.016 w
.70094 .91913 m
.69931 .92037 L
s
1 .286 0 r
.008 w
.69931 .92037 Mdot
.016 w
.69931 .92037 m
.69786 .92142 L
s
1 .278 0 r
.008 w
.69786 .92142 Mdot
.016 w
.69786 .92142 m
.69654 .92237 L
s
1 .271 0 r
.008 w
.69654 .92237 Mdot
.016 w
.69654 .92237 m
.69531 .92322 L
s
1 .263 0 r
.008 w
.69531 .92322 Mdot
.016 w
.69531 .92322 m
.69423 .92402 L
s
1 .256 0 r
.008 w
.69423 .92402 Mdot
.016 w
.69423 .92402 m
.69313 .92473 L
s
1 .248 0 r
.008 w
.69313 .92473 Mdot
.016 w
.69313 .92473 m
.69203 .92542 L
s
1 .241 0 r
.008 w
.69203 .92542 Mdot
.016 w
.69203 .92542 m
.69092 .92604 L
s
1 .233 0 r
.008 w
.69092 .92604 Mdot
.016 w
.69092 .92604 m
.68989 .92669 L
s
1 .226 0 r
.008 w
.68989 .92669 Mdot
.016 w
.68989 .92669 m
.68888 .92731 L
s
1 .218 0 r
.008 w
.68888 .92731 Mdot
.016 w
.68888 .92731 m
.68795 .92787 L
s
1 .211 0 r
.008 w
.68795 .92787 Mdot
.016 w
.68795 .92787 m
.68713 .92836 L
s
1 .203 0 r
.008 w
.68713 .92836 Mdot
.016 w
.68713 .92836 m
.68645 .92873 L
s
1 .195 0 r
.008 w
.68645 .92873 Mdot
.016 w
.68645 .92873 m
.68591 .92895 L
s
1 .188 0 r
.008 w
.68591 .92895 Mdot
.016 w
.68591 .92895 m
.68548 .92908 L
s
1 .18 0 r
.008 w
.68548 .92908 Mdot
.016 w
.68548 .92908 m
.68513 .92914 L
s
1 .173 0 r
.008 w
.68513 .92914 Mdot
.016 w
.68513 .92914 m
.6849 .92909 L
s
1 .165 0 r
.008 w
.6849 .92909 Mdot
.016 w
.6849 .92909 m
.68476 .92897 L
s
1 .158 0 r
.008 w
.68476 .92897 Mdot
.016 w
.68476 .92897 m
.68468 .92881 L
s
1 .15 0 r
.008 w
.68468 .92881 Mdot
.016 w
.68468 .92881 m
.68465 .92857 L
s
1 .143 0 r
.008 w
.68465 .92857 Mdot
.016 w
.68465 .92857 m
.68465 .92836 L
s
1 .135 0 r
.008 w
.68465 .92836 Mdot
.016 w
.68465 .92836 m
.68467 .9282 L
s
1 .128 0 r
.008 w
.68467 .9282 Mdot
.016 w
.68467 .9282 m
.68468 .92812 L
s
1 .12 0 r
.008 w
.68468 .92812 Mdot
.016 w
.68468 .92812 m
.68463 .92817 L
s
1 .113 0 r
.008 w
.68463 .92817 Mdot
.016 w
.68463 .92817 m
.68447 .92836 L
s
1 .105 0 r
.008 w
.68447 .92836 Mdot
.016 w
.68447 .92836 m
.6842 .9287 L
s
1 .098 0 r
.008 w
.6842 .9287 Mdot
.016 w
.6842 .9287 m
.68381 .92911 L
s
1 .09 0 r
.008 w
.68381 .92911 Mdot
.016 w
.68381 .92911 m
.68332 .9296 L
s
1 .083 0 r
.008 w
.68332 .9296 Mdot
.016 w
.68332 .9296 m
.68273 .93013 L
s
1 .075 0 r
.008 w
.68273 .93013 Mdot
.016 w
.68273 .93013 m
.68198 .93073 L
s
1 .068 0 r
.008 w
.68198 .93073 Mdot
.016 w
.68198 .93073 m
.68135 .93124 L
s
1 .06 0 r
.008 w
.68135 .93124 Mdot
.016 w
.68135 .93124 m
.68065 .93177 L
s
1 .053 0 r
.008 w
.68065 .93177 Mdot
.016 w
.68065 .93177 m
.68003 .93223 L
s
1 .045 0 r
.008 w
.68003 .93223 Mdot
.016 w
.68003 .93223 m
.67954 .93261 L
s
1 .038 0 r
.008 w
.67954 .93261 Mdot
.016 w
.67954 .93261 m
.67913 .93292 L
s
1 .03 0 r
.008 w
.67913 .93292 Mdot
.016 w
.67913 .93292 m
.67881 .93313 L
s
1 .023 0 r
.008 w
.67881 .93313 Mdot
.016 w
.67881 .93313 m
.67854 .93327 L
s
1 .015 0 r
.008 w
.67854 .93327 Mdot
.016 w
.67854 .93327 m
.67833 .93334 L
s
1 .008 0 r
.008 w
.67833 .93334 Mdot
.016 w
.67833 .93334 m
.6781 .93334 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?No:Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00HmklQooa0mk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_b7oo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?No8
Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00DmklQoo`Hmk`=oo`Hmk`Moo`03001oogoo
01]oo`007Goo00<007oo?Nl013g_agoo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolm
k`05?No6Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mklIoo`Dmk`Eoo`Dm
k`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_aGoo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo
000OOol7?No5Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Dmkl=oo`Dmk`Eo
o`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_`Woo1Cg_17oo1Sg_1Goo00<007ooOol0
7goo000POol00`00?Nlmk`06?No0Ool5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tmkkmoo`Dm
k`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl01Sg__Woo1Cg_17oo1cg_0goo00<007oo
Ool08Goo000SOol8?NnmOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`Tmkk]oo`Dmk`Eoo`Hm
k`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo
000UOol:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Ao
o`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo
000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5o
o`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0
:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tm
kjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007oo
Ool0:Woo000/Ool00`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03
001oocg_00Pmkj]oo`Dmk`03Oolmkcg_00Hmk`03001oogoo02aoo`00;Woo00<007ooOol023g_ZWoo
3Cg_00<007ooOol0;Goo000^Ool01000Oomoogoo23g_ZGoo2Sg_0goo00<007ooOol0;Goo000_Ool0
1000Oomoogoo2Cg_YWoo2Sg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo23g_YWoo0WnP00=o
h3g_?Nl013g_0goo00<007ooOol0;goo000aOol01000Oomoogoo23g_Y7oo17nP00Ao`3g_?Nlmk`Ao
o`03001oogoo031oo`00<Woo0P000Woo23g_XGoo0Wn01GnP0Sg_0goo0P00<goo000dOol00`00Oomo
o`08?NnNOol2Of04Oh02Oj000go0?Nmoo`02Ool00`00Oomoo`0cOol003Eoo`03001oocg_00Pmkiao
o`9o80=oH09oP003Oj1o`7o000=oo`03001oogoo03Aoo`00=Goo00@007ooOomoo`PmkiUoo`Anh003
O`1oH7mP009oP003Oj0mkcg_00=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`PmkiMoo`03O/1n
X7jP009n`003O`1oH7mP009oP0Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo1cg_UWoo17jP
00An`7l0Of1oH0Ioo`03001oogoo03Ioo`00>7oo00<007ooOol00Woo1cg_U7oo0Wj017jP00=o03g_
?Nl01Goo00<007ooOol0=goo000iOol20003Ool8?NnAOol2OV02OX02OZ0017k0?Nlmkcg_0goo0P00
>Woo000kOol00`00Oomoo`09?Nn?Ool4OV02OX0017k0?Nlmkcg_0goo00<007ooOol0>Woo000lOol0
0`00Oomoo`09?Nn=Ool6OV04?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhUoo`An@0=n
H08mk`Eoo`03001oogoo03aoo`00?Woo0P000Woo2Cg_Qgoo17hP00=n@7iPOV000Sg_17oo0P00?goo
0010Ool00`00Oomoo`09?Nn4Ool5OP000ghPOT1nH003?Nl3Ool00`00Oomoo`0oOol0045oo`800003
Oolmkcg_00Lmkh9oo`Emh004OP1n87i0OV04Ool20012Ool004=oo`03001oocg_00TmkgYoo`@mk`9m
P0=m`09mh003OP1n87i000Aoo`03001oogoo049oo`00A7oo00<003g_?Nl023g_NWoo0cg_17f000Im
X7g0ON1mh7h0OR04Ool00`00Oomoo`13Ool004Eoo`03000mkcg_00XmkgMoo`8mk`9mH0AmP003OL1m
h7gP00Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl02Sg_MGoo0Sg_17eP0Wf000AmX7g0ON0mk`=o
o`8004Moo`00B7oo3Sg_0Woo0Sg_K7oo0Sg_1geP0WfP0Sg_0Woo0P00BGoo001:OolA?NmZOol2?Nl5
OD02OF03?Nl2Ool2001;Ool004aooa0mkfMoo`<mk`9m80Am@003OF0mkgoo009oo`8004eoo`00CWoo
4Cg_Hgoo0cg_17dP0ge000EmH7ooOomoo`0004moo`00Cgoo00<003g_?Nl03cg_H7oo0Sg_17d00gdP
0We000@mkgooOol0051oo`00D7oo0P000Woo43g_FGoo00@mkgooOolmk`9lH0=lh003O@1m87dP009m
@09oo`80055oo`00DWoo0P0000=oocg_?Nl043g_DWoo00<mkgooOol013g_17aP00Al`7cPO@1m809m
@003Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_1goo1Cg_@goo1Sg_1G`P0WaP00Alh7d0OB1o
o`8005Eoo`00EWoo0P0017oo43g_0goo1Sg_@Woo1cg_00=l87`0O0000W`P00AlH7c0O>1m008005Mo
o`00F7oo0`0017oo5Sg_@7oo2Cg_00=l87`0O0000W`P00AlP7c0O>0005Uoo`00Fgoo0`000goo53g_
?Goo33g_1G`P00=lP7ooOol0FWoo001NOol20004OolB?NlhOol@?Nl4O21NOol0061oo`8000Aooa<m
kbQooahmkf5oo`00HWoo0`0017oo53g_47oo0Sg_3Goo83g_00<007ooOol0HGoo001UOol30005OolE
?Nl7Ool9?Nl3OolR?Nl3001VOol006Qoo`@000=ood@mk`@006Uoo`00K7oo10000goo>cg_00=oo`00
00000P00KGoo001`Ool30003Ool`?Nl5Ool4001aOol007=oo`D00003Oolmkcg_02Dmk`Moo`@007Eo
o`00N7oo10007Cg_1goo1`00NGoo001nOol@?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo0`000goo1@00Rgoo002<Ool00`00Oomoo`03Ool0
0`00Oomoo`2;Ool008]oo`<000Aoo`03001oogoo08]oo`00RWoo00@007ooOol000Aoo`03001oogoo
08]oo`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00Rgoo0`000goo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(92)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
1 .982 0 r
.008 w
.6744 .93349 Mdot
.016 w
.6744 .93349 m
.67431 .93363 L
s
1 .964 0 r
.008 w
.67431 .93363 Mdot
.016 w
.67431 .93363 m
.67416 .93377 L
s
1 .946 0 r
.008 w
.67416 .93377 Mdot
.016 w
.67416 .93377 m
.67398 .93389 L
s
1 .929 0 r
.008 w
.67398 .93389 Mdot
.016 w
.67398 .93389 m
.67381 .93397 L
s
1 .911 0 r
.008 w
.67381 .93397 Mdot
.016 w
.67381 .93397 m
.67366 .93402 L
s
1 .893 0 r
.008 w
.67366 .93402 Mdot
.016 w
.67366 .93402 m
.67329 .93413 L
s
1 .875 0 r
.008 w
.67329 .93413 Mdot
.016 w
.67329 .93413 m
.67302 .9342 L
s
1 .857 0 r
.008 w
.67302 .9342 Mdot
.016 w
.67302 .9342 m
.67268 .93428 L
s
1 .839 0 r
.008 w
.67268 .93428 Mdot
.016 w
.67268 .93428 m
.67219 .93438 L
s
1 .821 0 r
.008 w
.67219 .93438 Mdot
.016 w
.67219 .93438 m
.67152 .93449 L
s
1 .804 0 r
.008 w
.67152 .93449 Mdot
.016 w
.67152 .93449 m
.67064 .93462 L
s
1 .786 0 r
.008 w
.67064 .93462 Mdot
.016 w
.67064 .93462 m
.66947 .93477 L
s
1 .768 0 r
.008 w
.66947 .93477 Mdot
.016 w
.66947 .93477 m
.66813 .93497 L
s
1 .75 0 r
.008 w
.66813 .93497 Mdot
.016 w
.66813 .93497 m
.66644 .93522 L
s
1 .732 0 r
.008 w
.66644 .93522 Mdot
.016 w
.66644 .93522 m
.66447 .93552 L
s
1 .714 0 r
.008 w
.66447 .93552 Mdot
.016 w
.66447 .93552 m
.66236 .93587 L
s
1 .696 0 r
.008 w
.66236 .93587 Mdot
.016 w
.66236 .93587 m
.65998 .93627 L
s
1 .679 0 r
.008 w
.65998 .93627 Mdot
.016 w
.65998 .93627 m
.65736 .93673 L
s
1 .661 0 r
.008 w
.65736 .93673 Mdot
.016 w
.65736 .93673 m
.65459 .93724 L
s
1 .643 0 r
.008 w
.65459 .93724 Mdot
.016 w
.65459 .93724 m
.6517 .93784 L
s
1 .625 0 r
.008 w
.6517 .93784 Mdot
.016 w
.6517 .93784 m
.64921 .93839 L
s
1 .607 0 r
.008 w
.64921 .93839 Mdot
.016 w
.64921 .93839 m
.64686 .93901 L
s
1 .589 0 r
.008 w
.64686 .93901 Mdot
.016 w
.64686 .93901 m
.64493 .93965 L
s
1 .571 0 r
.008 w
.64493 .93965 Mdot
.016 w
.64493 .93965 m
.6433 .94025 L
s
1 .554 0 r
.008 w
.6433 .94025 Mdot
.016 w
.6433 .94025 m
.64217 .94078 L
s
1 .536 0 r
.008 w
.64217 .94078 Mdot
.016 w
.64217 .94078 m
.64139 .94121 L
s
1 .518 0 r
.008 w
.64139 .94121 Mdot
.016 w
.64139 .94121 m
.64096 .94153 L
s
1 .5 0 r
.008 w
.64096 .94153 Mdot
.016 w
.64096 .94153 m
.64087 .94173 L
s
1 .482 0 r
.008 w
.64087 .94173 Mdot
.016 w
.64087 .94173 m
.64096 .94181 L
s
1 .464 0 r
.008 w
.64096 .94181 Mdot
.016 w
.64096 .94181 m
.64123 .94182 L
s
1 .446 0 r
.008 w
.64123 .94182 Mdot
.016 w
.64123 .94182 m
.64164 .94175 L
s
1 .429 0 r
.008 w
.64164 .94175 Mdot
.016 w
.64164 .94175 m
.64214 .94156 L
s
1 .411 0 r
.008 w
.64214 .94156 Mdot
.016 w
.64214 .94156 m
.64267 .94131 L
s
1 .393 0 r
.008 w
.64267 .94131 Mdot
.016 w
.64267 .94131 m
.64315 .94102 L
s
1 .375 0 r
.008 w
.64315 .94102 Mdot
.016 w
.64315 .94102 m
.64352 .94069 L
s
1 .357 0 r
.008 w
.64352 .94069 Mdot
.016 w
.64352 .94069 m
.64372 .94034 L
s
1 .339 0 r
.008 w
.64372 .94034 Mdot
.016 w
.64372 .94034 m
.6438 .93999 L
s
1 .321 0 r
.008 w
.6438 .93999 Mdot
.016 w
.6438 .93999 m
.64377 .93967 L
s
1 .304 0 r
.008 w
.64377 .93967 Mdot
.016 w
.64377 .93967 m
.64368 .93938 L
s
1 .286 0 r
.008 w
.64368 .93938 Mdot
.016 w
.64368 .93938 m
.64352 .93915 L
s
1 .268 0 r
.008 w
.64352 .93915 Mdot
.016 w
.64352 .93915 m
.64328 .93897 L
s
1 .25 0 r
.008 w
.64328 .93897 Mdot
.016 w
.64328 .93897 m
.64298 .9388 L
s
1 .232 0 r
.008 w
.64298 .9388 Mdot
.016 w
.64298 .9388 m
.64264 .93857 L
s
1 .214 0 r
.008 w
.64264 .93857 Mdot
.016 w
.64264 .93857 m
.64229 .9383 L
s
1 .196 0 r
.008 w
.64229 .9383 Mdot
.016 w
.64229 .9383 m
.64196 .93796 L
s
1 .179 0 r
.008 w
.64196 .93796 Mdot
.016 w
.64196 .93796 m
.64166 .93756 L
s
1 .161 0 r
.008 w
.64166 .93756 Mdot
.016 w
.64166 .93756 m
.64139 .93705 L
s
1 .143 0 r
.008 w
.64139 .93705 Mdot
.016 w
.64139 .93705 m
.64116 .93644 L
s
1 .125 0 r
.008 w
.64116 .93644 Mdot
.016 w
.64116 .93644 m
.641 .93582 L
s
1 .107 0 r
.008 w
.641 .93582 Mdot
.016 w
.641 .93582 m
.64091 .93523 L
s
1 .089 0 r
.008 w
.64091 .93523 Mdot
.016 w
.64091 .93523 m
.64086 .93468 L
s
1 .071 0 r
.008 w
.64086 .93468 Mdot
.016 w
.64086 .93468 m
.64083 .93419 L
s
1 .054 0 r
.008 w
.64083 .93419 Mdot
.016 w
.64083 .93419 m
.64082 .93376 L
s
1 .036 0 r
.008 w
.64082 .93376 Mdot
.016 w
.64082 .93376 m
.64081 .9335 L
s
1 .018 0 r
.008 w
.64081 .9335 Mdot
.016 w
.64081 .9335 m
.64082 .93339 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?No:Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00HmklQooa0mk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_b7oo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?No8
Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00DmklQoo`Hmk`=oo`Hmk`Moo`03001oogoo
01]oo`007Goo00<007oo?Nl013g_agoo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolm
k`05?No6Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mklIoo`Dmk`Eoo`Dm
k`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_aGoo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo
000OOol7?No5Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Dmkl=oo`Dmk`Eo
o`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_`Woo1Cg_17oo1Sg_1Goo00<007ooOol0
7goo000POol00`00?Nlmk`06?No0Ool5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tmkkmoo`Dm
k`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl01Sg__Woo1Cg_17oo1cg_0goo00<007oo
Ool08Goo000SOol8?NnmOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`Tmkk]oo`Dmk`Eoo`Hm
k`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo
000UOol:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Ao
o`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo
000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5o
o`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0
:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tm
kjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007oo
Ool0:Woo000/Ool00`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03
001oocg_00Pmkj]oo`Dmk`03Oolmkcg_00Hmk`03001oogoo02aoo`00;Woo00<007ooOol023g_ZWoo
3Cg_00<007ooOol0;Goo000^Ool01000Oomoogoo23g_ZGoo2Sg_0goo00<007ooOol0;Goo000_Ool0
1000Oomoogoo2Cg_YWoo2Sg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo23g_YWoo2Cg_0goo
00<007ooOol0;goo000aOol01000Oomoogoo23g_Y7oo23g_17oo00<007ooOol0<7oo000bOol20002
Ool8?NnQOol9?Nl3Ool2000cOol003Aoo`03001oogoo00Pmkiioo`Xmk`=oo`03001oogoo03=oo`00
=Goo00<007oo?Nl023g_W7oo2Sg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo23g_VGoo33g_
0goo00<007ooOol0=7oo000fOol01000Oomoogoo23g_Ugoo2Sg_1Goo00<007ooOol0=Goo000gOol0
0`00Oomoo`02Ool7?NnFOol8?Nl6Ool00`00Oomoo`0fOol003Qoo`03001oogoo009oo`LmkiAoo`Tm
k`Eoo`03001oogoo03Moo`00>Goo0P000goo23g_TGoo2Sg_0goo0P00>Woo000kOol00`00Oomoo`09
?Nn?Ool:?Nl3Ool00`00Oomoo`0jOol003aoo`03001oogoo00Tmkheoo`Xmk`=oo`03001oogoo03]o
o`00?Goo00<007ooOol02Sg_RGoo2Cg_1Goo00<007ooOol0?7oo000nOol20002Ool9?Nn7Ool9?Nl4
Ool2000oOol0041oo`03001oogoo00TmkhAoo`/mk`=oo`03001oogoo03moo`00@Goo0P0000=oocg_
?Nl01cg_PWoo2Cg_17oo0P00@Woo0013Ool00`00Oolmk`09?NmjOol>?Nl4Ool00`00Oomoo`12Ool0
04Aoo`03000mkcg_00PmkgYoo`dmk`Aoo`03001oogoo04=oo`00AGoo00<003g_?Nl02Sg_Mgoo2cg_
1Goo00<007ooOol0A7oo0016Ool00`00?Nlmk`0:?NmeOol<?Nl3Ool20017Ool004Qoo`hmk`9oo`8m
kfaoo`dmk`9oo`8004Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo001<Ool@?NmWOol;?Nl3Ool2001=
Ool004iooa4mkf=oo`/mk`=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03cg_H7oo33g_0Woo00<0
07ooOol0CWoo001@Ool20002Ool@?NmIOol00cg_Oomoo`0:?Nl3Ool2001AOol0059oo`800003Oolm
kcg_010mke9oo`03?Nmoogoo00hmk`03Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_1goo1Cg_
@7oo0W`000Aoocg_?Nlmk`9n`0/mk`03Ool0000005Eoo`00EWoo0P0017oo43g_0goo1Sg_?goo17`0
0Sg_17k000=nh7l0Of001Sg_0P00Egoo001HOol30004OolF?NloOol4O0000gi0OV1nH002OZ02O/00
0gl0Of0mk`04?Nl00`00Oomoo`1GOol005]oo`<000=ooa@mkceoo`8mk`04O61l07`0O602OT0027iP
OZ1nX7k0O^1o07mP?Nl2001LOol005ioo`8000Aooa8mkcQoo`Hmk`AlH003OT1nH7iP009nX09nh003
O`1oH3g_05ioo`00H7oo0P0017oo4cg_:7oo4cg_17aP0giP0WjP0Sg_HGoo001ROol30004OolD?Nl@
Ool2?Nl=OolH?Nl4OB04?Nl00`00Oomoo`1QOol006Eoo`<000EooaDmk`Moo`Tmk`=oob8mk`<006Io
o`00J7oo10000gooA3g_1000JGoo001/Ool40003Oolk?Nl00goo00000002001]Ool0071oo`<000=o
oc0mk`Eoo`@0075oo`00Lgoo1@0000=oocg_?Nl09Cg_1goo1000MGoo001hOol4000M?Nl7Ool7001i
Ool007iooa0mk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo002:Ool30003Ool4002<Ool008aoo`05001oogooOol0002?Ool008]oo`<000=oo`03001o
ogoo08aoo`00RWoo00@007ooOol000Aoo`03001oogoo08]oo`00RWoo00@007ooOol0009oo`04001o
ogoo002<Ool008]oo`<000=oo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(93)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
1 .989 0 r
.008 w
.6426 .9335 Mdot
.016 w
.6426 .9335 m
.64257 .93352 L
s
1 .977 0 r
.008 w
.64257 .93352 Mdot
.016 w
.64257 .93352 m
.6424 .93368 L
s
1 .966 0 r
.008 w
.6424 .93368 Mdot
.016 w
.6424 .93368 m
.64206 .93399 L
s
1 .954 0 r
.008 w
.64206 .93399 Mdot
.016 w
.64206 .93399 m
.64151 .93441 L
s
1 .943 0 r
.008 w
.64151 .93441 Mdot
.016 w
.64151 .93441 m
.64074 .93497 L
s
1 .931 0 r
.008 w
.64074 .93497 Mdot
.016 w
.64074 .93497 m
.63974 .93565 L
s
1 .92 0 r
.008 w
.63974 .93565 Mdot
.016 w
.63974 .93565 m
.63853 .93639 L
s
1 .908 0 r
.008 w
.63853 .93639 Mdot
.016 w
.63853 .93639 m
.63715 .93723 L
s
1 .897 0 r
.008 w
.63715 .93723 Mdot
.016 w
.63715 .93723 m
.63534 .93796 L
s
1 .885 0 r
.008 w
.63534 .93796 Mdot
.016 w
.63534 .93796 m
.63347 .93876 L
s
1 .874 0 r
.008 w
.63347 .93876 Mdot
.016 w
.63347 .93876 m
.63133 .93958 L
s
1 .862 0 r
.008 w
.63133 .93958 Mdot
.016 w
.63133 .93958 m
.62875 .94041 L
s
1 .851 0 r
.008 w
.62875 .94041 Mdot
.016 w
.62875 .94041 m
.62584 .94128 L
s
1 .839 0 r
.008 w
.62584 .94128 Mdot
.016 w
.62584 .94128 m
.62255 .94211 L
s
1 .828 0 r
.008 w
.62255 .94211 Mdot
.016 w
.62255 .94211 m
.61926 .94297 L
s
1 .816 0 r
.008 w
.61926 .94297 Mdot
.016 w
.61926 .94297 m
.61604 .94385 L
s
1 .805 0 r
.008 w
.61604 .94385 Mdot
.016 w
.61604 .94385 m
.61251 .94471 L
s
1 .793 0 r
.008 w
.61251 .94471 Mdot
.016 w
.61251 .94471 m
.60867 .94563 L
s
1 .782 0 r
.008 w
.60867 .94563 Mdot
.016 w
.60867 .94563 m
.60525 .94657 L
s
1 .77 0 r
.008 w
.60525 .94657 Mdot
.016 w
.60525 .94657 m
.60122 .94737 L
s
1 .759 0 r
.008 w
.60122 .94737 Mdot
.016 w
.60122 .94737 m
.59736 .94814 L
s
1 .747 0 r
.008 w
.59736 .94814 Mdot
.016 w
.59736 .94814 m
.59307 .94887 L
s
1 .736 0 r
.008 w
.59307 .94887 Mdot
.016 w
.59307 .94887 m
.58893 .94959 L
s
1 .724 0 r
.008 w
.58893 .94959 Mdot
.016 w
.58893 .94959 m
.58508 .95022 L
s
1 .713 0 r
.008 w
.58508 .95022 Mdot
.016 w
.58508 .95022 m
.581 .95083 L
s
1 .701 0 r
.008 w
.581 .95083 Mdot
.016 w
.581 .95083 m
.57687 .95142 L
s
1 .69 0 r
.008 w
.57687 .95142 Mdot
.016 w
.57687 .95142 m
.57354 .95195 L
s
1 .678 0 r
.008 w
.57354 .95195 Mdot
.016 w
.57354 .95195 m
.56985 .95243 L
s
1 .667 0 r
.008 w
.56985 .95243 Mdot
.016 w
.56985 .95243 m
.56649 .95288 L
s
1 .655 0 r
.008 w
.56649 .95288 Mdot
.016 w
.56649 .95288 m
.56294 .95329 L
s
1 .644 0 r
.008 w
.56294 .95329 Mdot
.016 w
.56294 .95329 m
.55963 .9537 L
s
1 .632 0 r
.008 w
.55963 .9537 Mdot
.016 w
.55963 .9537 m
.55612 .95411 L
s
1 .621 0 r
.008 w
.55612 .95411 Mdot
.016 w
.55612 .95411 m
.55259 .95453 L
s
1 .609 0 r
.008 w
.55259 .95453 Mdot
.016 w
.55259 .95453 m
.54933 .95493 L
s
1 .598 0 r
.008 w
.54933 .95493 Mdot
.016 w
.54933 .95493 m
.54591 .95537 L
s
1 .586 0 r
.008 w
.54591 .95537 Mdot
.016 w
.54591 .95537 m
.54237 .95585 L
s
1 .575 0 r
.008 w
.54237 .95585 Mdot
.016 w
.54237 .95585 m
.53924 .95638 L
s
1 .563 0 r
.008 w
.53924 .95638 Mdot
.016 w
.53924 .95638 m
.53628 .95691 L
s
1 .552 0 r
.008 w
.53628 .95691 Mdot
.016 w
.53628 .95691 m
.53285 .95742 L
s
1 .54 0 r
.008 w
.53285 .95742 Mdot
.016 w
.53285 .95742 m
.52997 .95789 L
s
1 .529 0 r
.008 w
.52997 .95789 Mdot
.016 w
.52997 .95789 m
.52701 .9583 L
s
1 .517 0 r
.008 w
.52701 .9583 Mdot
.016 w
.52701 .9583 m
.52395 .95863 L
s
1 .506 0 r
.008 w
.52395 .95863 Mdot
.016 w
.52395 .95863 m
.52092 .95889 L
s
1 .494 0 r
.008 w
.52092 .95889 Mdot
.016 w
.52092 .95889 m
.51827 .95901 L
s
1 .483 0 r
.008 w
.51827 .95901 Mdot
.016 w
.51827 .95901 m
.51563 .95898 L
s
1 .471 0 r
.008 w
.51563 .95898 Mdot
.016 w
.51563 .95898 m
.51316 .95877 L
s
1 .46 0 r
.008 w
.51316 .95877 Mdot
.016 w
.51316 .95877 m
.51078 .95844 L
s
1 .448 0 r
.008 w
.51078 .95844 Mdot
.016 w
.51078 .95844 m
.50865 .958 L
s
1 .437 0 r
.008 w
.50865 .958 Mdot
.016 w
.50865 .958 m
.5066 .95747 L
s
1 .425 0 r
.008 w
.5066 .95747 Mdot
.016 w
.5066 .95747 m
.50467 .95688 L
s
1 .414 0 r
.008 w
.50467 .95688 Mdot
.016 w
.50467 .95688 m
.5031 .95632 L
s
1 .402 0 r
.008 w
.5031 .95632 Mdot
.016 w
.5031 .95632 m
.50172 .95584 L
s
1 .391 0 r
.008 w
.50172 .95584 Mdot
.016 w
.50172 .95584 m
.50052 .95541 L
s
1 .379 0 r
.008 w
.50052 .95541 Mdot
.016 w
.50052 .95541 m
.49956 .95508 L
s
1 .368 0 r
.008 w
.49956 .95508 Mdot
.016 w
.49956 .95508 m
.49879 .95486 L
s
1 .356 0 r
.008 w
.49879 .95486 Mdot
.016 w
.49879 .95486 m
.49816 .95472 L
s
1 .345 0 r
.008 w
.49816 .95472 Mdot
.016 w
.49816 .95472 m
.49758 .95463 L
s
1 .333 0 r
.008 w
.49758 .95463 Mdot
.016 w
.49758 .95463 m
.49696 .95457 L
s
1 .322 0 r
.008 w
.49696 .95457 Mdot
.016 w
.49696 .95457 m
.49623 .95457 L
s
1 .31 0 r
.008 w
.49623 .95457 Mdot
.016 w
.49623 .95457 m
.49532 .95461 L
s
1 .299 0 r
.008 w
.49532 .95461 Mdot
.016 w
.49532 .95461 m
.4941 .95466 L
s
1 .287 0 r
.008 w
.4941 .95466 Mdot
.016 w
.4941 .95466 m
.49255 .95475 L
s
1 .276 0 r
.008 w
.49255 .95475 Mdot
.016 w
.49255 .95475 m
.49077 .95488 L
s
1 .264 0 r
.008 w
.49077 .95488 Mdot
.016 w
.49077 .95488 m
.48859 .95501 L
s
1 .253 0 r
.008 w
.48859 .95501 Mdot
.016 w
.48859 .95501 m
.48602 .95512 L
s
1 .241 0 r
.008 w
.48602 .95512 Mdot
.016 w
.48602 .95512 m
.48301 .9552 L
s
1 .23 0 r
.008 w
.48301 .9552 Mdot
.016 w
.48301 .9552 m
.47979 .95531 L
s
1 .218 0 r
.008 w
.47979 .95531 Mdot
.016 w
.47979 .95531 m
.47637 .95546 L
s
1 .207 0 r
.008 w
.47637 .95546 Mdot
.016 w
.47637 .95546 m
.47249 .95567 L
s
1 .195 0 r
.008 w
.47249 .95567 Mdot
.016 w
.47249 .95567 m
.46851 .95591 L
s
1 .184 0 r
.008 w
.46851 .95591 Mdot
.016 w
.46851 .95591 m
.46475 .95615 L
s
1 .172 0 r
.008 w
.46475 .95615 Mdot
.016 w
.46475 .95615 m
.46075 .95636 L
s
1 .161 0 r
.008 w
.46075 .95636 Mdot
.016 w
.46075 .95636 m
.45673 .95653 L
s
1 .149 0 r
.008 w
.45673 .95653 Mdot
.016 w
.45673 .95653 m
.45278 .9566 L
s
1 .138 0 r
.008 w
.45278 .9566 Mdot
.016 w
.45278 .9566 m
.44902 .95655 L
s
1 .126 0 r
.008 w
.44902 .95655 Mdot
.016 w
.44902 .95655 m
.4452 .9564 L
s
1 .115 0 r
.008 w
.4452 .9564 Mdot
.016 w
.4452 .9564 m
.44188 .95622 L
s
1 .103 0 r
.008 w
.44188 .95622 Mdot
.016 w
.44188 .95622 m
.43878 .95605 L
s
1 .092 0 r
.008 w
.43878 .95605 Mdot
.016 w
.43878 .95605 m
.43599 .9559 L
s
1 .08 0 r
.008 w
.43599 .9559 Mdot
.016 w
.43599 .9559 m
.43365 .95578 L
s
1 .069 0 r
.008 w
.43365 .95578 Mdot
.016 w
.43365 .95578 m
.43162 .95567 L
s
1 .057 0 r
.008 w
.43162 .95567 Mdot
.016 w
.43162 .95567 m
.42993 .95558 L
s
1 .046 0 r
.008 w
.42993 .95558 Mdot
.016 w
.42993 .95558 m
.42867 .95551 L
s
1 .034 0 r
.008 w
.42867 .95551 Mdot
.016 w
.42867 .95551 m
.42771 .95546 L
s
1 .023 0 r
.008 w
.42771 .95546 Mdot
.016 w
.42771 .95546 m
.42705 .95541 L
s
1 .011 0 r
.008 w
.42705 .95541 Mdot
.016 w
.42705 .95541 m
.42669 .95537 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool??NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooa0m
knUoo`03001oogoo00aoo`003Goo00<007ooOol027oo4Cg_j7oo00<007ooOol037oo000<Ool00`00
Oomoo`08OolC?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`DmknQoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo5cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`05OolH
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6
Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]o
o`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7
?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07
Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001o
ogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomo
o`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03
001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tm
kmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9o
o`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dm
ko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00
Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo
1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomo
o`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol0
0goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00
Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007oo
Ool00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool0
0`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<0
07ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo
00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<0
07ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogoo
Ool6?No:Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00HmklQooa0mk`Moo`03001oogoo
01Yoo`006goo00<007ooOol01Sg_b7oo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`05?No8
Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00DmklQoo`Hmk`=oo`Hmk`Moo`03001oogoo
01]oo`007Goo00<007oo?Nl013g_agoo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolm
k`05?No6Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00@mklIoo`Dmk`Eoo`Dm
k`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl01Cg_aGoo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo
000OOol7?No5Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Dmkl=oo`Dmk`Eo
o`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl01Cg_`Woo1Cg_17oo1Sg_1Goo00<007ooOol0
7goo000POol00`00?Nlmk`06?No0Ool5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`Tmkkmoo`Dm
k`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl01Sg__Woo1Cg_17oo1cg_0goo00<007oo
Ool08Goo000SOol8?NnmOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`Tmkk]oo`Dmk`Eoo`Hm
k`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo
000UOol:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Ao
o`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo
000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5o
o`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0
:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tm
kjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007oo
Ool0:Woo000/Ool00`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03
001oocg_00Pmkj]oo`Dmk`03Oolmkcg_00Hmk`03001oogoo02aoo`00;Woo00<007ooOol023g_ZWoo
3Cg_00<007ooOol0;Goo000^Ool01000Oomoogoo23g_ZGoo2Sg_0goo00<007ooOol0;Goo000_Ool0
1000Oomoogoo2Cg_YWoo2Sg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo23g_YWoo2Cg_0goo
00<007ooOol0;goo000aOol01000Oomoogoo23g_Y7oo23g_17oo00<007ooOol0<7oo000bOol20002
Ool8?NnQOol9?Nl3Ool2000cOol003Aoo`03001oogoo00Pmkiioo`Xmk`=oo`03001oogoo03=oo`00
=Goo00<007oo?Nl023g_W7oo2Sg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo23g_VGoo33g_
0goo00<007ooOol0=7oo000fOol01000Oomoogoo23g_Ugoo2Sg_1Goo00<007ooOol0=Goo000gOol0
0`00Oomoo`02Ool7?NnFOol8?Nl6Ool00`00Oomoo`0fOol003Qoo`03001oogoo009oo`LmkiAoo`Tm
k`Eoo`03001oogoo03Moo`00>Goo0P000goo23g_TGoo2Sg_0goo0P00>Woo000kOol00`00Oomoo`09
?Nn?Ool:?Nl3Ool00`00Oomoo`0jOol003aoo`03001oogoo00Tmkheoo`Xmk`=oo`03001oogoo03]o
o`00?Goo00<007ooOol02Sg_RGoo2Cg_1Goo00<007ooOol0?7oo000nOol20002Ool9?Nn7Ool9?Nl4
Ool2000oOol0041oo`03001oogoo00TmkhAoo`/mk`=oo`03001oogoo03moo`00@Goo0P0000=oocg_
?Nl01cg_PWoo2Cg_17oo0P00@Woo0013Ool00`00Oolmk`09?NmjOol>?Nl4Ool00`00Oomoo`12Ool0
04Aoo`03000mkcg_00PmkgYoo`dmk`Aoo`03001oogoo04=oo`00AGoo00<003g_?Nl02Sg_Mgoo2cg_
1Goo00<007ooOol0A7oo0016Ool00`00?Nlmk`0:?NmeOol<?Nl3Ool20017Ool004Qoo`hmk`9oo`8m
kfaoo`dmk`9oo`8004Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo001<Ool@?NmWOol;?Nl3Ool2001=
Ool004iooa4mkf=oo`/mk`=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03cg_H7oo33g_0Woo00<0
07ooOol0CWoo001@Ool20002Ool@?NmIOol00cg_Oomoo`0:?Nl3Ool2001AOol0059oo`800003Oolm
kcg_010mke9oo`03?Nmoogoo00hmk`03Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_1goo1Cg_
@7oo0WoP00=oocg_?Nl03Sg_00=oo`000000EGoo001FOol20004Ool@?Nl3Ool6?NlmOol2Of04Oj0?
?Nl2001GOol005Qoo`<000AooaHmkcYoo`9o@0EoH003Oh1oX3g_00dmk`03001oogoo05Moo`00Fgoo
0`000goo53g_=Woo0Wl000=oogm0Od0017m00WmP00=oP7nP?Nl02Cg_0P00G7oo001NOol20004OolB
?Nl_Ool2O/03Ool4O`03Ob03Od02Of000gn0Oj0mk`09?NmNOol0061oo`8000Aooa<mkbAoo`9nH09o
o`<mk`An`0Anh0=o009o80=o@09oH003Oh0mkcg_00Hmkf5oo`00HWoo0`0017oo53g_47oo0Sg_27oo
0WhP0goo17iP0gj00WjP17k00gkP0Wl00glP0gm023g_00<007ooOol0HGoo001UOol30005Ool<?Nl0
0g`PO01l0002O202O402O603O803O:03O<02O>02O@0017dPOF1mP7fP0Woo00<mkghPOR000ghP0gi0
0giP0Wj00WjP0gk017kP00=o07lPOb000WlP1Sg_0`00IWoo001XOol40003Ool:?Nl00g`PO01l0002
O202O402O603O803O:03O<02O>02O@0017dPOF1mP7fP0Wg00WgP0Wh00WhP0gi00WiP0gj00WjP0Wk0
1GkP00=o03g_?Nl013g_00@003g_000006Uoo`00K7oo10000goo1Sg_1G`P0Wa00WaP0gb00gbP0gc0
0WcP0Wd000Am87ePOH1mX09m`09mh09n009n80=n@003OV1nP7j0009nP09nX09n`0Lmk`03Ool00000
008006eoo`00L7oo0`000goo0cg_1G`P0Wa00WaP0gb00gbP0gc00WcP0Wd000Am87ePOH1mX09m`09m
h09n009n80=n@003OV0mkcg_00Dmk`Eoo`@0075oo`00Lgoo1@0000=oocg_?Nl053g_17fP0Wg00WgP
0Wh01cg_1goo1000MGoo001hOol4000M?Nl7Ool7001iOol007iooa0mk`Aoo`h0081oo`00SGoo1@00
SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool30004Ool2002=Ool008ao
o`05001oogooOol00002Ool00`00Oomoo`2:Ool008]oo`<000Aoo`03001oogoo08]oo`00RWoo00@0
07ooOol000Eoo`03001oogoo08Yoo`00RWoo00@007ooOol0009oo`04001oogoo002<Ool008]oo`<0
00=oo`8008eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(94)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
1 .996 0 r
.008 w
.42637 .94992 Mdot
.016 w
.42637 .94992 m
.42609 .9499 L
s
1 .991 0 r
.008 w
.42609 .9499 Mdot
.016 w
.42609 .9499 m
.4255 .94991 L
s
1 .987 0 r
.008 w
.4255 .94991 Mdot
.016 w
.4255 .94991 m
.42454 .94995 L
s
1 .983 0 r
.008 w
.42454 .94995 Mdot
.016 w
.42454 .94995 m
.42311 .94999 L
s
1 .978 0 r
.008 w
.42311 .94999 Mdot
.016 w
.42311 .94999 m
.42117 .94996 L
s
1 .974 0 r
.008 w
.42117 .94996 Mdot
.016 w
.42117 .94996 m
.41872 .94985 L
s
1 .97 0 r
.008 w
.41872 .94985 Mdot
.016 w
.41872 .94985 m
.41626 .94964 L
s
1 .965 0 r
.008 w
.41626 .94964 Mdot
.016 w
.41626 .94964 m
.41339 .94931 L
s
1 .961 0 r
.008 w
.41339 .94931 Mdot
.016 w
.41339 .94931 m
.40982 .94886 L
s
1 .957 0 r
.008 w
.40982 .94886 Mdot
.016 w
.40982 .94886 m
.40636 .94828 L
s
1 .952 0 r
.008 w
.40636 .94828 Mdot
.016 w
.40636 .94828 m
.40186 .94756 L
s
1 .948 0 r
.008 w
.40186 .94756 Mdot
.016 w
.40186 .94756 m
.39824 .9467 L
s
1 .944 0 r
.008 w
.39824 .9467 Mdot
.016 w
.39824 .9467 m
.39366 .94579 L
s
1 .939 0 r
.008 w
.39366 .94579 Mdot
.016 w
.39366 .94579 m
.38961 .94468 L
s
1 .935 0 r
.008 w
.38961 .94468 Mdot
.016 w
.38961 .94468 m
.3854 .94352 L
s
1 .931 0 r
.008 w
.3854 .94352 Mdot
.016 w
.3854 .94352 m
.3807 .94223 L
s
1 .926 0 r
.008 w
.3807 .94223 Mdot
.016 w
.3807 .94223 m
.37702 .94083 L
s
1 .922 0 r
.008 w
.37702 .94083 Mdot
.016 w
.37702 .94083 m
.37275 .93938 L
s
1 .918 0 r
.008 w
.37275 .93938 Mdot
.016 w
.37275 .93938 m
.36889 .93787 L
s
1 .913 0 r
.008 w
.36889 .93787 Mdot
.016 w
.36889 .93787 m
.36494 .93636 L
s
1 .909 0 r
.008 w
.36494 .93636 Mdot
.016 w
.36494 .93636 m
.36108 .93484 L
s
1 .905 0 r
.008 w
.36108 .93484 Mdot
.016 w
.36108 .93484 m
.35687 .93338 L
s
1 .9 0 r
.008 w
.35687 .93338 Mdot
.016 w
.35687 .93338 m
.3533 .93197 L
s
1 .896 0 r
.008 w
.3533 .93197 Mdot
.016 w
.3533 .93197 m
.34922 .93062 L
s
1 .892 0 r
.008 w
.34922 .93062 Mdot
.016 w
.34922 .93062 m
.34546 .9293 L
s
1 .887 0 r
.008 w
.34546 .9293 Mdot
.016 w
.34546 .9293 m
.34156 .928 L
s
1 .883 0 r
.008 w
.34156 .928 Mdot
.016 w
.34156 .928 m
.33767 .92674 L
s
1 .879 0 r
.008 w
.33767 .92674 Mdot
.016 w
.33767 .92674 m
.33398 .92546 L
s
1 .874 0 r
.008 w
.33398 .92546 Mdot
.016 w
.33398 .92546 m
.32993 .92419 L
s
1 .87 0 r
.008 w
.32993 .92419 Mdot
.016 w
.32993 .92419 m
.32652 .92294 L
s
1 .866 0 r
.008 w
.32652 .92294 Mdot
.016 w
.32652 .92294 m
.32284 .92166 L
s
1 .861 0 r
.008 w
.32284 .92166 Mdot
.016 w
.32284 .92166 m
.3193 .9204 L
s
1 .857 0 r
.008 w
.3193 .9204 Mdot
.016 w
.3193 .9204 m
.31589 .91914 L
s
1 .853 0 r
.008 w
.31589 .91914 Mdot
.016 w
.31589 .91914 m
.31248 .91793 L
s
1 .848 0 r
.008 w
.31248 .91793 Mdot
.016 w
.31248 .91793 m
.30933 .91682 L
s
1 .844 0 r
.008 w
.30933 .91682 Mdot
.016 w
.30933 .91682 m
.30612 .91573 L
s
1 .84 0 r
.008 w
.30612 .91573 Mdot
.016 w
.30612 .91573 m
.30327 .91469 L
s
1 .835 0 r
.008 w
.30327 .91469 Mdot
.016 w
.30327 .91469 m
.30082 .91375 L
s
1 .831 0 r
.008 w
.30082 .91375 Mdot
.016 w
.30082 .91375 m
.29859 .91289 L
s
1 .827 0 r
.008 w
.29859 .91289 Mdot
.016 w
.29859 .91289 m
.29663 .91213 L
s
1 .823 0 r
.008 w
.29663 .91213 Mdot
.016 w
.29663 .91213 m
.29514 .91153 L
s
1 .818 0 r
.008 w
.29514 .91153 Mdot
.016 w
.29514 .91153 m
.29388 .91112 L
s
1 .814 0 r
.008 w
.29388 .91112 Mdot
.016 w
.29388 .91112 m
.29294 .91091 L
s
1 .81 0 r
.008 w
.29294 .91091 Mdot
.016 w
.29294 .91091 m
.29226 .91084 L
s
1 .805 0 r
.008 w
.29226 .91084 Mdot
.016 w
.29226 .91084 m
.29175 .91086 L
s
1 .801 0 r
.008 w
.29175 .91086 Mdot
.016 w
.29175 .91086 m
.29133 .91091 L
s
1 .797 0 r
.008 w
.29133 .91091 Mdot
.016 w
.29133 .91091 m
.29091 .9109 L
s
1 .792 0 r
.008 w
.29091 .9109 Mdot
.016 w
.29091 .9109 m
.29039 .91075 L
s
1 .788 0 r
.008 w
.29039 .91075 Mdot
.016 w
.29039 .91075 m
.28968 .9104 L
s
1 .784 0 r
.008 w
.28968 .9104 Mdot
.016 w
.28968 .9104 m
.28863 .90984 L
s
1 .779 0 r
.008 w
.28863 .90984 Mdot
.016 w
.28863 .90984 m
.28744 .90912 L
s
1 .775 0 r
.008 w
.28744 .90912 Mdot
.016 w
.28744 .90912 m
.28583 .90821 L
s
1 .771 0 r
.008 w
.28583 .90821 Mdot
.016 w
.28583 .90821 m
.2838 .90713 L
s
1 .766 0 r
.008 w
.2838 .90713 Mdot
.016 w
.2838 .90713 m
.28152 .90602 L
s
1 .762 0 r
.008 w
.28152 .90602 Mdot
.016 w
.28152 .90602 m
.27893 .90464 L
s
1 .758 0 r
.008 w
.27893 .90464 Mdot
.016 w
.27893 .90464 m
.27613 .90323 L
s
1 .753 0 r
.008 w
.27613 .90323 Mdot
.016 w
.27613 .90323 m
.27302 .90169 L
s
1 .749 0 r
.008 w
.27302 .90169 Mdot
.016 w
.27302 .90169 m
.27004 .90007 L
s
1 .745 0 r
.008 w
.27004 .90007 Mdot
.016 w
.27004 .90007 m
.2671 .89837 L
s
1 .74 0 r
.008 w
.2671 .89837 Mdot
.016 w
.2671 .89837 m
.26427 .89683 L
s
1 .736 0 r
.008 w
.26427 .89683 Mdot
.016 w
.26427 .89683 m
.26145 .8953 L
s
1 .732 0 r
.008 w
.26145 .8953 Mdot
.016 w
.26145 .8953 m
.25882 .89381 L
s
1 .727 0 r
.008 w
.25882 .89381 Mdot
.016 w
.25882 .89381 m
.25628 .89242 L
s
1 .723 0 r
.008 w
.25628 .89242 Mdot
.016 w
.25628 .89242 m
.25393 .89103 L
s
1 .719 0 r
.008 w
.25393 .89103 Mdot
.016 w
.25393 .89103 m
.25159 .88955 L
s
1 .714 0 r
.008 w
.25159 .88955 Mdot
.016 w
.25159 .88955 m
.24934 .88797 L
s
1 .71 0 r
.008 w
.24934 .88797 Mdot
.016 w
.24934 .88797 m
.24717 .88625 L
s
1 .706 0 r
.008 w
.24717 .88625 Mdot
.016 w
.24717 .88625 m
.24494 .88436 L
s
1 .701 0 r
.008 w
.24494 .88436 Mdot
.016 w
.24494 .88436 m
.24264 .88229 L
s
1 .697 0 r
.008 w
.24264 .88229 Mdot
.016 w
.24264 .88229 m
.24046 .88014 L
s
1 .693 0 r
.008 w
.24046 .88014 Mdot
.016 w
.24046 .88014 m
.23819 .87777 L
s
1 .688 0 r
.008 w
.23819 .87777 Mdot
.016 w
.23819 .87777 m
.2359 .87534 L
s
1 .684 0 r
.008 w
.2359 .87534 Mdot
.016 w
.2359 .87534 m
.23365 .87272 L
s
1 .68 0 r
.008 w
.23365 .87272 Mdot
.016 w
.23365 .87272 m
.23147 .86991 L
s
1 .675 0 r
.008 w
.23147 .86991 Mdot
.016 w
.23147 .86991 m
.22933 .86709 L
s
1 .671 0 r
.008 w
.22933 .86709 Mdot
.016 w
.22933 .86709 m
.22727 .86402 L
s
1 .667 0 r
.008 w
.22727 .86402 Mdot
.016 w
.22727 .86402 m
.22549 .86115 L
s
1 .662 0 r
.008 w
.22549 .86115 Mdot
.016 w
.22549 .86115 m
.22387 .85807 L
s
1 .658 0 r
.008 w
.22387 .85807 Mdot
.016 w
.22387 .85807 m
.22245 .85532 L
s
1 .654 0 r
.008 w
.22245 .85532 Mdot
.016 w
.22245 .85532 m
.22125 .85266 L
s
1 .649 0 r
.008 w
.22125 .85266 Mdot
.016 w
.22125 .85266 m
.22022 .85023 L
s
1 .645 0 r
.008 w
.22022 .85023 Mdot
.016 w
.22022 .85023 m
.21932 .84802 L
s
1 .641 0 r
.008 w
.21932 .84802 Mdot
.016 w
.21932 .84802 m
.21846 .84604 L
s
1 .636 0 r
.008 w
.21846 .84604 Mdot
.016 w
.21846 .84604 m
.21754 .84413 L
s
1 .632 0 r
.008 w
.21754 .84413 Mdot
.016 w
.21754 .84413 m
.21648 .8426 L
s
1 .628 0 r
.008 w
.21648 .8426 Mdot
.016 w
.21648 .8426 m
.21524 .84121 L
s
1 .623 0 r
.008 w
.21524 .84121 Mdot
.016 w
.21524 .84121 m
.21376 .83995 L
s
1 .619 0 r
.008 w
.21376 .83995 Mdot
.016 w
.21376 .83995 m
.21197 .83881 L
s
1 .615 0 r
.008 w
.21197 .83881 Mdot
.016 w
.21197 .83881 m
.20982 .83779 L
s
1 .61 0 r
.008 w
.20982 .83779 Mdot
.016 w
.20982 .83779 m
.20771 .83682 L
s
1 .606 0 r
.008 w
.20771 .83682 Mdot
.016 w
.20771 .83682 m
.20516 .83588 L
s
1 .602 0 r
.008 w
.20516 .83588 Mdot
.016 w
.20516 .83588 m
.2022 .83478 L
s
1 .597 0 r
.008 w
.2022 .83478 Mdot
.016 w
.2022 .83478 m
.19934 .8335 L
s
1 .593 0 r
.008 w
.19934 .8335 Mdot
.016 w
.19934 .8335 m
.19607 .83197 L
s
1 .589 0 r
.008 w
.19607 .83197 Mdot
.016 w
.19607 .83197 m
.19243 .83016 L
s
1 .584 0 r
.008 w
.19243 .83016 Mdot
.016 w
.19243 .83016 m
.18904 .82812 L
s
1 .58 0 r
.008 w
.18904 .82812 Mdot
.016 w
.18904 .82812 m
.18529 .82565 L
s
1 .576 0 r
.008 w
.18529 .82565 Mdot
.016 w
.18529 .82565 m
.18168 .82301 L
s
1 .571 0 r
.008 w
.18168 .82301 Mdot
.016 w
.18168 .82301 m
.17798 .8202 L
s
1 .567 0 r
.008 w
.17798 .8202 Mdot
.016 w
.17798 .8202 m
.17454 .81747 L
s
1 .563 0 r
.008 w
.17454 .81747 Mdot
.016 w
.17454 .81747 m
.17096 .81439 L
s
1 .558 0 r
.008 w
.17096 .81439 Mdot
.016 w
.17096 .81439 m
.16774 .81143 L
s
1 .554 0 r
.008 w
.16774 .81143 Mdot
.016 w
.16774 .81143 m
.16441 .80823 L
s
1 .55 0 r
.008 w
.16441 .80823 Mdot
.016 w
.16441 .80823 m
.16132 .80527 L
s
1 .545 0 r
.008 w
.16132 .80527 Mdot
.016 w
.16132 .80527 m
.1583 .8022 L
s
1 .541 0 r
.008 w
.1583 .8022 Mdot
.016 w
.1583 .8022 m
.15546 .79924 L
s
1 .537 0 r
.008 w
.15546 .79924 Mdot
.016 w
.15546 .79924 m
.15279 .79629 L
s
1 .532 0 r
.008 w
.15279 .79629 Mdot
.016 w
.15279 .79629 m
.15032 .79363 L
s
1 .528 0 r
.008 w
.15032 .79363 Mdot
.016 w
.15032 .79363 m
.14807 .79093 L
s
1 .524 0 r
.008 w
.14807 .79093 Mdot
.016 w
.14807 .79093 m
.14603 .78825 L
s
1 .519 0 r
.008 w
.14603 .78825 Mdot
.016 w
.14603 .78825 m
.14424 .78571 L
s
1 .515 0 r
.008 w
.14424 .78571 Mdot
.016 w
.14424 .78571 m
.14262 .78303 L
s
1 .511 0 r
.008 w
.14262 .78303 Mdot
.016 w
.14262 .78303 m
.14119 .78057 L
s
1 .506 0 r
.008 w
.14119 .78057 Mdot
.016 w
.14119 .78057 m
.13988 .77801 L
s
1 .502 0 r
.008 w
.13988 .77801 Mdot
.016 w
.13988 .77801 m
.13863 .77548 L
s
1 .498 0 r
.008 w
.13863 .77548 Mdot
.016 w
.13863 .77548 m
.13736 .77293 L
s
1 .494 0 r
.008 w
.13736 .77293 Mdot
.016 w
.13736 .77293 m
.13607 .77037 L
s
1 .489 0 r
.008 w
.13607 .77037 Mdot
.016 w
.13607 .77037 m
.13479 .76764 L
s
1 .485 0 r
.008 w
.13479 .76764 Mdot
.016 w
.13479 .76764 m
.13347 .76515 L
s
1 .481 0 r
.008 w
.13347 .76515 Mdot
.016 w
.13347 .76515 m
.13219 .76248 L
s
1 .476 0 r
.008 w
.13219 .76248 Mdot
.016 w
.13219 .76248 m
.13089 .75974 L
s
1 .472 0 r
.008 w
.13089 .75974 Mdot
.016 w
.13089 .75974 m
.1297 .75717 L
s
1 .468 0 r
.008 w
.1297 .75717 Mdot
.016 w
.1297 .75717 m
.12855 .75454 L
s
1 .463 0 r
.008 w
.12855 .75454 Mdot
.016 w
.12855 .75454 m
.12748 .75212 L
s
1 .459 0 r
.008 w
.12748 .75212 Mdot
.016 w
.12748 .75212 m
.12646 .74988 L
s
1 .455 0 r
.008 w
.12646 .74988 Mdot
.016 w
.12646 .74988 m
.12559 .74761 L
s
1 .45 0 r
.008 w
.12559 .74761 Mdot
.016 w
.12559 .74761 m
.12527 .74554 L
s
1 .446 0 r
.008 w
.12527 .74554 Mdot
.016 w
.12527 .74554 m
.1245 .74347 L
s
1 .442 0 r
.008 w
.1245 .74347 Mdot
.016 w
.1245 .74347 m
.12383 .74168 L
s
1 .437 0 r
.008 w
.12383 .74168 Mdot
.016 w
.12383 .74168 m
.12334 .74001 L
s
1 .433 0 r
.008 w
.12334 .74001 Mdot
.016 w
.12334 .74001 m
.12306 .73853 L
s
1 .429 0 r
.008 w
.12306 .73853 Mdot
.016 w
.12306 .73853 m
.12295 .73729 L
s
1 .424 0 r
.008 w
.12295 .73729 Mdot
.016 w
.12295 .73729 m
.12295 .73628 L
s
1 .42 0 r
.008 w
.12295 .73628 Mdot
.016 w
.12295 .73628 m
.12301 .73547 L
s
1 .416 0 r
.008 w
.12301 .73547 Mdot
.016 w
.12301 .73547 m
.12307 .73483 L
s
1 .411 0 r
.008 w
.12307 .73483 Mdot
.016 w
.12307 .73483 m
.12306 .73426 L
s
1 .407 0 r
.008 w
.12306 .73426 Mdot
.016 w
.12306 .73426 m
.12294 .7337 L
s
1 .403 0 r
.008 w
.12294 .7337 Mdot
.016 w
.12294 .7337 m
.12265 .73305 L
s
1 .398 0 r
.008 w
.12265 .73305 Mdot
.016 w
.12265 .73305 m
.12212 .73226 L
s
1 .394 0 r
.008 w
.12212 .73226 Mdot
.016 w
.12212 .73226 m
.12132 .73128 L
s
1 .39 0 r
.008 w
.12132 .73128 Mdot
.016 w
.12132 .73128 m
.12029 .73007 L
s
1 .385 0 r
.008 w
.12029 .73007 Mdot
.016 w
.12029 .73007 m
.11905 .72865 L
s
1 .381 0 r
.008 w
.11905 .72865 Mdot
.016 w
.11905 .72865 m
.11784 .72718 L
s
1 .377 0 r
.008 w
.11784 .72718 Mdot
.016 w
.11784 .72718 m
.11626 .72547 L
s
1 .372 0 r
.008 w
.11626 .72547 Mdot
.016 w
.11626 .72547 m
.11442 .72358 L
s
1 .368 0 r
.008 w
.11442 .72358 Mdot
.016 w
.11442 .72358 m
.11241 .72157 L
s
1 .364 0 r
.008 w
.11241 .72157 Mdot
.016 w
.11241 .72157 m
.11024 .71925 L
s
1 .359 0 r
.008 w
.11024 .71925 Mdot
.016 w
.11024 .71925 m
.10805 .71697 L
s
1 .355 0 r
.008 w
.10805 .71697 Mdot
.016 w
.10805 .71697 m
.10569 .7145 L
s
1 .351 0 r
.008 w
.10569 .7145 Mdot
.016 w
.10569 .7145 m
.10347 .71187 L
s
1 .346 0 r
.008 w
.10347 .71187 Mdot
.016 w
.10347 .71187 m
.10145 .70934 L
s
1 .342 0 r
.008 w
.10145 .70934 Mdot
.016 w
.10145 .70934 m
.09945 .70656 L
s
1 .338 0 r
.008 w
.09945 .70656 Mdot
.016 w
.09945 .70656 m
.09771 .70376 L
s
1 .333 0 r
.008 w
.09771 .70376 Mdot
.016 w
.09771 .70376 m
.09615 .70076 L
s
1 .329 0 r
.008 w
.09615 .70076 Mdot
.016 w
.09615 .70076 m
.09476 .69754 L
s
1 .325 0 r
.008 w
.09476 .69754 Mdot
.016 w
.09476 .69754 m
.09358 .69394 L
s
1 .32 0 r
.008 w
.09358 .69394 Mdot
.016 w
.09358 .69394 m
.09253 .69021 L
s
1 .316 0 r
.008 w
.09253 .69021 Mdot
.016 w
.09253 .69021 m
.09163 .68613 L
s
1 .312 0 r
.008 w
.09163 .68613 Mdot
.016 w
.09163 .68613 m
.09081 .68169 L
s
1 .307 0 r
.008 w
.09081 .68169 Mdot
.016 w
.09081 .68169 m
.09005 .67723 L
s
1 .303 0 r
.008 w
.09005 .67723 Mdot
.016 w
.09005 .67723 m
.08934 .67231 L
s
1 .299 0 r
.008 w
.08934 .67231 Mdot
.016 w
.08934 .67231 m
.08866 .66763 L
s
1 .294 0 r
.008 w
.08866 .66763 Mdot
.016 w
.08866 .66763 m
.08799 .66347 L
s
1 .29 0 r
.008 w
.08799 .66347 Mdot
.016 w
.08799 .66347 m
.08732 .65878 L
s
1 .286 0 r
.008 w
.08732 .65878 Mdot
.016 w
.08732 .65878 m
.08668 .65401 L
s
1 .281 0 r
.008 w
.08668 .65401 Mdot
.016 w
.08668 .65401 m
.08598 .6497 L
s
1 .277 0 r
.008 w
.08598 .6497 Mdot
.016 w
.08598 .6497 m
.08523 .64523 L
s
1 .273 0 r
.008 w
.08523 .64523 Mdot
.016 w
.08523 .64523 m
.08446 .64086 L
s
1 .268 0 r
.008 w
.08446 .64086 Mdot
.016 w
.08446 .64086 m
.08363 .63673 L
s
1 .264 0 r
.008 w
.08363 .63673 Mdot
.016 w
.08363 .63673 m
.08282 .63241 L
s
1 .26 0 r
.008 w
.08282 .63241 Mdot
.016 w
.08282 .63241 m
.08201 .6283 L
s
1 .255 0 r
.008 w
.08201 .6283 Mdot
.016 w
.08201 .6283 m
.08123 .6242 L
s
1 .251 0 r
.008 w
.08123 .6242 Mdot
.016 w
.08123 .6242 m
.08054 .62003 L
s
1 .247 0 r
.008 w
.08054 .62003 Mdot
.016 w
.08054 .62003 m
.07993 .61586 L
s
1 .242 0 r
.008 w
.07993 .61586 Mdot
.016 w
.07993 .61586 m
.07941 .61181 L
s
1 .238 0 r
.008 w
.07941 .61181 Mdot
.016 w
.07941 .61181 m
.07898 .60772 L
s
1 .234 0 r
.008 w
.07898 .60772 Mdot
.016 w
.07898 .60772 m
.07864 .60367 L
s
1 .229 0 r
.008 w
.07864 .60367 Mdot
.016 w
.07864 .60367 m
.07838 .59988 L
s
1 .225 0 r
.008 w
.07838 .59988 Mdot
.016 w
.07838 .59988 m
.07817 .59608 L
s
1 .221 0 r
.008 w
.07817 .59608 Mdot
.016 w
.07817 .59608 m
.07799 .59239 L
s
1 .216 0 r
.008 w
.07799 .59239 Mdot
.016 w
.07799 .59239 m
.0778 .58908 L
s
1 .212 0 r
.008 w
.0778 .58908 Mdot
.016 w
.0778 .58908 m
.07759 .58555 L
s
1 .208 0 r
.008 w
.07759 .58555 Mdot
.016 w
.07759 .58555 m
.07735 .58234 L
s
1 .203 0 r
.008 w
.07735 .58234 Mdot
.016 w
.07735 .58234 m
.07705 .57894 L
s
1 .199 0 r
.008 w
.07705 .57894 Mdot
.016 w
.07705 .57894 m
.07666 .57558 L
s
1 .195 0 r
.008 w
.07666 .57558 Mdot
.016 w
.07666 .57558 m
.07617 .57202 L
s
1 .19 0 r
.008 w
.07617 .57202 Mdot
.016 w
.07617 .57202 m
.07559 .56822 L
s
1 .186 0 r
.008 w
.07559 .56822 Mdot
.016 w
.07559 .56822 m
.07493 .56475 L
s
1 .182 0 r
.008 w
.07493 .56475 Mdot
.016 w
.07493 .56475 m
.07422 .56066 L
s
1 .177 0 r
.008 w
.07422 .56066 Mdot
.016 w
.07422 .56066 m
.07351 .55655 L
s
1 .173 0 r
.008 w
.07351 .55655 Mdot
.016 w
.07351 .55655 m
.07281 .55266 L
s
1 .169 0 r
.008 w
.07281 .55266 Mdot
.016 w
.07281 .55266 m
.07213 .54884 L
s
1 .165 0 r
.008 w
.07213 .54884 Mdot
.016 w
.07213 .54884 m
.07152 .54486 L
s
1 .16 0 r
.008 w
.07152 .54486 Mdot
.016 w
.07152 .54486 m
.07101 .54033 L
s
1 .156 0 r
.008 w
.07101 .54033 Mdot
.016 w
.07101 .54033 m
.07062 .53625 L
s
1 .152 0 r
.008 w
.07062 .53625 Mdot
.016 w
.07062 .53625 m
.07037 .53193 L
s
1 .147 0 r
.008 w
.07037 .53193 Mdot
.016 w
.07037 .53193 m
.07025 .52756 L
s
1 .143 0 r
.008 w
.07025 .52756 Mdot
.016 w
.07025 .52756 m
.07029 .52318 L
s
1 .139 0 r
.008 w
.07029 .52318 Mdot
.016 w
.07029 .52318 m
.07048 .51877 L
s
1 .134 0 r
.008 w
.07048 .51877 Mdot
.016 w
.07048 .51877 m
.07081 .5143 L
s
1 .13 0 r
.008 w
.07081 .5143 Mdot
.016 w
.07081 .5143 m
.07126 .51006 L
s
1 .126 0 r
.008 w
.07126 .51006 Mdot
.016 w
.07126 .51006 m
.07179 .50599 L
s
1 .121 0 r
.008 w
.07179 .50599 Mdot
.016 w
.07179 .50599 m
.07238 .50172 L
s
1 .117 0 r
.008 w
.07238 .50172 Mdot
.016 w
.07238 .50172 m
.073 .49805 L
s
1 .113 0 r
.008 w
.073 .49805 Mdot
.016 w
.073 .49805 m
.07363 .49446 L
s
1 .108 0 r
.008 w
.07363 .49446 Mdot
.016 w
.07363 .49446 m
.07426 .4912 L
s
1 .104 0 r
.008 w
.07426 .4912 Mdot
.016 w
.07426 .4912 m
.07485 .48854 L
s
1 .1 0 r
.008 w
.07485 .48854 Mdot
.016 w
.07485 .48854 m
.07538 .48632 L
s
1 .095 0 r
.008 w
.07538 .48632 Mdot
.016 w
.07538 .48632 m
.07584 .4846 L
s
1 .091 0 r
.008 w
.07584 .4846 Mdot
.016 w
.07584 .4846 m
.07621 .48331 L
s
1 .087 0 r
.008 w
.07621 .48331 Mdot
.016 w
.07621 .48331 m
.07649 .48233 L
s
1 .082 0 r
.008 w
.07649 .48233 Mdot
.016 w
.07649 .48233 m
.07667 .48164 L
s
1 .078 0 r
.008 w
.07667 .48164 Mdot
.016 w
.07667 .48164 m
.07678 .48116 L
s
1 .074 0 r
.008 w
.07678 .48116 Mdot
.016 w
.07678 .48116 m
.07686 .48076 L
s
1 .069 0 r
.008 w
.07686 .48076 Mdot
.016 w
.07686 .48076 m
.07695 .48035 L
s
1 .065 0 r
.008 w
.07695 .48035 Mdot
.016 w
.07695 .48035 m
.07708 .47985 L
s
1 .061 0 r
.008 w
.07708 .47985 Mdot
.016 w
.07708 .47985 m
.07727 .47923 L
s
1 .056 0 r
.008 w
.07727 .47923 Mdot
.016 w
.07727 .47923 m
.07753 .47851 L
s
1 .052 0 r
.008 w
.07753 .47851 Mdot
.016 w
.07753 .47851 m
.07787 .47765 L
s
1 .048 0 r
.008 w
.07787 .47765 Mdot
.016 w
.07787 .47765 m
.07829 .47678 L
s
1 .043 0 r
.008 w
.07829 .47678 Mdot
.016 w
.07829 .47678 m
.07878 .47574 L
s
1 .039 0 r
.008 w
.07878 .47574 Mdot
.016 w
.07878 .47574 m
.07933 .47465 L
s
1 .035 0 r
.008 w
.07933 .47465 Mdot
.016 w
.07933 .47465 m
.07988 .47351 L
s
1 .03 0 r
.008 w
.07988 .47351 Mdot
.016 w
.07988 .47351 m
.08048 .47242 L
s
1 .026 0 r
.008 w
.08048 .47242 Mdot
.016 w
.08048 .47242 m
.08103 .47149 L
s
1 .022 0 r
.008 w
.08103 .47149 Mdot
.016 w
.08103 .47149 m
.08156 .47068 L
s
1 .017 0 r
.008 w
.08156 .47068 Mdot
.016 w
.08156 .47068 m
.08204 .47003 L
s
1 .013 0 r
.008 w
.08204 .47003 Mdot
.016 w
.08204 .47003 m
.08244 .46955 L
s
1 .009 0 r
.008 w
.08244 .46955 Mdot
.016 w
.08244 .46955 m
.08274 .46924 L
s
1 .004 0 r
.008 w
.08274 .46924 Mdot
.016 w
.08274 .46924 m
.08294 .46909 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`hmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3Cg_igoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<Ool8?Nl00goo?Nlmk`03?NoWOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00]oo`Lmk`=oo`DmknMoo`03001oogoo00aoo`003Goo00<007ooOol02Goo3Cg_jgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool2?Nl4O009?NoZOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Qoo`8mk`Al00XmknUoo`03001oogoo00aoo`003Goo00<007ooOol027oo00<mkg`PO0000g`02cg_
j7oo00<007ooOol037oo000<Ool00`00Oomoo`08Ool2?Nl00g`PO01l0002O00<?NoXOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Moo`<mk`03O21l07`0009l00<mk`Aoo`DmknQoo`03001oogoo00]o
o`0037oo00<007ooOol01Woo0cg_00=lH7`PO0000g`03Sg_iWoo00<007ooOol02goo000<Ool00`00
Oomoo`05Ool4?Nl00gaPO21l8002O20??NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03
?NmlH7a000=l@0lmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo00<mkgaPO4000ga000=o
ocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_O61lH002O6000cg_Oomo
o`04Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`IlH0Yoo`HmknEoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1GaP00<mkgooOol027oo1Sg_iGoo00<007ooOol02goo000<Ool0
0`00Oomoo`07Ool00cg_O81lH003O6000cg_Oomoo`09Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Moo`05?NmlP7b0O61lP00<Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Mo
o`03?NmlP7b0009lP0aoo`Tmkn9oo`03001oogoo00]oo`0037oo00<007ooOol01goo00<mkgb0O800
0Wb037oo2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool00cg_O81lP002O80<Ool:?NoQ
Ool00`00Oomoo`0;Ool000eoo`03001oogoo00Ioo`03?NmlP7b0009lP0aoo`/mkn1oo`03001oogoo
00]oo`003Goo00<007ooOol01Woo00<mkgb0O8000Wb047oo1cg_ggoo00<007ooOol037oo000=Ool0
0`00Oomoo`06Ool00cg_O81lP002O80@Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Io
o`03?NmlP7b0009lP11oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol01Woo00<mkgb0O800
0Wb000<mkgooOol03Goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool00cg_O81lP002
O8000gbPOomoo`0>Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`AlP09lX0moo`Pm
kmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo1GbP47oo23g_gGoo00<007ooOol037oo000=
Ool00`00Oomoo`07Ool00cg_O:1lX002O:0@Ool9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Moo`03?NmlX7bP009lX11oo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol01goo00<mkgbP
O:000WbP4Goo2Sg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool00cg_O:1lX002O:0BOol9
?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo00Ioo`03?NmlX7bP009lX003O<1oogoo011oo`Pm
kmUoo`03001oogoo00eoo`003Woo00<007ooOol01goo17bP0Wc04Goo1Cg_g7oo00<007ooOol03Goo
000>Ool00`00Oomoo`07Ool4O:000gc0Oomoo`3aOol00`00Oomoo`0=Ool000ioo`03001oogoo00Mo
o`03?Nml`7c0009l`003?Nmoogoo0?1oo`03001oogoo00eoo`003goo00<007ooOol01Woo00<mkgc0
O<000Wc000<mkgooOol0l7oo00<007ooOol03Goo000?Ool00`00Oomoo`07Ool4O<02?No`Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Moo`Al`08mko1oo`03001oogoo00ioo`003goo00<007ooOol0
1goo17c00Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4O<02?No`Ool00`00Oomoo`0>
Ool0011oo`03001oogoo00Ioo`Alh08mko1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo1GcP
00<mkgooOol0kGoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool6O>3_Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Ioo`Elh003?Nmoogoo0>eoo`03001oogoo00moo`0047oo00<007ooOol01Woo
00<mkgcPO>000WcP00<mkgooOol0kGoo00<007ooOol03goo000AOol00`00Oomoo`05Ool00cg_O>1l
h002O>000cg_Oomoo`3]Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Ioo`Alh08mkneoo`03001o
ogoo011oo`004Goo00<007ooOol01Woo17cP00<mkgooOol0k7oo00<007ooOol047oo000BOol00`00
Oomoo`05Ool5O@3^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Im0>aoo`03001oogoo015o
o`004Woo00<007ooOol01Goo1Gd0kGoo00<007ooOol04Goo000COol00`00Oomoo`05Ool4O@3]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`Am0003?Nmoogoo0>Uoo`03001oogoo019oo`004goo
00<007ooOol01Goo1Gd0jgoo00<007ooOol04Woo000DOol00`00Oomoo`04Ool6O@3IOol00cg_Oomo
o`0>Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`Em0003?Nmoogoo0=Moo`8mk`ioo`03001o
ogoo01=oo`0057oo00<007ooOol017oo00HmkgdPO@1m07dP?NoIOol3?Nl=Ool00`00Oomoo`0COol0
01Eoo`03001oogoo00=oo`03?Nmm87dP009m8003?Nmoogoo0=Moo`@mk`aoo`03001oogoo01=oo`00
5Goo00<007ooOol00goo00<mkgdPOB000WdP00<mkgooOol0d7oo33g_2Woo00<007ooOol057oo000E
Ool00`00Oomoo`03Ool00cg_OB1m8002OB000cg_Oomoo`3AOol;?Nl:Ool00`00Oomoo`0DOol001Eo
o`03001oogoo00Aoo`Am8003?Nmoogoo0=9oo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007ooOol0
0goo1GdPeGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5OB3EOol9?Nl9Ool00`00
Oomoo`0EOol001Moo`03001oogoo009oo`03?Nmm87dP00=m8=Aoo`Pmk`Uoo`03001oogoo01Ioo`00
5goo00<007ooOol00Woo00<mkgdPOB000WdP00<mkgooOol0dWoo23g_2Goo00<007ooOol05Woo000H
Ool01@00Oomoogoo?Nl017dP00=m@7ooOol0dWoo23g_27oo00<007ooOol05goo000HOol01@00Oomo
ogoo?Nl01We0dWoo2Cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1We0d7oo2cg_27oo00<0
07ooOol05goo000IOol01@00Oomoogoo?Nl01We0cWoo2cg_27oo00<007ooOol067oo000JOol01000
Oomoocg_1ge0c7oo33g_27oo00<007ooOol067oo000JOol01000Oomoogoo0Sg_17e000=mH7ooOol0
agoo3Sg_27oo00<007ooOol06Goo000KOol00`00Oomoo`02?Nl00gePOD1m@003OF36Ool@?Nl7Ool0
0`00Oomoo`0JOol001]oo`03001oogoo008mk`MmH<Eooa0mk`Moo`03001oogoo01Yoo`0077oo00<0
07oo?Nl00cg_1WePa7oo43g_1Woo00<007ooOol06goo000LOol00`00Oomoo`04?Nl6OF33Ool6?Nl3
Ool6?Nl7Ool00`00Oomoo`0KOol001eoo`03001oocg_00@mk`AmH003OH1mX7oo0<1oo`Dmk`Eoo`Hm
k`Ioo`03001oogoo01aoo`007Goo00<007oo?Nl013g_00=mP7ePOF000Wf000=mX7ooOol0_goo1Cg_
1Goo1Sg_1Woo00<007ooOol077oo000NOol00`00?Nlmk`03?Nl5OH000gfPOomoo`2oOol5?Nl5Ool5
?Nl6Ool00`00Oomoo`0MOol001ioo`03000mkcg_00@mk`AmP003OJ1oogoo0;moo`Dmk`Eoo`Dmk`Io
o`03001oogoo01eoo`007goo1Sg_1GfP`Goo13g_1Goo1Sg_1Goo00<007ooOol07Woo000OOol00`00
?Nlmk`04?Nl4OJ000gg0Oomoo`2mOol5?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol0021oo`03000mkcg_
00<mk`Im`;ioo`Dmk`Aoo`Hmk`Eoo`03001oogoo01moo`0087oo00<003g_?Nl00cg_1Gg000=mh7oo
Ool0^goo1Cg_1Goo1Sg_1Goo00<007ooOol07goo000QOol6?Nl4OL02ON2lOol5?Nl5Ool6?Nl4Ool0
0`00Oomoo`0POol0029oo`03000mkcg_008mk`Am`09mh;aoo`Dmk`Aoo`Lmk`=oo`03001oogoo025o
o`008goo1Cg_1GgP^goo1Sg_17oo1Sg_0goo00<007ooOol08Woo000TOol4?Nl6ON2jOol5?Nl5Ool6
?Nl2Ool00`00Oomoo`0SOol002Aoo`04000mkcg_?Nl6ON2jOol4?Nl5Ool7?Nl2Ool00`00Oomoo`0S
Ool002Eoo`@mk`Emh003OP1oogoo0;Ioo`Dmk`Eoo`Dmk`=oo`03001oogoo02Aoo`009Woo00<003g_
?Nl01GgP00=n03g_Ool0]Goo1Sg_17oo1cg_00=oo`00Ool09Woo000VOol01000Oolmkcg_1Wh013g_
/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo000WOol00`00Oolmk`07OP03?NnbOol5?Nl3Ool8?Nl0
0goo001oo`0WOol002Qoo`03001oocg_00In0003OR0mkcg_0;5oo`Hmk`9oo`Pmk`03Ool007oo02Qo
o`00:Goo00<007oo?Nl01Gh00WhP0Sg_/7oo1Cg_0Woo23g_00=oo`00Ool0:Goo000ZOol00`00Oomn
0004OP03OR000cg_Oomoo`2^Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`04001oogoo?Nl7OR00
0cg_Oomoo`2/Ool5?Nl2Ool9?Nl00`00Oomoo`0YOol002]oo`03001oogoo00Qn8003?Nmoogoo0:]o
o`Dmk`9oo`Pmk`03001oogoo02Yoo`00;7oo00@007oo?Nlmk`Mn8:aoo`Dmk`03Oolmkcg_00Lmk`03
001oogoo02]oo`00;Goo00<007oo?Nl027hP00=n@7ooOol0Z7oo1Cg_00=oocg_?Nl01Sg_00<007oo
Ool0;7oo000^Ool00`00Oomoo`02?Nl4OR03OT2YOol=?Nl00`00Oomoo`0]Ool002ioo`04001oogoo
Ool2?Nl2OR06OT2WOol:?Nl3Ool00`00Oomoo`0]Ool002moo`04001oogooOol2?Nl8OT2UOol:?Nl3
Ool00`00Oomoo`0^Ool0031oo`05001oogooOolmk`09OT2TOol9?Nl3Ool00`00Oomoo`0_Ool0035o
o`04001oogooOol3?Nl7OT02OV2POol8?Nl4Ool00`00Oomoo`0`Ool0039oo`80009oo`8mk`In@0En
H9aoo`Tmk`=oo`8003=oo`00=7oo00<007ooOol013g_0Wi01WiPVWoo2Sg_0goo00<007ooOol0<goo
000eOol00`00Oolmk`03?Nl8OV000gj0Oomoo`2FOol:?Nl3Ool00`00Oomoo`0dOol003Eoo`04001o
ogooOol4?Nl6OV02OX2EOol<?Nl3Ool00`00Oomoo`0dOol003Ioo`04001oogooOol5?Nl6OX2DOol:
?Nl5Ool00`00Oomoo`0eOol003Moo`03001oogoo009oo`@mk`EnP9Aoo`Pmk`Ioo`03001oogoo03Io
o`00>7oo00<007ooOol00Woo0cg_1Gj000=nX7ooOol0T7oo2Cg_1Goo00<007ooOol0=goo000iOol2
0003Ool2?Nl5OX02OZ2@Ool:?Nl3Ool2000jOol003]oo`03001oogoo00<mk`InX8moo`Xmk`=oo`03
001oogoo03Yoo`00?7oo00<007ooOol00cg_1WjPSGoo2Sg_0goo00<007ooOol0>goo000mOol00`00
Oomoo`02?Nl7OZ000cg_Oomoo`27Ool9?Nl5Ool00`00Oomoo`0lOol003ioo`80009oo`8mk`AnX09n
`003?Nmoogoo08Eoo`Tmk`Aoo`8003moo`00@7oo00@007ooOolmk`AnX0=n`003?Nmoogoo089oo`/m
k`=oo`03001oogoo03moo`00@Goo0P0000=oogjPOZ000WjP17k000<mkgooOol0P7oo2Cg_17oo0P00
@Woo0013Ool00`00Oomn`007O/02?NmjOol>?Nl4Ool00`00Oomoo`12Ool004Aoo`03000mkgk000Mn
`09nh7Uoo`dmk`Aoo`03001oogoo04=oo`00AGoo00@003g_?Nlmk`An`0Anh003?Nmoogoo07Eoo`/m
k`Eoo`03001oogoo04Aoo`00AWoo00@003g_?Nlmk`9n`0Mnh003O`1oogoo079oo``mk`=oo`8004Mo
o`00B7oo0Sg_2GkP0Wl000<mkgooOol00Sg_K7oo3Cg_0Woo0P00BGoo001:Ool2?Nl7O^04O`0013g_
Od0mkcg_JWoo33g_0Woo0P00Bgoo001<Ool2?Nl5O^04O`001GlPOd1o@3g_Of00Igoo2cg_0goo0P00
CGoo001>Ool2?Nl7O`000glPOd1o@002Od02Of000cg_Oomoo`1QOol;?Nl3Ool00`00Oomoo`1=Ool0
04moo`03000mkcg_00Eo0003Ob1o@7m0009o@0=oH003?NmoH7oo05moo``mk`9oo`03001oogoo04io
o`00D7oo0P0000=ooglPOb000glP17m01WmP0Wn0FGoo00<mkgooOol02Sg_0goo0P00DGoo001BOol2
00000goo?Nlmk`05Od07Of05Oh1AOol00cg_Oomoo`0>?Nl00goo0000001COol005Aoo`800004?Nmo
ocg_?Nl:Of05Oh000gnPOomoo`04Ool5?Nm0OolC?Nl00goo0000001EOol005Ioo`8000Aoo`MoH0Qo
P004?NmoX7ooOol6?NlnOolD?Nl2001GOol005Qoo`<000Aoo`03Oh1oH7mP00UoP0AoX0HmkcaooaDm
k`03001oogoo05Moo`00Fgoo0`000goo0Sg_27n01gnP00<mkgo0?Nl0>Goo53g_0P00G7oo001NOol2
0004Ool2?Nl5Oh08Oj02Ol000cg_Oomoo`0bOolH?NmNOol0061oo`8000Aoo`8mk`]oX0Mo`0=oh2Ao
oahmkf5oo`00HWoo0`0017oo0Sg_27nP1go00goP47oo0Sg_3Goo83g_00<007ooOol0HGoo001UOol3
0005Ool00cg_Oj1oX003Oj07Ol03On0F?Nl2OolR?Nl3001VOol006Qoo`@000=oo`<mk`Qo`0=oh3Hm
k`04000mk`00001YOol006aoo`@000=ooc/mk`03Ool00000008006eoo`00L7oo0`000goo<3g_1Goo
1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L007Uoo`00OWoo
43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
08Yoo`<000Eoo`<008]oo`00S7oo00<007ooOol017oo00<007ooOol0RWoo002;Ool30002Ool5002;
Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002:Ool01000Oomoo`000goo00<007oo0000
S7oo002;Ool30004Ool2002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(95)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
1 .994 0 r
.008 w
.08243 .46962 Mdot
.016 w
.08243 .46962 m
.08244 .46945 L
s
1 .989 0 r
.008 w
.08244 .46945 Mdot
.016 w
.08244 .46945 m
.08253 .4692 L
s
1 .983 0 r
.008 w
.08253 .4692 Mdot
.016 w
.08253 .4692 m
.08274 .46889 L
s
1 .977 0 r
.008 w
.08274 .46889 Mdot
.016 w
.08274 .46889 m
.08308 .46851 L
s
1 .972 0 r
.008 w
.08308 .46851 Mdot
.016 w
.08308 .46851 m
.08354 .46806 L
s
1 .966 0 r
.008 w
.08354 .46806 Mdot
.016 w
.08354 .46806 m
.08412 .46755 L
s
1 .96 0 r
.008 w
.08412 .46755 Mdot
.016 w
.08412 .46755 m
.0848 .46701 L
s
1 .955 0 r
.008 w
.0848 .46701 Mdot
.016 w
.0848 .46701 m
.08551 .46642 L
s
1 .949 0 r
.008 w
.08551 .46642 Mdot
.016 w
.08551 .46642 m
.0863 .46581 L
s
1 .944 0 r
.008 w
.0863 .46581 Mdot
.016 w
.0863 .46581 m
.08711 .46519 L
s
1 .938 0 r
.008 w
.08711 .46519 Mdot
.016 w
.08711 .46519 m
.0879 .4646 L
s
1 .932 0 r
.008 w
.0879 .4646 Mdot
.016 w
.0879 .4646 m
.08866 .46405 L
s
1 .927 0 r
.008 w
.08866 .46405 Mdot
.016 w
.08866 .46405 m
.08931 .46359 L
s
1 .921 0 r
.008 w
.08931 .46359 Mdot
.016 w
.08931 .46359 m
.08986 .46322 L
s
1 .915 0 r
.008 w
.08986 .46322 Mdot
.016 w
.08986 .46322 m
.09029 .46292 L
s
1 .91 0 r
.008 w
.09029 .46292 Mdot
.016 w
.09029 .46292 m
.0906 .46272 L
s
1 .904 0 r
.008 w
.0906 .46272 Mdot
.016 w
.0906 .46272 m
.09079 .46259 L
s
1 .898 0 r
.008 w
.09079 .46259 Mdot
.016 w
.09079 .46259 m
.09088 .46253 L
s
1 .893 0 r
.008 w
.09088 .46253 Mdot
.016 w
.09088 .46253 m
.09091 .46251 L
s
1 .887 0 r
.008 w
.09091 .46251 Mdot
.016 w
.09091 .46251 m
.09093 .46251 L
s
1 .881 0 r
.008 w
.09093 .46251 Mdot
.016 w
.09093 .46251 m
.09098 .4625 L
s
1 .876 0 r
.008 w
.09098 .4625 Mdot
.016 w
.09098 .4625 m
.09112 .46246 L
s
1 .87 0 r
.008 w
.09112 .46246 Mdot
.016 w
.09112 .46246 m
.09139 .46238 L
s
1 .864 0 r
.008 w
.09139 .46238 Mdot
.016 w
.09139 .46238 m
.09184 .46223 L
s
1 .859 0 r
.008 w
.09184 .46223 Mdot
.016 w
.09184 .46223 m
.09247 .462 L
s
1 .853 0 r
.008 w
.09247 .462 Mdot
.016 w
.09247 .462 m
.09332 .46168 L
s
1 .847 0 r
.008 w
.09332 .46168 Mdot
.016 w
.09332 .46168 m
.09441 .46129 L
s
1 .842 0 r
.008 w
.09441 .46129 Mdot
.016 w
.09441 .46129 m
.09567 .46088 L
s
1 .836 0 r
.008 w
.09567 .46088 Mdot
.016 w
.09567 .46088 m
.09715 .46046 L
s
1 .831 0 r
.008 w
.09715 .46046 Mdot
.016 w
.09715 .46046 m
.09871 .46003 L
s
1 .825 0 r
.008 w
.09871 .46003 Mdot
.016 w
.09871 .46003 m
.10046 .45955 L
s
1 .819 0 r
.008 w
.10046 .45955 Mdot
.016 w
.10046 .45955 m
.1022 .45903 L
s
1 .814 0 r
.008 w
.1022 .45903 Mdot
.016 w
.1022 .45903 m
.10427 .45847 L
s
1 .808 0 r
.008 w
.10427 .45847 Mdot
.016 w
.10427 .45847 m
.10605 .4579 L
s
1 .802 0 r
.008 w
.10605 .4579 Mdot
.016 w
.10605 .4579 m
.10788 .45733 L
s
1 .797 0 r
.008 w
.10788 .45733 Mdot
.016 w
.10788 .45733 m
.10985 .45679 L
s
1 .791 0 r
.008 w
.10985 .45679 Mdot
.016 w
.10985 .45679 m
.11173 .45629 L
s
1 .785 0 r
.008 w
.11173 .45629 Mdot
.016 w
.11173 .45629 m
.11365 .45583 L
s
1 .78 0 r
.008 w
.11365 .45583 Mdot
.016 w
.11365 .45583 m
.11548 .45541 L
s
1 .774 0 r
.008 w
.11548 .45541 Mdot
.016 w
.11548 .45541 m
.11696 .45503 L
s
1 .768 0 r
.008 w
.11696 .45503 Mdot
.016 w
.11696 .45503 m
.11847 .45466 L
s
1 .763 0 r
.008 w
.11847 .45466 Mdot
.016 w
.11847 .45466 m
.11984 .4543 L
s
1 .757 0 r
.008 w
.11984 .4543 Mdot
.016 w
.11984 .4543 m
.12115 .45394 L
s
1 .751 0 r
.008 w
.12115 .45394 Mdot
.016 w
.12115 .45394 m
.12236 .45358 L
s
1 .746 0 r
.008 w
.12236 .45358 Mdot
.016 w
.12236 .45358 m
.1236 .45332 L
s
1 .74 0 r
.008 w
.1236 .45332 Mdot
.016 w
.1236 .45332 m
.12481 .4531 L
s
1 .734 0 r
.008 w
.12481 .4531 Mdot
.016 w
.12481 .4531 m
.12606 .45293 L
s
1 .729 0 r
.008 w
.12606 .45293 Mdot
.016 w
.12606 .45293 m
.12729 .4528 L
s
1 .723 0 r
.008 w
.12729 .4528 Mdot
.016 w
.12729 .4528 m
.12853 .45268 L
s
1 .718 0 r
.008 w
.12853 .45268 Mdot
.016 w
.12853 .45268 m
.12976 .45256 L
s
1 .712 0 r
.008 w
.12976 .45256 Mdot
.016 w
.12976 .45256 m
.13091 .45241 L
s
1 .706 0 r
.008 w
.13091 .45241 Mdot
.016 w
.13091 .45241 m
.13207 .45221 L
s
1 .701 0 r
.008 w
.13207 .45221 Mdot
.016 w
.13207 .45221 m
.13322 .45197 L
s
1 .695 0 r
.008 w
.13322 .45197 Mdot
.016 w
.13322 .45197 m
.13434 .45168 L
s
1 .689 0 r
.008 w
.13434 .45168 Mdot
.016 w
.13434 .45168 m
.13541 .45136 L
s
1 .684 0 r
.008 w
.13541 .45136 Mdot
.016 w
.13541 .45136 m
.13633 .45102 L
s
1 .678 0 r
.008 w
.13633 .45102 Mdot
.016 w
.13633 .45102 m
.13715 .4507 L
s
1 .672 0 r
.008 w
.13715 .4507 Mdot
.016 w
.13715 .4507 m
.1378 .45044 L
s
1 .667 0 r
.008 w
.1378 .45044 Mdot
.016 w
.1378 .45044 m
.13824 .45027 L
s
1 .661 0 r
.008 w
.13824 .45027 Mdot
.016 w
.13824 .45027 m
.13843 .45022 L
s
1 .655 0 r
.008 w
.13843 .45022 Mdot
.016 w
.13843 .45022 m
.13835 .45032 L
s
1 .65 0 r
.008 w
.13835 .45032 Mdot
.016 w
.13835 .45032 m
.13803 .45057 L
s
1 .644 0 r
.008 w
.13803 .45057 Mdot
.016 w
.13803 .45057 m
.13751 .45098 L
s
1 .638 0 r
.008 w
.13751 .45098 Mdot
.016 w
.13751 .45098 m
.13689 .45154 L
s
1 .633 0 r
.008 w
.13689 .45154 Mdot
.016 w
.13689 .45154 m
.13625 .45222 L
s
1 .627 0 r
.008 w
.13625 .45222 Mdot
.016 w
.13625 .45222 m
.13566 .45298 L
s
1 .621 0 r
.008 w
.13566 .45298 Mdot
.016 w
.13566 .45298 m
.13517 .45381 L
s
1 .616 0 r
.008 w
.13517 .45381 Mdot
.016 w
.13517 .45381 m
.13479 .45468 L
s
1 .61 0 r
.008 w
.13479 .45468 Mdot
.016 w
.13479 .45468 m
.13454 .45563 L
s
1 .605 0 r
.008 w
.13454 .45563 Mdot
.016 w
.13454 .45563 m
.13442 .45667 L
s
1 .599 0 r
.008 w
.13442 .45667 Mdot
.016 w
.13442 .45667 m
.13446 .45781 L
s
1 .593 0 r
.008 w
.13446 .45781 Mdot
.016 w
.13446 .45781 m
.13467 .45902 L
s
1 .588 0 r
.008 w
.13467 .45902 Mdot
.016 w
.13467 .45902 m
.13504 .46025 L
s
1 .582 0 r
.008 w
.13504 .46025 Mdot
.016 w
.13504 .46025 m
.13566 .46153 L
s
1 .576 0 r
.008 w
.13566 .46153 Mdot
.016 w
.13566 .46153 m
.13641 .46287 L
s
1 .571 0 r
.008 w
.13641 .46287 Mdot
.016 w
.13641 .46287 m
.13731 .46425 L
s
1 .565 0 r
.008 w
.13731 .46425 Mdot
.016 w
.13731 .46425 m
.13833 .46559 L
s
1 .559 0 r
.008 w
.13833 .46559 Mdot
.016 w
.13833 .46559 m
.13936 .46697 L
s
1 .554 0 r
.008 w
.13936 .46697 Mdot
.016 w
.13936 .46697 m
.14033 .46832 L
s
1 .548 0 r
.008 w
.14033 .46832 Mdot
.016 w
.14033 .46832 m
.14118 .46966 L
s
1 .542 0 r
.008 w
.14118 .46966 Mdot
.016 w
.14118 .46966 m
.1419 .47091 L
s
1 .537 0 r
.008 w
.1419 .47091 Mdot
.016 w
.1419 .47091 m
.14252 .47199 L
s
1 .531 0 r
.008 w
.14252 .47199 Mdot
.016 w
.14252 .47199 m
.14306 .47297 L
s
1 .525 0 r
.008 w
.14306 .47297 Mdot
.016 w
.14306 .47297 m
.14352 .47386 L
s
1 .52 0 r
.008 w
.14352 .47386 Mdot
.016 w
.14352 .47386 m
.14394 .47464 L
s
1 .514 0 r
.008 w
.14394 .47464 Mdot
.016 w
.14394 .47464 m
.14436 .47534 L
s
1 .508 0 r
.008 w
.14436 .47534 Mdot
.016 w
.14436 .47534 m
.1448 .47597 L
s
1 .503 0 r
.008 w
.1448 .47597 Mdot
.016 w
.1448 .47597 m
.14528 .47652 L
s
1 .497 0 r
.008 w
.14528 .47652 Mdot
.016 w
.14528 .47652 m
.14584 .47701 L
s
1 .492 0 r
.008 w
.14584 .47701 Mdot
.016 w
.14584 .47701 m
.14654 .47746 L
s
1 .486 0 r
.008 w
.14654 .47746 Mdot
.016 w
.14654 .47746 m
.14741 .47789 L
s
1 .48 0 r
.008 w
.14741 .47789 Mdot
.016 w
.14741 .47789 m
.14843 .47827 L
s
1 .475 0 r
.008 w
.14843 .47827 Mdot
.016 w
.14843 .47827 m
.14965 .47864 L
s
1 .469 0 r
.008 w
.14965 .47864 Mdot
.016 w
.14965 .47864 m
.15105 .47901 L
s
1 .463 0 r
.008 w
.15105 .47901 Mdot
.016 w
.15105 .47901 m
.15266 .47936 L
s
1 .458 0 r
.008 w
.15266 .47936 Mdot
.016 w
.15266 .47936 m
.1543 .47967 L
s
1 .452 0 r
.008 w
.1543 .47967 Mdot
.016 w
.1543 .47967 m
.15607 .47991 L
s
1 .446 0 r
.008 w
.15607 .47991 Mdot
.016 w
.15607 .47991 m
.15791 .48008 L
s
1 .441 0 r
.008 w
.15791 .48008 Mdot
.016 w
.15791 .48008 m
.15974 .48016 L
s
1 .435 0 r
.008 w
.15974 .48016 Mdot
.016 w
.15974 .48016 m
.16148 .48017 L
s
1 .429 0 r
.008 w
.16148 .48017 Mdot
.016 w
.16148 .48017 m
.163 .48012 L
s
1 .424 0 r
.008 w
.163 .48012 Mdot
.016 w
.163 .48012 m
.16434 .48003 L
s
1 .418 0 r
.008 w
.16434 .48003 Mdot
.016 w
.16434 .48003 m
.16538 .47994 L
s
1 .412 0 r
.008 w
.16538 .47994 Mdot
.016 w
.16538 .47994 m
.16613 .4799 L
s
1 .407 0 r
.008 w
.16613 .4799 Mdot
.016 w
.16613 .4799 m
.16659 .47992 L
s
1 .401 0 r
.008 w
.16659 .47992 Mdot
.016 w
.16659 .47992 m
.16678 .47998 L
s
1 .395 0 r
.008 w
.16678 .47998 Mdot
.016 w
.16678 .47998 m
.16675 .48005 L
s
1 .39 0 r
.008 w
.16675 .48005 Mdot
.016 w
.16675 .48005 m
.16652 .48009 L
s
1 .384 0 r
.008 w
.16652 .48009 Mdot
.016 w
.16652 .48009 m
.16617 .48009 L
s
1 .379 0 r
.008 w
.16617 .48009 Mdot
.016 w
.16617 .48009 m
.16574 .48001 L
s
1 .373 0 r
.008 w
.16574 .48001 Mdot
.016 w
.16574 .48001 m
.16529 .47987 L
s
1 .367 0 r
.008 w
.16529 .47987 Mdot
.016 w
.16529 .47987 m
.16479 .47964 L
s
1 .362 0 r
.008 w
.16479 .47964 Mdot
.016 w
.16479 .47964 m
.16429 .47932 L
s
1 .356 0 r
.008 w
.16429 .47932 Mdot
.016 w
.16429 .47932 m
.16383 .4789 L
s
1 .35 0 r
.008 w
.16383 .4789 Mdot
.016 w
.16383 .4789 m
.16344 .47839 L
s
1 .345 0 r
.008 w
.16344 .47839 Mdot
.016 w
.16344 .47839 m
.16319 .47781 L
s
1 .339 0 r
.008 w
.16319 .47781 Mdot
.016 w
.16319 .47781 m
.16311 .47718 L
s
1 .333 0 r
.008 w
.16311 .47718 Mdot
.016 w
.16311 .47718 m
.16323 .47652 L
s
1 .328 0 r
.008 w
.16323 .47652 Mdot
.016 w
.16323 .47652 m
.16349 .47584 L
s
1 .322 0 r
.008 w
.16349 .47584 Mdot
.016 w
.16349 .47584 m
.16382 .47517 L
s
1 .316 0 r
.008 w
.16382 .47517 Mdot
.016 w
.16382 .47517 m
.16418 .47457 L
s
1 .311 0 r
.008 w
.16418 .47457 Mdot
.016 w
.16418 .47457 m
.1645 .4741 L
s
1 .305 0 r
.008 w
.1645 .4741 Mdot
.016 w
.1645 .4741 m
.16477 .4738 L
s
1 .299 0 r
.008 w
.16477 .4738 Mdot
.016 w
.16477 .4738 m
.16496 .47369 L
s
1 .294 0 r
.008 w
.16496 .47369 Mdot
.016 w
.16496 .47369 m
.16507 .47373 L
s
1 .288 0 r
.008 w
.16507 .47373 Mdot
.016 w
.16507 .47373 m
.16506 .47386 L
s
1 .282 0 r
.008 w
.16506 .47386 Mdot
.016 w
.16506 .47386 m
.16492 .47405 L
s
1 .277 0 r
.008 w
.16492 .47405 Mdot
.016 w
.16492 .47405 m
.16458 .47424 L
s
1 .271 0 r
.008 w
.16458 .47424 Mdot
.016 w
.16458 .47424 m
.16395 .47437 L
s
1 .266 0 r
.008 w
.16395 .47437 Mdot
.016 w
.16395 .47437 m
.16318 .47438 L
s
1 .26 0 r
.008 w
.16318 .47438 Mdot
.016 w
.16318 .47438 m
.16219 .47424 L
s
1 .254 0 r
.008 w
.16219 .47424 Mdot
.016 w
.16219 .47424 m
.1609 .47395 L
s
1 .249 0 r
.008 w
.1609 .47395 Mdot
.016 w
.1609 .47395 m
.15918 .4735 L
s
1 .243 0 r
.008 w
.15918 .4735 Mdot
.016 w
.15918 .4735 m
.15705 .47285 L
s
1 .237 0 r
.008 w
.15705 .47285 Mdot
.016 w
.15705 .47285 m
.15526 .47211 L
s
1 .232 0 r
.008 w
.15526 .47211 Mdot
.016 w
.15526 .47211 m
.15267 .4711 L
s
1 .226 0 r
.008 w
.15267 .4711 Mdot
.016 w
.15267 .4711 m
.15036 .47007 L
s
1 .22 0 r
.008 w
.15036 .47007 Mdot
.016 w
.15036 .47007 m
.14715 .46892 L
s
1 .215 0 r
.008 w
.14715 .46892 Mdot
.016 w
.14715 .46892 m
.14451 .46769 L
s
1 .209 0 r
.008 w
.14451 .46769 Mdot
.016 w
.14451 .46769 m
.14106 .46648 L
s
1 .203 0 r
.008 w
.14106 .46648 Mdot
.016 w
.14106 .46648 m
.13855 .46543 L
s
1 .198 0 r
.008 w
.13855 .46543 Mdot
.016 w
.13855 .46543 m
.13476 .46449 L
s
1 .192 0 r
.008 w
.13476 .46449 Mdot
.016 w
.13476 .46449 m
.13185 .46369 L
s
1 .186 0 r
.008 w
.13185 .46369 Mdot
.016 w
.13185 .46369 m
.12811 .46305 L
s
1 .181 0 r
.008 w
.12811 .46305 Mdot
.016 w
.12811 .46305 m
.12552 .46254 L
s
1 .175 0 r
.008 w
.12552 .46254 Mdot
.016 w
.12552 .46254 m
.12177 .46213 L
s
1 .169 0 r
.008 w
.12177 .46213 Mdot
.016 w
.12177 .46213 m
.11897 .46182 L
s
1 .164 0 r
.008 w
.11897 .46182 Mdot
.016 w
.11897 .46182 m
.11542 .46162 L
s
1 .158 0 r
.008 w
.11542 .46162 Mdot
.016 w
.11542 .46162 m
.11289 .46152 L
s
1 .153 0 r
.008 w
.11289 .46152 Mdot
.016 w
.11289 .46152 m
.10957 .46155 L
s
1 .147 0 r
.008 w
.10957 .46155 Mdot
.016 w
.10957 .46155 m
.10635 .46174 L
s
1 .141 0 r
.008 w
.10635 .46174 Mdot
.016 w
.10635 .46174 m
.10373 .46211 L
s
1 .136 0 r
.008 w
.10373 .46211 Mdot
.016 w
.10373 .46211 m
.10007 .46264 L
s
1 .13 0 r
.008 w
.10007 .46264 Mdot
.016 w
.10007 .46264 m
.0975 .46333 L
s
1 .124 0 r
.008 w
.0975 .46333 Mdot
.016 w
.0975 .46333 m
.09443 .46419 L
s
1 .119 0 r
.008 w
.09443 .46419 Mdot
.016 w
.09443 .46419 m
.09109 .46521 L
s
1 .113 0 r
.008 w
.09109 .46521 Mdot
.016 w
.09109 .46521 m
.08847 .46616 L
s
1 .107 0 r
.008 w
.08847 .46616 Mdot
.016 w
.08847 .46616 m
.0859 .46723 L
s
1 .102 0 r
.008 w
.0859 .46723 Mdot
.016 w
.0859 .46723 m
.08392 .46824 L
s
1 .096 0 r
.008 w
.08392 .46824 Mdot
.016 w
.08392 .46824 m
.08154 .46935 L
s
1 .09 0 r
.008 w
.08154 .46935 Mdot
.016 w
.08154 .46935 m
.0794 .47066 L
s
1 .085 0 r
.008 w
.0794 .47066 Mdot
.016 w
.0794 .47066 m
.07788 .47178 L
s
1 .079 0 r
.008 w
.07788 .47178 Mdot
.016 w
.07788 .47178 m
.07663 .47288 L
s
1 .073 0 r
.008 w
.07663 .47288 Mdot
.016 w
.07663 .47288 m
.07558 .47395 L
s
1 .068 0 r
.008 w
.07558 .47395 Mdot
.016 w
.07558 .47395 m
.07477 .47498 L
s
1 .062 0 r
.008 w
.07477 .47498 Mdot
.016 w
.07477 .47498 m
.07418 .47595 L
s
1 .056 0 r
.008 w
.07418 .47595 Mdot
.016 w
.07418 .47595 m
.07377 .47683 L
s
1 .051 0 r
.008 w
.07377 .47683 Mdot
.016 w
.07377 .47683 m
.07348 .47761 L
s
1 .045 0 r
.008 w
.07348 .47761 Mdot
.016 w
.07348 .47761 m
.07328 .47827 L
s
1 .04 0 r
.008 w
.07328 .47827 Mdot
.016 w
.07328 .47827 m
.0731 .47885 L
s
1 .034 0 r
.008 w
.0731 .47885 Mdot
.016 w
.0731 .47885 m
.07297 .4794 L
s
1 .028 0 r
.008 w
.07297 .4794 Mdot
.016 w
.07297 .4794 m
.07292 .48001 L
s
1 .023 0 r
.008 w
.07292 .48001 Mdot
.016 w
.07292 .48001 m
.0729 .48046 L
s
1 .017 0 r
.008 w
.0729 .48046 Mdot
.016 w
.0729 .48046 m
.07285 .48091 L
s
1 .011 0 r
.008 w
.07285 .48091 Mdot
.016 w
.07285 .48091 m
.07283 .48124 L
s
1 .006 0 r
.008 w
.07283 .48124 Mdot
.016 w
.07283 .48124 m
.07287 .48144 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`Pmk`9o008mk`EnP>=oo`03001oogoo00aoo`003Goo00<007ooOol03Goo1cg_00=o
07kPO^000Wk017iP00=nP7ooOol0hGoo00<007ooOol037oo000=Ool00`00Oomoo`0<Ool4?Nl00glP
O81lP002O`02O^000gk0O:1n@003OT000gj0Oomoo`3QOol00`00Oomoo`0<Ool000eoo`03001oogoo
00]oo`8mk`9lH003Od1lP7b000ElP0=lX0=n@003OX1oogoo0>5oo`03001oogoo00aoo`003Goo00<0
07ooOol02Goo0Sg_00=o`7aPO60017aP1Gb01GbP0Wc000=lh7ooOol0h7oo00<007ooOol037oo000=
Ool00`00Oomoo`08Ool2?Nl4O404O605O805O:04O<3QOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Qoo`03?Nml@7a000=l@0AlH0ElP0ElX0Al`0=lh003OB1oogoo0=]oo`03001oogoo00aoo`003Goo
00<007ooOol027oo17`P0Wa017aP00=lP3g_?Nl00Sg_1GbP17c017cP00=m07ooOol0fWoo00<007oo
Ool037oo000<Ool00`00Oomoo`08Ool00cg_O01l0002O002O4000gaP?Nlmk`09?Nl6O<04O>000gd0
OH1oo`3KOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`8mk`Al009l@0<mk`Aoo`Dmk`03Oomn
07gP00Mlh003O@1mP7oo0=]oo`03001oogoo00]oo`0037oo00<007ooOol01Woo0cg_17`03cg_00An
07gPOL1m`0Elh003O@1mP7oo0=]oo`03001oogoo00]oo`0037oo00<007ooOol01Goo13g_17`043g_
00Emh7g0OL1m`7fP00Am@003OH1oogoo0=Yoo`03001oogoo00]oo`0037oo00<007ooOol027oo00<m
kg`0O0000W`043g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl00goo?Nlmk`0<?NoV
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Ioo`TmknIoo`03001oogoo00]oo`0037oo
00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:Ool6
?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Lmk`]oo`HmknAoo`03001oogoo00]oo`00
37oo00<007ooOol01goo1Cg_37oo1cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5?Nl<
Ool9?NoROol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001oogoo00]o
o`0037oo00<007ooOol01goo1Cg_37oo2Sg_hGoo00<007ooOol02goo000=Ool00`00Oomoo`06Ool5
?Nl<Ool;?NoPOol00`00Oomoo`0;Ool000eoo`03001oogoo00Ioo`Dmka1oo`Lmkmmoo`03001oogoo
00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06
Ool5?Nl@Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmk`moo`Pmkmioo`03001o
ogoo00aoo`003Goo00<007ooOol01Woo1Sg_47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2Cg_g7oo00<007ooOol037oo000=Ool00`00
Oomoo`07Ool5?Nl@Ool;?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka5oo`XmkmYo
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_4Woo2Cg_fWoo00<007ooOol037oo000>Ool0
0`00Oomoo`06Ool6?NlBOol8?NoIOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmka9oo`Dm
kmaoo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_lgoo00<007ooOol03Goo000>Ool00`00
Oomoo`07Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Ioo`Hmko9oo`03001oogoo00eo
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`003goo00<007ooOol0
1goo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No`Ool00`00Oomoo`0>Ool0011o
o`03001oogoo00Ioo`Hmknmoo`03001oogoo00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Hm
knmoo`03001oogoo00moo`004Goo00<007ooOol01Goo1Sg_kgoo00<007ooOol03goo000AOol00`00
Oomoo`06Ool6?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Ioo`Dmknioo`03001oogoo011o
o`004Woo00<007ooOol01Goo1Cg_kWoo00<007ooOol047oo000BOol00`00Oomoo`05Ool5?No]Ool0
0`00Oomoo`0AOol0019oo`03001oogoo00Eoo`Dmkneoo`03001oogoo015oo`004goo00<007ooOol0
1Goo13g_kGoo00<007ooOol04Goo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001=o
o`03001oogoo00Eoo`Dmkn]oo`03001oogoo019oo`0057oo00<007ooOol017oo1Cg_fWoo00<mkgoo
Ool03Woo00<007ooOol04Woo000DOol00`00Oomoo`04Ool6?NoIOol2?Nl>Ool00`00Oomoo`0COol0
01Aoo`03001oogoo00Aoo`HmkmUoo`<mk`eoo`03001oogoo01=oo`005Goo00<007ooOol00goo1Sg_
fGoo13g_37oo00<007ooOol04goo000EOol00`00Oomoo`03Ool6?NoBOol<?Nl:Ool00`00Oomoo`0D
Ool001Eoo`03001oogoo00=oo`Hmkm=oo`/mk`Yoo`03001oogoo01Aoo`005Goo00<007ooOol017oo
1Cg_e7oo2Sg_2Woo00<007ooOol057oo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool00`00Oomo
o`0EOol001Ioo`03001oogoo00=oo`DmkmEoo`Tmk`Uoo`03001oogoo01Eoo`005goo00<007ooOol0
0Woo1Cg_eGoo23g_2Goo00<007ooOol05Woo000GOol00`00Oomoo`02Ool6?NoDOol8?Nl9Ool00`00
Oomoo`0FOol001Qoo`04001oogooOol6?NoDOol8?Nl8Ool00`00Oomoo`0GOol001Qoo`04001oogoo
Ool6?NoCOol9?Nl8Ool00`00Oomoo`0GOol001Uoo`04001oogooOol6?No@Ool;?Nl8Ool00`00Oomo
o`0GOol001Uoo`04001oogooOol7?No>Ool;?Nl8Ool00`00Oomoo`0HOol001Yoo`03001oogoo00Lm
kleoo``mk`Qoo`03001oogoo01Qoo`006Woo00@007ooOomoo`LmklUoo`hmk`Qoo`03001oogoo01Uo
o`006goo00<007ooOol023g_aWoo43g_1goo00<007ooOol06Woo000KOol00`00Oomoo`09?No5Ool@
?Nl7Ool00`00Oomoo`0JOol001aoo`03001oocg_00TmklAooa0mk`Ioo`03001oogoo01]oo`0077oo
00<007ooOol02Sg_`goo1Sg_0goo1Sg_1goo00<007ooOol06goo000MOol00`00Oolmk`09?No2Ool5
?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001eoo`03001oocg_00Xmkl5oo`Dmk`Eoo`Hmk`Ioo`03001o
ogoo01aoo`007Woo00<003g_?Nl02Cg_`Goo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo000NOol00`00
?Nlmk`09?No1Ool5?Nl5Ool5?Nl6Ool00`00Oomoo`0MOol001moo`/mkl5oo`@mk`Eoo`Hmk`Eoo`03
001oogoo01ioo`007goo00<003g_?Nl02Cg__goo1Cg_1Goo1Sg_1Goo00<007ooOol07Woo000POol0
0`00?Nlmk`08?NnoOol5?Nl4Ool6?Nl5Ool00`00Oomoo`0OOol0021oo`03000mkcg_00Tmkkeoo`Dm
k`Eoo`Hmk`Eoo`03001oogoo01moo`008Goo2cg__Goo1Cg_1Goo1Sg_17oo00<007ooOol087oo000R
Ool00`00?Nlmk`08?NnlOol5?Nl4Ool7?Nl3Ool00`00Oomoo`0QOol002=oo`Xmkk]oo`Hmk`Aoo`Hm
k`=oo`03001oogoo029oo`0097oo2Sg_^Woo1Cg_1Goo1Sg_0Woo00<007ooOol08goo000TOol00`00
?Nlmk`07?NnjOol4?Nl5Ool7?Nl2Ool00`00Oomoo`0SOol002Eoo`XmkkQoo`Dmk`Eoo`Dmk`=oo`03
001oogoo02Aoo`009Woo00<003g_?Nl01cg_]Woo1Sg_17oo1cg_00=oo`00Ool09Woo000VOol00`00
Oolmk`0;?NnbOol5?Nl4Ool7?Nl2Ool00`00Oomoo`0UOol002Moo`03001oocg_00Xmkk9oo`Dmk`=o
o`Pmk`03Ool007oo02Moo`00:7oo00<007oo?Nl02Cg_/Goo1Sg_0Woo23g_00=oo`00Ool0:7oo000Y
Ool00`00Oolmk`09?Nn`Ool5?Nl2Ool8?Nl00goo001oo`0YOol002Yoo`03001oocg_00Pmkk1oo`@m
k`9oo`Tmk`03001oogoo02Uoo`00:Woo00<007ooOol02Cg_[Woo1Cg_0Woo2Cg_00<007ooOol0:Goo
000[Ool00`00Oomoo`09?Nn]Ool5?Nl2Ool8?Nl00`00Oomoo`0ZOol002aoo`03001oocg_00Pmkjao
o`Dmk`03Oolmkcg_00Lmk`03001oogoo02]oo`00;Goo00<007oo?Nl023g_Zgoo1Cg_00=oocg_?Nl0
1Sg_00<007ooOol0;7oo000^Ool00`00Oomoo`09?NnYOol=?Nl00`00Oomoo`0]Ool002ioo`04001o
ogooOol9?NnXOol:?Nl3Ool00`00Oomoo`0]Ool002moo`04001oogooOol:?NnUOol:?Nl3Ool00`00
Oomoo`0^Ool0031oo`04001oogooOol:?NnTOol9?Nl3Ool00`00Oomoo`0_Ool0035oo`04001oogoo
Ool<?NnPOol8?Nl4Ool00`00Oomoo`0`Ool0039oo`80009oo`dmkiaoo`Tmk`=oo`8003=oo`00=7oo
00<007ooOol033g_VWoo2Sg_0goo00<007ooOol0<goo000eOol00`00Oolmk`0<?NnHOol:?Nl3Ool0
0`00Oomoo`0dOol003Eoo`04001oogooOol;?NnFOol<?Nl3Ool00`00Oomoo`0dOol003Ioo`04001o
ogooOol;?NnDOol:?Nl5Ool00`00Oomoo`0eOol003Moo`03001oogoo009oo`TmkiAoo`Pmk`Ioo`03
001oogoo03Ioo`00>7oo00<007ooOol00Woo2Cg_TWoo2Cg_1Goo00<007ooOol0=goo000iOol20003
Ool8?NnAOol:?Nl3Ool2000jOol003]oo`03001oogoo00Tmkhmoo`Xmk`=oo`03001oogoo03Yoo`00
?7oo00<007ooOol02Cg_SGoo2Sg_0goo00<007ooOol0>goo000mOol00`00Oomoo`0:?Nn9Ool9?Nl5
Ool00`00Oomoo`0lOol003ioo`80009oo`TmkhMoo`Tmk`Aoo`8003moo`00@7oo00<007ooOol02Cg_
Q7oo2cg_0goo00<007ooOol0?goo0011Ool200000goo?Nlmk`07?Nn2Ool9?Nl4Ool20012Ool004=o
o`03001oocg_00TmkgYoo`hmk`Aoo`03001oogoo049oo`00A7oo00<003g_?Nl02Cg_NGoo3Cg_17oo
00<007ooOol0@goo0015Ool00`00?Nlmk`0:?NmgOol;?Nl5Ool00`00Oomoo`14Ool004Ioo`03000m
kcg_00/mkgAoo``mk`=oo`8004Moo`00B7oo3Sg_0Woo0Sg_K7oo3Cg_0Woo0P00BGoo001:OolA?NmZ
Ool<?Nl2Ool2001;Ool004aooa0mkfMoo`/mk`=oo`8004eoo`00CWoo4Cg_Hgoo2cg_0goo00<007oo
Ool0CGoo001?Ool00`00?Nlmk`0??NmPOol<?Nl2Ool00`00Oomoo`1>Ool0051oo`800003Oolmkcg_
00lmkeUoo`03?Nmoogoo00Xmk`=oo`80055oo`00DWoo0P0000=oocg_?Nl043g_DWoo00<mkgooOol0
3Sg_00=oo`000000Dgoo001DOol200000cg_Oolmk`0@?Nl7Ool5?Nm0OolC?Nl00goo0000001EOol0
05Ioo`8000Aooa0mk`=oo`Hmkciooa@mk`8005Moo`00F7oo0`0017oo5Sg_?7oo5Cg_00<007ooOol0
Egoo001KOol30003OolD?NliOolD?Nl2001LOol005ioo`8000Aooa8mkcAooaPmkeioo`00H7oo0P00
17oo5cg_97oo7Sg_HGoo001ROol30004OolD?Nl@Ool2?Nl=OolP?Nl00`00Oomoo`1QOol006Eoo`<0
00EoobHmk`9oob8mk`<006Ioo`00J7oo10000gooA3g_00@003g_000006Uoo`00K7oo10000goo>cg_
00=oo`0000000P00KGoo001`Ool30003Ool`?Nl5Ool4001aOol007=oo`D00003Oolmkcg_02Dmk`Mo
o`@007Eoo`00N7oo10007Cg_1goo1`00NGoo001nOol@?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00RWoo0`0017oo0P00SGoo002<Ool01@00Oomo
ogoo00000Woo00<007ooOol0RWoo002;Ool30005Ool00`00Oomoo`2:Ool008Yoo`04001oogoo0003
Ool2002=Ool008Yoo`04001oogoo0003Ool00`00Oomoo`2<Ool008]oo`<000=oo`<008aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(96)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
.08243 .46962 m
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
Mistroke
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
Mistroke
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
Mistroke
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
Mfstroke
1 .983 0 r
.008 w
.07656 .49788 Mdot
.016 w
.07656 .49788 m
.07648 .49774 L
s
1 .967 0 r
.008 w
.07648 .49774 Mdot
.016 w
.07648 .49774 m
.07631 .49745 L
s
1 .95 0 r
.008 w
.07631 .49745 Mdot
.016 w
.07631 .49745 m
.07607 .49706 L
s
1 .933 0 r
.008 w
.07607 .49706 Mdot
.016 w
.07607 .49706 m
.07577 .49663 L
s
1 .917 0 r
.008 w
.07577 .49663 Mdot
.016 w
.07577 .49663 m
.07544 .49619 L
s
1 .9 0 r
.008 w
.07544 .49619 Mdot
.016 w
.07544 .49619 m
.0751 .49573 L
s
1 .883 0 r
.008 w
.0751 .49573 Mdot
.016 w
.0751 .49573 m
.07479 .49527 L
s
1 .867 0 r
.008 w
.07479 .49527 Mdot
.016 w
.07479 .49527 m
.07452 .49479 L
s
1 .85 0 r
.008 w
.07452 .49479 Mdot
.016 w
.07452 .49479 m
.0743 .49427 L
s
1 .833 0 r
.008 w
.0743 .49427 Mdot
.016 w
.0743 .49427 m
.07416 .49371 L
s
1 .817 0 r
.008 w
.07416 .49371 Mdot
.016 w
.07416 .49371 m
.07411 .4931 L
s
1 .8 0 r
.008 w
.07411 .4931 Mdot
.016 w
.07411 .4931 m
.07417 .49243 L
s
1 .783 0 r
.008 w
.07417 .49243 Mdot
.016 w
.07417 .49243 m
.07433 .49171 L
s
1 .767 0 r
.008 w
.07433 .49171 Mdot
.016 w
.07433 .49171 m
.07457 .49093 L
s
1 .75 0 r
.008 w
.07457 .49093 Mdot
.016 w
.07457 .49093 m
.07487 .49011 L
s
1 .733 0 r
.008 w
.07487 .49011 Mdot
.016 w
.07487 .49011 m
.07521 .48935 L
s
1 .717 0 r
.008 w
.07521 .48935 Mdot
.016 w
.07521 .48935 m
.07557 .48849 L
s
1 .7 0 r
.008 w
.07557 .48849 Mdot
.016 w
.07557 .48849 m
.07591 .48749 L
s
1 .683 0 r
.008 w
.07591 .48749 Mdot
.016 w
.07591 .48749 m
.07621 .48643 L
s
1 .667 0 r
.008 w
.07621 .48643 Mdot
.016 w
.07621 .48643 m
.07646 .48529 L
s
1 .65 0 r
.008 w
.07646 .48529 Mdot
.016 w
.07646 .48529 m
.07667 .48406 L
s
1 .633 0 r
.008 w
.07667 .48406 Mdot
.016 w
.07667 .48406 m
.07683 .48298 L
s
1 .617 0 r
.008 w
.07683 .48298 Mdot
.016 w
.07683 .48298 m
.07695 .48186 L
s
1 .6 0 r
.008 w
.07695 .48186 Mdot
.016 w
.07695 .48186 m
.07703 .48071 L
s
1 .583 0 r
.008 w
.07703 .48071 Mdot
.016 w
.07703 .48071 m
.07711 .47954 L
s
1 .567 0 r
.008 w
.07711 .47954 Mdot
.016 w
.07711 .47954 m
.07723 .47837 L
s
1 .55 0 r
.008 w
.07723 .47837 Mdot
.016 w
.07723 .47837 m
.07739 .47737 L
s
1 .533 0 r
.008 w
.07739 .47737 Mdot
.016 w
.07739 .47737 m
.07763 .47629 L
s
1 .517 0 r
.008 w
.07763 .47629 Mdot
.016 w
.07763 .47629 m
.07797 .47524 L
s
1 .5 0 r
.008 w
.07797 .47524 Mdot
.016 w
.07797 .47524 m
.07839 .47426 L
s
1 .483 0 r
.008 w
.07839 .47426 Mdot
.016 w
.07839 .47426 m
.07888 .47327 L
s
1 .467 0 r
.008 w
.07888 .47327 Mdot
.016 w
.07888 .47327 m
.07936 .47227 L
s
1 .45 0 r
.008 w
.07936 .47227 Mdot
.016 w
.07936 .47227 m
.07986 .47139 L
s
1 .433 0 r
.008 w
.07986 .47139 Mdot
.016 w
.07986 .47139 m
.08038 .47052 L
s
1 .417 0 r
.008 w
.08038 .47052 Mdot
.016 w
.08038 .47052 m
.08092 .46968 L
s
1 .4 0 r
.008 w
.08092 .46968 Mdot
.016 w
.08092 .46968 m
.08143 .4689 L
s
1 .383 0 r
.008 w
.08143 .4689 Mdot
.016 w
.08143 .4689 m
.08194 .46818 L
s
1 .367 0 r
.008 w
.08194 .46818 Mdot
.016 w
.08194 .46818 m
.08242 .46755 L
s
1 .35 0 r
.008 w
.08242 .46755 Mdot
.016 w
.08242 .46755 m
.08288 .46698 L
s
1 .333 0 r
.008 w
.08288 .46698 Mdot
.016 w
.08288 .46698 m
.08328 .4665 L
s
1 .317 0 r
.008 w
.08328 .4665 Mdot
.016 w
.08328 .4665 m
.08362 .46606 L
s
1 .3 0 r
.008 w
.08362 .46606 Mdot
.016 w
.08362 .46606 m
.0839 .46568 L
s
1 .283 0 r
.008 w
.0839 .46568 Mdot
.016 w
.0839 .46568 m
.08413 .46534 L
s
1 .267 0 r
.008 w
.08413 .46534 Mdot
.016 w
.08413 .46534 m
.08434 .46504 L
s
1 .25 0 r
.008 w
.08434 .46504 Mdot
.016 w
.08434 .46504 m
.08455 .4648 L
s
1 .233 0 r
.008 w
.08455 .4648 Mdot
.016 w
.08455 .4648 m
.08479 .46463 L
s
1 .217 0 r
.008 w
.08479 .46463 Mdot
.016 w
.08479 .46463 m
.08506 .46454 L
s
1 .2 0 r
.008 w
.08506 .46454 Mdot
.016 w
.08506 .46454 m
.08535 .46451 L
s
1 .183 0 r
.008 w
.08535 .46451 Mdot
.016 w
.08535 .46451 m
.08567 .46454 L
s
1 .167 0 r
.008 w
.08567 .46454 Mdot
.016 w
.08567 .46454 m
.08599 .46461 L
s
1 .15 0 r
.008 w
.08599 .46461 Mdot
.016 w
.08599 .46461 m
.08629 .46468 L
s
1 .133 0 r
.008 w
.08629 .46468 Mdot
.016 w
.08629 .46468 m
.08657 .46473 L
s
1 .117 0 r
.008 w
.08657 .46473 Mdot
.016 w
.08657 .46473 m
.08682 .46474 L
s
1 .1 0 r
.008 w
.08682 .46474 Mdot
.016 w
.08682 .46474 m
.08706 .46474 L
s
1 .083 0 r
.008 w
.08706 .46474 Mdot
.016 w
.08706 .46474 m
.08728 .46474 L
s
1 .067 0 r
.008 w
.08728 .46474 Mdot
.016 w
.08728 .46474 m
.08751 .46474 L
s
1 .05 0 r
.008 w
.08751 .46474 Mdot
.016 w
.08751 .46474 m
.08774 .46474 L
s
1 .033 0 r
.008 w
.08774 .46474 Mdot
.016 w
.08774 .46474 m
.08794 .46473 L
s
1 .017 0 r
.008 w
.08794 .46473 Mdot
.016 w
.08794 .46473 m
.08811 .46473 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol0
3Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Pmknao
o`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_k7oo00<007ooOol03Goo000>Ool00`00Oomo
o`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`XmknUoo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool<?NoWOol00`00
Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007ooOol03Woo
3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03
001oogoo00eoo`lmknEoo`03001oogoo00aoo`003Goo00<007ooOol03Goo3cg_iGoo00<007ooOol0
37oo000=Ool00`00Oomoo`0<OolA?NoTOol00`00Oomoo`0<Ool000eoo`03001oogoo00]ooa8mknAo
o`03001oogoo00aoo`003Goo00<007ooOol02Goo0Sg_1GaP3Sg_hgoo00<007ooOol037oo000=Ool0
0`00Oomoo`08Ool2?Nl017e0O61lH7`00WaP43g_hGoo00<007ooOol037oo000=Ool00`00Oomoo`08
Ool00cg_OL1m@002O6000g`0O61lH00E?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`03
?Nmm`7e000ElH1Hmkm]oo`03001oogoo00aoo`0037oo00<007ooOol027oo0Sg_00=m`7e0OD000ge0
5cg_g7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool3?Nl00gg0OJ1mX002OJ03?Nl4Ool5?Nl0
0goo?Nlmk`09?NoLOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`@mk`Amh1Tmkmaoo`03001o
ogoo00]oo`0037oo00<007ooOol01Goo13g_00=n`7hPOR000WhP00=n`3g_?Nl05Cg_gGoo00<007oo
Ool02goo000<Ool00`00Oomoo`08Ool00cg_O/1nH003OV0??NoVOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Qoo`03?Nmo07j000=nP003Oolmkcg_00`mknIoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo00Hmkgl0O`1n`7l0Oj06Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03
?Nmo07l0009o0003Oj1oogoo00Qoo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo00<m
kgn0Oh000Wn000=oX7ooOol027oo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7?Nl;
Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo00]o
o`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5
?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001oogoo
00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`06
Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03001o
ogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomo
o`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeoo`03
001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool00`00
Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tmkmao
o`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=Ool0
0`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9oo`Tm
kmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo000>
Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmko=o
o`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00Oomo
o`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`00
3goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool00`00
Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo
1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011oo`03
001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007ooOol0
3goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hmknmo
o`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011oo`00
4Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool00`00
Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo
1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03
001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_
fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomoo`0C
Ool001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol00goo
1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00Oomo
o`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007ooOol0
0goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool00`00
Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<007oo
Ool00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<0
07ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000Oomo
ogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<007oo
Ool067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogooOol7
?No9Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo00PmklIooa0mk`Moo`03001oogoo01Yo
o`006goo00<007ooOol02Cg_aGoo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`09?No4Ool@
?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Xmkl=oo`Hmk`=oo`Hmk`Moo`03001oogoo01]o
o`007Goo00<007oo?Nl02Cg_`Woo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`0:
?No1Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00Tmkl5oo`Dmk`Eoo`Dmk`Io
o`03001oogoo01eoo`007Woo00<003g_?Nl02Cg_`Goo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo000O
Ool;?No1Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Tmkkmoo`Dmk`Eoo`Hm
k`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl023g__goo1Cg_17oo1Sg_1Goo00<007ooOol07goo
000POol00`00?Nlmk`09?NnmOol5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`/mkkeoo`Dmk`Eo
o`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl023g__7oo1Cg_17oo1cg_0goo00<007ooOol0
8Goo000SOol:?NnkOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`XmkkYoo`Dmk`Eoo`Hmk`9o
o`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo000U
Ool:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Aoo`Lm
k`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo000W
Ool00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5oo`Hm
k`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0:Goo
000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tmkjio
o`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007ooOol0
:Woo000/Ool00`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03001o
ocg_00Pmkj]oo`Dmk`03Oolmkcg_00Hmk`03001oogoo02aoo`00;Woo00<007ooOol02Cg_ZGoo3Cg_
00<007ooOol0;Goo000^Ool01000Oomoogoo2Cg_Z7oo2Sg_0goo00<007ooOol0;Goo000_Ool01000
Oomoogoo2Sg_YGoo2Sg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo2Sg_Y7oo2Cg_0goo00<0
07ooOol0;goo000aOol01000Oomoogoo33g_X7oo23g_17oo00<007ooOol0<7oo000bOol20002Ool=
?NnLOol9?Nl3Ool2000cOol003Aoo`03001oogoo00`mkiYoo`Xmk`=oo`03001oogoo03=oo`00=Goo
00<007oo?Nl033g_V7oo2Sg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo2cg_UWoo33g_0goo
00<007ooOol0=7oo000fOol01000Oomoogoo2cg_U7oo2Sg_1Goo00<007ooOol0=Goo000gOol00`00
Oomoo`02Ool9?NnDOol8?Nl6Ool00`00Oomoo`0fOol003Qoo`03001oogoo009oo`Tmki9oo`Tmk`Eo
o`03001oogoo03Moo`00>Goo0P000goo23g_TGoo2Sg_0goo0P00>Woo000kOol00`00Oomoo`09?Nn?
Ool:?Nl3Ool00`00Oomoo`0jOol003aoo`03001oogoo00Tmkheoo`Xmk`=oo`03001oogoo03]oo`00
?Goo00<007ooOol02Sg_RGoo2Cg_1Goo00<007ooOol0?7oo000nOol20002Ool9?Nn7Ool9?Nl4Ool2
000oOol0041oo`03001oogoo00TmkhAoo`/mk`=oo`03001oogoo03moo`00@Goo0P0000=oocg_?Nl0
1cg_PWoo2Cg_17oo0P00@Woo0013Ool00`00Oolmk`09?NmjOol>?Nl4Ool00`00Oomoo`12Ool004Ao
o`03000mkcg_00TmkgUoo`dmk`Aoo`03001oogoo04=oo`00AGoo00<003g_?Nl02Sg_Mgoo2cg_1Goo
00<007ooOol0A7oo0016Ool00`00?Nlmk`0;?NmdOol<?Nl3Ool20017Ool004Qoo`hmk`9oo`8mkfao
o`dmk`9oo`8004Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo001<Ool@?NmWOol;?Nl3Ool2001=Ool0
04iooa4mkf=oo`/mk`=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03cg_H7oo33g_0Woo00<007oo
Ool0CWoo001@Ool200000goo?Nlmk`0??NmIOol00cg_Oomoo`0:?Nl3Ool2001AOol0059oo`800003
Oolmkcg_010mke9oo`03?Nmoogoo00hmk`03Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_1goo
1Cg_@7oo4cg_00=oo`000000EGoo001FOol20004Ool@?Nl3Ool6?NlnOolD?Nl2001GOol005Qoo`<0
00AooaHmkcaooaDmk`03001oogoo05Moo`00Fgoo0`000goo53g_>Goo53g_0P00G7oo001NOol20004
OolB?NldOolH?NmNOol0061oo`8000AooaLmkbAooahmkf5oo`00HWoo0`0017oo53g_47oo0Sg_3Goo
83g_00<007ooOol0HGoo001UOol30005OolV?Nl2OolR?Nl3001VOol006Qoo`@000=ood@mk`04000m
k`00001YOol006aoo`@000=ooc/mk`03Ool00000008006eoo`00L7oo0`000goo<3g_1Goo1000LGoo
001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L007Uoo`00OWoo43g_17oo
3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yoo`<0
00=oo`<008eoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00Rgoo0`000Woo00@007oo
Ool008aoo`00RWoo00@007ooOol0009oo`<008eoo`00RWoo00@007ooOol000=oo`03001oogoo08ao
o`00Rgoo0`000goo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(97)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
.08243 .46962 m
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
Mistroke
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
Mistroke
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
Mistroke
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
Mfstroke
.07656 .49788 m
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
Mistroke
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
Mfstroke
1 .975 0 r
.008 w
.08794 .46459 Mdot
.016 w
.08794 .46459 m
.0879 .46447 L
s
1 .95 0 r
.008 w
.0879 .46447 Mdot
.016 w
.0879 .46447 m
.08792 .46428 L
s
1 .925 0 r
.008 w
.08792 .46428 Mdot
.016 w
.08792 .46428 m
.08802 .464 L
s
1 .9 0 r
.008 w
.08802 .464 Mdot
.016 w
.08802 .464 m
.08823 .46361 L
s
1 .875 0 r
.008 w
.08823 .46361 Mdot
.016 w
.08823 .46361 m
.08854 .46311 L
s
1 .85 0 r
.008 w
.08854 .46311 Mdot
.016 w
.08854 .46311 m
.08895 .46245 L
s
1 .825 0 r
.008 w
.08895 .46245 Mdot
.016 w
.08895 .46245 m
.08944 .46158 L
s
1 .8 0 r
.008 w
.08944 .46158 Mdot
.016 w
.08944 .46158 m
.09002 .4605 L
s
1 .775 0 r
.008 w
.09002 .4605 Mdot
.016 w
.09002 .4605 m
.09067 .45921 L
s
1 .75 0 r
.008 w
.09067 .45921 Mdot
.016 w
.09067 .45921 m
.09132 .45793 L
s
1 .725 0 r
.008 w
.09132 .45793 Mdot
.016 w
.09132 .45793 m
.09198 .4561 L
s
1 .7 0 r
.008 w
.09198 .4561 Mdot
.016 w
.09198 .4561 m
.09265 .45435 L
s
1 .675 0 r
.008 w
.09265 .45435 Mdot
.016 w
.09265 .45435 m
.09338 .45224 L
s
1 .65 0 r
.008 w
.09338 .45224 Mdot
.016 w
.09338 .45224 m
.09418 .44988 L
s
1 .625 0 r
.008 w
.09418 .44988 Mdot
.016 w
.09418 .44988 m
.09483 .44731 L
s
1 .6 0 r
.008 w
.09483 .44731 Mdot
.016 w
.09483 .44731 m
.09544 .44454 L
s
1 .575 0 r
.008 w
.09544 .44454 Mdot
.016 w
.09544 .44454 m
.0959 .44142 L
s
1 .55 0 r
.008 w
.0959 .44142 Mdot
.016 w
.0959 .44142 m
.09632 .43866 L
s
1 .525 0 r
.008 w
.09632 .43866 Mdot
.016 w
.09632 .43866 m
.09664 .43627 L
s
1 .5 0 r
.008 w
.09664 .43627 Mdot
.016 w
.09664 .43627 m
.09688 .4335 L
s
1 .475 0 r
.008 w
.09688 .4335 Mdot
.016 w
.09688 .4335 m
.09706 .43094 L
s
1 .45 0 r
.008 w
.09706 .43094 Mdot
.016 w
.09706 .43094 m
.0972 .42799 L
s
1 .425 0 r
.008 w
.0972 .42799 Mdot
.016 w
.0972 .42799 m
.09727 .42579 L
s
1 .4 0 r
.008 w
.09727 .42579 Mdot
.016 w
.09727 .42579 m
.09723 .42364 L
s
1 .375 0 r
.008 w
.09723 .42364 Mdot
.016 w
.09723 .42364 m
.09707 .42151 L
s
1 .35 0 r
.008 w
.09707 .42151 Mdot
.016 w
.09707 .42151 m
.09679 .41974 L
s
1 .325 0 r
.008 w
.09679 .41974 Mdot
.016 w
.09679 .41974 m
.09637 .41811 L
s
1 .3 0 r
.008 w
.09637 .41811 Mdot
.016 w
.09637 .41811 m
.09581 .41664 L
s
1 .275 0 r
.008 w
.09581 .41664 Mdot
.016 w
.09581 .41664 m
.09519 .41543 L
s
1 .25 0 r
.008 w
.09519 .41543 Mdot
.016 w
.09519 .41543 m
.0945 .41441 L
s
1 .225 0 r
.008 w
.0945 .41441 Mdot
.016 w
.0945 .41441 m
.09376 .41355 L
s
1 .2 0 r
.008 w
.09376 .41355 Mdot
.016 w
.09376 .41355 m
.093 .41284 L
s
1 .175 0 r
.008 w
.093 .41284 Mdot
.016 w
.093 .41284 m
.09227 .41229 L
s
1 .15 0 r
.008 w
.09227 .41229 Mdot
.016 w
.09227 .41229 m
.09163 .41186 L
s
1 .125 0 r
.008 w
.09163 .41186 Mdot
.016 w
.09163 .41186 m
.09101 .41154 L
s
1 .1 0 r
.008 w
.09101 .41154 Mdot
.016 w
.09101 .41154 m
.09044 .41132 L
s
1 .075 0 r
.008 w
.09044 .41132 Mdot
.016 w
.09044 .41132 m
.08994 .41119 L
s
1 .05 0 r
.008 w
.08994 .41119 Mdot
.016 w
.08994 .41119 m
.08956 .41113 L
s
1 .025 0 r
.008 w
.08956 .41113 Mdot
.016 w
.08956 .41113 m
.08931 .41113 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00@Goo0P0043g_RGoo0P00@Woo0010Ool00`00
Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001oogoo00Xmki=oo`8003moo`00?Woo00<007oo
?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnHOol00`00Oomoo`0kOol003]oo`03001oocg_
00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl02cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:
?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_00Xmkj5oo`03001oogoo03Ioo`00=Woo00<0
07ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00Oomoo`0:?NnWOol00`00Oomoo`0dOol003Ao
o`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039oo`8000=oo`XmkjYoo`03001oogoo039oo`00
<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00
Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03001oogoo02moo`00;goo00<007ooOol00Woo
2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03
001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo00<007ooOol017oo2Sg_]Goo00<007ooOol0
:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo00Aoo`XmkkMo
o`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg__Woo00<007ooOol0:Goo000YOol00`00Oomo
o`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00
:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00
Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo
2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03
001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol0
8Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUo
o`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomo
o`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`00
7goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00
Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo
23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03
001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol0
6goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMo
o`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomo
o`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`00
6Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00
Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo
23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04Ool9?NoPOol00`00Oomoo`0FOol001Moo`03
001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol0
5Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEo
o`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000EOol00`00Oomo
o`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`00
57oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo000DOol00`00Oomoo`05Ool7?NoWOol00`00
Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo
1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol0019oo`03
001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol0
4Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`Dmkneo
o`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomo
o`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmkneoo`03001oogoo00moo`00
47oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo
1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09Ool6?No^Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<007ooOol02Goo00<mkga0O4000ga000<m
kgooOol0jgoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool013g_O41l@7`00Wa000=lh7ooOol0
jgoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool013g_O41l@7`00Wa000=lh3g_Ool0jgoo00<0
07ooOol03Woo000>Ool00`00Oomoo`0:Ool00cg_O41l@003O4000gcP?Nlmk`3/Ool00`00Oomoo`0=
Ool000ioo`03001oogoo00Yoo`8mk`AlH003O>0mkcg_00<mknUoo`03001oogoo00eoo`003Woo00<0
07ooOol037oo00<mkgcPO>000WcP1Cg_jGoo00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool4OD07
?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`AmH0PmknMoo`03001oogoo00aoo`003Goo
00<007ooOol03Woo17fP2Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool4OL09?NoVOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00eoo`03?Nmmh7gP009mh0TmknIoo`03001oogoo00aoo`00
3Goo00<007ooOol03Goo00<mkgh0OP000Wh02Sg_iGoo00<007ooOol037oo000=Ool00`00Oomoo`0=
Ool00gj0OR1n8002OR000gj0?Nlmk`07?NoUOol00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`03
?NmnP7i000=n@0/mknAoo`03001oogoo00aoo`003Goo00<007ooOol02goo00<mkgl0O/0017iP2cg_
i7oo00<007ooOol037oo000=Ool00`00Oomoo`09Ool3?Nl01Gl0O/1n`7j0O/003Cg_hgoo00<007oo
Ool037oo000=Ool00`00Oomoo`08Ool4?Nl00gl0O/1n`002O/0??NoQOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Qoo`@mk`03O`1nh7kP009nh1@mkmaoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo13g_17mP5Sg_fgoo00<007ooOol037oo000<Ool00`00Oomoo`08OolO?NoLOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Moo`/mk`Aoo`Dmk`03Oolmkcg_00Tmkmaoo`03001oogoo00]oo`0037oo
00<007ooOol01Woo8Cg_g7oo00<007ooOol02goo000<Ool00`00Oomoo`05OolQ?NoMOol00`00Oomo
o`0;Ool000aoo`03001oogoo00QooaDmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_
00=oocg_?Nl033g_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]oo`0037oo00<007oo
Ool027oo1Sg_2Woo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7?Nl;Ool6?NoTOol0
0`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo00]oo`0037oo00<0
07ooOol01goo1Cg_37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5?Nl<Ool:?NoQ
Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001oogoo00]oo`003Goo
00<007ooOol01Woo1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`06Ool5?Nl@Ool7
?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03001oogoo00aoo`00
3Goo00<007ooOol01Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool6?Nl?
Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeoo`03001oogoo00ao
o`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5
?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1oo`Tmkmaoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1Cg_47oo2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`07
Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9oo`TmkmYoo`03001o
ogoo00aoo`003Woo00<007ooOol01Woo1Sg_4Woo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomo
o`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmko=oo`03001oogoo
00eoo`003Woo00<007ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00Oomoo`06Ool6?Nob
Ool00`00Oomoo`0=Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`003goo00<007oo
Ool01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo1Sg_l7oo00<0
07ooOol03Woo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Io
o`Dmko1oo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007ooOol03goo000@Ool0
0`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hmknmoo`03001oogoo
00moo`004Goo00<007ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool5?No^
Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmknioo`03001oogoo011oo`004Woo00<007oo
Ool01Goo1Cg_kGoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool00`00Oomoo`0AOol0
01=oo`03001oogoo00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<0
07ooOol04Woo000COol00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Ao
o`DmkmYoo`03?Nmoogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_fGoo0Sg_3Woo
00<007ooOol04goo000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomoo`0COol001Eoo`03
001oogoo00=oo`HmkmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol00goo1Sg_dWoo33g_
2Woo00<007ooOol057oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00Oomoo`0DOol001Eo
o`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_eGoo
2Cg_2Goo00<007ooOol05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool00`00Oomoo`0EOol0
01Moo`03001oogoo009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<007ooOol00Woo1Sg_
e7oo23g_2Goo00<007ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo
000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1Sg_d7oo
2cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<007ooOol067oo000J
Ool00`00Oomoo`07?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogooOol7?No9Ool>?Nl8
Ool00`00Oomoo`0IOol001]oo`03001oogoo00PmklIooa0mk`Moo`03001oogoo01Yoo`006goo00<0
07ooOol02Cg_aGoo43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`09?No4Ool@?Nl6Ool00`00
Oomoo`0KOol001aoo`03001oogoo00Xmkl=oo`Hmk`=oo`Hmk`Moo`03001oogoo01]oo`007Goo00<0
07oo?Nl02Cg_`Woo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`0:?No1Ool5?Nl5
Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03000mkcg_00Tmkl5oo`Dmk`Eoo`Dmk`Ioo`03001oogoo
01eoo`007Woo00<003g_?Nl02Cg_`Goo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo000OOol;?No1Ool4
?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001moo`03000mkcg_00Tmkkmoo`Dmk`Eoo`Hmk`Eoo`03001o
ogoo01ioo`0087oo00<003g_?Nl023g__goo1Cg_17oo1Sg_1Goo00<007ooOol07goo000POol00`00
?Nlmk`09?NnmOol5?Nl5Ool6?Nl5Ool00`00Oomoo`0OOol0025oo`/mkkeoo`Dmk`Eoo`Hmk`Aoo`03
001oogoo021oo`008Woo00<003g_?Nl023g__7oo1Cg_17oo1cg_0goo00<007ooOol08Goo000SOol:
?NnkOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0ROol002Aoo`XmkkYoo`Dmk`Eoo`Hmk`9oo`03001oogoo
02=oo`0097oo00<003g_?Nl01cg_^Woo13g_1Goo1cg_0Woo00<007ooOol08goo000UOol:?NnhOol5
?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Ioo`03000mkcg_00LmkkIoo`Hmk`Aoo`Lmk`03Ool007oo
02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo000WOol00`00Oolm
k`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0WOol002Qoo`03001oocg_00Tmkk5oo`Hmk`9oo`Pmk`03
Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0:Goo000ZOol00`00
Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tmkjioo`Dmk`9oo`Tm
k`03001oogoo02Uoo`00:goo00<007ooOol02Cg_[Goo1Cg_0Woo23g_00<007ooOol0:Woo000/Ool0
0`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03001oocg_00Pmkj]o
o`Dmk`03Oolmkcg_00Hmk`03001oogoo02aoo`00;Woo00<007ooOol02Cg_ZGoo3Cg_00<007ooOol0
;Goo000^Ool01000Oomoogoo2Cg_Z7oo2Sg_0goo00<007ooOol0;Goo000_Ool01000Oomoogoo2Sg_
YGoo2Sg_0goo00<007ooOol0;Woo000`Ool01000Oomoogoo2Sg_Y7oo2Cg_0goo00<007ooOol0;goo
000aOol01000Oomoogoo33g_X7oo23g_17oo00<007ooOol0<7oo000bOol20002Ool=?NnLOol9?Nl3
Ool2000cOol003Aoo`03001oogoo00`mkiYoo`Xmk`=oo`03001oogoo03=oo`00=Goo00<007oo?Nl0
33g_V7oo2Sg_0goo00<007ooOol0=7oo000eOol01000Oomoogoo2cg_UWoo33g_0goo00<007ooOol0
=7oo000fOol01000Oomoogoo2cg_U7oo2Sg_1Goo00<007ooOol0=Goo000gOol00`00Oomoo`02Ool9
?NnDOol8?Nl6Ool00`00Oomoo`0fOol003Qoo`03001oogoo009oo`Tmki9oo`Tmk`Eoo`03001oogoo
03Moo`00>Goo0P000goo23g_TGoo2Sg_0goo0P00>Woo000kOol00`00Oomoo`09?Nn?Ool:?Nl3Ool0
0`00Oomoo`0jOol003aoo`03001oogoo00Tmkheoo`Xmk`=oo`03001oogoo03]oo`00?Goo00<007oo
Ool02Sg_RGoo2Cg_1Goo00<007ooOol0?7oo000nOol20002Ool9?Nn7Ool9?Nl4Ool2000oOol0041o
o`03001oogoo00TmkhAoo`/mk`=oo`03001oogoo03moo`00@Goo0P0000=oocg_?Nl01cg_PWoo2Cg_
17oo0P00@Woo0013Ool00`00Oolmk`09?NmjOol>?Nl4Ool00`00Oomoo`12Ool004Aoo`03000mkcg_
00TmkgUoo`dmk`Aoo`03001oogoo04=oo`00AGoo00<003g_?Nl02Sg_Mgoo2cg_1Goo00<007ooOol0
A7oo0016Ool00`00?Nlmk`0;?NmdOol<?Nl3Ool20017Ool004Qoo`hmk`9oo`8mkfaoo`dmk`9oo`80
04Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo001<Ool@?NmWOol;?Nl3Ool2001=Ool004iooa4mkf=o
o`/mk`=oo`03001oogoo04eoo`00Cgoo00<003g_?Nl03cg_H7oo33g_0Woo00<007ooOol0CWoo001@
Ool200000goo?Nlmk`0??NmIOol00cg_Oomoo`0:?Nl3Ool2001AOol0059oo`800003Oolmkcg_010m
ke9oo`03?Nmoogoo00hmk`03Ool0000005=oo`00E7oo0P0000<mkgoo?Nl043g_1goo1Cg_@7oo4cg_
00=oo`000000EGoo001FOol20004Ool@?Nl3Ool6?NlnOolD?Nl2001GOol005Qoo`<000AooaHmkcao
oaDmk`03001oogoo05Moo`00Fgoo0`000goo53g_>Goo53g_0P00G7oo001NOol20004OolB?NldOolH
?NmNOol0061oo`8000AooaLmkbAooahmkf5oo`00HWoo0`0017oo53g_47oo0Sg_3Goo83g_00<007oo
Ool0HGoo001UOol30005OolV?Nl2OolR?Nl3001VOol006Qoo`@000=ood@mk`04000mk`00001YOol0
06aoo`@000=ooc/mk`03Ool00000008006eoo`00L7oo0`000goo<3g_1Goo1000LGoo001cOol50000
0goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@001dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=
Ool5002>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Yoo`<000Eoo`03001o
ogoo08]oo`00S7oo00<007ooOol00goo00<007ooOol0Rgoo002;Ool30004Ool00`00Oomoo`2;Ool0
08Yoo`04001oogoo0005Ool00`00Oomoo`2:Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo
002;Ool30002Ool4002<Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(98)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
.08243 .46962 m
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
Mistroke
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
Mistroke
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
Mistroke
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
Mfstroke
.07656 .49788 m
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
Mistroke
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
Mfstroke
.08794 .46459 m
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
s
1 .994 0 r
.008 w
.08955 .41166 Mdot
.016 w
.08955 .41166 m
.08937 .41149 L
s
1 .988 0 r
.008 w
.08937 .41149 Mdot
.016 w
.08937 .41149 m
.08908 .41118 L
s
1 .982 0 r
.008 w
.08908 .41118 Mdot
.016 w
.08908 .41118 m
.08868 .41073 L
s
1 .976 0 r
.008 w
.08868 .41073 Mdot
.016 w
.08868 .41073 m
.08821 .41015 L
s
1 .97 0 r
.008 w
.08821 .41015 Mdot
.016 w
.08821 .41015 m
.08771 .40943 L
s
1 .964 0 r
.008 w
.08771 .40943 Mdot
.016 w
.08771 .40943 m
.0872 .4086 L
s
1 .958 0 r
.008 w
.0872 .4086 Mdot
.016 w
.0872 .4086 m
.08671 .4078 L
s
1 .952 0 r
.008 w
.08671 .4078 Mdot
.016 w
.08671 .4078 m
.08625 .40694 L
s
1 .945 0 r
.008 w
.08625 .40694 Mdot
.016 w
.08625 .40694 m
.08578 .40606 L
s
1 .939 0 r
.008 w
.08578 .40606 Mdot
.016 w
.08578 .40606 m
.0853 .40516 L
s
1 .933 0 r
.008 w
.0853 .40516 Mdot
.016 w
.0853 .40516 m
.08486 .40443 L
s
1 .927 0 r
.008 w
.08486 .40443 Mdot
.016 w
.08486 .40443 m
.0845 .4038 L
s
1 .921 0 r
.008 w
.0845 .4038 Mdot
.016 w
.0845 .4038 m
.08425 .40328 L
s
1 .915 0 r
.008 w
.08425 .40328 Mdot
.016 w
.08425 .40328 m
.08409 .40289 L
s
1 .909 0 r
.008 w
.08409 .40289 Mdot
.016 w
.08409 .40289 m
.084 .40259 L
s
1 .903 0 r
.008 w
.084 .40259 Mdot
.016 w
.084 .40259 m
.08399 .40236 L
s
1 .897 0 r
.008 w
.08399 .40236 Mdot
.016 w
.08399 .40236 m
.08407 .40215 L
s
1 .891 0 r
.008 w
.08407 .40215 Mdot
.016 w
.08407 .40215 m
.0842 .40189 L
s
1 .885 0 r
.008 w
.0842 .40189 Mdot
.016 w
.0842 .40189 m
.08434 .40146 L
s
1 .879 0 r
.008 w
.08434 .40146 Mdot
.016 w
.08434 .40146 m
.0845 .40079 L
s
1 .873 0 r
.008 w
.0845 .40079 Mdot
.016 w
.0845 .40079 m
.08468 .39986 L
s
1 .867 0 r
.008 w
.08468 .39986 Mdot
.016 w
.08468 .39986 m
.08488 .39859 L
s
1 .861 0 r
.008 w
.08488 .39859 Mdot
.016 w
.08488 .39859 m
.08512 .39692 L
s
1 .855 0 r
.008 w
.08512 .39692 Mdot
.016 w
.08512 .39692 m
.08539 .39515 L
s
1 .848 0 r
.008 w
.08539 .39515 Mdot
.016 w
.08539 .39515 m
.08568 .39276 L
s
1 .842 0 r
.008 w
.08568 .39276 Mdot
.016 w
.08568 .39276 m
.08601 .39019 L
s
1 .836 0 r
.008 w
.08601 .39019 Mdot
.016 w
.08601 .39019 m
.08637 .3874 L
s
1 .83 0 r
.008 w
.08637 .3874 Mdot
.016 w
.08637 .3874 m
.08678 .38417 L
s
1 .824 0 r
.008 w
.08678 .38417 Mdot
.016 w
.08678 .38417 m
.08722 .38054 L
s
1 .818 0 r
.008 w
.08722 .38054 Mdot
.016 w
.08722 .38054 m
.08769 .37667 L
s
1 .812 0 r
.008 w
.08769 .37667 Mdot
.016 w
.08769 .37667 m
.08815 .37239 L
s
1 .806 0 r
.008 w
.08815 .37239 Mdot
.016 w
.08815 .37239 m
.08863 .36874 L
s
1 .8 0 r
.008 w
.08863 .36874 Mdot
.016 w
.08863 .36874 m
.08911 .36398 L
s
1 .794 0 r
.008 w
.08911 .36398 Mdot
.016 w
.08911 .36398 m
.08963 .36015 L
s
1 .788 0 r
.008 w
.08963 .36015 Mdot
.016 w
.08963 .36015 m
.0902 .35568 L
s
1 .782 0 r
.008 w
.0902 .35568 Mdot
.016 w
.0902 .35568 m
.09085 .351 L
s
1 .776 0 r
.008 w
.09085 .351 Mdot
.016 w
.09085 .351 m
.09157 .34648 L
s
1 .77 0 r
.008 w
.09157 .34648 Mdot
.016 w
.09157 .34648 m
.09229 .34188 L
s
1 .764 0 r
.008 w
.09229 .34188 Mdot
.016 w
.09229 .34188 m
.09304 .33794 L
s
1 .758 0 r
.008 w
.09304 .33794 Mdot
.016 w
.09304 .33794 m
.09381 .33363 L
s
1 .752 0 r
.008 w
.09381 .33363 Mdot
.016 w
.09381 .33363 m
.09457 .33014 L
s
1 .745 0 r
.008 w
.09457 .33014 Mdot
.016 w
.09457 .33014 m
.09523 .32673 L
s
1 .739 0 r
.008 w
.09523 .32673 Mdot
.016 w
.09523 .32673 m
.09598 .32352 L
s
1 .733 0 r
.008 w
.09598 .32352 Mdot
.016 w
.09598 .32352 m
.09662 .32057 L
s
1 .727 0 r
.008 w
.09662 .32057 Mdot
.016 w
.09662 .32057 m
.09724 .31839 L
s
1 .721 0 r
.008 w
.09724 .31839 Mdot
.016 w
.09724 .31839 m
.09785 .31632 L
s
1 .715 0 r
.008 w
.09785 .31632 Mdot
.016 w
.09785 .31632 m
.09843 .31466 L
s
1 .709 0 r
.008 w
.09843 .31466 Mdot
.016 w
.09843 .31466 m
.09894 .31324 L
s
1 .703 0 r
.008 w
.09894 .31324 Mdot
.016 w
.09894 .31324 m
.09937 .31212 L
s
1 .697 0 r
.008 w
.09937 .31212 Mdot
.016 w
.09937 .31212 m
.09972 .31147 L
s
1 .691 0 r
.008 w
.09972 .31147 Mdot
.016 w
.09972 .31147 m
.09999 .31095 L
s
1 .685 0 r
.008 w
.09999 .31095 Mdot
.016 w
.09999 .31095 m
.1002 .31061 L
s
1 .679 0 r
.008 w
.1002 .31061 Mdot
.016 w
.1002 .31061 m
.10036 .3104 L
s
1 .673 0 r
.008 w
.10036 .3104 Mdot
.016 w
.10036 .3104 m
.10049 .31032 L
s
1 .667 0 r
.008 w
.10049 .31032 Mdot
.016 w
.10049 .31032 m
.10059 .31026 L
s
1 .661 0 r
.008 w
.10059 .31026 Mdot
.016 w
.10059 .31026 m
.10067 .31019 L
s
1 .655 0 r
.008 w
.10067 .31019 Mdot
.016 w
.10067 .31019 m
.1007 .31009 L
s
1 .648 0 r
.008 w
.1007 .31009 Mdot
.016 w
.1007 .31009 m
.10067 .30997 L
s
1 .642 0 r
.008 w
.10067 .30997 Mdot
.016 w
.10067 .30997 m
.10062 .30982 L
s
1 .636 0 r
.008 w
.10062 .30982 Mdot
.016 w
.10062 .30982 m
.10056 .30963 L
s
1 .63 0 r
.008 w
.10056 .30963 Mdot
.016 w
.10056 .30963 m
.10053 .30937 L
s
1 .624 0 r
.008 w
.10053 .30937 Mdot
.016 w
.10053 .30937 m
.10055 .30906 L
s
1 .618 0 r
.008 w
.10055 .30906 Mdot
.016 w
.10055 .30906 m
.10063 .30868 L
s
1 .612 0 r
.008 w
.10063 .30868 Mdot
.016 w
.10063 .30868 m
.10078 .30827 L
s
1 .606 0 r
.008 w
.10078 .30827 Mdot
.016 w
.10078 .30827 m
.10096 .30785 L
s
1 .6 0 r
.008 w
.10096 .30785 Mdot
.016 w
.10096 .30785 m
.10118 .30744 L
s
1 .594 0 r
.008 w
.10118 .30744 Mdot
.016 w
.10118 .30744 m
.1014 .30709 L
s
1 .588 0 r
.008 w
.1014 .30709 Mdot
.016 w
.1014 .30709 m
.10158 .3068 L
s
1 .582 0 r
.008 w
.10158 .3068 Mdot
.016 w
.10158 .3068 m
.10172 .30662 L
s
1 .576 0 r
.008 w
.10172 .30662 Mdot
.016 w
.10172 .30662 m
.10187 .30646 L
s
1 .57 0 r
.008 w
.10187 .30646 Mdot
.016 w
.10187 .30646 m
.10204 .30632 L
s
1 .564 0 r
.008 w
.10204 .30632 Mdot
.016 w
.10204 .30632 m
.10227 .3062 L
s
1 .558 0 r
.008 w
.10227 .3062 Mdot
.016 w
.10227 .3062 m
.10255 .30602 L
s
1 .552 0 r
.008 w
.10255 .30602 Mdot
.016 w
.10255 .30602 m
.1029 .30572 L
s
1 .545 0 r
.008 w
.1029 .30572 Mdot
.016 w
.1029 .30572 m
.10333 .30524 L
s
1 .539 0 r
.008 w
.10333 .30524 Mdot
.016 w
.10333 .30524 m
.10386 .30449 L
s
1 .533 0 r
.008 w
.10386 .30449 Mdot
.016 w
.10386 .30449 m
.10454 .30339 L
s
1 .527 0 r
.008 w
.10454 .30339 Mdot
.016 w
.10454 .30339 m
.10539 .3019 L
s
1 .521 0 r
.008 w
.10539 .3019 Mdot
.016 w
.10539 .3019 m
.10643 .30015 L
s
1 .515 0 r
.008 w
.10643 .30015 Mdot
.016 w
.10643 .30015 m
.10752 .29802 L
s
1 .509 0 r
.008 w
.10752 .29802 Mdot
.016 w
.10752 .29802 m
.10892 .29582 L
s
1 .503 0 r
.008 w
.10892 .29582 Mdot
.016 w
.10892 .29582 m
.11039 .29324 L
s
1 .497 0 r
.008 w
.11039 .29324 Mdot
.016 w
.11039 .29324 m
.11209 .2902 L
s
1 .491 0 r
.008 w
.11209 .2902 Mdot
.016 w
.11209 .2902 m
.11384 .28711 L
s
1 .485 0 r
.008 w
.11384 .28711 Mdot
.016 w
.11384 .28711 m
.11574 .28413 L
s
1 .479 0 r
.008 w
.11574 .28413 Mdot
.016 w
.11574 .28413 m
.11752 .28085 L
s
1 .473 0 r
.008 w
.11752 .28085 Mdot
.016 w
.11752 .28085 m
.11941 .2775 L
s
1 .467 0 r
.008 w
.11941 .2775 Mdot
.016 w
.11941 .2775 m
.12129 .27414 L
s
1 .461 0 r
.008 w
.12129 .27414 Mdot
.016 w
.12129 .27414 m
.12307 .27098 L
s
1 .455 0 r
.008 w
.12307 .27098 Mdot
.016 w
.12307 .27098 m
.1249 .26778 L
s
1 .448 0 r
.008 w
.1249 .26778 Mdot
.016 w
.1249 .26778 m
.12671 .2647 L
s
1 .442 0 r
.008 w
.12671 .2647 Mdot
.016 w
.12671 .2647 m
.12853 .26157 L
s
1 .436 0 r
.008 w
.12853 .26157 Mdot
.016 w
.12853 .26157 m
.13049 .25844 L
s
1 .43 0 r
.008 w
.13049 .25844 Mdot
.016 w
.13049 .25844 m
.1324 .25523 L
s
1 .424 0 r
.008 w
.1324 .25523 Mdot
.016 w
.1324 .25523 m
.13444 .25188 L
s
1 .418 0 r
.008 w
.13444 .25188 Mdot
.016 w
.13444 .25188 m
.13649 .24866 L
s
1 .412 0 r
.008 w
.13649 .24866 Mdot
.016 w
.13649 .24866 m
.1386 .24501 L
s
1 .406 0 r
.008 w
.1386 .24501 Mdot
.016 w
.1386 .24501 m
.14076 .24164 L
s
1 .4 0 r
.008 w
.14076 .24164 Mdot
.016 w
.14076 .24164 m
.14299 .23805 L
s
1 .394 0 r
.008 w
.14299 .23805 Mdot
.016 w
.14299 .23805 m
.14531 .23434 L
s
1 .388 0 r
.008 w
.14531 .23434 Mdot
.016 w
.14531 .23434 m
.1475 .23089 L
s
1 .382 0 r
.008 w
.1475 .23089 Mdot
.016 w
.1475 .23089 m
.14976 .22731 L
s
1 .376 0 r
.008 w
.14976 .22731 Mdot
.016 w
.14976 .22731 m
.15224 .22351 L
s
1 .37 0 r
.008 w
.15224 .22351 Mdot
.016 w
.15224 .22351 m
.15436 .22016 L
s
1 .364 0 r
.008 w
.15436 .22016 Mdot
.016 w
.15436 .22016 m
.15671 .21649 L
s
1 .358 0 r
.008 w
.15671 .21649 Mdot
.016 w
.15671 .21649 m
.15906 .21276 L
s
1 .352 0 r
.008 w
.15906 .21276 Mdot
.016 w
.15906 .21276 m
.16165 .20913 L
s
1 .345 0 r
.008 w
.16165 .20913 Mdot
.016 w
.16165 .20913 m
.1639 .20533 L
s
1 .339 0 r
.008 w
.1639 .20533 Mdot
.016 w
.1639 .20533 m
.16633 .2017 L
s
1 .333 0 r
.008 w
.16633 .2017 Mdot
.016 w
.16633 .2017 m
.16879 .1981 L
s
1 .327 0 r
.008 w
.16879 .1981 Mdot
.016 w
.16879 .1981 m
.17113 .19446 L
s
1 .321 0 r
.008 w
.17113 .19446 Mdot
.016 w
.17113 .19446 m
.17346 .19099 L
s
1 .315 0 r
.008 w
.17346 .19099 Mdot
.016 w
.17346 .19099 m
.17579 .18749 L
s
1 .309 0 r
.008 w
.17579 .18749 Mdot
.016 w
.17579 .18749 m
.17798 .18398 L
s
1 .303 0 r
.008 w
.17798 .18398 Mdot
.016 w
.17798 .18398 m
.17999 .18071 L
s
1 .297 0 r
.008 w
.17999 .18071 Mdot
.016 w
.17999 .18071 m
.18202 .17732 L
s
1 .291 0 r
.008 w
.18202 .17732 Mdot
.016 w
.18202 .17732 m
.18397 .1738 L
s
1 .285 0 r
.008 w
.18397 .1738 Mdot
.016 w
.18397 .1738 m
.18584 .17083 L
s
1 .279 0 r
.008 w
.18584 .17083 Mdot
.016 w
.18584 .17083 m
.18755 .16781 L
s
1 .273 0 r
.008 w
.18755 .16781 Mdot
.016 w
.18755 .16781 m
.18925 .16488 L
s
1 .267 0 r
.008 w
.18925 .16488 Mdot
.016 w
.18925 .16488 m
.19079 .16256 L
s
1 .261 0 r
.008 w
.19079 .16256 Mdot
.016 w
.19079 .16256 m
.19232 .16023 L
s
1 .255 0 r
.008 w
.19232 .16023 Mdot
.016 w
.19232 .16023 m
.19363 .15828 L
s
1 .248 0 r
.008 w
.19363 .15828 Mdot
.016 w
.19363 .15828 m
.19484 .15646 L
s
1 .242 0 r
.008 w
.19484 .15646 Mdot
.016 w
.19484 .15646 m
.19604 .15493 L
s
1 .236 0 r
.008 w
.19604 .15493 Mdot
.016 w
.19604 .15493 m
.197 .15367 L
s
1 .23 0 r
.008 w
.197 .15367 Mdot
.016 w
.197 .15367 m
.19786 .15264 L
s
1 .224 0 r
.008 w
.19786 .15264 Mdot
.016 w
.19786 .15264 m
.19859 .15187 L
s
1 .218 0 r
.008 w
.19859 .15187 Mdot
.016 w
.19859 .15187 m
.19917 .15136 L
s
1 .212 0 r
.008 w
.19917 .15136 Mdot
.016 w
.19917 .15136 m
.19957 .1511 L
s
1 .206 0 r
.008 w
.19957 .1511 Mdot
.016 w
.19957 .1511 m
.19978 .15106 L
s
1 .2 0 r
.008 w
.19978 .15106 Mdot
.016 w
.19978 .15106 m
.19982 .15116 L
s
1 .194 0 r
.008 w
.19982 .15116 Mdot
.016 w
.19982 .15116 m
.19975 .15133 L
s
1 .188 0 r
.008 w
.19975 .15133 Mdot
.016 w
.19975 .15133 m
.19964 .15145 L
s
1 .182 0 r
.008 w
.19964 .15145 Mdot
.016 w
.19964 .15145 m
.19956 .15143 L
s
1 .176 0 r
.008 w
.19956 .15143 Mdot
.016 w
.19956 .15143 m
.1996 .15123 L
s
1 .17 0 r
.008 w
.1996 .15123 Mdot
.016 w
.1996 .15123 m
.19979 .1508 L
s
1 .164 0 r
.008 w
.19979 .1508 Mdot
.016 w
.19979 .1508 m
.20016 .15014 L
s
1 .158 0 r
.008 w
.20016 .15014 Mdot
.016 w
.20016 .15014 m
.20073 .14926 L
s
1 .152 0 r
.008 w
.20073 .14926 Mdot
.016 w
.20073 .14926 m
.20149 .14819 L
s
1 .145 0 r
.008 w
.20149 .14819 Mdot
.016 w
.20149 .14819 m
.20247 .14694 L
s
1 .139 0 r
.008 w
.20247 .14694 Mdot
.016 w
.20247 .14694 m
.20371 .1455 L
s
1 .133 0 r
.008 w
.20371 .1455 Mdot
.016 w
.20371 .1455 m
.20515 .14393 L
s
1 .127 0 r
.008 w
.20515 .14393 Mdot
.016 w
.20515 .14393 m
.20678 .14223 L
s
1 .121 0 r
.008 w
.20678 .14223 Mdot
.016 w
.20678 .14223 m
.20874 .14038 L
s
1 .115 0 r
.008 w
.20874 .14038 Mdot
.016 w
.20874 .14038 m
.21096 .13837 L
s
1 .109 0 r
.008 w
.21096 .13837 Mdot
.016 w
.21096 .13837 m
.21312 .13637 L
s
1 .103 0 r
.008 w
.21312 .13637 Mdot
.016 w
.21312 .13637 m
.2157 .13425 L
s
1 .097 0 r
.008 w
.2157 .13425 Mdot
.016 w
.2157 .13425 m
.21838 .13218 L
s
1 .091 0 r
.008 w
.21838 .13218 Mdot
.016 w
.21838 .13218 m
.22103 .13014 L
s
1 .085 0 r
.008 w
.22103 .13014 Mdot
.016 w
.22103 .13014 m
.22393 .12818 L
s
1 .079 0 r
.008 w
.22393 .12818 Mdot
.016 w
.22393 .12818 m
.22664 .1263 L
s
1 .073 0 r
.008 w
.22664 .1263 Mdot
.016 w
.22664 .1263 m
.22936 .12468 L
s
1 .067 0 r
.008 w
.22936 .12468 Mdot
.016 w
.22936 .12468 m
.23195 .12312 L
s
1 .061 0 r
.008 w
.23195 .12312 Mdot
.016 w
.23195 .12312 m
.2343 .12185 L
s
1 .055 0 r
.008 w
.2343 .12185 Mdot
.016 w
.2343 .12185 m
.23642 .12069 L
s
1 .048 0 r
.008 w
.23642 .12069 Mdot
.016 w
.23642 .12069 m
.23828 .11976 L
s
1 .042 0 r
.008 w
.23828 .11976 Mdot
.016 w
.23828 .11976 m
.23985 .11901 L
s
1 .036 0 r
.008 w
.23985 .11901 Mdot
.016 w
.23985 .11901 m
.24105 .11846 L
s
1 .03 0 r
.008 w
.24105 .11846 Mdot
.016 w
.24105 .11846 m
.242 .11811 L
s
1 .024 0 r
.008 w
.242 .11811 Mdot
.016 w
.242 .11811 m
.24272 .11794 L
s
1 .018 0 r
.008 w
.24272 .11794 Mdot
.016 w
.24272 .11794 m
.24322 .1179 L
s
1 .012 0 r
.008 w
.24322 .1179 Mdot
.016 w
.24322 .1179 m
.24355 .11796 L
s
1 .006 0 r
.008 w
.24355 .11796 Mdot
.016 w
.24355 .11796 m
.24375 .11809 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00KGoo13g_0Woo83g_47oo1P00Mgoo001YOol[?NlEOol5001bOol006MoobhmkaUo
o`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0069ooc<mkbAoo`<006Aoo`00
H7oo7cg_1goo23g_;Woo0`00HGoo001NOolB?Nl00goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005ao
oa8mk`Eoo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl02cg_Fgoo0P00Fgoo001HOol0
0`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00Dgoo0P000Woo2cg_J7oo0P00
E7oo001AOol2000<?Nm]Ool2001BOol0051oo`03001oogoo00`mkfmoo`03001oogoo04moo`00Cgoo
00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool200000goo?Nlmk`0<?NmbOol2001>Ool004]o
o`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P0000=oocg_?Nl033g_NWoo0P00BWoo0018Ool0
0`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`800003Oolmkcg_00lmkgeoo`8004Moo`00AGoo
00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool00`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool0
04=oo`03000mkg`P00El00XmkhIoo`03001oogoo049oo`00@Goo0P000g`P1G`023g_RGoo0P00@Woo
0010Ool00`00Ooml@003O205O008?Nn;Ool00`00Oomoo`0oOol003moo`04001l@7a0O403O205O000
0cg_Oomoo`2AOol2000oOol003ioo`03001lH7a0009l@0Il808mkiIoo`03001oogoo03aoo`00?7oo
0P000WaP1ga00cg_V7oo00<007ooOol0>goo000kOol00`00OomlH002O605O404?NnJOol00`00Oomo
o`0jOol003Yoo`03000mkgaP00=lH0Al@0@mkiaoo`8003Yoo`00>Goo00<003g_O8001GaP1Cg_X7oo
00<007ooOol0=goo000gOol2000017ooO<1lP7b00gaP1Sg_XGoo00<007ooOol0=Woo000fOol01P00
OomoogcPO<1lX09lP004O60mkcg_?NnVOol00`00Oomoo`0eOol003Eoo`06001oogoo?Nmlh7c00WbP
00=lP7bP?Nl00Sg_Ygoo00<007ooOol0=7oo000dOol01`00OomoogooO@1lh7c000AlX08mkjUoo`03
001oogoo03=oo`00<Woo0P000goo00<mkgd0O>0017cP0cg_ZWoo00<007ooOol0<Woo000aOol00`00
Oomoo`02Ool00cg_O@1m0004O>04?Nn[Ool00`00Oomoo`0aOol0031oo`03001oogoo009oo`03?Nmm
87d000Am00Dmkjaoo`03001oogoo031oo`00<7oo00<007ooOol00Woo00<mkgdPOB0017d013g_[Woo
00<007ooOol0;goo000_Ool00`00Oomoo`02Ool00cg_OB1m8002OB000gd0OB0mk`02?NnaOol00`00
Oomoo`0^Ool002ioo`03001oogoo00=oo`03?Nmm87dP00=m80@mkk9oo`03001oogoo02eoo`00;Goo
00<007ooOol017oo1WdP13g_/goo00<007ooOol0;7oo000/Ool00`00Oomoo`04Ool00ge0OB1m8003
OB04?NneOol00`00Oomoo`0[Ool002aoo`03001oogoo00=oo`03?Nmm@7e000Am80<mkkIoo`03001o
ogoo02]oo`00:goo00<007ooOol017oo17e000=m87e0?Nl00cg_]goo00<007ooOol0:Woo000ZOol0
0`00Oomoo`04Ool6OD2mOol00`00Oomoo`0YOol002Uoo`03001oogoo00Aoo`03?Nmm@7e000Am@;io
o`03001oogoo02Qoo`00:7oo00<007ooOol017oo00<mkgePOD000ge000=mH7ooOol0_Woo00<007oo
Ool09goo000XOol00`00Oomoo`04Ool2OF04OD31Ool00`00Oomoo`0WOol002Moo`03001oogoo00Ao
o`03?NmmH7eP00Am@<9oo`03001oogoo02Ioo`009Woo00<007ooOol01Goo1WeP0Sg_`Woo00<007oo
Ool09Goo000UOol00`00Oomoo`05Ool00cg_OF1mH003OF03?No3Ool00`00Oomoo`0TOol002Aoo`03
001oogoo00Ioo`03OH1mH7eP00=mH08mklEoo`03001oogoo02=oo`0097oo00<007ooOol01Goo0Wf0
17eP0Sg_aWoo00<007ooOol08goo000SOol00`00Oomoo`05Ool00cg_OH1mP004OF000cg_Oomoo`36
Ool00`00Oomoo`0ROol0029oo`03001oogoo00Eoo`03?NmmP7f000AmP08mklUoo`03001oogoo025o
o`008Woo00<007ooOol01Goo1Wf00cg_bGoo00<007ooOol08Goo000QOol00`00Oomoo`05Ool00cg_
OH1mP004OH02?No;Ool00`00Oomoo`0POol0021oo`03001oogoo00Ioo`03OJ1mP7f0009mP003OJ0m
kcg_0<eoo`03001oogoo01moo`0087oo00<007ooOol01Goo00<mkgfPOH000gf000<mkgooOol0cGoo
00<007ooOol07goo000OOol00`00Oomoo`06Ool2OJ04OH3AOol00`00Oomoo`0NOol001moo`03001o
ogoo00Eoo`ImX003?Nmoogoo0=1oo`03001oogoo01eoo`007Woo00<007ooOol01Woo1WfP00<mkgoo
Ool0d7oo00<007ooOol07Goo000MOol00`00Oomoo`06Ool2OL03OJ000gg0?Nlmk`3COol00`00Oomo
o`0LOol001eoo`03001oogoo00Eoo`06?Nmm`7g0OL1mX7g00cg_dgoo00<007ooOol077oo000LOol0
0`00Oomoo`06Ool6OL02?NoEOol00`00Oomoo`0KOol001aoo`03001oogoo00Eoo`03?Nmm`7g000=m
`0<mkmEoo`03001oogoo01]oo`006goo00<007ooOol01Woo00=mh7g0OL000gg00cg_eWoo00<007oo
Ool06Woo000KOol00`00Oomoo`05Ool2ON04OL03?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo
00Eoo`=mh0Am`0<mkmQoo`03001oogoo01Uoo`006Woo00<007ooOol01Goo1GgP13g_fGoo00<007oo
Ool06Goo000IOol00`00Oomoo`05Ool00gh0ON1mh002ON04?NoKOol00`00Oomoo`0HOol001Uoo`03
001oogoo00Eoo`03OP1mh7gP009mh0<mkmaoo`03001oogoo01Qoo`0067oo00<007ooOol01Goo0Wh0
17gP0Sg_gWoo00<007ooOol05goo000HOol00`00Oomoo`04Ool00giPOP1n0004OP000cg_Oomoo`3M
Ool00`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`03OV1n87h000=n008mkmmoo`03001oogoo01Mo
o`005goo00<007ooOol017oo00HmkgiPOR1n87h0OR03?NoPOol00`00Oomoo`0FOol001Moo`03001o
ogoo00Aoo`03O^1nH7hP00=n808mkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo00=nh7j0
OX000Wj00cg_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool00gkPO/1n`002O/000cg_Oomo
o`3ROol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`Anh08mknEoo`03001oogoo01Aoo`005Goo
00<007ooOol01Goo00=o07kPO^000WkP00=o03g_Ool0i7oo00<007ooOol057oo000EOol00`00Oomo
o`05Ool00gl0O^1nh002O^02?NoUOol00`00Oomoo`0DOol001Aoo`03001oogoo00Ioo`03O`1nh7kP
009nh003?Nmoogoo0>Eoo`03001oogoo01=oo`0057oo00<007ooOol01Woo17l00Sg_igoo00<007oo
Ool04goo000DOol00`00Oomoo`05Ool00cg_O`1o0002O`02?NoWOol00`00Oomoo`0COol001=oo`03
001oogoo00Ioo`03?Nmo07l0009o0003?Nmoogoo0>Moo`03001oogoo019oo`004goo00<007ooOol0
1Woo00=o87l0O`000Wl000=o87ooOol0igoo00<007ooOol04Woo000COol00`00Oomoo`06Ool00glP
O`1o0002O`000cg_Oomoo`3WOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`03Ob1o07l0009o
0>]oo`03001oogoo015oo`004Woo00<007ooOol01goo17lP00<mkgooOol0jGoo00<007ooOol04Goo
000BOol00`00Oomoo`06Ool00cg_Ob1o8002Ob3/Ool00`00Oomoo`0AOol0015oo`03001oogoo00Mo
o`03?Nmo87lP009o8>eoo`03001oogoo011oo`004Goo00<007ooOol01goo00<mkglPOb000WlPkGoo
00<007ooOol047oo000AOol00`00Oomoo`07Ool00cg_Ob1o8002Ob000cg_Oomoo`3ZOol00`00Oomo
o`0@Ool0015oo`03001oogoo00Moo`03?Nmo87lP009o8003?Nmoogoo0>]oo`03001oogoo00moo`00
47oo00<007ooOol027oo00=o@7lPOb000WlP00=o@7ooOol0jgoo00<007ooOol03goo000@Ool00`00
Oomoo`08Ool5Od3^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Eo@>ioo`03001oogoo00mo
o`0047oo00<007ooOol027oo17m000<mkgooOol0k7oo00<007ooOol03goo000?Ool00`00Oomoo`09
Ool4Od02?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`AoH003Ol0mkcg_0>eoo`03001o
ogoo00ioo`003goo00<007ooOol02Goo17mP00=o`3g_?Nl0kGoo00<007ooOol03Woo000?Ool00`00
Oomoo`09Ool4Of000go0?Nlmk`3]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`AoX004Ol0m
kcg_?No/Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`03?Nmo`7o0009o`0@mknaoo`03001o
ogoo00eoo`003Woo00<007ooOol02Woo00<mkgoPOn000WoP1cg_jGoo00<007ooOol03Goo000>Ool0
0`00Oomoo`0<Ool:?NoYOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`/mknMoo`03001oogoo
00eoo`003Woo00<007ooOol03Goo33g_igoo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool=?NoV
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03001oogoo00aoo`003Goo00<007oo
Ool03Goo3Sg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool??NoUOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00eoo`lmknEoo`03001oogoo00aoo`003Goo00<007ooOol037oo4Cg_i7oo00<0
07ooOol037oo000=Ool00`00Oomoo`0;OolB?NoTOol00`00Oomoo`0<Ool000eoo`03001oogoo00Uo
oaDmkn=oo`03001oogoo00aoo`003Goo00<007ooOol027oo63g_hGoo00<007ooOol037oo000=Ool0
0`00Oomoo`08OolM?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qooahmkm]oo`03001oogoo
00aoo`0037oo00<007ooOol027oo7cg_g7oo00<007ooOol02goo000<Ool00`00Oomoo`07Ool;?Nl4
Ool5?Nl00goo?Nlmk`09?NoLOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioob4mkmaoo`03001o
ogoo00]oo`0037oo00<007ooOol01Goo8Cg_gGoo00<007ooOol02goo000<Ool00`00Oomoo`08OolE
?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`03Oolmkcg_00`mknIoo`03001oogoo
00]oo`0037oo00<007ooOol027oo1Sg_1Woo2Cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08
Ool6?Nl:Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001o
ogoo00]oo`0037oo00<007ooOol01goo1cg_2goo1Sg_i7oo00<007ooOol02goo000<Ool00`00Oomo
o`07Ool5?Nl<Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dmk`aoo`Tmkn9oo`03
001oogoo00]oo`0037oo00<007ooOol01goo1Cg_37oo2Sg_hGoo00<007ooOol02goo000<Ool00`00
Oomoo`07Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000eoo`03001oogoo00Ioo`Dmk`aoo`/mkn1o
o`03001oogoo00]oo`003Goo00<007ooOol01Woo1Cg_47oo1cg_ggoo00<007ooOol037oo000=Ool0
0`00Oomoo`06Ool5?Nl@Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pm
kmioo`03001oogoo00aoo`003Goo00<007ooOol01Woo1Sg_3goo23g_gWoo00<007ooOol037oo000=
Ool00`00Oomoo`06Ool6?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka1o
o`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_gGoo00<007ooOol037oo
000=Ool00`00Oomoo`07Ool5?Nl@Ool9?NoLOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dm
ka1oo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_4Goo2Sg_fWoo00<007ooOol0
37oo000=Ool00`00Oomoo`07Ool5?NlBOol9?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo00Io
o`Hmka9oo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_4Woo1Cg_g7oo00<007oo
Ool03Goo000>Ool00`00Oomoo`07Ool5?NocOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Hm
ko9oo`03001oogoo00eoo`003goo00<007ooOol01Woo1Sg_lWoo00<007ooOol03Goo000?Ool00`00
Oomoo`07Ool6?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00io
o`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool0
0`00Oomoo`0>Ool0011oo`03001oogoo00Ioo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol0
1Woo1Sg_kgoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0011o
o`03001oogoo00Ioo`Hmknmoo`03001oogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007oo
Ool03goo000AOol00`00Oomoo`05Ool6?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Ioo`Hm
kneoo`03001oogoo011oo`004Goo00<007ooOol01Woo1Cg_kWoo00<007ooOol047oo000BOol00`00
Oomoo`05Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Dmkneoo`03001oogoo015o
o`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000COol00`00Oomoo`05Ool4?No]Ool0
0`00Oomoo`0AOol001=oo`03001oogoo00Eoo`Dmkn]oo`03001oogoo019oo`004goo00<007ooOol0
1Goo1Cg_jgoo00<007ooOol04Woo000DOol00`00Oomoo`04Ool5?NoJOol00cg_Oomoo`0>Ool00`00
Oomoo`0BOol001Aoo`03001oogoo00Aoo`HmkmUoo`8mk`ioo`03001oogoo01=oo`0057oo00<007oo
Ool017oo1Sg_fGoo0cg_3Goo00<007ooOol04goo000EOol00`00Oomoo`03Ool6?NoIOol4?Nl<Ool0
0`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hmkm9oo``mk`Yoo`03001oogoo01Aoo`005Goo00<0
07ooOol00goo1Sg_dgoo2cg_2Woo00<007ooOol057oo000EOol00`00Oomoo`04Ool5?NoDOol:?Nl:
Ool00`00Oomoo`0DOol001Ioo`03001oogoo00=oo`DmkmEoo`Tmk`Uoo`03001oogoo01Eoo`005Woo
00<007ooOol00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000GOol00`00Oomoo`02Ool5?NoEOol8
?Nl9Ool00`00Oomoo`0FOol001Moo`03001oogoo009oo`HmkmAoo`Pmk`Uoo`03001oogoo01Ioo`00
67oo00@007ooOomoo`HmkmAoo`Pmk`Qoo`03001oogoo01Moo`0067oo00@007ooOomoo`Hmkm=oo`Tm
k`Qoo`03001oogoo01Moo`006Goo00@007ooOomoo`Hmkm1oo`/mk`Qoo`03001oogoo01Moo`006Goo
00@007ooOomoo`Lmklioo`/mk`Qoo`03001oogoo01Qoo`006Woo00<007ooOol01cg_cGoo33g_27oo
00<007ooOol067oo000JOol01000Oomoogoo1cg_bGoo3Sg_27oo00<007ooOol06Goo000KOol00`00
Oomoo`08?No6Ool@?Nl7Ool00`00Oomoo`0JOol001]oo`03001oogoo00TmklEooa0mk`Moo`03001o
ogoo01Yoo`0077oo00<007oo?Nl02Cg_a7oo43g_1Woo00<007ooOol06goo000LOol00`00Oomoo`0:
?No3Ool6?Nl3Ool6?Nl7Ool00`00Oomoo`0KOol001eoo`03001oocg_00Tmkl9oo`Dmk`Eoo`Hmk`Io
o`03001oogoo01aoo`007Goo00<007oo?Nl02Sg_`Goo1Cg_1Goo1Sg_1Woo00<007ooOol077oo000N
Ool00`00?Nlmk`09?No1Ool5?Nl5Ool5?Nl6Ool00`00Oomoo`0MOol001ioo`03000mkcg_00Tmkl5o
o`Dmk`Eoo`Dmk`Ioo`03001oogoo01eoo`007goo2cg_`Goo13g_1Goo1Sg_1Goo00<007ooOol07Woo
000OOol00`00?Nlmk`09?NnoOol5?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol0021oo`03000mkcg_00Pm
kkmoo`Dmk`Aoo`Hmk`Eoo`03001oogoo01moo`0087oo00<003g_?Nl02Cg__Goo1Cg_1Goo1Sg_1Goo
00<007ooOol07goo000QOol;?NnmOol5?Nl5Ool6?Nl4Ool00`00Oomoo`0POol0029oo`03000mkcg_
00Pmkkaoo`Dmk`Aoo`Lmk`=oo`03001oogoo025oo`008goo2Sg_^goo1Sg_17oo1Sg_0goo00<007oo
Ool08Woo000TOol:?NnjOol5?Nl5Ool6?Nl2Ool00`00Oomoo`0SOol002Aoo`03000mkcg_00LmkkYo
o`@mk`Eoo`Lmk`9oo`03001oogoo02=oo`009Goo2Sg_^7oo1Cg_1Goo1Cg_0goo00<007ooOol097oo
000VOol00`00?Nlmk`07?NnfOol6?Nl4Ool7?Nl00goo001oo`0VOol002Ioo`03001oocg_00/mkk9o
o`Dmk`Aoo`Lmk`9oo`03001oogoo02Eoo`009goo00<007oo?Nl02Sg_/Woo1Cg_0goo23g_00=oo`00
Ool09goo000XOol00`00Oolmk`09?NnaOol6?Nl2Ool8?Nl00goo001oo`0XOol002Uoo`03001oocg_
00Tmkk1oo`Dmk`9oo`Pmk`03Ool007oo02Uoo`00:Woo00<007oo?Nl023g_/7oo13g_0Woo2Cg_00<0
07ooOol0:Goo000ZOol00`00Oomoo`09?Nn^Ool5?Nl2Ool9?Nl00`00Oomoo`0YOol002]oo`03001o
ogoo00Tmkjeoo`Dmk`9oo`Pmk`03001oogoo02Yoo`00;7oo00<007oo?Nl023g_[7oo1Cg_00=oocg_
?Nl01cg_00<007ooOol0:goo000]Ool00`00Oolmk`08?Nn[Ool5?Nl00goo?Nlmk`06?Nl00`00Oomo
o`0/Ool002ioo`03001oogoo00TmkjUoo`dmk`03001oogoo02eoo`00;Woo00@007ooOomoo`TmkjQo
o`Xmk`=oo`03001oogoo02eoo`00;goo00@007ooOomoo`XmkjEoo`Xmk`=oo`03001oogoo02ioo`00
<7oo00@007ooOomoo`XmkjAoo`Tmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo``mkj1oo`Pm
k`Aoo`03001oogoo031oo`00<Woo0P000Woo3Cg_W7oo2Cg_0goo0P00<goo000dOol00`00Oomoo`0<
?NnJOol:?Nl3Ool00`00Oomoo`0cOol003Eoo`03001oocg_00`mkiQoo`Xmk`=oo`03001oogoo03Ao
o`00=Goo00@007ooOomoo`/mkiIoo``mk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomoo`/mkiAo
o`Xmk`Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo2Cg_U7oo23g_1Woo00<007ooOol0=Woo
000hOol00`00Oomoo`02Ool9?NnBOol9?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pmki5oo`Xm
k`=oo`8003Yoo`00>goo00<007ooOol02Cg_Sgoo2Sg_0goo00<007ooOol0>Woo000lOol00`00Oomo
o`09?Nn=Ool:?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhUoo`Tmk`Eoo`03001oogoo
03aoo`00?Woo0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;?Nl3Ool0
0`00Oomoo`0oOol0045oo`800003Oolmkcg_00Lmkh9oo`Tmk`Aoo`80049oo`00@goo00<007oo?Nl0
2Cg_NWoo3Sg_17oo00<007ooOol0@Woo0014Ool00`00?Nlmk`09?NmiOol=?Nl4Ool00`00Oomoo`13
Ool004Eoo`03000mkcg_00XmkgMoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl02cg_M7oo
33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYoo``mk`9oo`80
04]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomoo`1=Ool004mo
o`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P0000=oocg_?Nl03cg_FGoo00<m
kgooOol02Sg_0goo0P00DGoo001BOol200000goo?Nlmk`0@?NmBOol00cg_Oomoo`0>?Nl00goo0000
001COol005Aoo`800003?Nmoocg_010mk`Moo`Dmkd1ooa<mk`03Ool0000005Eoo`00EWoo0P0017oo
43g_0goo1Sg_?Woo53g_0P00Egoo001HOol30004OolF?NllOolE?Nl00`00Oomoo`1GOol005]oo`<0
00=ooa@mkcUooa@mk`8005aoo`00GWoo0P0017oo4Sg_=7oo63g_GWoo001POol20004OolG?NlTOolN
?NmQOol0069oo`<000Aooa@mka1oo`8mk`eoob0mk`03001oogoo065oo`00IGoo0`001Goo9Sg_0Woo
8Sg_0`00IWoo001XOol40003Oom4?Nl01000?Nl00000JGoo001/Ool40003Oolk?Nl00goo00000002
001]Ool0071oo`<000=ooc0mk`Eoo`@0075oo`00Lgoo1@0000=oocg_?Nl09Cg_1goo1000MGoo001h
Ool4000M?Nl7Ool7001iOol007iooa0mk`Aoo`h0081oo`00SGoo1@00SWoo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002:Ool30004Ool2002=Ool008aoo`05001oogooOol00002Ool0
0`00Oomoo`2:Ool008]oo`<0009oo`04001oogoo002<Ool008Yoo`04001oogoo0003Ool2002=Ool0
08Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002;Ool30003Ool2002=Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(99)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
.08243 .46962 m
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
Mistroke
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
Mistroke
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
Mistroke
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
Mfstroke
.07656 .49788 m
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
Mistroke
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
Mfstroke
.08794 .46459 m
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
s
.08955 .41166 m
.08937 .41149 L
.08908 .41118 L
.08868 .41073 L
.08821 .41015 L
.08771 .40943 L
.0872 .4086 L
.08671 .4078 L
.08625 .40694 L
.08578 .40606 L
.0853 .40516 L
.08486 .40443 L
.0845 .4038 L
.08425 .40328 L
.08409 .40289 L
.084 .40259 L
.08399 .40236 L
.08407 .40215 L
.0842 .40189 L
.08434 .40146 L
.0845 .40079 L
.08468 .39986 L
.08488 .39859 L
.08512 .39692 L
.08539 .39515 L
.08568 .39276 L
.08601 .39019 L
.08637 .3874 L
.08678 .38417 L
.08722 .38054 L
.08769 .37667 L
.08815 .37239 L
.08863 .36874 L
.08911 .36398 L
.08963 .36015 L
.0902 .35568 L
.09085 .351 L
.09157 .34648 L
.09229 .34188 L
.09304 .33794 L
.09381 .33363 L
.09457 .33014 L
.09523 .32673 L
.09598 .32352 L
.09662 .32057 L
.09724 .31839 L
.09785 .31632 L
.09843 .31466 L
.09894 .31324 L
.09937 .31212 L
Mistroke
.09972 .31147 L
.09999 .31095 L
.1002 .31061 L
.10036 .3104 L
.10049 .31032 L
.10059 .31026 L
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
.10062 .30982 L
.10056 .30963 L
.10053 .30937 L
.10055 .30906 L
.10063 .30868 L
.10078 .30827 L
.10096 .30785 L
.10118 .30744 L
.1014 .30709 L
.10158 .3068 L
.10172 .30662 L
.10187 .30646 L
.10204 .30632 L
.10227 .3062 L
.10255 .30602 L
.1029 .30572 L
.10333 .30524 L
.10386 .30449 L
.10454 .30339 L
.10539 .3019 L
.10643 .30015 L
.10752 .29802 L
.10892 .29582 L
.11039 .29324 L
.11209 .2902 L
.11384 .28711 L
.11574 .28413 L
.11752 .28085 L
.11941 .2775 L
.12129 .27414 L
.12307 .27098 L
.1249 .26778 L
.12671 .2647 L
.12853 .26157 L
.13049 .25844 L
.1324 .25523 L
.13444 .25188 L
.13649 .24866 L
.1386 .24501 L
.14076 .24164 L
.14299 .23805 L
Mistroke
.14531 .23434 L
.1475 .23089 L
.14976 .22731 L
.15224 .22351 L
.15436 .22016 L
.15671 .21649 L
.15906 .21276 L
.16165 .20913 L
.1639 .20533 L
.16633 .2017 L
.16879 .1981 L
.17113 .19446 L
.17346 .19099 L
.17579 .18749 L
.17798 .18398 L
.17999 .18071 L
.18202 .17732 L
.18397 .1738 L
.18584 .17083 L
.18755 .16781 L
.18925 .16488 L
.19079 .16256 L
.19232 .16023 L
.19363 .15828 L
.19484 .15646 L
.19604 .15493 L
.197 .15367 L
.19786 .15264 L
.19859 .15187 L
.19917 .15136 L
.19957 .1511 L
.19978 .15106 L
.19982 .15116 L
.19975 .15133 L
.19964 .15145 L
.19956 .15143 L
.1996 .15123 L
.19979 .1508 L
.20016 .15014 L
.20073 .14926 L
.20149 .14819 L
.20247 .14694 L
.20371 .1455 L
.20515 .14393 L
.20678 .14223 L
.20874 .14038 L
.21096 .13837 L
.21312 .13637 L
.2157 .13425 L
.21838 .13218 L
Mistroke
.22103 .13014 L
.22393 .12818 L
.22664 .1263 L
.22936 .12468 L
.23195 .12312 L
.2343 .12185 L
.23642 .12069 L
.23828 .11976 L
.23985 .11901 L
.24105 .11846 L
.242 .11811 L
.24272 .11794 L
.24322 .1179 L
.24355 .11796 L
.24375 .11809 L
Mfstroke
1 .98 0 r
.008 w
.24411 .11892 Mdot
.016 w
.24411 .11892 m
.24425 .11881 L
s
1 .96 0 r
.008 w
.24425 .11881 Mdot
.016 w
.24425 .11881 m
.24447 .11856 L
s
1 .94 0 r
.008 w
.24447 .11856 Mdot
.016 w
.24447 .11856 m
.24481 .11814 L
s
1 .92 0 r
.008 w
.24481 .11814 Mdot
.016 w
.24481 .11814 m
.24533 .11754 L
s
1 .9 0 r
.008 w
.24533 .11754 Mdot
.016 w
.24533 .11754 m
.24608 .11676 L
s
1 .88 0 r
.008 w
.24608 .11676 Mdot
.016 w
.24608 .11676 m
.2471 .1158 L
s
1 .86 0 r
.008 w
.2471 .1158 Mdot
.016 w
.2471 .1158 m
.24843 .11478 L
s
1 .84 0 r
.008 w
.24843 .11478 Mdot
.016 w
.24843 .11478 m
.24997 .11356 L
s
1 .82 0 r
.008 w
.24997 .11356 Mdot
.016 w
.24997 .11356 m
.25179 .11211 L
s
1 .8 0 r
.008 w
.25179 .11211 Mdot
.016 w
.25179 .11211 m
.25405 .11064 L
s
1 .78 0 r
.008 w
.25405 .11064 Mdot
.016 w
.25405 .11064 m
.25651 .10894 L
s
1 .76 0 r
.008 w
.25651 .10894 Mdot
.016 w
.25651 .10894 m
.25932 .10708 L
s
1 .74 0 r
.008 w
.25932 .10708 Mdot
.016 w
.25932 .10708 m
.2627 .10514 L
s
1 .72 0 r
.008 w
.2627 .10514 Mdot
.016 w
.2627 .10514 m
.26561 .10319 L
s
1 .7 0 r
.008 w
.26561 .10319 Mdot
.016 w
.26561 .10319 m
.26893 .10107 L
s
1 .68 0 r
.008 w
.26893 .10107 Mdot
.016 w
.26893 .10107 m
.27257 .09909 L
s
1 .66 0 r
.008 w
.27257 .09909 Mdot
.016 w
.27257 .09909 m
.27569 .09696 L
s
1 .64 0 r
.008 w
.27569 .09696 Mdot
.016 w
.27569 .09696 m
.27906 .09495 L
s
1 .62 0 r
.008 w
.27906 .09495 Mdot
.016 w
.27906 .09495 m
.28232 .09285 L
s
1 .6 0 r
.008 w
.28232 .09285 Mdot
.016 w
.28232 .09285 m
.28565 .09059 L
s
1 .58 0 r
.008 w
.28565 .09059 Mdot
.016 w
.28565 .09059 m
.28874 .08849 L
s
1 .56 0 r
.008 w
.28874 .08849 Mdot
.016 w
.28874 .08849 m
.29197 .08615 L
s
1 .54 0 r
.008 w
.29197 .08615 Mdot
.016 w
.29197 .08615 m
.2954 .08397 L
s
1 .52 0 r
.008 w
.2954 .08397 Mdot
.016 w
.2954 .08397 m
.29875 .08165 L
s
1 .5 0 r
.008 w
.29875 .08165 Mdot
.016 w
.29875 .08165 m
.30248 .0792 L
s
1 .48 0 r
.008 w
.30248 .0792 Mdot
.016 w
.30248 .0792 m
.30607 .07692 L
s
1 .46 0 r
.008 w
.30607 .07692 Mdot
.016 w
.30607 .07692 m
.30991 .07448 L
s
1 .44 0 r
.008 w
.30991 .07448 Mdot
.016 w
.30991 .07448 m
.31399 .07207 L
s
1 .42 0 r
.008 w
.31399 .07207 Mdot
.016 w
.31399 .07207 m
.318 .06956 L
s
1 .4 0 r
.008 w
.318 .06956 Mdot
.016 w
.318 .06956 m
.32208 .06703 L
s
1 .38 0 r
.008 w
.32208 .06703 Mdot
.016 w
.32208 .06703 m
.32671 .06433 L
s
1 .36 0 r
.008 w
.32671 .06433 Mdot
.016 w
.32671 .06433 m
.33062 .06172 L
s
1 .34 0 r
.008 w
.33062 .06172 Mdot
.016 w
.33062 .06172 m
.33505 .05898 L
s
1 .32 0 r
.008 w
.33505 .05898 Mdot
.016 w
.33505 .05898 m
.33922 .0563 L
s
1 .3 0 r
.008 w
.33922 .0563 Mdot
.016 w
.33922 .0563 m
.34365 .0536 L
s
1 .28 0 r
.008 w
.34365 .0536 Mdot
.016 w
.34365 .0536 m
.34758 .05118 L
s
1 .26 0 r
.008 w
.34758 .05118 Mdot
.016 w
.34758 .05118 m
.35139 .04886 L
s
1 .24 0 r
.008 w
.35139 .04886 Mdot
.016 w
.35139 .04886 m
.35495 .04663 L
s
1 .22 0 r
.008 w
.35495 .04663 Mdot
.016 w
.35495 .04663 m
.35829 .04472 L
s
1 .2 0 r
.008 w
.35829 .04472 Mdot
.016 w
.35829 .04472 m
.36117 .04318 L
s
1 .18 0 r
.008 w
.36117 .04318 Mdot
.016 w
.36117 .04318 m
.36375 .0418 L
s
1 .16 0 r
.008 w
.36375 .0418 Mdot
.016 w
.36375 .0418 m
.36607 .04063 L
s
1 .14 0 r
.008 w
.36607 .04063 Mdot
.016 w
.36607 .04063 m
.36783 .03972 L
s
1 .12 0 r
.008 w
.36783 .03972 Mdot
.016 w
.36783 .03972 m
.36939 .03905 L
s
1 .1 0 r
.008 w
.36939 .03905 Mdot
.016 w
.36939 .03905 m
.37057 .03862 L
s
1 .08 0 r
.008 w
.37057 .03862 Mdot
.016 w
.37057 .03862 m
.37147 .0384 L
s
1 .06 0 r
.008 w
.37147 .0384 Mdot
.016 w
.37147 .0384 m
.37209 .03831 L
s
1 .04 0 r
.008 w
.37209 .03831 Mdot
.016 w
.37209 .03831 m
.37245 .03834 L
s
1 .02 0 r
.008 w
.37245 .03834 Mdot
.016 w
.37245 .03834 m
.37259 .03844 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Qoo`hm
kaAoo`T007eoo`00JWoo0Wb000=oocg_?Nl00Sg_0Woo83g_47oo1P00Mgoo001XOol00gc0O41l@003
O40V?NlEOol5001bOol006Ioo`03O>1lX7b0009l@003O01l@7a002LmkaUoo`@006ioo`00IGoo00Al
h7c0O:1lP09l@003O01l@7a002Lmkaeoo`@006Yoo`00Hgoo00Am87cPO>1l`09lX0El@2Lmkb5oo`<0
06Moo`00HWoo0Wd00gcP0gbP00=lP7bP?Nl0:3g_97oo0`00I7oo001OOol2OF0017dPO@1m07d00gcP
00=l`7cP?Nl053g_1goo23g_;Woo0`00HGoo001NOol3OD000gdPO@1m0002O@000gcP?Nlmk`07?Nl0
0goo?Nlmk`0:?Nl9Ool4?NleOol2001OOol005aoo`03?NmmH7e000=m@0Em00Lmk`Eoo`03?Nmoogoo
00HmkdEoo`8005eoo`00FWoo00@007g0OH1mH0Em@003OB0mkcg_008mke]oo`8005]oo`00F7oo00<0
03g_OJ000gf01We0HGoo0P00FGoo001EOol300000ggPOL1mX004OH000geP?Nlmk`1UOol3001FOol0
05=oo`80009oo`03ON1m`7g0009mX0=mP0<mkfQoo`8005Aoo`00DGoo0P000Sg_00=n87gPON000Wg0
0gfP00=mP7fPOol0K7oo0P00DWoo001@Ool01P00OomoogiPOR1n00=mh0=m`0<mkfmoo`03001oogoo
04moo`00Cgoo00@007oo?Nmn@09n809n00=mh003OL1mh3g_008mkg1oo`03001oogoo04ioo`00CGoo
0P0000Aoocg_OV1n@0=n809n0003ON0mkcg_00<mkg9oo`8004ioo`00Bgoo0P0000=oocg_OX000WiP
0Wi00ghP00An07hP?NlmkgMoo`8004aoo`00BGoo0P0000Eoocg_O^1nX7j0009nH0=n@003OR1n@3g_
008mkgYoo`8004Yoo`00B7oo00L007oo?Nmo07kPO/1nX002OX03OV06?NmlOol00`00Oomoo`17Ool0
04Ioo`800003Oolmkgl0009nh003O/1nX7j0009nP003OV1nP3g_00Dmkgeoo`8004Moo`00AGoo00@0
07oo?Nlmk`9o00=nh0EnX0Hmkh1oo`03001oogoo04Aoo`00A7oo00D007oo?Nlmkgm000=o00=nh003
O/1nh3g_00@mkhAoo`03001oogoo04=oo`00@goo00D003g_?Nlmkgn0009o@0=o0003O^1o03g_00Dm
khIoo`03001oogoo049oo`00@Goo0P0013g_0Wn00Wm000=o03g_?Nl01Cg_RGoo0P00@Woo0010Ool0
0`00Oolmk`05?Nl2Oh000gm0?Nlmk`06?Nn;Ool00`00Oomoo`0oOol003moo`03000mkcg_00Lmk`03
Oh0mkcg_09=oo`8003moo`00?Woo00<003g_?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnH
Ool00`00Oomoo`0kOol003]oo`03001oocg_00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl0
2cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_
00Xmkj5oo`03001oogoo03Ioo`00=Woo00<007ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00
Oomoo`0:?NnWOol00`00Oomoo`0dOol003Aoo`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039o
o`8000=oo`XmkjYoo`03001oogoo039oo`00<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo
000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03
001oogoo02moo`00;goo00<007ooOol00Woo2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03
Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo
00<007ooOol017oo2Sg_]Goo00<007ooOol0:goo000/Ool00`00Oomoo`03Ool:?NnfOol00`00Oomo
o`0[Ool002]oo`03001oogoo00Aoo`XmkkMoo`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Sg_
_Goo00<007ooOol0:Goo000YOol00`00Oomoo`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001o
ogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo
000WOol00`00Oomoo`04Ool7?No2Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03
001oogoo02Eoo`009Goo00<007ooOol01Goo2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06
Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo
00<007ooOol01Goo23g_b7oo00<007ooOol08Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomo
o`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_
bgoo00<007ooOol087oo000POol00`00Oomoo`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001o
ogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo
000OOol00`00Oomoo`05Ool7?NoBOol00`00Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03
001oogoo01eoo`007Goo00<007ooOol01Woo23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05
Ool9?NoCOol00`00Oomoo`0LOol001aoo`03001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo
00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomo
o`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_
f7oo00<007ooOol06Goo000JOol00`00Oomoo`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001o
ogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`006Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo
000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03
001oogoo01Moo`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04
Ool9?NoPOol00`00Oomoo`0FOol001Moo`03001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo
00<007ooOol01Goo23g_hWoo00<007ooOol05Goo000FOol00`00Oomoo`05Ool6?NoTOol00`00Oomo
o`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_
iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001o
ogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo
000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03
001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06
Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo
00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomo
o`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_
kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001o
ogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo
000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03
001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09
Ool6?No^Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo
00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7?No]Ool00`00Oomo
o`0>Ool000moo`03001oogoo00Uoo`Pmknaoo`03001oogoo00ioo`003Woo00<007ooOol02Woo2Cg_
k7oo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool<?NoYOol00`00Oomoo`0=Ool000ioo`03001o
ogoo00aoo`XmknUoo`03001oogoo00eoo`003Woo00<007ooOol03Goo2cg_igoo00<007ooOol03Goo
000>Ool00`00Oomoo`0=Ool<?NoWOol00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`dmknIoo`03
001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=Ool00`00Oomoo`0=
Ool>?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`lmknEoo`03001oogoo00aoo`003Goo
00<007ooOol03Goo3cg_iGoo00<007ooOol037oo000=Ool00`00Oomoo`0<OolA?NoTOol00`00Oomo
o`0<Ool000eoo`03001oogoo00]ooa8mknAoo`03001oogoo00aoo`003Goo00<007ooOol02Goo5Cg_
hgoo00<007ooOol037oo000=Ool00`00Oomoo`08OolH?NoQOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00Qooadmkmaoo`03001oogoo00aoo`003Goo00<007ooOol027oo7Sg_fgoo00<007ooOol037oo
000<Ool00`00Oomoo`08OolO?NoLOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`/mk`Aoo`Dm
k`03Oolmkcg_00Tmkmaoo`03001oogoo00]oo`0037oo00<007ooOol01Woo8Cg_g7oo00<007ooOol0
2goo000<Ool00`00Oomoo`05OolQ?NoMOol00`00Oomoo`0;Ool000aoo`03001oogoo00QooaDmknIo
o`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_?Nl033g_iWoo00<007ooOol02goo
000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
k`Yoo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<007ooOol0
2goo000<Ool00`00Oomoo`07Ool7?Nl;Ool6?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Mo
o`Dmk`aoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_37oo2Cg_hWoo00<007oo
Ool02goo000<Ool00`00Oomoo`07Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Moo`Dmk`aoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol01Woo1Cg_37oo2cg_h7oo00<0
07ooOol02goo000=Ool00`00Oomoo`06Ool5?Nl@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001o
ogoo00Ioo`Dmka1oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_gWoo
00<007ooOol037oo000=Ool00`00Oomoo`06Ool6?Nl?Ool8?NoNOol00`00Oomoo`0<Ool000eoo`03
001oogoo00Ioo`Hmka1oo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_
gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Moo`Dmka1oo`Tmkmaoo`03001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo
2cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?NlAOol:?NoJOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Moo`Dmka9oo`TmkmYoo`03001oogoo00aoo`003Woo00<007ooOol01Woo1Sg_
4Woo23g_fGoo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool5?NlBOol5?NoLOol00`00Oomoo`0=
Ool000ioo`03001oogoo00Moo`Dmko=oo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_lWoo
00<007ooOol03Goo000?Ool00`00Oomoo`06Ool6?NobOol00`00Oomoo`0=Ool000moo`03001oogoo
00Moo`Hmko1oo`03001oogoo00ioo`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000?
Ool00`00Oomoo`07Ool6?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Moo`Hmko1oo`03001o
ogoo00ioo`0047oo00<007ooOol01Woo1Sg_l7oo00<007ooOol03Woo000@Ool00`00Oomoo`06Ool6
?No_Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001oogoo00moo`0047oo00<0
07ooOol01Woo1Sg_kgoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool6?No_Ool00`00Oomoo`0?
Ool0015oo`03001oogoo00Eoo`Hmknmoo`03001oogoo00moo`004Goo00<007ooOol01Woo1Sg_kGoo
00<007ooOol047oo000AOol00`00Oomoo`06Ool5?No^Ool00`00Oomoo`0@Ool0019oo`03001oogoo
00Eoo`Dmknioo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo00<007ooOol04Goo000B
Ool00`00Oomoo`05Ool5?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`@mkneoo`03001o
ogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool5
?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`DmkmYoo`03?Nmoogoo00ioo`03001oogoo
019oo`0057oo00<007ooOol017oo1Sg_fGoo0Sg_3Woo00<007ooOol04goo000DOol00`00Oomoo`04
Ool6?NoIOol3?Nl=Ool00`00Oomoo`0COol001Eoo`03001oogoo00=oo`HmkmUoo`@mk`aoo`03001o
ogoo01=oo`005Goo00<007ooOol00goo1Sg_dWoo33g_2Woo00<007ooOol057oo000EOol00`00Oomo
o`03Ool6?NoCOol;?Nl:Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`DmkmAoo`Xmk`Yoo`03
001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_eGoo2Cg_2Goo00<007ooOol05Goo000FOol00`00
Oomoo`03Ool5?NoEOol9?Nl9Ool00`00Oomoo`0EOol001Moo`03001oogoo009oo`DmkmEoo`Pmk`Uo
o`03001oogoo01Ioo`005goo00<007ooOol00Woo1Sg_e7oo23g_2Goo00<007ooOol05Woo000HOol0
1000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000HOol01000Oomoogoo1Sg_dgoo2Cg_27oo
00<007ooOol05goo000IOol01000Oomoogoo1Sg_d7oo2cg_27oo00<007ooOol05goo000IOol01000
Oomoogoo1cg_cWoo2cg_27oo00<007ooOol067oo000JOol00`00Oomoo`07?No=Ool<?Nl8Ool00`00
Oomoo`0HOol001Yoo`04001oogooOol7?No9Ool>?Nl8Ool00`00Oomoo`0IOol001]oo`03001oogoo
00PmklIooa0mk`Moo`03001oogoo01Yoo`006goo00<007ooOol02Cg_aGoo43g_1goo00<007ooOol0
6Woo000LOol00`00Oolmk`09?No4Ool@?Nl6Ool00`00Oomoo`0KOol001aoo`03001oogoo00Xmkl=o
o`Hmk`=oo`Hmk`Moo`03001oogoo01]oo`007Goo00<007oo?Nl02Cg_`Woo1Cg_1Goo1Sg_1Woo00<0
07ooOol077oo000MOol00`00Oolmk`0:?No1Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001ioo`03
000mkcg_00Tmkl5oo`Dmk`Eoo`Dmk`Ioo`03001oogoo01eoo`007Woo00<003g_?Nl02Cg_`Goo1Cg_
1Goo1Cg_1Woo00<007ooOol07Goo000OOol;?No1Ool4?Nl5Ool6?Nl5Ool00`00Oomoo`0NOol001mo
o`03000mkcg_00Tmkkmoo`Dmk`Eoo`Hmk`Eoo`03001oogoo01ioo`0087oo00<003g_?Nl023g__goo
1Cg_17oo1Sg_1Goo00<007ooOol07goo000POol00`00?Nlmk`09?NnmOol5?Nl5Ool6?Nl5Ool00`00
Oomoo`0OOol0025oo`/mkkeoo`Dmk`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_?Nl023g_
_7oo1Cg_17oo1cg_0goo00<007ooOol08Goo000SOol:?NnkOol6?Nl4Ool6?Nl3Ool00`00Oomoo`0R
Ool002Aoo`XmkkYoo`Dmk`Eoo`Hmk`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_^Woo13g_
1Goo1cg_0Woo00<007ooOol08goo000UOol:?NnhOol5?Nl5Ool5?Nl3Ool00`00Oomoo`0TOol002Io
o`03000mkcg_00LmkkIoo`Hmk`Aoo`Lmk`03Ool007oo02Ioo`009Woo00<007oo?Nl02cg_/Woo1Cg_
17oo1cg_0Woo00<007ooOol09Goo000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl00goo001oo`0W
Ool002Qoo`03001oocg_00Tmkk5oo`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<007oo?Nl02Cg_
/7oo1Cg_0Woo23g_00=oo`00Ool0:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9?Nl00`00Oomo
o`0YOol002Yoo`03001oogoo00Tmkjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo00<007ooOol0
2Cg_[Goo1Cg_0Woo23g_00<007ooOol0:Woo000/Ool00`00Oolmk`08?Nn/Ool5?Nl00goo?Nlmk`07
?Nl00`00Oomoo`0[Ool002eoo`03001oocg_00Pmkj]oo`Dmk`03Oolmkcg_00Hmk`03001oogoo02ao
o`00;Woo00<007ooOol02Cg_ZGoo3Cg_00<007ooOol0;Goo000^Ool01000Oomoogoo2Cg_Z7oo2Sg_
0goo00<007ooOol0;Goo000_Ool01000Oomoogoo2Sg_YGoo2Sg_0goo00<007ooOol0;Woo000`Ool0
1000Oomoogoo2Sg_Y7oo2Cg_0goo00<007ooOol0;goo000aOol01000Oomoogoo33g_X7oo23g_17oo
00<007ooOol0<7oo000bOol20002Ool=?NnLOol9?Nl3Ool2000cOol003Aoo`03001oogoo00`mkiYo
o`Xmk`=oo`03001oogoo03=oo`00=Goo00<007oo?Nl033g_V7oo2Sg_0goo00<007ooOol0=7oo000e
Ool01000Oomoogoo2cg_UWoo33g_0goo00<007ooOol0=7oo000fOol01000Oomoogoo2cg_U7oo2Sg_
1Goo00<007ooOol0=Goo000gOol00`00Oomoo`02Ool9?NnDOol8?Nl6Ool00`00Oomoo`0fOol003Qo
o`03001oogoo009oo`Tmki9oo`Tmk`Eoo`03001oogoo03Moo`00>Goo0P000goo23g_TGoo2Sg_0goo
0P00>Woo000kOol00`00Oomoo`09?Nn?Ool:?Nl3Ool00`00Oomoo`0jOol003aoo`03001oogoo00Tm
kheoo`Xmk`=oo`03001oogoo03]oo`00?Goo00<007ooOol02Sg_RGoo2Cg_1Goo00<007ooOol0?7oo
000nOol20002Ool9?Nn7Ool9?Nl4Ool2000oOol0041oo`03001oogoo00TmkhAoo`/mk`=oo`03001o
ogoo03moo`00@Goo0P0000=oocg_?Nl01cg_PWoo2Cg_17oo0P00@Woo0013Ool00`00Oolmk`09?Nmj
Ool>?Nl4Ool00`00Oomoo`12Ool004Aoo`03000mkcg_00TmkgUoo`dmk`Aoo`03001oogoo04=oo`00
AGoo00<003g_?Nl02Sg_Mgoo2cg_1Goo00<007ooOol0A7oo0016Ool00`00?Nlmk`0;?NmdOol<?Nl3
Ool20017Ool004Qoo`hmk`9oo`8mkfaoo`dmk`9oo`8004Uoo`00BWoo4Cg_JWoo33g_0Woo0P00Bgoo
001<Ool@?NmWOol;?Nl3Ool2001=Ool004iooa4mkf=oo`/mk`=oo`03001oogoo04eoo`00Cgoo00<0
03g_?Nl03cg_H7oo33g_0Woo00<007ooOol0CWoo001@Ool200000goo?Nlmk`0??NmIOol00cg_Oomo
o`0:?Nl3Ool2001AOol0059oo`800003Oolmkcg_010mke9oo`03?Nmoogoo00hmk`03Ool0000005=o
o`00E7oo0P0000<mkgoo?Nl043g_1goo1Cg_@7oo4cg_00=oo`000000EGoo001FOol20004Ool@?Nl3
Ool6?NlnOolD?Nl2001GOol005Qoo`<000AooaHmkcaooaDmk`03001oogoo05Moo`00Fgoo0`000goo
53g_>Goo53g_0P00G7oo001NOol20004OolB?NldOolH?NmNOol0061oo`8000AooaLmkbAooahmkf5o
o`00HWoo0`0017oo53g_47oo0Sg_3Goo83g_00<007ooOol0HGoo001UOol30005OolV?Nl2OolR?Nl3
001VOol006Qoo`@000=ood@mk`04000mk`00001YOol006aoo`@000=ooc/mk`03Ool00000008006eo
o`00L7oo0`000goo<3g_1Goo1000LGoo001cOol500000goo?Nlmk`0U?Nl7Ool4001eOol007Qoo`@0
01dmk`Moo`L007Uoo`00OWoo43g_17oo3P00P7oo002=Ool5002>Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol008Yoo`<000=oo`<008eoo`00S7oo00<007ooOol00goo00<007ooOol0
Rgoo002;Ool30003Ool3002<Ool008Yoo`04001oogoo0002Ool01000Oomoo`00S7oo002:Ool01000
Oomoo`000Woo00@007ooOol008aoo`00Rgoo0`000goo0`00S7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -9 0 ]
[.5 1.0125 9 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(100)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.1221 .45146 m
.12212 .45128 L
.12229 .45097 L
.12251 .4505 L
.12288 .44986 L
.12356 .44901 L
.12444 .44785 L
.12545 .44655 L
.12653 .4453 L
.12752 .44387 L
.12834 .44248 L
.12897 .44119 L
.12942 .44005 L
.12971 .43911 L
.12986 .43842 L
.12984 .43796 L
.12972 .43769 L
s
.07766 .46922 m
.07747 .46934 L
.07718 .46958 L
.07678 .46998 L
.0763 .47053 L
.07577 .47122 L
.07526 .47204 L
.0748 .47296 L
.07432 .47386 L
.0739 .47495 L
.07352 .47609 L
.07314 .4773 L
.07285 .47855 L
.07262 .47968 L
.07248 .48076 L
.07239 .48175 L
.07237 .48264 L
.07238 .48342 L
.0724 .48409 L
.07237 .4847 L
.07228 .48526 L
.07213 .48578 L
.07195 .48625 L
.07179 .48667 L
.07167 .48703 L
.07157 .48731 L
.0715 .4875 L
.07148 .48765 L
.07149 .48778 L
.07153 .48796 L
.07156 .48816 L
.07157 .48843 L
.07158 .48874 L
.07157 .48907 L
.07155 .48942 L
.07149 .48983 L
.07141 .49031 L
.07132 .49088 L
.07124 .49155 L
.07119 .49231 L
.07119 .49313 L
.07124 .49397 L
.07135 .49478 L
.07151 .49552 L
.07173 .49617 L
.07195 .49666 L
.07222 .49712 L
.07249 .49749 L
.07278 .49778 L
.07307 .498 L
Mistroke
.07335 .49816 L
.07359 .49826 L
.07379 .49831 L
Mfstroke
.07393 .49306 m
.07403 .4929 L
.07407 .49262 L
.07405 .49217 L
.07396 .49156 L
.07382 .49079 L
.07369 .48993 L
.0736 .48896 L
.07357 .48791 L
.07359 .48683 L
.07368 .48576 L
.07383 .48473 L
.07408 .48378 L
.07438 .483 L
.07471 .48237 L
.07504 .48186 L
.07536 .48144 L
.07565 .48114 L
.07592 .48095 L
.07614 .48084 L
.07632 .4808 L
s
.08931 .4591 m
.08931 .45905 L
.08934 .4589 L
.08944 .45867 L
.08962 .45835 L
.08988 .45795 L
.09023 .4575 L
.09064 .45702 L
.0911 .45651 L
.09155 .45594 L
.09196 .4553 L
.09232 .45462 L
.09261 .45386 L
.09286 .45302 L
.09305 .45217 L
.0932 .45127 L
.09333 .45032 L
.09344 .44936 L
.09355 .44839 L
.09365 .44746 L
.09375 .44653 L
.09387 .44563 L
.09402 .44479 L
.09422 .44403 L
.09446 .44341 L
.09476 .44292 L
.09508 .44261 L
.0954 .44249 L
.09571 .44254 L
.096 .44273 L
.09628 .44301 L
.09651 .44336 L
.09669 .44377 L
.09681 .44425 L
.09684 .4448 L
.09678 .44539 L
.09663 .44598 L
.09641 .44656 L
.09615 .44714 L
.09587 .44771 L
.09558 .4482 L
.09529 .4486 L
.09502 .44889 L
.09476 .44913 L
.09454 .4493 L
.09439 .44937 L
s
.09655 .44601 m
.09656 .44622 L
.0966 .44651 L
.09665 .44688 L
.09667 .4473 L
.09668 .44777 L
.09666 .44829 L
.09662 .44872 L
.09654 .44924 L
.09642 .44983 L
.09622 .45046 L
.09594 .4511 L
.09557 .45174 L
.09508 .45233 L
.09463 .45291 L
.09399 .45349 L
.09326 .45408 L
.09245 .45471 L
.09161 .45541 L
.09066 .45615 L
.08967 .45694 L
.08861 .45773 L
.08774 .45848 L
.087 .45918 L
.0863 .45983 L
.08576 .4604 L
.08535 .46093 L
.08512 .46143 L
.08507 .46189 L
.08518 .46232 L
.08539 .46273 L
.08567 .46311 L
.08601 .46345 L
.08639 .46373 L
.08685 .46394 L
.0872 .46411 L
.08759 .46427 L
.08793 .46442 L
.08819 .46456 L
.08829 .46464 L
.08831 .46466 L
.08821 .46464 L
.088 .46462 L
.0877 .46463 L
.08734 .46469 L
.08692 .46484 L
.08644 .46509 L
.08585 .46544 L
.0852 .46587 L
.0845 .46634 L
Mistroke
.08376 .46683 L
.08308 .46731 L
.08241 .4678 L
.08185 .46827 L
.08139 .4687 L
.08101 .46908 L
.0807 .46939 L
.08046 .4696 L
.08024 .46971 L
.07999 .46975 L
.07974 .46972 L
.07951 .46966 L
.07928 .46959 L
.07908 .46953 L
.0789 .46951 L
.07879 .46951 L
.07876 .46951 L
Mfstroke
.07182 .48132 m
.07181 .48142 L
.07177 .4817 L
.0717 .48221 L
.07161 .48293 L
.07151 .48379 L
.0714 .48473 L
.0713 .48569 L
.07122 .48667 L
.07114 .4876 L
.07105 .48846 L
.07094 .48927 L
.07084 .49003 L
.07073 .49059 L
.07063 .491 L
.07057 .49125 L
s
.07159 .48858 m
.07174 .48865 L
.07194 .48881 L
.07221 .48909 L
.07256 .48953 L
.07299 .4901 L
.0735 .49075 L
.07408 .49146 L
.07473 .49223 L
.07542 .49307 L
.0761 .49393 L
.07676 .49477 L
.07737 .49552 L
.07788 .4961 L
.07829 .49654 L
.07861 .49684 L
.07883 .49699 L
.07895 .497 L
.07897 .49688 L
.07885 .4966 L
.07858 .49617 L
.07818 .4956 L
.07766 .49492 L
.07705 .49414 L
.07639 .49331 L
.07571 .4925 L
.07502 .49178 L
.07437 .49117 L
.07377 .49066 L
.07323 .49026 L
.07273 .48994 L
.07229 .48967 L
.07191 .48948 L
.07162 .48929 L
.07144 .48911 L
s
.07124 .49794 m
.07125 .49775 L
.07126 .49749 L
.07127 .49714 L
.07129 .49669 L
.07131 .49614 L
.07133 .49551 L
.07135 .49481 L
.07137 .494 L
.07139 .49309 L
.07141 .49208 L
.07144 .49098 L
.07149 .48991 L
.07156 .48882 L
.07164 .48776 L
.07172 .48675 L
.07181 .48579 L
.07189 .48487 L
.07196 .48398 L
.07202 .48316 L
.07206 .48239 L
.07209 .48167 L
.07212 .481 L
.07213 .4804 L
.07212 .47984 L
.07208 .47934 L
.07202 .47888 L
.07194 .47849 L
.07188 .47811 L
.07184 .47781 L
.07186 .47749 L
.07194 .4772 L
.07209 .47694 L
.07229 .47674 L
.07255 .47663 L
.07285 .47657 L
.07318 .47656 L
.0735 .47657 L
.0738 .47659 L
.07409 .4766 L
.07432 .47661 L
.07449 .47663 L
s
.09074 .46306 m
.09086 .46294 L
.09101 .4627 L
.09122 .46234 L
.09154 .46184 L
.092 .4612 L
.09256 .46044 L
.09313 .45962 L
.0937 .45876 L
.09425 .45789 L
.09478 .45702 L
.0953 .45619 L
.09574 .45546 L
.09611 .45482 L
.09644 .45422 L
.09675 .45365 L
.09701 .4531 L
.09725 .45256 L
.09746 .45201 L
.09768 .45143 L
.0979 .45083 L
.09815 .4502 L
.09841 .44958 L
.09865 .44897 L
.09884 .44837 L
.09898 .44778 L
.09907 .44722 L
.09913 .44673 L
.09917 .44633 L
.09921 .44604 L
.09928 .44585 L
.09939 .44577 L
.09954 .44576 L
.09972 .4458 L
.09993 .44587 L
.10016 .44595 L
.10043 .44604 L
.10075 .44613 L
.10111 .44624 L
.10149 .44637 L
.10187 .44645 L
.10224 .44646 L
.10256 .44637 L
.10282 .44614 L
.10299 .44575 L
.10307 .4452 L
.10306 .44449 L
.10299 .44364 L
.10287 .44268 L
.10271 .44177 L
Mistroke
.1025 .44057 L
.10222 .43947 L
.10189 .4383 L
.10151 .43705 L
.10111 .43577 L
.10069 .43454 L
.10028 .43332 L
.09989 .43214 L
.09956 .43106 L
.09926 .43 L
.09896 .42897 L
.09868 .42794 L
.0984 .42697 L
.09814 .42604 L
.09788 .42518 L
.09767 .42444 L
.09746 .42384 L
.09728 .4234 L
.09714 .42311 L
.09706 .42296 L
.09704 .42292 L
.09708 .42294 L
.09714 .42298 L
.09721 .42298 L
.09725 .4229 L
.09722 .42267 L
.09709 .42228 L
.09688 .42175 L
.09658 .42109 L
.09623 .42031 L
.09586 .41955 L
.09546 .41871 L
.09507 .41776 L
.09468 .41701 L
.09429 .41622 L
.09395 .41553 L
.09364 .41492 L
.09337 .41438 L
.09314 .41405 L
.09294 .41386 L
Mfstroke
.08753 .40931 m
.08758 .40949 L
.08767 .40974 L
.08779 .41 L
.08794 .41032 L
.08815 .4106 L
.0884 .4108 L
.08871 .41084 L
.08906 .41068 L
.08945 .41027 L
.08988 .40962 L
.09034 .40876 L
.09083 .40785 L
.09132 .40686 L
.09177 .40588 L
.09221 .40498 L
.09261 .40431 L
.09296 .40382 L
.09324 .40352 L
.09345 .40342 L
.09358 .40353 L
.09363 .40383 L
.09358 .40422 L
.09343 .40467 L
.09318 .40516 L
.09285 .40561 L
.09249 .40597 L
.09211 .40622 L
.09172 .40636 L
.09135 .40645 L
.09101 .40657 L
.0907 .40674 L
.09043 .40698 L
.09018 .40726 L
.08996 .40756 L
.08979 .40799 L
.08969 .40852 L
.08969 .4091 L
.08982 .40969 L
.09007 .41025 L
.09045 .41073 L
.09094 .41108 L
.09154 .41126 L
.0922 .41126 L
.09291 .41107 L
.09361 .41068 L
.0943 .41014 L
.09496 .40954 L
.09558 .40892 L
.09614 .40832 L
Mistroke
.09661 .40776 L
.09698 .40729 L
.09724 .40693 L
.09738 .40673 L
Mfstroke
.09447 .4114 m
.09446 .41156 L
.09446 .41185 L
.09447 .41226 L
.09449 .41278 L
.09454 .41336 L
.09463 .41399 L
.09477 .41465 L
.09496 .4153 L
.09518 .41599 L
.09542 .41673 L
.09568 .41751 L
.09594 .4183 L
.09619 .41911 L
.09644 .41995 L
.09667 .42085 L
.09687 .42174 L
.09705 .42272 L
.09716 .4238 L
.09721 .42502 L
.09719 .4264 L
.0971 .4278 L
.09698 .42929 L
.09686 .43085 L
.09675 .43243 L
.09667 .43398 L
.09658 .4356 L
.09647 .43721 L
.09634 .43892 L
.09616 .44056 L
.09596 .44225 L
.09573 .44393 L
.09548 .44548 L
.09522 .44702 L
.09498 .44846 L
.09476 .44971 L
.09454 .45074 L
.09434 .45163 L
.09415 .45233 L
.09399 .45283 L
.09384 .45312 L
.09372 .45324 L
.09363 .45325 L
.09361 .4532 L
.09364 .45312 L
.09375 .45305 L
.09393 .45303 L
.0941 .45312 L
.09417 .45336 L
.09412 .45376 L
Mistroke
.09393 .45432 L
.09355 .45503 L
.09294 .45586 L
.09208 .45678 L
.09106 .4578 L
.08998 .45887 L
.0889 .45996 L
.08789 .46095 L
.08694 .46189 L
.08596 .46275 L
.08495 .46346 L
.08399 .46405 L
.08325 .4645 L
.08281 .46482 L
.08261 .46503 L
Mfstroke
.0828 .46487 m
.08297 .46486 L
.08324 .46484 L
.08358 .46481 L
.08396 .46476 L
.08436 .46469 L
.08473 .46459 L
.08505 .46446 L
.08533 .46432 L
.08561 .46418 L
.08589 .46406 L
.08616 .46396 L
.08641 .46384 L
.08666 .4637 L
.08694 .46353 L
.08722 .46333 L
.08755 .46308 L
.08791 .46278 L
.08842 .46237 L
.08889 .46189 L
.08954 .46127 L
.09027 .46051 L
.09108 .45965 L
.09184 .4587 L
.09258 .45766 L
.0933 .45657 L
.09393 .45548 L
.09447 .45449 L
.09493 .45358 L
.09531 .45278 L
.09565 .45216 L
.09594 .45164 L
.09617 .45122 L
.09635 .45087 L
.09647 .45052 L
.09655 .45014 L
.0966 .44976 L
.09661 .44944 L
.09659 .44914 L
.09656 .44884 L
.09652 .44848 L
.09649 .44814 L
.09646 .4478 L
.09642 .44746 L
.09637 .44713 L
.09632 .44679 L
.09631 .44653 L
s
.09913 .44617 m
.09933 .44599 L
.09966 .44572 L
.10015 .44536 L
.10083 .44495 L
.10163 .44449 L
.1026 .44401 L
.10367 .44353 L
.10483 .44306 L
.10607 .44259 L
.10734 .44216 L
.10856 .44178 L
.10974 .44147 L
.11085 .44126 L
.11183 .44113 L
.11268 .44109 L
.1134 .44111 L
.11399 .44116 L
.11447 .4412 L
.11483 .44125 L
.11505 .44129 L
.11514 .44134 L
s
.11205 .442 m
.11208 .44193 L
.11226 .44179 L
.11257 .44155 L
.11303 .44121 L
.11363 .44077 L
.11433 .44024 L
.11511 .43968 L
.11594 .43908 L
.11682 .43846 L
.11775 .43778 L
.11871 .43708 L
.11968 .43637 L
.12056 .43569 L
.12137 .43508 L
.12202 .43459 L
.12248 .43425 L
.12274 .43411 L
.12277 .43416 L
.12255 .4344 L
.12208 .43483 L
.12143 .4354 L
.12066 .43607 L
.1198 .4368 L
.11892 .43747 L
.11806 .43825 L
.1172 .43892 L
.11639 .43958 L
.11567 .44021 L
.11509 .44076 L
.11473 .4412 L
.1146 .44148 L
s
.11651 .44157 m
.11648 .44142 L
.1164 .44117 L
.11633 .44082 L
.11632 .44038 L
.1164 .43988 L
.11656 .43934 L
.11676 .43875 L
.11692 .43812 L
.11701 .43743 L
.11696 .4367 L
.11681 .43595 L
.11655 .43523 L
.11625 .43448 L
.11592 .43371 L
.11559 .43292 L
.11523 .43212 L
.11487 .43136 L
.11445 .43058 L
.11399 .42977 L
.11351 .42894 L
.11303 .42814 L
.11268 .42741 L
.11248 .42678 L
.1124 .42623 L
.11243 .42578 L
.11256 .42544 L
.11275 .42522 L
.11295 .42512 L
.11305 .42509 L
.113 .42509 L
.11279 .42509 L
.11242 .42507 L
.11185 .42503 L
.11111 .42495 L
.11024 .42482 L
.10934 .42468 L
.10848 .42455 L
.1078 .42446 L
.10698 .4244 L
.10627 .42437 L
.10556 .42436 L
.1049 .42438 L
.10438 .42443 L
.1041 .42451 L
.10404 .42463 L
.10412 .42477 L
.1043 .42493 L
.10454 .42508 L
.10477 .42522 L
Mistroke
Mfstroke
.105 .42536 m
.10481 .4254 L
.10454 .42545 L
.1042 .42547 L
.10378 .42545 L
.10329 .42537 L
.10274 .42523 L
.10214 .42499 L
.10152 .42464 L
.10086 .42416 L
.10019 .42356 L
.09957 .42284 L
.09904 .422 L
.09863 .42107 L
.09831 .42011 L
.09804 .41914 L
.09779 .41812 L
.09752 .4171 L
.09721 .41611 L
.09682 .41523 L
.09634 .41442 L
.09582 .4137 L
.0953 .41308 L
.09478 .41257 L
.0943 .41217 L
.09383 .41187 L
.09336 .41165 L
.09291 .41148 L
.09255 .41137 L
.0923 .4113 L
.09215 .41129 L
s
.08695 .40735 m
.08685 .40715 L
.0867 .40685 L
.08652 .40643 L
.08629 .40588 L
.08605 .40523 L
.08579 .40447 L
.08554 .40368 L
.08528 .40282 L
.08503 .40186 L
.08481 .40095 L
.08461 .40002 L
.08446 .39912 L
.08435 .39828 L
.0843 .39753 L
.08429 .39692 L
.08431 .39641 L
.08436 .39599 L
.08441 .39566 L
.08444 .39538 L
.08446 .39516 L
.08447 .395 L
s
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
Mfstroke
.11315 .2931 m
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
Mistroke
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
Mistroke
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
Mistroke
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
Mistroke
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
Mistroke
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
s
.08713 .38373 m
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
s
.08664 .41128 m
.08676 .41138 L
.08694 .41151 L
.0872 .41169 L
.08756 .4119 L
.08804 .41213 L
.08857 .41236 L
.08905 .41257 L
.08958 .41275 L
.09014 .41294 L
.0906 .41315 L
.09099 .41342 L
.0913 .41366 L
.09151 .41393 L
.0917 .41422 L
.09191 .41456 L
.09211 .41484 L
.0923 .41519 L
.09246 .41559 L
.09271 .41603 L
.09307 .41656 L
.09351 .41719 L
.09395 .41791 L
.09449 .4187 L
.09508 .41959 L
.09555 .42058 L
.09599 .42153 L
.09641 .42256 L
.09675 .42372 L
.09696 .42498 L
.0971 .42627 L
.09715 .4275 L
.09712 .42879 L
.09701 .43022 L
.09682 .43194 L
.09657 .43335 L
.09631 .43488 L
.09602 .43666 L
.09572 .43856 L
.0954 .4403 L
.09513 .44162 L
.09488 .44351 L
.09462 .44487 L
.09435 .44647 L
.09407 .44826 L
.09385 .44967 L
.09367 .45088 L
.0935 .452 L
.09336 .45302 L
.09321 .45392 L
Mistroke
.09304 .45468 L
.09281 .45532 L
.09249 .45589 L
.09206 .45648 L
.09151 .45711 L
.09083 .45778 L
.08999 .45852 L
.08901 .45937 L
.08802 .46027 L
.08717 .46112 L
.08638 .46177 L
.08565 .4625 L
.08498 .46309 L
.08431 .46365 L
.08365 .46416 L
.08314 .46458 L
.08287 .46487 L
.08276 .46504 L
Mfstroke
.08434 .47421 m
.0845 .47406 L
.08479 .47385 L
.08522 .47357 L
.08576 .47324 L
.08636 .47286 L
.08712 .4724 L
.08802 .47186 L
.08904 .47126 L
.09013 .47057 L
.09116 .46984 L
.09213 .46908 L
.09303 .46834 L
.09381 .46764 L
.09445 .46701 L
.09498 .46648 L
.09539 .46602 L
.0957 .46561 L
.09593 .46526 L
.09612 .46495 L
.09629 .46469 L
.09646 .4645 L
.09667 .46439 L
.09696 .46436 L
.09732 .46438 L
.09773 .46445 L
.09821 .46452 L
.09877 .46457 L
.09938 .46459 L
.1 .46459 L
.10062 .46458 L
.10124 .46457 L
.10187 .46456 L
.10254 .46456 L
.10322 .46454 L
.10395 .46451 L
.10472 .46445 L
.10554 .46437 L
.10634 .46429 L
.10716 .46425 L
.10793 .46426 L
.10862 .46435 L
.10932 .46453 L
.10994 .46479 L
.11051 .46514 L
.11105 .46554 L
.11154 .46599 L
.11197 .46647 L
.11232 .46693 L
.1126 .4674 L
Mistroke
.11284 .46786 L
.11304 .46829 L
.11322 .46866 L
.1134 .46896 L
.1136 .46917 L
.11381 .46928 L
.11401 .46932 L
.11417 .46929 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
Mfstroke
.14734 .54959 m
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
Mistroke
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
Mistroke
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
Mfstroke
.12986 .49201 m
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
Mistroke
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.09681 .43477 m
.09681 .43455 L
.09682 .43418 L
.09683 .43366 L
.09684 .43299 L
.09686 .43219 L
.09688 .4313 L
.0969 .4305 L
.09692 .4296 L
.09694 .42862 L
.09696 .42778 L
.09698 .427 L
.09699 .42631 L
.097 .42576 L
.09701 .42539 L
.09701 .42519 L
.09701 .42515 L
.09701 .42521 L
.09701 .42529 L
.09701 .42528 L
.09701 .42513 L
.09702 .42482 L
.09704 .42431 L
.09708 .42359 L
.09714 .42276 L
.0972 .42177 L
.09724 .42067 L
.09725 .4196 L
.09723 .41846 L
.09717 .41719 L
.09707 .41613 L
.09694 .41512 L
.09677 .4142 L
.09655 .4134 L
.09629 .41275 L
.096 .41224 L
.0957 .41181 L
.09539 .41142 L
.09503 .41102 L
.09463 .41058 L
.09419 .41012 L
.09368 .40964 L
.0931 .40922 L
.09246 .4088 L
.09174 .40845 L
.09095 .40815 L
.09008 .40791 L
.08919 .40778 L
.0884 .40777 L
.08761 .40787 L
Mistroke
.08682 .40807 L
.08606 .40837 L
.08545 .40872 L
.08493 .40915 L
.08453 .40961 L
.08424 .41002 L
.08405 .41044 L
.08396 .41081 L
.08396 .41111 L
.08401 .41135 L
.08407 .41146 L
Mfstroke
.08968 .40207 m
.08952 .40196 L
.08923 .40188 L
.08882 .4018 L
.08832 .4017 L
.08779 .40155 L
.08728 .40131 L
.08681 .40096 L
.08637 .40051 L
.08591 .39996 L
.08543 .39931 L
.08496 .39856 L
.0846 .39772 L
.08438 .39687 L
.08428 .39602 L
.08425 .39515 L
.08428 .39429 L
.08436 .39347 L
.08446 .39274 L
.08451 .3921 L
.08452 .39152 L
.08453 .39104 L
.08454 .39069 L
.08454 .39045 L
s
.08973 .39509 m
.08962 .39525 L
.08947 .39547 L
.08926 .39578 L
.08901 .39619 L
.0887 .39673 L
.08833 .39745 L
.08796 .39815 L
.08755 .39902 L
.08711 .39998 L
.08664 .40099 L
.08617 .40201 L
.08575 .40298 L
.08539 .40382 L
.08508 .40457 L
.08481 .40525 L
.08459 .40584 L
.08441 .40633 L
.08427 .4067 L
.08419 .40693 L
s
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
s
.09783 .31714 m
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
s
.10571 .30326 m
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
Mistroke
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
Mistroke
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
Mistroke
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
Mistroke
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
Mistroke
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
Mistroke
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
Mfstroke
.37152 .05234 m
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
s
.40831 .03963 m
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
Mistroke
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
Mfstroke
.34937 .05462 m
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
Mistroke
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
Mfstroke
.28352 .10375 m
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
.25982 .10946 L
.2595 .10956 L
Mistroke
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
.22643 .14055 L
.22638 .14068 L
Mistroke
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
Mfstroke
.18985 .18586 m
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
s
.20672 .16354 m
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
Mistroke
.24049 .12506 L
.24062 .12497 L
Mfstroke
.24016 .12551 m
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
Mistroke
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
Mistroke
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
Mistroke
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
Mistroke
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
Mistroke
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
.51228 .03854 L
.51246 .03843 L
Mfstroke
.51382 .04322 m
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
Mistroke
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
Mfstroke
.41089 .03979 m
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
Mistroke
.38497 .03476 L
Mfstroke
.37434 .03896 m
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
s
.34919 .049 m
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
s
.34194 .05548 m
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
s
.31177 .07271 m
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
s
.29343 .08516 m
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
s
.23839 .11792 m
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
s
.22906 .12906 m
.22885 .12915 L
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
Mistroke
.18189 .17608 L
.17999 .17855 L
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
Mistroke
.13111 .25715 L
.12943 .26037 L
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
Mfstroke
.09798 .31453 m
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
Mistroke
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.09214 .41345 m
.09231 .41353 L
.09256 .41373 L
.0929 .41405 L
.09331 .41451 L
.09377 .41504 L
.09425 .41573 L
.09475 .41655 L
.09525 .41742 L
.09572 .41847 L
.09614 .41974 L
.09651 .42109 L
.09684 .42263 L
.0971 .42436 L
.09727 .42624 L
.09735 .42835 L
.09737 .43041 L
.0973 .43272 L
.09714 .43512 L
.09689 .43776 L
.09652 .44048 L
.09603 .44292 L
.09543 .44553 L
.09467 .44837 L
.09375 .45099 L
.09278 .45354 L
.09162 .45593 L
.09025 .4581 L
.08883 .46012 L
.08743 .46194 L
.0858 .4637 L
.08431 .46532 L
.08281 .46687 L
.08128 .46828 L
.07987 .46962 L
.07869 .47086 L
.07772 .47196 L
.07681 .47293 L
.07597 .47373 L
.07524 .47445 L
.07467 .4751 L
.07422 .47571 L
.07385 .47629 L
.07354 .47681 L
.07328 .47727 L
.07309 .47764 L
.07297 .47789 L
.0728 .47806 L
.07255 .47816 L
.07231 .47826 L
Mistroke
.07211 .47839 L
.07194 .47856 L
.07183 .47879 L
.07176 .479 L
.07173 .47922 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
Mfstroke
.10263 .73756 m
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
Mistroke
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
Mistroke
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
Mistroke
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
Mistroke
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
Mistroke
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
Mistroke
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
Mistroke
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
Mfstroke
.50259 .95646 m
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
Mistroke
.39194 .94579 L
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
Mistroke
.29925 .91004 L
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
Mistroke
.25388 .8921 L
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
Mistroke
.18351 .82511 L
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
Mistroke
.10565 .74515 L
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
Mfstroke
.10137 .71568 m
.10141 .71572 L
.10134 .71584 L
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
Mistroke
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
Mfstroke
.08503 .62555 m
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
Mistroke
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.08301 .46465 m
.08292 .46484 L
.08277 .46511 L
.08256 .46546 L
.08233 .46583 L
.08214 .4662 L
.08196 .46658 L
.08173 .46697 L
.08146 .46741 L
.08114 .46785 L
.08073 .4684 L
.08023 .46902 L
.07966 .46972 L
.07904 .47051 L
.07841 .47138 L
.07779 .47232 L
.07722 .47333 L
.07675 .47428 L
.0763 .47525 L
.0758 .47627 L
.07524 .47743 L
.07487 .47845 L
.07456 .47934 L
.07437 .48004 L
.0743 .48055 L
.07432 .4809 L
.07438 .48114 L
.07446 .48131 L
.07448 .48146 L
.07443 .48169 L
.07428 .48205 L
.07408 .48252 L
.07382 .48307 L
.07355 .48368 L
.07327 .48437 L
.07301 .48509 L
.07275 .48578 L
.07247 .48647 L
.07218 .48714 L
.07188 .48772 L
.07157 .48816 L
.07127 .48845 L
.07098 .48863 L
.07071 .48875 L
.07049 .48885 L
.07031 .48898 L
.07018 .48919 L
.07008 .48944 L
.07001 .48983 L
.06997 .49028 L
Mistroke
.06998 .49075 L
.07005 .49118 L
.07018 .49163 L
.07034 .49206 L
.07055 .49246 L
.07079 .49279 L
.07104 .49301 L
.07124 .49313 L
.0714 .49318 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
Mfstroke
.07423 .55704 m
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
s
.08089 .58586 m
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
s
.08341 .59316 m
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
s
.08024 .60537 m
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
Mistroke
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
Mfstroke
.11285 .75251 m
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
Mistroke
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
Mfstroke
.12767 .7691 m
.12765 .76931 L
.12765 .7696 L
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
Mistroke
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
Mfstroke
.15535 .80208 m
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
Mistroke
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
Mistroke
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
Mistroke
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
Mfstroke
.47195 .96642 m
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
Mistroke
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
Mistroke
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
Mfstroke
.65255 .93648 m
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
s
.65242 .94241 m
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
Mistroke
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
Mfstroke
.65756 .93928 m
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
s
.65815 .93795 m
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
Mistroke
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
Mfstroke
.68712 .92334 m
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
Mistroke
.68731 .92601 L
Mfstroke
.66726 .93047 m
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
Mistroke
.67071 .9302 L
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
Mistroke
.72078 .89072 L
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
Mistroke
.65894 .93632 L
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
Mistroke
.51206 .96122 L
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
Mfstroke
.4968 .95772 m
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
Mistroke
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
Mistroke
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
Mistroke
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
Mistroke
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
Mistroke
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
Mistroke
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07435 .48155 m
.07458 .48158 L
.07492 .48155 L
.07538 .48145 L
.07593 .48127 L
.07657 .48102 L
.07718 .4807 L
.07792 .48032 L
.07862 .4799 L
.07934 .47945 L
.08003 .47898 L
.0807 .47848 L
.08128 .47797 L
.08184 .47742 L
.08239 .47683 L
.08293 .4762 L
.08351 .47553 L
.08415 .47482 L
.08483 .47403 L
.08562 .47313 L
.08652 .47209 L
.08749 .47089 L
.08843 .46949 L
.08931 .46785 L
.09021 .46608 L
.0911 .46415 L
.09194 .46213 L
.09264 .45995 L
.09327 .45776 L
.09378 .45526 L
.09426 .45297 L
.09469 .45043 L
.09504 .44776 L
.09535 .44532 L
.09563 .4426 L
.09588 .44048 L
.09613 .43828 L
.09635 .4363 L
.09655 .43462 L
.09672 .43303 L
.09687 .43189 L
.09697 .43094 L
.09703 .43016 L
.09706 .4297 L
.09705 .42939 L
s
.09692 .43021 m
.09695 .42998 L
.09704 .42958 L
.09714 .42897 L
.09722 .42814 L
.09727 .42705 L
.09727 .42593 L
.0972 .42454 L
.097 .4229 L
.09664 .42119 L
.09614 .41958 L
.09554 .41776 L
.09485 .41587 L
.09412 .41422 L
.09346 .41261 L
.09276 .41123 L
.09203 .40999 L
.09128 .40895 L
.09068 .40819 L
.09015 .4076 L
.0897 .40709 L
.08942 .4068 L
.08923 .4066 L
s
.08975 .39498 m
.08961 .39518 L
.08934 .39554 L
.08886 .39608 L
.08826 .39677 L
.08773 .39761 L
.08727 .39849 L
.08683 .39941 L
.08638 .4003 L
.08589 .40118 L
.0854 .40219 L
.0849 .40323 L
.0845 .40411 L
.08428 .40475 L
.08419 .40534 L
.08415 .40588 L
.08416 .40637 L
.08423 .40683 L
.08427 .40727 L
.08427 .40775 L
.08426 .40826 L
.08425 .40874 L
.08424 .40916 L
.08423 .40949 L
.08423 .4098 L
.08422 .41019 L
.08421 .41061 L
.0842 .41099 L
.0842 .41127 L
.08419 .41145 L
s
.10432 .42244 m
.10407 .42238 L
.10367 .42241 L
.10313 .42255 L
.10246 .42285 L
.10176 .42337 L
.10104 .42414 L
.10027 .42515 L
.09947 .42643 L
.09872 .42786 L
.09813 .4295 L
.09764 .4314 L
.09726 .43343 L
.09697 .43562 L
.09675 .43789 L
.09658 .44015 L
.09639 .44246 L
.09616 .4445 L
.09585 .44653 L
.09544 .44851 L
.09487 .4503 L
.09413 .45198 L
.09318 .45366 L
.09189 .45538 L
.09085 .45705 L
.08931 .45885 L
.08757 .46078 L
.08591 .46266 L
.08444 .46468 L
.08284 .46677 L
.08096 .46875 L
.07916 .47074 L
.07764 .47278 L
.07636 .47463 L
.07512 .47649 L
.0739 .47835 L
.07303 .47995 L
.07233 .4814 L
.07181 .48268 L
.07151 .48379 L
.07136 .48476 L
.0713 .48562 L
.07132 .48642 L
.07139 .48719 L
.07144 .48798 L
.07147 .48877 L
.07148 .48954 L
.07149 .49026 L
.07149 .4909 L
.07147 .49142 L
Mistroke
.07146 .49187 L
.07145 .49224 L
.07143 .49256 L
.07143 .49284 L
.07143 .49306 L
.07146 .49316 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
Mfstroke
.10208 .74482 m
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
Mistroke
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
Mfstroke
.25127 .89093 m
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
s
.25987 .89024 m
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
Mistroke
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
Mfstroke
.3928 .94554 m
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
Mistroke
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
Mistroke
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
Mistroke
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
Mfstroke
.6724 .93382 m
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
Mistroke
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
Mistroke
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
Mistroke
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
Mistroke
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
Mistroke
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
Mfstroke
.88107 .71365 m
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
s
.87837 .75257 m
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
Mistroke
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
Mfstroke
.85208 .80052 m
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
s
.8538 .79278 m
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
s
.87618 .76236 m
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
s
.8738 .75155 m
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
Mistroke
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
Mistroke
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
Mistroke
.84297 .74542 L
.84311 .74552 L
Mfstroke
.84345 .74496 m
.84334 .7452 L
.84315 .74565 L
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
Mistroke
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
Mfstroke
.81384 .81451 m
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
s
.80909 .83492 m
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
Mistroke
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
Mistroke
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
Mfstroke
.6744 .93349 m
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
Mistroke
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
Mfstroke
.6426 .9335 m
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
Mistroke
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
Mfstroke
.42637 .94992 m
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
Mistroke
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
Mistroke
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
Mistroke
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
Mistroke
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
.08243 .46962 m
.08244 .46945 L
.08253 .4692 L
.08274 .46889 L
.08308 .46851 L
.08354 .46806 L
.08412 .46755 L
.0848 .46701 L
.08551 .46642 L
.0863 .46581 L
.08711 .46519 L
.0879 .4646 L
.08866 .46405 L
.08931 .46359 L
.08986 .46322 L
.09029 .46292 L
.0906 .46272 L
.09079 .46259 L
.09088 .46253 L
.09091 .46251 L
.09093 .46251 L
.09098 .4625 L
.09112 .46246 L
.09139 .46238 L
.09184 .46223 L
.09247 .462 L
.09332 .46168 L
.09441 .46129 L
.09567 .46088 L
.09715 .46046 L
.09871 .46003 L
.10046 .45955 L
.1022 .45903 L
.10427 .45847 L
.10605 .4579 L
.10788 .45733 L
.10985 .45679 L
.11173 .45629 L
.11365 .45583 L
.11548 .45541 L
.11696 .45503 L
.11847 .45466 L
.11984 .4543 L
.12115 .45394 L
.12236 .45358 L
.1236 .45332 L
.12481 .4531 L
.12606 .45293 L
.12729 .4528 L
.12853 .45268 L
Mistroke
.12976 .45256 L
.13091 .45241 L
.13207 .45221 L
.13322 .45197 L
.13434 .45168 L
.13541 .45136 L
.13633 .45102 L
.13715 .4507 L
.1378 .45044 L
.13824 .45027 L
.13843 .45022 L
.13835 .45032 L
.13803 .45057 L
.13751 .45098 L
.13689 .45154 L
.13625 .45222 L
.13566 .45298 L
.13517 .45381 L
.13479 .45468 L
.13454 .45563 L
.13442 .45667 L
.13446 .45781 L
.13467 .45902 L
.13504 .46025 L
.13566 .46153 L
.13641 .46287 L
.13731 .46425 L
.13833 .46559 L
.13936 .46697 L
.14033 .46832 L
.14118 .46966 L
.1419 .47091 L
.14252 .47199 L
.14306 .47297 L
.14352 .47386 L
.14394 .47464 L
.14436 .47534 L
.1448 .47597 L
.14528 .47652 L
.14584 .47701 L
.14654 .47746 L
.14741 .47789 L
.14843 .47827 L
.14965 .47864 L
.15105 .47901 L
.15266 .47936 L
.1543 .47967 L
.15607 .47991 L
.15791 .48008 L
.15974 .48016 L
Mistroke
.16148 .48017 L
.163 .48012 L
.16434 .48003 L
.16538 .47994 L
.16613 .4799 L
.16659 .47992 L
.16678 .47998 L
.16675 .48005 L
.16652 .48009 L
.16617 .48009 L
.16574 .48001 L
.16529 .47987 L
.16479 .47964 L
.16429 .47932 L
.16383 .4789 L
.16344 .47839 L
.16319 .47781 L
.16311 .47718 L
.16323 .47652 L
.16349 .47584 L
.16382 .47517 L
.16418 .47457 L
.1645 .4741 L
.16477 .4738 L
.16496 .47369 L
.16507 .47373 L
.16506 .47386 L
.16492 .47405 L
.16458 .47424 L
.16395 .47437 L
.16318 .47438 L
.16219 .47424 L
.1609 .47395 L
.15918 .4735 L
.15705 .47285 L
.15526 .47211 L
.15267 .4711 L
.15036 .47007 L
.14715 .46892 L
.14451 .46769 L
.14106 .46648 L
.13855 .46543 L
.13476 .46449 L
.13185 .46369 L
.12811 .46305 L
.12552 .46254 L
.12177 .46213 L
.11897 .46182 L
.11542 .46162 L
.11289 .46152 L
Mistroke
.10957 .46155 L
.10635 .46174 L
.10373 .46211 L
.10007 .46264 L
.0975 .46333 L
.09443 .46419 L
.09109 .46521 L
.08847 .46616 L
.0859 .46723 L
.08392 .46824 L
.08154 .46935 L
.0794 .47066 L
.07788 .47178 L
.07663 .47288 L
.07558 .47395 L
.07477 .47498 L
.07418 .47595 L
.07377 .47683 L
.07348 .47761 L
.07328 .47827 L
.0731 .47885 L
.07297 .4794 L
.07292 .48001 L
.0729 .48046 L
.07285 .48091 L
.07283 .48124 L
.07287 .48144 L
Mfstroke
.07656 .49788 m
.07648 .49774 L
.07631 .49745 L
.07607 .49706 L
.07577 .49663 L
.07544 .49619 L
.0751 .49573 L
.07479 .49527 L
.07452 .49479 L
.0743 .49427 L
.07416 .49371 L
.07411 .4931 L
.07417 .49243 L
.07433 .49171 L
.07457 .49093 L
.07487 .49011 L
.07521 .48935 L
.07557 .48849 L
.07591 .48749 L
.07621 .48643 L
.07646 .48529 L
.07667 .48406 L
.07683 .48298 L
.07695 .48186 L
.07703 .48071 L
.07711 .47954 L
.07723 .47837 L
.07739 .47737 L
.07763 .47629 L
.07797 .47524 L
.07839 .47426 L
.07888 .47327 L
.07936 .47227 L
.07986 .47139 L
.08038 .47052 L
.08092 .46968 L
.08143 .4689 L
.08194 .46818 L
.08242 .46755 L
.08288 .46698 L
.08328 .4665 L
.08362 .46606 L
.0839 .46568 L
.08413 .46534 L
.08434 .46504 L
.08455 .4648 L
.08479 .46463 L
.08506 .46454 L
.08535 .46451 L
.08567 .46454 L
Mistroke
.08599 .46461 L
.08629 .46468 L
.08657 .46473 L
.08682 .46474 L
.08706 .46474 L
.08728 .46474 L
.08751 .46474 L
.08774 .46474 L
.08794 .46473 L
.08811 .46473 L
Mfstroke
.08794 .46459 m
.0879 .46447 L
.08792 .46428 L
.08802 .464 L
.08823 .46361 L
.08854 .46311 L
.08895 .46245 L
.08944 .46158 L
.09002 .4605 L
.09067 .45921 L
.09132 .45793 L
.09198 .4561 L
.09265 .45435 L
.09338 .45224 L
.09418 .44988 L
.09483 .44731 L
.09544 .44454 L
.0959 .44142 L
.09632 .43866 L
.09664 .43627 L
.09688 .4335 L
.09706 .43094 L
.0972 .42799 L
.09727 .42579 L
.09723 .42364 L
.09707 .42151 L
.09679 .41974 L
.09637 .41811 L
.09581 .41664 L
.09519 .41543 L
.0945 .41441 L
.09376 .41355 L
.093 .41284 L
.09227 .41229 L
.09163 .41186 L
.09101 .41154 L
.09044 .41132 L
.08994 .41119 L
.08956 .41113 L
.08931 .41113 L
s
.08955 .41166 m
.08937 .41149 L
.08908 .41118 L
.08868 .41073 L
.08821 .41015 L
.08771 .40943 L
.0872 .4086 L
.08671 .4078 L
.08625 .40694 L
.08578 .40606 L
.0853 .40516 L
.08486 .40443 L
.0845 .4038 L
.08425 .40328 L
.08409 .40289 L
.084 .40259 L
.08399 .40236 L
.08407 .40215 L
.0842 .40189 L
.08434 .40146 L
.0845 .40079 L
.08468 .39986 L
.08488 .39859 L
.08512 .39692 L
.08539 .39515 L
.08568 .39276 L
.08601 .39019 L
.08637 .3874 L
.08678 .38417 L
.08722 .38054 L
.08769 .37667 L
.08815 .37239 L
.08863 .36874 L
.08911 .36398 L
.08963 .36015 L
.0902 .35568 L
.09085 .351 L
.09157 .34648 L
.09229 .34188 L
.09304 .33794 L
.09381 .33363 L
.09457 .33014 L
.09523 .32673 L
.09598 .32352 L
.09662 .32057 L
.09724 .31839 L
.09785 .31632 L
.09843 .31466 L
.09894 .31324 L
.09937 .31212 L
Mistroke
.09972 .31147 L
.09999 .31095 L
.1002 .31061 L
.10036 .3104 L
.10049 .31032 L
.10059 .31026 L
.10067 .31019 L
.1007 .31009 L
.10067 .30997 L
.10062 .30982 L
.10056 .30963 L
.10053 .30937 L
.10055 .30906 L
.10063 .30868 L
.10078 .30827 L
.10096 .30785 L
.10118 .30744 L
.1014 .30709 L
.10158 .3068 L
.10172 .30662 L
.10187 .30646 L
.10204 .30632 L
.10227 .3062 L
.10255 .30602 L
.1029 .30572 L
.10333 .30524 L
.10386 .30449 L
.10454 .30339 L
.10539 .3019 L
.10643 .30015 L
.10752 .29802 L
.10892 .29582 L
.11039 .29324 L
.11209 .2902 L
.11384 .28711 L
.11574 .28413 L
.11752 .28085 L
.11941 .2775 L
.12129 .27414 L
.12307 .27098 L
.1249 .26778 L
.12671 .2647 L
.12853 .26157 L
.13049 .25844 L
.1324 .25523 L
.13444 .25188 L
.13649 .24866 L
.1386 .24501 L
.14076 .24164 L
.14299 .23805 L
Mistroke
.14531 .23434 L
.1475 .23089 L
.14976 .22731 L
.15224 .22351 L
.15436 .22016 L
.15671 .21649 L
.15906 .21276 L
.16165 .20913 L
.1639 .20533 L
.16633 .2017 L
.16879 .1981 L
.17113 .19446 L
.17346 .19099 L
.17579 .18749 L
.17798 .18398 L
.17999 .18071 L
.18202 .17732 L
.18397 .1738 L
.18584 .17083 L
.18755 .16781 L
.18925 .16488 L
.19079 .16256 L
.19232 .16023 L
.19363 .15828 L
.19484 .15646 L
.19604 .15493 L
.197 .15367 L
.19786 .15264 L
.19859 .15187 L
.19917 .15136 L
.19957 .1511 L
.19978 .15106 L
.19982 .15116 L
.19975 .15133 L
.19964 .15145 L
.19956 .15143 L
.1996 .15123 L
.19979 .1508 L
.20016 .15014 L
.20073 .14926 L
.20149 .14819 L
.20247 .14694 L
.20371 .1455 L
.20515 .14393 L
.20678 .14223 L
.20874 .14038 L
.21096 .13837 L
.21312 .13637 L
.2157 .13425 L
.21838 .13218 L
Mistroke
.22103 .13014 L
.22393 .12818 L
.22664 .1263 L
.22936 .12468 L
.23195 .12312 L
.2343 .12185 L
.23642 .12069 L
.23828 .11976 L
.23985 .11901 L
.24105 .11846 L
.242 .11811 L
.24272 .11794 L
.24322 .1179 L
.24355 .11796 L
.24375 .11809 L
Mfstroke
.24411 .11892 m
.24425 .11881 L
.24447 .11856 L
.24481 .11814 L
.24533 .11754 L
.24608 .11676 L
.2471 .1158 L
.24843 .11478 L
.24997 .11356 L
.25179 .11211 L
.25405 .11064 L
.25651 .10894 L
.25932 .10708 L
.2627 .10514 L
.26561 .10319 L
.26893 .10107 L
.27257 .09909 L
.27569 .09696 L
.27906 .09495 L
.28232 .09285 L
.28565 .09059 L
.28874 .08849 L
.29197 .08615 L
.2954 .08397 L
.29875 .08165 L
.30248 .0792 L
.30607 .07692 L
.30991 .07448 L
.31399 .07207 L
.318 .06956 L
.32208 .06703 L
.32671 .06433 L
.33062 .06172 L
.33505 .05898 L
.33922 .0563 L
.34365 .0536 L
.34758 .05118 L
.35139 .04886 L
.35495 .04663 L
.35829 .04472 L
.36117 .04318 L
.36375 .0418 L
.36607 .04063 L
.36783 .03972 L
.36939 .03905 L
.37057 .03862 L
.37147 .0384 L
.37209 .03831 L
.37245 .03834 L
.37259 .03844 L
Mistroke
Mfstroke
1 .964 0 r
.008 w
.37161 .03888 Mdot
.016 w
.37161 .03888 m
.37178 .03891 L
s
1 .929 0 r
.008 w
.37178 .03891 Mdot
.016 w
.37178 .03891 m
.37207 .03897 L
s
1 .893 0 r
.008 w
.37207 .03897 Mdot
.016 w
.37207 .03897 m
.37251 .03905 L
s
1 .857 0 r
.008 w
.37251 .03905 Mdot
.016 w
.37251 .03905 m
.37313 .03913 L
s
1 .821 0 r
.008 w
.37313 .03913 Mdot
.016 w
.37313 .03913 m
.37392 .03919 L
s
1 .786 0 r
.008 w
.37392 .03919 Mdot
.016 w
.37392 .03919 m
.37491 .0392 L
s
1 .75 0 r
.008 w
.37491 .0392 Mdot
.016 w
.37491 .0392 m
.3761 .03914 L
s
1 .714 0 r
.008 w
.3761 .03914 Mdot
.016 w
.3761 .03914 m
.3775 .03901 L
s
1 .679 0 r
.008 w
.3775 .03901 Mdot
.016 w
.3775 .03901 m
.37906 .0388 L
s
1 .643 0 r
.008 w
.37906 .0388 Mdot
.016 w
.37906 .0388 m
.38089 .03852 L
s
1 .607 0 r
.008 w
.38089 .03852 Mdot
.016 w
.38089 .03852 m
.38273 .03818 L
s
1 .571 0 r
.008 w
.38273 .03818 Mdot
.016 w
.38273 .03818 m
.38483 .03781 L
s
1 .536 0 r
.008 w
.38483 .03781 Mdot
.016 w
.38483 .03781 m
.38699 .03742 L
s
1 .5 0 r
.008 w
.38699 .03742 Mdot
.016 w
.38699 .03742 m
.38932 .03704 L
s
1 .464 0 r
.008 w
.38932 .03704 Mdot
.016 w
.38932 .03704 m
.39142 .03666 L
s
1 .429 0 r
.008 w
.39142 .03666 Mdot
.016 w
.39142 .03666 m
.39365 .03628 L
s
1 .393 0 r
.008 w
.39365 .03628 Mdot
.016 w
.39365 .03628 m
.39576 .03594 L
s
1 .357 0 r
.008 w
.39576 .03594 Mdot
.016 w
.39576 .03594 m
.39777 .03564 L
s
1 .321 0 r
.008 w
.39777 .03564 Mdot
.016 w
.39777 .03564 m
.39958 .03541 L
s
1 .286 0 r
.008 w
.39958 .03541 Mdot
.016 w
.39958 .03541 m
.40122 .03526 L
s
1 .25 0 r
.008 w
.40122 .03526 Mdot
.016 w
.40122 .03526 m
.40265 .03519 L
s
1 .214 0 r
.008 w
.40265 .03519 Mdot
.016 w
.40265 .03519 m
.40388 .03519 L
s
1 .179 0 r
.008 w
.40388 .03519 Mdot
.016 w
.40388 .03519 m
.40483 .03524 L
s
1 .143 0 r
.008 w
.40483 .03524 Mdot
.016 w
.40483 .03524 m
.40557 .03533 L
s
1 .107 0 r
.008 w
.40557 .03533 Mdot
.016 w
.40557 .03533 m
.40612 .03542 L
s
1 .071 0 r
.008 w
.40612 .03542 Mdot
.016 w
.40612 .03542 m
.40648 .03549 L
s
1 .036 0 r
.008 w
.40648 .03549 Mdot
.016 w
.40648 .03549 m
.40666 .03552 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool0075oo`9m
X0Eoo`hmkaAoo`T007eoo`00KGoo0cg_00=mH7dPO<0017c073g_47oo1P00Mgoo001YOol02Cg_Ob1n
X7iPOR1mh7fPOF1m8002O<000gb0O21l`00M?NlEOol5001bOol006Moo`<mk`08Ob1nX7iPOR1mh7fP
OF1m809l`003O81l87c001hmkaUoo`@006ioo`00IGoo1Cg_00Ao87jPOV1n809mh003OF1m87c000Al
`1hmkaeoo`@006Yoo`00Hgoo1cg_00Ao87jPOV1n80=mh003OJ1mh3g_024mkb5oo`<006Moo`00HWoo
<cg_97oo0`00I7oo001POolO?Nl7Ool8?Nl^Ool3001QOol005iooa8mk`03Oolmkcg_00Xmk`Uoo`@m
kcEoo`8005moo`00G7oo4Sg_1Goo00<mkgooOol01Sg_AGoo0P00GGoo001JOol00`00?Nlmk`0;?NmK
Ool2001KOol005Qoo`03000mkcg_00Tmkf5oo`8005Uoo`00EGoo0`002Sg_IGoo0`00EWoo001COol2
0002Ool;?NmXOol2001DOol0055oo`8000`mkfeoo`80059oo`00D7oo00<007ooOol033g_Kgoo00<0
07ooOol0Cgoo001?Ool00`00Oolmk`0=?Nm`Ool00`00Oomoo`1>Ool004eoo`800003Oolmkcg_00`m
kg9oo`8004ioo`00Bgoo0P0000=oocg_?Nl02cg_Mgoo0P00C7oo0019Ool200000goo?Nlmk`0<?Nmj
Ool2001:Ool004Qoo`03001oocg_00lmkgaoo`03001oogoo04Moo`00AWoo0P0000=oocg_?Nl03cg_
OGoo0P00Agoo0015Ool00`00Oolmk`0A?Nn0Ool00`00Oomoo`14Ool004Aoo`03001oocg_00lmkhAo
o`03001oogoo04=oo`00@goo00<003g_?Nl03cg_QWoo00<007ooOol0@Woo0011Ool2000@?Nn9Ool2
0012Ool0041oo`03001oocg_010mkh]oo`03001oogoo03moo`00?goo00<003g_?Nl02Sg_Tgoo0P00
?goo000nOol00`00?Nlmk`0:?NnFOol00`00Oomoo`0lOol003aoo`8000`mkiQoo`03001oogoo03]o
o`00>goo00<007oo?Nl02cg_VWoo00<007ooOol0>Woo000jOol00`00?Nlmk`0;?NnLOol2000jOol0
03Uoo`03000mkcg_00Xmkj1oo`03001oogoo03Moo`00=goo0P0000=oocg_?Nl02Sg_XGoo00<007oo
Ool0=Woo000fOol00`00Oomoo`09?NnVOol00`00Oomoo`0eOol003Eoo`03001oogoo00XmkjMoo`03
001oogoo03Aoo`00=7oo00@007ooOomoo`TmkjUoo`03001oogoo03=oo`00<Woo0P000goo2Sg_ZWoo
00<007ooOol0<Woo000aOol00`00Oomoo`02Ool;?Nn[Ool00`00Oomoo`0aOol0031oo`03001oogoo
009oo``mkjaoo`03001oogoo031oo`00<7oo00<007ooOol00Woo2cg_[Woo00<007ooOol0;goo000_
Ool00`00Oomoo`02Ool:?NnaOol00`00Oomoo`0^Ool002ioo`03001oogoo00=oo`Xmkk9oo`03001o
ogoo02eoo`00;Goo00<007ooOol017oo2Sg_/goo00<007ooOol0;7oo000/Ool00`00Oomoo`04Ool:
?NneOol00`00Oomoo`0[Ool002aoo`03001oogoo00=oo`XmkkIoo`03001oogoo02]oo`00:goo00<0
07ooOol017oo2Sg_]goo00<007ooOol0:Woo000ZOol00`00Oomoo`04Ool6?NnmOol00`00Oomoo`0Y
Ool002Uoo`03001oogoo00Aoo`Hmkkmoo`03001oogoo02Qoo`00:7oo00<007ooOol017oo1Sg_`Goo
00<007ooOol09goo000XOol00`00Oomoo`04Ool6?No1Ool00`00Oomoo`0WOol002Moo`03001oogoo
00Aoo`Lmkl9oo`03001oogoo02Ioo`009Woo00<007ooOol01Goo23g_`Woo00<007ooOol09Goo000U
Ool00`00Oomoo`05Ool9?No3Ool00`00Oomoo`0TOol002Aoo`03001oogoo00Ioo`PmklEoo`03001o
ogoo02=oo`0097oo00<007ooOol01Goo23g_aWoo00<007ooOol08goo000SOol00`00Oomoo`05Ool8
?No8Ool00`00Oomoo`0ROol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Woo00<0
07ooOol01Goo2Cg_bGoo00<007ooOol08Goo000QOol00`00Oomoo`05Ool9?No;Ool00`00Oomoo`0P
Ool0021oo`03001oogoo00Ioo`Pmkleoo`03001oogoo01moo`0087oo00<007ooOol01Goo1cg_cgoo
00<007ooOol07goo000OOol00`00Oomoo`06Ool6?NoAOol00`00Oomoo`0NOol001moo`03001oogoo
00Eoo`Lmkm9oo`03001oogoo01eoo`007Woo00<007ooOol01Woo1cg_dWoo00<007ooOol07Goo000M
Ool00`00Oomoo`06Ool8?NoCOol00`00Oomoo`0LOol001eoo`03001oogoo00Eoo`Tmkm=oo`03001o
ogoo01aoo`0077oo00<007ooOol01Woo23g_eGoo00<007ooOol06goo000LOol00`00Oomoo`05Ool9
?NoEOol00`00Oomoo`0KOol001]oo`03001oogoo00Ioo`TmkmIoo`03001oogoo01Yoo`006goo00<0
07ooOol01Goo2Cg_egoo00<007ooOol06Woo000JOol00`00Oomoo`05Ool:?NoHOol00`00Oomoo`0I
Ool001Yoo`03001oogoo00Eoo`TmkmUoo`03001oogoo01Uoo`006Goo00<007ooOol01Goo2Cg_fgoo
00<007ooOol067oo000IOol00`00Oomoo`05Ool8?NoLOol00`00Oomoo`0HOol001Qoo`03001oogoo
00Eoo`Pmkmioo`03001oogoo01Moo`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo000H
Ool00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol001Moo`03001oogoo00Aoo`Tmkn1oo`03001o
ogoo01Ioo`005goo00<007ooOol017oo23g_hGoo00<007ooOol05Woo000FOol00`00Oomoo`05Ool8
?NoROol00`00Oomoo`0EOol001Ioo`03001oogoo00Eoo`HmknAoo`03001oogoo01Eoo`005Goo00<0
07ooOol01Woo1Sg_iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0D
Ool001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`0057oo00<007ooOol01Woo1Sg_igoo
00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo
00Eoo`LmknMoo`03001oogoo01=oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000C
Ool00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001o
ogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`07Ool5
?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Ioo`Dmknaoo`03001oogoo015oo`004Goo00<0
07ooOol01goo1Cg_kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool5?No]Ool00`00Oomoo`0@
Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo011oo`004Goo00<007ooOol01goo1Sg_kGoo
00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo
00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@
Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool000moo`03001oogoo00Uoo`Hmknioo`03001o
ogoo00ioo`003goo00<007ooOol02Goo1cg_kGoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool7
?No]Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Lmkneoo`03001oogoo00ioo`003goo00<0
07ooOol02Goo23g_k7oo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool9?No/Ool00`00Oomoo`0=
Ool000ioo`03001oogoo00Yoo``mknUoo`03001oogoo00eoo`003Woo00<007ooOol037oo2Sg_jGoo
00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool;?NoWOol00`00Oomoo`0=Ool000ioo`03001oogoo
00eoo``mknMoo`03001oogoo00aoo`003Goo00<007ooOol03Woo3Cg_iWoo00<007ooOol037oo000=
Ool00`00Oomoo`0>Ool=?NoVOol00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`hmknIoo`03001o
ogoo00aoo`003Goo00<007ooOol03Goo3cg_iGoo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool?
?NoUOol00`00Oomoo`0<Ool000eoo`03001oogoo00aooa4mknAoo`03001oogoo00aoo`003Goo00<0
07ooOol02goo4Sg_i7oo00<007ooOol037oo000=Ool00`00Oomoo`09OolE?NoSOol00`00Oomoo`0<
Ool000eoo`03001oogoo00QooaPmkn5oo`03001oogoo00aoo`003Goo00<007ooOol027oo7Cg_g7oo
00<007ooOol037oo000=Ool00`00Oomoo`08OolN?NoKOol00`00Oomoo`0<Ool000aoo`03001oogoo
00Qooalmkmaoo`03001oogoo00]oo`0037oo00<007ooOol01goo2cg_17oo1Cg_00=oocg_?Nl02Cg_
g7oo00<007ooOol02goo000<Ool00`00Oomoo`06OolQ?NoLOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Eoob4mkmeoo`03001oogoo00]oo`0037oo00<007ooOol027oo5Cg_iWoo00<007ooOol02goo
000<Ool00`00Oomoo`08Ool6?Nl00goo?Nlmk`0<?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`Hmk`Ioo`TmknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo1Sg_iGoo00<0
07ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl:Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001o
ogoo00Moo`Lmk`]oo`HmknAoo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_37oo1cg_i7oo
00<007ooOol02goo000<Ool00`00Oomoo`07Ool5?Nl<Ool9?NoROol00`00Oomoo`0;Ool000aoo`03
001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_37oo2Sg_
hGoo00<007ooOol02goo000=Ool00`00Oomoo`06Ool5?Nl<Ool;?NoPOol00`00Oomoo`0;Ool000eo
o`03001oogoo00Ioo`Dmka1oo`Lmkmmoo`03001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo
23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool5?Nl@Ool8?NoNOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Ioo`Hmk`moo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol01Woo1Sg_
47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?Nl@Ool8?NoMOol00`00Oomoo`0<
Ool000eoo`03001oogoo00Moo`Dmka1oo`Pmkmeoo`03001oogoo00aoo`003Goo00<007ooOol01goo
1Cg_47oo2Cg_g7oo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?Nl@Ool;?NoJOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Moo`Dmka5oo`XmkmYoo`03001oogoo00aoo`003Goo00<007ooOol0
1goo1Cg_4Woo2Cg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`06Ool6?NlBOol8?NoIOol00`00
Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmka9oo`Dmkmaoo`03001oogoo00eoo`003Woo00<007oo
Ool01goo1Cg_lgoo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool6?NobOol00`00Oomoo`0=Ool0
00moo`03001oogoo00Ioo`Hmko9oo`03001oogoo00eoo`003goo00<007ooOol01goo1Sg_l7oo00<0
07ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Mo
o`Hmko1oo`03001oogoo00ioo`003goo00<007ooOol01goo1Sg_l7oo00<007ooOol03Woo000@Ool0
0`00Oomoo`06Ool6?No`Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Ioo`Hmknmoo`03001oogoo
00moo`0047oo00<007ooOol01Woo1Cg_l7oo00<007ooOol03goo000@Ool00`00Oomoo`06Ool6?No_
Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Hmknmoo`03001oogoo00moo`004Goo00<007oo
Ool01Goo1Sg_kgoo00<007ooOol03goo000AOol00`00Oomoo`06Ool6?No]Ool00`00Oomoo`0@Ool0
015oo`03001oogoo00Ioo`Dmknioo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kWoo00<0
07ooOol047oo000BOol00`00Oomoo`05Ool5?No]Ool00`00Oomoo`0AOol0019oo`03001oogoo00Eo
o`Dmkneoo`03001oogoo015oo`004goo00<007ooOol01Goo13g_kGoo00<007ooOol04Goo000COol0
0`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001=oo`03001oogoo00Eoo`Dmkn]oo`03001oogoo
019oo`0057oo00<007ooOol017oo1Cg_fWoo00<mkgooOol03Woo00<007ooOol04Woo000DOol00`00
Oomoo`04Ool6?NoIOol2?Nl>Ool00`00Oomoo`0COol001Aoo`03001oogoo00Aoo`HmkmUoo`<mk`eo
o`03001oogoo01=oo`005Goo00<007ooOol00goo1Sg_fGoo13g_37oo00<007ooOol04goo000EOol0
0`00Oomoo`03Ool6?NoBOol<?Nl:Ool00`00Oomoo`0DOol001Eoo`03001oogoo00=oo`Hmkm=oo`/m
k`Yoo`03001oogoo01Aoo`005Goo00<007ooOol017oo1Cg_e7oo2Sg_2Woo00<007ooOol057oo000F
Ool00`00Oomoo`03Ool5?NoEOol9?Nl9Ool00`00Oomoo`0EOol001Ioo`03001oogoo00=oo`DmkmEo
o`Tmk`Uoo`03001oogoo01Eoo`005goo00<007ooOol00Woo1Cg_eGoo23g_2Goo00<007ooOol05Woo
000GOol00`00Oomoo`02Ool6?NoDOol8?Nl9Ool00`00Oomoo`0FOol001Qoo`04001oogooOol6?NoD
Ool8?Nl8Ool00`00Oomoo`0GOol001Qoo`04001oogooOol6?NoCOol9?Nl8Ool00`00Oomoo`0GOol0
01Uoo`04001oogooOol6?No@Ool;?Nl8Ool00`00Oomoo`0GOol001Uoo`04001oogooOol7?No>Ool;
?Nl8Ool00`00Oomoo`0HOol001Yoo`03001oogoo00Lmkleoo``mk`Qoo`03001oogoo01Qoo`006Woo
00@007ooOomoo`LmklUoo`hmk`Qoo`03001oogoo01Uoo`006goo00<007ooOol023g_aWoo43g_1goo
00<007ooOol06Woo000KOol00`00Oomoo`09?No5Ool@?Nl7Ool00`00Oomoo`0JOol001aoo`03001o
ocg_00TmklAooa0mk`Ioo`03001oogoo01]oo`0077oo00<007ooOol02Sg_`goo1Sg_0goo1Sg_1goo
00<007ooOol06goo000MOol00`00Oolmk`09?No2Ool5?Nl5Ool6?Nl6Ool00`00Oomoo`0LOol001eo
o`03001oocg_00Xmkl5oo`Dmk`Eoo`Hmk`Ioo`03001oogoo01aoo`007Woo00<003g_?Nl02Cg_`Goo
1Cg_1Goo1Cg_1Woo00<007ooOol07Goo000NOol00`00?Nlmk`09?No1Ool5?Nl5Ool5?Nl6Ool00`00
Oomoo`0MOol001moo`/mkl5oo`@mk`Eoo`Hmk`Eoo`03001oogoo01ioo`007goo00<003g_?Nl02Cg_
_goo1Cg_1Goo1Sg_1Goo00<007ooOol07Woo000POol00`00?Nlmk`08?NnoOol5?Nl4Ool6?Nl5Ool0
0`00Oomoo`0OOol0021oo`03000mkcg_00Tmkkeoo`Dmk`Eoo`Hmk`Eoo`03001oogoo01moo`008Goo
2cg__Goo1Cg_1Goo1Sg_17oo00<007ooOol087oo000ROol00`00?Nlmk`08?NnlOol5?Nl4Ool7?Nl3
Ool00`00Oomoo`0QOol002=oo`Xmkk]oo`Hmk`Aoo`Hmk`=oo`03001oogoo029oo`0097oo2Sg_^Woo
1Cg_1Goo1Sg_0Woo00<007ooOol08goo000TOol00`00?Nlmk`07?NnjOol4?Nl5Ool7?Nl2Ool00`00
Oomoo`0SOol002Eoo`XmkkQoo`Dmk`Eoo`Dmk`=oo`03001oogoo02Aoo`009Woo00<003g_?Nl01cg_
]Woo1Sg_17oo1cg_00=oo`00Ool09Woo000VOol00`00Oolmk`0;?NnbOol5?Nl4Ool7?Nl2Ool00`00
Oomoo`0UOol002Moo`03001oocg_00Xmkk9oo`Dmk`=oo`Pmk`03Ool007oo02Moo`00:7oo00<007oo
?Nl02Cg_/Goo1Sg_0Woo23g_00=oo`00Ool0:7oo000YOol00`00Oolmk`09?Nn`Ool5?Nl2Ool8?Nl0
0goo001oo`0YOol002Yoo`03001oocg_00Pmkk1oo`@mk`9oo`Tmk`03001oogoo02Uoo`00:Woo00<0
07ooOol02Cg_[Woo1Cg_0Woo2Cg_00<007ooOol0:Goo000[Ool00`00Oomoo`09?Nn]Ool5?Nl2Ool8
?Nl00`00Oomoo`0ZOol002aoo`03001oocg_00Pmkjaoo`Dmk`03Oolmkcg_00Lmk`03001oogoo02]o
o`00;Goo00<007oo?Nl023g_Zgoo1Cg_00=oocg_?Nl01Sg_00<007ooOol0;7oo000^Ool00`00Oomo
o`09?NnYOol=?Nl00`00Oomoo`0]Ool002ioo`04001oogooOol9?NnXOol:?Nl3Ool00`00Oomoo`0]
Ool002moo`04001oogooOol:?NnUOol:?Nl3Ool00`00Oomoo`0^Ool0031oo`04001oogooOol:?NnT
Ool9?Nl3Ool00`00Oomoo`0_Ool0035oo`04001oogooOol<?NnPOol8?Nl4Ool00`00Oomoo`0`Ool0
039oo`80009oo`dmkiaoo`Tmk`=oo`8003=oo`00=7oo00<007ooOol033g_VWoo2Sg_0goo00<007oo
Ool0<goo000eOol00`00Oolmk`0<?NnHOol:?Nl3Ool00`00Oomoo`0dOol003Eoo`04001oogooOol;
?NnFOol<?Nl3Ool00`00Oomoo`0dOol003Ioo`04001oogooOol;?NnDOol:?Nl5Ool00`00Oomoo`0e
Ool003Moo`03001oogoo009oo`TmkiAoo`Pmk`Ioo`03001oogoo03Ioo`00>7oo00<007ooOol00Woo
2Cg_TWoo2Cg_1Goo00<007ooOol0=goo000iOol20003Ool8?NnAOol:?Nl3Ool2000jOol003]oo`03
001oogoo00Tmkhmoo`Xmk`=oo`03001oogoo03Yoo`00?7oo00<007ooOol02Cg_SGoo2Sg_0goo00<0
07ooOol0>goo000mOol00`00Oomoo`0:?Nn9Ool9?Nl5Ool00`00Oomoo`0lOol003ioo`80009oo`Tm
khMoo`Tmk`Aoo`8003moo`00@7oo00<007ooOol02Cg_Q7oo2cg_0goo00<007ooOol0?goo0011Ool2
00000goo?Nlmk`07?Nn2Ool9?Nl4Ool20012Ool004=oo`03001oocg_00TmkgYoo`hmk`Aoo`03001o
ogoo049oo`00A7oo00<003g_?Nl02Cg_NGoo3Cg_17oo00<007ooOol0@goo0015Ool00`00?Nlmk`0:
?NmgOol;?Nl5Ool00`00Oomoo`14Ool004Ioo`03000mkcg_00/mkgAoo``mk`=oo`8004Moo`00B7oo
3Sg_0Woo0Sg_K7oo3Cg_0Woo0P00BGoo001:OolA?NmZOol<?Nl2Ool2001;Ool004aooa0mkfMoo`/m
k`=oo`8004eoo`00CWoo4Cg_Hgoo2cg_0goo00<007ooOol0CGoo001?Ool00`00?Nlmk`0??NmPOol<
?Nl2Ool00`00Oomoo`1>Ool0051oo`800003Oolmkcg_00lmkeUoo`03?Nmoogoo00Xmk`=oo`80055o
o`00DWoo0P0000=oocg_?Nl043g_DWoo00<mkgooOol03Sg_00=oo`000000Dgoo001DOol200000cg_
Oolmk`0@?Nl7Ool5?Nm0OolC?Nl00goo0000001EOol005Ioo`8000Aooa0mk`=oo`Hmkciooa@mk`80
05Moo`00F7oo0`0017oo5Sg_?7oo5Cg_00<007ooOol0Egoo001KOol30003OolD?NliOolD?Nl2001L
Ool005ioo`8000Aooa8mkcAooaPmkeioo`00H7oo0P0017oo5cg_97oo7Sg_HGoo001ROol30004OolD
?Nl@Ool2?Nl=OolP?Nl00`00Oomoo`1QOol006Eoo`<000EoobHmk`9oob8mk`<006Ioo`00J7oo1000
0gooA3g_00@003g_000006Uoo`00K7oo10000goo>cg_00=oo`0000000P00KGoo001`Ool30003Ool`
?Nl5Ool4001aOol007=oo`D00003Oolmkcg_02Dmk`Moo`@007Eoo`00N7oo10007Cg_1goo1`00NGoo
001nOol@?Nl4Ool>0020Ool008eoo`D008ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00Qgoo1@000Woo0P0017oo0P00RWoo0029Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo08Moo`00RGoo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`27Ool0
08Uoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0Qgoo0029Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo08Moo`00R7oo0P0017oo0P0017oo0P00RWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}]
}, Closed]],

Cell[BoxData[
    \(animation\ of\ \(\(excursions\)\(:\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(exc = Excursions[{\(-150\), \(-20\)}, 20];\)\)], "Input"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(1\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(Part::"pspec" \(\(:\)\(\ \)\) 
      "Part specification \!\(\(\({}\)\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\) is neither an integer nor a list of integers."\)], \
"Message"],

Cell[BoxData[
    \(Part::"pspec" \(\(:\)\(\ \)\) 
      "Part specification \!\(\(\({}\)\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\) is neither an integer nor a list of integers."\)], \
"Message"],

Cell[BoxData[
    \(Part::"pspec" \(\(:\)\(\ \)\) 
      "Part specification \!\(\(\({}\)\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\) is neither an integer nor a list of integers."\)], \
"Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"pspec\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(2\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(1\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partw\"\) will be suppressed during \
this calculation."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Length[exc[\([1]\)]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(13\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[See[{AnimSeg[i, exc[\([1]\)]], \ 
          TimePlot1[StopsPerExcursion[reallingering, \ i]]}, 
        DisplayFunction -> $DisplayFunction, PlotLabel -> i], {i, 1, 
        12}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.52398 0.00266006 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(1)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.45221 0.47619 scale
1.15871 1.05 1 0 365.73 arc
setmatrix s
1 .998 0 r
.008 w
.12929 .39535 Mdot
.016 w
.12929 .39535 m
.12939 .39522 L
s
1 .995 0 r
.008 w
.12939 .39522 Mdot
.016 w
.12939 .39522 m
.12953 .39503 L
s
1 .993 0 r
.008 w
.12953 .39503 Mdot
.016 w
.12953 .39503 m
.1297 .39476 L
s
1 .99 0 r
.008 w
.1297 .39476 Mdot
.016 w
.1297 .39476 m
.12989 .39442 L
s
1 .988 0 r
.008 w
.12989 .39442 Mdot
.016 w
.12989 .39442 m
.13009 .39398 L
s
1 .986 0 r
.008 w
.13009 .39398 Mdot
.016 w
.13009 .39398 m
.13028 .39344 L
s
1 .983 0 r
.008 w
.13028 .39344 Mdot
.016 w
.13028 .39344 m
.13047 .39282 L
s
1 .981 0 r
.008 w
.13047 .39282 Mdot
.016 w
.13047 .39282 m
.13065 .39214 L
s
1 .979 0 r
.008 w
.13065 .39214 Mdot
.016 w
.13065 .39214 m
.13085 .39138 L
s
1 .976 0 r
.008 w
.13085 .39138 Mdot
.016 w
.13085 .39138 m
.13108 .39053 L
s
1 .974 0 r
.008 w
.13108 .39053 Mdot
.016 w
.13108 .39053 m
.13134 .38961 L
s
1 .971 0 r
.008 w
.13134 .38961 Mdot
.016 w
.13134 .38961 m
.13164 .38868 L
s
1 .969 0 r
.008 w
.13164 .38868 Mdot
.016 w
.13164 .38868 m
.13193 .38771 L
s
1 .967 0 r
.008 w
.13193 .38771 Mdot
.016 w
.13193 .38771 m
.13219 .38674 L
s
1 .964 0 r
.008 w
.13219 .38674 Mdot
.016 w
.13219 .38674 m
.13246 .38582 L
s
1 .962 0 r
.008 w
.13246 .38582 Mdot
.016 w
.13246 .38582 m
.13273 .38496 L
s
1 .959 0 r
.008 w
.13273 .38496 Mdot
.016 w
.13273 .38496 m
.133 .3841 L
s
1 .957 0 r
.008 w
.133 .3841 Mdot
.016 w
.133 .3841 m
.13329 .38322 L
s
1 .955 0 r
.008 w
.13329 .38322 Mdot
.016 w
.13329 .38322 m
.1336 .38231 L
s
1 .952 0 r
.008 w
.1336 .38231 Mdot
.016 w
.1336 .38231 m
.1339 .38135 L
s
1 .95 0 r
.008 w
.1339 .38135 Mdot
.016 w
.1339 .38135 m
.13416 .38041 L
s
1 .947 0 r
.008 w
.13416 .38041 Mdot
.016 w
.13416 .38041 m
.13437 .37941 L
s
1 .945 0 r
.008 w
.13437 .37941 Mdot
.016 w
.13437 .37941 m
.13451 .37835 L
s
1 .943 0 r
.008 w
.13451 .37835 Mdot
.016 w
.13451 .37835 m
.13456 .37722 L
s
1 .94 0 r
.008 w
.13456 .37722 Mdot
.016 w
.13456 .37722 m
.13453 .37612 L
s
1 .938 0 r
.008 w
.13453 .37612 Mdot
.016 w
.13453 .37612 m
.13444 .3749 L
s
1 .936 0 r
.008 w
.13444 .3749 Mdot
.016 w
.13444 .3749 m
.13435 .3737 L
s
1 .933 0 r
.008 w
.13435 .3737 Mdot
.016 w
.13435 .3737 m
.13427 .37248 L
s
1 .931 0 r
.008 w
.13427 .37248 Mdot
.016 w
.13427 .37248 m
.13421 .37117 L
s
1 .928 0 r
.008 w
.13421 .37117 Mdot
.016 w
.13421 .37117 m
.13416 .36984 L
s
1 .926 0 r
.008 w
.13416 .36984 Mdot
.016 w
.13416 .36984 m
.13415 .36862 L
s
1 .924 0 r
.008 w
.13415 .36862 Mdot
.016 w
.13415 .36862 m
.13415 .36741 L
s
1 .921 0 r
.008 w
.13415 .36741 Mdot
.016 w
.13415 .36741 m
.13414 .36629 L
s
1 .919 0 r
.008 w
.13414 .36629 Mdot
.016 w
.13414 .36629 m
.13415 .36529 L
s
1 .916 0 r
.008 w
.13415 .36529 Mdot
.016 w
.13415 .36529 m
.13417 .36442 L
s
1 .914 0 r
.008 w
.13417 .36442 Mdot
.016 w
.13417 .36442 m
.13423 .36366 L
s
1 .912 0 r
.008 w
.13423 .36366 Mdot
.016 w
.13423 .36366 m
.13433 .363 L
s
1 .909 0 r
.008 w
.13433 .363 Mdot
.016 w
.13433 .363 m
.13446 .3624 L
s
1 .907 0 r
.008 w
.13446 .3624 Mdot
.016 w
.13446 .3624 m
.13463 .36179 L
s
1 .905 0 r
.008 w
.13463 .36179 Mdot
.016 w
.13463 .36179 m
.13481 .36113 L
s
1 .902 0 r
.008 w
.13481 .36113 Mdot
.016 w
.13481 .36113 m
.13498 .36037 L
s
1 .9 0 r
.008 w
.13498 .36037 Mdot
.016 w
.13498 .36037 m
.13515 .35951 L
s
1 .897 0 r
.008 w
.13515 .35951 Mdot
.016 w
.13515 .35951 m
.13532 .3585 L
s
1 .895 0 r
.008 w
.13532 .3585 Mdot
.016 w
.13532 .3585 m
.13554 .35732 L
s
1 .893 0 r
.008 w
.13554 .35732 Mdot
.016 w
.13554 .35732 m
.13582 .35621 L
s
1 .89 0 r
.008 w
.13582 .35621 Mdot
.016 w
.13582 .35621 m
.13618 .35488 L
s
1 .888 0 r
.008 w
.13618 .35488 Mdot
.016 w
.13618 .35488 m
.13662 .35349 L
s
1 .885 0 r
.008 w
.13662 .35349 Mdot
.016 w
.13662 .35349 m
.13713 .35185 L
s
1 .883 0 r
.008 w
.13713 .35185 Mdot
.016 w
.13713 .35185 m
.13769 .35031 L
s
1 .881 0 r
.008 w
.13769 .35031 Mdot
.016 w
.13769 .35031 m
.13826 .34854 L
s
1 .878 0 r
.008 w
.13826 .34854 Mdot
.016 w
.13826 .34854 m
.13882 .34661 L
s
1 .876 0 r
.008 w
.13882 .34661 Mdot
.016 w
.13882 .34661 m
.13937 .3448 L
s
1 .874 0 r
.008 w
.13937 .3448 Mdot
.016 w
.13937 .3448 m
.13989 .34293 L
s
1 .871 0 r
.008 w
.13989 .34293 Mdot
.016 w
.13989 .34293 m
.14038 .3411 L
s
1 .869 0 r
.008 w
.14038 .3411 Mdot
.016 w
.14038 .3411 m
.14087 .33931 L
s
1 .866 0 r
.008 w
.14087 .33931 Mdot
.016 w
.14087 .33931 m
.14138 .33785 L
s
1 .864 0 r
.008 w
.14138 .33785 Mdot
.016 w
.14138 .33785 m
.1419 .33638 L
s
1 .862 0 r
.008 w
.1419 .33638 Mdot
.016 w
.1419 .33638 m
.1424 .33506 L
s
1 .859 0 r
.008 w
.1424 .33506 Mdot
.016 w
.1424 .33506 m
.14286 .33394 L
s
1 .857 0 r
.008 w
.14286 .33394 Mdot
.016 w
.14286 .33394 m
.14325 .3329 L
s
1 .854 0 r
.008 w
.14325 .3329 Mdot
.016 w
.14325 .3329 m
.14357 .33207 L
s
1 .852 0 r
.008 w
.14357 .33207 Mdot
.016 w
.14357 .33207 m
.1438 .3314 L
s
1 .85 0 r
.008 w
.1438 .3314 Mdot
.016 w
.1438 .3314 m
.144 .33089 L
s
1 .847 0 r
.008 w
.144 .33089 Mdot
.016 w
.144 .33089 m
.14417 .33055 L
s
1 .845 0 r
.008 w
.14417 .33055 Mdot
.016 w
.14417 .33055 m
.14436 .3304 L
s
1 .842 0 r
.008 w
.14436 .3304 Mdot
.016 w
.14436 .3304 m
.14455 .33039 L
s
1 .84 0 r
.008 w
.14455 .33039 Mdot
.016 w
.14455 .33039 m
.14472 .3305 L
s
1 .838 0 r
.008 w
.14472 .3305 Mdot
.016 w
.14472 .3305 m
.14485 .33068 L
s
1 .835 0 r
.008 w
.14485 .33068 Mdot
.016 w
.14485 .33068 m
.14491 .33086 L
s
1 .833 0 r
.008 w
.14491 .33086 Mdot
.016 w
.14491 .33086 m
.14491 .33098 L
s
1 .831 0 r
.008 w
.14491 .33098 Mdot
.016 w
.14491 .33098 m
.14484 .33099 L
s
1 .828 0 r
.008 w
.14484 .33099 Mdot
.016 w
.14484 .33099 m
.14471 .33085 L
s
1 .826 0 r
.008 w
.14471 .33085 Mdot
.016 w
.14471 .33085 m
.14453 .33056 L
s
1 .823 0 r
.008 w
.14453 .33056 Mdot
.016 w
.14453 .33056 m
.14432 .3301 L
s
1 .821 0 r
.008 w
.14432 .3301 Mdot
.016 w
.14432 .3301 m
.14409 .3295 L
s
1 .819 0 r
.008 w
.14409 .3295 Mdot
.016 w
.14409 .3295 m
.14385 .32876 L
s
1 .816 0 r
.008 w
.14385 .32876 Mdot
.016 w
.14385 .32876 m
.1436 .32793 L
s
1 .814 0 r
.008 w
.1436 .32793 Mdot
.016 w
.1436 .32793 m
.14335 .3271 L
s
1 .811 0 r
.008 w
.14335 .3271 Mdot
.016 w
.14335 .3271 m
.14311 .32618 L
s
1 .809 0 r
.008 w
.14311 .32618 Mdot
.016 w
.14311 .32618 m
.14287 .32521 L
s
1 .807 0 r
.008 w
.14287 .32521 Mdot
.016 w
.14287 .32521 m
.14264 .32421 L
s
1 .804 0 r
.008 w
.14264 .32421 Mdot
.016 w
.14264 .32421 m
.14245 .32335 L
s
1 .802 0 r
.008 w
.14245 .32335 Mdot
.016 w
.14245 .32335 m
.14229 .32258 L
s
1 .8 0 r
.008 w
.14229 .32258 Mdot
.016 w
.14229 .32258 m
.14217 .32197 L
s
1 .797 0 r
.008 w
.14217 .32197 Mdot
.016 w
.14217 .32197 m
.14208 .32156 L
s
1 .795 0 r
.008 w
.14208 .32156 Mdot
.016 w
.14208 .32156 m
.14202 .32142 L
s
1 .792 0 r
.008 w
.14202 .32142 Mdot
.016 w
.14202 .32142 m
.142 .32155 L
s
1 .79 0 r
.008 w
.142 .32155 Mdot
.016 w
.142 .32155 m
.14201 .32191 L
s
1 .788 0 r
.008 w
.14201 .32191 Mdot
.016 w
.14201 .32191 m
.14205 .32242 L
s
1 .785 0 r
.008 w
.14205 .32242 Mdot
.016 w
.14205 .32242 m
.1421 .32301 L
s
1 .783 0 r
.008 w
.1421 .32301 Mdot
.016 w
.1421 .32301 m
.14217 .3236 L
s
1 .78 0 r
.008 w
.14217 .3236 Mdot
.016 w
.14217 .3236 m
.14228 .32412 L
s
1 .778 0 r
.008 w
.14228 .32412 Mdot
.016 w
.14228 .32412 m
.14244 .32454 L
s
1 .776 0 r
.008 w
.14244 .32454 Mdot
.016 w
.14244 .32454 m
.14265 .32484 L
s
1 .773 0 r
.008 w
.14265 .32484 Mdot
.016 w
.14265 .32484 m
.14292 .32496 L
s
1 .771 0 r
.008 w
.14292 .32496 Mdot
.016 w
.14292 .32496 m
.14323 .3249 L
s
1 .768 0 r
.008 w
.14323 .3249 Mdot
.016 w
.14323 .3249 m
.1436 .32466 L
s
1 .766 0 r
.008 w
.1436 .32466 Mdot
.016 w
.1436 .32466 m
.14401 .32423 L
s
1 .764 0 r
.008 w
.14401 .32423 Mdot
.016 w
.14401 .32423 m
.14447 .32364 L
s
1 .761 0 r
.008 w
.14447 .32364 Mdot
.016 w
.14447 .32364 m
.14498 .32294 L
s
1 .759 0 r
.008 w
.14498 .32294 Mdot
.016 w
.14498 .32294 m
.14552 .32212 L
s
1 .757 0 r
.008 w
.14552 .32212 Mdot
.016 w
.14552 .32212 m
.14604 .3212 L
s
1 .754 0 r
.008 w
.14604 .3212 Mdot
.016 w
.14604 .3212 m
.14654 .32026 L
s
1 .752 0 r
.008 w
.14654 .32026 Mdot
.016 w
.14654 .32026 m
.14702 .3194 L
s
1 .749 0 r
.008 w
.14702 .3194 Mdot
.016 w
.14702 .3194 m
.14747 .31868 L
s
1 .747 0 r
.008 w
.14747 .31868 Mdot
.016 w
.14747 .31868 m
.1479 .31807 L
s
1 .745 0 r
.008 w
.1479 .31807 Mdot
.016 w
.1479 .31807 m
.1483 .31754 L
s
1 .742 0 r
.008 w
.1483 .31754 Mdot
.016 w
.1483 .31754 m
.14867 .31708 L
s
1 .74 0 r
.008 w
.14867 .31708 Mdot
.016 w
.14867 .31708 m
.14905 .31666 L
s
1 .737 0 r
.008 w
.14905 .31666 Mdot
.016 w
.14905 .31666 m
.14944 .31625 L
s
1 .735 0 r
.008 w
.14944 .31625 Mdot
.016 w
.14944 .31625 m
.14986 .31581 L
s
1 .733 0 r
.008 w
.14986 .31581 Mdot
.016 w
.14986 .31581 m
.15031 .3153 L
s
1 .73 0 r
.008 w
.15031 .3153 Mdot
.016 w
.15031 .3153 m
.1508 .31468 L
s
1 .728 0 r
.008 w
.1508 .31468 Mdot
.016 w
.1508 .31468 m
.15131 .31393 L
s
1 .726 0 r
.008 w
.15131 .31393 Mdot
.016 w
.15131 .31393 m
.15187 .31302 L
s
1 .723 0 r
.008 w
.15187 .31302 Mdot
.016 w
.15187 .31302 m
.15248 .31191 L
s
1 .721 0 r
.008 w
.15248 .31191 Mdot
.016 w
.15248 .31191 m
.1531 .31073 L
s
1 .718 0 r
.008 w
.1531 .31073 Mdot
.016 w
.1531 .31073 m
.1537 .30929 L
s
1 .716 0 r
.008 w
.1537 .30929 Mdot
.016 w
.1537 .30929 m
.15429 .30767 L
s
1 .714 0 r
.008 w
.15429 .30767 Mdot
.016 w
.15429 .30767 m
.15487 .30609 L
s
1 .711 0 r
.008 w
.15487 .30609 Mdot
.016 w
.15487 .30609 m
.15541 .30436 L
s
1 .709 0 r
.008 w
.15541 .30436 Mdot
.016 w
.15541 .30436 m
.15588 .30262 L
s
1 .706 0 r
.008 w
.15588 .30262 Mdot
.016 w
.15588 .30262 m
.15626 .30089 L
s
1 .704 0 r
.008 w
.15626 .30089 Mdot
.016 w
.15626 .30089 m
.15656 .29934 L
s
1 .702 0 r
.008 w
.15656 .29934 Mdot
.016 w
.15656 .29934 m
.15678 .29788 L
s
1 .699 0 r
.008 w
.15678 .29788 Mdot
.016 w
.15678 .29788 m
.15692 .29659 L
s
1 .697 0 r
.008 w
.15692 .29659 Mdot
.016 w
.15692 .29659 m
.157 .29553 L
s
1 .695 0 r
.008 w
.157 .29553 Mdot
.016 w
.157 .29553 m
.15702 .29464 L
s
1 .692 0 r
.008 w
.15702 .29464 Mdot
.016 w
.15702 .29464 m
.157 .29388 L
s
1 .69 0 r
.008 w
.157 .29388 Mdot
.016 w
.157 .29388 m
.15696 .29328 L
s
1 .687 0 r
.008 w
.15696 .29328 Mdot
.016 w
.15696 .29328 m
.15691 .29282 L
s
1 .685 0 r
.008 w
.15691 .29282 Mdot
.016 w
.15691 .29282 m
.15685 .29252 L
s
1 .683 0 r
.008 w
.15685 .29252 Mdot
.016 w
.15685 .29252 m
.15678 .29236 L
s
1 .68 0 r
.008 w
.15678 .29236 Mdot
.016 w
.15678 .29236 m
.15673 .29233 L
s
1 .678 0 r
.008 w
.15673 .29233 Mdot
.016 w
.15673 .29233 m
.15667 .29241 L
s
1 .675 0 r
.008 w
.15667 .29241 Mdot
.016 w
.15667 .29241 m
.15662 .29257 L
s
1 .673 0 r
.008 w
.15662 .29257 Mdot
.016 w
.15662 .29257 m
.15658 .29275 L
s
1 .671 0 r
.008 w
.15658 .29275 Mdot
.016 w
.15658 .29275 m
.15655 .29292 L
s
1 .668 0 r
.008 w
.15655 .29292 Mdot
.016 w
.15655 .29292 m
.15656 .29304 L
s
1 .666 0 r
.008 w
.15656 .29304 Mdot
.016 w
.15656 .29304 m
.15661 .2931 L
s
1 .663 0 r
.008 w
.15661 .2931 Mdot
.016 w
.15661 .2931 m
.15677 .29307 L
s
1 .661 0 r
.008 w
.15677 .29307 Mdot
.016 w
.15677 .29307 m
.15704 .29294 L
s
1 .659 0 r
.008 w
.15704 .29294 Mdot
.016 w
.15704 .29294 m
.15746 .29268 L
s
1 .656 0 r
.008 w
.15746 .29268 Mdot
.016 w
.15746 .29268 m
.15802 .29229 L
s
1 .654 0 r
.008 w
.15802 .29229 Mdot
.016 w
.15802 .29229 m
.15871 .29178 L
s
1 .652 0 r
.008 w
.15871 .29178 Mdot
.016 w
.15871 .29178 m
.15955 .29112 L
s
1 .649 0 r
.008 w
.15955 .29112 Mdot
.016 w
.15955 .29112 m
.16056 .29033 L
s
1 .647 0 r
.008 w
.16056 .29033 Mdot
.016 w
.16056 .29033 m
.16162 .28943 L
s
1 .644 0 r
.008 w
.16162 .28943 Mdot
.016 w
.16162 .28943 m
.1628 .28847 L
s
1 .642 0 r
.008 w
.1628 .28847 Mdot
.016 w
.1628 .28847 m
.16395 .28743 L
s
1 .64 0 r
.008 w
.16395 .28743 Mdot
.016 w
.16395 .28743 m
.16513 .28636 L
s
1 .637 0 r
.008 w
.16513 .28636 Mdot
.016 w
.16513 .28636 m
.16631 .28532 L
s
1 .635 0 r
.008 w
.16631 .28532 Mdot
.016 w
.16631 .28532 m
.16733 .28444 L
s
1 .632 0 r
.008 w
.16733 .28444 Mdot
.016 w
.16733 .28444 m
.16832 .28368 L
s
1 .63 0 r
.008 w
.16832 .28368 Mdot
.016 w
.16832 .28368 m
.16923 .28305 L
s
1 .628 0 r
.008 w
.16923 .28305 Mdot
.016 w
.16923 .28305 m
.17003 .28255 L
s
1 .625 0 r
.008 w
.17003 .28255 Mdot
.016 w
.17003 .28255 m
.17068 .28215 L
s
1 .623 0 r
.008 w
.17068 .28215 Mdot
.016 w
.17068 .28215 m
.17122 .28182 L
s
1 .621 0 r
.008 w
.17122 .28182 Mdot
.016 w
.17122 .28182 m
.17166 .28149 L
s
1 .618 0 r
.008 w
.17166 .28149 Mdot
.016 w
.17166 .28149 m
.17201 .28114 L
s
1 .616 0 r
.008 w
.17201 .28114 Mdot
.016 w
.17201 .28114 m
.17231 .28071 L
s
1 .613 0 r
.008 w
.17231 .28071 Mdot
.016 w
.17231 .28071 m
.17258 .28019 L
s
1 .611 0 r
.008 w
.17258 .28019 Mdot
.016 w
.17258 .28019 m
.17286 .27956 L
s
1 .609 0 r
.008 w
.17286 .27956 Mdot
.016 w
.17286 .27956 m
.17319 .27882 L
s
1 .606 0 r
.008 w
.17319 .27882 Mdot
.016 w
.17319 .27882 m
.17356 .27794 L
s
1 .604 0 r
.008 w
.17356 .27794 Mdot
.016 w
.17356 .27794 m
.17397 .27705 L
s
1 .601 0 r
.008 w
.17397 .27705 Mdot
.016 w
.17397 .27705 m
.17441 .27607 L
s
1 .599 0 r
.008 w
.17441 .27607 Mdot
.016 w
.17441 .27607 m
.17487 .27505 L
s
1 .597 0 r
.008 w
.17487 .27505 Mdot
.016 w
.17487 .27505 m
.17533 .27401 L
s
1 .594 0 r
.008 w
.17533 .27401 Mdot
.016 w
.17533 .27401 m
.1758 .27304 L
s
1 .592 0 r
.008 w
.1758 .27304 Mdot
.016 w
.1758 .27304 m
.17626 .27214 L
s
1 .589 0 r
.008 w
.17626 .27214 Mdot
.016 w
.17626 .27214 m
.17668 .27135 L
s
1 .587 0 r
.008 w
.17668 .27135 Mdot
.016 w
.17668 .27135 m
.17708 .27075 L
s
1 .585 0 r
.008 w
.17708 .27075 Mdot
.016 w
.17708 .27075 m
.17743 .27031 L
s
1 .582 0 r
.008 w
.17743 .27031 Mdot
.016 w
.17743 .27031 m
.17773 .26998 L
s
1 .58 0 r
.008 w
.17773 .26998 Mdot
.016 w
.17773 .26998 m
.17797 .26973 L
s
1 .578 0 r
.008 w
.17797 .26973 Mdot
.016 w
.17797 .26973 m
.17814 .2695 L
s
1 .575 0 r
.008 w
.17814 .2695 Mdot
.016 w
.17814 .2695 m
.17826 .26922 L
s
1 .573 0 r
.008 w
.17826 .26922 Mdot
.016 w
.17826 .26922 m
.17834 .26883 L
s
1 .57 0 r
.008 w
.17834 .26883 Mdot
.016 w
.17834 .26883 m
.17841 .26829 L
s
1 .568 0 r
.008 w
.17841 .26829 Mdot
.016 w
.17841 .26829 m
.17849 .26761 L
s
1 .566 0 r
.008 w
.17849 .26761 Mdot
.016 w
.17849 .26761 m
.17861 .2668 L
s
1 .563 0 r
.008 w
.17861 .2668 Mdot
.016 w
.17861 .2668 m
.17876 .26592 L
s
1 .561 0 r
.008 w
.17876 .26592 Mdot
.016 w
.17876 .26592 m
.17892 .26513 L
s
1 .558 0 r
.008 w
.17892 .26513 Mdot
.016 w
.17892 .26513 m
.17911 .26407 L
s
1 .556 0 r
.008 w
.17911 .26407 Mdot
.016 w
.17911 .26407 m
.17932 .26307 L
s
1 .554 0 r
.008 w
.17932 .26307 Mdot
.016 w
.17932 .26307 m
.17952 .26199 L
s
1 .551 0 r
.008 w
.17952 .26199 Mdot
.016 w
.17952 .26199 m
.17971 .26083 L
s
1 .549 0 r
.008 w
.17971 .26083 Mdot
.016 w
.17971 .26083 m
.17987 .25958 L
s
1 .547 0 r
.008 w
.17987 .25958 Mdot
.016 w
.17987 .25958 m
.18 .25835 L
s
1 .544 0 r
.008 w
.18 .25835 Mdot
.016 w
.18 .25835 m
.18011 .25707 L
s
1 .542 0 r
.008 w
.18011 .25707 Mdot
.016 w
.18011 .25707 m
.18022 .25573 L
s
1 .539 0 r
.008 w
.18022 .25573 Mdot
.016 w
.18022 .25573 m
.18034 .25434 L
s
1 .537 0 r
.008 w
.18034 .25434 Mdot
.016 w
.18034 .25434 m
.18049 .25308 L
s
1 .535 0 r
.008 w
.18049 .25308 Mdot
.016 w
.18049 .25308 m
.18065 .25161 L
s
1 .532 0 r
.008 w
.18065 .25161 Mdot
.016 w
.18065 .25161 m
.18085 .25012 L
s
1 .53 0 r
.008 w
.18085 .25012 Mdot
.016 w
.18085 .25012 m
.18108 .24856 L
s
1 .527 0 r
.008 w
.18108 .24856 Mdot
.016 w
.18108 .24856 m
.18138 .24694 L
s
1 .525 0 r
.008 w
.18138 .24694 Mdot
.016 w
.18138 .24694 m
.18176 .24518 L
s
1 .523 0 r
.008 w
.18176 .24518 Mdot
.016 w
.18176 .24518 m
.18224 .24367 L
s
1 .52 0 r
.008 w
.18224 .24367 Mdot
.016 w
.18224 .24367 m
.18283 .24217 L
s
1 .518 0 r
.008 w
.18283 .24217 Mdot
.016 w
.18283 .24217 m
.18354 .24071 L
s
1 .516 0 r
.008 w
.18354 .24071 Mdot
.016 w
.18354 .24071 m
.18428 .23935 L
s
1 .513 0 r
.008 w
.18428 .23935 Mdot
.016 w
.18428 .23935 m
.18508 .23811 L
s
1 .511 0 r
.008 w
.18508 .23811 Mdot
.016 w
.18508 .23811 m
.18593 .23692 L
s
1 .508 0 r
.008 w
.18593 .23692 Mdot
.016 w
.18593 .23692 m
.1868 .23575 L
s
1 .506 0 r
.008 w
.1868 .23575 Mdot
.016 w
.1868 .23575 m
.18762 .23462 L
s
1 .504 0 r
.008 w
.18762 .23462 Mdot
.016 w
.18762 .23462 m
.18848 .23346 L
s
1 .501 0 r
.008 w
.18848 .23346 Mdot
.016 w
.18848 .23346 m
.18932 .23233 L
s
1 .499 0 r
.008 w
.18932 .23233 Mdot
.016 w
.18932 .23233 m
.19025 .23124 L
s
1 .496 0 r
.008 w
.19025 .23124 Mdot
.016 w
.19025 .23124 m
.19115 .23012 L
s
1 .494 0 r
.008 w
.19115 .23012 Mdot
.016 w
.19115 .23012 m
.19214 .22897 L
s
1 .492 0 r
.008 w
.19214 .22897 Mdot
.016 w
.19214 .22897 m
.19323 .2278 L
s
1 .489 0 r
.008 w
.19323 .2278 Mdot
.016 w
.19323 .2278 m
.19435 .22663 L
s
1 .487 0 r
.008 w
.19435 .22663 Mdot
.016 w
.19435 .22663 m
.19553 .22539 L
s
1 .484 0 r
.008 w
.19553 .22539 Mdot
.016 w
.19553 .22539 m
.19673 .22417 L
s
1 .482 0 r
.008 w
.19673 .22417 Mdot
.016 w
.19673 .22417 m
.19781 .22293 L
s
1 .48 0 r
.008 w
.19781 .22293 Mdot
.016 w
.19781 .22293 m
.19888 .22171 L
s
1 .477 0 r
.008 w
.19888 .22171 Mdot
.016 w
.19888 .22171 m
.19989 .22053 L
s
1 .475 0 r
.008 w
.19989 .22053 Mdot
.016 w
.19989 .22053 m
.20083 .21954 L
s
1 .473 0 r
.008 w
.20083 .21954 Mdot
.016 w
.20083 .21954 m
.20174 .21854 L
s
1 .47 0 r
.008 w
.20174 .21854 Mdot
.016 w
.20174 .21854 m
.20249 .21763 L
s
1 .468 0 r
.008 w
.20249 .21763 Mdot
.016 w
.20249 .21763 m
.20314 .21692 L
s
1 .465 0 r
.008 w
.20314 .21692 Mdot
.016 w
.20314 .21692 m
.20367 .2163 L
s
1 .463 0 r
.008 w
.20367 .2163 Mdot
.016 w
.20367 .2163 m
.20405 .21577 L
s
1 .461 0 r
.008 w
.20405 .21577 Mdot
.016 w
.20405 .21577 m
.20432 .21532 L
s
1 .458 0 r
.008 w
.20432 .21532 Mdot
.016 w
.20432 .21532 m
.20443 .21493 L
s
1 .456 0 r
.008 w
.20443 .21493 Mdot
.016 w
.20443 .21493 m
.20444 .21458 L
s
1 .453 0 r
.008 w
.20444 .21458 Mdot
.016 w
.20444 .21458 m
.20439 .21426 L
s
1 .451 0 r
.008 w
.20439 .21426 Mdot
.016 w
.20439 .21426 m
.20432 .21391 L
s
1 .449 0 r
.008 w
.20432 .21391 Mdot
.016 w
.20432 .21391 m
.20426 .21351 L
s
1 .446 0 r
.008 w
.20426 .21351 Mdot
.016 w
.20426 .21351 m
.20422 .213 L
s
1 .444 0 r
.008 w
.20422 .213 Mdot
.016 w
.20422 .213 m
.2042 .21242 L
s
1 .442 0 r
.008 w
.2042 .21242 Mdot
.016 w
.2042 .21242 m
.20419 .21185 L
s
1 .439 0 r
.008 w
.20419 .21185 Mdot
.016 w
.20419 .21185 m
.20418 .21139 L
s
1 .437 0 r
.008 w
.20418 .21139 Mdot
.016 w
.20418 .21139 m
.20413 .21101 L
s
1 .434 0 r
.008 w
.20413 .21101 Mdot
.016 w
.20413 .21101 m
.20403 .21078 L
s
1 .432 0 r
.008 w
.20403 .21078 Mdot
.016 w
.20403 .21078 m
.20389 .21077 L
s
1 .43 0 r
.008 w
.20389 .21077 Mdot
.016 w
.20389 .21077 m
.20371 .21098 L
s
1 .427 0 r
.008 w
.20371 .21098 Mdot
.016 w
.20371 .21098 m
.20349 .21144 L
s
1 .425 0 r
.008 w
.20349 .21144 Mdot
.016 w
.20349 .21144 m
.20323 .21211 L
s
1 .422 0 r
.008 w
.20323 .21211 Mdot
.016 w
.20323 .21211 m
.20295 .21296 L
s
1 .42 0 r
.008 w
.20295 .21296 Mdot
.016 w
.20295 .21296 m
.20267 .21384 L
s
1 .418 0 r
.008 w
.20267 .21384 Mdot
.016 w
.20267 .21384 m
.2024 .21496 L
s
1 .415 0 r
.008 w
.2024 .21496 Mdot
.016 w
.2024 .21496 m
.20215 .21598 L
s
1 .413 0 r
.008 w
.20215 .21598 Mdot
.016 w
.20215 .21598 m
.20194 .217 L
s
1 .411 0 r
.008 w
.20194 .217 Mdot
.016 w
.20194 .217 m
.20179 .21793 L
s
1 .408 0 r
.008 w
.20179 .21793 Mdot
.016 w
.20179 .21793 m
.20172 .21869 L
s
1 .406 0 r
.008 w
.20172 .21869 Mdot
.016 w
.20172 .21869 m
.20178 .21926 L
s
1 .403 0 r
.008 w
.20178 .21926 Mdot
.016 w
.20178 .21926 m
.20197 .21961 L
s
1 .401 0 r
.008 w
.20197 .21961 Mdot
.016 w
.20197 .21961 m
.20229 .21977 L
s
1 .399 0 r
.008 w
.20229 .21977 Mdot
.016 w
.20229 .21977 m
.20274 .2198 L
s
1 .396 0 r
.008 w
.20274 .2198 Mdot
.016 w
.20274 .2198 m
.2033 .21974 L
s
1 .394 0 r
.008 w
.2033 .21974 Mdot
.016 w
.2033 .21974 m
.20397 .21964 L
s
1 .391 0 r
.008 w
.20397 .21964 Mdot
.016 w
.20397 .21964 m
.20471 .21953 L
s
1 .389 0 r
.008 w
.20471 .21953 Mdot
.016 w
.20471 .21953 m
.20548 .21946 L
s
1 .387 0 r
.008 w
.20548 .21946 Mdot
.016 w
.20548 .21946 m
.20617 .21944 L
s
1 .384 0 r
.008 w
.20617 .21944 Mdot
.016 w
.20617 .21944 m
.20681 .21945 L
s
1 .382 0 r
.008 w
.20681 .21945 Mdot
.016 w
.20681 .21945 m
.20734 .21947 L
s
1 .379 0 r
.008 w
.20734 .21947 Mdot
.016 w
.20734 .21947 m
.20772 .21947 L
s
1 .377 0 r
.008 w
.20772 .21947 Mdot
.016 w
.20772 .21947 m
.20795 .21948 L
s
1 .375 0 r
.008 w
.20795 .21948 Mdot
.016 w
.20795 .21948 m
.208 .21947 L
s
1 .372 0 r
.008 w
.208 .21947 Mdot
.016 w
.208 .21947 m
.20791 .21944 L
s
1 .37 0 r
.008 w
.20791 .21944 Mdot
.016 w
.20791 .21944 m
.20773 .21938 L
s
1 .368 0 r
.008 w
.20773 .21938 Mdot
.016 w
.20773 .21938 m
.20748 .21929 L
s
1 .365 0 r
.008 w
.20748 .21929 Mdot
.016 w
.20748 .21929 m
.20711 .21918 L
s
1 .363 0 r
.008 w
.20711 .21918 Mdot
.016 w
.20711 .21918 m
.20666 .21906 L
s
1 .36 0 r
.008 w
.20666 .21906 Mdot
.016 w
.20666 .21906 m
.20611 .21897 L
s
1 .358 0 r
.008 w
.20611 .21897 Mdot
.016 w
.20611 .21897 m
.20545 .21895 L
s
1 .356 0 r
.008 w
.20545 .21895 Mdot
.016 w
.20545 .21895 m
.20471 .21902 L
s
1 .353 0 r
.008 w
.20471 .21902 Mdot
.016 w
.20471 .21902 m
.20391 .21921 L
s
1 .351 0 r
.008 w
.20391 .21921 Mdot
.016 w
.20391 .21921 m
.20306 .21956 L
s
1 .348 0 r
.008 w
.20306 .21956 Mdot
.016 w
.20306 .21956 m
.20215 .22009 L
s
1 .346 0 r
.008 w
.20215 .22009 Mdot
.016 w
.20215 .22009 m
.20118 .2208 L
s
1 .344 0 r
.008 w
.20118 .2208 Mdot
.016 w
.20118 .2208 m
.20017 .22174 L
s
1 .341 0 r
.008 w
.20017 .22174 Mdot
.016 w
.20017 .22174 m
.19922 .22285 L
s
1 .339 0 r
.008 w
.19922 .22285 Mdot
.016 w
.19922 .22285 m
.19819 .22418 L
s
1 .337 0 r
.008 w
.19819 .22418 Mdot
.016 w
.19819 .22418 m
.197 .22572 L
s
1 .334 0 r
.008 w
.197 .22572 Mdot
.016 w
.197 .22572 m
.19553 .22738 L
s
1 .332 0 r
.008 w
.19553 .22738 Mdot
.016 w
.19553 .22738 m
.1942 .22902 L
s
1 .329 0 r
.008 w
.1942 .22902 Mdot
.016 w
.1942 .22902 m
.19281 .23076 L
s
1 .327 0 r
.008 w
.19281 .23076 Mdot
.016 w
.19281 .23076 m
.19138 .23258 L
s
1 .325 0 r
.008 w
.19138 .23258 Mdot
.016 w
.19138 .23258 m
.19002 .23433 L
s
1 .322 0 r
.008 w
.19002 .23433 Mdot
.016 w
.19002 .23433 m
.18864 .23593 L
s
1 .32 0 r
.008 w
.18864 .23593 Mdot
.016 w
.18864 .23593 m
.18728 .23751 L
s
1 .317 0 r
.008 w
.18728 .23751 Mdot
.016 w
.18728 .23751 m
.18605 .23906 L
s
1 .315 0 r
.008 w
.18605 .23906 Mdot
.016 w
.18605 .23906 m
.18492 .24047 L
s
1 .313 0 r
.008 w
.18492 .24047 Mdot
.016 w
.18492 .24047 m
.18377 .24189 L
s
1 .31 0 r
.008 w
.18377 .24189 Mdot
.016 w
.18377 .24189 m
.18259 .24335 L
s
1 .308 0 r
.008 w
.18259 .24335 Mdot
.016 w
.18259 .24335 m
.18141 .24489 L
s
1 .305 0 r
.008 w
.18141 .24489 Mdot
.016 w
.18141 .24489 m
.1803 .24641 L
s
1 .303 0 r
.008 w
.1803 .24641 Mdot
.016 w
.1803 .24641 m
.17926 .24804 L
s
1 .301 0 r
.008 w
.17926 .24804 Mdot
.016 w
.17926 .24804 m
.17824 .24983 L
s
1 .298 0 r
.008 w
.17824 .24983 Mdot
.016 w
.17824 .24983 m
.17725 .25177 L
s
1 .296 0 r
.008 w
.17725 .25177 Mdot
.016 w
.17725 .25177 m
.17634 .25363 L
s
1 .294 0 r
.008 w
.17634 .25363 Mdot
.016 w
.17634 .25363 m
.17548 .25572 L
s
1 .291 0 r
.008 w
.17548 .25572 Mdot
.016 w
.17548 .25572 m
.17467 .25774 L
s
1 .289 0 r
.008 w
.17467 .25774 Mdot
.016 w
.17467 .25774 m
.17391 .25981 L
s
1 .286 0 r
.008 w
.17391 .25981 Mdot
.016 w
.17391 .25981 m
.17323 .26173 L
s
1 .284 0 r
.008 w
.17323 .26173 Mdot
.016 w
.17323 .26173 m
.17267 .2634 L
s
1 .282 0 r
.008 w
.17267 .2634 Mdot
.016 w
.17267 .2634 m
.17222 .2649 L
s
1 .279 0 r
.008 w
.17222 .2649 Mdot
.016 w
.17222 .2649 m
.17188 .2662 L
s
1 .277 0 r
.008 w
.17188 .2662 Mdot
.016 w
.17188 .2662 m
.17163 .26717 L
s
1 .274 0 r
.008 w
.17163 .26717 Mdot
.016 w
.17163 .26717 m
.17144 .26794 L
s
1 .272 0 r
.008 w
.17144 .26794 Mdot
.016 w
.17144 .26794 m
.17127 .26855 L
s
1 .27 0 r
.008 w
.17127 .26855 Mdot
.016 w
.17127 .26855 m
.1711 .26902 L
s
1 .267 0 r
.008 w
.1711 .26902 Mdot
.016 w
.1711 .26902 m
.17089 .26938 L
s
1 .265 0 r
.008 w
.17089 .26938 Mdot
.016 w
.17089 .26938 m
.1706 .26971 L
s
1 .263 0 r
.008 w
.1706 .26971 Mdot
.016 w
.1706 .26971 m
.17021 .27006 L
s
1 .26 0 r
.008 w
.17021 .27006 Mdot
.016 w
.17021 .27006 m
.16974 .27042 L
s
1 .258 0 r
.008 w
.16974 .27042 Mdot
.016 w
.16974 .27042 m
.16918 .27082 L
s
1 .255 0 r
.008 w
.16918 .27082 Mdot
.016 w
.16918 .27082 m
.16855 .27127 L
s
1 .253 0 r
.008 w
.16855 .27127 Mdot
.016 w
.16855 .27127 m
.16795 .27178 L
s
1 .251 0 r
.008 w
.16795 .27178 Mdot
.016 w
.16795 .27178 m
.16719 .27246 L
s
1 .248 0 r
.008 w
.16719 .27246 Mdot
.016 w
.16719 .27246 m
.16644 .27321 L
s
1 .246 0 r
.008 w
.16644 .27321 Mdot
.016 w
.16644 .27321 m
.16562 .27409 L
s
1 .243 0 r
.008 w
.16562 .27409 Mdot
.016 w
.16562 .27409 m
.16475 .27509 L
s
1 .241 0 r
.008 w
.16475 .27509 Mdot
.016 w
.16475 .27509 m
.16386 .27618 L
s
1 .239 0 r
.008 w
.16386 .27618 Mdot
.016 w
.16386 .27618 m
.16299 .27735 L
s
1 .236 0 r
.008 w
.16299 .27735 Mdot
.016 w
.16299 .27735 m
.16217 .27861 L
s
1 .234 0 r
.008 w
.16217 .27861 Mdot
.016 w
.16217 .27861 m
.16144 .27984 L
s
1 .232 0 r
.008 w
.16144 .27984 Mdot
.016 w
.16144 .27984 m
.1607 .28115 L
s
1 .229 0 r
.008 w
.1607 .28115 Mdot
.016 w
.1607 .28115 m
.15998 .2825 L
s
1 .227 0 r
.008 w
.15998 .2825 Mdot
.016 w
.15998 .2825 m
.1593 .28389 L
s
1 .224 0 r
.008 w
.1593 .28389 Mdot
.016 w
.1593 .28389 m
.15864 .28523 L
s
1 .222 0 r
.008 w
.15864 .28523 Mdot
.016 w
.15864 .28523 m
.15796 .28668 L
s
1 .22 0 r
.008 w
.15796 .28668 Mdot
.016 w
.15796 .28668 m
.15734 .28825 L
s
1 .217 0 r
.008 w
.15734 .28825 Mdot
.016 w
.15734 .28825 m
.15686 .28981 L
s
1 .215 0 r
.008 w
.15686 .28981 Mdot
.016 w
.15686 .28981 m
.15649 .29131 L
s
1 .212 0 r
.008 w
.15649 .29131 Mdot
.016 w
.15649 .29131 m
.15618 .29276 L
s
1 .21 0 r
.008 w
.15618 .29276 Mdot
.016 w
.15618 .29276 m
.15589 .2942 L
s
1 .208 0 r
.008 w
.15589 .2942 Mdot
.016 w
.15589 .2942 m
.1556 .29539 L
s
1 .205 0 r
.008 w
.1556 .29539 Mdot
.016 w
.1556 .29539 m
.15526 .29664 L
s
1 .203 0 r
.008 w
.15526 .29664 Mdot
.016 w
.15526 .29664 m
.1548 .29777 L
s
1 .2 0 r
.008 w
.1548 .29777 Mdot
.016 w
.1548 .29777 m
.15421 .29899 L
s
1 .198 0 r
.008 w
.15421 .29899 Mdot
.016 w
.15421 .29899 m
.15357 .30028 L
s
1 .196 0 r
.008 w
.15357 .30028 Mdot
.016 w
.15357 .30028 m
.15275 .30152 L
s
1 .193 0 r
.008 w
.15275 .30152 Mdot
.016 w
.15275 .30152 m
.15179 .3028 L
s
1 .191 0 r
.008 w
.15179 .3028 Mdot
.016 w
.15179 .3028 m
.15077 .3041 L
s
1 .189 0 r
.008 w
.15077 .3041 Mdot
.016 w
.15077 .3041 m
.14979 .30542 L
s
1 .186 0 r
.008 w
.14979 .30542 Mdot
.016 w
.14979 .30542 m
.14875 .30675 L
s
1 .184 0 r
.008 w
.14875 .30675 Mdot
.016 w
.14875 .30675 m
.14762 .30799 L
s
1 .181 0 r
.008 w
.14762 .30799 Mdot
.016 w
.14762 .30799 m
.14643 .30926 L
s
1 .179 0 r
.008 w
.14643 .30926 Mdot
.016 w
.14643 .30926 m
.14524 .31056 L
s
1 .177 0 r
.008 w
.14524 .31056 Mdot
.016 w
.14524 .31056 m
.1442 .31194 L
s
1 .174 0 r
.008 w
.1442 .31194 Mdot
.016 w
.1442 .31194 m
.14328 .31324 L
s
1 .172 0 r
.008 w
.14328 .31324 Mdot
.016 w
.14328 .31324 m
.14249 .3146 L
s
1 .169 0 r
.008 w
.14249 .3146 Mdot
.016 w
.14249 .3146 m
.14183 .31601 L
s
1 .167 0 r
.008 w
.14183 .31601 Mdot
.016 w
.14183 .31601 m
.14128 .31745 L
s
1 .165 0 r
.008 w
.14128 .31745 Mdot
.016 w
.14128 .31745 m
.14085 .31882 L
s
1 .162 0 r
.008 w
.14085 .31882 Mdot
.016 w
.14085 .31882 m
.1405 .32016 L
s
1 .16 0 r
.008 w
.1405 .32016 Mdot
.016 w
.1405 .32016 m
.14024 .32153 L
s
1 .158 0 r
.008 w
.14024 .32153 Mdot
.016 w
.14024 .32153 m
.14003 .32297 L
s
1 .155 0 r
.008 w
.14003 .32297 Mdot
.016 w
.14003 .32297 m
.13987 .32443 L
s
1 .153 0 r
.008 w
.13987 .32443 Mdot
.016 w
.13987 .32443 m
.13973 .32594 L
s
1 .15 0 r
.008 w
.13973 .32594 Mdot
.016 w
.13973 .32594 m
.1396 .32751 L
s
1 .148 0 r
.008 w
.1396 .32751 Mdot
.016 w
.1396 .32751 m
.13945 .32907 L
s
1 .146 0 r
.008 w
.13945 .32907 Mdot
.016 w
.13945 .32907 m
.13928 .33049 L
s
1 .143 0 r
.008 w
.13928 .33049 Mdot
.016 w
.13928 .33049 m
.13909 .33178 L
s
1 .141 0 r
.008 w
.13909 .33178 Mdot
.016 w
.13909 .33178 m
.13891 .33292 L
s
1 .138 0 r
.008 w
.13891 .33292 Mdot
.016 w
.13891 .33292 m
.13874 .33392 L
s
1 .136 0 r
.008 w
.13874 .33392 Mdot
.016 w
.13874 .33392 m
.13855 .3348 L
s
1 .134 0 r
.008 w
.13855 .3348 Mdot
.016 w
.13855 .3348 m
.13832 .33553 L
s
1 .131 0 r
.008 w
.13832 .33553 Mdot
.016 w
.13832 .33553 m
.13807 .33618 L
s
1 .129 0 r
.008 w
.13807 .33618 Mdot
.016 w
.13807 .33618 m
.13779 .33676 L
s
1 .126 0 r
.008 w
.13779 .33676 Mdot
.016 w
.13779 .33676 m
.1375 .3373 L
s
1 .124 0 r
.008 w
.1375 .3373 Mdot
.016 w
.1375 .3373 m
.13723 .33784 L
s
1 .122 0 r
.008 w
.13723 .33784 Mdot
.016 w
.13723 .33784 m
.13697 .33842 L
s
1 .119 0 r
.008 w
.13697 .33842 Mdot
.016 w
.13697 .33842 m
.13672 .33908 L
s
1 .117 0 r
.008 w
.13672 .33908 Mdot
.016 w
.13672 .33908 m
.13648 .33988 L
s
1 .115 0 r
.008 w
.13648 .33988 Mdot
.016 w
.13648 .33988 m
.13623 .34087 L
s
1 .112 0 r
.008 w
.13623 .34087 Mdot
.016 w
.13623 .34087 m
.13597 .34199 L
s
1 .11 0 r
.008 w
.13597 .34199 Mdot
.016 w
.13597 .34199 m
.13567 .34328 L
s
1 .107 0 r
.008 w
.13567 .34328 Mdot
.016 w
.13567 .34328 m
.13531 .34479 L
s
1 .105 0 r
.008 w
.13531 .34479 Mdot
.016 w
.13531 .34479 m
.13489 .34661 L
s
1 .103 0 r
.008 w
.13489 .34661 Mdot
.016 w
.13489 .34661 m
.13444 .34849 L
s
1 .1 0 r
.008 w
.13444 .34849 Mdot
.016 w
.13444 .34849 m
.13399 .35058 L
s
1 .098 0 r
.008 w
.13399 .35058 Mdot
.016 w
.13399 .35058 m
.13357 .35285 L
s
1 .095 0 r
.008 w
.13357 .35285 Mdot
.016 w
.13357 .35285 m
.13319 .35486 L
s
1 .093 0 r
.008 w
.13319 .35486 Mdot
.016 w
.13319 .35486 m
.13283 .35718 L
s
1 .091 0 r
.008 w
.13283 .35718 Mdot
.016 w
.13283 .35718 m
.13249 .35927 L
s
1 .088 0 r
.008 w
.13249 .35927 Mdot
.016 w
.13249 .35927 m
.13217 .36153 L
s
1 .086 0 r
.008 w
.13217 .36153 Mdot
.016 w
.13217 .36153 m
.13185 .36398 L
s
1 .084 0 r
.008 w
.13185 .36398 Mdot
.016 w
.13185 .36398 m
.13153 .36645 L
s
1 .081 0 r
.008 w
.13153 .36645 Mdot
.016 w
.13153 .36645 m
.13122 .36865 L
s
1 .079 0 r
.008 w
.13122 .36865 Mdot
.016 w
.13122 .36865 m
.13092 .37091 L
s
1 .076 0 r
.008 w
.13092 .37091 Mdot
.016 w
.13092 .37091 m
.13066 .37331 L
s
1 .074 0 r
.008 w
.13066 .37331 Mdot
.016 w
.13066 .37331 m
.13044 .37576 L
s
1 .072 0 r
.008 w
.13044 .37576 Mdot
.016 w
.13044 .37576 m
.13027 .37783 L
s
1 .069 0 r
.008 w
.13027 .37783 Mdot
.016 w
.13027 .37783 m
.1301 .38005 L
s
1 .067 0 r
.008 w
.1301 .38005 Mdot
.016 w
.1301 .38005 m
.12995 .38216 L
s
1 .064 0 r
.008 w
.12995 .38216 Mdot
.016 w
.12995 .38216 m
.1298 .38421 L
s
1 .062 0 r
.008 w
.1298 .38421 Mdot
.016 w
.1298 .38421 m
.12966 .38618 L
s
1 .06 0 r
.008 w
.12966 .38618 Mdot
.016 w
.12966 .38618 m
.12954 .38791 L
s
1 .057 0 r
.008 w
.12954 .38791 Mdot
.016 w
.12954 .38791 m
.12941 .38949 L
s
1 .055 0 r
.008 w
.12941 .38949 Mdot
.016 w
.12941 .38949 m
.12935 .39082 L
s
1 .053 0 r
.008 w
.12935 .39082 Mdot
.016 w
.12935 .39082 m
.12931 .39195 L
s
1 .05 0 r
.008 w
.12931 .39195 Mdot
.016 w
.12931 .39195 m
.12931 .39287 L
s
1 .048 0 r
.008 w
.12931 .39287 Mdot
.016 w
.12931 .39287 m
.12933 .3936 L
s
1 .045 0 r
.008 w
.12933 .3936 Mdot
.016 w
.12933 .3936 m
.12936 .39418 L
s
1 .043 0 r
.008 w
.12936 .39418 Mdot
.016 w
.12936 .39418 m
.12937 .39463 L
s
1 .041 0 r
.008 w
.12937 .39463 Mdot
.016 w
.12937 .39463 m
.12938 .39502 L
s
1 .038 0 r
.008 w
.12938 .39502 Mdot
.016 w
.12938 .39502 m
.12937 .39544 L
s
1 .036 0 r
.008 w
.12937 .39544 Mdot
.016 w
.12937 .39544 m
.12937 .39591 L
s
1 .033 0 r
.008 w
.12937 .39591 Mdot
.016 w
.12937 .39591 m
.12936 .39647 L
s
1 .031 0 r
.008 w
.12936 .39647 Mdot
.016 w
.12936 .39647 m
.12935 .39715 L
s
1 .029 0 r
.008 w
.12935 .39715 Mdot
.016 w
.12935 .39715 m
.12933 .39796 L
s
1 .026 0 r
.008 w
.12933 .39796 Mdot
.016 w
.12933 .39796 m
.12932 .3988 L
s
1 .024 0 r
.008 w
.12932 .3988 Mdot
.016 w
.12932 .3988 m
.1293 .39975 L
s
1 .021 0 r
.008 w
.1293 .39975 Mdot
.016 w
.1293 .39975 m
.12929 .40078 L
s
1 .019 0 r
.008 w
.12929 .40078 Mdot
.016 w
.12929 .40078 m
.12927 .40187 L
s
1 .017 0 r
.008 w
.12927 .40187 Mdot
.016 w
.12927 .40187 m
.12925 .40297 L
s
1 .014 0 r
.008 w
.12925 .40297 Mdot
.016 w
.12925 .40297 m
.12924 .40391 L
s
1 .012 0 r
.008 w
.12924 .40391 Mdot
.016 w
.12924 .40391 m
.12922 .40479 L
s
1 .01 0 r
.008 w
.12922 .40479 Mdot
.016 w
.12922 .40479 m
.12921 .40556 L
s
1 .007 0 r
.008 w
.12921 .40556 Mdot
.016 w
.12921 .40556 m
.1292 .4062 L
s
1 .005 0 r
.008 w
.1292 .4062 Mdot
.016 w
.1292 .4062 m
.12919 .40668 L
s
1 .002 0 r
.008 w
.12919 .40668 Mdot
.016 w
.12919 .40668 m
.12919 .40697 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.133003 0.140056 scale
1.179 2.08766 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002<OolD0020Ool008=oo`T0
01Aoo`P007Qoo`00Ogoo10009Goo1P00LWoo001iOol6000_Ool5001]Ool007Ioo`<003Yoo`<006Yo
o`00Lgoo0`00@7oo0`00Igoo001`Ool30016Ool3001TOol006eoo`<004aoo`<0065oo`00JWoo0`00
DWoo0`00GWoo001WOol3001HOol3001KOol006Eoo`8005ioo`8005Uoo`00I7oo00<007ooOol0H7oo
0P00Egoo001ROol2001UOol2001EOol005moo`<006Uoo`8005=oo`00GGoo0P00KWoo0P00DGoo001K
Ool2001bOol2001?Ool005Yoo`03001oogoo07Aoo`03001oogoo04aoo`00FGoo00<007ooOol0MWoo
0P00C7oo001GOol2001kOol2001:Ool005Eoo`8007moo`03001oogoo04Moo`00Dgoo0P00PWoo0P00
Agoo001BOol00`00Oomoo`24Ool00`00Oomoo`14Ool0055oo`03001oogoo08Ioo`8004Aoo`00D7oo
00<007ooOol0RGoo00<007ooOol0@Goo001>Ool2002=Ool00`00Oomoo`10Ool004eoo`03001oogoo
08ioo`03001oogoo03moo`00C7oo00<007ooOol0T7oo0P00?goo001;Ool00`00Oomoo`2COol00`00
Oomoo`0lOol004Uoo`8009Moo`03001oogoo03]oo`00B7oo00<007ooOol0V7oo00<007ooOol0>Woo
0017Ool00`00Oomoo`2JOol00`00Oomoo`0iOol004Ioo`03001oogoo09aoo`03001oogoo03Qoo`00
A7oo0P00X7oo0P00>7oo0013Ool00`00Oomoo`2ROol00`00Oomoo`0eOol0049oo`03001oogoo0:Ao
o`03001oogoo03Aoo`00;Goo200037oo00<007ooOol0YWoo00<007ooOol0<goo000XOol50008Ool6
0005Ool00`00Oomoo`2XOol00`00Oomoo`0bOol002Aoo`@001=oo`<00003Ool007oo0:]oo`03001o
ogoo035oo`008goo00<007ooOol067oo0P00[Goo00<007ooOol0<7oo000QOol2000JOol01000Oomo
o`00[7oo00<007ooOol0<7oo000NOol3000KOol00`00Oomoo`02Ool4002YOol00`00Oomoo`0_Ool0
01eoo`03001oogoo01aoo`03001oogoo00Ioo`03001oogoo0:Moo`8002moo`0077oo00<007ooOol0
77oo00<007ooOol027oo00<007ooOol0Z7oo00<007ooOol0;7oo000KOol00`00Oomoo`0LOol00`00
Oomoo`0:Ool00`00Oomoo`2XOol00`00Oomoo`0[Ool001Yoo`03001oogoo01aoo`03001oogoo00ao
o`03001oogoo0:Qoo`03001oogoo02Yoo`006Goo00<007ooOol077oo00<007ooOol03Woo00<007oo
Ool0Z7oo00<007ooOol0:Goo000HOol00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`2WOol0
0`00Oomoo`0YOol001Moo`03001oogoo01aoo`03001oogoo019oo`03001oogoo0:Moo`03001oogoo
02Qoo`005Woo00<007ooOol07Goo00<007ooOol04goo00<007ooOol0Ygoo00<007ooOol09goo000E
Ool00`00Oomoo`0MOol00`00Oomoo`0EOol00`00Oomoo`2WOol00`00Oomoo`0VOol001Eoo`03001o
ogoo01aoo`03001oogoo00Eoo`AmX0ioo`03001oogoo0:Moo`03001oogoo02Eoo`0057oo00<007oo
Ool07Goo00<007ooOol017oo1GfP3Woo00<007ooOol0Ygoo00<007ooOol09Goo000COol00`00Oomo
o`0MOol00`00Oomoo`05Ool00gfPOD1m@002OF0?Ool00`00Oomoo`2WOol00`00Oomoo`0TOol001=o
o`03001oogoo01aoo`03001oogoo00Eoo`03ON1m@7e0009m@09mH0moo`03001oogoo0:Moo`03001o
ogoo02=oo`004Woo00<007ooOol077oo00<007ooOol01Goo00=mh7e0OD0017e000=mH7ooOol03Goo
00<007ooOol0Ygoo00<007ooOol08goo000AOol00`00Oomoo`0LOol00`00Oomoo`05Ool00ggPOD1m
@004OD02OF0@Ool00`00Oomoo`2WOol00`00Oomoo`0ROol0015oo`03001oogoo01aoo`03001oogoo
00Eoo`Im@0=mH15oo`03001oogoo0:Ioo`03001oogoo029oo`0047oo00<007ooOol077oo00<007oo
Ool01Goo00=n07e0OD000ge000=mh7ooOol04Woo00<007ooOol0Ygoo00<007ooOol08Goo000@Ool0
0`00Oomoo`0KOol00`00Oomoo`05Ool00gh0OD1m@004OD0EOol00`00Oomoo`2XOol00`00Oomoo`0P
Ool000moo`03001oogoo01aoo`03001oogoo00Eoo`Am80=m@1Eoo`03001oogoo0:Qoo`03001oogoo
021oo`003goo00<007ooOol06goo00<007ooOol01Goo1GdP0We05goo00<007ooOol0Z7oo00<007oo
Ool07goo000>Ool00`00Oomoo`0LOol00`00Oomoo`05Ool5OB000gh0Oomoo`0FOol00`00Oomoo`2Y
Ool00`00Oomoo`0NOol000ioo`03001oogoo01]oo`03001oogoo00Eoo`Im81Yoo`03001oogoo0:Qo
o`03001oogoo01ioo`003Woo00<007ooOol06goo00<007ooOol01Goo1WdP6Woo00<007ooOol0ZGoo
00<007ooOol07Goo000=Ool00`00Oomoo`0KOol00`00Oomoo`05Ool6OB0KOol00`00Oomoo`2ZOol0
0`00Oomoo`0LOol000eoo`03001oogoo01Yoo`03001oogoo00Ioo`Am0003OB1n87oo01]oo`03001o
ogoo0:Uoo`03001oogoo01aoo`003Goo00<007ooOol06Woo00<007ooOol01Woo0WcP0Wd000=m87hP
Ool06goo00<007ooOol0ZWoo00<007ooOol06goo000=Ool00`00Oomoo`0IOol00`00Oomoo`06Ool4
O>000gd0OR1n800LOol00`00Oomoo`2ZOol00`00Oomoo`0KOol000eoo`03001oogoo01Uoo`03001o
ogoo00Eoo`Ilh09n81aoo`03001oogoo0:]oo`03001oogoo01Yoo`003Goo00<007ooOol067oo00<0
07ooOol01Goo1WcP00=m07hPOR0077oo00<007ooOol0Zgoo00<007ooOol06Woo000<Ool00`00Oomo
o`0IOol00`00Oomoo`04Ool6O>02O@02OT0LOol00`00Oomoo`2/Ool00`00Oomoo`0IOol000aoo`03
001oogoo01Qoo`03001oogoo00Eoo`Elh0AnH1eoo`03001oogoo0:aoo`03001oogoo01Uoo`0037oo
00<007ooOol067oo00<007ooOol01Goo17c000Alh7iPOV1nH1ioo`03001oogoo0:aoo`03001oogoo
01Uoo`0037oo00<007ooOol05goo00<007ooOol01Woo17c000Alh7iPOV1nH1ioo`03001oogoo0:eo
o`03001oogoo01Qoo`0037oo00<007ooOol05goo00<007ooOol01Goo1Wc00Wj07goo00<007ooOol0
[Goo00<007ooOol067oo000<Ool00`00Oomoo`0FOol00`00Oomoo`06Ool5O<0ROol00`00Oomoo`2^
Ool00`00Oomoo`0GOol000aoo`03001oogoo01Ioo`03001oogoo00Eoo`AlX09l`29oo`03001oogoo
0:ioo`03001oogoo01Moo`0037oo00<007ooOol05Goo00<007ooOol01Goo1GbP00=l`7k0Ool08Goo
00<007ooOol0[goo00<007ooOol05Woo000<Ool00`00Oomoo`0EOol00`00Oomoo`04Ool6O:000gc0
O/1oo`0QOol00`00Oomoo`2_Ool00`00Oomoo`0FOol000eoo`03001oogoo01=oo`03001oogoo00Eo
o`IlX09n`29oo`03001oogoo0;1oo`03001oogoo01Eoo`003Goo00<007ooOol04goo00<007ooOol0
17oo1gbP00=n`7ooOol08Goo00<007ooOol0/7oo00<007ooOol05Goo000=Ool00`00Oomoo`0COol0
0`00Oomoo`04Ool4O802O:02O/0SOol00`00Oomoo`2aOol00`00Oomoo`0DOol000eoo`03001oogoo
019oo`03001oogoo00Eoo`AlP003O:1nh7kP02Aoo`03001oogoo0;5oo`03001oogoo01Aoo`003Goo
00<007ooOol04Woo00<007ooOol01Goo17b000=lX7kPO^008goo00<007ooOol0/Woo00<007ooOol0
57oo000>Ool00`00Oomoo`0AOol00`00Oomoo`05Ool4O802O`0TOol00`00Oomoo`2cOol00`00Oomo
o`0COol000ioo`03001oogoo011oo`03001oogoo00Eoo`AlH003O81o07m002Aoo`03001oogoo0;=o
o`03001oogoo01=oo`003Woo00<007ooOol047oo00<007ooOol01Goo17aP00=lP7m0Od0097oo00<0
07ooOol0/goo00<007ooOol04goo000>Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool4O6000gb0Of1o
o`0SOol00`00Oomoo`2eOol00`00Oomoo`0BOol000moo`03001oogoo00ioo`03001oogoo00Ioo`Al
H003O81oH7oo02=oo`03001oogoo0;Eoo`03001oogoo019oo`003goo00<007ooOol03Woo00<007oo
Ool01Goo1GaP00=oH7ooOol08Woo00<007ooOol0]Woo00<007ooOol04Woo000@Ool00`00Oomoo`0=
Ool00`00Oomoo`05Ool4O4000gaPOf1oo`0SOol00`00Oomoo`2gOol00`00Oomoo`0AOol0015oo`03
001oogoo00]oo`03001oogoo00Ioo`Al@003O61oP7oo02=oo`03001oogoo0;Moo`03001oogoo015o
o`004Goo00<007ooOol02goo00<007ooOol01Woo17a000=lH7n0Ool08Woo00<007ooOol0^7oo00<0
07ooOol04Goo000BOol00`00Oomoo`0:Ool00`00Oomoo`06Ool4O4000gn0Oomoo`0ROol00`00Oomo
o`2iOol00`00Oomoo`0@Ool0019oo`03001oogoo00Uoo`03001oogoo00Moo`Al@003Oh1oogoo025o
o`03001oogoo0;Yoo`03001oogoo011oo`004goo00<007ooOol027oo00<007ooOol01goo17a000=o
P7ooOol087oo00<007ooOol0^goo00<007ooOol047oo000DOol00`00Oomoo`07Ool00`00Oomoo`06
Ool5O4000gnPOomoo`0POol00`00Oomoo`2lOol00`00Oomoo`0?Ool001Aoo`03001oogoo00Moo`03
001oogoo00Ioo`El@003Oj1oogoo01moo`03001oogoo0;eoo`03001oogoo00moo`005Goo00<007oo
Ool01Woo00<007ooOol01Woo17`P00=l@7nPOol07goo00<007ooOol0_Woo00<007ooOol03goo000E
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool4O2000ga0Ol1oo`0NOol00`00Oomoo`2oOol00`00Oomo
o`0?Ool001Ioo`03001oogoo00Aoo`03001oogoo00Moo`Al809o`1ioo`03001oogoo0<1oo`03001o
ogoo00moo`005goo00<007ooOol00goo00<007ooOol01goo17`000=o`7oPOol077oo00<007ooOol0
`Woo00<007ooOol03Woo000HOol00`00Oomoo`02Ool00`00Oomoo`07Ool4O0000go0Oomoo`0KOol0
0`00Oomoo`33Ool00`00Oomoo`0>Ool001Uoo`04001oogoo000:Ool4O0000goPOomoo`0KOol00`00
Oomoo`33Ool00`00Oomoo`0>Ool001Yoo`03001oo`0000Yoo`Al01eoo`03001oogoo0<Aoo`03001o
ogoo00ioo`006goo0P002Woo17`06goo0P00agoo00<007ooOol03Woo000LOol30008Ool4O00IOol2
003:Ool00`00Oomoo`0=Ool001aoo`04001oogoo0007Ool4O00GOol2003<Ool00`00Oomoo`0=Ool0
01]oo`03001oogoo009oo`8001moo`03001oogoo0<aoo`03001oogoo00eoo`006goo00<007ooOol0
17oo00<007ooOol06Woo0P00cgoo00<007ooOol03Goo000KOol00`00Oomoo`05Ool4000EOol3003A
Ool00`00Oomoo`0=Ool001]oo`03001oogoo00Uoo`<000ioo`@00=Aoo`03001oogoo00eoo`006goo
00<007ooOol037oo3P00fGoo00<007ooOol037oo000KOol00`00Oomoo`3cOol00`00Oomoo`0<Ool0
01]oo`03001oogoo0?=oo`03001oogoo00aoo`006Woo00<007ooOol0m7oo00<007ooOol037oo000J
Ool00`00Oomoo`3dOol00`00Oomoo`0<Ool001Yoo`03001oogoo0?Aoo`03001oogoo00aoo`006Woo
00<007ooOol0m7oo00<007ooOol037oo000JOol00`00Oomoo`3dOol00`00Oomoo`0<Ool001Yoo`03
001oogoo0?Aoo`03001oogoo00aoo`006Woo00<007ooOol0m7oo00<007ooOol037oo000JOol00`00
Oomoo`3eOol00`00Oomoo`0;Ool001Yoo`03001oogoo0?Eoo`03001oogoo00]oo`006Woo00<007oo
Ool0mGoo00<007ooOol02goo000JOol00`00Oomoo`3eOol00`00Oomoo`0;Ool001Yoo`03001oogoo
0?Eoo`03001oogoo00]oo`006Woo00<007ooOol0mGoo00<007ooOol02goo000IOol00`00Oomoo`3f
Ool00`00Oomoo`0;Ool001Uoo`03001oogoo0?Ioo`03001oogoo00]oo`006Goo00<007ooOol0mWoo
00<007ooOol02goo000IOol00`00Oomoo`3fOol00`00Oomoo`0;Ool001Uoo`03001oogoo0?Ioo`03
001oogoo00]oo`006Goo00<007ooOol0mWoo00<007ooOol02goo000IOol00`00Oomoo`3fOol00`00
Oomoo`0;Ool001Yoo`03001oogoo0?Eoo`03001oogoo00]oo`006Woo00<007ooOol0mGoo00<007oo
Ool02goo000JOol00`00Oomoo`3eOol00`00Oomoo`0;Ool001Yoo`03001oogoo0?Eoo`03001oogoo
00]oo`006Woo00<007ooOol0mGoo00<007ooOol02goo000JOol00`00Oomoo`3eOol00`00Oomoo`0;
Ool001Yoo`03001oogoo0?Aoo`03001oogoo00aoo`006Woo00<007ooOol0m7oo00<007ooOol037oo
000JOol00`00Oomoo`3dOol00`00Oomoo`0<Ool001Yoo`03001oogoo0?Aoo`03001oogoo00aoo`00
6Woo00<007ooOol0m7oo00<007ooOol037oo000JOol00`00Oomoo`3dOol00`00Oomoo`0<Ool001Yo
o`03001oogoo0?Aoo`03001oogoo00aoo`006goo00<007ooOol0lgoo00<007ooOol037oo000KOol0
0`00Oomoo`3cOol00`00Oomoo`0<Ool001]oo`03001oogoo0?9oo`03001oogoo00eoo`006goo00<0
07ooOol0lWoo00<007ooOol03Goo000KOol00`00Oomoo`3bOol00`00Oomoo`0=Ool001]oo`03001o
ogoo0?9oo`03001oogoo00eoo`0077oo00<007ooOol0lGoo00<007ooOol03Goo000LOol00`00Oomo
o`3aOol00`00Oomoo`0=Ool001aoo`03001oogoo0?5oo`03001oogoo00eoo`0077oo00<007ooOol0
l7oo00<007ooOol03Woo000LOol00`00Oomoo`3`Ool00`00Oomoo`0>Ool001eoo`03001oogoo0>mo
o`03001oogoo00ioo`007Goo00<007ooOol0kgoo00<007ooOol03Woo000MOol00`00Oomoo`3^Ool0
0`00Oomoo`0?Ool001eoo`03001oogoo0>ioo`03001oogoo00moo`007Goo00<007ooOol0kWoo00<0
07ooOol03goo000NOol00`00Oomoo`3]Ool00`00Oomoo`0?Ool001ioo`03001oogoo0>eoo`03001o
ogoo00moo`007Woo00<007ooOol0k7oo00<007ooOol047oo000NOol00`00Oomoo`3/Ool00`00Oomo
o`0@Ool001ioo`03001oogoo0>aoo`03001oogoo011oo`007goo00<007ooOol0jWoo00<007ooOol0
4Goo000OOol00`00Oomoo`3ZOol00`00Oomoo`0AOol001moo`03001oogoo0>Yoo`03001oogoo015o
o`0087oo00<007ooOol0j7oo00<007ooOol04Woo000POol00`00Oomoo`3XOol00`00Oomoo`0BOol0
021oo`03001oogoo0>Qoo`03001oogoo019oo`008Goo00<007ooOol0igoo00<007ooOol04Woo000Q
Ool00`00Oomoo`3VOol00`00Oomoo`0COol0025oo`03001oogoo0>Ioo`03001oogoo01=oo`008Woo
00<007ooOol0iGoo00<007ooOol04goo000ROol00`00Oomoo`3TOol00`00Oomoo`0DOol0029oo`03
001oogoo0>Aoo`03001oogoo01Aoo`008goo00<007ooOol0hWoo00<007ooOol05Goo000SOol00`00
Oomoo`3ROol00`00Oomoo`0EOol002=oo`03001oogoo0>9oo`03001oogoo01Eoo`0097oo00<007oo
Ool0h7oo00<007ooOol05Woo000TOol00`00Oomoo`3POol00`00Oomoo`0FOol002Eoo`03001oogoo
0=ioo`03001oogoo01Moo`009Woo00<007ooOol0gGoo00<007ooOol05goo000VOol00`00Oomoo`3L
Ool00`00Oomoo`0HOol002Moo`03001oogoo0=]oo`03001oogoo01Qoo`009goo00<007ooOol0fWoo
00<007ooOol06Goo000XOol00`00Oomoo`3IOol00`00Oomoo`0IOol002Qoo`03001oogoo0=Qoo`03
001oogoo01Yoo`00:Goo00<007ooOol0egoo00<007ooOol06Woo000YOol00`00Oomoo`3FOol00`00
Oomoo`0KOol002Yoo`03001oogoo0=Eoo`03001oogoo01]oo`00:Woo00<007ooOol0e7oo00<007oo
Ool077oo000[Ool00`00Oomoo`3COol00`00Oomoo`0LOol002]oo`03001oogoo0=9oo`03001oogoo
01eoo`00;7oo00<007ooOol0dGoo00<007ooOol07Goo000/Ool00`00Oomoo`3@Ool00`00Oomoo`0N
Ool002eoo`03001oogoo0<moo`03001oogoo01ioo`00;Goo00<007ooOol0cWoo00<007ooOol07goo
000^Ool00`00Oomoo`3<Ool00`00Oomoo`0POol002moo`03001oogoo0<Yoo`03001oogoo025oo`00
<7oo00<007ooOol0b7oo00<007ooOol08Woo000`Ool00`00Oomoo`38Ool00`00Oomoo`0ROol0035o
o`03001oogoo0<Ioo`03001oogoo02=oo`00<Woo00<007ooOol0aGoo00<007ooOol08goo000bOol0
0`00Oomoo`34Ool00`00Oomoo`0TOol003=oo`03001oogoo0<=oo`03001oogoo02Aoo`00=7oo00<0
07ooOol0`Goo00<007ooOol09Goo000eOol00`00Oomoo`2oOol00`00Oomoo`0VOol003Eoo`03001o
ogoo0;ioo`03001oogoo02Moo`00=Woo00<007ooOol0_Goo00<007ooOol09goo000fOol00`00Oomo
o`2lOol00`00Oomoo`0XOol003Moo`03001oogoo0;Yoo`03001oogoo02Uoo`00>7oo00<007ooOol0
^7oo00<007ooOol0:Woo000iOol00`00Oomoo`2fOol00`00Oomoo`0[Ool003Yoo`03001oogoo0;Eo
o`03001oogoo02]oo`00>goo00<007ooOol0/goo00<007ooOol0;7oo000lOol00`00Oomoo`2`Ool2
000_Ool003eoo`03001oogoo0:ioo`03001oogoo02moo`00?Woo00<007ooOol0[7oo00<007ooOol0
<7oo000oOol00`00Oomoo`2ZOol00`00Oomoo`0aOol0041oo`03001oogoo0:Qoo`03001oogoo039o
o`00@7oo00<007ooOol0Z7oo00<007ooOol0<Woo0011Ool00`00Oomoo`2VOol00`00Oomoo`0cOol0
049oo`03001oogoo0:Aoo`03001oogoo03Aoo`00@goo00<007ooOol0XWoo00<007ooOol0=Goo0014
Ool2002POol2000hOol004Ioo`03001oogoo09aoo`03001oogoo03Qoo`00Agoo00<007ooOol0VWoo
00<007ooOol0>Goo0018Ool00`00Oomoo`2HOol00`00Oomoo`0jOol004Uoo`8009Moo`03001oogoo
03]oo`00Bgoo00<007ooOol0Tgoo00<007ooOol0?7oo001<Ool00`00Oomoo`2@Ool2000oOol004eo
o`03001oogoo08ioo`03001oogoo03moo`00CWoo0P00SGoo00<007ooOol0@7oo001@Ool00`00Oomo
o`29Ool00`00Oomoo`11Ool0055oo`03001oogoo08Ioo`8004Aoo`00DWoo0P00Q7oo0P00AWoo001D
Ool20020Ool20018Ool005Ioo`03001oogoo07aoo`03001oogoo04Qoo`00Egoo00<007ooOol0NWoo
00<007ooOol0BGoo001HOol2001hOol2001<Ool005Yoo`8007Aoo`8004ioo`00G7oo0P00L7oo0P00
D7oo001NOol2001/Ool2001BOol0061oo`8006Qoo`8005Aoo`00HWoo0`00Hgoo0P00EWoo001UOol2
001NOol3001HOol006Moo`8005Yoo`8005]oo`00JGoo0P00EWoo0P00GGoo001[Ool2001BOol2001O
Ool006eoo`<004aoo`<0065oo`00L7oo0`00AWoo0`00I7oo001cOol6000jOol6001WOol007Uoo`<0
03Aoo`<006eoo`00O7oo1000;7oo1000L7oo0020Ool6000POol6001dOol008Ioo`h000Aoo`h007Yo
o`00U7oo1000R7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002=Ool5002>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00SWoo0P00T7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-205.493, -178.502, 1.36919, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.535449 0.0025926 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(2)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.440741 0.47619 scale
1.21488 1.05 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.15077 .39535 m
.15086 .39522 L
.151 .39503 L
.15117 .39476 L
.15136 .39442 L
.15155 .39398 L
.15173 .39344 L
.15192 .39282 L
.15209 .39214 L
.15228 .39138 L
.15251 .39053 L
.15277 .38961 L
.15306 .38868 L
.15335 .38771 L
.15359 .38674 L
.15386 .38582 L
.15412 .38496 L
.15439 .3841 L
.15467 .38322 L
.15497 .38231 L
.15526 .38135 L
.15552 .38041 L
.15572 .37941 L
.15585 .37835 L
.15591 .37722 L
.15588 .37612 L
.15579 .3749 L
.1557 .3737 L
.15562 .37248 L
.15556 .37117 L
.15552 .36984 L
.15551 .36862 L
.15551 .36741 L
.1555 .36629 L
.1555 .36529 L
.15553 .36442 L
.15558 .36366 L
.15568 .363 L
.15581 .3624 L
.15597 .36179 L
.15615 .36113 L
.15632 .36037 L
.15648 .35951 L
.15665 .3585 L
.15686 .35732 L
.15714 .35621 L
.15749 .35488 L
.15791 .35349 L
.15841 .35185 L
.15895 .35031 L
Mistroke
.15951 .34854 L
.16006 .34661 L
.16059 .3448 L
.1611 .34293 L
.16158 .3411 L
.16206 .33931 L
.16255 .33785 L
.16306 .33638 L
.16355 .33506 L
.16399 .33394 L
.16437 .3329 L
.16468 .33207 L
.16491 .3314 L
.1651 .33089 L
.16527 .33055 L
.16545 .3304 L
.16564 .33039 L
.1658 .3305 L
.16593 .33068 L
.166 .33086 L
.166 .33098 L
.16593 .33099 L
.1658 .33085 L
.16562 .33056 L
.16542 .3301 L
.1652 .3295 L
.16496 .32876 L
.16472 .32793 L
.16448 .3271 L
.16424 .32618 L
.164 .32521 L
.16378 .32421 L
.16359 .32335 L
.16344 .32258 L
.16332 .32197 L
.16323 .32156 L
.16318 .32142 L
.16316 .32155 L
.16317 .32191 L
.16321 .32242 L
.16326 .32301 L
.16332 .3236 L
.16343 .32412 L
.16358 .32454 L
.16379 .32484 L
.16405 .32496 L
.16436 .3249 L
.16471 .32466 L
.16511 .32423 L
.16556 .32364 L
Mistroke
.16606 .32294 L
.16659 .32212 L
.1671 .3212 L
.16758 .32026 L
.16805 .3194 L
.16849 .31868 L
.1689 .31807 L
.16929 .31754 L
.16966 .31708 L
.17003 .31666 L
.17041 .31625 L
.17082 .31581 L
.17126 .3153 L
.17174 .31468 L
.17223 .31393 L
.17278 .31302 L
.17337 .31191 L
.17398 .31073 L
.17456 .30929 L
.17513 .30767 L
.1757 .30609 L
.17623 .30436 L
.17668 .30262 L
.17706 .30089 L
.17735 .29934 L
.17756 .29788 L
.1777 .29659 L
.17777 .29553 L
.1778 .29464 L
.17778 .29388 L
.17774 .29328 L
.17768 .29282 L
.17763 .29252 L
.17757 .29236 L
.17751 .29233 L
.17746 .29241 L
.17741 .29257 L
.17737 .29275 L
.17734 .29292 L
.17734 .29304 L
.1774 .2931 L
.17755 .29307 L
.17782 .29294 L
.17822 .29268 L
.17877 .29229 L
.17944 .29178 L
.18027 .29112 L
.18125 .29033 L
.18228 .28943 L
.18343 .28847 L
Mistroke
.18455 .28743 L
.1857 .28636 L
.18685 .28532 L
.18784 .28444 L
.18881 .28368 L
.1897 .28305 L
.19047 .28255 L
.19111 .28215 L
.19164 .28182 L
.19206 .28149 L
.19241 .28114 L
.19269 .28071 L
.19296 .28019 L
.19324 .27956 L
.19355 .27882 L
.19392 .27794 L
.19432 .27705 L
.19474 .27607 L
.1952 .27505 L
.19564 .27401 L
.1961 .27304 L
.19654 .27214 L
.19696 .27135 L
.19734 .27075 L
.19769 .27031 L
.19798 .26998 L
.19821 .26973 L
.19838 .2695 L
.19849 .26922 L
.19858 .26883 L
.19864 .26829 L
.19872 .26761 L
.19884 .2668 L
.19898 .26592 L
.19914 .26513 L
.19932 .26407 L
.19953 .26307 L
.19973 .26199 L
.19991 .26083 L
.20006 .25958 L
.20019 .25835 L
.2003 .25707 L
.20041 .25573 L
.20053 .25434 L
.20067 .25308 L
.20083 .25161 L
.20102 .25012 L
.20125 .24856 L
.20153 .24694 L
.20191 .24518 L
Mistroke
.20238 .24367 L
.20295 .24217 L
.20364 .24071 L
.20436 .23935 L
.20514 .23811 L
.20597 .23692 L
.20682 .23575 L
.20762 .23462 L
.20846 .23346 L
.20928 .23233 L
.21018 .23124 L
.21106 .23012 L
.21202 .22897 L
.21309 .2278 L
.21418 .22663 L
.21532 .22539 L
.2165 .22417 L
.21755 .22293 L
.21859 .22171 L
.21958 .22053 L
.2205 .21954 L
.22138 .21854 L
.22211 .21763 L
.22275 .21692 L
.22326 .2163 L
.22363 .21577 L
.22389 .21532 L
.224 .21493 L
.22402 .21458 L
.22396 .21426 L
.22389 .21391 L
.22384 .21351 L
.2238 .213 L
.22378 .21242 L
.22377 .21185 L
.22376 .21139 L
.22371 .21101 L
.22361 .21078 L
.22348 .21077 L
.2233 .21098 L
.22309 .21144 L
.22283 .21211 L
.22256 .21296 L
.22229 .21384 L
.22202 .21496 L
.22178 .21598 L
.22157 .217 L
.22143 .21793 L
.22137 .21869 L
.22142 .21926 L
Mistroke
.2216 .21961 L
.22192 .21977 L
.22236 .2198 L
.2229 .21974 L
.22355 .21964 L
.22428 .21953 L
.22503 .21946 L
.2257 .21944 L
.22632 .21945 L
.22684 .21947 L
.22721 .21947 L
.22743 .21948 L
.22749 .21947 L
.22739 .21944 L
.22722 .21938 L
.22698 .21929 L
.22662 .21918 L
.22618 .21906 L
.22564 .21897 L
.22499 .21895 L
.22427 .21902 L
.2235 .21921 L
.22267 .21956 L
.22178 .22009 L
.22084 .2208 L
.21985 .22174 L
.21892 .22285 L
.21792 .22418 L
.21677 .22572 L
.21533 .22738 L
.21403 .22902 L
.21268 .23076 L
.21128 .23258 L
.20996 .23433 L
.20861 .23593 L
.20728 .23751 L
.20609 .23906 L
.20498 .24047 L
.20386 .24189 L
.20272 .24335 L
.20157 .24489 L
.20049 .24641 L
.19947 .24804 L
.19847 .24983 L
.19751 .25177 L
.19662 .25363 L
.19579 .25572 L
.195 .25774 L
.19425 .25981 L
.1936 .26173 L
Mistroke
.19305 .2634 L
.19261 .2649 L
.19228 .2662 L
.19204 .26717 L
.19185 .26794 L
.19169 .26855 L
.19152 .26902 L
.19132 .26938 L
.19103 .26971 L
.19065 .27006 L
.19019 .27042 L
.18965 .27082 L
.18904 .27127 L
.18844 .27178 L
.1877 .27246 L
.18698 .27321 L
.18618 .27409 L
.18533 .27509 L
.18446 .27618 L
.18362 .27735 L
.18281 .27861 L
.1821 .27984 L
.18138 .28115 L
.18069 .2825 L
.18002 .28389 L
.17937 .28523 L
.17871 .28668 L
.17811 .28825 L
.17764 .28981 L
.17728 .29131 L
.17697 .29276 L
.17669 .2942 L
.17641 .29539 L
.17608 .29664 L
.17563 .29777 L
.17506 .29899 L
.17444 .30028 L
.17363 .30152 L
.1727 .3028 L
.1717 .3041 L
.17075 .30542 L
.16974 .30675 L
.16864 .30799 L
.16747 .30926 L
.16631 .31056 L
.1653 .31194 L
.1644 .31324 L
.16363 .3146 L
.16299 .31601 L
.16246 .31745 L
Mistroke
.16204 .31882 L
.1617 .32016 L
.16144 .32153 L
.16124 .32297 L
.16108 .32443 L
.16094 .32594 L
.16082 .32751 L
.16067 .32907 L
.1605 .33049 L
.16032 .33178 L
.16015 .33292 L
.15998 .33392 L
.15979 .3348 L
.15957 .33553 L
.15932 .33618 L
.15905 .33676 L
.15877 .3373 L
.15851 .33784 L
.15825 .33842 L
.15801 .33908 L
.15777 .33988 L
.15753 .34087 L
.15728 .34199 L
.15699 .34328 L
.15664 .34479 L
.15623 .34661 L
.15579 .34849 L
.15535 .35058 L
.15494 .35285 L
.15457 .35486 L
.15422 .35718 L
.15389 .35927 L
.15358 .36153 L
.15327 .36398 L
.15295 .36645 L
.15265 .36865 L
.15236 .37091 L
.1521 .37331 L
.15189 .37576 L
.15172 .37783 L
.15156 .38005 L
.15141 .38216 L
.15127 .38421 L
.15113 .38618 L
.15101 .38791 L
.15089 .38949 L
.15083 .39082 L
.15079 .39195 L
.15079 .39287 L
.15081 .3936 L
Mistroke
.15083 .39418 L
.15085 .39463 L
.15085 .39502 L
.15085 .39544 L
.15084 .39591 L
.15083 .39647 L
.15082 .39715 L
.15081 .39796 L
.1508 .3988 L
.15078 .39975 L
.15077 .40078 L
.15075 .40187 L
.15073 .40297 L
.15072 .40391 L
.1507 .40479 L
.15069 .40556 L
.15068 .4062 L
.15068 .40668 L
.15067 .40697 L
Mfstroke
1 .99 0 r
.008 w
.1507 .40668 Mdot
.016 w
.1507 .40668 m
.1507 .40651 L
s
1 .98 0 r
.008 w
.1507 .40651 Mdot
.016 w
.1507 .40651 m
.1507 .40629 L
s
1 .97 0 r
.008 w
.1507 .40629 Mdot
.016 w
.1507 .40629 m
.15069 .40601 L
s
1 .96 0 r
.008 w
.15069 .40601 Mdot
.016 w
.15069 .40601 m
.15066 .40564 L
s
1 .949 0 r
.008 w
.15066 .40564 Mdot
.016 w
.15066 .40564 m
.15062 .40537 L
s
1 .939 0 r
.008 w
.15062 .40537 Mdot
.016 w
.15062 .40537 m
.15061 .40494 L
s
1 .929 0 r
.008 w
.15061 .40494 Mdot
.016 w
.15061 .40494 m
.15062 .4045 L
s
1 .919 0 r
.008 w
.15062 .4045 Mdot
.016 w
.15062 .4045 m
.15066 .40399 L
s
1 .909 0 r
.008 w
.15066 .40399 Mdot
.016 w
.15066 .40399 m
.15075 .4033 L
s
1 .899 0 r
.008 w
.15075 .4033 Mdot
.016 w
.15075 .4033 m
.15089 .40262 L
s
1 .889 0 r
.008 w
.15089 .40262 Mdot
.016 w
.15089 .40262 m
.15109 .40208 L
s
1 .879 0 r
.008 w
.15109 .40208 Mdot
.016 w
.15109 .40208 m
.15133 .40132 L
s
1 .869 0 r
.008 w
.15133 .40132 Mdot
.016 w
.15133 .40132 m
.15158 .40059 L
s
1 .859 0 r
.008 w
.15158 .40059 Mdot
.016 w
.15158 .40059 m
.15183 .39979 L
s
1 .848 0 r
.008 w
.15183 .39979 Mdot
.016 w
.15183 .39979 m
.15207 .39891 L
s
1 .838 0 r
.008 w
.15207 .39891 Mdot
.016 w
.15207 .39891 m
.15229 .39786 L
s
1 .828 0 r
.008 w
.15229 .39786 Mdot
.016 w
.15229 .39786 m
.15253 .39697 L
s
1 .818 0 r
.008 w
.15253 .39697 Mdot
.016 w
.15253 .39697 m
.15277 .39605 L
s
1 .808 0 r
.008 w
.15277 .39605 Mdot
.016 w
.15277 .39605 m
.153 .39498 L
s
1 .798 0 r
.008 w
.153 .39498 Mdot
.016 w
.153 .39498 m
.15319 .39377 L
s
1 .788 0 r
.008 w
.15319 .39377 Mdot
.016 w
.15319 .39377 m
.15332 .39255 L
s
1 .778 0 r
.008 w
.15332 .39255 Mdot
.016 w
.15332 .39255 m
.15339 .39156 L
s
1 .768 0 r
.008 w
.15339 .39156 Mdot
.016 w
.15339 .39156 m
.15343 .39047 L
s
1 .758 0 r
.008 w
.15343 .39047 Mdot
.016 w
.15343 .39047 m
.15344 .38935 L
s
1 .747 0 r
.008 w
.15344 .38935 Mdot
.016 w
.15344 .38935 m
.15342 .38838 L
s
1 .737 0 r
.008 w
.15342 .38838 Mdot
.016 w
.15342 .38838 m
.15339 .38742 L
s
1 .727 0 r
.008 w
.15339 .38742 Mdot
.016 w
.15339 .38742 m
.15338 .38652 L
s
1 .717 0 r
.008 w
.15338 .38652 Mdot
.016 w
.15338 .38652 m
.15339 .38576 L
s
1 .707 0 r
.008 w
.15339 .38576 Mdot
.016 w
.15339 .38576 m
.1534 .38514 L
s
1 .697 0 r
.008 w
.1534 .38514 Mdot
.016 w
.1534 .38514 m
.1534 .38461 L
s
1 .687 0 r
.008 w
.1534 .38461 Mdot
.016 w
.1534 .38461 m
.15341 .38416 L
s
1 .677 0 r
.008 w
.15341 .38416 Mdot
.016 w
.15341 .38416 m
.15341 .38381 L
s
1 .667 0 r
.008 w
.15341 .38381 Mdot
.016 w
.15341 .38381 m
.15341 .38357 L
s
1 .657 0 r
.008 w
.15341 .38357 Mdot
.016 w
.15341 .38357 m
.15341 .38344 L
s
1 .646 0 r
.008 w
.15341 .38344 Mdot
.016 w
.15341 .38344 m
.15342 .38337 L
s
1 .636 0 r
.008 w
.15342 .38337 Mdot
.016 w
.15342 .38337 m
.15342 .38336 L
s
1 .626 0 r
.008 w
.15342 .38336 Mdot
.016 w
.15342 .38336 m
.15341 .38339 L
s
1 .616 0 r
.008 w
.15341 .38339 Mdot
.016 w
.15341 .38339 m
.15341 .38345 L
s
1 .606 0 r
.008 w
.15341 .38345 Mdot
.016 w
.15341 .38345 m
.15341 .38353 L
s
1 .596 0 r
.008 w
.15341 .38353 Mdot
.016 w
.15341 .38353 m
.15341 .3836 L
s
1 .586 0 r
.008 w
.15341 .3836 Mdot
.016 w
.15341 .3836 m
.15341 .38362 L
s
1 .576 0 r
.008 w
.15341 .38362 Mdot
.016 w
.15341 .38362 m
.15341 .38363 L
s
1 .566 0 r
.008 w
.15341 .38363 Mdot
.016 w
.15341 .38363 m
.15341 .38363 L
s
1 .556 0 r
.008 w
.15341 .38363 Mdot
.016 w
.15341 .38363 m
.15341 .38364 L
s
1 .545 0 r
.008 w
.15341 .38364 Mdot
.016 w
.15341 .38364 m
.15341 .38368 L
s
1 .535 0 r
.008 w
.15341 .38368 Mdot
.016 w
.15341 .38368 m
.15341 .38375 L
s
1 .525 0 r
.008 w
.15341 .38375 Mdot
.016 w
.15341 .38375 m
.1534 .38382 L
s
1 .515 0 r
.008 w
.1534 .38382 Mdot
.016 w
.1534 .38382 m
.15338 .38385 L
s
1 .505 0 r
.008 w
.15338 .38385 Mdot
.016 w
.15338 .38385 m
.15334 .38382 L
s
1 .495 0 r
.008 w
.15334 .38382 Mdot
.016 w
.15334 .38382 m
.15331 .38373 L
s
1 .485 0 r
.008 w
.15331 .38373 Mdot
.016 w
.15331 .38373 m
.15331 .38356 L
s
1 .475 0 r
.008 w
.15331 .38356 Mdot
.016 w
.15331 .38356 m
.15332 .38329 L
s
1 .465 0 r
.008 w
.15332 .38329 Mdot
.016 w
.15332 .38329 m
.15338 .38293 L
s
1 .455 0 r
.008 w
.15338 .38293 Mdot
.016 w
.15338 .38293 m
.15348 .3825 L
s
1 .444 0 r
.008 w
.15348 .3825 Mdot
.016 w
.15348 .3825 m
.15363 .38204 L
s
1 .434 0 r
.008 w
.15363 .38204 Mdot
.016 w
.15363 .38204 m
.15383 .38156 L
s
1 .424 0 r
.008 w
.15383 .38156 Mdot
.016 w
.15383 .38156 m
.15406 .38107 L
s
1 .414 0 r
.008 w
.15406 .38107 Mdot
.016 w
.15406 .38107 m
.15435 .3806 L
s
1 .404 0 r
.008 w
.15435 .3806 Mdot
.016 w
.15435 .3806 m
.15466 .38012 L
s
1 .394 0 r
.008 w
.15466 .38012 Mdot
.016 w
.15466 .38012 m
.15493 .37965 L
s
1 .384 0 r
.008 w
.15493 .37965 Mdot
.016 w
.15493 .37965 m
.15516 .37925 L
s
1 .374 0 r
.008 w
.15516 .37925 Mdot
.016 w
.15516 .37925 m
.15539 .37895 L
s
1 .364 0 r
.008 w
.15539 .37895 Mdot
.016 w
.15539 .37895 m
.15561 .37881 L
s
1 .354 0 r
.008 w
.15561 .37881 Mdot
.016 w
.15561 .37881 m
.15576 .37885 L
s
1 .343 0 r
.008 w
.15576 .37885 Mdot
.016 w
.15576 .37885 m
.1558 .37906 L
s
1 .333 0 r
.008 w
.1558 .37906 Mdot
.016 w
.1558 .37906 m
.15571 .3794 L
s
1 .323 0 r
.008 w
.15571 .3794 Mdot
.016 w
.15571 .3794 m
.15553 .37983 L
s
1 .313 0 r
.008 w
.15553 .37983 Mdot
.016 w
.15553 .37983 m
.15529 .38034 L
s
1 .303 0 r
.008 w
.15529 .38034 Mdot
.016 w
.15529 .38034 m
.15501 .38086 L
s
1 .293 0 r
.008 w
.15501 .38086 Mdot
.016 w
.15501 .38086 m
.15472 .38125 L
s
1 .283 0 r
.008 w
.15472 .38125 Mdot
.016 w
.15472 .38125 m
.15444 .38152 L
s
1 .273 0 r
.008 w
.15444 .38152 Mdot
.016 w
.15444 .38152 m
.15417 .38185 L
s
1 .263 0 r
.008 w
.15417 .38185 Mdot
.016 w
.15417 .38185 m
.15394 .38224 L
s
1 .253 0 r
.008 w
.15394 .38224 Mdot
.016 w
.15394 .38224 m
.15375 .38265 L
s
1 .242 0 r
.008 w
.15375 .38265 Mdot
.016 w
.15375 .38265 m
.1536 .38306 L
s
1 .232 0 r
.008 w
.1536 .38306 Mdot
.016 w
.1536 .38306 m
.15349 .38344 L
s
1 .222 0 r
.008 w
.15349 .38344 Mdot
.016 w
.15349 .38344 m
.15342 .38383 L
s
1 .212 0 r
.008 w
.15342 .38383 Mdot
.016 w
.15342 .38383 m
.15336 .38435 L
s
1 .202 0 r
.008 w
.15336 .38435 Mdot
.016 w
.15336 .38435 m
.15327 .38507 L
s
1 .192 0 r
.008 w
.15327 .38507 Mdot
.016 w
.15327 .38507 m
.15314 .38601 L
s
1 .182 0 r
.008 w
.15314 .38601 Mdot
.016 w
.15314 .38601 m
.15296 .38715 L
s
1 .172 0 r
.008 w
.15296 .38715 Mdot
.016 w
.15296 .38715 m
.15271 .38843 L
s
1 .162 0 r
.008 w
.15271 .38843 Mdot
.016 w
.15271 .38843 m
.1525 .38971 L
s
1 .152 0 r
.008 w
.1525 .38971 Mdot
.016 w
.1525 .38971 m
.15223 .39142 L
s
1 .141 0 r
.008 w
.15223 .39142 Mdot
.016 w
.15223 .39142 m
.15197 .39365 L
s
1 .131 0 r
.008 w
.15197 .39365 Mdot
.016 w
.15197 .39365 m
.15173 .39534 L
s
1 .121 0 r
.008 w
.15173 .39534 Mdot
.016 w
.15173 .39534 m
.15148 .3977 L
s
1 .111 0 r
.008 w
.15148 .3977 Mdot
.016 w
.15148 .3977 m
.15123 .3996 L
s
1 .101 0 r
.008 w
.15123 .3996 Mdot
.016 w
.15123 .3996 m
.15098 .40164 L
s
1 .091 0 r
.008 w
.15098 .40164 Mdot
.016 w
.15098 .40164 m
.15079 .40381 L
s
1 .081 0 r
.008 w
.15079 .40381 Mdot
.016 w
.15079 .40381 m
.15066 .40532 L
s
1 .071 0 r
.008 w
.15066 .40532 Mdot
.016 w
.15066 .40532 m
.15059 .40693 L
s
1 .061 0 r
.008 w
.15059 .40693 Mdot
.016 w
.15059 .40693 m
.15055 .40844 L
s
1 .051 0 r
.008 w
.15055 .40844 Mdot
.016 w
.15055 .40844 m
.15054 .40944 L
s
1 .04 0 r
.008 w
.15054 .40944 Mdot
.016 w
.15054 .40944 m
.15055 .41026 L
s
1 .03 0 r
.008 w
.15055 .41026 Mdot
.016 w
.15055 .41026 m
.15058 .41091 L
s
1 .02 0 r
.008 w
.15058 .41091 Mdot
.016 w
.15058 .41091 m
.15059 .41137 L
s
1 .01 0 r
.008 w
.15059 .41137 Mdot
.016 w
.15059 .41137 m
.15059 .41164 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.12963 0.140056 scale
1.18368 2.7389 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002?OolE001lOol008Ioo`T0
01Eoo`H007Ioo`00Pgoo0`0097oo1P00L7oo001mOol6000]Ool6001ZOol007Yoo`<003Uoo`<006Mo
o`00Mgoo0`00?goo0`00I7oo001dOol30015Ool2001ROol0075oo`<004Yoo`<005moo`00KWoo0`00
D7oo0`00G7oo001/Ool2001FOol3001IOol006Yoo`8005]oo`8005Moo`00J7oo0P00Ggoo0P00EGoo
001VOol2001SOol2001COol006=oo`<006Moo`80055oo`00HWoo00<007ooOol0JWoo0P00Cgoo001P
Ool2001_Ool2001=Ool005moo`03001oogoo075oo`03001oogoo04Yoo`00GGoo0P00MGoo00<007oo
Ool0BGoo001KOol2001hOol20019Ool005Yoo`03001oogoo07Yoo`8004Moo`00F7oo0P00Ogoo00<0
07ooOol0A7oo001GOol00`00Oomoo`20Ool00`00Oomoo`13Ool005Ioo`03001oogoo089oo`8004=o
o`00EGoo00<007ooOol0QGoo00<007ooOol0@7oo001COol20029Ool00`00Oomoo`0oOol0059oo`03
001oogoo08Yoo`03001oogoo03ioo`00DGoo00<007ooOol0S7oo0P00?Woo001@Ool00`00Oomoo`2?
Ool00`00Oomoo`0kOol004ioo`8009=oo`03001oogoo03Yoo`00CGoo00<007ooOol0U7oo00<007oo
Ool0>Goo001<Ool00`00Oomoo`2FOol2000iOol004]oo`03001oogoo09Uoo`03001oogoo03Ioo`00
BWoo00<007ooOol0Vgoo00<007ooOol0=Goo0019Ool00`00Oomoo`2MOol00`00Oomoo`0dOol004Mo
o`800:5oo`03001oogoo03=oo`00AWoo00<007ooOol0XWoo00<007ooOol0<Woo0015Ool00`00Oomo
o`2TOol00`00Oomoo`0aOol004Aoo`03001oogoo0:Ioo`03001oogoo031oo`00@goo00<007ooOol0
Z7oo00<007ooOol0;goo0012Ool00`00Oomoo`2YOol00`00Oomoo`0_Ool0045oo`03001oogoo0:]o
o`03001oogoo02ioo`00@Goo00<007ooOol0[7oo00<007ooOol0;Goo0010Ool00`00Oomoo`2^Ool0
0`00Oomoo`0/Ool003moo`03001oogoo0;1oo`03001oogoo02]oo`00?Woo00<007ooOol0/Woo00<0
07ooOol0:Woo000mOol00`00Oomoo`2dOol00`00Oomoo`0YOol003eoo`03001oogoo0;Aoo`03001o
ogoo02Uoo`00?7oo00<007ooOol0]Woo00<007ooOol0:7oo000kOol00`00Oomoo`2hOol00`00Oomo
o`0WOol003Yoo`03001oogoo0;Yoo`03001oogoo02Ioo`00>Goo00<007ooOol01goo0Sg_/goo00<0
07ooOol09Goo000iOol00`00Oomoo`06Ool4?NnbOol00`00Oomoo`0UOol003Qoo`03001oogoo00Io
o`Dmkk=oo`03001oogoo02Aoo`00=goo00<007ooOol01Woo1cg_/goo00<007ooOol08goo000fOol0
0`00Oomoo`06Ool8?NndOol00`00Oomoo`0ROol003Ioo`03001oogoo00Eoo`PmkkIoo`03001oogoo
025oo`00=Goo00<007ooOol01Goo23g_]goo00<007ooOol08Goo000eOol00`00Oomoo`05Ool7?Nni
Ool00`00Oomoo`0POol003Aoo`03001oogoo00Eoo`LmkkYoo`03001oogoo021oo`00=7oo00<007oo
Ool017oo1cg__7oo00<007ooOol07goo000/Ool80007Ool6?NnmOol00`00Oomoo`0OOol002Moo`D0
00Ioo`03001oo`0000@00003Oolmkcg_00Dmkkioo`03001oogoo01ioo`0097oo0`002goo00<007oo
Ool017oo10000cg__goo00<007ooOol07Woo000ROol2000=Ool00`00Oomoo`05Ool4?Nl00`00?Nmo
o`30Ool00`00Oomoo`0MOol0025oo`03001oogoo00eoo`03001oogoo00Eoo`Dmk`800<5oo`03001o
ogoo01aoo`007goo0P003goo00<007ooOol01Woo1Sg_00=oo`000000`7oo00<007ooOol06goo000N
Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool7?Nl3Ool00`00Oomoo`2mOol00`00Oomoo`0KOol001ao
o`80015oo`03001oogoo00Eoo`Pmk`Aoo`03001oogoo0;eoo`03001oogoo01Yoo`006goo00<007oo
Ool047oo00<007ooOol01Goo2Cg_1Goo0P00_Goo00<007ooOol06Woo000IOol2000COol00`00Oomo
o`05Ool8?Nl8Ool00`00Oomoo`2jOol00`00Oomoo`0JOol001Qoo`03001oogoo019oo`03001oogoo
00Eoo`Pmk`Yoo`800;]oo`03001oogoo01Uoo`005goo00<007ooOol04goo00<007ooOol01Goo23g_
37oo00<007ooOol0^7oo00<007ooOol06Goo000GOol00`00Oomoo`0COol00`00Oomoo`04Ool9?Nl=
Ool00`00Oomoo`2hOol00`00Oomoo`0HOol001Ioo`03001oogoo01=oo`03001oogoo00Eoo`Tmk`eo
o`03001oogoo0;Qoo`03001oogoo01Qoo`005Goo00<007ooOol057oo00<007ooOol01Goo1Sg_4Goo
00<007ooOol0^7oo00<007ooOol05goo000DOol00`00Oomoo`0DOol00`00Oomoo`05Ool7?NlBOol0
0`00Oomoo`2gOol00`00Oomoo`0GOol001=oo`03001oogoo01Eoo`03001oogoo00Eoo`Hmka=oo`03
001oogoo0;Qoo`03001oogoo01Ioo`004Woo00<007ooOol05Goo00<007ooOol01Goo1cg_57oo00<0
07ooOol0]goo00<007ooOol05Woo000BOol00`00Oomoo`0EOol00`00Oomoo`04Ool7?NlFOol00`00
Oomoo`2fOol00`00Oomoo`0FOol0015oo`03001oogoo01Eoo`03001oogoo00Aoo`PmkaIoo`03001o
ogoo0;Moo`03001oogoo01Eoo`004Goo00<007ooOol05Goo00<007ooOol017oo1cg_67oo00<007oo
Ool0]Woo00<007ooOol05Goo000AOol00`00Oomoo`0EOol00`00Oomoo`04Ool7?NlIOol00`00Oomo
o`2fOol00`00Oomoo`0DOol0011oo`03001oogoo01Eoo`03001oogoo00Eoo`LmkaUoo`03001oogoo
0;Ioo`03001oogoo01Aoo`0047oo00<007ooOol05Goo00<007ooOol01Goo1Sg_6goo00<007ooOol0
]Goo00<007ooOol057oo000?Ool00`00Oomoo`0FOol00`00Oomoo`05Ool6?NlKOol00`00Oomoo`2f
Ool00`00Oomoo`0COol000moo`03001oogoo01Ioo`03001oogoo00Aoo`Lmka]oo`03001oogoo0;Io
o`03001oogoo01=oo`003Woo00<007ooOol05Woo00<007ooOol01Goo1Sg_77oo00<007ooOol0]Woo
00<007ooOol04goo000>Ool00`00Oomoo`0FOol00`00Oomoo`05Ool5?NlNOol00`00Oomoo`2fOol0
0`00Oomoo`0BOol000ioo`03001oogoo01Ioo`03001oogoo00Aoo`Hmkaioo`03001oogoo0;Ioo`03
001oogoo019oo`003Goo00<007ooOol05Woo00<007ooOol01Goo1Sg_7Woo00<007ooOol0]Woo00<0
07ooOol04Woo000=Ool00`00Oomoo`0FOol00`00Oomoo`05Ool6?NlOOol00`00Oomoo`2fOol00`00
Oomoo`0AOol000eoo`03001oogoo01Ioo`03001oogoo00Eoo`Dmkb1oo`03001oogoo0;Ioo`03001o
ogoo015oo`003Goo00<007ooOol05Goo00<007ooOol01Woo1Cg_87oo00<007ooOol0]Woo00<007oo
Ool04Goo000=Ool00`00Oomoo`0EOol00`00Oomoo`06Ool5?NlPOol00`00Oomoo`2gOol00`00Oomo
o`0@Ool000eoo`03001oogoo01Eoo`03001oogoo00Ioo`Dmkb1oo`03001oogoo0;Moo`03001oogoo
011oo`0037oo00<007ooOol05Goo00<007ooOol01Woo1Sg_87oo00<007ooOol0]goo00<007ooOol0
47oo000<Ool00`00Oomoo`0EOol00`00Oomoo`06Ool3?Nl2OF000cg_Oomoo`0NOol00`00Oomoo`2h
Ool00`00Oomoo`0?Ool000aoo`03001oogoo01Eoo`03001oogoo00Ioo`03?Nmm07d0009m0003OF0m
kgoo01ioo`03001oogoo0;Qoo`03001oogoo00moo`0037oo00<007ooOol05Goo00<007ooOol01Woo
00<mkgbPO:000WbP00=mH7ooOol07Woo00<007ooOol0^7oo00<007ooOol03goo000<Ool00`00Oomo
o`0DOol00`00Oomoo`07Ool01Cg_O:1lP7b0O:008Goo00<007ooOol0^7oo00<007ooOol03goo000<
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00cg_O81lP002O80QOol00`00Oomoo`2hOol00`00Oomo
o`0?Ool000aoo`03001oogoo01Aoo`03001oogoo00Moo`AlH09lP21oo`03001oogoo0;Uoo`03001o
ogoo00ioo`0037oo00<007ooOol057oo00<007ooOol01goo17aP00=lP7ooOol07goo00<007ooOol0
^Goo00<007ooOol03Woo000<Ool00`00Oomoo`0COol00`00Oomoo`08Ool4O4000gbPOomoo`0OOol0
0`00Oomoo`2iOol00`00Oomoo`0>Ool000eoo`03001oogoo019oo`03001oogoo00Qoo`Al8003Ob1o
ogoo01moo`03001oogoo0;Uoo`03001oogoo00ioo`003Goo00<007ooOol04Woo00<007ooOol027oo
17`000=o@7ooOol07goo00<007ooOol0^Goo00<007ooOol03Woo000=Ool00`00Oomoo`0BOol00`00
Oomoo`08Ool4O00ROol00`00Oomoo`2jOol00`00Oomoo`0=Ool000eoo`03001oogoo019oo`03001o
ogoo00Qoo`Al029oo`03001oogoo0;Yoo`03001oogoo00eoo`003Goo00<007ooOol04Woo00<007oo
Ool027oo17`08Goo00<007ooOol0^goo00<007ooOol03Goo000>Ool00`00Oomoo`0AOol00`00Oomo
o`08Ool4O00QOol00`00Oomoo`2kOol00`00Oomoo`0=Ool000ioo`03001oogoo011oo`03001oogoo
02ioo`03001oogoo0;]oo`03001oogoo00eoo`003Woo00<007ooOol047oo00<007ooOol0;Woo00<0
07ooOol0^goo00<007ooOol03Goo000>Ool00`00Oomoo`0@Ool00`00Oomoo`0]Ool00`00Oomoo`2m
Ool00`00Oomoo`0<Ool000moo`03001oogoo00moo`03001oogoo02eoo`03001oogoo0;eoo`03001o
ogoo00aoo`003goo00<007ooOol03goo00<007ooOol0;Goo00<007ooOol0_Goo00<007ooOol037oo
000@Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`2mOol00`00Oomoo`0<Ool0011oo`03
001oogoo00eoo`03001oogoo02eoo`03001oogoo0;ioo`03001oogoo00aoo`004Goo00<007ooOol0
37oo00<007ooOol0;7oo00<007ooOol0_goo00<007ooOol037oo000AOol00`00Oomoo`0<Ool00`00
Oomoo`0/Ool00`00Oomoo`2oOol00`00Oomoo`0<Ool0015oo`03001oogoo00aoo`03001oogoo02]o
o`03001oogoo0<1oo`03001oogoo00aoo`004Woo00<007ooOol02goo00<007ooOol0:Woo00<007oo
Ool0`Goo00<007ooOol037oo000COol00`00Oomoo`0:Ool00`00Oomoo`0ZOol00`00Oomoo`31Ool0
0`00Oomoo`0<Ool001=oo`03001oogoo00Yoo`03001oogoo02Uoo`03001oogoo0<=oo`03001oogoo
00]oo`0057oo00<007ooOol02Goo00<007ooOol0:Goo00<007ooOol0`goo00<007ooOol02goo000E
Ool00`00Oomoo`08Ool00`00Oomoo`0XOol00`00Oomoo`34Ool00`00Oomoo`0;Ool001Ioo`03001o
ogoo00Moo`03001oogoo02Moo`03001oogoo0<Eoo`03001oogoo00]oo`005goo00<007ooOol01Woo
00<007ooOol09Woo00<007ooOol0aWoo00<007ooOol02goo000GOol00`00Oomoo`06Ool00`00Oomo
o`0UOol00`00Oomoo`37Ool00`00Oomoo`0;Ool001Qoo`03001oogoo00Eoo`03001oogoo02Aoo`03
001oogoo0<Qoo`03001oogoo00]oo`006Goo0P001Goo00<007ooOol08goo00<007ooOol0bGoo00<0
07ooOol02goo000KOol00`00Oomoo`02Ool00`00Oomoo`0QOol2003<Ool00`00Oomoo`0;Ool001ao
o`80009oo`03001oogoo021oo`03001oogoo0<aoo`03001oogoo00]oo`007Woo0`0087oo0P00cgoo
00<007ooOol02goo000POol00`00Oomoo`0LOol2003AOol00`00Oomoo`0;Ool0021oo`<001]oo`03
001oogoo0=5oo`03001oogoo00]oo`0087oo00<007ooOol00`0057oo1000e7oo00<007ooOol02goo
000POol00`00Oomoo`03Ool4000=Ool3003HOol00`00Oomoo`0;Ool0021oo`03001oogoo00Moo`d0
0=]oo`03001oogoo00]oo`0087oo00<007ooOol0kgoo00<007ooOol02goo000POol00`00Oomoo`3_
Ool00`00Oomoo`0;Ool0021oo`03001oogoo0>moo`03001oogoo00]oo`0087oo00<007ooOol0kWoo
00<007ooOol037oo000POol00`00Oomoo`3^Ool00`00Oomoo`0<Ool0021oo`03001oogoo0>ioo`03
001oogoo00aoo`0087oo00<007ooOol0kWoo00<007ooOol037oo000POol00`00Oomoo`3^Ool00`00
Oomoo`0<Ool0025oo`03001oogoo0>eoo`03001oogoo00aoo`008Goo00<007ooOol0kGoo00<007oo
Ool037oo000QOol00`00Oomoo`3]Ool00`00Oomoo`0<Ool0025oo`03001oogoo0>eoo`03001oogoo
00aoo`008Goo00<007ooOol0k7oo00<007ooOol03Goo000QOol00`00Oomoo`3/Ool00`00Oomoo`0=
Ool0025oo`03001oogoo0>aoo`03001oogoo00eoo`008Woo00<007ooOol0jgoo00<007ooOol03Goo
000ROol00`00Oomoo`3[Ool00`00Oomoo`0=Ool0029oo`03001oogoo0>]oo`03001oogoo00eoo`00
8Woo00<007ooOol0jgoo00<007ooOol03Goo000ROol00`00Oomoo`3ZOol00`00Oomoo`0>Ool0029o
o`03001oogoo0>Yoo`03001oogoo00ioo`008goo00<007ooOol0jGoo00<007ooOol03Woo000SOol0
0`00Oomoo`3YOol00`00Oomoo`0>Ool002=oo`03001oogoo0>Qoo`03001oogoo00moo`008goo00<0
07ooOol0j7oo00<007ooOol03goo000SOol00`00Oomoo`3XOol00`00Oomoo`0?Ool002Aoo`03001o
ogoo0>Moo`03001oogoo00moo`0097oo00<007ooOol0igoo00<007ooOol03goo000TOol00`00Oomo
o`3VOol00`00Oomoo`0@Ool002Eoo`03001oogoo0>Eoo`03001oogoo011oo`009Goo00<007ooOol0
iGoo00<007ooOol047oo000UOol00`00Oomoo`3TOol00`00Oomoo`0AOol002Ioo`03001oogoo0>=o
o`03001oogoo015oo`009Woo00<007ooOol0hgoo00<007ooOol04Goo000VOol00`00Oomoo`3ROol0
0`00Oomoo`0BOol002Moo`03001oogoo0>5oo`03001oogoo019oo`009goo00<007ooOol0hGoo00<0
07ooOol04Woo000WOol00`00Oomoo`3QOol00`00Oomoo`0BOol002Qoo`03001oogoo0=moo`03001o
ogoo01=oo`00:7oo00<007ooOol0ggoo00<007ooOol04goo000XOol00`00Oomoo`3OOol00`00Oomo
o`0COol002Qoo`03001oogoo0=ioo`03001oogoo01Aoo`00:7oo00<007ooOol0gWoo00<007ooOol0
57oo000YOol00`00Oomoo`3LOol00`00Oomoo`0EOol002Uoo`03001oogoo0=aoo`03001oogoo01Eo
o`00:Goo00<007ooOol0g7oo00<007ooOol05Goo000ZOol00`00Oomoo`3JOol00`00Oomoo`0FOol0
02Yoo`03001oogoo0=Yoo`03001oogoo01Ioo`00:goo00<007ooOol0fGoo00<007ooOol05Woo000/
Ool00`00Oomoo`3GOol00`00Oomoo`0GOol002aoo`03001oogoo0=Moo`03001oogoo01Moo`00;Goo
00<007ooOol0eGoo00<007ooOol067oo000]Ool00`00Oomoo`3DOol00`00Oomoo`0IOol002eoo`03
001oogoo0=Aoo`03001oogoo01Uoo`00;Woo00<007ooOol0dWoo00<007ooOol06Woo000^Ool00`00
Oomoo`3BOol00`00Oomoo`0JOol002moo`03001oogoo0=5oo`03001oogoo01Yoo`00;goo00<007oo
Ool0d7oo00<007ooOol06goo000`Ool00`00Oomoo`3?Ool00`00Oomoo`0KOol0031oo`03001oogoo
0<ioo`03001oogoo01aoo`00<Goo00<007ooOol0cGoo00<007ooOol077oo000aOol00`00Oomoo`3<
Ool00`00Oomoo`0MOol0039oo`03001oogoo0<Yoo`03001oogoo01ioo`00<Woo00<007ooOol0bWoo
00<007ooOol07Woo000cOol00`00Oomoo`38Ool00`00Oomoo`0OOol003Aoo`03001oogoo0<Moo`03
001oogoo01moo`00=Goo00<007ooOol0aGoo00<007ooOol087oo000eOol00`00Oomoo`34Ool00`00
Oomoo`0QOol003Ioo`03001oogoo0<=oo`03001oogoo025oo`00=Woo00<007ooOol0`Woo00<007oo
Ool08Woo000gOol00`00Oomoo`30Ool00`00Oomoo`0SOol003Moo`03001oogoo0<1oo`03001oogoo
02=oo`00>7oo00<007ooOol0_Woo00<007ooOol097oo000iOol00`00Oomoo`2lOol00`00Oomoo`0U
Ool003Yoo`03001oogoo0;Yoo`03001oogoo02Ioo`00>goo00<007ooOol0^7oo00<007ooOol09goo
000kOol00`00Oomoo`2hOol00`00Oomoo`0WOol003aoo`03001oogoo0;Ioo`03001oogoo02Qoo`00
?Goo00<007ooOol0]7oo00<007ooOol0:Goo000nOol00`00Oomoo`2bOol00`00Oomoo`0ZOol003mo
o`03001oogoo0;1oo`03001oogoo02]oo`00?goo00<007ooOol0/7oo00<007ooOol0:goo0010Ool0
0`00Oomoo`2^Ool00`00Oomoo`0/Ool0045oo`03001oogoo0:aoo`03001oogoo02eoo`00@Woo00<0
07ooOol0ZWoo00<007ooOol0;Woo0013Ool00`00Oomoo`2XOol00`00Oomoo`0_Ool004Aoo`03001o
ogoo0:Ioo`03001oogoo031oo`00AGoo00<007ooOol0Y7oo00<007ooOol0<Goo0015Ool00`00Oomo
o`2TOol00`00Oomoo`0aOol004Ioo`03001oogoo0:9oo`03001oogoo039oo`00Agoo0P00XGoo00<0
07ooOol0<goo0019Ool00`00Oomoo`2MOol00`00Oomoo`0dOol004Yoo`03001oogoo09]oo`03001o
ogoo03Eoo`00Bgoo00<007ooOol0VGoo00<007ooOol0=Woo001<Ool00`00Oomoo`2FOol2000iOol0
04eoo`03001oogoo09Aoo`03001oogoo03Uoo`00CWoo0P00Tgoo00<007ooOol0>Woo001@Ool00`00
Oomoo`2?Ool00`00Oomoo`0kOol0055oo`03001oogoo08aoo`8003ioo`00DWoo00<007ooOol0RWoo
00<007ooOol0?Woo001COol20029Ool00`00Oomoo`0oOol005Eoo`03001oogoo08Eoo`03001oogoo
041oo`00EWoo00<007ooOol0PWoo0P00@goo001GOol20020Ool20015Ool005Uoo`8007eoo`03001o
ogoo04Eoo`00Fgoo00<007ooOol0N7oo0P00B7oo001LOol00`00Oomoo`1fOol00`00Oomoo`18Ool0
05eoo`8007Eoo`03001oogoo04Uoo`00Ggoo0P00LGoo0P00C7oo001QOol2001]Ool2001>Ool006=o
o`03001oogoo06Qoo`80051oo`00I7oo0P00IWoo0P00DWoo001VOol3001POol3001DOol006Uoo`<0
05]oo`8005Moo`00K7oo0P00Egoo0P00FGoo001^Ool00`00Oomoo`1BOol2001KOol006moo`80051o
o`8005eoo`00LGoo0`00BWoo0`00Ggoo001dOol30014Ool3001ROol007Moo`H003Uoo`D006Eoo`00
OGoo0`00<goo0`00JWoo0020Ool3000]Ool3001]Ool008=oo`H0025oo`H0071oo`00RGoo3`000goo
3`00MWoo002HOol30025Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008eoo`@0
08moo`00SGoo00<007ooOol0T7oo002>Ool00`00Oomoo`2?Ool008moo`03001oogoo08ioo`00SGoo
00@007ooOol008moo`00SWoo0P00T7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-215.264, -178.502, 1.40481, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.509771 0.00274365 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(3)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.46642 0.47619 scale
1.09294 1.05 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.10268 .39535 m
.10278 .39522 L
.10292 .39503 L
.1031 .39476 L
.1033 .39442 L
.1035 .39398 L
.1037 .39344 L
.10389 .39282 L
.10408 .39214 L
.10428 .39138 L
.10452 .39053 L
.10479 .38961 L
.10511 .38868 L
.10541 .38771 L
.10567 .38674 L
.10595 .38582 L
.10622 .38496 L
.10651 .3841 L
.1068 .38322 L
.10712 .38231 L
.10743 .38135 L
.1077 .38041 L
.10792 .37941 L
.10806 .37835 L
.10812 .37722 L
.10808 .37612 L
.10799 .3749 L
.1079 .3737 L
.10782 .37248 L
.10775 .37117 L
.10771 .36984 L
.10769 .36862 L
.10769 .36741 L
.10768 .36629 L
.10769 .36529 L
.10771 .36442 L
.10777 .36366 L
.10788 .363 L
.10802 .3624 L
.10818 .36179 L
.10837 .36113 L
.10855 .36037 L
.10872 .35951 L
.1089 .3585 L
.10912 .35732 L
.10942 .35621 L
.10979 .35488 L
.11024 .35349 L
.11076 .35185 L
.11134 .35031 L
Mistroke
.11193 .34854 L
.11251 .34661 L
.11308 .3448 L
.11361 .34293 L
.11412 .3411 L
.11463 .33931 L
.11515 .33785 L
.11568 .33638 L
.1162 .33506 L
.11667 .33394 L
.11707 .3329 L
.1174 .33207 L
.11765 .3314 L
.11785 .33089 L
.11803 .33055 L
.11822 .3304 L
.11841 .33039 L
.11859 .3305 L
.11872 .33068 L
.11879 .33086 L
.11879 .33098 L
.11872 .33099 L
.11858 .33085 L
.1184 .33056 L
.11818 .3301 L
.11795 .3295 L
.1177 .32876 L
.11744 .32793 L
.11718 .3271 L
.11693 .32618 L
.11668 .32521 L
.11645 .32421 L
.11625 .32335 L
.11609 .32258 L
.11596 .32197 L
.11587 .32156 L
.11581 .32142 L
.11579 .32155 L
.1158 .32191 L
.11584 .32242 L
.11589 .32301 L
.11596 .3236 L
.11607 .32412 L
.11624 .32454 L
.11646 .32484 L
.11673 .32496 L
.11706 .3249 L
.11743 .32466 L
.11786 .32423 L
.11834 .32364 L
Mistroke
.11886 .32294 L
.11942 .32212 L
.11996 .3212 L
.12047 .32026 L
.12096 .3194 L
.12143 .31868 L
.12187 .31807 L
.12228 .31754 L
.12267 .31708 L
.12306 .31666 L
.12346 .31625 L
.1239 .31581 L
.12436 .3153 L
.12487 .31468 L
.12539 .31393 L
.12597 .31302 L
.12659 .31191 L
.12724 .31073 L
.12785 .30929 L
.12846 .30767 L
.12906 .30609 L
.12962 .30436 L
.1301 .30262 L
.1305 .30089 L
.1308 .29934 L
.13103 .29788 L
.13118 .29659 L
.13126 .29553 L
.13128 .29464 L
.13126 .29388 L
.13122 .29328 L
.13116 .29282 L
.1311 .29252 L
.13104 .29236 L
.13098 .29233 L
.13092 .29241 L
.13087 .29257 L
.13082 .29275 L
.1308 .29292 L
.1308 .29304 L
.13086 .2931 L
.13102 .29307 L
.1313 .29294 L
.13173 .29268 L
.13231 .29229 L
.13302 .29178 L
.13389 .29112 L
.13493 .29033 L
.13602 .28943 L
.13724 .28847 L
Mistroke
.13842 .28743 L
.13964 .28636 L
.14086 .28532 L
.14191 .28444 L
.14293 .28368 L
.14388 .28305 L
.14469 .28255 L
.14537 .28215 L
.14593 .28182 L
.14638 .28149 L
.14674 .28114 L
.14705 .28071 L
.14732 .28019 L
.14762 .27956 L
.14796 .27882 L
.14834 .27794 L
.14876 .27705 L
.14922 .27607 L
.14969 .27505 L
.15017 .27401 L
.15065 .27304 L
.15112 .27214 L
.15156 .27135 L
.15197 .27075 L
.15233 .27031 L
.15264 .26998 L
.15288 .26973 L
.15306 .2695 L
.15318 .26922 L
.15327 .26883 L
.15334 .26829 L
.15343 .26761 L
.15355 .2668 L
.1537 .26592 L
.15387 .26513 L
.15406 .26407 L
.15428 .26307 L
.15449 .26199 L
.15468 .26083 L
.15485 .25958 L
.15498 .25835 L
.15509 .25707 L
.15521 .25573 L
.15533 .25434 L
.15549 .25308 L
.15565 .25161 L
.15585 .25012 L
.1561 .24856 L
.1564 .24694 L
.1568 .24518 L
Mistroke
.1573 .24367 L
.1579 .24217 L
.15863 .24071 L
.15939 .23935 L
.16022 .23811 L
.1611 .23692 L
.162 .23575 L
.16284 .23462 L
.16373 .23346 L
.1646 .23233 L
.16555 .23124 L
.16648 .23012 L
.1675 .22897 L
.16863 .2278 L
.16978 .22663 L
.17099 .22539 L
.17224 .22417 L
.17336 .22293 L
.17445 .22171 L
.1755 .22053 L
.17647 .21954 L
.1774 .21854 L
.17818 .21763 L
.17885 .21692 L
.17939 .2163 L
.17979 .21577 L
.18006 .21532 L
.18018 .21493 L
.18019 .21458 L
.18014 .21426 L
.18006 .21391 L
.18 .21351 L
.17996 .213 L
.17994 .21242 L
.17994 .21185 L
.17992 .21139 L
.17987 .21101 L
.17977 .21078 L
.17962 .21077 L
.17944 .21098 L
.17921 .21144 L
.17894 .21211 L
.17865 .21296 L
.17837 .21384 L
.17809 .21496 L
.17783 .21598 L
.17761 .217 L
.17745 .21793 L
.17739 .21869 L
.17744 .21926 L
Mistroke
.17764 .21961 L
.17797 .21977 L
.17844 .2198 L
.17902 .21974 L
.1797 .21964 L
.18047 .21953 L
.18126 .21946 L
.18198 .21944 L
.18263 .21945 L
.18318 .21947 L
.18357 .21947 L
.18381 .21948 L
.18386 .21947 L
.18377 .21944 L
.18359 .21938 L
.18333 .21929 L
.18295 .21918 L
.18248 .21906 L
.18191 .21897 L
.18123 .21895 L
.18047 .21902 L
.17964 .21921 L
.17876 .21956 L
.17783 .22009 L
.17683 .2208 L
.17578 .22174 L
.1748 .22285 L
.17374 .22418 L
.17252 .22572 L
.171 .22738 L
.16963 .22902 L
.1682 .23076 L
.16671 .23258 L
.16531 .23433 L
.16389 .23593 L
.16249 .23751 L
.16122 .23906 L
.16005 .24047 L
.15887 .24189 L
.15765 .24335 L
.15644 .24489 L
.15529 .24641 L
.15422 .24804 L
.15316 .24983 L
.15214 .25177 L
.15121 .25363 L
.15032 .25572 L
.14949 .25774 L
.1487 .25981 L
.148 .26173 L
Mistroke
.14742 .2634 L
.14695 .2649 L
.14661 .2662 L
.14635 .26717 L
.14615 .26794 L
.14598 .26855 L
.1458 .26902 L
.14559 .26938 L
.14529 .26971 L
.14489 .27006 L
.1444 .27042 L
.14382 .27082 L
.14318 .27127 L
.14255 .27178 L
.14176 .27246 L
.141 .27321 L
.14015 .27409 L
.13925 .27509 L
.13834 .27618 L
.13744 .27735 L
.13659 .27861 L
.13583 .27984 L
.13507 .28115 L
.13434 .2825 L
.13363 .28389 L
.13295 .28523 L
.13225 .28668 L
.13161 .28825 L
.13111 .28981 L
.13073 .29131 L
.13041 .29276 L
.13011 .2942 L
.12981 .29539 L
.12946 .29664 L
.12899 .29777 L
.12838 .29899 L
.12772 .30028 L
.12687 .30152 L
.12589 .3028 L
.12483 .3041 L
.12383 .30542 L
.12275 .30675 L
.12159 .30799 L
.12035 .30926 L
.11913 .31056 L
.11806 .31194 L
.11711 .31324 L
.11629 .3146 L
.11561 .31601 L
.11505 .31745 L
Mistroke
.1146 .31882 L
.11424 .32016 L
.11397 .32153 L
.11375 .32297 L
.11359 .32443 L
.11345 .32594 L
.11331 .32751 L
.11316 .32907 L
.11298 .33049 L
.11278 .33178 L
.1126 .33292 L
.11242 .33392 L
.11223 .3348 L
.112 .33553 L
.11173 .33618 L
.11144 .33676 L
.11115 .3373 L
.11087 .33784 L
.1106 .33842 L
.11034 .33908 L
.11009 .33988 L
.10984 .34087 L
.10957 .34199 L
.10926 .34328 L
.10889 .34479 L
.10846 .34661 L
.10799 .34849 L
.10753 .35058 L
.10709 .35285 L
.1067 .35486 L
.10633 .35718 L
.10598 .35927 L
.10565 .36153 L
.10532 .36398 L
.10499 .36645 L
.10467 .36865 L
.10436 .37091 L
.10409 .37331 L
.10386 .37576 L
.10368 .37783 L
.10352 .38005 L
.10336 .38216 L
.1032 .38421 L
.10306 .38618 L
.10294 .38791 L
.1028 .38949 L
.10274 .39082 L
.1027 .39195 L
.1027 .39287 L
.10272 .3936 L
Mistroke
.10275 .39418 L
.10276 .39463 L
.10277 .39502 L
.10276 .39544 L
.10276 .39591 L
.10275 .39647 L
.10274 .39715 L
.10272 .39796 L
.10271 .3988 L
.10269 .39975 L
.10267 .40078 L
.10266 .40187 L
.10264 .40297 L
.10262 .40391 L
.10261 .40479 L
.1026 .40556 L
.10259 .4062 L
.10258 .40668 L
.10257 .40697 L
Mfstroke
.1026 .40668 m
.10261 .40651 L
.10261 .40629 L
.10259 .40601 L
.10256 .40564 L
.10252 .40537 L
.10251 .40494 L
.10252 .4045 L
.10257 .40399 L
.10266 .4033 L
.10281 .40262 L
.10302 .40208 L
.10327 .40132 L
.10354 .40059 L
.1038 .39979 L
.10405 .39891 L
.10429 .39786 L
.10454 .39697 L
.10479 .39605 L
.10504 .39498 L
.10524 .39377 L
.10538 .39255 L
.10546 .39156 L
.10549 .39047 L
.1055 .38935 L
.10548 .38838 L
.10545 .38742 L
.10544 .38652 L
.10545 .38576 L
.10546 .38514 L
.10547 .38461 L
.10547 .38416 L
.10547 .38381 L
.10548 .38357 L
.10548 .38344 L
.10548 .38337 L
.10548 .38336 L
.10548 .38339 L
.10548 .38345 L
.10548 .38353 L
.10548 .3836 L
.10548 .38362 L
.10547 .38363 L
.10547 .38363 L
.10547 .38364 L
.10547 .38368 L
.10547 .38375 L
.10547 .38382 L
.10544 .38385 L
.1054 .38382 L
Mistroke
.10537 .38373 L
.10536 .38356 L
.10538 .38329 L
.10544 .38293 L
.10554 .3825 L
.1057 .38204 L
.10591 .38156 L
.10617 .38107 L
.10647 .3806 L
.1068 .38012 L
.10708 .37965 L
.10733 .37925 L
.10757 .37895 L
.1078 .37881 L
.10796 .37885 L
.10801 .37906 L
.10791 .3794 L
.10771 .37983 L
.10746 .38034 L
.10717 .38086 L
.10686 .38125 L
.10656 .38152 L
.10628 .38185 L
.10603 .38224 L
.10583 .38265 L
.10567 .38306 L
.10555 .38344 L
.10548 .38383 L
.10542 .38435 L
.10533 .38507 L
.10518 .38601 L
.105 .38715 L
.10474 .38843 L
.10451 .38971 L
.10422 .39142 L
.10395 .39365 L
.1037 .39534 L
.10343 .3977 L
.10316 .3996 L
.1029 .40164 L
.1027 .40381 L
.10257 .40532 L
.10249 .40693 L
.10245 .40844 L
.10243 .40944 L
.10245 .41026 L
.10247 .41091 L
.10249 .41137 L
.10249 .41164 L
Mfstroke
1 .997 0 r
.008 w
.13189 .46895 Mdot
.016 w
.13189 .46895 m
.13207 .46905 L
s
1 .994 0 r
.008 w
.13207 .46905 Mdot
.016 w
.13207 .46905 m
.1323 .46919 L
s
1 .992 0 r
.008 w
.1323 .46919 Mdot
.016 w
.1323 .46919 m
.13257 .46936 L
s
1 .989 0 r
.008 w
.13257 .46936 Mdot
.016 w
.13257 .46936 m
.1329 .46956 L
s
1 .986 0 r
.008 w
.1329 .46956 Mdot
.016 w
.1329 .46956 m
.13327 .4698 L
s
1 .983 0 r
.008 w
.13327 .4698 Mdot
.016 w
.13327 .4698 m
.13368 .47009 L
s
1 .981 0 r
.008 w
.13368 .47009 Mdot
.016 w
.13368 .47009 m
.13419 .4705 L
s
1 .978 0 r
.008 w
.13419 .4705 Mdot
.016 w
.13419 .4705 m
.1347 .47097 L
s
1 .975 0 r
.008 w
.1347 .47097 Mdot
.016 w
.1347 .47097 m
.13527 .47155 L
s
1 .972 0 r
.008 w
.13527 .47155 Mdot
.016 w
.13527 .47155 m
.13591 .47227 L
s
1 .969 0 r
.008 w
.13591 .47227 Mdot
.016 w
.13591 .47227 m
.13657 .47305 L
s
1 .967 0 r
.008 w
.13657 .47305 Mdot
.016 w
.13657 .47305 m
.13719 .47379 L
s
1 .964 0 r
.008 w
.13719 .47379 Mdot
.016 w
.13719 .47379 m
.13783 .47464 L
s
1 .961 0 r
.008 w
.13783 .47464 Mdot
.016 w
.13783 .47464 m
.13842 .47549 L
s
1 .958 0 r
.008 w
.13842 .47549 Mdot
.016 w
.13842 .47549 m
.13899 .47634 L
s
1 .955 0 r
.008 w
.13899 .47634 Mdot
.016 w
.13899 .47634 m
.13952 .47716 L
s
1 .953 0 r
.008 w
.13952 .47716 Mdot
.016 w
.13952 .47716 m
.14002 .47794 L
s
1 .95 0 r
.008 w
.14002 .47794 Mdot
.016 w
.14002 .47794 m
.14048 .47859 L
s
1 .947 0 r
.008 w
.14048 .47859 Mdot
.016 w
.14048 .47859 m
.14091 .47917 L
s
1 .944 0 r
.008 w
.14091 .47917 Mdot
.016 w
.14091 .47917 m
.14129 .47968 L
s
1 .942 0 r
.008 w
.14129 .47968 Mdot
.016 w
.14129 .47968 m
.14159 .48007 L
s
1 .939 0 r
.008 w
.14159 .48007 Mdot
.016 w
.14159 .48007 m
.14179 .48033 L
s
1 .936 0 r
.008 w
.14179 .48033 Mdot
.016 w
.14179 .48033 m
.14187 .48048 L
s
1 .933 0 r
.008 w
.14187 .48048 Mdot
.016 w
.14187 .48048 m
.14185 .48059 L
s
1 .93 0 r
.008 w
.14185 .48059 Mdot
.016 w
.14185 .48059 m
.14178 .48075 L
s
1 .928 0 r
.008 w
.14178 .48075 Mdot
.016 w
.14178 .48075 m
.14167 .481 L
s
1 .925 0 r
.008 w
.14167 .481 Mdot
.016 w
.14167 .481 m
.14158 .48133 L
s
1 .922 0 r
.008 w
.14158 .48133 Mdot
.016 w
.14158 .48133 m
.14153 .48176 L
s
1 .919 0 r
.008 w
.14153 .48176 Mdot
.016 w
.14153 .48176 m
.14157 .48229 L
s
1 .916 0 r
.008 w
.14157 .48229 Mdot
.016 w
.14157 .48229 m
.14173 .48291 L
s
1 .914 0 r
.008 w
.14173 .48291 Mdot
.016 w
.14173 .48291 m
.14203 .48357 L
s
1 .911 0 r
.008 w
.14203 .48357 Mdot
.016 w
.14203 .48357 m
.14247 .48426 L
s
1 .908 0 r
.008 w
.14247 .48426 Mdot
.016 w
.14247 .48426 m
.14303 .48494 L
s
1 .905 0 r
.008 w
.14303 .48494 Mdot
.016 w
.14303 .48494 m
.14368 .48559 L
s
1 .903 0 r
.008 w
.14368 .48559 Mdot
.016 w
.14368 .48559 m
.14439 .48617 L
s
1 .9 0 r
.008 w
.14439 .48617 Mdot
.016 w
.14439 .48617 m
.14505 .48666 L
s
1 .897 0 r
.008 w
.14505 .48666 Mdot
.016 w
.14505 .48666 m
.14572 .48705 L
s
1 .894 0 r
.008 w
.14572 .48705 Mdot
.016 w
.14572 .48705 m
.14641 .4873 L
s
1 .891 0 r
.008 w
.14641 .4873 Mdot
.016 w
.14641 .4873 m
.14711 .48744 L
s
1 .889 0 r
.008 w
.14711 .48744 Mdot
.016 w
.14711 .48744 m
.14774 .48749 L
s
1 .886 0 r
.008 w
.14774 .48749 Mdot
.016 w
.14774 .48749 m
.14831 .48749 L
s
1 .883 0 r
.008 w
.14831 .48749 Mdot
.016 w
.14831 .48749 m
.14881 .4875 L
s
1 .88 0 r
.008 w
.14881 .4875 Mdot
.016 w
.14881 .4875 m
.14923 .48757 L
s
1 .877 0 r
.008 w
.14923 .48757 Mdot
.016 w
.14923 .48757 m
.14957 .48774 L
s
1 .875 0 r
.008 w
.14957 .48774 Mdot
.016 w
.14957 .48774 m
.14985 .48801 L
s
1 .872 0 r
.008 w
.14985 .48801 Mdot
.016 w
.14985 .48801 m
.1501 .48838 L
s
1 .869 0 r
.008 w
.1501 .48838 Mdot
.016 w
.1501 .48838 m
.15033 .48876 L
s
1 .866 0 r
.008 w
.15033 .48876 Mdot
.016 w
.15033 .48876 m
.15056 .48918 L
s
1 .864 0 r
.008 w
.15056 .48918 Mdot
.016 w
.15056 .48918 m
.15078 .48962 L
s
1 .861 0 r
.008 w
.15078 .48962 Mdot
.016 w
.15078 .48962 m
.15097 .49002 L
s
1 .858 0 r
.008 w
.15097 .49002 Mdot
.016 w
.15097 .49002 m
.15113 .49043 L
s
1 .855 0 r
.008 w
.15113 .49043 Mdot
.016 w
.15113 .49043 m
.15124 .49081 L
s
1 .852 0 r
.008 w
.15124 .49081 Mdot
.016 w
.15124 .49081 m
.15128 .49115 L
s
1 .85 0 r
.008 w
.15128 .49115 Mdot
.016 w
.15128 .49115 m
.15123 .49143 L
s
1 .847 0 r
.008 w
.15123 .49143 Mdot
.016 w
.15123 .49143 m
.1511 .4916 L
s
1 .844 0 r
.008 w
.1511 .4916 Mdot
.016 w
.1511 .4916 m
.1509 .49166 L
s
1 .841 0 r
.008 w
.1509 .49166 Mdot
.016 w
.1509 .49166 m
.15062 .49165 L
s
1 .838 0 r
.008 w
.15062 .49165 Mdot
.016 w
.15062 .49165 m
.15031 .49159 L
s
1 .836 0 r
.008 w
.15031 .49159 Mdot
.016 w
.15031 .49159 m
.14999 .49151 L
s
1 .833 0 r
.008 w
.14999 .49151 Mdot
.016 w
.14999 .49151 m
.14968 .49147 L
s
1 .83 0 r
.008 w
.14968 .49147 Mdot
.016 w
.14968 .49147 m
.14941 .49156 L
s
1 .827 0 r
.008 w
.14941 .49156 Mdot
.016 w
.14941 .49156 m
.14921 .49184 L
s
1 .825 0 r
.008 w
.14921 .49184 Mdot
.016 w
.14921 .49184 m
.14909 .49233 L
s
1 .822 0 r
.008 w
.14909 .49233 Mdot
.016 w
.14909 .49233 m
.14906 .493 L
s
1 .819 0 r
.008 w
.14906 .493 Mdot
.016 w
.14906 .493 m
.14911 .49384 L
s
1 .816 0 r
.008 w
.14911 .49384 Mdot
.016 w
.14911 .49384 m
.14923 .49482 L
s
1 .813 0 r
.008 w
.14923 .49482 Mdot
.016 w
.14923 .49482 m
.14941 .49591 L
s
1 .811 0 r
.008 w
.14941 .49591 Mdot
.016 w
.14941 .49591 m
.14964 .49689 L
s
1 .808 0 r
.008 w
.14964 .49689 Mdot
.016 w
.14964 .49689 m
.14987 .49792 L
s
1 .805 0 r
.008 w
.14987 .49792 Mdot
.016 w
.14987 .49792 m
.15008 .49894 L
s
1 .802 0 r
.008 w
.15008 .49894 Mdot
.016 w
.15008 .49894 m
.15028 .49994 L
s
1 .799 0 r
.008 w
.15028 .49994 Mdot
.016 w
.15028 .49994 m
.15044 .5009 L
s
1 .797 0 r
.008 w
.15044 .5009 Mdot
.016 w
.15044 .5009 m
.15061 .5016 L
s
1 .794 0 r
.008 w
.15061 .5016 Mdot
.016 w
.15061 .5016 m
.15077 .50228 L
s
1 .791 0 r
.008 w
.15077 .50228 Mdot
.016 w
.15077 .50228 m
.15091 .50283 L
s
1 .788 0 r
.008 w
.15091 .50283 Mdot
.016 w
.15091 .50283 m
.15104 .50328 L
s
1 .786 0 r
.008 w
.15104 .50328 Mdot
.016 w
.15104 .50328 m
.15117 .50371 L
s
1 .783 0 r
.008 w
.15117 .50371 Mdot
.016 w
.15117 .50371 m
.15132 .50418 L
s
1 .78 0 r
.008 w
.15132 .50418 Mdot
.016 w
.15132 .50418 m
.15153 .50479 L
s
1 .777 0 r
.008 w
.15153 .50479 Mdot
.016 w
.15153 .50479 m
.15181 .50558 L
s
1 .774 0 r
.008 w
.15181 .50558 Mdot
.016 w
.15181 .50558 m
.15218 .50658 L
s
1 .772 0 r
.008 w
.15218 .50658 Mdot
.016 w
.15218 .50658 m
.15263 .50763 L
s
1 .769 0 r
.008 w
.15263 .50763 Mdot
.016 w
.15263 .50763 m
.15316 .50887 L
s
1 .766 0 r
.008 w
.15316 .50887 Mdot
.016 w
.15316 .50887 m
.15375 .51027 L
s
1 .763 0 r
.008 w
.15375 .51027 Mdot
.016 w
.15375 .51027 m
.15439 .51183 L
s
1 .76 0 r
.008 w
.15439 .51183 Mdot
.016 w
.15439 .51183 m
.15502 .51333 L
s
1 .758 0 r
.008 w
.15502 .51333 Mdot
.016 w
.15502 .51333 m
.15556 .5147 L
s
1 .755 0 r
.008 w
.15556 .5147 Mdot
.016 w
.15556 .5147 m
.15609 .51605 L
s
1 .752 0 r
.008 w
.15609 .51605 Mdot
.016 w
.15609 .51605 m
.15654 .51713 L
s
1 .749 0 r
.008 w
.15654 .51713 Mdot
.016 w
.15654 .51713 m
.15698 .51809 L
s
1 .747 0 r
.008 w
.15698 .51809 Mdot
.016 w
.15698 .51809 m
.15741 .51889 L
s
1 .744 0 r
.008 w
.15741 .51889 Mdot
.016 w
.15741 .51889 m
.15784 .51951 L
s
1 .741 0 r
.008 w
.15784 .51951 Mdot
.016 w
.15784 .51951 m
.15826 .51995 L
s
1 .738 0 r
.008 w
.15826 .51995 Mdot
.016 w
.15826 .51995 m
.15871 .52025 L
s
1 .735 0 r
.008 w
.15871 .52025 Mdot
.016 w
.15871 .52025 m
.15917 .52047 L
s
1 .733 0 r
.008 w
.15917 .52047 Mdot
.016 w
.15917 .52047 m
.15964 .52062 L
s
1 .73 0 r
.008 w
.15964 .52062 Mdot
.016 w
.15964 .52062 m
.1601 .52074 L
s
1 .727 0 r
.008 w
.1601 .52074 Mdot
.016 w
.1601 .52074 m
.16054 .52085 L
s
1 .724 0 r
.008 w
.16054 .52085 Mdot
.016 w
.16054 .52085 m
.16098 .52097 L
s
1 .721 0 r
.008 w
.16098 .52097 Mdot
.016 w
.16098 .52097 m
.16144 .52116 L
s
1 .719 0 r
.008 w
.16144 .52116 Mdot
.016 w
.16144 .52116 m
.16194 .52138 L
s
1 .716 0 r
.008 w
.16194 .52138 Mdot
.016 w
.16194 .52138 m
.16243 .52161 L
s
1 .713 0 r
.008 w
.16243 .52161 Mdot
.016 w
.16243 .52161 m
.16285 .5218 L
s
1 .71 0 r
.008 w
.16285 .5218 Mdot
.016 w
.16285 .5218 m
.16316 .52193 L
s
1 .708 0 r
.008 w
.16316 .52193 Mdot
.016 w
.16316 .52193 m
.16332 .52197 L
s
1 .705 0 r
.008 w
.16332 .52197 Mdot
.016 w
.16332 .52197 m
.16335 .52189 L
s
1 .702 0 r
.008 w
.16335 .52189 Mdot
.016 w
.16335 .52189 m
.16324 .52168 L
s
1 .699 0 r
.008 w
.16324 .52168 Mdot
.016 w
.16324 .52168 m
.16304 .52137 L
s
1 .696 0 r
.008 w
.16304 .52137 Mdot
.016 w
.16304 .52137 m
.16275 .52101 L
s
1 .694 0 r
.008 w
.16275 .52101 Mdot
.016 w
.16275 .52101 m
.16243 .52065 L
s
1 .691 0 r
.008 w
.16243 .52065 Mdot
.016 w
.16243 .52065 m
.16209 .52031 L
s
1 .688 0 r
.008 w
.16209 .52031 Mdot
.016 w
.16209 .52031 m
.16176 .52006 L
s
1 .685 0 r
.008 w
.16176 .52006 Mdot
.016 w
.16176 .52006 m
.16145 .51994 L
s
1 .682 0 r
.008 w
.16145 .51994 Mdot
.016 w
.16145 .51994 m
.16116 .51998 L
s
1 .68 0 r
.008 w
.16116 .51998 Mdot
.016 w
.16116 .51998 m
.16092 .52025 L
s
1 .677 0 r
.008 w
.16092 .52025 Mdot
.016 w
.16092 .52025 m
.16076 .52081 L
s
1 .674 0 r
.008 w
.16076 .52081 Mdot
.016 w
.16076 .52081 m
.16067 .5217 L
s
1 .671 0 r
.008 w
.16067 .5217 Mdot
.016 w
.16067 .5217 m
.16066 .52293 L
s
1 .669 0 r
.008 w
.16066 .52293 Mdot
.016 w
.16066 .52293 m
.16073 .52439 L
s
1 .666 0 r
.008 w
.16073 .52439 Mdot
.016 w
.16073 .52439 m
.16084 .52607 L
s
1 .663 0 r
.008 w
.16084 .52607 Mdot
.016 w
.16084 .52607 m
.161 .52806 L
s
1 .66 0 r
.008 w
.161 .52806 Mdot
.016 w
.161 .52806 m
.16118 .53035 L
s
1 .657 0 r
.008 w
.16118 .53035 Mdot
.016 w
.16118 .53035 m
.16138 .53244 L
s
1 .655 0 r
.008 w
.16138 .53244 Mdot
.016 w
.16138 .53244 m
.1616 .5349 L
s
1 .652 0 r
.008 w
.1616 .5349 Mdot
.016 w
.1616 .5349 m
.16183 .53705 L
s
1 .649 0 r
.008 w
.16183 .53705 Mdot
.016 w
.16183 .53705 m
.16209 .53929 L
s
1 .646 0 r
.008 w
.16209 .53929 Mdot
.016 w
.16209 .53929 m
.16235 .54152 L
s
1 .643 0 r
.008 w
.16235 .54152 Mdot
.016 w
.16235 .54152 m
.16262 .5433 L
s
1 .641 0 r
.008 w
.16262 .5433 Mdot
.016 w
.16262 .5433 m
.16288 .54492 L
s
1 .638 0 r
.008 w
.16288 .54492 Mdot
.016 w
.16288 .54492 m
.16313 .54633 L
s
1 .635 0 r
.008 w
.16313 .54633 Mdot
.016 w
.16313 .54633 m
.16335 .54748 L
s
1 .632 0 r
.008 w
.16335 .54748 Mdot
.016 w
.16335 .54748 m
.16354 .54833 L
s
1 .63 0 r
.008 w
.16354 .54833 Mdot
.016 w
.16354 .54833 m
.16372 .54897 L
s
1 .627 0 r
.008 w
.16372 .54897 Mdot
.016 w
.16372 .54897 m
.1639 .54942 L
s
1 .624 0 r
.008 w
.1639 .54942 Mdot
.016 w
.1639 .54942 m
.16408 .54971 L
s
1 .621 0 r
.008 w
.16408 .54971 Mdot
.016 w
.16408 .54971 m
.16425 .5499 L
s
1 .618 0 r
.008 w
.16425 .5499 Mdot
.016 w
.16425 .5499 m
.16439 .55002 L
s
1 .616 0 r
.008 w
.16439 .55002 Mdot
.016 w
.16439 .55002 m
.16448 .55007 L
s
1 .613 0 r
.008 w
.16448 .55007 Mdot
.016 w
.16448 .55007 m
.1645 .55004 L
s
1 .61 0 r
.008 w
.1645 .55004 Mdot
.016 w
.1645 .55004 m
.16448 .54995 L
s
1 .607 0 r
.008 w
.16448 .54995 Mdot
.016 w
.16448 .54995 m
.16443 .54983 L
s
1 .604 0 r
.008 w
.16443 .54983 Mdot
.016 w
.16443 .54983 m
.16438 .5497 L
s
1 .602 0 r
.008 w
.16438 .5497 Mdot
.016 w
.16438 .5497 m
.16434 .54961 L
s
1 .599 0 r
.008 w
.16434 .54961 Mdot
.016 w
.16434 .54961 m
.16435 .54959 L
s
1 .596 0 r
.008 w
.16435 .54959 Mdot
.016 w
.16435 .54959 m
.1644 .54968 L
s
1 .593 0 r
.008 w
.1644 .54968 Mdot
.016 w
.1644 .54968 m
.16451 .54986 L
s
1 .591 0 r
.008 w
.16451 .54986 Mdot
.016 w
.16451 .54986 m
.1647 .55014 L
s
1 .588 0 r
.008 w
.1647 .55014 Mdot
.016 w
.1647 .55014 m
.165 .55052 L
s
1 .585 0 r
.008 w
.165 .55052 Mdot
.016 w
.165 .55052 m
.1654 .551 L
s
1 .582 0 r
.008 w
.1654 .551 Mdot
.016 w
.1654 .551 m
.1659 .55155 L
s
1 .579 0 r
.008 w
.1659 .55155 Mdot
.016 w
.1659 .55155 m
.16651 .55217 L
s
1 .577 0 r
.008 w
.16651 .55217 Mdot
.016 w
.16651 .55217 m
.16721 .55283 L
s
1 .574 0 r
.008 w
.16721 .55283 Mdot
.016 w
.16721 .55283 m
.16801 .55359 L
s
1 .571 0 r
.008 w
.16801 .55359 Mdot
.016 w
.16801 .55359 m
.16883 .55442 L
s
1 .568 0 r
.008 w
.16883 .55442 Mdot
.016 w
.16883 .55442 m
.16971 .55527 L
s
1 .565 0 r
.008 w
.16971 .55527 Mdot
.016 w
.16971 .55527 m
.17063 .55611 L
s
1 .563 0 r
.008 w
.17063 .55611 Mdot
.016 w
.17063 .55611 m
.17155 .5569 L
s
1 .56 0 r
.008 w
.17155 .5569 Mdot
.016 w
.17155 .5569 m
.17238 .55763 L
s
1 .557 0 r
.008 w
.17238 .55763 Mdot
.016 w
.17238 .55763 m
.17318 .55835 L
s
1 .554 0 r
.008 w
.17318 .55835 Mdot
.016 w
.17318 .55835 m
.17392 .55904 L
s
1 .552 0 r
.008 w
.17392 .55904 Mdot
.016 w
.17392 .55904 m
.17459 .55971 L
s
1 .549 0 r
.008 w
.17459 .55971 Mdot
.016 w
.17459 .55971 m
.17516 .56038 L
s
1 .546 0 r
.008 w
.17516 .56038 Mdot
.016 w
.17516 .56038 m
.17562 .56106 L
s
1 .543 0 r
.008 w
.17562 .56106 Mdot
.016 w
.17562 .56106 m
.17599 .56179 L
s
1 .54 0 r
.008 w
.17599 .56179 Mdot
.016 w
.17599 .56179 m
.17626 .56255 L
s
1 .538 0 r
.008 w
.17626 .56255 Mdot
.016 w
.17626 .56255 m
.17645 .5633 L
s
1 .535 0 r
.008 w
.17645 .5633 Mdot
.016 w
.17645 .5633 m
.17655 .56396 L
s
1 .532 0 r
.008 w
.17655 .56396 Mdot
.016 w
.17655 .56396 m
.17659 .56449 L
s
1 .529 0 r
.008 w
.17659 .56449 Mdot
.016 w
.17659 .56449 m
.17655 .56494 L
s
1 .526 0 r
.008 w
.17655 .56494 Mdot
.016 w
.17655 .56494 m
.17644 .56527 L
s
1 .524 0 r
.008 w
.17644 .56527 Mdot
.016 w
.17644 .56527 m
.17625 .56546 L
s
1 .521 0 r
.008 w
.17625 .56546 Mdot
.016 w
.17625 .56546 m
.17598 .56548 L
s
1 .518 0 r
.008 w
.17598 .56548 Mdot
.016 w
.17598 .56548 m
.17564 .56534 L
s
1 .515 0 r
.008 w
.17564 .56534 Mdot
.016 w
.17564 .56534 m
.17529 .56505 L
s
1 .513 0 r
.008 w
.17529 .56505 Mdot
.016 w
.17529 .56505 m
.17495 .56465 L
s
1 .51 0 r
.008 w
.17495 .56465 Mdot
.016 w
.17495 .56465 m
.17466 .56418 L
s
1 .507 0 r
.008 w
.17466 .56418 Mdot
.016 w
.17466 .56418 m
.17442 .56367 L
s
1 .504 0 r
.008 w
.17442 .56367 Mdot
.016 w
.17442 .56367 m
.17427 .56312 L
s
1 .501 0 r
.008 w
.17427 .56312 Mdot
.016 w
.17427 .56312 m
.17427 .56258 L
s
1 .499 0 r
.008 w
.17427 .56258 Mdot
.016 w
.17427 .56258 m
.17447 .56211 L
s
1 .496 0 r
.008 w
.17447 .56211 Mdot
.016 w
.17447 .56211 m
.17488 .56175 L
s
1 .493 0 r
.008 w
.17488 .56175 Mdot
.016 w
.17488 .56175 m
.17553 .56149 L
s
1 .49 0 r
.008 w
.17553 .56149 Mdot
.016 w
.17553 .56149 m
.17637 .56133 L
s
1 .487 0 r
.008 w
.17637 .56133 Mdot
.016 w
.17637 .56133 m
.17747 .56124 L
s
1 .485 0 r
.008 w
.17747 .56124 Mdot
.016 w
.17747 .56124 m
.17874 .56121 L
s
1 .482 0 r
.008 w
.17874 .56121 Mdot
.016 w
.17874 .56121 m
.18023 .56121 L
s
1 .479 0 r
.008 w
.18023 .56121 Mdot
.016 w
.18023 .56121 m
.18175 .56122 L
s
1 .476 0 r
.008 w
.18175 .56122 Mdot
.016 w
.18175 .56122 m
.18335 .56122 L
s
1 .474 0 r
.008 w
.18335 .56122 Mdot
.016 w
.18335 .56122 m
.18473 .56119 L
s
1 .471 0 r
.008 w
.18473 .56119 Mdot
.016 w
.18473 .56119 m
.18606 .56115 L
s
1 .468 0 r
.008 w
.18606 .56115 Mdot
.016 w
.18606 .56115 m
.18707 .56111 L
s
1 .465 0 r
.008 w
.18707 .56111 Mdot
.016 w
.18707 .56111 m
.18785 .5611 L
s
1 .462 0 r
.008 w
.18785 .5611 Mdot
.016 w
.18785 .5611 m
.18832 .56111 L
s
1 .46 0 r
.008 w
.18832 .56111 Mdot
.016 w
.18832 .56111 m
.18843 .56115 L
s
1 .457 0 r
.008 w
.18843 .56115 Mdot
.016 w
.18843 .56115 m
.1882 .5612 L
s
1 .454 0 r
.008 w
.1882 .5612 Mdot
.016 w
.1882 .5612 m
.18769 .56125 L
s
1 .451 0 r
.008 w
.18769 .56125 Mdot
.016 w
.18769 .56125 m
.18697 .56128 L
s
1 .448 0 r
.008 w
.18697 .56128 Mdot
.016 w
.18697 .56128 m
.18607 .56132 L
s
1 .446 0 r
.008 w
.18607 .56132 Mdot
.016 w
.18607 .56132 m
.18517 .56137 L
s
1 .443 0 r
.008 w
.18517 .56137 Mdot
.016 w
.18517 .56137 m
.1842 .56143 L
s
1 .44 0 r
.008 w
.1842 .56143 Mdot
.016 w
.1842 .56143 m
.18317 .56147 L
s
1 .437 0 r
.008 w
.18317 .56147 Mdot
.016 w
.18317 .56147 m
.18217 .56146 L
s
1 .435 0 r
.008 w
.18217 .56146 Mdot
.016 w
.18217 .56146 m
.18131 .56135 L
s
1 .432 0 r
.008 w
.18131 .56135 Mdot
.016 w
.18131 .56135 m
.18063 .56109 L
s
1 .429 0 r
.008 w
.18063 .56109 Mdot
.016 w
.18063 .56109 m
.18011 .56062 L
s
1 .426 0 r
.008 w
.18011 .56062 Mdot
.016 w
.18011 .56062 m
.17969 .55994 L
s
1 .423 0 r
.008 w
.17969 .55994 Mdot
.016 w
.17969 .55994 m
.17936 .55901 L
s
1 .421 0 r
.008 w
.17936 .55901 Mdot
.016 w
.17936 .55901 m
.17906 .55779 L
s
1 .418 0 r
.008 w
.17906 .55779 Mdot
.016 w
.17906 .55779 m
.17876 .55624 L
s
1 .415 0 r
.008 w
.17876 .55624 Mdot
.016 w
.17876 .55624 m
.17839 .55436 L
s
1 .412 0 r
.008 w
.17839 .55436 Mdot
.016 w
.17839 .55436 m
.17792 .5525 L
s
1 .409 0 r
.008 w
.17792 .5525 Mdot
.016 w
.17792 .5525 m
.17731 .55028 L
s
1 .407 0 r
.008 w
.17731 .55028 Mdot
.016 w
.17731 .55028 m
.17659 .54769 L
s
1 .404 0 r
.008 w
.17659 .54769 Mdot
.016 w
.17659 .54769 m
.17574 .54518 L
s
1 .401 0 r
.008 w
.17574 .54518 Mdot
.016 w
.17574 .54518 m
.17488 .54247 L
s
1 .398 0 r
.008 w
.17488 .54247 Mdot
.016 w
.17488 .54247 m
.17388 .53958 L
s
1 .396 0 r
.008 w
.17388 .53958 Mdot
.016 w
.17388 .53958 m
.17281 .53682 L
s
1 .393 0 r
.008 w
.17281 .53682 Mdot
.016 w
.17281 .53682 m
.17175 .53423 L
s
1 .39 0 r
.008 w
.17175 .53423 Mdot
.016 w
.17175 .53423 m
.17068 .53177 L
s
1 .387 0 r
.008 w
.17068 .53177 Mdot
.016 w
.17068 .53177 m
.16963 .52937 L
s
1 .384 0 r
.008 w
.16963 .52937 Mdot
.016 w
.16963 .52937 m
.16871 .52756 L
s
1 .382 0 r
.008 w
.16871 .52756 Mdot
.016 w
.16871 .52756 m
.16791 .52588 L
s
1 .379 0 r
.008 w
.16791 .52588 Mdot
.016 w
.16791 .52588 m
.16725 .52448 L
s
1 .376 0 r
.008 w
.16725 .52448 Mdot
.016 w
.16725 .52448 m
.16674 .52347 L
s
1 .373 0 r
.008 w
.16674 .52347 Mdot
.016 w
.16674 .52347 m
.16638 .52264 L
s
1 .37 0 r
.008 w
.16638 .52264 Mdot
.016 w
.16638 .52264 m
.16614 .52202 L
s
1 .368 0 r
.008 w
.16614 .52202 Mdot
.016 w
.16614 .52202 m
.16595 .5216 L
s
1 .365 0 r
.008 w
.16595 .5216 Mdot
.016 w
.16595 .5216 m
.16575 .52132 L
s
1 .362 0 r
.008 w
.16575 .52132 Mdot
.016 w
.16575 .52132 m
.16548 .52115 L
s
1 .359 0 r
.008 w
.16548 .52115 Mdot
.016 w
.16548 .52115 m
.16509 .52106 L
s
1 .357 0 r
.008 w
.16509 .52106 Mdot
.016 w
.16509 .52106 m
.16451 .521 L
s
1 .354 0 r
.008 w
.16451 .521 Mdot
.016 w
.16451 .521 m
.16372 .52095 L
s
1 .351 0 r
.008 w
.16372 .52095 Mdot
.016 w
.16372 .52095 m
.1627 .52087 L
s
1 .348 0 r
.008 w
.1627 .52087 Mdot
.016 w
.1627 .52087 m
.16155 .52073 L
s
1 .345 0 r
.008 w
.16155 .52073 Mdot
.016 w
.16155 .52073 m
.16017 .52052 L
s
1 .343 0 r
.008 w
.16017 .52052 Mdot
.016 w
.16017 .52052 m
.15857 .52022 L
s
1 .34 0 r
.008 w
.15857 .52022 Mdot
.016 w
.15857 .52022 m
.15683 .51987 L
s
1 .337 0 r
.008 w
.15683 .51987 Mdot
.016 w
.15683 .51987 m
.15522 .51949 L
s
1 .334 0 r
.008 w
.15522 .51949 Mdot
.016 w
.15522 .51949 m
.1536 .5191 L
s
1 .331 0 r
.008 w
.1536 .5191 Mdot
.016 w
.1536 .5191 m
.15202 .51874 L
s
1 .329 0 r
.008 w
.15202 .51874 Mdot
.016 w
.15202 .51874 m
.15058 .51844 L
s
1 .326 0 r
.008 w
.15058 .51844 Mdot
.016 w
.15058 .51844 m
.14939 .51816 L
s
1 .323 0 r
.008 w
.14939 .51816 Mdot
.016 w
.14939 .51816 m
.14846 .51793 L
s
1 .32 0 r
.008 w
.14846 .51793 Mdot
.016 w
.14846 .51793 m
.14775 .51769 L
s
1 .318 0 r
.008 w
.14775 .51769 Mdot
.016 w
.14775 .51769 m
.14726 .51739 L
s
1 .315 0 r
.008 w
.14726 .51739 Mdot
.016 w
.14726 .51739 m
.14697 .51696 L
s
1 .312 0 r
.008 w
.14697 .51696 Mdot
.016 w
.14697 .51696 m
.14688 .51647 L
s
1 .309 0 r
.008 w
.14688 .51647 Mdot
.016 w
.14688 .51647 m
.14695 .516 L
s
1 .306 0 r
.008 w
.14695 .516 Mdot
.016 w
.14695 .516 m
.14712 .51539 L
s
1 .304 0 r
.008 w
.14712 .51539 Mdot
.016 w
.14712 .51539 m
.14739 .51468 L
s
1 .301 0 r
.008 w
.14739 .51468 Mdot
.016 w
.14739 .51468 m
.1477 .51384 L
s
1 .298 0 r
.008 w
.1477 .51384 Mdot
.016 w
.1477 .51384 m
.14801 .51281 L
s
1 .295 0 r
.008 w
.14801 .51281 Mdot
.016 w
.14801 .51281 m
.14828 .51168 L
s
1 .292 0 r
.008 w
.14828 .51168 Mdot
.016 w
.14828 .51168 m
.14844 .51036 L
s
1 .29 0 r
.008 w
.14844 .51036 Mdot
.016 w
.14844 .51036 m
.14844 .50879 L
s
1 .287 0 r
.008 w
.14844 .50879 Mdot
.016 w
.14844 .50879 m
.14828 .50702 L
s
1 .284 0 r
.008 w
.14828 .50702 Mdot
.016 w
.14828 .50702 m
.14802 .50518 L
s
1 .281 0 r
.008 w
.14802 .50518 Mdot
.016 w
.14802 .50518 m
.14769 .50339 L
s
1 .279 0 r
.008 w
.14769 .50339 Mdot
.016 w
.14769 .50339 m
.14732 .50148 L
s
1 .276 0 r
.008 w
.14732 .50148 Mdot
.016 w
.14732 .50148 m
.14693 .49993 L
s
1 .273 0 r
.008 w
.14693 .49993 Mdot
.016 w
.14693 .49993 m
.14654 .49844 L
s
1 .27 0 r
.008 w
.14654 .49844 Mdot
.016 w
.14654 .49844 m
.14618 .49729 L
s
1 .267 0 r
.008 w
.14618 .49729 Mdot
.016 w
.14618 .49729 m
.14587 .49634 L
s
1 .265 0 r
.008 w
.14587 .49634 Mdot
.016 w
.14587 .49634 m
.14562 .49559 L
s
1 .262 0 r
.008 w
.14562 .49559 Mdot
.016 w
.14562 .49559 m
.14544 .49517 L
s
1 .259 0 r
.008 w
.14544 .49517 Mdot
.016 w
.14544 .49517 m
.14533 .49492 L
s
1 .256 0 r
.008 w
.14533 .49492 Mdot
.016 w
.14533 .49492 m
.14529 .49481 L
s
1 .253 0 r
.008 w
.14529 .49481 Mdot
.016 w
.14529 .49481 m
.14532 .49482 L
s
1 .251 0 r
.008 w
.14532 .49482 Mdot
.016 w
.14532 .49482 m
.14543 .495 L
s
1 .248 0 r
.008 w
.14543 .495 Mdot
.016 w
.14543 .495 m
.14559 .49531 L
s
1 .245 0 r
.008 w
.14559 .49531 Mdot
.016 w
.14559 .49531 m
.14578 .4957 L
s
1 .242 0 r
.008 w
.14578 .4957 Mdot
.016 w
.14578 .4957 m
.14598 .49612 L
s
1 .24 0 r
.008 w
.14598 .49612 Mdot
.016 w
.14598 .49612 m
.14615 .49648 L
s
1 .237 0 r
.008 w
.14615 .49648 Mdot
.016 w
.14615 .49648 m
.14629 .49676 L
s
1 .234 0 r
.008 w
.14629 .49676 Mdot
.016 w
.14629 .49676 m
.14639 .49691 L
s
1 .231 0 r
.008 w
.14639 .49691 Mdot
.016 w
.14639 .49691 m
.14645 .49693 L
s
1 .228 0 r
.008 w
.14645 .49693 Mdot
.016 w
.14645 .49693 m
.14645 .49679 L
s
1 .226 0 r
.008 w
.14645 .49679 Mdot
.016 w
.14645 .49679 m
.14643 .49647 L
s
1 .223 0 r
.008 w
.14643 .49647 Mdot
.016 w
.14643 .49647 m
.1464 .49606 L
s
1 .22 0 r
.008 w
.1464 .49606 Mdot
.016 w
.1464 .49606 m
.14639 .4956 L
s
1 .217 0 r
.008 w
.14639 .4956 Mdot
.016 w
.14639 .4956 m
.14639 .49512 L
s
1 .214 0 r
.008 w
.14639 .49512 Mdot
.016 w
.14639 .49512 m
.1464 .49463 L
s
1 .212 0 r
.008 w
.1464 .49463 Mdot
.016 w
.1464 .49463 m
.14642 .49415 L
s
1 .209 0 r
.008 w
.14642 .49415 Mdot
.016 w
.14642 .49415 m
.14644 .49369 L
s
1 .206 0 r
.008 w
.14644 .49369 Mdot
.016 w
.14644 .49369 m
.14646 .49323 L
s
1 .203 0 r
.008 w
.14646 .49323 Mdot
.016 w
.14646 .49323 m
.14652 .49279 L
s
1 .201 0 r
.008 w
.14652 .49279 Mdot
.016 w
.14652 .49279 m
.14666 .49241 L
s
1 .198 0 r
.008 w
.14666 .49241 Mdot
.016 w
.14666 .49241 m
.14687 .49212 L
s
1 .195 0 r
.008 w
.14687 .49212 Mdot
.016 w
.14687 .49212 m
.14708 .49196 L
s
1 .192 0 r
.008 w
.14708 .49196 Mdot
.016 w
.14708 .49196 m
.14724 .49191 L
s
1 .189 0 r
.008 w
.14724 .49191 Mdot
.016 w
.14724 .49191 m
.1473 .49194 L
s
1 .187 0 r
.008 w
.1473 .49194 Mdot
.016 w
.1473 .49194 m
.14723 .49201 L
s
1 .184 0 r
.008 w
.14723 .49201 Mdot
.016 w
.14723 .49201 m
.14697 .49208 L
s
1 .181 0 r
.008 w
.14697 .49208 Mdot
.016 w
.14697 .49208 m
.1464 .49209 L
s
1 .178 0 r
.008 w
.1464 .49209 Mdot
.016 w
.1464 .49209 m
.14546 .492 L
s
1 .175 0 r
.008 w
.14546 .492 Mdot
.016 w
.14546 .492 m
.14415 .49178 L
s
1 .173 0 r
.008 w
.14415 .49178 Mdot
.016 w
.14415 .49178 m
.1425 .49143 L
s
1 .17 0 r
.008 w
.1425 .49143 Mdot
.016 w
.1425 .49143 m
.1405 .49099 L
s
1 .167 0 r
.008 w
.1405 .49099 Mdot
.016 w
.1405 .49099 m
.13855 .49047 L
s
1 .164 0 r
.008 w
.13855 .49047 Mdot
.016 w
.13855 .49047 m
.13613 .48989 L
s
1 .162 0 r
.008 w
.13613 .48989 Mdot
.016 w
.13613 .48989 m
.13355 .48931 L
s
1 .159 0 r
.008 w
.13355 .48931 Mdot
.016 w
.13355 .48931 m
.13092 .48872 L
s
1 .156 0 r
.008 w
.13092 .48872 Mdot
.016 w
.13092 .48872 m
.12817 .48815 L
s
1 .153 0 r
.008 w
.12817 .48815 Mdot
.016 w
.12817 .48815 m
.12552 .48761 L
s
1 .15 0 r
.008 w
.12552 .48761 Mdot
.016 w
.12552 .48761 m
.12262 .48712 L
s
1 .148 0 r
.008 w
.12262 .48712 Mdot
.016 w
.12262 .48712 m
.12032 .48667 L
s
1 .145 0 r
.008 w
.12032 .48667 Mdot
.016 w
.12032 .48667 m
.11812 .48627 L
s
1 .142 0 r
.008 w
.11812 .48627 Mdot
.016 w
.11812 .48627 m
.11588 .4859 L
s
1 .139 0 r
.008 w
.11588 .4859 Mdot
.016 w
.11588 .4859 m
.11388 .48555 L
s
1 .136 0 r
.008 w
.11388 .48555 Mdot
.016 w
.11388 .48555 m
.11196 .4852 L
s
1 .134 0 r
.008 w
.11196 .4852 Mdot
.016 w
.11196 .4852 m
.11013 .48486 L
s
1 .131 0 r
.008 w
.11013 .48486 Mdot
.016 w
.11013 .48486 m
.10845 .4845 L
s
1 .128 0 r
.008 w
.10845 .4845 Mdot
.016 w
.10845 .4845 m
.10702 .48416 L
s
1 .125 0 r
.008 w
.10702 .48416 Mdot
.016 w
.10702 .48416 m
.10603 .48381 L
s
1 .123 0 r
.008 w
.10603 .48381 Mdot
.016 w
.10603 .48381 m
.10481 .48346 L
s
1 .12 0 r
.008 w
.10481 .48346 Mdot
.016 w
.10481 .48346 m
.10388 .48309 L
s
1 .117 0 r
.008 w
.10388 .48309 Mdot
.016 w
.10388 .48309 m
.10296 .48267 L
s
1 .114 0 r
.008 w
.10296 .48267 Mdot
.016 w
.10296 .48267 m
.10205 .4822 L
s
1 .111 0 r
.008 w
.10205 .4822 Mdot
.016 w
.10205 .4822 m
.1012 .48169 L
s
1 .109 0 r
.008 w
.1012 .48169 Mdot
.016 w
.1012 .48169 m
.10042 .48119 L
s
1 .106 0 r
.008 w
.10042 .48119 Mdot
.016 w
.10042 .48119 m
.09969 .48068 L
s
1 .103 0 r
.008 w
.09969 .48068 Mdot
.016 w
.09969 .48068 m
.09901 .48015 L
s
1 .1 0 r
.008 w
.09901 .48015 Mdot
.016 w
.09901 .48015 m
.0984 .47956 L
s
1 .097 0 r
.008 w
.0984 .47956 Mdot
.016 w
.0984 .47956 m
.09785 .47893 L
s
1 .095 0 r
.008 w
.09785 .47893 Mdot
.016 w
.09785 .47893 m
.09732 .47827 L
s
1 .092 0 r
.008 w
.09732 .47827 Mdot
.016 w
.09732 .47827 m
.09668 .47753 L
s
1 .089 0 r
.008 w
.09668 .47753 Mdot
.016 w
.09668 .47753 m
.09601 .47668 L
s
1 .086 0 r
.008 w
.09601 .47668 Mdot
.016 w
.09601 .47668 m
.09532 .4757 L
s
1 .084 0 r
.008 w
.09532 .4757 Mdot
.016 w
.09532 .4757 m
.09466 .47471 L
s
1 .081 0 r
.008 w
.09466 .47471 Mdot
.016 w
.09466 .47471 m
.09409 .47373 L
s
1 .078 0 r
.008 w
.09409 .47373 Mdot
.016 w
.09409 .47373 m
.09362 .4728 L
s
1 .075 0 r
.008 w
.09362 .4728 Mdot
.016 w
.09362 .4728 m
.09328 .47197 L
s
1 .072 0 r
.008 w
.09328 .47197 Mdot
.016 w
.09328 .47197 m
.09308 .47129 L
s
1 .07 0 r
.008 w
.09308 .47129 Mdot
.016 w
.09308 .47129 m
.09302 .47071 L
s
1 .067 0 r
.008 w
.09302 .47071 Mdot
.016 w
.09302 .47071 m
.09309 .47026 L
s
1 .064 0 r
.008 w
.09309 .47026 Mdot
.016 w
.09309 .47026 m
.09327 .46994 L
s
1 .061 0 r
.008 w
.09327 .46994 Mdot
.016 w
.09327 .46994 m
.09351 .46972 L
s
1 .058 0 r
.008 w
.09351 .46972 Mdot
.016 w
.09351 .46972 m
.09379 .46959 L
s
1 .056 0 r
.008 w
.09379 .46959 Mdot
.016 w
.09379 .46959 m
.09409 .46949 L
s
1 .053 0 r
.008 w
.09409 .46949 Mdot
.016 w
.09409 .46949 m
.09439 .46939 L
s
1 .05 0 r
.008 w
.09439 .46939 Mdot
.016 w
.09439 .46939 m
.09466 .46926 L
s
1 .047 0 r
.008 w
.09466 .46926 Mdot
.016 w
.09466 .46926 m
.09492 .46906 L
s
1 .045 0 r
.008 w
.09492 .46906 Mdot
.016 w
.09492 .46906 m
.09515 .46879 L
s
1 .042 0 r
.008 w
.09515 .46879 Mdot
.016 w
.09515 .46879 m
.09538 .46843 L
s
1 .039 0 r
.008 w
.09538 .46843 Mdot
.016 w
.09538 .46843 m
.09561 .46799 L
s
1 .036 0 r
.008 w
.09561 .46799 Mdot
.016 w
.09561 .46799 m
.09585 .46751 L
s
1 .033 0 r
.008 w
.09585 .46751 Mdot
.016 w
.09585 .46751 m
.09609 .46703 L
s
1 .031 0 r
.008 w
.09609 .46703 Mdot
.016 w
.09609 .46703 m
.09632 .46657 L
s
1 .028 0 r
.008 w
.09632 .46657 Mdot
.016 w
.09632 .46657 m
.09655 .46611 L
s
1 .025 0 r
.008 w
.09655 .46611 Mdot
.016 w
.09655 .46611 m
.09678 .46567 L
s
1 .022 0 r
.008 w
.09678 .46567 Mdot
.016 w
.09678 .46567 m
.09701 .46528 L
s
1 .019 0 r
.008 w
.09701 .46528 Mdot
.016 w
.09701 .46528 m
.09724 .46497 L
s
1 .017 0 r
.008 w
.09724 .46497 Mdot
.016 w
.09724 .46497 m
.09748 .46475 L
s
1 .014 0 r
.008 w
.09748 .46475 Mdot
.016 w
.09748 .46475 m
.09773 .46463 L
s
1 .011 0 r
.008 w
.09773 .46463 Mdot
.016 w
.09773 .46463 m
.09799 .46459 L
s
1 .008 0 r
.008 w
.09799 .46459 Mdot
.016 w
.09799 .46459 m
.09823 .46461 L
s
1 .006 0 r
.008 w
.09823 .46461 Mdot
.016 w
.09823 .46461 m
.09843 .46467 L
s
1 .003 0 r
.008 w
.09843 .46467 Mdot
.016 w
.09843 .46467 m
.0986 .46474 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0631815 0.0645051 scale
2.60392 8.52879 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.121767 0.124317 scale
1.19557 3.98311 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0028OolE0023Ool007ioo`X0
01Eoo`P007]oo`00NGoo1@009goo1P00MGoo001eOol4000bOol5001`Ool0071oo`D003]oo`@006ao
o`00KGoo0`00A7oo0`00JGoo001[Ool2001:Ool3001VOol006Qoo`<004moo`<006=oo`00IGoo0`00
EGoo0`00H7oo001ROol3001KOol2001NOol0061oo`80061oo`8005aoo`00GWoo0P00I7oo0P00FWoo
001LOol2001XOol2001HOol005Uoo`<006aoo`<005Eoo`00Egoo0P00LWoo0P00Dgoo001EOol2001f
Ool2001AOol005Aoo`03001oogoo07Qoo`03001oogoo04ioo`00Dgoo00<007ooOol0NWoo0P00CWoo
001AOol2001oOol2001<Ool004moo`8008=oo`03001oogoo04Uoo`00CGoo0P00QWoo0P00BGoo001<
Ool00`00Oomoo`28Ool00`00Oomoo`16Ool004]oo`03001oogoo08Yoo`8004Ioo`00BWoo00<007oo
Ool0SGoo00<007ooOol0@goo0018Ool2002AOol00`00Oomoo`12Ool004Moo`03001oogoo099oo`03
001oogoo045oo`00AGoo0P00UWoo0P00@Goo0014Ool00`00Oomoo`2HOol00`00Oomoo`0nOol004=o
o`03001oogoo09Yoo`8003ioo`00@Woo00<007ooOol0WGoo00<007ooOol0>goo0010Ool2002QOol0
0`00Oomoo`0jOol003moo`03001oogoo0:9oo`03001oogoo03Uoo`00?Woo00<007ooOol0Y7oo00<0
07ooOol0>7oo000mOol00`00Oomoo`2VOol00`00Oomoo`0gOol003aoo`03001oogoo0:Qoo`8003Mo
o`00>goo00<007ooOol0Zgoo00<007ooOol0=7oo000iOol2002_Ool00`00Oomoo`0cOol003Qoo`03
001oogoo0;1oo`03001oogoo039oo`00=goo00<007ooOol0/Woo00<007ooOol0<Goo000fOol00`00
Oomoo`2cOol00`00Oomoo`0aOol003Eoo`03001oogoo0;Eoo`03001oogoo031oo`00=Goo00<007oo
Ool0]Woo0P00<7oo000dOol00`00Oomoo`2iOol00`00Oomoo`0]Ool003=oo`03001oogoo0;]oo`03
001oogoo02aoo`00<Woo00<007ooOol0_Goo00<007ooOol0:goo000aOol00`00Oomoo`2oOol00`00
Oomoo`0ZOol0035oo`03001oogoo0;moo`03001oogoo02Yoo`00<7oo00<007ooOol0`Goo00<007oo
Ool0:Goo000_Ool00`00Oomoo`33Ool00`00Oomoo`0XOol002ioo`03001oogoo0<Eoo`03001oogoo
02Moo`00;Goo00<007ooOol0agoo00<007ooOol09Woo000]Ool00`00Oomoo`37Ool00`00Oomoo`0V
Ool002aoo`03001oogoo00Eoo`Dmkkmoo`03001oogoo02Eoo`00:goo00<007ooOol01Woo1Cg_`7oo
00<007ooOol097oo000ZOol00`00Oomoo`06Ool6?No1Ool00`00Oomoo`0SOol002Uoo`03001oogoo
00Ioo`Lmkl9oo`03001oogoo029oo`00:Goo00<007ooOol01Goo1cg_`goo00<007ooOol08Woo000X
Ool00`00Oomoo`05Ool8?No4Ool00`00Oomoo`0QOol002Moo`03001oogoo00Eoo`PmklEoo`03001o
ogoo025oo`009goo00<007ooOol01Goo1cg_agoo00<007ooOol087oo000VOol00`00Oomoo`05Ool7
?No8Ool00`00Oomoo`0POol002Eoo`03001oogoo00Ioo`HmklYoo`03001oogoo01moo`009Goo00<0
07ooOol01Goo1cg_bWoo00<007ooOol07goo000TOol00`00Oomoo`06Ool6?No<Ool00`00Oomoo`0N
Ool002Aoo`03001oogoo00Eoo`Hmklioo`03001oogoo01eoo`008goo00<007ooOol01Woo1Sg_cgoo
00<007ooOol077oo000ROol00`00Oomoo`07Ool6?No?Ool00`00Oomoo`0LOol0029oo`03001oogoo
00Ioo`Lmkm1oo`03001oogoo01]oo`008Goo00<007ooOol01Woo23g_d7oo00<007ooOol06goo000Q
Ool00`00Oomoo`05Ool9?NoAOol00`00Oomoo`0JOol0021oo`03001oogoo00Eoo`Xmkm5oo`03001o
ogoo01Yoo`0087oo00<007ooOol01Goo2Cg_dgoo00<007ooOol06Goo000OOol00`00Oomoo`06Ool9
?NoCOol00`00Oomoo`0IOol001moo`03001oogoo00Eoo`TmkmEoo`03001oogoo01Qoo`007Woo00<0
07ooOol01Woo23g_eWoo00<007ooOol067oo000NOol00`00Oomoo`06Ool6?NoHOol00`00Oomoo`0H
Ool001eoo`03001oogoo00Ioo`HmkmYoo`03001oogoo01Moo`007Goo00<007ooOol01Goo1cg_fWoo
00<007ooOol05goo000MOol00`00Oomoo`04Ool7?NoLOol00`00Oomoo`0FOol001aoo`03001oogoo
00Aoo`Pmkmaoo`03001oogoo01Ioo`0077oo00<007ooOol017oo23g_gGoo00<007ooOol05Goo000K
Ool00`00Oomoo`05Ool8?NoMOol00`00Oomoo`0EOol001]oo`03001oogoo00Eoo`Hmkmmoo`03001o
ogoo01Eoo`006Woo00<007ooOol01Woo1Sg_h7oo00<007ooOol057oo000JOol00`00Oomoo`06Ool6
?NoPOol00`00Oomoo`0DOol001Yoo`03001oogoo00Eoo`Lmkn1oo`03001oogoo01Aoo`006Goo00<0
07ooOol01Woo1Sg_hWoo00<007ooOol04goo000IOol00`00Oomoo`06Ool5?NoTOol00`00Oomoo`0B
Ool001Uoo`03001oogoo00Eoo`HmknAoo`03001oogoo019oo`0067oo00<007ooOol01Woo1Sg_i7oo
00<007ooOol04Woo000HOol00`00Oomoo`06Ool6?NoUOol00`00Oomoo`0AOol001Qoo`03001oogoo
00Ioo`HmknEoo`03001oogoo015oo`005goo00<007ooOol01goo1Cg_iWoo00<007ooOol04Goo000G
Ool00`00Oomoo`07Ool5?NoWOol00`00Oomoo`0@Ool001Moo`03001oogoo00Ioo`DmknQoo`03001o
ogoo011oo`005Woo00<007ooOol01goo1Cg_1Woo1`00fgoo00<007ooOol047oo000FOol00`00Oomo
o`07Ool5?Nl00goo000000030007Ool5003FOol00`00Oomoo`0@Ool001Ioo`03001oogoo00Moo`8m
k`@0015oo`<00==oo`03001oogoo011oo`005Woo00<007ooOol01goo0P0013g_57oo0P00dWoo00<0
07ooOol03goo000FOol00`00Oomoo`05Ool20005?NlGOol2003@Ool00`00Oomoo`0?Ool001Eoo`03
001oogoo00Eoo`03001oogoo00DmkaUoo`800<ioo`03001oogoo00moo`005Goo00<007ooOol00goo
0P000goo1Cg_6goo00<007ooOol0c7oo00<007ooOol03Woo000EOol00`00Oomoo`02Ool00`00Oomo
o`03Ool5?NlLOol2003<Ool00`00Oomoo`0>Ool001Aoo`03001oogoo009oo`03001oogoo00Aoo`Dm
kaioo`03001oogoo0<Uoo`03001oogoo00ioo`0057oo00D007ooOomoo`0000Moo`Dmkamoo`03001o
ogoo0<Qoo`03001oogoo00ioo`0057oo00@007oo000000Qoo`@mkb5oo`03001oogoo0<Moo`03001o
ogoo00ioo`0057oo0P002Woo13g_8Woo00<007ooOol0agoo00<007ooOol03Goo000DOol00`00Oomo
o`09Ool4?NlROol00`00Oomoo`37Ool00`00Oomoo`0=Ool001Aoo`03001oogoo00Uoo`@mkb=oo`03
001oogoo0<Ioo`03001oogoo00eoo`004goo0P002goo13g_97oo00<007ooOol0aGoo00<007ooOol0
3Goo000BOol2000eOol00`00Oomoo`34Ool00`00Oomoo`0=Ool0019oo`8003Ioo`03001oogoo0<=o
o`03001oogoo00eoo`004Goo00<007oo0000=Woo00<007ooOol0a7oo00<007ooOol037oo000AOol0
0`00Ool0000gOol00`00Oomoo`33Ool00`00Oomoo`0<Ool0011oo`04001oogoo000hOol00`00Oomo
o`32Ool00`00Oomoo`0<Ool0011oo`04001oogoo000hOol00`00Oomoo`32Ool00`00Oomoo`0<Ool0
00moo`04001oogoo000jOol00`00Oomoo`31Ool00`00Oomoo`0<Ool000moo`04001oogoo000jOol0
0`00Oomoo`31Ool00`00Oomoo`0<Ool000ioo`05001oogooOol0000jOol00`00Oomoo`31Ool00`00
Oomoo`0<Ool000ioo`05001oogooOol0000kOol00`00Oomoo`30Ool00`00Oomoo`0<Ool000ioo`05
001oogooOol0000;Ool5O00[Ool00`00Oomoo`30Ool00`00Oomoo`0<Ool000eoo`03001oogoo009o
o`03001oogoo00Qoo`03O21l07`000=l00Eoo`Aoh29oo`03001oogoo0<1oo`03001oogoo00aoo`00
3Goo00<007ooOol00Woo00<007ooOol027oo00=l87`0O0000g`01Goo00=oh7o0Ol000Wo08Goo00<0
07ooOol0`Goo00<007ooOol02goo000=Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00g`PO01l0003
O005Ool00goPOl1o`003Ol0POol00`00Oomoo`31Ool00`00Oomoo`0;Ool000eoo`03001oogoo009o
o`03001oogoo00Qoo`03O21l07`0009l0003O41oogoo00=oo`03On1o`7o000AoX21oo`03001oogoo
0<1oo`03001oogoo00]oo`003Goo00<007ooOol00Woo00<007ooOol027oo17`P00Al@7aPO61lH0=o
o`03O81o`7o000AoX21oo`03001oogoo0<1oo`03001oogoo00]oo`0037oo00<007ooOol00goo00<0
07ooOol02Goo17a00gaP1Gb000=o`7n0Oh0017mP7Woo00<007ooOol0`7oo00<007ooOol02goo000<
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool4O403O607O802O:0:000GOol00`00Oomoo`30Ool00`00
Oomoo`0;Ool000aoo`03001oogoo00=oo`03001oogoo00Yoo`IlH0IlP0<0009lX003Od1oogoo00Eo
o`<001Aoo`03001oogoo0<1oo`03001oogoo00]oo`0037oo00<007ooOol00goo00<007ooOol037oo
2Gb000<007b0O:000gbP00=o87ooOol027oo00<007ooOol04Goo00<007ooOol0`7oo00<007ooOol0
2goo000<Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00gb000000002O804O:000glPOomoo`09Ool2
000AOol00`00Oomoo`30Ool00`00Oomoo`0;Ool000aoo`03001oogoo00=oo`03001oogoo019oo`04
001oogooOol5O:000gl0Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`30Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=oo`Al`09o00eoo`03001oogoo00eo
o`03001oogoo0<1oo`03001oogoo00]oo`0037oo00<007ooOol00goo00<007ooOol04Goo00<007oo
Ool00goo17d00gl03Goo00<007ooOol037oo00<007ooOol0`7oo00<007ooOol02goo000=Ool00`00
Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool4O@03O^0>Ool00`00Oomoo`0;Ool00`00Oomo
o`30Ool00`00Oomoo`0;Ool000eoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Eoo`Am
80Am@0eoo`03001oogoo00]oo`03001oogoo0<1oo`03001oogoo00]oo`003Goo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol01Goo17dP17e00WeP37oo00<007ooOol02Goo00<007ooOol0`Goo
00<007ooOol02goo000=Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool4OB04OD02
OF0=Ool00`00Oomoo`08Ool00`00Oomoo`31Ool00`00Oomoo`0;Ool000eoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo00Ioo`Qm@09mH0eoo`03001oogoo00Qoo`03001oogoo0<5oo`03001o
ogoo00]oo`003Woo00D007ooOomoo`00011oo`03001oogoo00Yoo`ImH003OH1oogoo00Yoo`03001o
ogoo00Qoo`03001oogoo0<1oo`03001oogoo00aoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00]oo`9nP0ImP0aoo`03001oogoo00Moo`03001oogoo0<1oo`03001oogoo00aoo`003Woo00D007oo
Oomoo`0000moo`03001oogoo00]oo`9nP0ImP0aoo`03001oogoo00Ioo`03001oogoo0<5oo`03001o
ogoo00aoo`003goo00@007ooOol000moo`03001oogoo00]oo`=nP0EmP0aoo`03001oogoo00Ioo`03
001oogoo0<5oo`03001oogoo00aoo`003goo00@007ooOol000moo`03001oogoo00]oo`03OX1n@7i0
00EmP0aoo`03001oogoo00Eoo`03001oogoo0<9oo`03001oogoo00aoo`0047oo00<007oo00003goo
00<007ooOol02goo00=nP7i0OT001Gf000=mX7ooOol02Goo00<007ooOol01Goo00<007ooOol0`Woo
00<007ooOol037oo000@Ool00`00Ool0000?Ool00`00Oomoo`0;Ool017j0OT1n@7hP17f000=mX7oo
Ool02Goo00<007ooOol01Goo00<007ooOol0`Woo00<007ooOol037oo000AOol00`00Ool0000>Ool0
0`00Oomoo`0<Ool2OT000ghPOH1mP002OH000gfPOomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`33
Ool00`00Oomoo`0<Ool0015oo`03001oo`0000ioo`03001oogoo00aoo`9n@003OR1mX7fP00AmX003
OL1oogoo00Moo`03001oogoo00=oo`03001oogoo0<Aoo`03001oogoo00aoo`004Woo0P003Woo00<0
07ooOol03Goo00=n@7hPON001GfP00=m`7ooOol01goo00<007ooOol00goo00<007ooOol0a7oo00<0
07ooOol037oo000BOol2000>Ool00`00Oomoo`0>Ool00ghPON1mX004OJ000gg0Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`35Ool00`00Oomoo`0<Ool001=oo`03001oogoo00eoo`03001oogoo00io
o`03ON1mX7fP00=mX003OL1oogoo00Ioo`03001oogoo009oo`03001oogoo0<Eoo`03001oogoo00eo
o`004goo0P003Woo00<007ooOol03Woo17h02goo00D007ooOomoo`000<Qoo`03001oogoo00eoo`00
4goo0P003Woo00<007ooOol07Goo00@007ooOol00<Uoo`03001oogoo00eoo`0057oo0P003Woo00<0
07ooOol06goo00D007ooOomoo`000<Uoo`03001oogoo00eoo`0057oo00@007oo000000aoo`03001o
ogoo01]oo`04001oogoo003:Ool00`00Oomoo`0=Ool001Aoo`05001oogooOol0000<Ool00`00Oomo
o`0IOol01000Oomoo`00bgoo00<007ooOol03Goo000DOol00`00Oomoo`02Ool00`00Oomoo`09Ool0
0`00Oomoo`0HOol01000Oomoo`00c7oo00<007ooOol03Goo000DOol00`00Oomoo`03Ool00`00Oomo
o`09Ool00`00Oomoo`0FOol01000Ool00000c7oo00<007ooOol03Woo000DOol00`00Oomoo`04Ool2
000:Ool2000DOol200000goo001oo`3=Ool00`00Oomoo`0>Ool001Eoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo011oo`04001oo`00003?Ool00`00Oomoo`0>Ool001Eoo`03001oogoo00Io
o`8000Yoo`8000ioo`@00=5oo`03001oogoo00ioo`005Goo00<007ooOol027oo0`002Goo0`002Woo
0`00dWoo00<007ooOol03goo000FOol00`00Oomoo`0:Ool30009Ool:003EOol00`00Oomoo`0?Ool0
01Ioo`03001oogoo00eoo`L000=oo`H00=Qoo`03001oogoo00moo`005Woo00<007ooOol057oo0`00
gWoo00<007ooOol03goo000FOol00`00Oomoo`3dOol00`00Oomoo`0@Ool001Ioo`03001oogoo0?Ao
o`03001oogoo011oo`005goo00<007ooOol0lgoo00<007ooOol047oo000GOol00`00Oomoo`3cOol0
0`00Oomoo`0@Ool001Moo`03001oogoo0?9oo`03001oogoo015oo`0067oo00<007ooOol0lGoo00<0
07ooOol04Goo000HOol00`00Oomoo`3aOol00`00Oomoo`0AOol001Qoo`03001oogoo0?1oo`03001o
ogoo019oo`006Goo00<007ooOol0kgoo00<007ooOol04Woo000IOol00`00Oomoo`3_Ool00`00Oomo
o`0BOol001Uoo`03001oogoo0>moo`03001oogoo019oo`006Woo00<007ooOol0kGoo00<007ooOol0
4goo000JOol00`00Oomoo`3/Ool00`00Oomoo`0DOol001Yoo`03001oogoo0>aoo`03001oogoo01Ao
o`006Woo00<007ooOol0k7oo00<007ooOol057oo000KOol00`00Oomoo`3[Ool00`00Oomoo`0DOol0
01]oo`03001oogoo0>Yoo`03001oogoo01Eoo`0077oo00<007ooOol0jGoo00<007ooOol05Goo000L
Ool00`00Oomoo`3XOol00`00Oomoo`0FOol001eoo`03001oogoo0>Moo`03001oogoo01Ioo`007Goo
00<007ooOol0iWoo00<007ooOol05goo000NOol00`00Oomoo`3UOol00`00Oomoo`0GOol001ioo`03
001oogoo0>Aoo`03001oogoo01Qoo`007goo00<007ooOol0hgoo00<007ooOol067oo000OOol00`00
Oomoo`3SOol00`00Oomoo`0HOol0021oo`03001oogoo0>5oo`03001oogoo01Uoo`0087oo00<007oo
Ool0h7oo00<007ooOol06Woo000QOol00`00Oomoo`3OOol00`00Oomoo`0JOol0025oo`03001oogoo
0=ioo`03001oogoo01]oo`008Woo00<007ooOol0gGoo00<007ooOol06goo000ROol00`00Oomoo`3L
Ool00`00Oomoo`0LOol002=oo`03001oogoo0=]oo`03001oogoo01aoo`008goo00<007ooOol0fWoo
00<007ooOol07Goo000TOol00`00Oomoo`3IOol00`00Oomoo`0MOol002Aoo`03001oogoo0=Qoo`03
001oogoo01ioo`009Goo00<007ooOol0eWoo00<007ooOol07goo000UOol00`00Oomoo`3FOol00`00
Oomoo`0OOol002Ioo`03001oogoo0=Aoo`03001oogoo021oo`009goo00<007ooOol0dWoo00<007oo
Ool08Goo000XOol00`00Oomoo`3@Ool00`00Oomoo`0ROol002Uoo`03001oogoo0<moo`03001oogoo
029oo`00:Goo00<007ooOol0cWoo00<007ooOol08goo000ZOol00`00Oomoo`3=Ool00`00Oomoo`0S
Ool002]oo`03001oogoo0<]oo`03001oogoo02Aoo`00:goo00<007ooOol0bgoo00<007ooOol097oo
000/Ool00`00Oomoo`39Ool00`00Oomoo`0UOol002eoo`03001oogoo0<Moo`03001oogoo02Ioo`00
;Woo00<007ooOol0aGoo00<007ooOol09goo000_Ool00`00Oomoo`33Ool00`00Oomoo`0XOol002mo
o`03001oogoo0<=oo`03001oogoo02Qoo`00<7oo00<007ooOol0`Goo00<007ooOol0:Goo000aOol0
0`00Oomoo`2oOol00`00Oomoo`0ZOol0039oo`03001oogoo0;eoo`03001oogoo02]oo`00<goo00<0
07ooOol0^goo00<007ooOol0;7oo000cOol00`00Oomoo`2kOol00`00Oomoo`0/Ool003Aoo`03001o
ogoo0;Uoo`03001oogoo02eoo`00=Goo00<007ooOol0]Woo0P00<7oo000fOol00`00Oomoo`2dOol0
0`00Oomoo`0`Ool003Moo`03001oogoo0;9oo`03001oogoo035oo`00>7oo00<007ooOol0/7oo00<0
07ooOol0<Woo000iOol00`00Oomoo`2^Ool00`00Oomoo`0cOol003Yoo`03001oogoo0:eoo`03001o
ogoo03=oo`00>goo00<007ooOol0Zgoo00<007ooOol0=7oo000lOol00`00Oomoo`2XOol2000gOol0
03eoo`03001oogoo0:Ioo`03001oogoo03Moo`00?Woo00<007ooOol0Y7oo00<007ooOol0>7oo000o
Ool00`00Oomoo`2ROol00`00Oomoo`0iOol0041oo`800:5oo`03001oogoo03Yoo`00@Woo00<007oo
Ool0WGoo00<007ooOol0>goo0013Ool00`00Oomoo`2JOol2000nOol004Aoo`03001oogoo09Qoo`03
001oogoo03ioo`00AGoo0P00UWoo0P00@Goo0017Ool00`00Oomoo`2BOol00`00Oomoo`11Ool004Qo
o`80095oo`03001oogoo049oo`00BWoo00<007ooOol0SGoo00<007ooOol0@goo001;Ool00`00Oomo
o`2:Ool20016Ool004aoo`8008Qoo`8004Qoo`00CWoo0P00Q7oo0P00BWoo001@Ool20021Ool00`00
Oomoo`1:Ool0059oo`03001oogoo07eoo`03001oogoo04]oo`00Dgoo00<007ooOol0NWoo0P00CWoo
001DOol2001hOol2001@Ool005Ioo`8007Aoo`80059oo`00F7oo0P00L7oo0P00E7oo001JOol2001/
Ool2001FOol005aoo`<006Ioo`<005Qoo`00Ggoo0`00H7oo0`00Fgoo001ROol2001LOol2001NOol0
06Aoo`8005Qoo`80061oo`00IWoo0P00Dgoo0`00HWoo001XOol4001=Ool2001UOol006aoo`<004Io
o`@006Moo`00Kgoo1@00?Goo1000Jgoo001dOol3000gOol3001_Ool007Moo`@002ioo`D0079oo`00
Ngoo1`008Goo1P00Mgoo0022Ool>0004Ool?001mOol0091oo`@008aoo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00SWoo0P00T7oo002=Ool01000Oomoo`00Sgoo002?Ool00`00Oomo
o`2>Ool0091oo`03001oogoo08eoo`00SGoo00@007ooOol008moo`00SWoo0P00T7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-194.054, -178.502, 1.32747, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.537257 0.00258196 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(4)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.438934 scale
1.05 1.22401 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .4408 m
.08448 .44068 L
.08463 .4405 L
.08481 .44025 L
.08501 .43993 L
.08522 .43953 L
.08542 .43904 L
.08562 .43846 L
.08581 .43784 L
.08602 .43713 L
.08626 .43636 L
.08654 .43551 L
.08686 .43464 L
.08716 .43375 L
.08743 .43286 L
.08772 .43201 L
.088 .43121 L
.08829 .43042 L
.08859 .42961 L
.08891 .42877 L
.08923 .42789 L
.08951 .42702 L
.08973 .4261 L
.08987 .42512 L
.08993 .42408 L
.0899 .42307 L
.08981 .42195 L
.08971 .42084 L
.08963 .41971 L
.08956 .41851 L
.08951 .41728 L
.0895 .41616 L
.0895 .41504 L
.08949 .414 L
.08949 .41309 L
.08952 .41228 L
.08958 .41158 L
.08969 .41097 L
.08983 .41042 L
.09 .40986 L
.09019 .40925 L
.09037 .40856 L
.09055 .40776 L
.09073 .40683 L
.09096 .40574 L
.09126 .40471 L
.09164 .40349 L
.0921 .40221 L
.09264 .4007 L
.09322 .39928 L
Mistroke
.09382 .39765 L
.09442 .39587 L
.09499 .3942 L
.09554 .39247 L
.09606 .39079 L
.09658 .38914 L
.09711 .3878 L
.09765 .38644 L
.09819 .38522 L
.09867 .38419 L
.09908 .38323 L
.09941 .38247 L
.09966 .38185 L
.09987 .38138 L
.10005 .38107 L
.10024 .38092 L
.10045 .38092 L
.10063 .38102 L
.10076 .38119 L
.10083 .38135 L
.10083 .38146 L
.10076 .38147 L
.10062 .38134 L
.10043 .38107 L
.10021 .38065 L
.09997 .38009 L
.09971 .37942 L
.09945 .37865 L
.09919 .37789 L
.09893 .37704 L
.09868 .37614 L
.09844 .37522 L
.09823 .37443 L
.09807 .37372 L
.09794 .37315 L
.09785 .37278 L
.09779 .37265 L
.09776 .37277 L
.09778 .3731 L
.09782 .37357 L
.09787 .37411 L
.09794 .37466 L
.09806 .37514 L
.09823 .37553 L
.09845 .3758 L
.09873 .37591 L
.09906 .37586 L
.09944 .37564 L
.09988 .37524 L
.10037 .3747 L
Mistroke
.1009 .37405 L
.10147 .37329 L
.10202 .37245 L
.10254 .37158 L
.10305 .37078 L
.10353 .37012 L
.10397 .36956 L
.10439 .36907 L
.10479 .36865 L
.10519 .36826 L
.1056 .36788 L
.10604 .36748 L
.10652 .367 L
.10703 .36643 L
.10757 .36574 L
.10816 .3649 L
.1088 .36388 L
.10946 .3628 L
.11008 .36147 L
.1107 .35997 L
.11132 .35852 L
.11189 .35692 L
.11238 .35532 L
.11278 .35372 L
.1131 .35229 L
.11332 .35095 L
.11347 .34976 L
.11356 .34879 L
.11358 .34796 L
.11356 .34726 L
.11352 .34671 L
.11346 .34629 L
.1134 .34601 L
.11333 .34586 L
.11327 .34583 L
.11321 .34591 L
.11316 .34605 L
.11312 .34622 L
.11309 .34637 L
.11309 .34649 L
.11315 .34655 L
.11331 .34652 L
.11361 .3464 L
.11404 .34616 L
.11463 .34579 L
.11536 .34532 L
.11625 .34472 L
.11731 .34399 L
.11842 .34316 L
.11967 .34228 L
Mistroke
.12087 .34132 L
.12212 .34033 L
.12336 .33938 L
.12444 .33856 L
.12548 .33786 L
.12644 .33728 L
.12728 .33682 L
.12797 .33645 L
.12853 .33615 L
.129 .33585 L
.12937 .33552 L
.12968 .33512 L
.12996 .33464 L
.13026 .33407 L
.13061 .33338 L
.131 .33257 L
.13143 .33175 L
.13189 .33085 L
.13238 .32991 L
.13287 .32894 L
.13336 .32805 L
.13384 .32722 L
.13429 .3265 L
.1347 .32594 L
.13507 .32554 L
.13539 .32524 L
.13564 .325 L
.13582 .32479 L
.13594 .32453 L
.13603 .32417 L
.1361 .32368 L
.13619 .32305 L
.13631 .3223 L
.13647 .32149 L
.13664 .32076 L
.13684 .31978 L
.13706 .31886 L
.13727 .31787 L
.13747 .3168 L
.13764 .31565 L
.13778 .31452 L
.13789 .31333 L
.13801 .3121 L
.13814 .31082 L
.1383 .30965 L
.13846 .3083 L
.13867 .30693 L
.13892 .30549 L
.13923 .30399 L
.13964 .30237 L
Mistroke
.14014 .30098 L
.14076 .2996 L
.1415 .29825 L
.14228 .297 L
.14313 .29586 L
.14402 .29476 L
.14494 .29368 L
.14581 .29264 L
.14671 .29157 L
.1476 .29053 L
.14857 .28952 L
.14952 .28849 L
.15056 .28743 L
.15171 .28635 L
.15289 .28528 L
.15413 .28413 L
.1554 .28301 L
.15654 .28187 L
.15766 .28074 L
.15872 .27965 L
.15972 .27874 L
.16067 .27782 L
.16146 .27698 L
.16215 .27632 L
.1627 .27575 L
.16311 .27526 L
.16339 .27485 L
.16351 .27449 L
.16352 .27417 L
.16346 .27387 L
.16339 .27355 L
.16332 .27318 L
.16328 .27271 L
.16326 .27217 L
.16326 .27165 L
.16324 .27123 L
.16318 .27088 L
.16308 .27066 L
.16294 .27065 L
.16275 .27085 L
.16251 .27127 L
.16224 .27189 L
.16195 .27268 L
.16165 .27348 L
.16137 .27452 L
.1611 .27546 L
.16088 .27639 L
.16072 .27725 L
.16066 .27796 L
.16071 .27848 L
Mistroke
.16091 .2788 L
.16125 .27895 L
.16173 .27897 L
.16232 .27893 L
.16302 .27883 L
.1638 .27873 L
.16461 .27867 L
.16534 .27865 L
.16601 .27866 L
.16657 .27867 L
.16697 .27868 L
.16721 .27868 L
.16727 .27868 L
.16717 .27865 L
.16698 .27859 L
.16672 .27851 L
.16633 .27841 L
.16586 .2783 L
.16527 .27821 L
.16457 .27819 L
.1638 .27826 L
.16296 .27844 L
.16206 .27876 L
.1611 .27924 L
.16008 .2799 L
.15901 .28077 L
.15802 .28179 L
.15693 .28302 L
.15568 .28443 L
.15413 .28597 L
.15273 .28747 L
.15127 .28908 L
.14976 .29076 L
.14833 .29237 L
.14687 .29385 L
.14544 .2953 L
.14415 .29673 L
.14295 .29803 L
.14174 .29934 L
.14051 .30069 L
.13927 .3021 L
.1381 .30351 L
.137 .30501 L
.13592 .30666 L
.13488 .30845 L
.13392 .31016 L
.13302 .31209 L
.13217 .31395 L
.13136 .31586 L
.13065 .31763 L
Mistroke
.13006 .31916 L
.12958 .32055 L
.12923 .32174 L
.12897 .32264 L
.12877 .32335 L
.12859 .32392 L
.12841 .32435 L
.12819 .32468 L
.12788 .32499 L
.12747 .3253 L
.12697 .32564 L
.12639 .32601 L
.12573 .32642 L
.12509 .32689 L
.12428 .32752 L
.1235 .32821 L
.12264 .32902 L
.12172 .32994 L
.12078 .33095 L
.11987 .33203 L
.119 .33319 L
.11823 .33432 L
.11745 .33553 L
.1167 .33678 L
.11598 .33805 L
.11528 .33929 L
.11457 .34063 L
.11392 .34207 L
.11341 .34351 L
.11302 .34489 L
.11269 .34623 L
.11239 .34756 L
.11208 .34865 L
.11172 .3498 L
.11124 .35085 L
.11062 .35197 L
.10995 .35316 L
.10908 .35431 L
.10808 .35549 L
.107 .35668 L
.10597 .3579 L
.10488 .35913 L
.10369 .36027 L
.10243 .36144 L
.10117 .36264 L
.10008 .36391 L
.09911 .36511 L
.09828 .36636 L
.09758 .36766 L
.09701 .36899 L
Mistroke
.09655 .37025 L
.09619 .37149 L
.09591 .37275 L
.09569 .37407 L
.09552 .37543 L
.09537 .37682 L
.09524 .37826 L
.09508 .3797 L
.0949 .38101 L
.0947 .3822 L
.09451 .38325 L
.09433 .38417 L
.09413 .38498 L
.09389 .38565 L
.09362 .38625 L
.09333 .38679 L
.09303 .38729 L
.09274 .38778 L
.09247 .38832 L
.09221 .38893 L
.09195 .38967 L
.09169 .39057 L
.09142 .39161 L
.0911 .3928 L
.09072 .39419 L
.09028 .39587 L
.0898 .3976 L
.08933 .39953 L
.08888 .40162 L
.08848 .40347 L
.08811 .40561 L
.08775 .40754 L
.08741 .40962 L
.08708 .41187 L
.08674 .41415 L
.08641 .41618 L
.0861 .41826 L
.08582 .42048 L
.08559 .42274 L
.08541 .42465 L
.08524 .42669 L
.08507 .42864 L
.08492 .43053 L
.08477 .43234 L
.08464 .43394 L
.08451 .43539 L
.08444 .43662 L
.08441 .43766 L
.0844 .43851 L
.08442 .43919 L
Mistroke
.08445 .43972 L
.08447 .44013 L
.08447 .44049 L
.08447 .44088 L
.08446 .44131 L
.08445 .44183 L
.08444 .44245 L
.08443 .4432 L
.08441 .44398 L
.08439 .44485 L
.08438 .4458 L
.08436 .44681 L
.08434 .44781 L
.08432 .44869 L
.08431 .44949 L
.0843 .45021 L
.08429 .4508 L
.08428 .45124 L
.08427 .45151 L
Mfstroke
.0843 .45124 m
.08431 .45108 L
.08431 .45088 L
.08429 .45062 L
.08426 .45028 L
.08422 .45003 L
.08421 .44964 L
.08422 .44923 L
.08427 .44876 L
.08436 .44812 L
.08451 .4475 L
.08473 .447 L
.08498 .4463 L
.08526 .44562 L
.08553 .44489 L
.08578 .44407 L
.08603 .4431 L
.08628 .44228 L
.08654 .44144 L
.08679 .44045 L
.087 .43933 L
.08714 .43822 L
.08722 .4373 L
.08725 .4363 L
.08726 .43527 L
.08724 .43437 L
.08721 .43349 L
.0872 .43266 L
.08721 .43195 L
.08722 .43138 L
.08723 .43089 L
.08723 .43048 L
.08723 .43016 L
.08724 .42994 L
.08724 .42981 L
.08724 .42975 L
.08724 .42974 L
.08724 .42977 L
.08724 .42983 L
.08724 .4299 L
.08724 .42996 L
.08724 .42998 L
.08724 .42999 L
.08724 .42999 L
.08723 .43 L
.08723 .43004 L
.08723 .43011 L
.08723 .43016 L
.0872 .43019 L
.08716 .43017 L
Mistroke
.08713 .43009 L
.08712 .42993 L
.08714 .42967 L
.0872 .42934 L
.08731 .42895 L
.08747 .42853 L
.08768 .42808 L
.08794 .42763 L
.08825 .4272 L
.08859 .42675 L
.08888 .42633 L
.08913 .42595 L
.08937 .42567 L
.08961 .42555 L
.08978 .42558 L
.08982 .42578 L
.08972 .42609 L
.08952 .42649 L
.08926 .42696 L
.08897 .42744 L
.08865 .42779 L
.08835 .42805 L
.08806 .42835 L
.0878 .42871 L
.0876 .42909 L
.08744 .42947 L
.08732 .42981 L
.08724 .43018 L
.08718 .43065 L
.08708 .43132 L
.08694 .43219 L
.08675 .43324 L
.08648 .43441 L
.08625 .4356 L
.08595 .43718 L
.08567 .43923 L
.08542 .44078 L
.08515 .44296 L
.08487 .44471 L
.08461 .44659 L
.0844 .44859 L
.08427 .44999 L
.08419 .45147 L
.08414 .45286 L
.08413 .45378 L
.08415 .45453 L
.08417 .45513 L
.08419 .45556 L
.08419 .45581 L
Mfstroke
.11421 .50864 m
.11439 .50873 L
.11462 .50885 L
.1149 .50901 L
.11523 .5092 L
.11562 .50942 L
.11603 .50969 L
.11655 .51006 L
.11707 .5105 L
.11765 .51103 L
.11831 .51169 L
.11899 .51242 L
.11961 .5131 L
.12027 .51389 L
.12087 .51466 L
.12145 .51545 L
.12199 .51621 L
.1225 .51692 L
.12298 .51753 L
.12341 .51806 L
.1238 .51852 L
.12411 .51889 L
.12431 .51913 L
.1244 .51926 L
.12438 .51936 L
.1243 .51951 L
.12419 .51974 L
.12409 .52005 L
.12404 .52045 L
.12408 .52093 L
.12425 .5215 L
.12456 .52211 L
.12501 .52275 L
.12557 .52337 L
.12624 .52398 L
.12696 .52451 L
.12764 .52496 L
.12833 .52532 L
.12902 .52555 L
.12975 .52568 L
.13039 .52572 L
.13097 .52572 L
.13148 .52573 L
.13191 .5258 L
.13226 .52596 L
.13254 .52621 L
.1328 .52655 L
.13303 .52689 L
.13327 .52729 L
.13349 .52768 L
Mistroke
.13369 .52806 L
.13385 .52843 L
.13396 .52879 L
.134 .5291 L
.13395 .52936 L
.13382 .52952 L
.13361 .52957 L
.13333 .52956 L
.13301 .52951 L
.13268 .52943 L
.13236 .52939 L
.13209 .52947 L
.13189 .52974 L
.13177 .53018 L
.13173 .5308 L
.13178 .53158 L
.13191 .53248 L
.13209 .53349 L
.13232 .53439 L
.13256 .53534 L
.13277 .53628 L
.13298 .5372 L
.13314 .53809 L
.13331 .53873 L
.13347 .53936 L
.13362 .53986 L
.13375 .54028 L
.13388 .54067 L
.13404 .54111 L
.13426 .54167 L
.13454 .5424 L
.13492 .54332 L
.13538 .54429 L
.13592 .54543 L
.13652 .54672 L
.13717 .54816 L
.13782 .54954 L
.13837 .55081 L
.13891 .55205 L
.13937 .55305 L
.13982 .55393 L
.14026 .55467 L
.14069 .55524 L
.14113 .55565 L
.14158 .55592 L
.14205 .55612 L
.14254 .55626 L
.143 .55637 L
.14346 .55647 L
.1439 .55659 L
Mistroke
.14438 .55676 L
.14489 .55696 L
.14538 .55717 L
.14581 .55735 L
.14613 .55747 L
.1463 .55751 L
.14632 .55743 L
.14621 .55724 L
.146 .55695 L
.14571 .55663 L
.14538 .55629 L
.14503 .55598 L
.1447 .55575 L
.14438 .55564 L
.14409 .55568 L
.14384 .55592 L
.14367 .55644 L
.14358 .55726 L
.14358 .5584 L
.14365 .55974 L
.14376 .56129 L
.14392 .56312 L
.1441 .56523 L
.14431 .56716 L
.14453 .56942 L
.14477 .57141 L
.14504 .57347 L
.1453 .57553 L
.14557 .57717 L
.14584 .57866 L
.1461 .57996 L
.14632 .58102 L
.14652 .5818 L
.1467 .5824 L
.14689 .58281 L
.14707 .58308 L
.14724 .58325 L
.14739 .58336 L
.14747 .58341 L
.1475 .58338 L
.14748 .5833 L
.14743 .58319 L
.14737 .58307 L
.14734 .58298 L
.14734 .58297 L
.14739 .58305 L
.14751 .58322 L
.1477 .58348 L
.148 .58383 L
.14841 .58427 L
Mistroke
.14893 .58477 L
.14955 .58534 L
.15027 .58596 L
.15108 .58666 L
.15192 .58742 L
.15282 .5882 L
.15376 .58897 L
.15469 .5897 L
.15554 .59038 L
.15636 .59104 L
.15712 .59168 L
.1578 .5923 L
.15838 .59291 L
.15885 .59354 L
.15922 .59421 L
.1595 .59492 L
.15969 .5956 L
.1598 .59621 L
.15984 .5967 L
.1598 .59711 L
.15969 .59742 L
.15949 .5976 L
.15921 .59762 L
.15888 .59748 L
.15851 .59722 L
.15817 .59685 L
.15787 .59642 L
.15762 .59594 L
.15747 .59544 L
.15747 .59494 L
.15767 .5945 L
.15809 .59417 L
.15876 .59394 L
.15962 .59379 L
.16074 .5937 L
.16203 .59367 L
.16355 .59368 L
.16511 .59369 L
.16675 .59369 L
.16815 .59366 L
.1695 .59362 L
.17054 .59359 L
.17134 .59357 L
.17182 .59359 L
.17193 .59362 L
.17169 .59367 L
.17118 .59371 L
.17044 .59375 L
.16952 .59378 L
.1686 .59382 L
Mistroke
.16761 .59388 L
.16655 .59392 L
.16553 .59391 L
.16466 .5938 L
.16396 .59356 L
.16343 .59313 L
.16301 .5925 L
.16267 .59165 L
.16236 .59052 L
.16205 .58909 L
.16168 .58736 L
.16119 .58565 L
.16058 .58361 L
.15984 .58121 L
.15897 .5789 L
.15809 .5764 L
.15707 .57374 L
.15598 .5712 L
.1549 .56881 L
.1538 .56654 L
.15273 .56432 L
.15179 .56266 L
.15098 .56111 L
.1503 .55982 L
.14978 .55889 L
.14942 .55813 L
.14918 .55756 L
.14898 .55717 L
.14877 .55691 L
.1485 .55675 L
.1481 .55666 L
.14751 .55661 L
.1467 .55657 L
.14565 .5565 L
.14448 .55637 L
.14307 .55617 L
.14144 .5559 L
.13966 .55557 L
.13802 .55522 L
.13636 .55486 L
.13475 .55453 L
.13329 .55425 L
.13207 .554 L
.13112 .55379 L
.13039 .55356 L
.12989 .55328 L
.1296 .55289 L
.1295 .55244 L
.12958 .552 L
.12976 .55144 L
Mistroke
.13003 .55079 L
.13035 .55001 L
.13066 .54906 L
.13094 .54803 L
.1311 .54681 L
.1311 .54536 L
.13094 .54373 L
.13068 .54203 L
.13034 .54038 L
.12996 .53862 L
.12956 .53719 L
.12916 .53581 L
.12879 .53475 L
.12848 .53388 L
.12822 .53319 L
.12804 .53281 L
.12793 .53257 L
.12789 .53247 L
.12792 .53248 L
.12803 .53265 L
.12819 .53294 L
.12839 .5333 L
.12858 .53368 L
.12876 .53401 L
.12891 .53427 L
.12901 .53441 L
.12907 .53443 L
.12907 .53429 L
.12905 .53401 L
.12902 .53363 L
.129 .5332 L
.12901 .53276 L
.12902 .5323 L
.12904 .53186 L
.12906 .53144 L
.12908 .53102 L
.12914 .53061 L
.12928 .53026 L
.1295 .52999 L
.12972 .52985 L
.12988 .5298 L
.12994 .52983 L
.12986 .52989 L
.1296 .52995 L
.12902 .52997 L
.12805 .52988 L
.12672 .52968 L
.12504 .52936 L
.12299 .52895 L
.12101 .52847 L
Mistroke
.11853 .52794 L
.1159 .5274 L
.11321 .52686 L
.11041 .52633 L
.1077 .52584 L
.10474 .52538 L
.10239 .52497 L
.10015 .5246 L
.09785 .52426 L
.09582 .52393 L
.09386 .52362 L
.09199 .5233 L
.09027 .52297 L
.08881 .52265 L
.0878 .52233 L
.08656 .52201 L
.08561 .52167 L
.08467 .52128 L
.08374 .52084 L
.08287 .52038 L
.08207 .51992 L
.08133 .51945 L
.08064 .51896 L
.08002 .51842 L
.07945 .51783 L
.07891 .51722 L
.07826 .51655 L
.07757 .51576 L
.07687 .51485 L
.0762 .51394 L
.07561 .51304 L
.07513 .51218 L
.07478 .51142 L
.07458 .51079 L
.07452 .51026 L
.07459 .50985 L
.07477 .50955 L
.07502 .50935 L
.0753 .50922 L
.07561 .50913 L
.07592 .50904 L
.0762 .50892 L
.07645 .50874 L
.07669 .50848 L
.07693 .50816 L
.07717 .50776 L
.07741 .50731 L
.07765 .50687 L
.07789 .50644 L
.07813 .50602 L
Mistroke
.07836 .50561 L
.07859 .50525 L
.07883 .50496 L
.07907 .50477 L
.07933 .50465 L
.0796 .50461 L
.07984 .50463 L
.08005 .50469 L
.08021 .50476 L
Mfstroke
1 1 0 r
.008 w
.08429 .44729 Mdot
.016 w
.08429 .44729 m
.0843 .44718 L
s
1 .999 0 r
.008 w
.0843 .44718 Mdot
.016 w
.0843 .44718 m
.08432 .44697 L
s
.008 w
.08432 .44697 Mdot
.016 w
.08432 .44697 m
.08436 .44665 L
s
1 .998 0 r
.008 w
.08436 .44665 Mdot
.016 w
.08436 .44665 m
.08441 .44617 L
s
.008 w
.08441 .44617 Mdot
.016 w
.08441 .44617 m
.08449 .44552 L
s
.008 w
.08449 .44552 Mdot
.016 w
.08449 .44552 m
.08459 .44469 L
s
1 .997 0 r
.008 w
.08459 .44469 Mdot
.016 w
.08459 .44469 m
.08472 .44362 L
s
.008 w
.08472 .44362 Mdot
.016 w
.08472 .44362 m
.08489 .44231 L
s
1 .996 0 r
.008 w
.08489 .44231 Mdot
.016 w
.08489 .44231 m
.0851 .44082 L
s
.008 w
.0851 .44082 Mdot
.016 w
.0851 .44082 m
.08529 .43896 L
s
.008 w
.08529 .43896 Mdot
.016 w
.08529 .43896 m
.08547 .43699 L
s
1 .995 0 r
.008 w
.08547 .43699 Mdot
.016 w
.08547 .43699 m
.08569 .43471 L
s
.008 w
.08569 .43471 Mdot
.016 w
.08569 .43471 m
.08595 .43224 L
s
1 .994 0 r
.008 w
.08595 .43224 Mdot
.016 w
.08595 .43224 m
.08623 .42989 L
s
.008 w
.08623 .42989 Mdot
.016 w
.08623 .42989 m
.08648 .42702 L
s
.008 w
.08648 .42702 Mdot
.016 w
.08648 .42702 m
.08677 .4246 L
s
1 .993 0 r
.008 w
.08677 .4246 Mdot
.016 w
.08677 .4246 m
.08707 .42172 L
s
.008 w
.08707 .42172 Mdot
.016 w
.08707 .42172 m
.08739 .41908 L
s
.008 w
.08739 .41908 Mdot
.016 w
.08739 .41908 m
.08773 .41626 L
s
1 .992 0 r
.008 w
.08773 .41626 Mdot
.016 w
.08773 .41626 m
.08811 .41308 L
s
.008 w
.08811 .41308 Mdot
.016 w
.08811 .41308 m
.08852 .41061 L
s
1 .991 0 r
.008 w
.08852 .41061 Mdot
.016 w
.08852 .41061 m
.08894 .40799 L
s
.008 w
.08894 .40799 Mdot
.016 w
.08894 .40799 m
.08937 .40536 L
s
.008 w
.08937 .40536 Mdot
.016 w
.08937 .40536 m
.08979 .40269 L
s
1 .99 0 r
.008 w
.08979 .40269 Mdot
.016 w
.08979 .40269 m
.09022 .39994 L
s
.008 w
.09022 .39994 Mdot
.016 w
.09022 .39994 m
.09066 .39784 L
s
1 .989 0 r
.008 w
.09066 .39784 Mdot
.016 w
.09066 .39784 m
.09111 .3954 L
s
.008 w
.09111 .3954 Mdot
.016 w
.09111 .3954 m
.09157 .39316 L
s
.008 w
.09157 .39316 Mdot
.016 w
.09157 .39316 m
.09202 .39109 L
s
1 .988 0 r
.008 w
.09202 .39109 Mdot
.016 w
.09202 .39109 m
.09246 .38906 L
s
.008 w
.09246 .38906 Mdot
.016 w
.09246 .38906 m
.09289 .38734 L
s
1 .987 0 r
.008 w
.09289 .38734 Mdot
.016 w
.09289 .38734 m
.09331 .38572 L
s
.008 w
.09331 .38572 Mdot
.016 w
.09331 .38572 m
.0937 .38442 L
s
.008 w
.0937 .38442 Mdot
.016 w
.0937 .38442 m
.09406 .38331 L
s
1 .986 0 r
.008 w
.09406 .38331 Mdot
.016 w
.09406 .38331 m
.09438 .38245 L
s
.008 w
.09438 .38245 Mdot
.016 w
.09438 .38245 m
.09467 .38178 L
s
1 .985 0 r
.008 w
.09467 .38178 Mdot
.016 w
.09467 .38178 m
.09491 .38129 L
s
.008 w
.09491 .38129 Mdot
.016 w
.09491 .38129 m
.09511 .38097 L
s
.008 w
.09511 .38097 Mdot
.016 w
.09511 .38097 m
.09528 .38079 L
s
1 .984 0 r
.008 w
.09528 .38079 Mdot
.016 w
.09528 .38079 m
.09541 .38071 L
s
.008 w
.09541 .38071 Mdot
.016 w
.09541 .38071 m
.0955 .38072 L
s
1 .983 0 r
.008 w
.0955 .38072 Mdot
.016 w
.0955 .38072 m
.09555 .38079 L
s
.008 w
.09555 .38079 Mdot
.016 w
.09555 .38079 m
.09556 .38089 L
s
.008 w
.09556 .38089 Mdot
.016 w
.09556 .38089 m
.09555 .381 L
s
1 .982 0 r
.008 w
.09555 .381 Mdot
.016 w
.09555 .381 m
.09551 .38109 L
s
.008 w
.09551 .38109 Mdot
.016 w
.09551 .38109 m
.09546 .38114 L
s
1 .981 0 r
.008 w
.09546 .38114 Mdot
.016 w
.09546 .38114 m
.09543 .38116 L
s
.008 w
.09543 .38116 Mdot
.016 w
.09543 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
1 .98 0 r
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
1 .979 0 r
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
1 .978 0 r
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09542 .38116 L
s
.008 w
.09542 .38116 Mdot
.016 w
.09542 .38116 m
.09543 .38119 L
s
1 .977 0 r
.008 w
.09543 .38119 Mdot
.016 w
.09543 .38119 m
.09546 .38124 L
s
.008 w
.09546 .38124 Mdot
.016 w
.09546 .38124 m
.0955 .38131 L
s
1 .976 0 r
.008 w
.0955 .38131 Mdot
.016 w
.0955 .38131 m
.09554 .38137 L
s
.008 w
.09554 .38137 Mdot
.016 w
.09554 .38137 m
.09556 .38139 L
s
.008 w
.09556 .38139 Mdot
.016 w
.09556 .38139 m
.09554 .38137 L
s
1 .975 0 r
.008 w
.09554 .38137 Mdot
.016 w
.09554 .38137 m
.09548 .38127 L
s
.008 w
.09548 .38127 Mdot
.016 w
.09548 .38127 m
.09538 .3811 L
s
1 .974 0 r
.008 w
.09538 .3811 Mdot
.016 w
.09538 .3811 m
.09522 .38084 L
s
.008 w
.09522 .38084 Mdot
.016 w
.09522 .38084 m
.09501 .38049 L
s
.008 w
.09501 .38049 Mdot
.016 w
.09501 .38049 m
.09475 .38006 L
s
1 .973 0 r
.008 w
.09475 .38006 Mdot
.016 w
.09475 .38006 m
.09444 .37956 L
s
.008 w
.09444 .37956 Mdot
.016 w
.09444 .37956 m
.09413 .37903 L
s
1 .972 0 r
.008 w
.09413 .37903 Mdot
.016 w
.09413 .37903 m
.09386 .37858 L
s
.008 w
.09386 .37858 Mdot
.016 w
.09386 .37858 m
.09361 .37821 L
s
.008 w
.09361 .37821 Mdot
.016 w
.09361 .37821 m
.0934 .37791 L
s
1 .971 0 r
.008 w
.0934 .37791 Mdot
.016 w
.0934 .37791 m
.09326 .37768 L
s
.008 w
.09326 .37768 Mdot
.016 w
.09326 .37768 m
.09319 .37754 L
s
1 .97 0 r
.008 w
.09319 .37754 Mdot
.016 w
.09319 .37754 m
.09322 .3775 L
s
.008 w
.09322 .3775 Mdot
.016 w
.09322 .3775 m
.09334 .37756 L
s
.008 w
.09334 .37756 Mdot
.016 w
.09334 .37756 m
.09354 .37769 L
s
1 .969 0 r
.008 w
.09354 .37769 Mdot
.016 w
.09354 .37769 m
.09378 .37786 L
s
.008 w
.09378 .37786 Mdot
.016 w
.09378 .37786 m
.09407 .37805 L
s
.008 w
.09407 .37805 Mdot
.016 w
.09407 .37805 m
.09436 .37821 L
s
1 .968 0 r
.008 w
.09436 .37821 Mdot
.016 w
.09436 .37821 m
.09467 .37833 L
s
.008 w
.09467 .37833 Mdot
.016 w
.09467 .37833 m
.09495 .37835 L
s
1 .967 0 r
.008 w
.09495 .37835 Mdot
.016 w
.09495 .37835 m
.09518 .37826 L
s
.008 w
.09518 .37826 Mdot
.016 w
.09518 .37826 m
.09536 .37801 L
s
.008 w
.09536 .37801 Mdot
.016 w
.09536 .37801 m
.09548 .37761 L
s
1 .966 0 r
.008 w
.09548 .37761 Mdot
.016 w
.09548 .37761 m
.09555 .37708 L
s
.008 w
.09555 .37708 Mdot
.016 w
.09555 .37708 m
.09558 .37645 L
s
1 .965 0 r
.008 w
.09558 .37645 Mdot
.016 w
.09558 .37645 m
.09557 .37578 L
s
.008 w
.09557 .37578 Mdot
.016 w
.09557 .37578 m
.09554 .37511 L
s
.008 w
.09554 .37511 Mdot
.016 w
.09554 .37511 m
.0955 .37451 L
s
1 .964 0 r
.008 w
.0955 .37451 Mdot
.016 w
.0955 .37451 m
.09546 .37398 L
s
.008 w
.09546 .37398 Mdot
.016 w
.09546 .37398 m
.09545 .37354 L
s
1 .963 0 r
.008 w
.09545 .37354 Mdot
.016 w
.09545 .37354 m
.09545 .37319 L
s
.008 w
.09545 .37319 Mdot
.016 w
.09545 .37319 m
.09545 .37291 L
s
.008 w
.09545 .37291 Mdot
.016 w
.09545 .37291 m
.09545 .37269 L
s
1 .962 0 r
.008 w
.09545 .37269 Mdot
.016 w
.09545 .37269 m
.09545 .37253 L
s
.008 w
.09545 .37253 Mdot
.016 w
.09545 .37253 m
.09545 .37243 L
s
1 .961 0 r
.008 w
.09545 .37243 Mdot
.016 w
.09545 .37243 m
.09545 .37241 L
s
.008 w
.09545 .37241 Mdot
.016 w
.09545 .37241 m
.09545 .37243 L
s
.008 w
.09545 .37243 Mdot
.016 w
.09545 .37243 m
.09545 .3725 L
s
1 .96 0 r
.008 w
.09545 .3725 Mdot
.016 w
.09545 .3725 m
.09545 .37257 L
s
.008 w
.09545 .37257 Mdot
.016 w
.09545 .37257 m
.09545 .37262 L
s
1 .959 0 r
.008 w
.09545 .37262 Mdot
.016 w
.09545 .37262 m
.09545 .37265 L
s
.008 w
.09545 .37265 Mdot
.016 w
.09545 .37265 m
.09545 .37265 L
s
.008 w
.09545 .37265 Mdot
.016 w
.09545 .37265 m
.09544 .37265 L
s
1 .958 0 r
.008 w
.09544 .37265 Mdot
.016 w
.09544 .37265 m
.09541 .37267 L
s
.008 w
.09541 .37267 Mdot
.016 w
.09541 .37267 m
.09537 .37272 L
s
1 .957 0 r
.008 w
.09537 .37272 Mdot
.016 w
.09537 .37272 m
.09533 .37279 L
s
.008 w
.09533 .37279 Mdot
.016 w
.09533 .37279 m
.09531 .37285 L
s
.008 w
.09531 .37285 Mdot
.016 w
.09531 .37285 m
.09532 .37288 L
s
1 .956 0 r
.008 w
.09532 .37288 Mdot
.016 w
.09532 .37288 m
.09538 .37286 L
s
.008 w
.09538 .37286 Mdot
.016 w
.09538 .37286 m
.09548 .37277 L
s
.008 w
.09548 .37277 Mdot
.016 w
.09548 .37277 m
.09563 .3726 L
s
1 .955 0 r
.008 w
.09563 .3726 Mdot
.016 w
.09563 .3726 m
.09583 .37236 L
s
.008 w
.09583 .37236 Mdot
.016 w
.09583 .37236 m
.09606 .37204 L
s
1 .954 0 r
.008 w
.09606 .37204 Mdot
.016 w
.09606 .37204 m
.09631 .37166 L
s
.008 w
.09631 .37166 Mdot
.016 w
.09631 .37166 m
.09657 .37125 L
s
.008 w
.09657 .37125 Mdot
.016 w
.09657 .37125 m
.09684 .37082 L
s
1 .953 0 r
.008 w
.09684 .37082 Mdot
.016 w
.09684 .37082 m
.09709 .37039 L
s
.008 w
.09709 .37039 Mdot
.016 w
.09709 .37039 m
.09735 .36997 L
s
1 .952 0 r
.008 w
.09735 .36997 Mdot
.016 w
.09735 .36997 m
.09759 .36955 L
s
.008 w
.09759 .36955 Mdot
.016 w
.09759 .36955 m
.0978 .36916 L
s
.008 w
.0978 .36916 Mdot
.016 w
.0978 .36916 m
.09797 .36882 L
s
1 .951 0 r
.008 w
.09797 .36882 Mdot
.016 w
.09797 .36882 m
.09809 .36854 L
s
.008 w
.09809 .36854 Mdot
.016 w
.09809 .36854 m
.09815 .36835 L
s
1 .95 0 r
.008 w
.09815 .36835 Mdot
.016 w
.09815 .36835 m
.09817 .36824 L
s
.008 w
.09817 .36824 Mdot
.016 w
.09817 .36824 m
.09816 .36821 L
s
.008 w
.09816 .36821 Mdot
.016 w
.09816 .36821 m
.09812 .36823 L
s
1 .949 0 r
.008 w
.09812 .36823 Mdot
.016 w
.09812 .36823 m
.09808 .36829 L
s
.008 w
.09808 .36829 Mdot
.016 w
.09808 .36829 m
.09805 .36836 L
s
1 .948 0 r
.008 w
.09805 .36836 Mdot
.016 w
.09805 .36836 m
.09803 .36841 L
s
.008 w
.09803 .36841 Mdot
.016 w
.09803 .36841 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
1 .947 0 r
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
1 .946 0 r
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
1 .945 0 r
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
1 .944 0 r
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36844 L
s
.008 w
.09803 .36844 Mdot
.016 w
.09803 .36844 m
.09803 .36845 L
s
1 .943 0 r
.008 w
.09803 .36845 Mdot
.016 w
.09803 .36845 m
.09803 .36846 L
s
.008 w
.09803 .36846 Mdot
.016 w
.09803 .36846 m
.09803 .36849 L
s
.008 w
.09803 .36849 Mdot
.016 w
.09803 .36849 m
.09801 .36854 L
s
1 .942 0 r
.008 w
.09801 .36854 Mdot
.016 w
.09801 .36854 m
.09798 .36862 L
s
.008 w
.09798 .36862 Mdot
.016 w
.09798 .36862 m
.09793 .3687 L
s
1 .941 0 r
.008 w
.09793 .3687 Mdot
.016 w
.09793 .3687 m
.09789 .36875 L
s
.008 w
.09789 .36875 Mdot
.016 w
.09789 .36875 m
.09785 .36876 L
s
.008 w
.09785 .36876 Mdot
.016 w
.09785 .36876 m
.09783 .36871 L
s
1 .94 0 r
.008 w
.09783 .36871 Mdot
.016 w
.09783 .36871 m
.09784 .36856 L
s
.008 w
.09784 .36856 Mdot
.016 w
.09784 .36856 m
.09792 .3683 L
s
1 .939 0 r
.008 w
.09792 .3683 Mdot
.016 w
.09792 .3683 m
.09807 .3679 L
s
.008 w
.09807 .3679 Mdot
.016 w
.09807 .3679 m
.09829 .36737 L
s
.008 w
.09829 .36737 Mdot
.016 w
.09829 .36737 m
.09858 .36671 L
s
1 .938 0 r
.008 w
.09858 .36671 Mdot
.016 w
.09858 .36671 m
.09895 .36596 L
s
.008 w
.09895 .36596 Mdot
.016 w
.09895 .36596 m
.09939 .36509 L
s
1 .937 0 r
.008 w
.09939 .36509 Mdot
.016 w
.09939 .36509 m
.09989 .36413 L
s
.008 w
.09989 .36413 Mdot
.016 w
.09989 .36413 m
.10046 .36315 L
s
.008 w
.10046 .36315 Mdot
.016 w
.10046 .36315 m
.10108 .36212 L
s
1 .936 0 r
.008 w
.10108 .36212 Mdot
.016 w
.10108 .36212 m
.10175 .36107 L
s
.008 w
.10175 .36107 Mdot
.016 w
.10175 .36107 m
.1024 .36006 L
s
1 .935 0 r
.008 w
.1024 .36006 Mdot
.016 w
.1024 .36006 m
.10304 .35915 L
s
.008 w
.10304 .35915 Mdot
.016 w
.10304 .35915 m
.10364 .35833 L
s
.008 w
.10364 .35833 Mdot
.016 w
.10364 .35833 m
.10419 .35763 L
s
1 .934 0 r
.008 w
.10419 .35763 Mdot
.016 w
.10419 .35763 m
.10464 .35706 L
s
.008 w
.10464 .35706 Mdot
.016 w
.10464 .35706 m
.10501 .35662 L
s
1 .933 0 r
.008 w
.10501 .35662 Mdot
.016 w
.10501 .35662 m
.1053 .3563 L
s
.008 w
.1053 .3563 Mdot
.016 w
.1053 .3563 m
.10552 .35605 L
s
.008 w
.10552 .35605 Mdot
.016 w
.10552 .35605 m
.10567 .35588 L
s
1 .932 0 r
.008 w
.10567 .35588 Mdot
.016 w
.10567 .35588 m
.10578 .35577 L
s
.008 w
.10578 .35577 Mdot
.016 w
.10578 .35577 m
.10585 .3557 L
s
1 .931 0 r
.008 w
.10585 .3557 Mdot
.016 w
.10585 .3557 m
.10588 .35568 L
s
.008 w
.10588 .35568 Mdot
.016 w
.10588 .35568 m
.10588 .35569 L
s
.008 w
.10588 .35569 Mdot
.016 w
.10588 .35569 m
.10586 .3557 L
s
1 .93 0 r
.008 w
.10586 .3557 Mdot
.016 w
.10586 .3557 m
.10582 .35572 L
s
.008 w
.10582 .35572 Mdot
.016 w
.10582 .35572 m
.10578 .35575 L
s
.008 w
.10578 .35575 Mdot
.016 w
.10578 .35575 m
.10574 .35579 L
s
1 .929 0 r
.008 w
.10574 .35579 Mdot
.016 w
.10574 .35579 m
.10573 .35582 L
s
.008 w
.10573 .35582 Mdot
.016 w
.10573 .35582 m
.10573 .35583 L
s
1 .928 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .927 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .926 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .925 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .924 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .923 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .922 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .921 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .92 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .919 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .918 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
1 .917 0 r
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10573 .35583 L
s
.008 w
.10573 .35583 Mdot
.016 w
.10573 .35583 m
.10572 .35583 L
s
.008 w
.10572 .35583 Mdot
.016 w
.10572 .35583 m
.10571 .35583 L
s
1 .916 0 r
.008 w
.10571 .35583 Mdot
.016 w
.10571 .35583 m
.10567 .35583 L
s
.008 w
.10567 .35583 Mdot
.016 w
.10567 .35583 m
.10563 .35583 L
s
1 .915 0 r
.008 w
.10563 .35583 Mdot
.016 w
.10563 .35583 m
.10559 .35583 L
s
.008 w
.10559 .35583 Mdot
.016 w
.10559 .35583 m
.10555 .35583 L
s
.008 w
.10555 .35583 Mdot
.016 w
.10555 .35583 m
.10555 .35584 L
s
1 .914 0 r
.008 w
.10555 .35584 Mdot
.016 w
.10555 .35584 m
.1056 .35587 L
s
.008 w
.1056 .35587 Mdot
.016 w
.1056 .35587 m
.10571 .35591 L
s
1 .913 0 r
.008 w
.10571 .35591 Mdot
.016 w
.10571 .35591 m
.10587 .35594 L
s
.008 w
.10587 .35594 Mdot
.016 w
.10587 .35594 m
.10608 .35595 L
s
.008 w
.10608 .35595 Mdot
.016 w
.10608 .35595 m
.10634 .35596 L
s
1 .912 0 r
.008 w
.10634 .35596 Mdot
.016 w
.10634 .35596 m
.10665 .35595 L
s
.008 w
.10665 .35595 Mdot
.016 w
.10665 .35595 m
.10698 .35592 L
s
1 .911 0 r
.008 w
.10698 .35592 Mdot
.016 w
.10698 .35592 m
.1073 .35587 L
s
.008 w
.1073 .35587 Mdot
.016 w
.1073 .35587 m
.10761 .35579 L
s
.008 w
.10761 .35579 Mdot
.016 w
.10761 .35579 m
.1079 .35568 L
s
1 .91 0 r
.008 w
.1079 .35568 Mdot
.016 w
.1079 .35568 m
.10819 .35552 L
s
.008 w
.10819 .35552 Mdot
.016 w
.10819 .35552 m
.10844 .35528 L
s
1 .909 0 r
.008 w
.10844 .35528 Mdot
.016 w
.10844 .35528 m
.10868 .35493 L
s
.008 w
.10868 .35493 Mdot
.016 w
.10868 .35493 m
.10893 .35452 L
s
.008 w
.10893 .35452 Mdot
.016 w
.10893 .35452 m
.1092 .35402 L
s
1 .908 0 r
.008 w
.1092 .35402 Mdot
.016 w
.1092 .35402 m
.10954 .35341 L
s
.008 w
.10954 .35341 Mdot
.016 w
.10954 .35341 m
.11003 .35275 L
s
1 .907 0 r
.008 w
.11003 .35275 Mdot
.016 w
.11003 .35275 m
.11067 .35194 L
s
.008 w
.11067 .35194 Mdot
.016 w
.11067 .35194 m
.11139 .35099 L
s
.008 w
.11139 .35099 Mdot
.016 w
.11139 .35099 m
.11236 .34991 L
s
1 .906 0 r
.008 w
.11236 .34991 Mdot
.016 w
.11236 .34991 m
.11344 .34876 L
s
.008 w
.11344 .34876 Mdot
.016 w
.11344 .34876 m
.11477 .34752 L
s
.008 w
.11477 .34752 Mdot
.016 w
.11477 .34752 m
.11614 .34619 L
s
1 .905 0 r
.008 w
.11614 .34619 Mdot
.016 w
.11614 .34619 m
.11765 .34487 L
s
.008 w
.11765 .34487 Mdot
.016 w
.11765 .34487 m
.11913 .34359 L
s
1 .904 0 r
.008 w
.11913 .34359 Mdot
.016 w
.11913 .34359 m
.12057 .34249 L
s
.008 w
.12057 .34249 Mdot
.016 w
.12057 .34249 m
.12169 .3415 L
s
.008 w
.12169 .3415 Mdot
.016 w
.12169 .3415 m
.12292 .34054 L
s
1 .903 0 r
.008 w
.12292 .34054 Mdot
.016 w
.12292 .34054 m
.12389 .33976 L
s
.008 w
.12389 .33976 Mdot
.016 w
.12389 .33976 m
.12473 .339 L
s
1 .902 0 r
.008 w
.12473 .339 Mdot
.016 w
.12473 .339 m
.12541 .33824 L
s
.008 w
.12541 .33824 Mdot
.016 w
.12541 .33824 m
.12599 .33745 L
s
.008 w
.12599 .33745 Mdot
.016 w
.12599 .33745 m
.12652 .33661 L
s
1 .901 0 r
.008 w
.12652 .33661 Mdot
.016 w
.12652 .33661 m
.12703 .33564 L
s
.008 w
.12703 .33564 Mdot
.016 w
.12703 .33564 m
.12755 .3345 L
s
1 .9 0 r
.008 w
.12755 .3345 Mdot
.016 w
.12755 .3345 m
.12811 .33318 L
s
.008 w
.12811 .33318 Mdot
.016 w
.12811 .33318 m
.12868 .33184 L
s
.008 w
.12868 .33184 Mdot
.016 w
.12868 .33184 m
.12916 .33043 L
s
1 .899 0 r
.008 w
.12916 .33043 Mdot
.016 w
.12916 .33043 m
.12974 .32869 L
s
.008 w
.12974 .32869 Mdot
.016 w
.12974 .32869 m
.13035 .327 L
s
1 .898 0 r
.008 w
.13035 .327 Mdot
.016 w
.13035 .327 m
.13103 .32513 L
s
.008 w
.13103 .32513 Mdot
.016 w
.13103 .32513 m
.13162 .32316 L
s
.008 w
.13162 .32316 Mdot
.016 w
.13162 .32316 m
.13218 .32147 L
s
1 .897 0 r
.008 w
.13218 .32147 Mdot
.016 w
.13218 .32147 m
.1327 .31978 L
s
.008 w
.1327 .31978 Mdot
.016 w
.1327 .31978 m
.13317 .31813 L
s
1 .896 0 r
.008 w
.13317 .31813 Mdot
.016 w
.13317 .31813 m
.13362 .31658 L
s
.008 w
.13362 .31658 Mdot
.016 w
.13362 .31658 m
.13409 .3152 L
s
.008 w
.13409 .3152 Mdot
.016 w
.13409 .3152 m
.13461 .31387 L
s
1 .895 0 r
.008 w
.13461 .31387 Mdot
.016 w
.13461 .31387 m
.13522 .31256 L
s
.008 w
.13522 .31256 Mdot
.016 w
.13522 .31256 m
.13591 .31121 L
s
1 .894 0 r
.008 w
.13591 .31121 Mdot
.016 w
.13591 .31121 m
.1368 .30979 L
s
.008 w
.1368 .30979 Mdot
.016 w
.1368 .30979 m
.1378 .30854 L
s
.008 w
.1378 .30854 Mdot
.016 w
.1378 .30854 m
.13898 .3071 L
s
1 .893 0 r
.008 w
.13898 .3071 Mdot
.016 w
.13898 .3071 m
.1403 .30561 L
s
.008 w
.1403 .30561 Mdot
.016 w
.1403 .30561 m
.14177 .30415 L
s
.008 w
.14177 .30415 Mdot
.016 w
.14177 .30415 m
.14326 .30257 L
s
1 .892 0 r
.008 w
.14326 .30257 Mdot
.016 w
.14326 .30257 m
.14497 .30099 L
s
.008 w
.14497 .30099 Mdot
.016 w
.14497 .30099 m
.14637 .29946 L
s
1 .891 0 r
.008 w
.14637 .29946 Mdot
.016 w
.14637 .29946 m
.14776 .2979 L
s
.008 w
.14776 .2979 Mdot
.016 w
.14776 .2979 m
.14917 .29646 L
s
.008 w
.14917 .29646 Mdot
.016 w
.14917 .29646 m
.15041 .29505 L
s
1 .89 0 r
.008 w
.15041 .29505 Mdot
.016 w
.15041 .29505 m
.1516 .29378 L
s
.008 w
.1516 .29378 Mdot
.016 w
.1516 .29378 m
.15265 .29257 L
s
1 .889 0 r
.008 w
.15265 .29257 Mdot
.016 w
.15265 .29257 m
.15369 .29142 L
s
.008 w
.15369 .29142 Mdot
.016 w
.15369 .29142 m
.15456 .29038 L
s
.008 w
.15456 .29038 Mdot
.016 w
.15456 .29038 m
.15538 .28937 L
s
1 .888 0 r
.008 w
.15538 .28937 Mdot
.016 w
.15538 .28937 m
.15614 .28835 L
s
.008 w
.15614 .28835 Mdot
.016 w
.15614 .28835 m
.15684 .28729 L
s
1 .887 0 r
.008 w
.15684 .28729 Mdot
.016 w
.15684 .28729 m
.15751 .28625 L
s
.008 w
.15751 .28625 Mdot
.016 w
.15751 .28625 m
.15809 .28512 L
s
.008 w
.15809 .28512 Mdot
.016 w
.15809 .28512 m
.15865 .28386 L
s
1 .886 0 r
.008 w
.15865 .28386 Mdot
.016 w
.15865 .28386 m
.15917 .28252 L
s
.008 w
.15917 .28252 Mdot
.016 w
.15917 .28252 m
.15963 .28104 L
s
1 .885 0 r
.008 w
.15963 .28104 Mdot
.016 w
.15963 .28104 m
.16007 .2794 L
s
.008 w
.16007 .2794 Mdot
.016 w
.16007 .2794 m
.16051 .27789 L
s
.008 w
.16051 .27789 Mdot
.016 w
.16051 .27789 m
.16097 .2761 L
s
1 .884 0 r
.008 w
.16097 .2761 Mdot
.016 w
.16097 .2761 m
.16147 .27434 L
s
.008 w
.16147 .27434 Mdot
.016 w
.16147 .27434 m
.162 .27228 L
s
1 .883 0 r
.008 w
.162 .27228 Mdot
.016 w
.162 .27228 m
.16258 .27022 L
s
.008 w
.16258 .27022 Mdot
.016 w
.16258 .27022 m
.16323 .26821 L
s
.008 w
.16323 .26821 Mdot
.016 w
.16323 .26821 m
.16399 .26601 L
s
1 .882 0 r
.008 w
.16399 .26601 Mdot
.016 w
.16399 .26601 m
.16488 .26377 L
s
.008 w
.16488 .26377 Mdot
.016 w
.16488 .26377 m
.16579 .26185 L
s
1 .881 0 r
.008 w
.16579 .26185 Mdot
.016 w
.16579 .26185 m
.16684 .25997 L
s
.008 w
.16684 .25997 Mdot
.016 w
.16684 .25997 m
.1679 .25808 L
s
.008 w
.1679 .25808 Mdot
.016 w
.1679 .25808 m
.16907 .25626 L
s
1 .88 0 r
.008 w
.16907 .25626 Mdot
.016 w
.16907 .25626 m
.17032 .25464 L
s
.008 w
.17032 .25464 Mdot
.016 w
.17032 .25464 m
.17153 .25298 L
s
.008 w
.17153 .25298 Mdot
.016 w
.17153 .25298 m
.17285 .25128 L
s
1 .879 0 r
.008 w
.17285 .25128 Mdot
.016 w
.17285 .25128 m
.17427 .24969 L
s
.008 w
.17427 .24969 Mdot
.016 w
.17427 .24969 m
.17573 .24808 L
s
1 .878 0 r
.008 w
.17573 .24808 Mdot
.016 w
.17573 .24808 m
.17727 .24657 L
s
.008 w
.17727 .24657 Mdot
.016 w
.17727 .24657 m
.17872 .24508 L
s
.008 w
.17872 .24508 Mdot
.016 w
.17872 .24508 m
.18019 .24377 L
s
1 .877 0 r
.008 w
.18019 .24377 Mdot
.016 w
.18019 .24377 m
.18167 .24249 L
s
.008 w
.18167 .24249 Mdot
.016 w
.18167 .24249 m
.18304 .24128 L
s
1 .876 0 r
.008 w
.18304 .24128 Mdot
.016 w
.18304 .24128 m
.18438 .24023 L
s
.008 w
.18438 .24023 Mdot
.016 w
.18438 .24023 m
.18567 .23926 L
s
.008 w
.18567 .23926 Mdot
.016 w
.18567 .23926 m
.1868 .23845 L
s
1 .875 0 r
.008 w
.1868 .23845 Mdot
.016 w
.1868 .23845 m
.18786 .23776 L
s
.008 w
.18786 .23776 Mdot
.016 w
.18786 .23776 m
.18869 .23721 L
s
1 .874 0 r
.008 w
.18869 .23721 Mdot
.016 w
.18869 .23721 m
.18937 .23684 L
s
.008 w
.18937 .23684 Mdot
.016 w
.18937 .23684 m
.18987 .23665 L
s
.008 w
.18987 .23665 Mdot
.016 w
.18987 .23665 m
.19018 .23662 L
s
1 .873 0 r
.008 w
.19018 .23662 Mdot
.016 w
.19018 .23662 m
.19029 .23672 L
s
.008 w
.19029 .23672 Mdot
.016 w
.19029 .23672 m
.19023 .23689 L
s
1 .872 0 r
.008 w
.19023 .23689 Mdot
.016 w
.19023 .23689 m
.19006 .23708 L
s
.008 w
.19006 .23708 Mdot
.016 w
.19006 .23708 m
.18986 .23724 L
s
.008 w
.18986 .23724 Mdot
.016 w
.18986 .23724 m
.18969 .23729 L
s
1 .871 0 r
.008 w
.18969 .23729 Mdot
.016 w
.18969 .23729 m
.18961 .23716 L
s
.008 w
.18961 .23716 Mdot
.016 w
.18961 .23716 m
.18969 .23683 L
s
1 .87 0 r
.008 w
.18969 .23683 Mdot
.016 w
.18969 .23683 m
.18996 .23626 L
s
.008 w
.18996 .23626 Mdot
.016 w
.18996 .23626 m
.19043 .23545 L
s
.008 w
.19043 .23545 Mdot
.016 w
.19043 .23545 m
.1911 .23436 L
s
1 .869 0 r
.008 w
.1911 .23436 Mdot
.016 w
.1911 .23436 m
.19192 .23312 L
s
.008 w
.19192 .23312 Mdot
.016 w
.19192 .23312 m
.19287 .23158 L
s
.008 w
.19287 .23158 Mdot
.016 w
.19287 .23158 m
.19393 .22974 L
s
1 .868 0 r
.008 w
.19393 .22974 Mdot
.016 w
.19393 .22974 m
.19497 .22795 L
s
.008 w
.19497 .22795 Mdot
.016 w
.19497 .22795 m
.19612 .22588 L
s
1 .867 0 r
.008 w
.19612 .22588 Mdot
.016 w
.19612 .22588 m
.19748 .22343 L
s
.008 w
.19748 .22343 Mdot
.016 w
.19748 .22343 m
.19881 .22137 L
s
.008 w
.19881 .22137 Mdot
.016 w
.19881 .22137 m
.20025 .21928 L
s
1 .866 0 r
.008 w
.20025 .21928 Mdot
.016 w
.20025 .21928 m
.20156 .21716 L
s
.008 w
.20156 .21716 Mdot
.016 w
.20156 .21716 m
.20281 .21518 L
s
1 .865 0 r
.008 w
.20281 .21518 Mdot
.016 w
.20281 .21518 m
.20395 .2134 L
s
.008 w
.20395 .2134 Mdot
.016 w
.20395 .2134 m
.20494 .21202 L
s
.008 w
.20494 .21202 Mdot
.016 w
.20494 .21202 m
.20586 .21077 L
s
1 .864 0 r
.008 w
.20586 .21077 Mdot
.016 w
.20586 .21077 m
.20672 .2098 L
s
.008 w
.20672 .2098 Mdot
.016 w
.20672 .2098 m
.20757 .209 L
s
1 .863 0 r
.008 w
.20757 .209 Mdot
.016 w
.20757 .209 m
.20838 .20836 L
s
.008 w
.20838 .20836 Mdot
.016 w
.20838 .20836 m
.20915 .20784 L
s
.008 w
.20915 .20784 Mdot
.016 w
.20915 .20784 m
.20987 .20742 L
s
1 .862 0 r
.008 w
.20987 .20742 Mdot
.016 w
.20987 .20742 m
.21052 .2071 L
s
.008 w
.21052 .2071 Mdot
.016 w
.21052 .2071 m
.21111 .20686 L
s
1 .861 0 r
.008 w
.21111 .20686 Mdot
.016 w
.21111 .20686 m
.2117 .20669 L
s
.008 w
.2117 .20669 Mdot
.016 w
.2117 .20669 m
.21232 .20658 L
s
.008 w
.21232 .20658 Mdot
.016 w
.21232 .20658 m
.21302 .20651 L
s
1 .86 0 r
.008 w
.21302 .20651 Mdot
.016 w
.21302 .20651 m
.21384 .20643 L
s
.008 w
.21384 .20643 Mdot
.016 w
.21384 .20643 m
.2148 .20632 L
s
1 .859 0 r
.008 w
.2148 .20632 Mdot
.016 w
.2148 .20632 m
.21591 .20618 L
s
.008 w
.21591 .20618 Mdot
.016 w
.21591 .20618 m
.21715 .20606 L
s
.008 w
.21715 .20606 Mdot
.016 w
.21715 .20606 m
.21831 .20596 L
s
1 .858 0 r
.008 w
.21831 .20596 Mdot
.016 w
.21831 .20596 m
.21958 .2059 L
s
.008 w
.21958 .2059 Mdot
.016 w
.21958 .2059 m
.22064 .20588 L
s
1 .857 0 r
.008 w
.22064 .20588 Mdot
.016 w
.22064 .20588 m
.22178 .20591 L
s
.008 w
.22178 .20591 Mdot
.016 w
.22178 .20591 m
.22287 .20598 L
s
.008 w
.22287 .20598 Mdot
.016 w
.22287 .20598 m
.22376 .20611 L
s
1 .856 0 r
.008 w
.22376 .20611 Mdot
.016 w
.22376 .20611 m
.22455 .20629 L
s
.008 w
.22455 .20629 Mdot
.016 w
.22455 .20629 m
.2252 .20646 L
s
.008 w
.2252 .20646 Mdot
.016 w
.2252 .20646 m
.22566 .2066 L
s
1 .855 0 r
.008 w
.22566 .2066 Mdot
.016 w
.22566 .2066 m
.22595 .20666 L
s
.008 w
.22595 .20666 Mdot
.016 w
.22595 .20666 m
.22611 .20663 L
s
1 .854 0 r
.008 w
.22611 .20663 Mdot
.016 w
.22611 .20663 m
.22622 .20647 L
s
.008 w
.22622 .20647 Mdot
.016 w
.22622 .20647 m
.22637 .20616 L
s
.008 w
.22637 .20616 Mdot
.016 w
.22637 .20616 m
.22667 .20569 L
s
1 .853 0 r
.008 w
.22667 .20569 Mdot
.016 w
.22667 .20569 m
.22718 .20502 L
s
.008 w
.22718 .20502 Mdot
.016 w
.22718 .20502 m
.22795 .20414 L
s
1 .852 0 r
.008 w
.22795 .20414 Mdot
.016 w
.22795 .20414 m
.22902 .20304 L
s
.008 w
.22902 .20304 Mdot
.016 w
.22902 .20304 m
.23027 .20184 L
s
.008 w
.23027 .20184 Mdot
.016 w
.23027 .20184 m
.23183 .20029 L
s
1 .851 0 r
.008 w
.23183 .20029 Mdot
.016 w
.23183 .20029 m
.23354 .19865 L
s
.008 w
.23354 .19865 Mdot
.016 w
.23354 .19865 m
.23562 .19675 L
s
1 .85 0 r
.008 w
.23562 .19675 Mdot
.016 w
.23562 .19675 m
.23751 .19468 L
s
.008 w
.23751 .19468 Mdot
.016 w
.23751 .19468 m
.23967 .19255 L
s
.008 w
.23967 .19255 Mdot
.016 w
.23967 .19255 m
.24197 .19035 L
s
1 .849 0 r
.008 w
.24197 .19035 Mdot
.016 w
.24197 .19035 m
.24385 .18827 L
s
.008 w
.24385 .18827 Mdot
.016 w
.24385 .18827 m
.24582 .18624 L
s
1 .848 0 r
.008 w
.24582 .18624 Mdot
.016 w
.24582 .18624 m
.24764 .18437 L
s
.008 w
.24764 .18437 Mdot
.016 w
.24764 .18437 m
.24917 .18279 L
s
.008 w
.24917 .18279 Mdot
.016 w
.24917 .18279 m
.25055 .18135 L
s
1 .847 0 r
.008 w
.25055 .18135 Mdot
.016 w
.25055 .18135 m
.25172 .18007 L
s
.008 w
.25172 .18007 Mdot
.016 w
.25172 .18007 m
.25268 .17905 L
s
1 .846 0 r
.008 w
.25268 .17905 Mdot
.016 w
.25268 .17905 m
.2535 .17823 L
s
.008 w
.2535 .17823 Mdot
.016 w
.2535 .17823 m
.2542 .17762 L
s
.008 w
.2542 .17762 Mdot
.016 w
.2542 .17762 m
.25482 .17724 L
s
1 .845 0 r
.008 w
.25482 .17724 Mdot
.016 w
.25482 .17724 m
.2554 .17704 L
s
.008 w
.2554 .17704 Mdot
.016 w
.2554 .17704 m
.25596 .17699 L
s
1 .844 0 r
.008 w
.25596 .17699 Mdot
.016 w
.25596 .17699 m
.25655 .17703 L
s
.008 w
.25655 .17703 Mdot
.016 w
.25655 .17703 m
.25716 .17714 L
s
.008 w
.25716 .17714 Mdot
.016 w
.25716 .17714 m
.25782 .17727 L
s
1 .843 0 r
.008 w
.25782 .17727 Mdot
.016 w
.25782 .17727 m
.25848 .17739 L
s
.008 w
.25848 .17739 Mdot
.016 w
.25848 .17739 m
.2591 .1775 L
s
.008 w
.2591 .1775 Mdot
.016 w
.2591 .1775 m
.25968 .1776 L
s
1 .842 0 r
.008 w
.25968 .1776 Mdot
.016 w
.25968 .1776 m
.26023 .17767 L
s
.008 w
.26023 .17767 Mdot
.016 w
.26023 .17767 m
.26073 .17769 L
s
1 .841 0 r
.008 w
.26073 .17769 Mdot
.016 w
.26073 .17769 m
.26118 .17769 L
s
.008 w
.26118 .17769 Mdot
.016 w
.26118 .17769 m
.26158 .17765 L
s
.008 w
.26158 .17765 Mdot
.016 w
.26158 .17765 m
.26192 .17759 L
s
1 .84 0 r
.008 w
.26192 .17759 Mdot
.016 w
.26192 .17759 m
.26219 .17752 L
s
.008 w
.26219 .17752 Mdot
.016 w
.26219 .17752 m
.26243 .17746 L
s
1 .839 0 r
.008 w
.26243 .17746 Mdot
.016 w
.26243 .17746 m
.26263 .17741 L
s
.008 w
.26263 .17741 Mdot
.016 w
.26263 .17741 m
.26281 .17738 L
s
.008 w
.26281 .17738 Mdot
.016 w
.26281 .17738 m
.26299 .17739 L
s
1 .838 0 r
.008 w
.26299 .17739 Mdot
.016 w
.26299 .17739 m
.26318 .17741 L
s
.008 w
.26318 .17741 Mdot
.016 w
.26318 .17741 m
.26336 .1776 L
s
1 .837 0 r
.008 w
.26336 .1776 Mdot
.016 w
.26336 .1776 m
.26357 .17755 L
s
.008 w
.26357 .17755 Mdot
.016 w
.26357 .17755 m
.2638 .17745 L
s
.008 w
.2638 .17745 Mdot
.016 w
.2638 .17745 m
.26401 .17733 L
s
1 .836 0 r
.008 w
.26401 .17733 Mdot
.016 w
.26401 .17733 m
.2642 .17719 L
s
.008 w
.2642 .17719 Mdot
.016 w
.2642 .17719 m
.26435 .17706 L
s
1 .835 0 r
.008 w
.26435 .17706 Mdot
.016 w
.26435 .17706 m
.26444 .17692 L
s
.008 w
.26444 .17692 Mdot
.016 w
.26444 .17692 m
.26448 .17677 L
s
.008 w
.26448 .17677 Mdot
.016 w
.26448 .17677 m
.26445 .17658 L
s
1 .834 0 r
.008 w
.26445 .17658 Mdot
.016 w
.26445 .17658 m
.2644 .17638 L
s
.008 w
.2644 .17638 Mdot
.016 w
.2644 .17638 m
.26433 .17613 L
s
1 .833 0 r
.008 w
.26433 .17613 Mdot
.016 w
.26433 .17613 m
.26428 .17588 L
s
.008 w
.26428 .17588 Mdot
.016 w
.26428 .17588 m
.26426 .1756 L
s
.008 w
.26426 .1756 Mdot
.016 w
.26426 .1756 m
.2643 .17527 L
s
1 .832 0 r
.008 w
.2643 .17527 Mdot
.016 w
.2643 .17527 m
.26442 .17498 L
s
.008 w
.26442 .17498 Mdot
.016 w
.26442 .17498 m
.26459 .17471 L
s
1 .831 0 r
.008 w
.26459 .17471 Mdot
.016 w
.26459 .17471 m
.26482 .17449 L
s
.008 w
.26482 .17449 Mdot
.016 w
.26482 .17449 m
.26509 .17424 L
s
.008 w
.26509 .17424 Mdot
.016 w
.26509 .17424 m
.2654 .17398 L
s
1 .83 0 r
.008 w
.2654 .17398 Mdot
.016 w
.2654 .17398 m
.26574 .17371 L
s
.008 w
.26574 .17371 Mdot
.016 w
.26574 .17371 m
.26614 .17343 L
s
.008 w
.26614 .17343 Mdot
.016 w
.26614 .17343 m
.26659 .17316 L
s
1 .829 0 r
.008 w
.26659 .17316 Mdot
.016 w
.26659 .17316 m
.26711 .17289 L
s
.008 w
.26711 .17289 Mdot
.016 w
.26711 .17289 m
.26769 .17262 L
s
1 .828 0 r
.008 w
.26769 .17262 Mdot
.016 w
.26769 .17262 m
.26835 .17234 L
s
.008 w
.26835 .17234 Mdot
.016 w
.26835 .17234 m
.26908 .17205 L
s
.008 w
.26908 .17205 Mdot
.016 w
.26908 .17205 m
.2699 .17175 L
s
1 .827 0 r
.008 w
.2699 .17175 Mdot
.016 w
.2699 .17175 m
.27079 .17141 L
s
.008 w
.27079 .17141 Mdot
.016 w
.27079 .17141 m
.27171 .17102 L
s
1 .826 0 r
.008 w
.27171 .17102 Mdot
.016 w
.27171 .17102 m
.27271 .17058 L
s
.008 w
.27271 .17058 Mdot
.016 w
.27271 .17058 m
.27375 .17014 L
s
.008 w
.27375 .17014 Mdot
.016 w
.27375 .17014 m
.27486 .16972 L
s
1 .825 0 r
.008 w
.27486 .16972 Mdot
.016 w
.27486 .16972 m
.27599 .16934 L
s
.008 w
.27599 .16934 Mdot
.016 w
.27599 .16934 m
.27713 .16897 L
s
1 .824 0 r
.008 w
.27713 .16897 Mdot
.016 w
.27713 .16897 m
.27823 .16863 L
s
.008 w
.27823 .16863 Mdot
.016 w
.27823 .16863 m
.27929 .16832 L
s
.008 w
.27929 .16832 Mdot
.016 w
.27929 .16832 m
.28021 .16808 L
s
1 .823 0 r
.008 w
.28021 .16808 Mdot
.016 w
.28021 .16808 m
.28101 .16791 L
s
.008 w
.28101 .16791 Mdot
.016 w
.28101 .16791 m
.28164 .16783 L
s
1 .822 0 r
.008 w
.28164 .16783 Mdot
.016 w
.28164 .16783 m
.28213 .1678 L
s
.008 w
.28213 .1678 Mdot
.016 w
.28213 .1678 m
.2825 .16778 L
s
.008 w
.2825 .16778 Mdot
.016 w
.2825 .16778 m
.28282 .16773 L
s
1 .821 0 r
.008 w
.28282 .16773 Mdot
.016 w
.28282 .16773 m
.2831 .16761 L
s
.008 w
.2831 .16761 Mdot
.016 w
.2831 .16761 m
.2834 .16739 L
s
1 .82 0 r
.008 w
.2834 .16739 Mdot
.016 w
.2834 .16739 m
.28371 .16704 L
s
.008 w
.28371 .16704 Mdot
.016 w
.28371 .16704 m
.28406 .16656 L
s
.008 w
.28406 .16656 Mdot
.016 w
.28406 .16656 m
.28443 .166 L
s
1 .819 0 r
.008 w
.28443 .166 Mdot
.016 w
.28443 .166 m
.28484 .16538 L
s
.008 w
.28484 .16538 Mdot
.016 w
.28484 .16538 m
.28527 .16479 L
s
.008 w
.28527 .16479 Mdot
.016 w
.28527 .16479 m
.28567 .16418 L
s
1 .818 0 r
.008 w
.28567 .16418 Mdot
.016 w
.28567 .16418 m
.28606 .16357 L
s
.008 w
.28606 .16357 Mdot
.016 w
.28606 .16357 m
.28641 .16305 L
s
1 .817 0 r
.008 w
.28641 .16305 Mdot
.016 w
.28641 .16305 m
.28674 .1626 L
s
.008 w
.28674 .1626 Mdot
.016 w
.28674 .1626 m
.28704 .16222 L
s
.008 w
.28704 .16222 Mdot
.016 w
.28704 .16222 m
.28733 .16193 L
s
1 .816 0 r
.008 w
.28733 .16193 Mdot
.016 w
.28733 .16193 m
.28763 .16173 L
s
.008 w
.28763 .16173 Mdot
.016 w
.28763 .16173 m
.28797 .16159 L
s
1 .815 0 r
.008 w
.28797 .16159 Mdot
.016 w
.28797 .16159 m
.28838 .16146 L
s
.008 w
.28838 .16146 Mdot
.016 w
.28838 .16146 m
.28888 .1613 L
s
.008 w
.28888 .1613 Mdot
.016 w
.28888 .1613 m
.28949 .16107 L
s
1 .814 0 r
.008 w
.28949 .16107 Mdot
.016 w
.28949 .16107 m
.29027 .16073 L
s
.008 w
.29027 .16073 Mdot
.016 w
.29027 .16073 m
.29119 .16027 L
s
1 .813 0 r
.008 w
.29119 .16027 Mdot
.016 w
.29119 .16027 m
.29234 .15969 L
s
.008 w
.29234 .15969 Mdot
.016 w
.29234 .15969 m
.29363 .15904 L
s
.008 w
.29363 .15904 Mdot
.016 w
.29363 .15904 m
.29508 .15829 L
s
1 .812 0 r
.008 w
.29508 .15829 Mdot
.016 w
.29508 .15829 m
.29673 .15751 L
s
.008 w
.29673 .15751 Mdot
.016 w
.29673 .15751 m
.29829 .15671 L
s
1 .811 0 r
.008 w
.29829 .15671 Mdot
.016 w
.29829 .15671 m
.2999 .15592 L
s
.008 w
.2999 .15592 Mdot
.016 w
.2999 .15592 m
.30149 .15522 L
s
.008 w
.30149 .15522 Mdot
.016 w
.30149 .15522 m
.30304 .15456 L
s
1 .81 0 r
.008 w
.30304 .15456 Mdot
.016 w
.30304 .15456 m
.30451 .15396 L
s
.008 w
.30451 .15396 Mdot
.016 w
.30451 .15396 m
.30593 .15339 L
s
1 .809 0 r
.008 w
.30593 .15339 Mdot
.016 w
.30593 .15339 m
.30734 .15286 L
s
.008 w
.30734 .15286 Mdot
.016 w
.30734 .15286 m
.30871 .15233 L
s
.008 w
.30871 .15233 Mdot
.016 w
.30871 .15233 m
.31011 .15178 L
s
1 .808 0 r
.008 w
.31011 .15178 Mdot
.016 w
.31011 .15178 m
.31151 .15115 L
s
.008 w
.31151 .15115 Mdot
.016 w
.31151 .15115 m
.31295 .15039 L
s
1 .807 0 r
.008 w
.31295 .15039 Mdot
.016 w
.31295 .15039 m
.31441 .14949 L
s
.008 w
.31441 .14949 Mdot
.016 w
.31441 .14949 m
.31575 .14854 L
s
.008 w
.31575 .14854 Mdot
.016 w
.31575 .14854 m
.31712 .14741 L
s
1 .806 0 r
.008 w
.31712 .14741 Mdot
.016 w
.31712 .14741 m
.31839 .1461 L
s
.008 w
.31839 .1461 Mdot
.016 w
.31839 .1461 m
.31963 .14476 L
s
.008 w
.31963 .14476 Mdot
.016 w
.31963 .14476 m
.32086 .14333 L
s
1 .805 0 r
.008 w
.32086 .14333 Mdot
.016 w
.32086 .14333 m
.32204 .14194 L
s
.008 w
.32204 .14194 Mdot
.016 w
.32204 .14194 m
.32322 .14049 L
s
1 .804 0 r
.008 w
.32322 .14049 Mdot
.016 w
.32322 .14049 m
.32441 .13912 L
s
.008 w
.32441 .13912 Mdot
.016 w
.32441 .13912 m
.32557 .13782 L
s
.008 w
.32557 .13782 Mdot
.016 w
.32557 .13782 m
.3268 .13648 L
s
1 .803 0 r
.008 w
.3268 .13648 Mdot
.016 w
.3268 .13648 m
.32809 .13536 L
s
.008 w
.32809 .13536 Mdot
.016 w
.32809 .13536 m
.32955 .13427 L
s
1 .802 0 r
.008 w
.32955 .13427 Mdot
.016 w
.32955 .13427 m
.33115 .13321 L
s
.008 w
.33115 .13321 Mdot
.016 w
.33115 .13321 m
.33301 .13215 L
s
.008 w
.33301 .13215 Mdot
.016 w
.33301 .13215 m
.33497 .13116 L
s
1 .801 0 r
.008 w
.33497 .13116 Mdot
.016 w
.33497 .13116 m
.33703 .13014 L
s
.008 w
.33703 .13014 Mdot
.016 w
.33703 .13014 m
.33929 .12916 L
s
1 .8 0 r
.008 w
.33929 .12916 Mdot
.016 w
.33929 .12916 m
.34171 .12818 L
s
.008 w
.34171 .12818 Mdot
.016 w
.34171 .12818 m
.34402 .12719 L
s
.008 w
.34402 .12719 Mdot
.016 w
.34402 .12719 m
.34627 .12621 L
s
1 .799 0 r
.008 w
.34627 .12621 Mdot
.016 w
.34627 .12621 m
.34837 .12532 L
s
.008 w
.34837 .12532 Mdot
.016 w
.34837 .12532 m
.35013 .12448 L
s
1 .798 0 r
.008 w
.35013 .12448 Mdot
.016 w
.35013 .12448 m
.35198 .12374 L
s
.008 w
.35198 .12374 Mdot
.016 w
.35198 .12374 m
.35372 .12316 L
s
.008 w
.35372 .12316 Mdot
.016 w
.35372 .12316 m
.35535 .12274 L
s
1 .797 0 r
.008 w
.35535 .12274 Mdot
.016 w
.35535 .12274 m
.357 .1225 L
s
.008 w
.357 .1225 Mdot
.016 w
.357 .1225 m
.35864 .12241 L
s
1 .796 0 r
.008 w
.35864 .12241 Mdot
.016 w
.35864 .12241 m
.36036 .12245 L
s
.008 w
.36036 .12245 Mdot
.016 w
.36036 .12245 m
.3621 .1226 L
s
.008 w
.3621 .1226 Mdot
.016 w
.3621 .1226 m
.36373 .12282 L
s
1 .795 0 r
.008 w
.36373 .12282 Mdot
.016 w
.36373 .12282 m
.36507 .12309 L
s
.008 w
.36507 .12309 Mdot
.016 w
.36507 .12309 m
.36639 .12339 L
s
1 .794 0 r
.008 w
.36639 .12339 Mdot
.016 w
.36639 .12339 m
.36752 .1237 L
s
.008 w
.36752 .1237 Mdot
.016 w
.36752 .1237 m
.36866 .12398 L
s
.008 w
.36866 .12398 Mdot
.016 w
.36866 .12398 m
.3698 .12422 L
s
1 .793 0 r
.008 w
.3698 .12422 Mdot
.016 w
.3698 .12422 m
.37083 .12441 L
s
.008 w
.37083 .12441 Mdot
.016 w
.37083 .12441 m
.37162 .12454 L
s
.008 w
.37162 .12454 Mdot
.016 w
.37162 .12454 m
.37213 .12461 L
s
1 .792 0 r
.008 w
.37213 .12461 Mdot
.016 w
.37213 .12461 m
.3724 .12465 L
s
.008 w
.3724 .12465 Mdot
.016 w
.3724 .12465 m
.37248 .12466 L
s
1 .791 0 r
.008 w
.37248 .12466 Mdot
.016 w
.37248 .12466 m
.37239 .12466 L
s
.008 w
.37239 .12466 Mdot
.016 w
.37239 .12466 m
.37215 .12465 L
s
.008 w
.37215 .12465 Mdot
.016 w
.37215 .12465 m
.37187 .12464 L
s
1 .79 0 r
.008 w
.37187 .12464 Mdot
.016 w
.37187 .12464 m
.37164 .12464 L
s
.008 w
.37164 .12464 Mdot
.016 w
.37164 .12464 m
.37149 .12464 L
s
1 .789 0 r
.008 w
.37149 .12464 Mdot
.016 w
.37149 .12464 m
.37144 .12464 L
s
.008 w
.37144 .12464 Mdot
.016 w
.37144 .12464 m
.37152 .12462 L
s
.008 w
.37152 .12462 Mdot
.016 w
.37152 .12462 m
.37174 .12455 L
s
1 .788 0 r
.008 w
.37174 .12455 Mdot
.016 w
.37174 .12455 m
.37215 .1244 L
s
.008 w
.37215 .1244 Mdot
.016 w
.37215 .1244 m
.37273 .12415 L
s
1 .787 0 r
.008 w
.37273 .12415 Mdot
.016 w
.37273 .12415 m
.37349 .12377 L
s
.008 w
.37349 .12377 Mdot
.016 w
.37349 .12377 m
.37441 .12326 L
s
.008 w
.37441 .12326 Mdot
.016 w
.37441 .12326 m
.37547 .12263 L
s
1 .786 0 r
.008 w
.37547 .12263 Mdot
.016 w
.37547 .12263 m
.37653 .12189 L
s
.008 w
.37653 .12189 Mdot
.016 w
.37653 .12189 m
.37768 .12106 L
s
1 .785 0 r
.008 w
.37768 .12106 Mdot
.016 w
.37768 .12106 m
.37893 .12018 L
s
.008 w
.37893 .12018 Mdot
.016 w
.37893 .12018 m
.38029 .11935 L
s
.008 w
.38029 .11935 Mdot
.016 w
.38029 .11935 m
.38158 .11845 L
s
1 .784 0 r
.008 w
.38158 .11845 Mdot
.016 w
.38158 .11845 m
.3829 .11751 L
s
.008 w
.3829 .11751 Mdot
.016 w
.3829 .11751 m
.38423 .11669 L
s
1 .783 0 r
.008 w
.38423 .11669 Mdot
.016 w
.38423 .11669 m
.38549 .1159 L
s
.008 w
.38549 .1159 Mdot
.016 w
.38549 .1159 m
.38673 .11518 L
s
.008 w
.38673 .11518 Mdot
.016 w
.38673 .11518 m
.38794 .11455 L
s
1 .782 0 r
.008 w
.38794 .11455 Mdot
.016 w
.38794 .11455 m
.38922 .11403 L
s
.008 w
.38922 .11403 Mdot
.016 w
.38922 .11403 m
.39063 .11362 L
s
1 .781 0 r
.008 w
.39063 .11362 Mdot
.016 w
.39063 .11362 m
.39215 .11334 L
s
.008 w
.39215 .11334 Mdot
.016 w
.39215 .11334 m
.39379 .11315 L
s
.008 w
.39379 .11315 Mdot
.016 w
.39379 .11315 m
.39563 .11304 L
s
1 .78 0 r
.008 w
.39563 .11304 Mdot
.016 w
.39563 .11304 m
.39765 .11298 L
s
.008 w
.39765 .11298 Mdot
.016 w
.39765 .11298 m
.39964 .11294 L
s
.008 w
.39964 .11294 Mdot
.016 w
.39964 .11294 m
.40168 .11291 L
s
1 .779 0 r
.008 w
.40168 .11291 Mdot
.016 w
.40168 .11291 m
.40377 .1129 L
s
.008 w
.40377 .1129 Mdot
.016 w
.40377 .1129 m
.40572 .1129 L
s
1 .778 0 r
.008 w
.40572 .1129 Mdot
.016 w
.40572 .1129 m
.40759 .11295 L
s
.008 w
.40759 .11295 Mdot
.016 w
.40759 .11295 m
.40932 .113 L
s
.008 w
.40932 .113 Mdot
.016 w
.40932 .113 m
.41083 .11309 L
s
1 .777 0 r
.008 w
.41083 .11309 Mdot
.016 w
.41083 .11309 m
.41223 .11317 L
s
.008 w
.41223 .11317 Mdot
.016 w
.41223 .11317 m
.41344 .11325 L
s
1 .776 0 r
.008 w
.41344 .11325 Mdot
.016 w
.41344 .11325 m
.41439 .11331 L
s
.008 w
.41439 .11331 Mdot
.016 w
.41439 .11331 m
.41502 .11336 L
s
.008 w
.41502 .11336 Mdot
.016 w
.41502 .11336 m
.41534 .11339 L
s
1 .775 0 r
.008 w
.41534 .11339 Mdot
.016 w
.41534 .11339 m
.41535 .11341 L
s
.008 w
.41535 .11341 Mdot
.016 w
.41535 .11341 m
.41509 .11342 L
s
1 .774 0 r
.008 w
.41509 .11342 Mdot
.016 w
.41509 .11342 m
.41462 .11342 L
s
.008 w
.41462 .11342 Mdot
.016 w
.41462 .11342 m
.41401 .11341 L
s
.008 w
.41401 .11341 Mdot
.016 w
.41401 .11341 m
.41332 .11338 L
s
1 .773 0 r
.008 w
.41332 .11338 Mdot
.016 w
.41332 .11338 m
.41259 .11335 L
s
.008 w
.41259 .11335 Mdot
.016 w
.41259 .11335 m
.41187 .11333 L
s
1 .772 0 r
.008 w
.41187 .11333 Mdot
.016 w
.41187 .11333 m
.41115 .1133 L
s
.008 w
.41115 .1133 Mdot
.016 w
.41115 .1133 m
.41044 .11328 L
s
.008 w
.41044 .11328 Mdot
.016 w
.41044 .11328 m
.40976 .11327 L
s
1 .771 0 r
.008 w
.40976 .11327 Mdot
.016 w
.40976 .11327 m
.40915 .11325 L
s
.008 w
.40915 .11325 Mdot
.016 w
.40915 .11325 m
.40868 .11324 L
s
1 .77 0 r
.008 w
.40868 .11324 Mdot
.016 w
.40868 .11324 m
.40836 .11323 L
s
.008 w
.40836 .11323 Mdot
.016 w
.40836 .11323 m
.40818 .11323 L
s
.008 w
.40818 .11323 Mdot
.016 w
.40818 .11323 m
.40812 .11322 L
s
1 .769 0 r
.008 w
.40812 .11322 Mdot
.016 w
.40812 .11322 m
.40815 .11323 L
s
.008 w
.40815 .11323 Mdot
.016 w
.40815 .11323 m
.40825 .11323 L
s
.008 w
.40825 .11323 Mdot
.016 w
.40825 .11323 m
.40836 .11323 L
s
1 .768 0 r
.008 w
.40836 .11323 Mdot
.016 w
.40836 .11323 m
.40843 .11321 L
s
.008 w
.40843 .11321 Mdot
.016 w
.40843 .11321 m
.40843 .11317 L
s
1 .767 0 r
.008 w
.40843 .11317 Mdot
.016 w
.40843 .11317 m
.40838 .11309 L
s
.008 w
.40838 .11309 Mdot
.016 w
.40838 .11309 m
.40831 .11299 L
s
.008 w
.40831 .11299 Mdot
.016 w
.40831 .11299 m
.40825 .11292 L
s
1 .766 0 r
.008 w
.40825 .11292 Mdot
.016 w
.40825 .11292 m
.40825 .11288 L
s
.008 w
.40825 .11288 Mdot
.016 w
.40825 .11288 m
.40831 .11291 L
s
1 .765 0 r
.008 w
.40831 .11291 Mdot
.016 w
.40831 .11291 m
.40845 .11302 L
s
.008 w
.40845 .11302 Mdot
.016 w
.40845 .11302 m
.40868 .11325 L
s
.008 w
.40868 .11325 Mdot
.016 w
.40868 .11325 m
.40899 .11364 L
s
1 .764 0 r
.008 w
.40899 .11364 Mdot
.016 w
.40899 .11364 m
.40936 .11418 L
s
.008 w
.40936 .11418 Mdot
.016 w
.40936 .11418 m
.40979 .11485 L
s
1 .763 0 r
.008 w
.40979 .11485 Mdot
.016 w
.40979 .11485 m
.41025 .11567 L
s
.008 w
.41025 .11567 Mdot
.016 w
.41025 .11567 m
.41071 .11654 L
s
.008 w
.41071 .11654 Mdot
.016 w
.41071 .11654 m
.41119 .11753 L
s
1 .762 0 r
.008 w
.41119 .11753 Mdot
.016 w
.41119 .11753 m
.41167 .11852 L
s
.008 w
.41167 .11852 Mdot
.016 w
.41167 .11852 m
.41214 .11952 L
s
1 .761 0 r
.008 w
.41214 .11952 Mdot
.016 w
.41214 .11952 m
.41257 .12048 L
s
.008 w
.41257 .12048 Mdot
.016 w
.41257 .12048 m
.41293 .12128 L
s
.008 w
.41293 .12128 Mdot
.016 w
.41293 .12128 m
.4132 .12184 L
s
1 .76 0 r
.008 w
.4132 .12184 Mdot
.016 w
.4132 .12184 m
.41335 .12217 L
s
.008 w
.41335 .12217 Mdot
.016 w
.41335 .12217 m
.41338 .12227 L
s
1 .759 0 r
.008 w
.41338 .12227 Mdot
.016 w
.41338 .12227 m
.41329 .12214 L
s
.008 w
.41329 .12214 Mdot
.016 w
.41329 .12214 m
.41312 .12177 L
s
.008 w
.41312 .12177 Mdot
.016 w
.41312 .12177 m
.41291 .12119 L
s
1 .758 0 r
.008 w
.41291 .12119 Mdot
.016 w
.41291 .12119 m
.4127 .12053 L
s
.008 w
.4127 .12053 Mdot
.016 w
.4127 .12053 m
.41252 .11974 L
s
1 .757 0 r
.008 w
.41252 .11974 Mdot
.016 w
.41252 .11974 m
.41237 .11893 L
s
.008 w
.41237 .11893 Mdot
.016 w
.41237 .11893 m
.41223 .1181 L
s
.008 w
.41223 .1181 Mdot
.016 w
.41223 .1181 m
.41207 .11736 L
s
1 .756 0 r
.008 w
.41207 .11736 Mdot
.016 w
.41207 .11736 m
.41187 .11667 L
s
.008 w
.41187 .11667 Mdot
.016 w
.41187 .11667 m
.4116 .11605 L
s
.008 w
.4116 .11605 Mdot
.016 w
.4116 .11605 m
.41123 .11555 L
s
1 .755 0 r
.008 w
.41123 .11555 Mdot
.016 w
.41123 .11555 m
.41073 .11516 L
s
.008 w
.41073 .11516 Mdot
.016 w
.41073 .11516 m
.41009 .11491 L
s
1 .754 0 r
.008 w
.41009 .11491 Mdot
.016 w
.41009 .11491 m
.4093 .11478 L
s
.008 w
.4093 .11478 Mdot
.016 w
.4093 .11478 m
.40827 .11475 L
s
.008 w
.40827 .11475 Mdot
.016 w
.40827 .11475 m
.40705 .11476 L
s
1 .753 0 r
.008 w
.40705 .11476 Mdot
.016 w
.40705 .11476 m
.40557 .11478 L
s
.008 w
.40557 .11478 Mdot
.016 w
.40557 .11478 m
.40385 .11478 L
s
1 .752 0 r
.008 w
.40385 .11478 Mdot
.016 w
.40385 .11478 m
.40185 .11474 L
s
.008 w
.40185 .11474 Mdot
.016 w
.40185 .11474 m
.39968 .11463 L
s
.008 w
.39968 .11463 Mdot
.016 w
.39968 .11463 m
.39749 .11448 L
s
1 .751 0 r
.008 w
.39749 .11448 Mdot
.016 w
.39749 .11448 m
.39513 .1143 L
s
.008 w
.39513 .1143 Mdot
.016 w
.39513 .1143 m
.39288 .1141 L
s
1 .75 0 r
.008 w
.39288 .1141 Mdot
.016 w
.39288 .1141 m
.39078 .1139 L
s
.008 w
.39078 .1139 Mdot
.016 w
.39078 .1139 m
.38872 .1137 L
s
.008 w
.38872 .1137 Mdot
.016 w
.38872 .1137 m
.38671 .1135 L
s
1 .749 0 r
.008 w
.38671 .1135 Mdot
.016 w
.38671 .1135 m
.38508 .11329 L
s
.008 w
.38508 .11329 Mdot
.016 w
.38508 .11329 m
.38356 .11307 L
s
1 .748 0 r
.008 w
.38356 .11307 Mdot
.016 w
.38356 .11307 m
.38216 .11284 L
s
.008 w
.38216 .11284 Mdot
.016 w
.38216 .11284 m
.38084 .1126 L
s
.008 w
.38084 .1126 Mdot
.016 w
.38084 .1126 m
.3796 .11237 L
s
1 .747 0 r
.008 w
.3796 .11237 Mdot
.016 w
.3796 .11237 m
.37838 .11216 L
s
.008 w
.37838 .11216 Mdot
.016 w
.37838 .11216 m
.37719 .11202 L
s
1 .746 0 r
.008 w
.37719 .11202 Mdot
.016 w
.37719 .11202 m
.37599 .11193 L
s
.008 w
.37599 .11193 Mdot
.016 w
.37599 .11193 m
.37468 .11192 L
s
.008 w
.37468 .11192 Mdot
.016 w
.37468 .11192 m
.37324 .11201 L
s
1 .745 0 r
.008 w
.37324 .11201 Mdot
.016 w
.37324 .11201 m
.37181 .11222 L
s
.008 w
.37181 .11222 Mdot
.016 w
.37181 .11222 m
.37028 .11255 L
s
1 .744 0 r
.008 w
.37028 .11255 Mdot
.016 w
.37028 .11255 m
.36857 .11295 L
s
.008 w
.36857 .11295 Mdot
.016 w
.36857 .11295 m
.36675 .11344 L
s
.008 w
.36675 .11344 Mdot
.016 w
.36675 .11344 m
.36496 .11399 L
s
1 .743 0 r
.008 w
.36496 .11399 Mdot
.016 w
.36496 .11399 m
.36339 .11464 L
s
.008 w
.36339 .11464 Mdot
.016 w
.36339 .11464 m
.36187 .11536 L
s
.008 w
.36187 .11536 Mdot
.016 w
.36187 .11536 m
.36043 .1161 L
s
1 .742 0 r
.008 w
.36043 .1161 Mdot
.016 w
.36043 .1161 m
.35912 .11679 L
s
.008 w
.35912 .11679 Mdot
.016 w
.35912 .11679 m
.35797 .11745 L
s
1 .741 0 r
.008 w
.35797 .11745 Mdot
.016 w
.35797 .11745 m
.35701 .1182 L
s
.008 w
.35701 .1182 Mdot
.016 w
.35701 .1182 m
.3562 .11888 L
s
.008 w
.3562 .11888 Mdot
.016 w
.3562 .11888 m
.35548 .11957 L
s
1 .74 0 r
.008 w
.35548 .11957 Mdot
.016 w
.35548 .11957 m
.35481 .12029 L
s
.008 w
.35481 .12029 Mdot
.016 w
.35481 .12029 m
.35418 .12095 L
s
1 .739 0 r
.008 w
.35418 .12095 Mdot
.016 w
.35418 .12095 m
.35358 .12167 L
s
.008 w
.35358 .12167 Mdot
.016 w
.35358 .12167 m
.35297 .1224 L
s
.008 w
.35297 .1224 Mdot
.016 w
.35297 .1224 m
.35235 .12317 L
s
1 .738 0 r
.008 w
.35235 .12317 Mdot
.016 w
.35235 .12317 m
.35175 .12395 L
s
.008 w
.35175 .12395 Mdot
.016 w
.35175 .12395 m
.3512 .12473 L
s
1 .737 0 r
.008 w
.3512 .12473 Mdot
.016 w
.3512 .12473 m
.35073 .12545 L
s
.008 w
.35073 .12545 Mdot
.016 w
.35073 .12545 m
.35029 .12612 L
s
.008 w
.35029 .12612 Mdot
.016 w
.35029 .12612 m
.34987 .12675 L
s
1 .736 0 r
.008 w
.34987 .12675 Mdot
.016 w
.34987 .12675 m
.34946 .12732 L
s
.008 w
.34946 .12732 Mdot
.016 w
.34946 .12732 m
.34912 .12777 L
s
1 .735 0 r
.008 w
.34912 .12777 Mdot
.016 w
.34912 .12777 m
.34886 .1281 L
s
.008 w
.34886 .1281 Mdot
.016 w
.34886 .1281 m
.34868 .12829 L
s
.008 w
.34868 .12829 Mdot
.016 w
.34868 .12829 m
.34858 .12841 L
s
1 .734 0 r
.008 w
.34858 .12841 Mdot
.016 w
.34858 .12841 m
.34855 .12844 L
s
.008 w
.34855 .12844 Mdot
.016 w
.34855 .12844 m
.34858 .12839 L
s
1 .733 0 r
.008 w
.34858 .12839 Mdot
.016 w
.34858 .12839 m
.34865 .12828 L
s
.008 w
.34865 .12828 Mdot
.016 w
.34865 .12828 m
.34872 .12816 L
s
.008 w
.34872 .12816 Mdot
.016 w
.34872 .12816 m
.34876 .12807 L
s
1 .732 0 r
.008 w
.34876 .12807 Mdot
.016 w
.34876 .12807 m
.34878 .12801 L
s
.008 w
.34878 .12801 Mdot
.016 w
.34878 .12801 m
.34879 .12796 L
s
1 .731 0 r
.008 w
.34879 .12796 Mdot
.016 w
.34879 .12796 m
.34881 .12793 L
s
.008 w
.34881 .12793 Mdot
.016 w
.34881 .12793 m
.34883 .12789 L
s
.008 w
.34883 .12789 Mdot
.016 w
.34883 .12789 m
.34887 .12782 L
s
1 .73 0 r
.008 w
.34887 .12782 Mdot
.016 w
.34887 .12782 m
.3489 .12772 L
s
.008 w
.3489 .12772 Mdot
.016 w
.3489 .12772 m
.34894 .1276 L
s
.008 w
.34894 .1276 Mdot
.016 w
.34894 .1276 m
.34899 .12744 L
s
1 .729 0 r
.008 w
.34899 .12744 Mdot
.016 w
.34899 .12744 m
.34905 .1273 L
s
.008 w
.34905 .1273 Mdot
.016 w
.34905 .1273 m
.34911 .12715 L
s
1 .728 0 r
.008 w
.34911 .12715 Mdot
.016 w
.34911 .12715 m
.34918 .12701 L
s
.008 w
.34918 .12701 Mdot
.016 w
.34918 .12701 m
.34927 .12689 L
s
.008 w
.34927 .12689 Mdot
.016 w
.34927 .12689 m
.34936 .12681 L
s
1 .727 0 r
.008 w
.34936 .12681 Mdot
.016 w
.34936 .12681 m
.34941 .12675 L
s
.008 w
.34941 .12675 Mdot
.016 w
.34941 .12675 m
.34937 .12673 L
s
1 .726 0 r
.008 w
.34937 .12673 Mdot
.016 w
.34937 .12673 m
.34922 .1267 L
s
.008 w
.34922 .1267 Mdot
.016 w
.34922 .1267 m
.34895 .12668 L
s
.008 w
.34895 .12668 Mdot
.016 w
.34895 .12668 m
.34853 .1267 L
s
1 .725 0 r
.008 w
.34853 .1267 Mdot
.016 w
.34853 .1267 m
.34796 .12677 L
s
.008 w
.34796 .12677 Mdot
.016 w
.34796 .12677 m
.34725 .12693 L
s
1 .724 0 r
.008 w
.34725 .12693 Mdot
.016 w
.34725 .12693 m
.34643 .12712 L
s
.008 w
.34643 .12712 Mdot
.016 w
.34643 .12712 m
.34548 .1274 L
s
.008 w
.34548 .1274 Mdot
.016 w
.34548 .1274 m
.34445 .12774 L
s
1 .723 0 r
.008 w
.34445 .12774 Mdot
.016 w
.34445 .12774 m
.34332 .12811 L
s
.008 w
.34332 .12811 Mdot
.016 w
.34332 .12811 m
.3422 .12849 L
s
1 .722 0 r
.008 w
.3422 .12849 Mdot
.016 w
.3422 .12849 m
.34098 .12887 L
s
.008 w
.34098 .12887 Mdot
.016 w
.34098 .12887 m
.33965 .12925 L
s
.008 w
.33965 .12925 Mdot
.016 w
.33965 .12925 m
.33827 .12963 L
s
1 .721 0 r
.008 w
.33827 .12963 Mdot
.016 w
.33827 .12963 m
.33688 .13003 L
s
.008 w
.33688 .13003 Mdot
.016 w
.33688 .13003 m
.33543 .13049 L
s
1 .72 0 r
.008 w
.33543 .13049 Mdot
.016 w
.33543 .13049 m
.33399 .13103 L
s
.008 w
.33399 .13103 Mdot
.016 w
.33399 .13103 m
.33252 .13164 L
s
.008 w
.33252 .13164 Mdot
.016 w
.33252 .13164 m
.33098 .1323 L
s
1 .719 0 r
.008 w
.33098 .1323 Mdot
.016 w
.33098 .1323 m
.32938 .13303 L
s
.008 w
.32938 .13303 Mdot
.016 w
.32938 .13303 m
.32786 .13381 L
s
.008 w
.32786 .13381 Mdot
.016 w
.32786 .13381 m
.32632 .13466 L
s
1 .718 0 r
.008 w
.32632 .13466 Mdot
.016 w
.32632 .13466 m
.32467 .13558 L
s
.008 w
.32467 .13558 Mdot
.016 w
.32467 .13558 m
.32301 .13648 L
s
1 .717 0 r
.008 w
.32301 .13648 Mdot
.016 w
.32301 .13648 m
.32146 .13741 L
s
.008 w
.32146 .13741 Mdot
.016 w
.32146 .13741 m
.31995 .13834 L
s
.008 w
.31995 .13834 Mdot
.016 w
.31995 .13834 m
.31854 .13923 L
s
1 .716 0 r
.008 w
.31854 .13923 Mdot
.016 w
.31854 .13923 m
.31731 .14002 L
s
.008 w
.31731 .14002 Mdot
.016 w
.31731 .14002 m
.31616 .14072 L
s
1 .715 0 r
.008 w
.31616 .14072 Mdot
.016 w
.31616 .14072 m
.31511 .14129 L
s
.008 w
.31511 .14129 Mdot
.016 w
.31511 .14129 m
.31417 .1417 L
s
.008 w
.31417 .1417 Mdot
.016 w
.31417 .1417 m
.3134 .14197 L
s
1 .714 0 r
.008 w
.3134 .14197 Mdot
.016 w
.3134 .14197 m
.31274 .14211 L
s
.008 w
.31274 .14211 Mdot
.016 w
.31274 .14211 m
.31217 .1422 L
s
1 .713 0 r
.008 w
.31217 .1422 Mdot
.016 w
.31217 .1422 m
.31166 .14229 L
s
.008 w
.31166 .14229 Mdot
.016 w
.31166 .14229 m
.31119 .14243 L
s
.008 w
.31119 .14243 Mdot
.016 w
.31119 .14243 m
.31075 .14266 L
s
1 .712 0 r
.008 w
.31075 .14266 Mdot
.016 w
.31075 .14266 m
.31029 .14302 L
s
.008 w
.31029 .14302 Mdot
.016 w
.31029 .14302 m
.30991 .14343 L
s
1 .711 0 r
.008 w
.30991 .14343 Mdot
.016 w
.30991 .14343 m
.30946 .14405 L
s
.008 w
.30946 .14405 Mdot
.016 w
.30946 .14405 m
.30895 .14483 L
s
.008 w
.30895 .14483 Mdot
.016 w
.30895 .14483 m
.30839 .14577 L
s
1 .71 0 r
.008 w
.30839 .14577 Mdot
.016 w
.30839 .14577 m
.30776 .14676 L
s
.008 w
.30776 .14676 Mdot
.016 w
.30776 .14676 m
.30702 .14793 L
s
1 .709 0 r
.008 w
.30702 .14793 Mdot
.016 w
.30702 .14793 m
.30622 .14923 L
s
.008 w
.30622 .14923 Mdot
.016 w
.30622 .14923 m
.30536 .15047 L
s
.008 w
.30536 .15047 Mdot
.016 w
.30536 .15047 m
.30449 .15169 L
s
1 .708 0 r
.008 w
.30449 .15169 Mdot
.016 w
.30449 .15169 m
.30363 .15283 L
s
.008 w
.30363 .15283 Mdot
.016 w
.30363 .15283 m
.30281 .15388 L
s
1 .707 0 r
.008 w
.30281 .15388 Mdot
.016 w
.30281 .15388 m
.30206 .1548 L
s
.008 w
.30206 .1548 Mdot
.016 w
.30206 .1548 m
.30139 .15559 L
s
.008 w
.30139 .15559 Mdot
.016 w
.30139 .15559 m
.30082 .15631 L
s
1 .706 0 r
.008 w
.30082 .15631 Mdot
.016 w
.30082 .15631 m
.30036 .15695 L
s
.008 w
.30036 .15695 Mdot
.016 w
.30036 .15695 m
.3 .15753 L
s
.008 w
.3 .15753 Mdot
.016 w
.3 .15753 m
.29976 .15807 L
s
1 .705 0 r
.008 w
.29976 .15807 Mdot
.016 w
.29976 .15807 m
.29962 .15858 L
s
.008 w
.29962 .15858 Mdot
.016 w
.29962 .15858 m
.29956 .15907 L
s
1 .704 0 r
.008 w
.29956 .15907 Mdot
.016 w
.29956 .15907 m
.29955 .15952 L
s
.008 w
.29955 .15952 Mdot
.016 w
.29955 .15952 m
.29959 .15992 L
s
.008 w
.29959 .15992 Mdot
.016 w
.29959 .15992 m
.29969 .16022 L
s
1 .703 0 r
.008 w
.29969 .16022 Mdot
.016 w
.29969 .16022 m
.29983 .16046 L
s
.008 w
.29983 .16046 Mdot
.016 w
.29983 .16046 m
.29997 .16069 L
s
1 .702 0 r
.008 w
.29997 .16069 Mdot
.016 w
.29997 .16069 m
.30009 .16094 L
s
.008 w
.30009 .16094 Mdot
.016 w
.30009 .16094 m
.30018 .16119 L
s
.008 w
.30018 .16119 Mdot
.016 w
.30018 .16119 m
.30023 .16144 L
s
1 .701 0 r
.008 w
.30023 .16144 Mdot
.016 w
.30023 .16144 m
.30021 .16171 L
s
.008 w
.30021 .16171 Mdot
.016 w
.30021 .16171 m
.3001 .16206 L
s
1 .7 0 r
.008 w
.3001 .16206 Mdot
.016 w
.3001 .16206 m
.29986 .16249 L
s
.008 w
.29986 .16249 Mdot
.016 w
.29986 .16249 m
.29946 .16304 L
s
.008 w
.29946 .16304 Mdot
.016 w
.29946 .16304 m
.29887 .1637 L
s
1 .699 0 r
.008 w
.29887 .1637 Mdot
.016 w
.29887 .1637 m
.29809 .16448 L
s
.008 w
.29809 .16448 Mdot
.016 w
.29809 .16448 m
.29712 .16538 L
s
1 .698 0 r
.008 w
.29712 .16538 Mdot
.016 w
.29712 .16538 m
.29606 .16627 L
s
.008 w
.29606 .16627 Mdot
.016 w
.29606 .16627 m
.29488 .16724 L
s
.008 w
.29488 .16724 Mdot
.016 w
.29488 .16724 m
.29364 .16823 L
s
1 .697 0 r
.008 w
.29364 .16823 Mdot
.016 w
.29364 .16823 m
.29246 .16923 L
s
.008 w
.29246 .16923 Mdot
.016 w
.29246 .16923 m
.29136 .17009 L
s
1 .696 0 r
.008 w
.29136 .17009 Mdot
.016 w
.29136 .17009 m
.29026 .17084 L
s
.008 w
.29026 .17084 Mdot
.016 w
.29026 .17084 m
.28914 .17146 L
s
.008 w
.28914 .17146 Mdot
.016 w
.28914 .17146 m
.28817 .17192 L
s
1 .695 0 r
.008 w
.28817 .17192 Mdot
.016 w
.28817 .17192 m
.28729 .17221 L
s
.008 w
.28729 .17221 Mdot
.016 w
.28729 .17221 m
.28651 .17235 L
s
1 .694 0 r
.008 w
.28651 .17235 Mdot
.016 w
.28651 .17235 m
.28582 .17237 L
s
.008 w
.28582 .17237 Mdot
.016 w
.28582 .17237 m
.28527 .17231 L
s
.008 w
.28527 .17231 Mdot
.016 w
.28527 .17231 m
.28485 .17222 L
s
1 .693 0 r
.008 w
.28485 .17222 Mdot
.016 w
.28485 .17222 m
.28454 .17214 L
s
.008 w
.28454 .17214 Mdot
.016 w
.28454 .17214 m
.28431 .17206 L
s
.008 w
.28431 .17206 Mdot
.016 w
.28431 .17206 m
.2841 .172 L
s
1 .692 0 r
.008 w
.2841 .172 Mdot
.016 w
.2841 .172 m
.28386 .17195 L
s
.008 w
.28386 .17195 Mdot
.016 w
.28386 .17195 m
.28357 .17191 L
s
1 .691 0 r
.008 w
.28357 .17191 Mdot
.016 w
.28357 .17191 m
.28323 .17186 L
s
.008 w
.28323 .17186 Mdot
.016 w
.28323 .17186 m
.28288 .17179 L
s
.008 w
.28288 .17179 Mdot
.016 w
.28288 .17179 m
.28256 .17173 L
s
1 .69 0 r
.008 w
.28256 .17173 Mdot
.016 w
.28256 .17173 m
.28231 .17166 L
s
.008 w
.28231 .17166 Mdot
.016 w
.28231 .17166 m
.28216 .1716 L
s
1 .689 0 r
.008 w
.28216 .1716 Mdot
.016 w
.28216 .1716 m
.28211 .17155 L
s
.008 w
.28211 .17155 Mdot
.016 w
.28211 .17155 m
.28214 .17151 L
s
.008 w
.28214 .17151 Mdot
.016 w
.28214 .17151 m
.28217 .17149 L
s
1 .688 0 r
.008 w
.28217 .17149 Mdot
.016 w
.28217 .17149 m
.28218 .17149 L
s
.008 w
.28218 .17149 Mdot
.016 w
.28218 .17149 m
.2822 .17149 L
s
1 .687 0 r
.008 w
.2822 .17149 Mdot
.016 w
.2822 .17149 m
.28224 .17152 L
s
.008 w
.28224 .17152 Mdot
.016 w
.28224 .17152 m
.28234 .17154 L
s
.008 w
.28234 .17154 Mdot
.016 w
.28234 .17154 m
.28253 .17161 L
s
1 .686 0 r
.008 w
.28253 .17161 Mdot
.016 w
.28253 .17161 m
.28278 .17169 L
s
.008 w
.28278 .17169 Mdot
.016 w
.28278 .17169 m
.28305 .17177 L
s
1 .685 0 r
.008 w
.28305 .17177 Mdot
.016 w
.28305 .17177 m
.28329 .17186 L
s
.008 w
.28329 .17186 Mdot
.016 w
.28329 .17186 m
.28348 .17193 L
s
.008 w
.28348 .17193 Mdot
.016 w
.28348 .17193 m
.28357 .17198 L
s
1 .684 0 r
.008 w
.28357 .17198 Mdot
.016 w
.28357 .17198 m
.28352 .17201 L
s
.008 w
.28352 .17201 Mdot
.016 w
.28352 .17201 m
.28332 .17198 L
s
1 .683 0 r
.008 w
.28332 .17198 Mdot
.016 w
.28332 .17198 m
.283 .17192 L
s
.008 w
.283 .17192 Mdot
.016 w
.283 .17192 m
.28258 .1718 L
s
.008 w
.28258 .1718 Mdot
.016 w
.28258 .1718 m
.28208 .17163 L
s
1 .682 0 r
.008 w
.28208 .17163 Mdot
.016 w
.28208 .17163 m
.28149 .17138 L
s
.008 w
.28149 .17138 Mdot
.016 w
.28149 .17138 m
.2808 .17107 L
s
1 .681 0 r
.008 w
.2808 .17107 Mdot
.016 w
.2808 .17107 m
.28015 .17073 L
s
.008 w
.28015 .17073 Mdot
.016 w
.28015 .17073 m
.27937 .17043 L
s
.008 w
.27937 .17043 Mdot
.016 w
.27937 .17043 m
.27855 .17014 L
s
1 .68 0 r
.008 w
.27855 .17014 Mdot
.016 w
.27855 .17014 m
.27771 .16991 L
s
.008 w
.27771 .16991 Mdot
.016 w
.27771 .16991 m
.27693 .16976 L
s
.008 w
.27693 .16976 Mdot
.016 w
.27693 .16976 m
.2762 .16967 L
s
1 .679 0 r
.008 w
.2762 .16967 Mdot
.016 w
.2762 .16967 m
.27557 .16964 L
s
.008 w
.27557 .16964 Mdot
.016 w
.27557 .16964 m
.27503 .16966 L
s
1 .678 0 r
.008 w
.27503 .16966 Mdot
.016 w
.27503 .16966 m
.27464 .16976 L
s
.008 w
.27464 .16976 Mdot
.016 w
.27464 .16976 m
.27433 .16991 L
s
.008 w
.27433 .16991 Mdot
.016 w
.27433 .16991 m
.27414 .17009 L
s
1 .677 0 r
.008 w
.27414 .17009 Mdot
.016 w
.27414 .17009 m
.27404 .17033 L
s
.008 w
.27404 .17033 Mdot
.016 w
.27404 .17033 m
.27399 .17059 L
s
1 .676 0 r
.008 w
.27399 .17059 Mdot
.016 w
.27399 .17059 m
.27398 .17081 L
s
.008 w
.27398 .17081 Mdot
.016 w
.27398 .17081 m
.27397 .17097 L
s
.008 w
.27397 .17097 Mdot
.016 w
.27397 .17097 m
.2739 .1711 L
s
1 .675 0 r
.008 w
.2739 .1711 Mdot
.016 w
.2739 .1711 m
.27374 .17116 L
s
.008 w
.27374 .17116 Mdot
.016 w
.27374 .17116 m
.27344 .17119 L
s
1 .674 0 r
.008 w
.27344 .17119 Mdot
.016 w
.27344 .17119 m
.27298 .17122 L
s
.008 w
.27298 .17122 Mdot
.016 w
.27298 .17122 m
.27239 .17132 L
s
.008 w
.27239 .17132 Mdot
.016 w
.27239 .17132 m
.27165 .17158 L
s
1 .673 0 r
.008 w
.27165 .17158 Mdot
.016 w
.27165 .17158 m
.27077 .17203 L
s
.008 w
.27077 .17203 Mdot
.016 w
.27077 .17203 m
.26982 .17267 L
s
1 .672 0 r
.008 w
.26982 .17267 Mdot
.016 w
.26982 .17267 m
.26885 .17346 L
s
.008 w
.26885 .17346 Mdot
.016 w
.26885 .17346 m
.26782 .17435 L
s
.008 w
.26782 .17435 Mdot
.016 w
.26782 .17435 m
.26673 .17526 L
s
1 .671 0 r
.008 w
.26673 .17526 Mdot
.016 w
.26673 .17526 m
.26564 .17602 L
s
.008 w
.26564 .17602 Mdot
.016 w
.26564 .17602 m
.26461 .17678 L
s
1 .67 0 r
.008 w
.26461 .17678 Mdot
.016 w
.26461 .17678 m
.26366 .17747 L
s
.008 w
.26366 .17747 Mdot
.016 w
.26366 .17747 m
.26283 .17812 L
s
.008 w
.26283 .17812 Mdot
.016 w
.26283 .17812 m
.26212 .17859 L
s
1 .669 0 r
.008 w
.26212 .17859 Mdot
.016 w
.26212 .17859 m
.26153 .17894 L
s
.008 w
.26153 .17894 Mdot
.016 w
.26153 .17894 m
.26105 .17914 L
s
.008 w
.26105 .17914 Mdot
.016 w
.26105 .17914 m
.26066 .17922 L
s
1 .668 0 r
.008 w
.26066 .17922 Mdot
.016 w
.26066 .17922 m
.26036 .17911 L
s
.008 w
.26036 .17911 Mdot
.016 w
.26036 .17911 m
.26016 .17885 L
s
1 .667 0 r
.008 w
.26016 .17885 Mdot
.016 w
.26016 .17885 m
.26005 .17847 L
s
.008 w
.26005 .17847 Mdot
.016 w
.26005 .17847 m
.26001 .17807 L
s
.008 w
.26001 .17807 Mdot
.016 w
.26001 .17807 m
.26001 .17772 L
s
1 .666 0 r
.008 w
.26001 .17772 Mdot
.016 w
.26001 .17772 m
.26 .17747 L
s
.008 w
.26 .17747 Mdot
.016 w
.26 .17747 m
.25996 .17732 L
s
1 .665 0 r
.008 w
.25996 .17732 Mdot
.016 w
.25996 .17732 m
.25982 .17728 L
s
.008 w
.25982 .17728 Mdot
.016 w
.25982 .17728 m
.2595 .17737 L
s
.008 w
.2595 .17737 Mdot
.016 w
.2595 .17737 m
.25897 .17758 L
s
1 .664 0 r
.008 w
.25897 .17758 Mdot
.016 w
.25897 .17758 m
.25824 .1779 L
s
.008 w
.25824 .1779 Mdot
.016 w
.25824 .1779 m
.25729 .17829 L
s
1 .663 0 r
.008 w
.25729 .17829 Mdot
.016 w
.25729 .17829 m
.25609 .17875 L
s
.008 w
.25609 .17875 Mdot
.016 w
.25609 .17875 m
.25485 .17929 L
s
.008 w
.25485 .17929 Mdot
.016 w
.25485 .17929 m
.25335 .17989 L
s
1 .662 0 r
.008 w
.25335 .17989 Mdot
.016 w
.25335 .17989 m
.25173 .18049 L
s
.008 w
.25173 .18049 Mdot
.016 w
.25173 .18049 m
.25011 .18114 L
s
1 .661 0 r
.008 w
.25011 .18114 Mdot
.016 w
.25011 .18114 m
.24837 .1818 L
s
.008 w
.24837 .1818 Mdot
.016 w
.24837 .1818 m
.24663 .18245 L
s
.008 w
.24663 .18245 Mdot
.016 w
.24663 .18245 m
.24495 .18311 L
s
1 .66 0 r
.008 w
.24495 .18311 Mdot
.016 w
.24495 .18311 m
.24342 .18377 L
s
.008 w
.24342 .18377 Mdot
.016 w
.24342 .18377 m
.24187 .18447 L
s
1 .659 0 r
.008 w
.24187 .18447 Mdot
.016 w
.24187 .18447 m
.24032 .18522 L
s
.008 w
.24032 .18522 Mdot
.016 w
.24032 .18522 m
.23884 .186 L
s
.008 w
.23884 .186 Mdot
.016 w
.23884 .186 m
.23745 .18683 L
s
1 .658 0 r
.008 w
.23745 .18683 Mdot
.016 w
.23745 .18683 m
.23627 .18766 L
s
.008 w
.23627 .18766 Mdot
.016 w
.23627 .18766 m
.23503 .18858 L
s
1 .657 0 r
.008 w
.23503 .18858 Mdot
.016 w
.23503 .18858 m
.23384 .18957 L
s
.008 w
.23384 .18957 Mdot
.016 w
.23384 .18957 m
.23274 .19057 L
s
.008 w
.23274 .19057 Mdot
.016 w
.23274 .19057 m
.23171 .19168 L
s
1 .656 0 r
.008 w
.23171 .19168 Mdot
.016 w
.23171 .19168 m
.23069 .19294 L
s
.008 w
.23069 .19294 Mdot
.016 w
.23069 .19294 m
.22976 .19418 L
s
.008 w
.22976 .19418 Mdot
.016 w
.22976 .19418 m
.2289 .19548 L
s
1 .655 0 r
.008 w
.2289 .19548 Mdot
.016 w
.2289 .19548 m
.22815 .19677 L
s
.008 w
.22815 .19677 Mdot
.016 w
.22815 .19677 m
.22752 .19794 L
s
1 .654 0 r
.008 w
.22752 .19794 Mdot
.016 w
.22752 .19794 m
.22702 .19894 L
s
.008 w
.22702 .19894 Mdot
.016 w
.22702 .19894 m
.22666 .19967 L
s
.008 w
.22666 .19967 Mdot
.016 w
.22666 .19967 m
.2264 .2002 L
s
1 .653 0 r
.008 w
.2264 .2002 Mdot
.016 w
.2264 .2002 m
.22621 .20051 L
s
.008 w
.22621 .20051 Mdot
.016 w
.22621 .20051 m
.22606 .20061 L
s
1 .652 0 r
.008 w
.22606 .20061 Mdot
.016 w
.22606 .20061 m
.22596 .2005 L
s
.008 w
.22596 .2005 Mdot
.016 w
.22596 .2005 m
.22588 .20024 L
s
.008 w
.22588 .20024 Mdot
.016 w
.22588 .20024 m
.22583 .1999 L
s
1 .651 0 r
.008 w
.22583 .1999 Mdot
.016 w
.22583 .1999 m
.22581 .19956 L
s
.008 w
.22581 .19956 Mdot
.016 w
.22581 .19956 m
.22582 .19923 L
s
1 .65 0 r
.008 w
.22582 .19923 Mdot
.016 w
.22582 .19923 m
.22587 .19899 L
s
.008 w
.22587 .19899 Mdot
.016 w
.22587 .19899 m
.22593 .19888 L
s
.008 w
.22593 .19888 Mdot
.016 w
.22593 .19888 m
.226 .19897 L
s
1 .649 0 r
.008 w
.226 .19897 Mdot
.016 w
.226 .19897 m
.22606 .19932 L
s
.008 w
.22606 .19932 Mdot
.016 w
.22606 .19932 m
.2261 .19992 L
s
1 .648 0 r
.008 w
.2261 .19992 Mdot
.016 w
.2261 .19992 m
.22615 .20071 L
s
.008 w
.22615 .20071 Mdot
.016 w
.22615 .20071 m
.22621 .20152 L
s
.008 w
.22621 .20152 Mdot
.016 w
.22621 .20152 m
.22629 .20255 L
s
1 .647 0 r
.008 w
.22629 .20255 Mdot
.016 w
.22629 .20255 m
.22635 .20345 L
s
.008 w
.22635 .20345 Mdot
.016 w
.22635 .20345 m
.22641 .2043 L
s
1 .646 0 r
.008 w
.22641 .2043 Mdot
.016 w
.22641 .2043 m
.22643 .20504 L
s
.008 w
.22643 .20504 Mdot
.016 w
.22643 .20504 m
.22644 .20559 L
s
.008 w
.22644 .20559 Mdot
.016 w
.22644 .20559 m
.22643 .20593 L
s
1 .645 0 r
.008 w
.22643 .20593 Mdot
.016 w
.22643 .20593 m
.22638 .20605 L
s
.008 w
.22638 .20605 Mdot
.016 w
.22638 .20605 m
.22626 .20601 L
s
1 .644 0 r
.008 w
.22626 .20601 Mdot
.016 w
.22626 .20601 m
.22604 .20586 L
s
.008 w
.22604 .20586 Mdot
.016 w
.22604 .20586 m
.22572 .20566 L
s
.008 w
.22572 .20566 Mdot
.016 w
.22572 .20566 m
.22528 .20542 L
s
1 .643 0 r
.008 w
.22528 .20542 Mdot
.016 w
.22528 .20542 m
.22469 .20519 L
s
.008 w
.22469 .20519 Mdot
.016 w
.22469 .20519 m
.22395 .20501 L
s
.008 w
.22395 .20501 Mdot
.016 w
.22395 .20501 m
.22303 .20488 L
s
1 .642 0 r
.008 w
.22303 .20488 Mdot
.016 w
.22303 .20488 m
.22194 .20478 L
s
.008 w
.22194 .20478 Mdot
.016 w
.22194 .20478 m
.22068 .20474 L
s
1 .641 0 r
.008 w
.22068 .20474 Mdot
.016 w
.22068 .20474 m
.21923 .20479 L
s
.008 w
.21923 .20479 Mdot
.016 w
.21923 .20479 m
.21761 .20494 L
s
.008 w
.21761 .20494 Mdot
.016 w
.21761 .20494 m
.21608 .20523 L
s
1 .64 0 r
.008 w
.21608 .20523 Mdot
.016 w
.21608 .20523 m
.21438 .20565 L
s
.008 w
.21438 .20565 Mdot
.016 w
.21438 .20565 m
.21244 .2062 L
s
1 .639 0 r
.008 w
.21244 .2062 Mdot
.016 w
.21244 .2062 m
.21033 .2069 L
s
.008 w
.21033 .2069 Mdot
.016 w
.21033 .2069 m
.20831 .20773 L
s
.008 w
.20831 .20773 Mdot
.016 w
.20831 .20773 m
.2064 .20871 L
s
1 .638 0 r
.008 w
.2064 .20871 Mdot
.016 w
.2064 .20871 m
.20437 .20985 L
s
.008 w
.20437 .20985 Mdot
.016 w
.20437 .20985 m
.20236 .21108 L
s
1 .637 0 r
.008 w
.20236 .21108 Mdot
.016 w
.20236 .21108 m
.20037 .21252 L
s
.008 w
.20037 .21252 Mdot
.016 w
.20037 .21252 m
.19858 .21414 L
s
.008 w
.19858 .21414 Mdot
.016 w
.19858 .21414 m
.19669 .21588 L
s
1 .636 0 r
.008 w
.19669 .21588 Mdot
.016 w
.19669 .21588 m
.19513 .21764 L
s
.008 w
.19513 .21764 Mdot
.016 w
.19513 .21764 m
.19357 .21957 L
s
1 .635 0 r
.008 w
.19357 .21957 Mdot
.016 w
.19357 .21957 m
.19193 .22151 L
s
.008 w
.19193 .22151 Mdot
.016 w
.19193 .22151 m
.1904 .22363 L
s
.008 w
.1904 .22363 Mdot
.016 w
.1904 .22363 m
.18885 .22558 L
s
1 .634 0 r
.008 w
.18885 .22558 Mdot
.016 w
.18885 .22558 m
.18731 .22762 L
s
.008 w
.18731 .22762 Mdot
.016 w
.18731 .22762 m
.18579 .22973 L
s
1 .633 0 r
.008 w
.18579 .22973 Mdot
.016 w
.18579 .22973 m
.18455 .23153 L
s
.008 w
.18455 .23153 Mdot
.016 w
.18455 .23153 m
.18327 .23344 L
s
.008 w
.18327 .23344 Mdot
.016 w
.18327 .23344 m
.18215 .23526 L
s
1 .632 0 r
.008 w
.18215 .23526 Mdot
.016 w
.18215 .23526 m
.18116 .23697 L
s
.008 w
.18116 .23697 Mdot
.016 w
.18116 .23697 m
.18018 .23872 L
s
1 .631 0 r
.008 w
.18018 .23872 Mdot
.016 w
.18018 .23872 m
.17933 .2401 L
s
.008 w
.17933 .2401 Mdot
.016 w
.17933 .2401 m
.1786 .24144 L
s
.008 w
.1786 .24144 Mdot
.016 w
.1786 .24144 m
.17803 .24277 L
s
1 .63 0 r
.008 w
.17803 .24277 Mdot
.016 w
.17803 .24277 m
.17762 .24405 L
s
.008 w
.17762 .24405 Mdot
.016 w
.17762 .24405 m
.17738 .24525 L
s
.008 w
.17738 .24525 Mdot
.016 w
.17738 .24525 m
.1773 .24627 L
s
1 .629 0 r
.008 w
.1773 .24627 Mdot
.016 w
.1773 .24627 m
.17733 .24723 L
s
.008 w
.17733 .24723 Mdot
.016 w
.17733 .24723 m
.17743 .24808 L
s
1 .628 0 r
.008 w
.17743 .24808 Mdot
.016 w
.17743 .24808 m
.17754 .24878 L
s
.008 w
.17754 .24878 Mdot
.016 w
.17754 .24878 m
.17764 .2493 L
s
.008 w
.17764 .2493 Mdot
.016 w
.17764 .2493 m
.17772 .24968 L
s
1 .627 0 r
.008 w
.17772 .24968 Mdot
.016 w
.17772 .24968 m
.17776 .24992 L
s
.008 w
.17776 .24992 Mdot
.016 w
.17776 .24992 m
.17776 .25006 L
s
1 .626 0 r
.008 w
.17776 .25006 Mdot
.016 w
.17776 .25006 m
.17773 .25008 L
s
.008 w
.17773 .25008 Mdot
.016 w
.17773 .25008 m
.17769 .25 L
s
.008 w
.17769 .25 Mdot
.016 w
.17769 .25 m
.17763 .24976 L
s
1 .625 0 r
.008 w
.17763 .24976 Mdot
.016 w
.17763 .24976 m
.17756 .2494 L
s
.008 w
.17756 .2494 Mdot
.016 w
.17756 .2494 m
.1775 .24894 L
s
1 .624 0 r
.008 w
.1775 .24894 Mdot
.016 w
.1775 .24894 m
.17748 .24848 L
s
.008 w
.17748 .24848 Mdot
.016 w
.17748 .24848 m
.17754 .24803 L
s
.008 w
.17754 .24803 Mdot
.016 w
.17754 .24803 m
.1777 .2476 L
s
1 .623 0 r
.008 w
.1777 .2476 Mdot
.016 w
.1777 .2476 m
.17796 .24724 L
s
.008 w
.17796 .24724 Mdot
.016 w
.17796 .24724 m
.17834 .24701 L
s
1 .622 0 r
.008 w
.17834 .24701 Mdot
.016 w
.17834 .24701 m
.17882 .24692 L
s
.008 w
.17882 .24692 Mdot
.016 w
.17882 .24692 m
.17939 .24695 L
s
.008 w
.17939 .24695 Mdot
.016 w
.17939 .24695 m
.18001 .24701 L
s
1 .621 0 r
.008 w
.18001 .24701 Mdot
.016 w
.18001 .24701 m
.18072 .24709 L
s
.008 w
.18072 .24709 Mdot
.016 w
.18072 .24709 m
.18148 .24716 L
s
1 .62 0 r
.008 w
.18148 .24716 Mdot
.016 w
.18148 .24716 m
.18229 .24722 L
s
.008 w
.18229 .24722 Mdot
.016 w
.18229 .24722 m
.18307 .24727 L
s
.008 w
.18307 .24727 Mdot
.016 w
.18307 .24727 m
.18386 .2473 L
s
1 .619 0 r
.008 w
.18386 .2473 Mdot
.016 w
.18386 .2473 m
.18461 .24733 L
s
.008 w
.18461 .24733 Mdot
.016 w
.18461 .24733 m
.18531 .24734 L
s
.008 w
.18531 .24734 Mdot
.016 w
.18531 .24734 m
.1859 .24736 L
s
1 .618 0 r
.008 w
.1859 .24736 Mdot
.016 w
.1859 .24736 m
.18639 .24737 L
s
.008 w
.18639 .24737 Mdot
.016 w
.18639 .24737 m
.18675 .24738 L
s
1 .617 0 r
.008 w
.18675 .24738 Mdot
.016 w
.18675 .24738 m
.18702 .24739 L
s
.008 w
.18702 .24739 Mdot
.016 w
.18702 .24739 m
.18722 .24739 L
s
.008 w
.18722 .24739 Mdot
.016 w
.18722 .24739 m
.18737 .24739 L
s
1 .616 0 r
.008 w
.18737 .24739 Mdot
.016 w
.18737 .24739 m
.18748 .2474 L
s
.008 w
.18748 .2474 Mdot
.016 w
.18748 .2474 m
.18756 .2474 L
s
1 .615 0 r
.008 w
.18756 .2474 Mdot
.016 w
.18756 .2474 m
.18764 .2474 L
s
.008 w
.18764 .2474 Mdot
.016 w
.18764 .2474 m
.18768 .2474 L
s
.008 w
.18768 .2474 Mdot
.016 w
.18768 .2474 m
.1877 .2474 L
s
1 .614 0 r
.008 w
.1877 .2474 Mdot
.016 w
.1877 .2474 m
.18768 .2474 L
s
.008 w
.18768 .2474 Mdot
.016 w
.18768 .2474 m
.18764 .2474 L
s
1 .613 0 r
.008 w
.18764 .2474 Mdot
.016 w
.18764 .2474 m
.1876 .2474 L
s
.008 w
.1876 .2474 Mdot
.016 w
.1876 .2474 m
.18757 .2474 L
s
.008 w
.18757 .2474 Mdot
.016 w
.18757 .2474 m
.18755 .2474 L
s
1 .612 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .611 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .61 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .609 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .608 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .607 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .606 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18755 .2474 L
s
1 .605 0 r
.008 w
.18755 .2474 Mdot
.016 w
.18755 .2474 m
.18753 .2474 L
s
.008 w
.18753 .2474 Mdot
.016 w
.18753 .2474 m
.1875 .2474 L
s
1 .604 0 r
.008 w
.1875 .2474 Mdot
.016 w
.1875 .2474 m
.18746 .2474 L
s
.008 w
.18746 .2474 Mdot
.016 w
.18746 .2474 m
.18743 .2474 L
s
.008 w
.18743 .2474 Mdot
.016 w
.18743 .2474 m
.18741 .2474 L
s
1 .603 0 r
.008 w
.18741 .2474 Mdot
.016 w
.18741 .2474 m
.18742 .2474 L
s
.008 w
.18742 .2474 Mdot
.016 w
.18742 .2474 m
.18748 .2474 L
s
1 .602 0 r
.008 w
.18748 .2474 Mdot
.016 w
.18748 .2474 m
.18757 .2474 L
s
.008 w
.18757 .2474 Mdot
.016 w
.18757 .2474 m
.18772 .2474 L
s
.008 w
.18772 .2474 Mdot
.016 w
.18772 .2474 m
.1879 .24741 L
s
1 .601 0 r
.008 w
.1879 .24741 Mdot
.016 w
.1879 .24741 m
.18812 .24741 L
s
.008 w
.18812 .24741 Mdot
.016 w
.18812 .24741 m
.18836 .24742 L
s
1 .6 0 r
.008 w
.18836 .24742 Mdot
.016 w
.18836 .24742 m
.18861 .24743 L
s
.008 w
.18861 .24743 Mdot
.016 w
.18861 .24743 m
.18886 .24744 L
s
.008 w
.18886 .24744 Mdot
.016 w
.18886 .24744 m
.18912 .24747 L
s
1 .599 0 r
.008 w
.18912 .24747 Mdot
.016 w
.18912 .24747 m
.18935 .24753 L
s
.008 w
.18935 .24753 Mdot
.016 w
.18935 .24753 m
.18954 .2476 L
s
1 .598 0 r
.008 w
.18954 .2476 Mdot
.016 w
.18954 .2476 m
.18968 .24769 L
s
.008 w
.18968 .24769 Mdot
.016 w
.18968 .24769 m
.18978 .24777 L
s
.008 w
.18978 .24777 Mdot
.016 w
.18978 .24777 m
.18983 .24782 L
s
1 .597 0 r
.008 w
.18983 .24782 Mdot
.016 w
.18983 .24782 m
.18985 .2478 L
s
.008 w
.18985 .2478 Mdot
.016 w
.18985 .2478 m
.18985 .24769 L
s
1 .596 0 r
.008 w
.18985 .24769 Mdot
.016 w
.18985 .24769 m
.18987 .24749 L
s
.008 w
.18987 .24749 Mdot
.016 w
.18987 .24749 m
.18992 .24717 L
s
.008 w
.18992 .24717 Mdot
.016 w
.18992 .24717 m
.19007 .24674 L
s
1 .595 0 r
.008 w
.19007 .24674 Mdot
.016 w
.19007 .24674 m
.19035 .24618 L
s
.008 w
.19035 .24618 Mdot
.016 w
.19035 .24618 m
.19077 .24549 L
s
1 .594 0 r
.008 w
.19077 .24549 Mdot
.016 w
.19077 .24549 m
.19134 .24468 L
s
.008 w
.19134 .24468 Mdot
.016 w
.19134 .24468 m
.19203 .24372 L
s
.008 w
.19203 .24372 Mdot
.016 w
.19203 .24372 m
.19288 .24256 L
s
1 .593 0 r
.008 w
.19288 .24256 Mdot
.016 w
.19288 .24256 m
.19388 .2412 L
s
.008 w
.19388 .2412 Mdot
.016 w
.19388 .2412 m
.19502 .23977 L
s
.008 w
.19502 .23977 Mdot
.016 w
.19502 .23977 m
.19629 .2382 L
s
1 .592 0 r
.008 w
.19629 .2382 Mdot
.016 w
.19629 .2382 m
.19761 .2366 L
s
.008 w
.19761 .2366 Mdot
.016 w
.19761 .2366 m
.19898 .23496 L
s
1 .591 0 r
.008 w
.19898 .23496 Mdot
.016 w
.19898 .23496 m
.20035 .23349 L
s
.008 w
.20035 .23349 Mdot
.016 w
.20035 .23349 m
.20161 .23207 L
s
.008 w
.20161 .23207 Mdot
.016 w
.20161 .23207 m
.2028 .23078 L
s
1 .59 0 r
.008 w
.2028 .23078 Mdot
.016 w
.2028 .23078 m
.20379 .22975 L
s
.008 w
.20379 .22975 Mdot
.016 w
.20379 .22975 m
.20468 .22877 L
s
1 .589 0 r
.008 w
.20468 .22877 Mdot
.016 w
.20468 .22877 m
.20543 .22797 L
s
.008 w
.20543 .22797 Mdot
.016 w
.20543 .22797 m
.20609 .22725 L
s
.008 w
.20609 .22725 Mdot
.016 w
.20609 .22725 m
.20655 .22679 L
s
1 .588 0 r
.008 w
.20655 .22679 Mdot
.016 w
.20655 .22679 m
.20691 .22646 L
s
.008 w
.20691 .22646 Mdot
.016 w
.20691 .22646 m
.20713 .22629 L
s
1 .587 0 r
.008 w
.20713 .22629 Mdot
.016 w
.20713 .22629 m
.20724 .22625 L
s
.008 w
.20724 .22625 Mdot
.016 w
.20724 .22625 m
.20727 .22632 L
s
.008 w
.20727 .22632 Mdot
.016 w
.20727 .22632 m
.20725 .22643 L
s
1 .586 0 r
.008 w
.20725 .22643 Mdot
.016 w
.20725 .22643 m
.20719 .22654 L
s
.008 w
.20719 .22654 Mdot
.016 w
.20719 .22654 m
.20711 .22663 L
s
1 .585 0 r
.008 w
.20711 .22663 Mdot
.016 w
.20711 .22663 m
.20702 .22669 L
s
.008 w
.20702 .22669 Mdot
.016 w
.20702 .22669 m
.20695 .22673 L
s
.008 w
.20695 .22673 Mdot
.016 w
.20695 .22673 m
.20692 .22674 L
s
1 .584 0 r
.008 w
.20692 .22674 Mdot
.016 w
.20692 .22674 m
.20692 .22675 L
s
.008 w
.20692 .22675 Mdot
.016 w
.20692 .22675 m
.20693 .22677 L
s
1 .583 0 r
.008 w
.20693 .22677 Mdot
.016 w
.20693 .22677 m
.20693 .22683 L
s
.008 w
.20693 .22683 Mdot
.016 w
.20693 .22683 m
.20693 .2269 L
s
.008 w
.20693 .2269 Mdot
.016 w
.20693 .2269 m
.20691 .22699 L
s
1 .582 0 r
.008 w
.20691 .22699 Mdot
.016 w
.20691 .22699 m
.20688 .22708 L
s
.008 w
.20688 .22708 Mdot
.016 w
.20688 .22708 m
.20683 .22716 L
s
1 .581 0 r
.008 w
.20683 .22716 Mdot
.016 w
.20683 .22716 m
.20677 .22719 L
s
.008 w
.20677 .22719 Mdot
.016 w
.20677 .22719 m
.20672 .22712 L
s
.008 w
.20672 .22712 Mdot
.016 w
.20672 .22712 m
.2067 .22691 L
s
1 .58 0 r
.008 w
.2067 .22691 Mdot
.016 w
.2067 .22691 m
.20674 .22653 L
s
.008 w
.20674 .22653 Mdot
.016 w
.20674 .22653 m
.20685 .22597 L
s
.008 w
.20685 .22597 Mdot
.016 w
.20685 .22597 m
.20704 .2252 L
s
1 .579 0 r
.008 w
.20704 .2252 Mdot
.016 w
.20704 .2252 m
.20732 .2242 L
s
.008 w
.20732 .2242 Mdot
.016 w
.20732 .2242 m
.20767 .22309 L
s
1 .578 0 r
.008 w
.20767 .22309 Mdot
.016 w
.20767 .22309 m
.20809 .22176 L
s
.008 w
.20809 .22176 Mdot
.016 w
.20809 .22176 m
.20855 .22021 L
s
.008 w
.20855 .22021 Mdot
.016 w
.20855 .22021 m
.20901 .21871 L
s
1 .577 0 r
.008 w
.20901 .21871 Mdot
.016 w
.20901 .21871 m
.2095 .21708 L
s
.008 w
.2095 .21708 Mdot
.016 w
.2095 .21708 m
.20998 .21533 L
s
1 .576 0 r
.008 w
.20998 .21533 Mdot
.016 w
.20998 .21533 m
.21039 .21388 L
s
.008 w
.21039 .21388 Mdot
.016 w
.21039 .21388 m
.21074 .21249 L
s
.008 w
.21074 .21249 Mdot
.016 w
.21074 .21249 m
.21105 .21121 L
s
1 .575 0 r
.008 w
.21105 .21121 Mdot
.016 w
.21105 .21121 m
.21129 .21013 L
s
.008 w
.21129 .21013 Mdot
.016 w
.21129 .21013 m
.21145 .20929 L
s
1 .574 0 r
.008 w
.21145 .20929 Mdot
.016 w
.21145 .20929 m
.21158 .20866 L
s
.008 w
.21158 .20866 Mdot
.016 w
.21158 .20866 m
.21172 .20822 L
s
.008 w
.21172 .20822 Mdot
.016 w
.21172 .20822 m
.21189 .20792 L
s
1 .573 0 r
.008 w
.21189 .20792 Mdot
.016 w
.21189 .20792 m
.21213 .20768 L
s
.008 w
.21213 .20768 Mdot
.016 w
.21213 .20768 m
.21248 .20747 L
s
1 .572 0 r
.008 w
.21248 .20747 Mdot
.016 w
.21248 .20747 m
.21297 .20726 L
s
.008 w
.21297 .20726 Mdot
.016 w
.21297 .20726 m
.21362 .20701 L
s
.008 w
.21362 .20701 Mdot
.016 w
.21362 .20701 m
.21436 .2067 L
s
1 .571 0 r
.008 w
.21436 .2067 Mdot
.016 w
.21436 .2067 m
.21528 .20635 L
s
.008 w
.21528 .20635 Mdot
.016 w
.21528 .20635 m
.21627 .20592 L
s
1 .57 0 r
.008 w
.21627 .20592 Mdot
.016 w
.21627 .20592 m
.2174 .20539 L
s
.008 w
.2174 .20539 Mdot
.016 w
.2174 .20539 m
.21865 .20472 L
s
.008 w
.21865 .20472 Mdot
.016 w
.21865 .20472 m
.21981 .20394 L
s
1 .569 0 r
.008 w
.21981 .20394 Mdot
.016 w
.21981 .20394 m
.22104 .20312 L
s
.008 w
.22104 .20312 Mdot
.016 w
.22104 .20312 m
.22235 .20227 L
s
.008 w
.22235 .20227 Mdot
.016 w
.22235 .20227 m
.22363 .20141 L
s
1 .568 0 r
.008 w
.22363 .20141 Mdot
.016 w
.22363 .20141 m
.22494 .20057 L
s
.008 w
.22494 .20057 Mdot
.016 w
.22494 .20057 m
.22621 .19976 L
s
1 .567 0 r
.008 w
.22621 .19976 Mdot
.016 w
.22621 .19976 m
.22753 .19903 L
s
.008 w
.22753 .19903 Mdot
.016 w
.22753 .19903 m
.22878 .1983 L
s
.008 w
.22878 .1983 Mdot
.016 w
.22878 .1983 m
.23007 .19756 L
s
1 .566 0 r
.008 w
.23007 .19756 Mdot
.016 w
.23007 .19756 m
.23132 .19685 L
s
.008 w
.23132 .19685 Mdot
.016 w
.23132 .19685 m
.23259 .19615 L
s
1 .565 0 r
.008 w
.23259 .19615 Mdot
.016 w
.23259 .19615 m
.23379 .19548 L
s
.008 w
.23379 .19548 Mdot
.016 w
.23379 .19548 m
.23489 .19483 L
s
.008 w
.23489 .19483 Mdot
.016 w
.23489 .19483 m
.23596 .19423 L
s
1 .564 0 r
.008 w
.23596 .19423 Mdot
.016 w
.23596 .19423 m
.23694 .19369 L
s
.008 w
.23694 .19369 Mdot
.016 w
.23694 .19369 m
.23779 .19326 L
s
1 .563 0 r
.008 w
.23779 .19326 Mdot
.016 w
.23779 .19326 m
.23853 .1929 L
s
.008 w
.23853 .1929 Mdot
.016 w
.23853 .1929 m
.23916 .19258 L
s
.008 w
.23916 .19258 Mdot
.016 w
.23916 .19258 m
.23965 .19229 L
s
1 .562 0 r
.008 w
.23965 .19229 Mdot
.016 w
.23965 .19229 m
.24002 .19203 L
s
.008 w
.24002 .19203 Mdot
.016 w
.24002 .19203 m
.2403 .19181 L
s
1 .561 0 r
.008 w
.2403 .19181 Mdot
.016 w
.2403 .19181 m
.24049 .19165 L
s
.008 w
.24049 .19165 Mdot
.016 w
.24049 .19165 m
.24062 .19157 L
s
.008 w
.24062 .19157 Mdot
.016 w
.24062 .19157 m
.24069 .19155 L
s
1 .56 0 r
.008 w
.24069 .19155 Mdot
.016 w
.24069 .19155 m
.24073 .19158 L
s
.008 w
.24073 .19158 Mdot
.016 w
.24073 .19158 m
.24074 .19165 L
s
1 .559 0 r
.008 w
.24074 .19165 Mdot
.016 w
.24074 .19165 m
.24072 .19174 L
s
.008 w
.24072 .19174 Mdot
.016 w
.24072 .19174 m
.24067 .19184 L
s
.008 w
.24067 .19184 Mdot
.016 w
.24067 .19184 m
.24057 .19194 L
s
1 .558 0 r
.008 w
.24057 .19194 Mdot
.016 w
.24057 .19194 m
.24045 .19203 L
s
.008 w
.24045 .19203 Mdot
.016 w
.24045 .19203 m
.24031 .19209 L
s
1 .557 0 r
.008 w
.24031 .19209 Mdot
.016 w
.24031 .19209 m
.2402 .19211 L
s
.008 w
.2402 .19211 Mdot
.016 w
.2402 .19211 m
.24016 .19207 L
s
.008 w
.24016 .19207 Mdot
.016 w
.24016 .19207 m
.24022 .19194 L
s
1 .556 0 r
.008 w
.24022 .19194 Mdot
.016 w
.24022 .19194 m
.2404 .19169 L
s
.008 w
.2404 .19169 Mdot
.016 w
.2404 .19169 m
.24072 .19131 L
s
.008 w
.24072 .19131 Mdot
.016 w
.24072 .19131 m
.2412 .19079 L
s
1 .555 0 r
.008 w
.2412 .19079 Mdot
.016 w
.2412 .19079 m
.24185 .19014 L
s
.008 w
.24185 .19014 Mdot
.016 w
.24185 .19014 m
.24266 .18936 L
s
1 .554 0 r
.008 w
.24266 .18936 Mdot
.016 w
.24266 .18936 m
.2436 .18854 L
s
.008 w
.2436 .18854 Mdot
.016 w
.2436 .18854 m
.24451 .18763 L
s
.008 w
.24451 .18763 Mdot
.016 w
.24451 .18763 m
.24559 .18666 L
s
1 .553 0 r
.008 w
.24559 .18666 Mdot
.016 w
.24559 .18666 m
.24661 .18571 L
s
.008 w
.24661 .18571 Mdot
.016 w
.24661 .18571 m
.2477 .18477 L
s
1 .552 0 r
.008 w
.2477 .18477 Mdot
.016 w
.2477 .18477 m
.24858 .18389 L
s
.008 w
.24858 .18389 Mdot
.016 w
.24858 .18389 m
.24945 .18315 L
s
.008 w
.24945 .18315 Mdot
.016 w
.24945 .18315 m
.25028 .18252 L
s
1 .551 0 r
.008 w
.25028 .18252 Mdot
.016 w
.25028 .18252 m
.25103 .18202 L
s
.008 w
.25103 .18202 Mdot
.016 w
.25103 .18202 m
.25166 .18166 L
s
1 .55 0 r
.008 w
.25166 .18166 Mdot
.016 w
.25166 .18166 m
.25225 .18145 L
s
.008 w
.25225 .18145 Mdot
.016 w
.25225 .18145 m
.25283 .18138 L
s
.008 w
.25283 .18138 Mdot
.016 w
.25283 .18138 m
.25346 .18143 L
s
1 .549 0 r
.008 w
.25346 .18143 Mdot
.016 w
.25346 .18143 m
.25416 .18152 L
s
.008 w
.25416 .18152 Mdot
.016 w
.25416 .18152 m
.25496 .18161 L
s
1 .548 0 r
.008 w
.25496 .18161 Mdot
.016 w
.25496 .18161 m
.25584 .18165 L
s
.008 w
.25584 .18165 Mdot
.016 w
.25584 .18165 m
.25675 .18162 L
s
.008 w
.25675 .18162 Mdot
.016 w
.25675 .18162 m
.2577 .18152 L
s
1 .547 0 r
.008 w
.2577 .18152 Mdot
.016 w
.2577 .18152 m
.25874 .18136 L
s
.008 w
.25874 .18136 Mdot
.016 w
.25874 .18136 m
.25992 .18116 L
s
1 .546 0 r
.008 w
.25992 .18116 Mdot
.016 w
.25992 .18116 m
.26117 .18097 L
s
.008 w
.26117 .18097 Mdot
.016 w
.26117 .18097 m
.26246 .18083 L
s
.008 w
.26246 .18083 Mdot
.016 w
.26246 .18083 m
.26376 .18076 L
s
1 .545 0 r
.008 w
.26376 .18076 Mdot
.016 w
.26376 .18076 m
.26507 .18072 L
s
.008 w
.26507 .18072 Mdot
.016 w
.26507 .18072 m
.26635 .18071 L
s
1 .544 0 r
.008 w
.26635 .18071 Mdot
.016 w
.26635 .18071 m
.26759 .18072 L
s
.008 w
.26759 .18072 Mdot
.016 w
.26759 .18072 m
.2688 .18076 L
s
.008 w
.2688 .18076 Mdot
.016 w
.2688 .18076 m
.26987 .18082 L
s
1 .543 0 r
.008 w
.26987 .18082 Mdot
.016 w
.26987 .18082 m
.27089 .18092 L
s
.008 w
.27089 .18092 Mdot
.016 w
.27089 .18092 m
.27182 .18106 L
s
.008 w
.27182 .18106 Mdot
.016 w
.27182 .18106 m
.2726 .18121 L
s
1 .542 0 r
.008 w
.2726 .18121 Mdot
.016 w
.2726 .18121 m
.2732 .18133 L
s
.008 w
.2732 .18133 Mdot
.016 w
.2732 .18133 m
.27365 .18139 L
s
1 .541 0 r
.008 w
.27365 .18139 Mdot
.016 w
.27365 .18139 m
.27398 .18138 L
s
.008 w
.27398 .18138 Mdot
.016 w
.27398 .18138 m
.27419 .18128 L
s
.008 w
.27419 .18128 Mdot
.016 w
.27419 .18128 m
.27433 .18105 L
s
1 .54 0 r
.008 w
.27433 .18105 Mdot
.016 w
.27433 .18105 m
.27444 .18065 L
s
.008 w
.27444 .18065 Mdot
.016 w
.27444 .18065 m
.27453 .18011 L
s
1 .539 0 r
.008 w
.27453 .18011 Mdot
.016 w
.27453 .18011 m
.27464 .17953 L
s
.008 w
.27464 .17953 Mdot
.016 w
.27464 .17953 m
.2748 .1789 L
s
.008 w
.2748 .1789 Mdot
.016 w
.2748 .1789 m
.27503 .17824 L
s
1 .538 0 r
.008 w
.27503 .17824 Mdot
.016 w
.27503 .17824 m
.27533 .17758 L
s
.008 w
.27533 .17758 Mdot
.016 w
.27533 .17758 m
.27565 .17692 L
s
1 .537 0 r
.008 w
.27565 .17692 Mdot
.016 w
.27565 .17692 m
.27603 .17629 L
s
.008 w
.27603 .17629 Mdot
.016 w
.27603 .17629 m
.27646 .17571 L
s
.008 w
.27646 .17571 Mdot
.016 w
.27646 .17571 m
.27695 .17519 L
s
1 .536 0 r
.008 w
.27695 .17519 Mdot
.016 w
.27695 .17519 m
.27745 .17474 L
s
.008 w
.27745 .17474 Mdot
.016 w
.27745 .17474 m
.27793 .17439 L
s
1 .535 0 r
.008 w
.27793 .17439 Mdot
.016 w
.27793 .17439 m
.27836 .17417 L
s
.008 w
.27836 .17417 Mdot
.016 w
.27836 .17417 m
.27872 .17406 L
s
.008 w
.27872 .17406 Mdot
.016 w
.27872 .17406 m
.27903 .17404 L
s
1 .534 0 r
.008 w
.27903 .17404 Mdot
.016 w
.27903 .17404 m
.27929 .17408 L
s
.008 w
.27929 .17408 Mdot
.016 w
.27929 .17408 m
.27953 .17414 L
s
1 .533 0 r
.008 w
.27953 .17414 Mdot
.016 w
.27953 .17414 m
.27978 .17417 L
s
.008 w
.27978 .17417 Mdot
.016 w
.27978 .17417 m
.28007 .17411 L
s
.008 w
.28007 .17411 Mdot
.016 w
.28007 .17411 m
.28041 .17394 L
s
1 .532 0 r
.008 w
.28041 .17394 Mdot
.016 w
.28041 .17394 m
.28081 .17359 L
s
.008 w
.28081 .17359 Mdot
.016 w
.28081 .17359 m
.28126 .17302 L
s
1 .531 0 r
.008 w
.28126 .17302 Mdot
.016 w
.28126 .17302 m
.2818 .17221 L
s
.008 w
.2818 .17221 Mdot
.016 w
.2818 .17221 m
.28244 .17121 L
s
.008 w
.28244 .17121 Mdot
.016 w
.28244 .17121 m
.28315 .16994 L
s
1 .53 0 r
.008 w
.28315 .16994 Mdot
.016 w
.28315 .16994 m
.28403 .16855 L
s
.008 w
.28403 .16855 Mdot
.016 w
.28403 .16855 m
.28499 .16694 L
s
.008 w
.28499 .16694 Mdot
.016 w
.28499 .16694 m
.28612 .16518 L
s
1 .529 0 r
.008 w
.28612 .16518 Mdot
.016 w
.28612 .16518 m
.28742 .16337 L
s
.008 w
.28742 .16337 Mdot
.016 w
.28742 .16337 m
.28888 .16162 L
s
1 .528 0 r
.008 w
.28888 .16162 Mdot
.016 w
.28888 .16162 m
.29057 .15979 L
s
.008 w
.29057 .15979 Mdot
.016 w
.29057 .15979 m
.2922 .15816 L
s
.008 w
.2922 .15816 Mdot
.016 w
.2922 .15816 m
.29406 .15648 L
s
1 .527 0 r
.008 w
.29406 .15648 Mdot
.016 w
.29406 .15648 m
.29577 .15507 L
s
.008 w
.29577 .15507 Mdot
.016 w
.29577 .15507 m
.29772 .1537 L
s
1 .526 0 r
.008 w
.29772 .1537 Mdot
.016 w
.29772 .1537 m
.29967 .15251 L
s
.008 w
.29967 .15251 Mdot
.016 w
.29967 .15251 m
.30176 .15141 L
s
.008 w
.30176 .15141 Mdot
.016 w
.30176 .15141 m
.30398 .15037 L
s
1 .525 0 r
.008 w
.30398 .15037 Mdot
.016 w
.30398 .15037 m
.30609 .14939 L
s
.008 w
.30609 .14939 Mdot
.016 w
.30609 .14939 m
.30825 .14851 L
s
1 .524 0 r
.008 w
.30825 .14851 Mdot
.016 w
.30825 .14851 m
.3104 .14762 L
s
.008 w
.3104 .14762 Mdot
.016 w
.3104 .14762 m
.31248 .14669 L
s
.008 w
.31248 .14669 Mdot
.016 w
.31248 .14669 m
.31458 .14567 L
s
1 .523 0 r
.008 w
.31458 .14567 Mdot
.016 w
.31458 .14567 m
.31668 .14463 L
s
.008 w
.31668 .14463 Mdot
.016 w
.31668 .14463 m
.31875 .14344 L
s
1 .522 0 r
.008 w
.31875 .14344 Mdot
.016 w
.31875 .14344 m
.32101 .14208 L
s
.008 w
.32101 .14208 Mdot
.016 w
.32101 .14208 m
.32313 .14068 L
s
.008 w
.32313 .14068 Mdot
.016 w
.32313 .14068 m
.32538 .13916 L
s
1 .521 0 r
.008 w
.32538 .13916 Mdot
.016 w
.32538 .13916 m
.32775 .13762 L
s
.008 w
.32775 .13762 Mdot
.016 w
.32775 .13762 m
.32997 .13594 L
s
1 .52 0 r
.008 w
.32997 .13594 Mdot
.016 w
.32997 .13594 m
.33231 .13436 L
s
.008 w
.33231 .13436 Mdot
.016 w
.33231 .13436 m
.33478 .13268 L
s
.008 w
.33478 .13268 Mdot
.016 w
.33478 .13268 m
.3371 .13098 L
s
1 .519 0 r
.008 w
.3371 .13098 Mdot
.016 w
.3371 .13098 m
.33952 .12953 L
s
.008 w
.33952 .12953 Mdot
.016 w
.33952 .12953 m
.34202 .12811 L
s
.008 w
.34202 .12811 Mdot
.016 w
.34202 .12811 m
.34432 .12672 L
s
1 .518 0 r
.008 w
.34432 .12672 Mdot
.016 w
.34432 .12672 m
.34663 .12547 L
s
.008 w
.34663 .12547 Mdot
.016 w
.34663 .12547 m
.34879 .12437 L
s
1 .517 0 r
.008 w
.34879 .12437 Mdot
.016 w
.34879 .12437 m
.35084 .12336 L
s
.008 w
.35084 .12336 Mdot
.016 w
.35084 .12336 m
.35252 .12247 L
s
.008 w
.35252 .12247 Mdot
.016 w
.35252 .12247 m
.35404 .12167 L
s
1 .516 0 r
.008 w
.35404 .12167 Mdot
.016 w
.35404 .12167 m
.3553 .12097 L
s
.008 w
.3553 .12097 Mdot
.016 w
.3553 .12097 m
.35635 .12036 L
s
1 .515 0 r
.008 w
.35635 .12036 Mdot
.016 w
.35635 .12036 m
.35715 .11983 L
s
.008 w
.35715 .11983 Mdot
.016 w
.35715 .11983 m
.35774 .11939 L
s
.008 w
.35774 .11939 Mdot
.016 w
.35774 .11939 m
.35814 .11901 L
s
1 .514 0 r
.008 w
.35814 .11901 Mdot
.016 w
.35814 .11901 m
.35837 .11867 L
s
.008 w
.35837 .11867 Mdot
.016 w
.35837 .11867 m
.35845 .1184 L
s
1 .513 0 r
.008 w
.35845 .1184 Mdot
.016 w
.35845 .1184 m
.35841 .11819 L
s
.008 w
.35841 .11819 Mdot
.016 w
.35841 .11819 m
.35829 .11801 L
s
.008 w
.35829 .11801 Mdot
.016 w
.35829 .11801 m
.35813 .11789 L
s
1 .512 0 r
.008 w
.35813 .11789 Mdot
.016 w
.35813 .11789 m
.35797 .11783 L
s
.008 w
.35797 .11783 Mdot
.016 w
.35797 .11783 m
.35781 .11782 L
s
1 .511 0 r
.008 w
.35781 .11782 Mdot
.016 w
.35781 .11782 m
.35768 .11786 L
s
.008 w
.35768 .11786 Mdot
.016 w
.35768 .11786 m
.35761 .11792 L
s
.008 w
.35761 .11792 Mdot
.016 w
.35761 .11792 m
.35761 .11799 L
s
1 .51 0 r
.008 w
.35761 .11799 Mdot
.016 w
.35761 .11799 m
.35771 .11804 L
s
.008 w
.35771 .11804 Mdot
.016 w
.35771 .11804 m
.35794 .11807 L
s
1 .509 0 r
.008 w
.35794 .11807 Mdot
.016 w
.35794 .11807 m
.35833 .11808 L
s
.008 w
.35833 .11808 Mdot
.016 w
.35833 .11808 m
.35891 .11808 L
s
.008 w
.35891 .11808 Mdot
.016 w
.35891 .11808 m
.35969 .11808 L
s
1 .508 0 r
.008 w
.35969 .11808 Mdot
.016 w
.35969 .11808 m
.36066 .11809 L
s
.008 w
.36066 .11809 Mdot
.016 w
.36066 .11809 m
.36184 .11812 L
s
1 .507 0 r
.008 w
.36184 .11812 Mdot
.016 w
.36184 .11812 m
.36321 .11819 L
s
.008 w
.36321 .11819 Mdot
.016 w
.36321 .11819 m
.36453 .11828 L
s
.008 w
.36453 .11828 Mdot
.016 w
.36453 .11828 m
.36596 .11837 L
s
1 .506 0 r
.008 w
.36596 .11837 Mdot
.016 w
.36596 .11837 m
.36731 .11843 L
s
.008 w
.36731 .11843 Mdot
.016 w
.36731 .11843 m
.3687 .11846 L
s
.008 w
.3687 .11846 Mdot
.016 w
.3687 .11846 m
.36985 .11841 L
s
1 .505 0 r
.008 w
.36985 .11841 Mdot
.016 w
.36985 .11841 m
.37092 .11829 L
s
.008 w
.37092 .11829 Mdot
.016 w
.37092 .11829 m
.37191 .11807 L
s
1 .504 0 r
.008 w
.37191 .11807 Mdot
.016 w
.37191 .11807 m
.37271 .11779 L
s
.008 w
.37271 .11779 Mdot
.016 w
.37271 .11779 m
.37341 .11744 L
s
.008 w
.37341 .11744 Mdot
.016 w
.37341 .11744 m
.37404 .11706 L
s
1 .503 0 r
.008 w
.37404 .11706 Mdot
.016 w
.37404 .11706 m
.37462 .11665 L
s
.008 w
.37462 .11665 Mdot
.016 w
.37462 .11665 m
.37517 .11624 L
s
1 .502 0 r
.008 w
.37517 .11624 Mdot
.016 w
.37517 .11624 m
.37568 .11584 L
s
.008 w
.37568 .11584 Mdot
.016 w
.37568 .11584 m
.37616 .11545 L
s
.008 w
.37616 .11545 Mdot
.016 w
.37616 .11545 m
.37666 .11508 L
s
1 .501 0 r
.008 w
.37666 .11508 Mdot
.016 w
.37666 .11508 m
.37722 .11476 L
s
.008 w
.37722 .11476 Mdot
.016 w
.37722 .11476 m
.37784 .1145 L
s
1 .5 0 r
.008 w
.37784 .1145 Mdot
.016 w
.37784 .1145 m
.37848 .1143 L
s
.008 w
.37848 .1143 Mdot
.016 w
.37848 .1143 m
.37912 .11418 L
s
.008 w
.37912 .11418 Mdot
.016 w
.37912 .11418 m
.37968 .11413 L
s
1 .499 0 r
.008 w
.37968 .11413 Mdot
.016 w
.37968 .11413 m
.38018 .11414 L
s
.008 w
.38018 .11414 Mdot
.016 w
.38018 .11414 m
.3806 .11422 L
s
1 .498 0 r
.008 w
.3806 .11422 Mdot
.016 w
.3806 .11422 m
.38095 .11435 L
s
.008 w
.38095 .11435 Mdot
.016 w
.38095 .11435 m
.38122 .11454 L
s
.008 w
.38122 .11454 Mdot
.016 w
.38122 .11454 m
.38142 .11477 L
s
1 .497 0 r
.008 w
.38142 .11477 Mdot
.016 w
.38142 .11477 m
.38158 .11504 L
s
.008 w
.38158 .11504 Mdot
.016 w
.38158 .11504 m
.38178 .11533 L
s
1 .496 0 r
.008 w
.38178 .11533 Mdot
.016 w
.38178 .11533 m
.38202 .1156 L
s
.008 w
.38202 .1156 Mdot
.016 w
.38202 .1156 m
.3823 .1158 L
s
.008 w
.3823 .1158 Mdot
.016 w
.3823 .1158 m
.3826 .11594 L
s
1 .495 0 r
.008 w
.3826 .11594 Mdot
.016 w
.3826 .11594 m
.38294 .11601 L
s
.008 w
.38294 .11601 Mdot
.016 w
.38294 .11601 m
.3833 .11607 L
s
1 .494 0 r
.008 w
.3833 .11607 Mdot
.016 w
.3833 .11607 m
.38366 .11615 L
s
.008 w
.38366 .11615 Mdot
.016 w
.38366 .11615 m
.38403 .11623 L
s
.008 w
.38403 .11623 Mdot
.016 w
.38403 .11623 m
.38441 .11634 L
s
1 .493 0 r
.008 w
.38441 .11634 Mdot
.016 w
.38441 .11634 m
.3848 .11645 L
s
.008 w
.3848 .11645 Mdot
.016 w
.3848 .11645 m
.38525 .11654 L
s
.008 w
.38525 .11654 Mdot
.016 w
.38525 .11654 m
.38579 .11662 L
s
1 .492 0 r
.008 w
.38579 .11662 Mdot
.016 w
.38579 .11662 m
.38641 .11669 L
s
.008 w
.38641 .11669 Mdot
.016 w
.38641 .11669 m
.3872 .11678 L
s
1 .491 0 r
.008 w
.3872 .11678 Mdot
.016 w
.3872 .11678 m
.38798 .11692 L
s
.008 w
.38798 .11692 Mdot
.016 w
.38798 .11692 m
.38898 .11719 L
s
.008 w
.38898 .11719 Mdot
.016 w
.38898 .11719 m
.39016 .11759 L
s
1 .49 0 r
.008 w
.39016 .11759 Mdot
.016 w
.39016 .11759 m
.39139 .11812 L
s
.008 w
.39139 .11812 Mdot
.016 w
.39139 .11812 m
.39285 .11872 L
s
1 .489 0 r
.008 w
.39285 .11872 Mdot
.016 w
.39285 .11872 m
.39439 .11936 L
s
.008 w
.39439 .11936 Mdot
.016 w
.39439 .11936 m
.39621 .12001 L
s
.008 w
.39621 .12001 Mdot
.016 w
.39621 .12001 m
.39826 .12062 L
s
1 .488 0 r
.008 w
.39826 .12062 Mdot
.016 w
.39826 .12062 m
.40015 .12115 L
s
.008 w
.40015 .12115 Mdot
.016 w
.40015 .12115 m
.40225 .1216 L
s
1 .487 0 r
.008 w
.40225 .1216 Mdot
.016 w
.40225 .1216 m
.40436 .12202 L
s
.008 w
.40436 .12202 Mdot
.016 w
.40436 .12202 m
.40648 .12242 L
s
.008 w
.40648 .12242 Mdot
.016 w
.40648 .12242 m
.4087 .1228 L
s
1 .486 0 r
.008 w
.4087 .1228 Mdot
.016 w
.4087 .1228 m
.41075 .12317 L
s
.008 w
.41075 .12317 Mdot
.016 w
.41075 .12317 m
.41277 .12351 L
s
1 .485 0 r
.008 w
.41277 .12351 Mdot
.016 w
.41277 .12351 m
.41472 .12379 L
s
.008 w
.41472 .12379 Mdot
.016 w
.41472 .12379 m
.41647 .12399 L
s
.008 w
.41647 .12399 Mdot
.016 w
.41647 .12399 m
.4182 .1241 L
s
1 .484 0 r
.008 w
.4182 .1241 Mdot
.016 w
.4182 .1241 m
.41971 .1241 L
s
.008 w
.41971 .1241 Mdot
.016 w
.41971 .1241 m
.42102 .124 L
s
1 .483 0 r
.008 w
.42102 .124 Mdot
.016 w
.42102 .124 m
.42201 .12382 L
s
.008 w
.42201 .12382 Mdot
.016 w
.42201 .12382 m
.42277 .12357 L
s
.008 w
.42277 .12357 Mdot
.016 w
.42277 .12357 m
.4233 .1233 L
s
1 .482 0 r
.008 w
.4233 .1233 Mdot
.016 w
.4233 .1233 m
.42368 .12302 L
s
.008 w
.42368 .12302 Mdot
.016 w
.42368 .12302 m
.42394 .12272 L
s
1 .481 0 r
.008 w
.42394 .12272 Mdot
.016 w
.42394 .12272 m
.42415 .12241 L
s
.008 w
.42415 .12241 Mdot
.016 w
.42415 .12241 m
.42439 .12205 L
s
.008 w
.42439 .12205 Mdot
.016 w
.42439 .12205 m
.42474 .12166 L
s
1 .48 0 r
.008 w
.42474 .12166 Mdot
.016 w
.42474 .12166 m
.42526 .12119 L
s
.008 w
.42526 .12119 Mdot
.016 w
.42526 .12119 m
.42598 .12064 L
s
.008 w
.42598 .12064 Mdot
.016 w
.42598 .12064 m
.42689 .12004 L
s
1 .479 0 r
.008 w
.42689 .12004 Mdot
.016 w
.42689 .12004 m
.42794 .11933 L
s
.008 w
.42794 .11933 Mdot
.016 w
.42794 .11933 m
.4292 .11874 L
s
1 .478 0 r
.008 w
.4292 .11874 Mdot
.016 w
.4292 .11874 m
.43065 .1181 L
s
.008 w
.43065 .1181 Mdot
.016 w
.43065 .1181 m
.43227 .11748 L
s
.008 w
.43227 .11748 Mdot
.016 w
.43227 .11748 m
.43392 .11694 L
s
1 .477 0 r
.008 w
.43392 .11694 Mdot
.016 w
.43392 .11694 m
.43556 .11642 L
s
.008 w
.43556 .11642 Mdot
.016 w
.43556 .11642 m
.43721 .11589 L
s
1 .476 0 r
.008 w
.43721 .11589 Mdot
.016 w
.43721 .11589 m
.43852 .1154 L
s
.008 w
.43852 .1154 Mdot
.016 w
.43852 .1154 m
.43969 .11493 L
s
.008 w
.43969 .11493 Mdot
.016 w
.43969 .11493 m
.44058 .11451 L
s
1 .475 0 r
.008 w
.44058 .11451 Mdot
.016 w
.44058 .11451 m
.4413 .11418 L
s
.008 w
.4413 .11418 Mdot
.016 w
.4413 .11418 m
.44182 .11395 L
s
1 .474 0 r
.008 w
.44182 .11395 Mdot
.016 w
.44182 .11395 m
.44214 .11384 L
s
.008 w
.44214 .11384 Mdot
.016 w
.44214 .11384 m
.44237 .11383 L
s
.008 w
.44237 .11383 Mdot
.016 w
.44237 .11383 m
.44262 .11389 L
s
1 .473 0 r
.008 w
.44262 .11389 Mdot
.016 w
.44262 .11389 m
.44298 .11396 L
s
.008 w
.44298 .11396 Mdot
.016 w
.44298 .11396 m
.44348 .11404 L
s
1 .472 0 r
.008 w
.44348 .11404 Mdot
.016 w
.44348 .11404 m
.44419 .1141 L
s
.008 w
.44419 .1141 Mdot
.016 w
.44419 .1141 m
.44513 .11415 L
s
.008 w
.44513 .11415 Mdot
.016 w
.44513 .11415 m
.44633 .11418 L
s
1 .471 0 r
.008 w
.44633 .11418 Mdot
.016 w
.44633 .11418 m
.44759 .11423 L
s
.008 w
.44759 .11423 Mdot
.016 w
.44759 .11423 m
.44929 .11429 L
s
1 .47 0 r
.008 w
.44929 .11429 Mdot
.016 w
.44929 .11429 m
.45106 .11439 L
s
.008 w
.45106 .11439 Mdot
.016 w
.45106 .11439 m
.45309 .11452 L
s
.008 w
.45309 .11452 Mdot
.016 w
.45309 .11452 m
.45538 .11469 L
s
1 .469 0 r
.008 w
.45538 .11469 Mdot
.016 w
.45538 .11469 m
.45752 .11489 L
s
.008 w
.45752 .11489 Mdot
.016 w
.45752 .11489 m
.45987 .11512 L
s
.008 w
.45987 .11512 Mdot
.016 w
.45987 .11512 m
.46208 .11536 L
s
1 .468 0 r
.008 w
.46208 .11536 Mdot
.016 w
.46208 .11536 m
.46425 .11562 L
s
.008 w
.46425 .11562 Mdot
.016 w
.46425 .11562 m
.46633 .11587 L
s
1 .467 0 r
.008 w
.46633 .11587 Mdot
.016 w
.46633 .11587 m
.46818 .11609 L
s
.008 w
.46818 .11609 Mdot
.016 w
.46818 .11609 m
.46987 .11627 L
s
.008 w
.46987 .11627 Mdot
.016 w
.46987 .11627 m
.47139 .11642 L
s
1 .466 0 r
.008 w
.47139 .11642 Mdot
.016 w
.47139 .11642 m
.47267 .11655 L
s
.008 w
.47267 .11655 Mdot
.016 w
.47267 .11655 m
.4738 .11667 L
s
1 .465 0 r
.008 w
.4738 .11667 Mdot
.016 w
.4738 .11667 m
.47474 .11681 L
s
.008 w
.47474 .11681 Mdot
.016 w
.47474 .11681 m
.47546 .11698 L
s
.008 w
.47546 .11698 Mdot
.016 w
.47546 .11698 m
.47597 .11719 L
s
1 .464 0 r
.008 w
.47597 .11719 Mdot
.016 w
.47597 .11719 m
.47629 .11745 L
s
.008 w
.47629 .11745 Mdot
.016 w
.47629 .11745 m
.47646 .11775 L
s
1 .463 0 r
.008 w
.47646 .11775 Mdot
.016 w
.47646 .11775 m
.47651 .1181 L
s
.008 w
.47651 .1181 Mdot
.016 w
.47651 .1181 m
.47648 .1185 L
s
.008 w
.47648 .1185 Mdot
.016 w
.47648 .1185 m
.4764 .11891 L
s
1 .462 0 r
.008 w
.4764 .11891 Mdot
.016 w
.4764 .11891 m
.4763 .11933 L
s
.008 w
.4763 .11933 Mdot
.016 w
.4763 .11933 m
.47621 .11977 L
s
1 .461 0 r
.008 w
.47621 .11977 Mdot
.016 w
.47621 .11977 m
.47613 .12019 L
s
.008 w
.47613 .12019 Mdot
.016 w
.47613 .12019 m
.47602 .12057 L
s
.008 w
.47602 .12057 Mdot
.016 w
.47602 .12057 m
.47589 .12087 L
s
1 .46 0 r
.008 w
.47589 .12087 Mdot
.016 w
.47589 .12087 m
.47574 .12105 L
s
.008 w
.47574 .12105 Mdot
.016 w
.47574 .12105 m
.4756 .12108 L
s
1 .459 0 r
.008 w
.4756 .12108 Mdot
.016 w
.4756 .12108 m
.47553 .12097 L
s
.008 w
.47553 .12097 Mdot
.016 w
.47553 .12097 m
.47556 .12072 L
s
.008 w
.47556 .12072 Mdot
.016 w
.47556 .12072 m
.47572 .12039 L
s
1 .458 0 r
.008 w
.47572 .12039 Mdot
.016 w
.47572 .12039 m
.47605 .11998 L
s
.008 w
.47605 .11998 Mdot
.016 w
.47605 .11998 m
.47658 .11958 L
s
1 .457 0 r
.008 w
.47658 .11958 Mdot
.016 w
.47658 .11958 m
.47734 .11916 L
s
.008 w
.47734 .11916 Mdot
.016 w
.47734 .11916 m
.47836 .11879 L
s
.008 w
.47836 .11879 Mdot
.016 w
.47836 .11879 m
.47955 .11843 L
s
1 .456 0 r
.008 w
.47955 .11843 Mdot
.016 w
.47955 .11843 m
.48106 .11809 L
s
.008 w
.48106 .11809 Mdot
.016 w
.48106 .11809 m
.48255 .11779 L
s
.008 w
.48255 .11779 Mdot
.016 w
.48255 .11779 m
.48442 .11755 L
s
1 .455 0 r
.008 w
.48442 .11755 Mdot
.016 w
.48442 .11755 m
.48635 .11734 L
s
.008 w
.48635 .11734 Mdot
.016 w
.48635 .11734 m
.48826 .11716 L
s
1 .454 0 r
.008 w
.48826 .11716 Mdot
.016 w
.48826 .11716 m
.49045 .11696 L
s
.008 w
.49045 .11696 Mdot
.016 w
.49045 .11696 m
.4927 .11673 L
s
.008 w
.4927 .11673 Mdot
.016 w
.4927 .11673 m
.49499 .11646 L
s
1 .453 0 r
.008 w
.49499 .11646 Mdot
.016 w
.49499 .11646 m
.49727 .11615 L
s
.008 w
.49727 .11615 Mdot
.016 w
.49727 .11615 m
.49946 .11578 L
s
1 .452 0 r
.008 w
.49946 .11578 Mdot
.016 w
.49946 .11578 m
.50154 .11539 L
s
.008 w
.50154 .11539 Mdot
.016 w
.50154 .11539 m
.50359 .11494 L
s
.008 w
.50359 .11494 Mdot
.016 w
.50359 .11494 m
.50529 .11447 L
s
1 .451 0 r
.008 w
.50529 .11447 Mdot
.016 w
.50529 .11447 m
.50682 .114 L
s
.008 w
.50682 .114 Mdot
.016 w
.50682 .114 m
.5083 .11357 L
s
1 .45 0 r
.008 w
.5083 .11357 Mdot
.016 w
.5083 .11357 m
.5095 .11316 L
s
.008 w
.5095 .11316 Mdot
.016 w
.5095 .11316 m
.51055 .11277 L
s
.008 w
.51055 .11277 Mdot
.016 w
.51055 .11277 m
.51133 .11238 L
s
1 .449 0 r
.008 w
.51133 .11238 Mdot
.016 w
.51133 .11238 m
.51191 .11211 L
s
.008 w
.51191 .11211 Mdot
.016 w
.51191 .11211 m
.51228 .1119 L
s
1 .448 0 r
.008 w
.51228 .1119 Mdot
.016 w
.51228 .1119 m
.51246 .1118 L
s
.008 w
.51246 .1118 Mdot
.016 w
.51246 .1118 m
.51246 .11182 L
s
.008 w
.51246 .11182 Mdot
.016 w
.51246 .11182 m
.51231 .11194 L
s
1 .447 0 r
.008 w
.51231 .11194 Mdot
.016 w
.51231 .11194 m
.51205 .11216 L
s
.008 w
.51205 .11216 Mdot
.016 w
.51205 .11216 m
.51174 .11243 L
s
1 .446 0 r
.008 w
.51174 .11243 Mdot
.016 w
.51174 .11243 m
.51145 .11274 L
s
.008 w
.51145 .11274 Mdot
.016 w
.51145 .11274 m
.51122 .11309 L
s
.008 w
.51122 .11309 Mdot
.016 w
.51122 .11309 m
.51105 .11345 L
s
1 .445 0 r
.008 w
.51105 .11345 Mdot
.016 w
.51105 .11345 m
.51093 .11384 L
s
.008 w
.51093 .11384 Mdot
.016 w
.51093 .11384 m
.51085 .11422 L
s
1 .444 0 r
.008 w
.51085 .11422 Mdot
.016 w
.51085 .11422 m
.5108 .11462 L
s
.008 w
.5108 .11462 Mdot
.016 w
.5108 .11462 m
.5108 .11503 L
s
.008 w
.5108 .11503 Mdot
.016 w
.5108 .11503 m
.51085 .11535 L
s
1 .443 0 r
.008 w
.51085 .11535 Mdot
.016 w
.51085 .11535 m
.51094 .11565 L
s
.008 w
.51094 .11565 Mdot
.016 w
.51094 .11565 m
.51109 .11587 L
s
.008 w
.51109 .11587 Mdot
.016 w
.51109 .11587 m
.5113 .11603 L
s
1 .442 0 r
.008 w
.5113 .11603 Mdot
.016 w
.5113 .11603 m
.51157 .11612 L
s
.008 w
.51157 .11612 Mdot
.016 w
.51157 .11612 m
.51188 .11616 L
s
1 .441 0 r
.008 w
.51188 .11616 Mdot
.016 w
.51188 .11616 m
.51222 .11618 L
s
.008 w
.51222 .11618 Mdot
.016 w
.51222 .11618 m
.5126 .11621 L
s
.008 w
.5126 .11621 Mdot
.016 w
.5126 .11621 m
.51296 .11625 L
s
1 .44 0 r
.008 w
.51296 .11625 Mdot
.016 w
.51296 .11625 m
.5133 .1163 L
s
.008 w
.5133 .1163 Mdot
.016 w
.5133 .1163 m
.51357 .11633 L
s
1 .439 0 r
.008 w
.51357 .11633 Mdot
.016 w
.51357 .11633 m
.51374 .1163 L
s
.008 w
.51374 .1163 Mdot
.016 w
.51374 .1163 m
.51382 .11622 L
s
.008 w
.51382 .11622 Mdot
.016 w
.51382 .11622 m
.51382 .11605 L
s
1 .438 0 r
.008 w
.51382 .11605 Mdot
.016 w
.51382 .11605 m
.51377 .11582 L
s
.008 w
.51377 .11582 Mdot
.016 w
.51377 .11582 m
.51369 .11551 L
s
1 .437 0 r
.008 w
.51369 .11551 Mdot
.016 w
.51369 .11551 m
.51354 .11516 L
s
.008 w
.51354 .11516 Mdot
.016 w
.51354 .11516 m
.51332 .11479 L
s
.008 w
.51332 .11479 Mdot
.016 w
.51332 .11479 m
.51302 .11441 L
s
1 .436 0 r
.008 w
.51302 .11441 Mdot
.016 w
.51302 .11441 m
.51267 .11403 L
s
.008 w
.51267 .11403 Mdot
.016 w
.51267 .11403 m
.51226 .11364 L
s
1 .435 0 r
.008 w
.51226 .11364 Mdot
.016 w
.51226 .11364 m
.51181 .11322 L
s
.008 w
.51181 .11322 Mdot
.016 w
.51181 .11322 m
.51133 .11278 L
s
.008 w
.51133 .11278 Mdot
.016 w
.51133 .11278 m
.51085 .11236 L
s
1 .434 0 r
.008 w
.51085 .11236 Mdot
.016 w
.51085 .11236 m
.51035 .11198 L
s
.008 w
.51035 .11198 Mdot
.016 w
.51035 .11198 m
.50986 .11167 L
s
1 .433 0 r
.008 w
.50986 .11167 Mdot
.016 w
.50986 .11167 m
.50938 .11143 L
s
.008 w
.50938 .11143 Mdot
.016 w
.50938 .11143 m
.50895 .11123 L
s
.008 w
.50895 .11123 Mdot
.016 w
.50895 .11123 m
.50856 .11105 L
s
1 .432 0 r
.008 w
.50856 .11105 Mdot
.016 w
.50856 .11105 m
.50813 .11087 L
s
.008 w
.50813 .11087 Mdot
.016 w
.50813 .11087 m
.50769 .11065 L
s
1 .431 0 r
.008 w
.50769 .11065 Mdot
.016 w
.50769 .11065 m
.50719 .11039 L
s
.008 w
.50719 .11039 Mdot
.016 w
.50719 .11039 m
.50664 .11009 L
s
.008 w
.50664 .11009 Mdot
.016 w
.50664 .11009 m
.50599 .10974 L
s
1 .43 0 r
.008 w
.50599 .10974 Mdot
.016 w
.50599 .10974 m
.50521 .10939 L
s
.008 w
.50521 .10939 Mdot
.016 w
.50521 .10939 m
.50418 .10906 L
s
.008 w
.50418 .10906 Mdot
.016 w
.50418 .10906 m
.50285 .10878 L
s
1 .429 0 r
.008 w
.50285 .10878 Mdot
.016 w
.50285 .10878 m
.5012 .10851 L
s
.008 w
.5012 .10851 Mdot
.016 w
.5012 .10851 m
.49914 .10825 L
s
1 .428 0 r
.008 w
.49914 .10825 Mdot
.016 w
.49914 .10825 m
.49694 .10802 L
s
.008 w
.49694 .10802 Mdot
.016 w
.49694 .10802 m
.49431 .1078 L
s
.008 w
.49431 .1078 Mdot
.016 w
.49431 .1078 m
.49146 .10759 L
s
1 .427 0 r
.008 w
.49146 .10759 Mdot
.016 w
.49146 .10759 m
.48856 .10738 L
s
.008 w
.48856 .10738 Mdot
.016 w
.48856 .10738 m
.48527 .1072 L
s
1 .426 0 r
.008 w
.48527 .1072 Mdot
.016 w
.48527 .1072 m
.48253 .10705 L
s
.008 w
.48253 .10705 Mdot
.016 w
.48253 .10705 m
.47911 .10695 L
s
.008 w
.47911 .10695 Mdot
.016 w
.47911 .10695 m
.47637 .1069 L
s
1 .425 0 r
.008 w
.47637 .1069 Mdot
.016 w
.47637 .1069 m
.47295 .10687 L
s
.008 w
.47295 .10687 Mdot
.016 w
.47295 .10687 m
.47022 .10683 L
s
1 .424 0 r
.008 w
.47022 .10683 Mdot
.016 w
.47022 .10683 m
.46738 .10676 L
s
.008 w
.46738 .10676 Mdot
.016 w
.46738 .10676 m
.46439 .10669 L
s
.008 w
.46439 .10669 Mdot
.016 w
.46439 .10669 m
.4618 .10661 L
s
1 .423 0 r
.008 w
.4618 .10661 Mdot
.016 w
.4618 .10661 m
.45899 .10653 L
s
.008 w
.45899 .10653 Mdot
.016 w
.45899 .10653 m
.45596 .10643 L
s
1 .422 0 r
.008 w
.45596 .10643 Mdot
.016 w
.45596 .10643 m
.4534 .10631 L
s
.008 w
.4534 .10631 Mdot
.016 w
.4534 .10631 m
.45009 .10616 L
s
.008 w
.45009 .10616 Mdot
.016 w
.45009 .10616 m
.44739 .10602 L
s
1 .421 0 r
.008 w
.44739 .10602 Mdot
.016 w
.44739 .10602 m
.44436 .1059 L
s
.008 w
.44436 .1059 Mdot
.016 w
.44436 .1059 m
.44077 .10582 L
s
1 .42 0 r
.008 w
.44077 .10582 Mdot
.016 w
.44077 .10582 m
.43764 .10581 L
s
.008 w
.43764 .10581 Mdot
.016 w
.43764 .10581 m
.43413 .10588 L
s
.008 w
.43413 .10588 Mdot
.016 w
.43413 .10588 m
.43076 .10602 L
s
1 .419 0 r
.008 w
.43076 .10602 Mdot
.016 w
.43076 .10602 m
.42708 .10624 L
s
.008 w
.42708 .10624 Mdot
.016 w
.42708 .10624 m
.42413 .10653 L
s
.008 w
.42413 .10653 Mdot
.016 w
.42413 .10653 m
.42105 .10687 L
s
1 .418 0 r
.008 w
.42105 .10687 Mdot
.016 w
.42105 .10687 m
.41822 .10725 L
s
.008 w
.41822 .10725 Mdot
.016 w
.41822 .10725 m
.41552 .10764 L
s
1 .417 0 r
.008 w
.41552 .10764 Mdot
.016 w
.41552 .10764 m
.4132 .10803 L
s
.008 w
.4132 .10803 Mdot
.016 w
.4132 .10803 m
.41119 .10838 L
s
.008 w
.41119 .10838 Mdot
.016 w
.41119 .10838 m
.40942 .10865 L
s
1 .416 0 r
.008 w
.40942 .10865 Mdot
.016 w
.40942 .10865 m
.40808 .10881 L
s
.008 w
.40808 .10881 Mdot
.016 w
.40808 .10881 m
.40702 .10887 L
s
1 .415 0 r
.008 w
.40702 .10887 Mdot
.016 w
.40702 .10887 m
.40624 .10881 L
s
.008 w
.40624 .10881 Mdot
.016 w
.40624 .10881 m
.4057 .10866 L
s
.008 w
.4057 .10866 Mdot
.016 w
.4057 .10866 m
.4054 .10844 L
s
1 .414 0 r
.008 w
.4054 .10844 Mdot
.016 w
.4054 .10844 m
.40528 .1082 L
s
.008 w
.40528 .1082 Mdot
.016 w
.40528 .1082 m
.40531 .10795 L
s
1 .413 0 r
.008 w
.40531 .10795 Mdot
.016 w
.40531 .10795 m
.40542 .10775 L
s
.008 w
.40542 .10775 Mdot
.016 w
.40542 .10775 m
.4056 .10761 L
s
.008 w
.4056 .10761 Mdot
.016 w
.4056 .10761 m
.40578 .10754 L
s
1 .412 0 r
.008 w
.40578 .10754 Mdot
.016 w
.40578 .10754 m
.40592 .10753 L
s
.008 w
.40592 .10753 Mdot
.016 w
.40592 .10753 m
.40603 .10757 L
s
1 .411 0 r
.008 w
.40603 .10757 Mdot
.016 w
.40603 .10757 m
.40611 .10768 L
s
.008 w
.40611 .10768 Mdot
.016 w
.40611 .10768 m
.40616 .10785 L
s
.008 w
.40616 .10785 Mdot
.016 w
.40616 .10785 m
.40619 .10809 L
s
1 .41 0 r
.008 w
.40619 .10809 Mdot
.016 w
.40619 .10809 m
.40623 .10831 L
s
.008 w
.40623 .10831 Mdot
.016 w
.40623 .10831 m
.40624 .10857 L
s
1 .409 0 r
.008 w
.40624 .10857 Mdot
.016 w
.40624 .10857 m
.40625 .10881 L
s
.008 w
.40625 .10881 Mdot
.016 w
.40625 .10881 m
.40624 .109 L
s
.008 w
.40624 .109 Mdot
.016 w
.40624 .109 m
.40623 .10912 L
s
1 .408 0 r
.008 w
.40623 .10912 Mdot
.016 w
.40623 .10912 m
.40625 .10917 L
s
.008 w
.40625 .10917 Mdot
.016 w
.40625 .10917 m
.40633 .10919 L
s
1 .407 0 r
.008 w
.40633 .10919 Mdot
.016 w
.40633 .10919 m
.40643 .10918 L
s
.008 w
.40643 .10918 Mdot
.016 w
.40643 .10918 m
.40653 .10916 L
s
.008 w
.40653 .10916 Mdot
.016 w
.40653 .10916 m
.40658 .10914 L
s
1 .406 0 r
.008 w
.40658 .10914 Mdot
.016 w
.40658 .10914 m
.40654 .1091 L
s
.008 w
.40654 .1091 Mdot
.016 w
.40654 .1091 m
.4064 .10904 L
s
.008 w
.4064 .10904 Mdot
.016 w
.4064 .10904 m
.40613 .10897 L
s
1 .405 0 r
.008 w
.40613 .10897 Mdot
.016 w
.40613 .10897 m
.40573 .10892 L
s
.008 w
.40573 .10892 Mdot
.016 w
.40573 .10892 m
.40521 .10891 L
s
1 .404 0 r
.008 w
.40521 .10891 Mdot
.016 w
.40521 .10891 m
.4046 .10895 L
s
.008 w
.4046 .10895 Mdot
.016 w
.4046 .10895 m
.40393 .10904 L
s
.008 w
.40393 .10904 Mdot
.016 w
.40393 .10904 m
.40323 .10919 L
s
1 .403 0 r
.008 w
.40323 .10919 Mdot
.016 w
.40323 .10919 m
.40256 .1094 L
s
.008 w
.40256 .1094 Mdot
.016 w
.40256 .1094 m
.40196 .10968 L
s
1 .402 0 r
.008 w
.40196 .10968 Mdot
.016 w
.40196 .10968 m
.40134 .11002 L
s
.008 w
.40134 .11002 Mdot
.016 w
.40134 .11002 m
.4007 .11038 L
s
.008 w
.4007 .11038 Mdot
.016 w
.4007 .11038 m
.40009 .11077 L
s
1 .401 0 r
.008 w
.40009 .11077 Mdot
.016 w
.40009 .11077 m
.39961 .11115 L
s
.008 w
.39961 .11115 Mdot
.016 w
.39961 .11115 m
.3993 .11156 L
s
1 .4 0 r
.008 w
.3993 .11156 Mdot
.016 w
.3993 .11156 m
.39914 .11191 L
s
.008 w
.39914 .11191 Mdot
.016 w
.39914 .11191 m
.39908 .11226 L
s
.008 w
.39908 .11226 Mdot
.016 w
.39908 .11226 m
.3991 .11258 L
s
1 .399 0 r
.008 w
.3991 .11258 Mdot
.016 w
.3991 .11258 m
.39919 .11283 L
s
.008 w
.39919 .11283 Mdot
.016 w
.39919 .11283 m
.3993 .113 L
s
1 .398 0 r
.008 w
.3993 .113 Mdot
.016 w
.3993 .113 m
.39936 .1131 L
s
.008 w
.39936 .1131 Mdot
.016 w
.39936 .1131 m
.39937 .11314 L
s
.008 w
.39937 .11314 Mdot
.016 w
.39937 .11314 m
.39934 .11313 L
s
1 .397 0 r
.008 w
.39934 .11313 Mdot
.016 w
.39934 .11313 m
.39931 .1131 L
s
.008 w
.39931 .1131 Mdot
.016 w
.39931 .1131 m
.39927 .11306 L
s
1 .396 0 r
.008 w
.39927 .11306 Mdot
.016 w
.39927 .11306 m
.39925 .11303 L
s
.008 w
.39925 .11303 Mdot
.016 w
.39925 .11303 m
.39927 .11301 L
s
.008 w
.39927 .11301 Mdot
.016 w
.39927 .11301 m
.39931 .113 L
s
1 .395 0 r
.008 w
.39931 .113 Mdot
.016 w
.39931 .113 m
.39941 .11299 L
s
.008 w
.39941 .11299 Mdot
.016 w
.39941 .11299 m
.39954 .11299 L
s
1 .394 0 r
.008 w
.39954 .11299 Mdot
.016 w
.39954 .11299 m
.39971 .11299 L
s
.008 w
.39971 .11299 Mdot
.016 w
.39971 .11299 m
.39992 .113 L
s
.008 w
.39992 .113 Mdot
.016 w
.39992 .113 m
.40014 .11301 L
s
1 .393 0 r
.008 w
.40014 .11301 Mdot
.016 w
.40014 .11301 m
.40038 .11301 L
s
.008 w
.40038 .11301 Mdot
.016 w
.40038 .11301 m
.40061 .11302 L
s
.008 w
.40061 .11302 Mdot
.016 w
.40061 .11302 m
.40085 .11303 L
s
1 .392 0 r
.008 w
.40085 .11303 Mdot
.016 w
.40085 .11303 m
.40107 .11305 L
s
.008 w
.40107 .11305 Mdot
.016 w
.40107 .11305 m
.40128 .11309 L
s
1 .391 0 r
.008 w
.40128 .11309 Mdot
.016 w
.40128 .11309 m
.40147 .11314 L
s
.008 w
.40147 .11314 Mdot
.016 w
.40147 .11314 m
.40162 .11319 L
s
.008 w
.40162 .11319 Mdot
.016 w
.40162 .11319 m
.40173 .11322 L
s
1 .39 0 r
.008 w
.40173 .11322 Mdot
.016 w
.40173 .11322 m
.4018 .11321 L
s
.008 w
.4018 .11321 Mdot
.016 w
.4018 .11321 m
.40181 .11317 L
s
1 .389 0 r
.008 w
.40181 .11317 Mdot
.016 w
.40181 .11317 m
.40179 .11305 L
s
.008 w
.40179 .11305 Mdot
.016 w
.40179 .11305 m
.40174 .11285 L
s
.008 w
.40174 .11285 Mdot
.016 w
.40174 .11285 m
.40168 .11255 L
s
1 .388 0 r
.008 w
.40168 .11255 Mdot
.016 w
.40168 .11255 m
.40162 .1122 L
s
.008 w
.40162 .1122 Mdot
.016 w
.40162 .1122 m
.40158 .11182 L
s
1 .387 0 r
.008 w
.40158 .11182 Mdot
.016 w
.40158 .11182 m
.40156 .11147 L
s
.008 w
.40156 .11147 Mdot
.016 w
.40156 .11147 m
.40155 .11114 L
s
.008 w
.40155 .11114 Mdot
.016 w
.40155 .11114 m
.40155 .11091 L
s
1 .386 0 r
.008 w
.40155 .11091 Mdot
.016 w
.40155 .11091 m
.40155 .11078 L
s
.008 w
.40155 .11078 Mdot
.016 w
.40155 .11078 m
.40156 .11075 L
s
1 .385 0 r
.008 w
.40156 .11075 Mdot
.016 w
.40156 .11075 m
.40158 .11076 L
s
.008 w
.40158 .11076 Mdot
.016 w
.40158 .11076 m
.40159 .11082 L
s
.008 w
.40159 .11082 Mdot
.016 w
.40159 .11082 m
.40161 .11094 L
s
1 .384 0 r
.008 w
.40161 .11094 Mdot
.016 w
.40161 .11094 m
.40162 .11114 L
s
.008 w
.40162 .11114 Mdot
.016 w
.40162 .11114 m
.40164 .11141 L
s
1 .383 0 r
.008 w
.40164 .11141 Mdot
.016 w
.40164 .11141 m
.40168 .11172 L
s
.008 w
.40168 .11172 Mdot
.016 w
.40168 .11172 m
.40171 .11204 L
s
.008 w
.40171 .11204 Mdot
.016 w
.40171 .11204 m
.40177 .11237 L
s
1 .382 0 r
.008 w
.40177 .11237 Mdot
.016 w
.40177 .11237 m
.40186 .11266 L
s
.008 w
.40186 .11266 Mdot
.016 w
.40186 .11266 m
.40199 .11289 L
s
1 .381 0 r
.008 w
.40199 .11289 Mdot
.016 w
.40199 .11289 m
.40218 .11303 L
s
.008 w
.40218 .11303 Mdot
.016 w
.40218 .11303 m
.4024 .11309 L
s
.008 w
.4024 .11309 Mdot
.016 w
.4024 .11309 m
.40268 .1131 L
s
1 .38 0 r
.008 w
.40268 .1131 Mdot
.016 w
.40268 .1131 m
.40302 .11307 L
s
.008 w
.40302 .11307 Mdot
.016 w
.40302 .11307 m
.40337 .11303 L
s
.008 w
.40337 .11303 Mdot
.016 w
.40337 .11303 m
.40377 .11302 L
s
1 .379 0 r
.008 w
.40377 .11302 Mdot
.016 w
.40377 .11302 m
.40418 .11305 L
s
.008 w
.40418 .11305 Mdot
.016 w
.40418 .11305 m
.40459 .1131 L
s
1 .378 0 r
.008 w
.40459 .1131 Mdot
.016 w
.40459 .1131 m
.40499 .11314 L
s
.008 w
.40499 .11314 Mdot
.016 w
.40499 .11314 m
.40535 .11318 L
s
.008 w
.40535 .11318 Mdot
.016 w
.40535 .11318 m
.40566 .1132 L
s
1 .377 0 r
.008 w
.40566 .1132 Mdot
.016 w
.40566 .1132 m
.40592 .1132 L
s
.008 w
.40592 .1132 Mdot
.016 w
.40592 .1132 m
.40613 .11319 L
s
1 .376 0 r
.008 w
.40613 .11319 Mdot
.016 w
.40613 .11319 m
.40628 .11318 L
s
.008 w
.40628 .11318 Mdot
.016 w
.40628 .11318 m
.40636 .11318 L
s
.008 w
.40636 .11318 Mdot
.016 w
.40636 .11318 m
.40638 .11318 L
s
1 .375 0 r
.008 w
.40638 .11318 Mdot
.016 w
.40638 .11318 m
.40637 .11318 L
s
.008 w
.40637 .11318 Mdot
.016 w
.40637 .11318 m
.40634 .11318 L
s
1 .374 0 r
.008 w
.40634 .11318 Mdot
.016 w
.40634 .11318 m
.40631 .11318 L
s
.008 w
.40631 .11318 Mdot
.016 w
.40631 .11318 m
.40627 .11317 L
s
.008 w
.40627 .11317 Mdot
.016 w
.40627 .11317 m
.40624 .11317 L
s
1 .373 0 r
.008 w
.40624 .11317 Mdot
.016 w
.40624 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
1 .372 0 r
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
1 .371 0 r
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
1 .37 0 r
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
1 .369 0 r
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40622 .11317 L
s
.008 w
.40622 .11317 Mdot
.016 w
.40622 .11317 m
.40621 .11317 L
s
.008 w
.40621 .11317 Mdot
.016 w
.40621 .11317 m
.40618 .11317 L
s
1 .368 0 r
.008 w
.40618 .11317 Mdot
.016 w
.40618 .11317 m
.40614 .11317 L
s
.008 w
.40614 .11317 Mdot
.016 w
.40614 .11317 m
.40611 .11317 L
s
1 .367 0 r
.008 w
.40611 .11317 Mdot
.016 w
.40611 .11317 m
.40609 .11317 L
s
.008 w
.40609 .11317 Mdot
.016 w
.40609 .11317 m
.4061 .11317 L
s
.008 w
.4061 .11317 Mdot
.016 w
.4061 .11317 m
.40615 .11317 L
s
1 .366 0 r
.008 w
.40615 .11317 Mdot
.016 w
.40615 .11317 m
.40623 .11318 L
s
.008 w
.40623 .11318 Mdot
.016 w
.40623 .11318 m
.40636 .1132 L
s
1 .365 0 r
.008 w
.40636 .1132 Mdot
.016 w
.40636 .1132 m
.40652 .11322 L
s
.008 w
.40652 .11322 Mdot
.016 w
.40652 .11322 m
.40669 .11323 L
s
.008 w
.40669 .11323 Mdot
.016 w
.40669 .11323 m
.40688 .11322 L
s
1 .364 0 r
.008 w
.40688 .11322 Mdot
.016 w
.40688 .11322 m
.40708 .1132 L
s
.008 w
.40708 .1132 Mdot
.016 w
.40708 .1132 m
.4073 .11318 L
s
1 .363 0 r
.008 w
.4073 .11318 Mdot
.016 w
.4073 .11318 m
.40755 .11314 L
s
.008 w
.40755 .11314 Mdot
.016 w
.40755 .11314 m
.40784 .11311 L
s
.008 w
.40784 .11311 Mdot
.016 w
.40784 .11311 m
.40816 .11309 L
s
1 .362 0 r
.008 w
.40816 .11309 Mdot
.016 w
.40816 .11309 m
.40851 .11308 L
s
.008 w
.40851 .11308 Mdot
.016 w
.40851 .11308 m
.40885 .11307 L
s
1 .361 0 r
.008 w
.40885 .11307 Mdot
.016 w
.40885 .11307 m
.40915 .11305 L
s
.008 w
.40915 .11305 Mdot
.016 w
.40915 .11305 m
.40939 .11301 L
s
.008 w
.40939 .11301 Mdot
.016 w
.40939 .11301 m
.40958 .11297 L
s
1 .36 0 r
.008 w
.40958 .11297 Mdot
.016 w
.40958 .11297 m
.40972 .11294 L
s
.008 w
.40972 .11294 Mdot
.016 w
.40972 .11294 m
.40983 .1129 L
s
1 .359 0 r
.008 w
.40983 .1129 Mdot
.016 w
.40983 .1129 m
.40993 .11289 L
s
.008 w
.40993 .11289 Mdot
.016 w
.40993 .11289 m
.41003 .11289 L
s
.008 w
.41003 .11289 Mdot
.016 w
.41003 .11289 m
.41013 .11291 L
s
1 .358 0 r
.008 w
.41013 .11291 Mdot
.016 w
.41013 .11291 m
.41023 .11294 L
s
.008 w
.41023 .11294 Mdot
.016 w
.41023 .11294 m
.41031 .11299 L
s
1 .357 0 r
.008 w
.41031 .11299 Mdot
.016 w
.41031 .11299 m
.41036 .11304 L
s
.008 w
.41036 .11304 Mdot
.016 w
.41036 .11304 m
.41039 .11307 L
s
.008 w
.41039 .11307 Mdot
.016 w
.41039 .11307 m
.41039 .1131 L
s
1 .356 0 r
.008 w
.41039 .1131 Mdot
.016 w
.41039 .1131 m
.41041 .11313 L
s
.008 w
.41041 .11313 Mdot
.016 w
.41041 .11313 m
.41048 .11319 L
s
.008 w
.41048 .11319 Mdot
.016 w
.41048 .11319 m
.41059 .11328 L
s
1 .355 0 r
.008 w
.41059 .11328 Mdot
.016 w
.41059 .11328 m
.41074 .11339 L
s
.008 w
.41074 .11339 Mdot
.016 w
.41074 .11339 m
.41087 .11348 L
s
1 .354 0 r
.008 w
.41087 .11348 Mdot
.016 w
.41087 .11348 m
.41094 .1135 L
s
.008 w
.41094 .1135 Mdot
.016 w
.41094 .1135 m
.41092 .11345 L
s
.008 w
.41092 .11345 Mdot
.016 w
.41092 .11345 m
.41077 .11331 L
s
1 .353 0 r
.008 w
.41077 .11331 Mdot
.016 w
.41077 .11331 m
.41049 .11307 L
s
.008 w
.41049 .11307 Mdot
.016 w
.41049 .11307 m
.41008 .11274 L
s
1 .352 0 r
.008 w
.41008 .11274 Mdot
.016 w
.41008 .11274 m
.40959 .11234 L
s
.008 w
.40959 .11234 Mdot
.016 w
.40959 .11234 m
.40909 .1119 L
s
.008 w
.40909 .1119 Mdot
.016 w
.40909 .1119 m
.40862 .11147 L
s
1 .351 0 r
.008 w
.40862 .11147 Mdot
.016 w
.40862 .11147 m
.40822 .11104 L
s
.008 w
.40822 .11104 Mdot
.016 w
.40822 .11104 m
.40788 .11063 L
s
1 .35 0 r
.008 w
.40788 .11063 Mdot
.016 w
.40788 .11063 m
.40756 .11022 L
s
.008 w
.40756 .11022 Mdot
.016 w
.40756 .11022 m
.4073 .10983 L
s
.008 w
.4073 .10983 Mdot
.016 w
.4073 .10983 m
.40712 .1095 L
s
1 .349 0 r
.008 w
.40712 .1095 Mdot
.016 w
.40712 .1095 m
.40704 .10923 L
s
.008 w
.40704 .10923 Mdot
.016 w
.40704 .10923 m
.40708 .10904 L
s
1 .348 0 r
.008 w
.40708 .10904 Mdot
.016 w
.40708 .10904 m
.4072 .10894 L
s
.008 w
.4072 .10894 Mdot
.016 w
.4072 .10894 m
.40741 .10892 L
s
.008 w
.40741 .10892 Mdot
.016 w
.40741 .10892 m
.40766 .10895 L
s
1 .347 0 r
.008 w
.40766 .10895 Mdot
.016 w
.40766 .10895 m
.40795 .10901 L
s
.008 w
.40795 .10901 Mdot
.016 w
.40795 .10901 m
.40822 .10909 L
s
1 .346 0 r
.008 w
.40822 .10909 Mdot
.016 w
.40822 .10909 m
.40843 .10914 L
s
.008 w
.40843 .10914 Mdot
.016 w
.40843 .10914 m
.40855 .10917 L
s
.008 w
.40855 .10917 Mdot
.016 w
.40855 .10917 m
.40861 .10917 L
s
1 .345 0 r
.008 w
.40861 .10917 Mdot
.016 w
.40861 .10917 m
.40862 .10917 L
s
.008 w
.40862 .10917 Mdot
.016 w
.40862 .10917 m
.40861 .10917 L
s
1 .344 0 r
.008 w
.40861 .10917 Mdot
.016 w
.40861 .10917 m
.40857 .10917 L
s
.008 w
.40857 .10917 Mdot
.016 w
.40857 .10917 m
.40854 .10918 L
s
.008 w
.40854 .10918 Mdot
.016 w
.40854 .10918 m
.40851 .10918 L
s
1 .343 0 r
.008 w
.40851 .10918 Mdot
.016 w
.40851 .10918 m
.40849 .10919 L
s
.008 w
.40849 .10919 Mdot
.016 w
.40849 .10919 m
.40849 .1092 L
s
.008 w
.40849 .1092 Mdot
.016 w
.40849 .1092 m
.40849 .10921 L
s
1 .342 0 r
.008 w
.40849 .10921 Mdot
.016 w
.40849 .10921 m
.40849 .10921 L
s
.008 w
.40849 .10921 Mdot
.016 w
.40849 .10921 m
.40849 .10921 L
s
1 .341 0 r
.008 w
.40849 .10921 Mdot
.016 w
.40849 .10921 m
.40849 .10922 L
s
.008 w
.40849 .10922 Mdot
.016 w
.40849 .10922 m
.40849 .10922 L
s
.008 w
.40849 .10922 Mdot
.016 w
.40849 .10922 m
.40849 .10922 L
s
1 .34 0 r
.008 w
.40849 .10922 Mdot
.016 w
.40849 .10922 m
.40849 .10922 L
s
.008 w
.40849 .10922 Mdot
.016 w
.40849 .10922 m
.40849 .10921 L
s
1 .339 0 r
.008 w
.40849 .10921 Mdot
.016 w
.40849 .10921 m
.40849 .10921 L
s
.008 w
.40849 .10921 Mdot
.016 w
.40849 .10921 m
.40849 .1092 L
s
.008 w
.40849 .1092 Mdot
.016 w
.40849 .1092 m
.40849 .10919 L
s
1 .338 0 r
.008 w
.40849 .10919 Mdot
.016 w
.40849 .10919 m
.40849 .10918 L
s
.008 w
.40849 .10918 Mdot
.016 w
.40849 .10918 m
.40849 .10917 L
s
1 .337 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10916 L
s
.008 w
.40849 .10916 Mdot
.016 w
.40849 .10916 m
.40849 .10916 L
s
1 .336 0 r
.008 w
.40849 .10916 Mdot
.016 w
.40849 .10916 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .335 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .334 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .333 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .332 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .331 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .33 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .329 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .328 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .327 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .326 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .325 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .324 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .323 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .322 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.40849 .10917 L
s
1 .321 0 r
.008 w
.40849 .10917 Mdot
.016 w
.40849 .10917 m
.4085 .10918 L
s
.008 w
.4085 .10918 Mdot
.016 w
.4085 .10918 m
.40852 .10918 L
s
1 .32 0 r
.008 w
.40852 .10918 Mdot
.016 w
.40852 .10918 m
.40853 .10918 L
s
.008 w
.40853 .10918 Mdot
.016 w
.40853 .10918 m
.40854 .10918 L
s
.008 w
.40854 .10918 Mdot
.016 w
.40854 .10918 m
.40852 .10917 L
s
1 .319 0 r
.008 w
.40852 .10917 Mdot
.016 w
.40852 .10917 m
.40849 .10916 L
s
.008 w
.40849 .10916 Mdot
.016 w
.40849 .10916 m
.40845 .10915 L
s
.008 w
.40845 .10915 Mdot
.016 w
.40845 .10915 m
.40839 .10914 L
s
1 .318 0 r
.008 w
.40839 .10914 Mdot
.016 w
.40839 .10914 m
.40834 .10913 L
s
.008 w
.40834 .10913 Mdot
.016 w
.40834 .10913 m
.40829 .10912 L
s
1 .317 0 r
.008 w
.40829 .10912 Mdot
.016 w
.40829 .10912 m
.40824 .10911 L
s
.008 w
.40824 .10911 Mdot
.016 w
.40824 .10911 m
.40821 .10911 L
s
.008 w
.40821 .10911 Mdot
.016 w
.40821 .10911 m
.40819 .10911 L
s
1 .316 0 r
.008 w
.40819 .10911 Mdot
.016 w
.40819 .10911 m
.40818 .10911 L
s
.008 w
.40818 .10911 Mdot
.016 w
.40818 .10911 m
.40819 .10911 L
s
1 .315 0 r
.008 w
.40819 .10911 Mdot
.016 w
.40819 .10911 m
.40822 .10912 L
s
.008 w
.40822 .10912 Mdot
.016 w
.40822 .10912 m
.40826 .10913 L
s
.008 w
.40826 .10913 Mdot
.016 w
.40826 .10913 m
.40831 .10914 L
s
1 .314 0 r
.008 w
.40831 .10914 Mdot
.016 w
.40831 .10914 m
.40835 .10915 L
s
.008 w
.40835 .10915 Mdot
.016 w
.40835 .10915 m
.40836 .10915 L
s
1 .313 0 r
.008 w
.40836 .10915 Mdot
.016 w
.40836 .10915 m
.40836 .10915 L
s
.008 w
.40836 .10915 Mdot
.016 w
.40836 .10915 m
.40832 .10915 L
s
.008 w
.40832 .10915 Mdot
.016 w
.40832 .10915 m
.40827 .10915 L
s
1 .312 0 r
.008 w
.40827 .10915 Mdot
.016 w
.40827 .10915 m
.40821 .10914 L
s
.008 w
.40821 .10914 Mdot
.016 w
.40821 .10914 m
.40814 .10914 L
s
1 .311 0 r
.008 w
.40814 .10914 Mdot
.016 w
.40814 .10914 m
.40807 .10913 L
s
.008 w
.40807 .10913 Mdot
.016 w
.40807 .10913 m
.408 .10912 L
s
.008 w
.408 .10912 Mdot
.016 w
.408 .10912 m
.40796 .10912 L
s
1 .31 0 r
.008 w
.40796 .10912 Mdot
.016 w
.40796 .10912 m
.40794 .10912 L
s
.008 w
.40794 .10912 Mdot
.016 w
.40794 .10912 m
.40793 .10912 L
s
1 .309 0 r
.008 w
.40793 .10912 Mdot
.016 w
.40793 .10912 m
.40791 .10912 L
s
.008 w
.40791 .10912 Mdot
.016 w
.40791 .10912 m
.40792 .10913 L
s
.008 w
.40792 .10913 Mdot
.016 w
.40792 .10913 m
.40795 .10913 L
s
1 .308 0 r
.008 w
.40795 .10913 Mdot
.016 w
.40795 .10913 m
.40802 .10914 L
s
.008 w
.40802 .10914 Mdot
.016 w
.40802 .10914 m
.40813 .10915 L
s
1 .307 0 r
.008 w
.40813 .10915 Mdot
.016 w
.40813 .10915 m
.40828 .10916 L
s
.008 w
.40828 .10916 Mdot
.016 w
.40828 .10916 m
.40846 .10917 L
s
.008 w
.40846 .10917 Mdot
.016 w
.40846 .10917 m
.40867 .10918 L
s
1 .306 0 r
.008 w
.40867 .10918 Mdot
.016 w
.40867 .10918 m
.40889 .10919 L
s
.008 w
.40889 .10919 Mdot
.016 w
.40889 .10919 m
.4091 .10919 L
s
.008 w
.4091 .10919 Mdot
.016 w
.4091 .10919 m
.40931 .1092 L
s
1 .305 0 r
.008 w
.40931 .1092 Mdot
.016 w
.40931 .1092 m
.40952 .1092 L
s
.008 w
.40952 .1092 Mdot
.016 w
.40952 .1092 m
.40973 .10921 L
s
1 .304 0 r
.008 w
.40973 .10921 Mdot
.016 w
.40973 .10921 m
.40995 .10921 L
s
.008 w
.40995 .10921 Mdot
.016 w
.40995 .10921 m
.41018 .10922 L
s
.008 w
.41018 .10922 Mdot
.016 w
.41018 .10922 m
.41039 .10923 L
s
1 .303 0 r
.008 w
.41039 .10923 Mdot
.016 w
.41039 .10923 m
.41057 .10923 L
s
.008 w
.41057 .10923 Mdot
.016 w
.41057 .10923 m
.41072 .10923 L
s
1 .302 0 r
.008 w
.41072 .10923 Mdot
.016 w
.41072 .10923 m
.41082 .10924 L
s
.008 w
.41082 .10924 Mdot
.016 w
.41082 .10924 m
.41088 .10924 L
s
.008 w
.41088 .10924 Mdot
.016 w
.41088 .10924 m
.41089 .10924 L
s
1 .301 0 r
.008 w
.41089 .10924 Mdot
.016 w
.41089 .10924 m
.41088 .10924 L
s
.008 w
.41088 .10924 Mdot
.016 w
.41088 .10924 m
.41085 .10924 L
s
1 .3 0 r
.008 w
.41085 .10924 Mdot
.016 w
.41085 .10924 m
.41081 .10924 L
s
.008 w
.41081 .10924 Mdot
.016 w
.41081 .10924 m
.41078 .10924 L
s
.008 w
.41078 .10924 Mdot
.016 w
.41078 .10924 m
.41077 .10924 L
s
1 .299 0 r
.008 w
.41077 .10924 Mdot
.016 w
.41077 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .298 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .297 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .296 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .295 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .294 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
1 .293 0 r
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41077 .10924 L
s
.008 w
.41077 .10924 Mdot
.016 w
.41077 .10924 m
.41078 .10924 L
s
1 .292 0 r
.008 w
.41078 .10924 Mdot
.016 w
.41078 .10924 m
.41083 .10924 L
s
.008 w
.41083 .10924 Mdot
.016 w
.41083 .10924 m
.4109 .10924 L
s
1 .291 0 r
.008 w
.4109 .10924 Mdot
.016 w
.4109 .10924 m
.41096 .10924 L
s
.008 w
.41096 .10924 Mdot
.016 w
.41096 .10924 m
.41099 .10924 L
s
.008 w
.41099 .10924 Mdot
.016 w
.41099 .10924 m
.41097 .10924 L
s
1 .29 0 r
.008 w
.41097 .10924 Mdot
.016 w
.41097 .10924 m
.41088 .10924 L
s
.008 w
.41088 .10924 Mdot
.016 w
.41088 .10924 m
.41071 .10923 L
s
1 .289 0 r
.008 w
.41071 .10923 Mdot
.016 w
.41071 .10923 m
.41044 .10923 L
s
.008 w
.41044 .10923 Mdot
.016 w
.41044 .10923 m
.41009 .10922 L
s
.008 w
.41009 .10922 Mdot
.016 w
.41009 .10922 m
.40968 .10921 L
s
1 .288 0 r
.008 w
.40968 .10921 Mdot
.016 w
.40968 .10921 m
.40924 .10919 L
s
.008 w
.40924 .10919 Mdot
.016 w
.40924 .10919 m
.40877 .10918 L
s
1 .287 0 r
.008 w
.40877 .10918 Mdot
.016 w
.40877 .10918 m
.40832 .10917 L
s
.008 w
.40832 .10917 Mdot
.016 w
.40832 .10917 m
.40788 .10915 L
s
.008 w
.40788 .10915 Mdot
.016 w
.40788 .10915 m
.40744 .10914 L
s
1 .286 0 r
.008 w
.40744 .10914 Mdot
.016 w
.40744 .10914 m
.407 .10913 L
s
.008 w
.407 .10913 Mdot
.016 w
.407 .10913 m
.4066 .10912 L
s
1 .285 0 r
.008 w
.4066 .10912 Mdot
.016 w
.4066 .10912 m
.40627 .10911 L
s
.008 w
.40627 .10911 Mdot
.016 w
.40627 .10911 m
.40603 .1091 L
s
.008 w
.40603 .1091 Mdot
.016 w
.40603 .1091 m
.40589 .1091 L
s
1 .284 0 r
.008 w
.40589 .1091 Mdot
.016 w
.40589 .1091 m
.40586 .1091 L
s
.008 w
.40586 .1091 Mdot
.016 w
.40586 .1091 m
.40593 .1091 L
s
1 .283 0 r
.008 w
.40593 .1091 Mdot
.016 w
.40593 .1091 m
.40608 .1091 L
s
.008 w
.40608 .1091 Mdot
.016 w
.40608 .1091 m
.40628 .10911 L
s
.008 w
.40628 .10911 Mdot
.016 w
.40628 .10911 m
.4065 .10912 L
s
1 .282 0 r
.008 w
.4065 .10912 Mdot
.016 w
.4065 .10912 m
.40673 .10912 L
s
.008 w
.40673 .10912 Mdot
.016 w
.40673 .10912 m
.40696 .10913 L
s
1 .281 0 r
.008 w
.40696 .10913 Mdot
.016 w
.40696 .10913 m
.4072 .10914 L
s
.008 w
.4072 .10914 Mdot
.016 w
.4072 .10914 m
.40744 .10914 L
s
.008 w
.40744 .10914 Mdot
.016 w
.40744 .10914 m
.40767 .10915 L
s
1 .28 0 r
.008 w
.40767 .10915 Mdot
.016 w
.40767 .10915 m
.4079 .10916 L
s
.008 w
.4079 .10916 Mdot
.016 w
.4079 .10916 m
.40811 .10916 L
s
.008 w
.40811 .10916 Mdot
.016 w
.40811 .10916 m
.4083 .10917 L
s
1 .279 0 r
.008 w
.4083 .10917 Mdot
.016 w
.4083 .10917 m
.40844 .10918 L
s
.008 w
.40844 .10918 Mdot
.016 w
.40844 .10918 m
.40855 .10918 L
s
1 .278 0 r
.008 w
.40855 .10918 Mdot
.016 w
.40855 .10918 m
.4086 .10918 L
s
.008 w
.4086 .10918 Mdot
.016 w
.4086 .10918 m
.40862 .10918 L
s
.008 w
.40862 .10918 Mdot
.016 w
.40862 .10918 m
.40861 .10917 L
s
1 .277 0 r
.008 w
.40861 .10917 Mdot
.016 w
.40861 .10917 m
.4086 .10917 L
s
.008 w
.4086 .10917 Mdot
.016 w
.4086 .10917 m
.40858 .10916 L
s
1 .276 0 r
.008 w
.40858 .10916 Mdot
.016 w
.40858 .10916 m
.40855 .10915 L
s
.008 w
.40855 .10915 Mdot
.016 w
.40855 .10915 m
.40853 .10915 L
s
.008 w
.40853 .10915 Mdot
.016 w
.40853 .10915 m
.40849 .10914 L
s
1 .275 0 r
.008 w
.40849 .10914 Mdot
.016 w
.40849 .10914 m
.40845 .10914 L
s
.008 w
.40845 .10914 Mdot
.016 w
.40845 .10914 m
.40839 .10914 L
s
1 .274 0 r
.008 w
.40839 .10914 Mdot
.016 w
.40839 .10914 m
.40834 .10915 L
s
.008 w
.40834 .10915 Mdot
.016 w
.40834 .10915 m
.40828 .10916 L
s
.008 w
.40828 .10916 Mdot
.016 w
.40828 .10916 m
.40824 .10917 L
s
1 .273 0 r
.008 w
.40824 .10917 Mdot
.016 w
.40824 .10917 m
.40821 .10916 L
s
.008 w
.40821 .10916 Mdot
.016 w
.40821 .10916 m
.40819 .10914 L
s
1 .272 0 r
.008 w
.40819 .10914 Mdot
.016 w
.40819 .10914 m
.40818 .10911 L
s
.008 w
.40818 .10911 Mdot
.016 w
.40818 .10911 m
.40816 .10908 L
s
.008 w
.40816 .10908 Mdot
.016 w
.40816 .10908 m
.40814 .10905 L
s
1 .271 0 r
.008 w
.40814 .10905 Mdot
.016 w
.40814 .10905 m
.40812 .10901 L
s
.008 w
.40812 .10901 Mdot
.016 w
.40812 .10901 m
.40811 .10899 L
s
1 .27 0 r
.008 w
.40811 .10899 Mdot
.016 w
.40811 .10899 m
.40814 .10897 L
s
.008 w
.40814 .10897 Mdot
.016 w
.40814 .10897 m
.40821 .10896 L
s
.008 w
.40821 .10896 Mdot
.016 w
.40821 .10896 m
.40831 .10896 L
s
1 .269 0 r
.008 w
.40831 .10896 Mdot
.016 w
.40831 .10896 m
.40846 .10896 L
s
.008 w
.40846 .10896 Mdot
.016 w
.40846 .10896 m
.40865 .10897 L
s
.008 w
.40865 .10897 Mdot
.016 w
.40865 .10897 m
.40885 .10898 L
s
1 .268 0 r
.008 w
.40885 .10898 Mdot
.016 w
.40885 .10898 m
.40907 .10901 L
s
.008 w
.40907 .10901 Mdot
.016 w
.40907 .10901 m
.40929 .10904 L
s
1 .267 0 r
.008 w
.40929 .10904 Mdot
.016 w
.40929 .10904 m
.40951 .10908 L
s
.008 w
.40951 .10908 Mdot
.016 w
.40951 .10908 m
.40972 .10913 L
s
.008 w
.40972 .10913 Mdot
.016 w
.40972 .10913 m
.40995 .10918 L
s
1 .266 0 r
.008 w
.40995 .10918 Mdot
.016 w
.40995 .10918 m
.41018 .10922 L
s
.008 w
.41018 .10922 Mdot
.016 w
.41018 .10922 m
.41039 .10925 L
s
1 .265 0 r
.008 w
.41039 .10925 Mdot
.016 w
.41039 .10925 m
.41057 .10927 L
s
.008 w
.41057 .10927 Mdot
.016 w
.41057 .10927 m
.41072 .10927 L
s
.008 w
.41072 .10927 Mdot
.016 w
.41072 .10927 m
.41082 .10926 L
s
1 .264 0 r
.008 w
.41082 .10926 Mdot
.016 w
.41082 .10926 m
.41088 .10925 L
s
.008 w
.41088 .10925 Mdot
.016 w
.41088 .10925 m
.41089 .10924 L
s
1 .263 0 r
.008 w
.41089 .10924 Mdot
.016 w
.41089 .10924 m
.41088 .10924 L
s
.008 w
.41088 .10924 Mdot
.016 w
.41088 .10924 m
.41085 .10924 L
s
.008 w
.41085 .10924 Mdot
.016 w
.41085 .10924 m
.41081 .10924 L
s
1 .262 0 r
.008 w
.41081 .10924 Mdot
.016 w
.41081 .10924 m
.41078 .10924 L
s
.008 w
.41078 .10924 Mdot
.016 w
.41078 .10924 m
.41077 .10924 L
s
1 .261 0 r
.008 w
.41077 .10924 Mdot
.016 w
.41077 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10924 L
s
.008 w
.41076 .10924 Mdot
.016 w
.41076 .10924 m
.41076 .10923 L
s
1 .26 0 r
.008 w
.41076 .10923 Mdot
.016 w
.41076 .10923 m
.41077 .10921 L
s
.008 w
.41077 .10921 Mdot
.016 w
.41077 .10921 m
.41079 .10917 L
s
1 .259 0 r
.008 w
.41079 .10917 Mdot
.016 w
.41079 .10917 m
.41081 .1091 L
s
.008 w
.41081 .1091 Mdot
.016 w
.41081 .1091 m
.41081 .10905 L
s
.008 w
.41081 .10905 Mdot
.016 w
.41081 .10905 m
.4108 .10902 L
s
1 .258 0 r
.008 w
.4108 .10902 Mdot
.016 w
.4108 .10902 m
.41077 .10904 L
s
.008 w
.41077 .10904 Mdot
.016 w
.41077 .10904 m
.41072 .10912 L
s
1 .257 0 r
.008 w
.41072 .10912 Mdot
.016 w
.41072 .10912 m
.41067 .10928 L
s
.008 w
.41067 .10928 Mdot
.016 w
.41067 .10928 m
.41061 .10952 L
s
.008 w
.41061 .10952 Mdot
.016 w
.41061 .10952 m
.41056 .10982 L
s
1 .256 0 r
.008 w
.41056 .10982 Mdot
.016 w
.41056 .10982 m
.41052 .11019 L
s
.008 w
.41052 .11019 Mdot
.016 w
.41052 .11019 m
.41049 .11058 L
s
.008 w
.41049 .11058 Mdot
.016 w
.41049 .11058 m
.41047 .111 L
s
1 .255 0 r
.008 w
.41047 .111 Mdot
.016 w
.41047 .111 m
.41046 .11141 L
s
.008 w
.41046 .11141 Mdot
.016 w
.41046 .11141 m
.41046 .11182 L
s
1 .254 0 r
.008 w
.41046 .11182 Mdot
.016 w
.41046 .11182 m
.41046 .11222 L
s
.008 w
.41046 .11222 Mdot
.016 w
.41046 .11222 m
.41048 .1126 L
s
.008 w
.41048 .1126 Mdot
.016 w
.41048 .1126 m
.41051 .11293 L
s
1 .253 0 r
.008 w
.41051 .11293 Mdot
.016 w
.41051 .11293 m
.41055 .1132 L
s
.008 w
.41055 .1132 Mdot
.016 w
.41055 .1132 m
.41061 .11338 L
s
1 .252 0 r
.008 w
.41061 .11338 Mdot
.016 w
.41061 .11338 m
.41067 .11349 L
s
.008 w
.41067 .11349 Mdot
.016 w
.41067 .11349 m
.41073 .11352 L
s
.008 w
.41073 .11352 Mdot
.016 w
.41073 .11352 m
.41079 .11349 L
s
1 .251 0 r
.008 w
.41079 .11349 Mdot
.016 w
.41079 .11349 m
.41087 .11341 L
s
.008 w
.41087 .11341 Mdot
.016 w
.41087 .11341 m
.41095 .11331 L
s
1 .25 0 r
.008 w
.41095 .11331 Mdot
.016 w
.41095 .11331 m
.41101 .11321 L
s
.008 w
.41101 .11321 Mdot
.016 w
.41101 .11321 m
.41102 .11313 L
s
.008 w
.41102 .11313 Mdot
.016 w
.41102 .11313 m
.41099 .11307 L
s
1 .249 0 r
.008 w
.41099 .11307 Mdot
.016 w
.41099 .11307 m
.41089 .11306 L
s
.008 w
.41089 .11306 Mdot
.016 w
.41089 .11306 m
.41071 .1131 L
s
1 .248 0 r
.008 w
.41071 .1131 Mdot
.016 w
.41071 .1131 m
.41045 .11323 L
s
.008 w
.41045 .11323 Mdot
.016 w
.41045 .11323 m
.4101 .11345 L
s
.008 w
.4101 .11345 Mdot
.016 w
.4101 .11345 m
.4097 .11378 L
s
1 .247 0 r
.008 w
.4097 .11378 Mdot
.016 w
.4097 .11378 m
.40925 .1142 L
s
.008 w
.40925 .1142 Mdot
.016 w
.40925 .1142 m
.40879 .1147 L
s
1 .246 0 r
.008 w
.40879 .1147 Mdot
.016 w
.40879 .1147 m
.40833 .11524 L
s
.008 w
.40833 .11524 Mdot
.016 w
.40833 .11524 m
.40789 .11586 L
s
.008 w
.40789 .11586 Mdot
.016 w
.40789 .11586 m
.40746 .11652 L
s
1 .245 0 r
.008 w
.40746 .11652 Mdot
.016 w
.40746 .11652 m
.40704 .11719 L
s
.008 w
.40704 .11719 Mdot
.016 w
.40704 .11719 m
.40667 .1178 L
s
1 .244 0 r
.008 w
.40667 .1178 Mdot
.016 w
.40667 .1178 m
.40636 .11835 L
s
.008 w
.40636 .11835 Mdot
.016 w
.40636 .11835 m
.40615 .11881 L
s
.008 w
.40615 .11881 Mdot
.016 w
.40615 .11881 m
.40606 .11913 L
s
1 .243 0 r
.008 w
.40606 .11913 Mdot
.016 w
.40606 .11913 m
.40609 .11927 L
s
.008 w
.40609 .11927 Mdot
.016 w
.40609 .11927 m
.4062 .11923 L
s
.008 w
.4062 .11923 Mdot
.016 w
.4062 .11923 m
.40633 .11901 L
s
1 .242 0 r
.008 w
.40633 .11901 Mdot
.016 w
.40633 .11901 m
.40644 .11866 L
s
.008 w
.40644 .11866 Mdot
.016 w
.40644 .11866 m
.4065 .11824 L
s
1 .241 0 r
.008 w
.4065 .11824 Mdot
.016 w
.4065 .11824 m
.40645 .11778 L
s
.008 w
.40645 .11778 Mdot
.016 w
.40645 .11778 m
.40625 .11731 L
s
.008 w
.40625 .11731 Mdot
.016 w
.40625 .11731 m
.40597 .11687 L
s
1 .24 0 r
.008 w
.40597 .11687 Mdot
.016 w
.40597 .11687 m
.4055 .11643 L
s
.008 w
.4055 .11643 Mdot
.016 w
.4055 .11643 m
.40479 .11602 L
s
1 .239 0 r
.008 w
.40479 .11602 Mdot
.016 w
.40479 .11602 m
.40385 .11561 L
s
.008 w
.40385 .11561 Mdot
.016 w
.40385 .11561 m
.40274 .11523 L
s
.008 w
.40274 .11523 Mdot
.016 w
.40274 .11523 m
.40159 .11488 L
s
1 .238 0 r
.008 w
.40159 .11488 Mdot
.016 w
.40159 .11488 m
.4004 .11458 L
s
.008 w
.4004 .11458 Mdot
.016 w
.4004 .11458 m
.39897 .11431 L
s
1 .237 0 r
.008 w
.39897 .11431 Mdot
.016 w
.39897 .11431 m
.39724 .11408 L
s
.008 w
.39724 .11408 Mdot
.016 w
.39724 .11408 m
.39573 .1139 L
s
.008 w
.39573 .1139 Mdot
.016 w
.39573 .1139 m
.39406 .11375 L
s
1 .236 0 r
.008 w
.39406 .11375 Mdot
.016 w
.39406 .11375 m
.39257 .1136 L
s
.008 w
.39257 .1136 Mdot
.016 w
.39257 .1136 m
.39104 .11344 L
s
1 .235 0 r
.008 w
.39104 .11344 Mdot
.016 w
.39104 .11344 m
.38964 .11324 L
s
.008 w
.38964 .11324 Mdot
.016 w
.38964 .11324 m
.38852 .11303 L
s
.008 w
.38852 .11303 Mdot
.016 w
.38852 .11303 m
.38751 .11278 L
s
1 .234 0 r
.008 w
.38751 .11278 Mdot
.016 w
.38751 .11278 m
.38661 .11251 L
s
.008 w
.38661 .11251 Mdot
.016 w
.38661 .11251 m
.38587 .11219 L
s
1 .233 0 r
.008 w
.38587 .11219 Mdot
.016 w
.38587 .11219 m
.38532 .11185 L
s
.008 w
.38532 .11185 Mdot
.016 w
.38532 .11185 m
.38496 .11149 L
s
.008 w
.38496 .11149 Mdot
.016 w
.38496 .11149 m
.38477 .11111 L
s
1 .232 0 r
.008 w
.38477 .11111 Mdot
.016 w
.38477 .11111 m
.38473 .11072 L
s
.008 w
.38473 .11072 Mdot
.016 w
.38473 .11072 m
.38477 .11035 L
s
1 .231 0 r
.008 w
.38477 .11035 Mdot
.016 w
.38477 .11035 m
.38486 .10996 L
s
.008 w
.38486 .10996 Mdot
.016 w
.38486 .10996 m
.38496 .10956 L
s
.008 w
.38496 .10956 Mdot
.016 w
.38496 .10956 m
.38505 .10918 L
s
1 .23 0 r
.008 w
.38505 .10918 Mdot
.016 w
.38505 .10918 m
.38508 .10885 L
s
.008 w
.38508 .10885 Mdot
.016 w
.38508 .10885 m
.38504 .1086 L
s
.008 w
.38504 .1086 Mdot
.016 w
.38504 .1086 m
.38497 .10842 L
s
1 .229 0 r
.008 w
.38497 .10842 Mdot
.016 w
.38497 .10842 m
.38487 .10832 L
s
.008 w
.38487 .10832 Mdot
.016 w
.38487 .10832 m
.38475 .10829 L
s
1 .228 0 r
.008 w
.38475 .10829 Mdot
.016 w
.38475 .10829 m
.38462 .1083 L
s
.008 w
.38462 .1083 Mdot
.016 w
.38462 .1083 m
.38446 .10836 L
s
.008 w
.38446 .10836 Mdot
.016 w
.38446 .10836 m
.38427 .10842 L
s
1 .227 0 r
.008 w
.38427 .10842 Mdot
.016 w
.38427 .10842 m
.38405 .10848 L
s
.008 w
.38405 .10848 Mdot
.016 w
.38405 .10848 m
.38382 .1085 L
s
1 .226 0 r
.008 w
.38382 .1085 Mdot
.016 w
.38382 .1085 m
.38359 .10849 L
s
.008 w
.38359 .10849 Mdot
.016 w
.38359 .10849 m
.38341 .10848 L
s
.008 w
.38341 .10848 Mdot
.016 w
.38341 .10848 m
.38328 .10847 L
s
1 .225 0 r
.008 w
.38328 .10847 Mdot
.016 w
.38328 .10847 m
.3832 .10847 L
s
.008 w
.3832 .10847 Mdot
.016 w
.3832 .10847 m
.38316 .10847 L
s
1 .224 0 r
.008 w
.38316 .10847 Mdot
.016 w
.38316 .10847 m
.38318 .10847 L
s
.008 w
.38318 .10847 Mdot
.016 w
.38318 .10847 m
.38325 .10849 L
s
.008 w
.38325 .10849 Mdot
.016 w
.38325 .10849 m
.38335 .10851 L
s
1 .223 0 r
.008 w
.38335 .10851 Mdot
.016 w
.38335 .10851 m
.38346 .10854 L
s
.008 w
.38346 .10854 Mdot
.016 w
.38346 .10854 m
.38356 .10857 L
s
1 .222 0 r
.008 w
.38356 .10857 Mdot
.016 w
.38356 .10857 m
.38363 .10861 L
s
.008 w
.38363 .10861 Mdot
.016 w
.38363 .10861 m
.38368 .10864 L
s
.008 w
.38368 .10864 Mdot
.016 w
.38368 .10864 m
.38371 .10867 L
s
1 .221 0 r
.008 w
.38371 .10867 Mdot
.016 w
.38371 .10867 m
.38375 .1087 L
s
.008 w
.38375 .1087 Mdot
.016 w
.38375 .1087 m
.3838 .10873 L
s
1 .22 0 r
.008 w
.3838 .10873 Mdot
.016 w
.3838 .10873 m
.38388 .10875 L
s
.008 w
.38388 .10875 Mdot
.016 w
.38388 .10875 m
.384 .10876 L
s
.008 w
.384 .10876 Mdot
.016 w
.384 .10876 m
.38416 .10876 L
s
1 .219 0 r
.008 w
.38416 .10876 Mdot
.016 w
.38416 .10876 m
.38435 .10875 L
s
.008 w
.38435 .10875 Mdot
.016 w
.38435 .10875 m
.38453 .10872 L
s
.008 w
.38453 .10872 Mdot
.016 w
.38453 .10872 m
.38469 .10867 L
s
1 .218 0 r
.008 w
.38469 .10867 Mdot
.016 w
.38469 .10867 m
.38482 .10875 L
s
.008 w
.38482 .10875 Mdot
.016 w
.38482 .10875 m
.38492 .1087 L
s
1 .217 0 r
.008 w
.38492 .1087 Mdot
.016 w
.38492 .1087 m
.38499 .10868 L
s
.008 w
.38499 .10868 Mdot
.016 w
.38499 .10868 m
.38503 .10868 L
s
.008 w
.38503 .10868 Mdot
.016 w
.38503 .10868 m
.38503 .1087 L
s
1 .216 0 r
.008 w
.38503 .1087 Mdot
.016 w
.38503 .1087 m
.38498 .10877 L
s
.008 w
.38498 .10877 Mdot
.016 w
.38498 .10877 m
.38487 .10888 L
s
1 .215 0 r
.008 w
.38487 .10888 Mdot
.016 w
.38487 .10888 m
.38467 .10904 L
s
.008 w
.38467 .10904 Mdot
.016 w
.38467 .10904 m
.38438 .10927 L
s
.008 w
.38438 .10927 Mdot
.016 w
.38438 .10927 m
.384 .10952 L
s
1 .214 0 r
.008 w
.384 .10952 Mdot
.016 w
.384 .10952 m
.38355 .10983 L
s
.008 w
.38355 .10983 Mdot
.016 w
.38355 .10983 m
.38308 .11016 L
s
1 .213 0 r
.008 w
.38308 .11016 Mdot
.016 w
.38308 .11016 m
.38261 .1105 L
s
.008 w
.38261 .1105 Mdot
.016 w
.38261 .1105 m
.3822 .11088 L
s
.008 w
.3822 .11088 Mdot
.016 w
.3822 .11088 m
.38184 .11122 L
s
1 .212 0 r
.008 w
.38184 .11122 Mdot
.016 w
.38184 .11122 m
.38155 .1115 L
s
.008 w
.38155 .1115 Mdot
.016 w
.38155 .1115 m
.38132 .11177 L
s
1 .211 0 r
.008 w
.38132 .11177 Mdot
.016 w
.38132 .11177 m
.38115 .11201 L
s
.008 w
.38115 .11201 Mdot
.016 w
.38115 .11201 m
.38104 .1122 L
s
.008 w
.38104 .1122 Mdot
.016 w
.38104 .1122 m
.38097 .11235 L
s
1 .21 0 r
.008 w
.38097 .11235 Mdot
.016 w
.38097 .11235 m
.38095 .11246 L
s
.008 w
.38095 .11246 Mdot
.016 w
.38095 .11246 m
.38098 .11254 L
s
1 .209 0 r
.008 w
.38098 .11254 Mdot
.016 w
.38098 .11254 m
.38107 .11258 L
s
.008 w
.38107 .11258 Mdot
.016 w
.38107 .11258 m
.38121 .1126 L
s
.008 w
.38121 .1126 Mdot
.016 w
.38121 .1126 m
.38134 .11259 L
s
1 .208 0 r
.008 w
.38134 .11259 Mdot
.016 w
.38134 .11259 m
.38142 .11258 L
s
.008 w
.38142 .11258 Mdot
.016 w
.38142 .11258 m
.3814 .11254 L
s
1 .207 0 r
.008 w
.3814 .11254 Mdot
.016 w
.3814 .11254 m
.38126 .1125 L
s
.008 w
.38126 .1125 Mdot
.016 w
.38126 .1125 m
.381 .11248 L
s
.008 w
.381 .11248 Mdot
.016 w
.381 .11248 m
.3806 .11246 L
s
1 .206 0 r
.008 w
.3806 .11246 Mdot
.016 w
.3806 .11246 m
.38007 .11245 L
s
.008 w
.38007 .11245 Mdot
.016 w
.38007 .11245 m
.37945 .11243 L
s
.008 w
.37945 .11243 Mdot
.016 w
.37945 .11243 m
.37878 .11241 L
s
1 .205 0 r
.008 w
.37878 .11241 Mdot
.016 w
.37878 .11241 m
.37807 .11239 L
s
.008 w
.37807 .11239 Mdot
.016 w
.37807 .11239 m
.37739 .11237 L
s
1 .204 0 r
.008 w
.37739 .11237 Mdot
.016 w
.37739 .11237 m
.37672 .11235 L
s
.008 w
.37672 .11235 Mdot
.016 w
.37672 .11235 m
.37605 .11233 L
s
.008 w
.37605 .11233 Mdot
.016 w
.37605 .11233 m
.37541 .11231 L
s
1 .203 0 r
.008 w
.37541 .11231 Mdot
.016 w
.37541 .11231 m
.37483 .1123 L
s
.008 w
.37483 .1123 Mdot
.016 w
.37483 .1123 m
.37438 .11229 L
s
1 .202 0 r
.008 w
.37438 .11229 Mdot
.016 w
.37438 .11229 m
.37406 .11228 L
s
.008 w
.37406 .11228 Mdot
.016 w
.37406 .11228 m
.37389 .11227 L
s
.008 w
.37389 .11227 Mdot
.016 w
.37389 .11227 m
.37383 .11227 L
s
1 .201 0 r
.008 w
.37383 .11227 Mdot
.016 w
.37383 .11227 m
.37386 .11227 L
s
.008 w
.37386 .11227 Mdot
.016 w
.37386 .11227 m
.37396 .11227 L
s
1 .2 0 r
.008 w
.37396 .11227 Mdot
.016 w
.37396 .11227 m
.37407 .11228 L
s
.008 w
.37407 .11228 Mdot
.016 w
.37407 .11228 m
.37415 .11228 L
s
.008 w
.37415 .11228 Mdot
.016 w
.37415 .11228 m
.37419 .11228 L
s
1 .199 0 r
.008 w
.37419 .11228 Mdot
.016 w
.37419 .11228 m
.3742 .11226 L
s
.008 w
.3742 .11226 Mdot
.016 w
.3742 .11226 m
.37421 .11223 L
s
1 .198 0 r
.008 w
.37421 .11223 Mdot
.016 w
.37421 .11223 m
.37424 .11221 L
s
.008 w
.37424 .11221 Mdot
.016 w
.37424 .11221 m
.37427 .1122 L
s
.008 w
.37427 .1122 Mdot
.016 w
.37427 .1122 m
.37431 .11221 L
s
1 .197 0 r
.008 w
.37431 .11221 Mdot
.016 w
.37431 .11221 m
.37432 .11223 L
s
.008 w
.37432 .11223 Mdot
.016 w
.37432 .11223 m
.3743 .11229 L
s
1 .196 0 r
.008 w
.3743 .11229 Mdot
.016 w
.3743 .11229 m
.37422 .1124 L
s
.008 w
.37422 .1124 Mdot
.016 w
.37422 .1124 m
.37409 .11255 L
s
.008 w
.37409 .11255 Mdot
.016 w
.37409 .11255 m
.37392 .11273 L
s
1 .195 0 r
.008 w
.37392 .11273 Mdot
.016 w
.37392 .11273 m
.37374 .11292 L
s
.008 w
.37374 .11292 Mdot
.016 w
.37374 .11292 m
.37355 .11307 L
s
1 .194 0 r
.008 w
.37355 .11307 Mdot
.016 w
.37355 .11307 m
.37337 .11322 L
s
.008 w
.37337 .11322 Mdot
.016 w
.37337 .11322 m
.37323 .11331 L
s
.008 w
.37323 .11331 Mdot
.016 w
.37323 .11331 m
.37313 .11337 L
s
1 .193 0 r
.008 w
.37313 .11337 Mdot
.016 w
.37313 .11337 m
.37307 .11343 L
s
.008 w
.37307 .11343 Mdot
.016 w
.37307 .11343 m
.37304 .11343 L
s
.008 w
.37304 .11343 Mdot
.016 w
.37304 .11343 m
.37306 .1134 L
s
1 .192 0 r
.008 w
.37306 .1134 Mdot
.016 w
.37306 .1134 m
.37311 .11331 L
s
.008 w
.37311 .11331 Mdot
.016 w
.37311 .11331 m
.37319 .11318 L
s
1 .191 0 r
.008 w
.37319 .11318 Mdot
.016 w
.37319 .11318 m
.37333 .11301 L
s
.008 w
.37333 .11301 Mdot
.016 w
.37333 .11301 m
.37349 .11283 L
s
.008 w
.37349 .11283 Mdot
.016 w
.37349 .11283 m
.37369 .11264 L
s
1 .19 0 r
.008 w
.37369 .11264 Mdot
.016 w
.37369 .11264 m
.37389 .11246 L
s
.008 w
.37389 .11246 Mdot
.016 w
.37389 .11246 m
.37407 .11231 L
s
1 .189 0 r
.008 w
.37407 .11231 Mdot
.016 w
.37407 .11231 m
.37421 .11223 L
s
.008 w
.37421 .11223 Mdot
.016 w
.37421 .11223 m
.3743 .11219 L
s
.008 w
.3743 .11219 Mdot
.016 w
.3743 .11219 m
.37433 .11218 L
s
1 .188 0 r
.008 w
.37433 .11218 Mdot
.016 w
.37433 .11218 m
.37431 .11219 L
s
.008 w
.37431 .11219 Mdot
.016 w
.37431 .11219 m
.37428 .11221 L
s
1 .187 0 r
.008 w
.37428 .11221 Mdot
.016 w
.37428 .11221 m
.37424 .11224 L
s
.008 w
.37424 .11224 Mdot
.016 w
.37424 .11224 m
.37421 .11227 L
s
.008 w
.37421 .11227 Mdot
.016 w
.37421 .11227 m
.3742 .11228 L
s
1 .186 0 r
.008 w
.3742 .11228 Mdot
.016 w
.3742 .11228 m
.37419 .11228 L
s
.008 w
.37419 .11228 Mdot
.016 w
.37419 .11228 m
.37419 .11228 L
s
1 .185 0 r
.008 w
.37419 .11228 Mdot
.016 w
.37419 .11228 m
.37419 .11228 L
s
.008 w
.37419 .11228 Mdot
.016 w
.37419 .11228 m
.37419 .11228 L
s
.008 w
.37419 .11228 Mdot
.016 w
.37419 .11228 m
.3742 .11228 L
s
1 .184 0 r
.008 w
.3742 .11228 Mdot
.016 w
.3742 .11228 m
.37422 .11228 L
s
.008 w
.37422 .11228 Mdot
.016 w
.37422 .11228 m
.37427 .11228 L
s
1 .183 0 r
.008 w
.37427 .11228 Mdot
.016 w
.37427 .11228 m
.37434 .11229 L
s
.008 w
.37434 .11229 Mdot
.016 w
.37434 .11229 m
.37441 .11229 L
s
.008 w
.37441 .11229 Mdot
.016 w
.37441 .11229 m
.37444 .11229 L
s
1 .182 0 r
.008 w
.37444 .11229 Mdot
.016 w
.37444 .11229 m
.37443 .11229 L
s
.008 w
.37443 .11229 Mdot
.016 w
.37443 .11229 m
.37434 .11229 L
s
1 .181 0 r
.008 w
.37434 .11229 Mdot
.016 w
.37434 .11229 m
.37418 .11228 L
s
.008 w
.37418 .11228 Mdot
.016 w
.37418 .11228 m
.37393 .11227 L
s
.008 w
.37393 .11227 Mdot
.016 w
.37393 .11227 m
.37363 .11223 L
s
1 .18 0 r
.008 w
.37363 .11223 Mdot
.016 w
.37363 .11223 m
.3733 .11214 L
s
.008 w
.3733 .11214 Mdot
.016 w
.3733 .11214 m
.37294 .11203 L
s
.008 w
.37294 .11203 Mdot
.016 w
.37294 .11203 m
.37257 .11193 L
s
1 .179 0 r
.008 w
.37257 .11193 Mdot
.016 w
.37257 .11193 m
.37219 .11186 L
s
.008 w
.37219 .11186 Mdot
.016 w
.37219 .11186 m
.3718 .11185 L
s
1 .178 0 r
.008 w
.3718 .11185 Mdot
.016 w
.3718 .11185 m
.37135 .11192 L
s
.008 w
.37135 .11192 Mdot
.016 w
.37135 .11192 m
.37082 .11211 L
s
.008 w
.37082 .11211 Mdot
.016 w
.37082 .11211 m
.37021 .11245 L
s
1 .177 0 r
.008 w
.37021 .11245 Mdot
.016 w
.37021 .11245 m
.36951 .11294 L
s
.008 w
.36951 .11294 Mdot
.016 w
.36951 .11294 m
.3687 .11357 L
s
1 .176 0 r
.008 w
.3687 .11357 Mdot
.016 w
.3687 .11357 m
.36773 .11433 L
s
.008 w
.36773 .11433 Mdot
.016 w
.36773 .11433 m
.3666 .11519 L
s
.008 w
.3666 .11519 Mdot
.016 w
.3666 .11519 m
.36542 .11606 L
s
1 .175 0 r
.008 w
.36542 .11606 Mdot
.016 w
.36542 .11606 m
.36403 .11696 L
s
.008 w
.36403 .11696 Mdot
.016 w
.36403 .11696 m
.36243 .11788 L
s
1 .174 0 r
.008 w
.36243 .11788 Mdot
.016 w
.36243 .11788 m
.36085 .11881 L
s
.008 w
.36085 .11881 Mdot
.016 w
.36085 .11881 m
.35895 .11969 L
s
.008 w
.35895 .11969 Mdot
.016 w
.35895 .11969 m
.35725 .12043 L
s
1 .173 0 r
.008 w
.35725 .12043 Mdot
.016 w
.35725 .12043 m
.35554 .12105 L
s
.008 w
.35554 .12105 Mdot
.016 w
.35554 .12105 m
.35389 .12153 L
s
1 .172 0 r
.008 w
.35389 .12153 Mdot
.016 w
.35389 .12153 m
.35244 .12187 L
s
.008 w
.35244 .12187 Mdot
.016 w
.35244 .12187 m
.35126 .12207 L
s
.008 w
.35126 .12207 Mdot
.016 w
.35126 .12207 m
.35028 .12215 L
s
1 .171 0 r
.008 w
.35028 .12215 Mdot
.016 w
.35028 .12215 m
.34951 .12215 L
s
.008 w
.34951 .12215 Mdot
.016 w
.34951 .12215 m
.34897 .1221 L
s
1 .17 0 r
.008 w
.34897 .1221 Mdot
.016 w
.34897 .1221 m
.34862 .12204 L
s
.008 w
.34862 .12204 Mdot
.016 w
.34862 .12204 m
.34842 .12197 L
s
.008 w
.34842 .12197 Mdot
.016 w
.34842 .12197 m
.34836 .1219 L
s
1 .169 0 r
.008 w
.34836 .1219 Mdot
.016 w
.34836 .1219 m
.34838 .12184 L
s
.008 w
.34838 .12184 Mdot
.016 w
.34838 .12184 m
.34844 .12182 L
s
.008 w
.34844 .12182 Mdot
.016 w
.34844 .12182 m
.34855 .12181 L
s
1 .168 0 r
.008 w
.34855 .12181 Mdot
.016 w
.34855 .12181 m
.34867 .12182 L
s
.008 w
.34867 .12182 Mdot
.016 w
.34867 .12182 m
.34877 .12182 L
s
1 .167 0 r
.008 w
.34877 .12182 Mdot
.016 w
.34877 .12182 m
.34881 .12182 L
s
.008 w
.34881 .12182 Mdot
.016 w
.34881 .12182 m
.34882 .12182 L
s
.008 w
.34882 .12182 Mdot
.016 w
.34882 .12182 m
.34884 .12179 L
s
1 .166 0 r
.008 w
.34884 .12179 Mdot
.016 w
.34884 .12179 m
.3489 .12173 L
s
.008 w
.3489 .12173 Mdot
.016 w
.3489 .12173 m
.34902 .12163 L
s
1 .165 0 r
.008 w
.34902 .12163 Mdot
.016 w
.34902 .12163 m
.34912 .12155 L
s
.008 w
.34912 .12155 Mdot
.016 w
.34912 .12155 m
.34919 .12151 L
s
.008 w
.34919 .12151 Mdot
.016 w
.34919 .12151 m
.34919 .12154 L
s
1 .164 0 r
.008 w
.34919 .12154 Mdot
.016 w
.34919 .12154 m
.34909 .12167 L
s
.008 w
.34909 .12167 Mdot
.016 w
.34909 .12167 m
.34884 .12191 L
s
1 .163 0 r
.008 w
.34884 .12191 Mdot
.016 w
.34884 .12191 m
.3484 .12226 L
s
.008 w
.3484 .12226 Mdot
.016 w
.3484 .12226 m
.34778 .12271 L
s
.008 w
.34778 .12271 Mdot
.016 w
.34778 .12271 m
.34704 .12325 L
s
1 .162 0 r
.008 w
.34704 .12325 Mdot
.016 w
.34704 .12325 m
.34622 .12384 L
s
.008 w
.34622 .12384 Mdot
.016 w
.34622 .12384 m
.34538 .12447 L
s
1 .161 0 r
.008 w
.34538 .12447 Mdot
.016 w
.34538 .12447 m
.34454 .12507 L
s
.008 w
.34454 .12507 Mdot
.016 w
.34454 .12507 m
.34387 .12564 L
s
.008 w
.34387 .12564 Mdot
.016 w
.34387 .12564 m
.34311 .1262 L
s
1 .16 0 r
.008 w
.34311 .1262 Mdot
.016 w
.34311 .1262 m
.34239 .12674 L
s
.008 w
.34239 .12674 Mdot
.016 w
.34239 .12674 m
.34177 .12722 L
s
1 .159 0 r
.008 w
.34177 .12722 Mdot
.016 w
.34177 .12722 m
.34133 .12759 L
s
.008 w
.34133 .12759 Mdot
.016 w
.34133 .12759 m
.34111 .12782 L
s
.008 w
.34111 .12782 Mdot
.016 w
.34111 .12782 m
.3411 .12789 L
s
1 .158 0 r
.008 w
.3411 .12789 Mdot
.016 w
.3411 .12789 m
.34123 .12786 L
s
.008 w
.34123 .12786 Mdot
.016 w
.34123 .12786 m
.34144 .12776 L
s
1 .157 0 r
.008 w
.34144 .12776 Mdot
.016 w
.34144 .12776 m
.34167 .12764 L
s
.008 w
.34167 .12764 Mdot
.016 w
.34167 .12764 m
.34187 .12754 L
s
.008 w
.34187 .12754 Mdot
.016 w
.34187 .12754 m
.34194 .12751 L
s
1 .156 0 r
.008 w
.34194 .12751 Mdot
.016 w
.34194 .12751 m
.34181 .12759 L
s
.008 w
.34181 .12759 Mdot
.016 w
.34181 .12759 m
.34147 .12775 L
s
.008 w
.34147 .12775 Mdot
.016 w
.34147 .12775 m
.34091 .12798 L
s
1 .155 0 r
.008 w
.34091 .12798 Mdot
.016 w
.34091 .12798 m
.34011 .12828 L
s
.008 w
.34011 .12828 Mdot
.016 w
.34011 .12828 m
.33904 .12866 L
s
1 .154 0 r
.008 w
.33904 .12866 Mdot
.016 w
.33904 .12866 m
.33789 .12911 L
s
.008 w
.33789 .12911 Mdot
.016 w
.33789 .12911 m
.3364 .12966 L
s
.008 w
.3364 .12966 Mdot
.016 w
.3364 .12966 m
.33504 .13029 L
s
1 .153 0 r
.008 w
.33504 .13029 Mdot
.016 w
.33504 .13029 m
.33356 .13103 L
s
.008 w
.33356 .13103 Mdot
.016 w
.33356 .13103 m
.33186 .13186 L
s
1 .152 0 r
.008 w
.33186 .13186 Mdot
.016 w
.33186 .13186 m
.33023 .1328 L
s
.008 w
.33023 .1328 Mdot
.016 w
.33023 .1328 m
.32853 .1338 L
s
.008 w
.32853 .1338 Mdot
.016 w
.32853 .1338 m
.32675 .13483 L
s
1 .151 0 r
.008 w
.32675 .13483 Mdot
.016 w
.32675 .13483 m
.32495 .13582 L
s
.008 w
.32495 .13582 Mdot
.016 w
.32495 .13582 m
.32324 .13674 L
s
1 .15 0 r
.008 w
.32324 .13674 Mdot
.016 w
.32324 .13674 m
.3215 .13764 L
s
.008 w
.3215 .13764 Mdot
.016 w
.3215 .13764 m
.31979 .13847 L
s
.008 w
.31979 .13847 Mdot
.016 w
.31979 .13847 m
.31839 .13923 L
s
1 .149 0 r
.008 w
.31839 .13923 Mdot
.016 w
.31839 .13923 m
.31694 .13988 L
s
.008 w
.31694 .13988 Mdot
.016 w
.31694 .13988 m
.31559 .14045 L
s
1 .148 0 r
.008 w
.31559 .14045 Mdot
.016 w
.31559 .14045 m
.31452 .14093 L
s
.008 w
.31452 .14093 Mdot
.016 w
.31452 .14093 m
.31358 .14133 L
s
.008 w
.31358 .14133 Mdot
.016 w
.31358 .14133 m
.31276 .14164 L
s
1 .147 0 r
.008 w
.31276 .14164 Mdot
.016 w
.31276 .14164 m
.31209 .14187 L
s
.008 w
.31209 .14187 Mdot
.016 w
.31209 .14187 m
.31157 .14205 L
s
1 .146 0 r
.008 w
.31157 .14205 Mdot
.016 w
.31157 .14205 m
.31123 .14221 L
s
.008 w
.31123 .14221 Mdot
.016 w
.31123 .14221 m
.31106 .14237 L
s
.008 w
.31106 .14237 Mdot
.016 w
.31106 .14237 m
.31104 .14251 L
s
1 .145 0 r
.008 w
.31104 .14251 Mdot
.016 w
.31104 .14251 m
.31112 .14265 L
s
.008 w
.31112 .14265 Mdot
.016 w
.31112 .14265 m
.31125 .14281 L
s
1 .144 0 r
.008 w
.31125 .14281 Mdot
.016 w
.31125 .14281 m
.31139 .143 L
s
.008 w
.31139 .143 Mdot
.016 w
.31139 .143 m
.3115 .14319 L
s
.008 w
.3115 .14319 Mdot
.016 w
.3115 .14319 m
.31155 .14335 L
s
1 .143 0 r
.008 w
.31155 .14335 Mdot
.016 w
.31155 .14335 m
.31156 .14348 L
s
.008 w
.31156 .14348 Mdot
.016 w
.31156 .14348 m
.31156 .14358 L
s
.008 w
.31156 .14358 Mdot
.016 w
.31156 .14358 m
.31156 .14363 L
s
1 .142 0 r
.008 w
.31156 .14363 Mdot
.016 w
.31156 .14363 m
.31156 .14364 L
s
.008 w
.31156 .14364 Mdot
.016 w
.31156 .14364 m
.31156 .14363 L
s
1 .141 0 r
.008 w
.31156 .14363 Mdot
.016 w
.31156 .14363 m
.31156 .1436 L
s
.008 w
.31156 .1436 Mdot
.016 w
.31156 .1436 m
.31156 .14356 L
s
.008 w
.31156 .14356 Mdot
.016 w
.31156 .14356 m
.31156 .14353 L
s
1 .14 0 r
.008 w
.31156 .14353 Mdot
.016 w
.31156 .14353 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
1 .139 0 r
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
1 .138 0 r
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
1 .137 0 r
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31156 .14352 L
s
1 .136 0 r
.008 w
.31156 .14352 Mdot
.016 w
.31156 .14352 m
.31159 .1435 L
s
.008 w
.31159 .1435 Mdot
.016 w
.31159 .1435 m
.31165 .14345 L
s
1 .135 0 r
.008 w
.31165 .14345 Mdot
.016 w
.31165 .14345 m
.31176 .14339 L
s
.008 w
.31176 .14339 Mdot
.016 w
.31176 .14339 m
.31186 .14333 L
s
.008 w
.31186 .14333 Mdot
.016 w
.31186 .14333 m
.31192 .1433 L
s
1 .134 0 r
.008 w
.31192 .1433 Mdot
.016 w
.31192 .1433 m
.31189 .14332 L
s
.008 w
.31189 .14332 Mdot
.016 w
.31189 .14332 m
.31177 .14339 L
s
1 .133 0 r
.008 w
.31177 .14339 Mdot
.016 w
.31177 .14339 m
.31153 .14354 L
s
.008 w
.31153 .14354 Mdot
.016 w
.31153 .14354 m
.31115 .14376 L
s
.008 w
.31115 .14376 Mdot
.016 w
.31115 .14376 m
.31067 .14403 L
s
1 .132 0 r
.008 w
.31067 .14403 Mdot
.016 w
.31067 .14403 m
.31011 .14433 L
s
.008 w
.31011 .14433 Mdot
.016 w
.31011 .14433 m
.30952 .14464 L
s
1 .131 0 r
.008 w
.30952 .14464 Mdot
.016 w
.30952 .14464 m
.30888 .14499 L
s
.008 w
.30888 .14499 Mdot
.016 w
.30888 .14499 m
.30818 .14538 L
s
.008 w
.30818 .14538 Mdot
.016 w
.30818 .14538 m
.30745 .14582 L
s
1 .13 0 r
.008 w
.30745 .14582 Mdot
.016 w
.30745 .14582 m
.30666 .14631 L
s
.008 w
.30666 .14631 Mdot
.016 w
.30666 .14631 m
.30582 .14685 L
s
.008 w
.30582 .14685 Mdot
.016 w
.30582 .14685 m
.30495 .14741 L
s
1 .129 0 r
.008 w
.30495 .14741 Mdot
.016 w
.30495 .14741 m
.30412 .14798 L
s
.008 w
.30412 .14798 Mdot
.016 w
.30412 .14798 m
.30339 .14852 L
s
1 .128 0 r
.008 w
.30339 .14852 Mdot
.016 w
.30339 .14852 m
.3028 .14903 L
s
.008 w
.3028 .14903 Mdot
.016 w
.3028 .14903 m
.30233 .14949 L
s
.008 w
.30233 .14949 Mdot
.016 w
.30233 .14949 m
.30196 .14988 L
s
1 .127 0 r
.008 w
.30196 .14988 Mdot
.016 w
.30196 .14988 m
.30159 .15025 L
s
.008 w
.30159 .15025 Mdot
.016 w
.30159 .15025 m
.30118 .15061 L
s
1 .126 0 r
.008 w
.30118 .15061 Mdot
.016 w
.30118 .15061 m
.30068 .15095 L
s
.008 w
.30068 .15095 Mdot
.016 w
.30068 .15095 m
.30007 .15127 L
s
.008 w
.30007 .15127 Mdot
.016 w
.30007 .15127 m
.29937 .15154 L
s
1 .125 0 r
.008 w
.29937 .15154 Mdot
.016 w
.29937 .15154 m
.29863 .15172 L
s
.008 w
.29863 .15172 Mdot
.016 w
.29863 .15172 m
.29786 .15182 L
s
1 .124 0 r
.008 w
.29786 .15182 Mdot
.016 w
.29786 .15182 m
.29713 .15184 L
s
.008 w
.29713 .15184 Mdot
.016 w
.29713 .15184 m
.29647 .15179 L
s
.008 w
.29647 .15179 Mdot
.016 w
.29647 .15179 m
.29589 .15168 L
s
1 .123 0 r
.008 w
.29589 .15168 Mdot
.016 w
.29589 .15168 m
.29532 .15157 L
s
.008 w
.29532 .15157 Mdot
.016 w
.29532 .15157 m
.29472 .15147 L
s
1 .122 0 r
.008 w
.29472 .15147 Mdot
.016 w
.29472 .15147 m
.29408 .15141 L
s
.008 w
.29408 .15141 Mdot
.016 w
.29408 .15141 m
.29346 .15139 L
s
.008 w
.29346 .15139 Mdot
.016 w
.29346 .15139 m
.29292 .15141 L
s
1 .121 0 r
.008 w
.29292 .15141 Mdot
.016 w
.29292 .15141 m
.29247 .15148 L
s
.008 w
.29247 .15148 Mdot
.016 w
.29247 .15148 m
.29212 .15158 L
s
1 .12 0 r
.008 w
.29212 .15158 Mdot
.016 w
.29212 .15158 m
.29185 .15172 L
s
.008 w
.29185 .15172 Mdot
.016 w
.29185 .15172 m
.29165 .15189 L
s
.008 w
.29165 .15189 Mdot
.016 w
.29165 .15189 m
.29151 .15208 L
s
1 .119 0 r
.008 w
.29151 .15208 Mdot
.016 w
.29151 .15208 m
.29138 .15231 L
s
.008 w
.29138 .15231 Mdot
.016 w
.29138 .15231 m
.29121 .1525 L
s
.008 w
.29121 .1525 Mdot
.016 w
.29121 .1525 m
.29098 .15274 L
s
1 .118 0 r
.008 w
.29098 .15274 Mdot
.016 w
.29098 .15274 m
.29074 .15296 L
s
.008 w
.29074 .15296 Mdot
.016 w
.29074 .15296 m
.29052 .15316 L
s
1 .117 0 r
.008 w
.29052 .15316 Mdot
.016 w
.29052 .15316 m
.29034 .15332 L
s
.008 w
.29034 .15332 Mdot
.016 w
.29034 .15332 m
.29022 .15342 L
s
.008 w
.29022 .15342 Mdot
.016 w
.29022 .15342 m
.29017 .15345 L
s
1 .116 0 r
.008 w
.29017 .15345 Mdot
.016 w
.29017 .15345 m
.29021 .15342 L
s
.008 w
.29021 .15342 Mdot
.016 w
.29021 .15342 m
.29032 .15338 L
s
1 .115 0 r
.008 w
.29032 .15338 Mdot
.016 w
.29032 .15338 m
.29049 .15334 L
s
.008 w
.29049 .15334 Mdot
.016 w
.29049 .15334 m
.29071 .15334 L
s
.008 w
.29071 .15334 Mdot
.016 w
.29071 .15334 m
.29095 .1534 L
s
1 .114 0 r
.008 w
.29095 .1534 Mdot
.016 w
.29095 .1534 m
.29119 .15353 L
s
.008 w
.29119 .15353 Mdot
.016 w
.29119 .15353 m
.29144 .15375 L
s
1 .113 0 r
.008 w
.29144 .15375 Mdot
.016 w
.29144 .15375 m
.29169 .154 L
s
.008 w
.29169 .154 Mdot
.016 w
.29169 .154 m
.29195 .15427 L
s
.008 w
.29195 .15427 Mdot
.016 w
.29195 .15427 m
.29221 .1545 L
s
1 .112 0 r
.008 w
.29221 .1545 Mdot
.016 w
.29221 .1545 m
.29249 .15465 L
s
.008 w
.29249 .15465 Mdot
.016 w
.29249 .15465 m
.29276 .15473 L
s
1 .111 0 r
.008 w
.29276 .15473 Mdot
.016 w
.29276 .15473 m
.293 .15475 L
s
.008 w
.293 .15475 Mdot
.016 w
.293 .15475 m
.29322 .15476 L
s
.008 w
.29322 .15476 Mdot
.016 w
.29322 .15476 m
.29338 .15477 L
s
1 .11 0 r
.008 w
.29338 .15477 Mdot
.016 w
.29338 .15477 m
.29343 .15487 L
s
.008 w
.29343 .15487 Mdot
.016 w
.29343 .15487 m
.29334 .15488 L
s
1 .109 0 r
.008 w
.29334 .15488 Mdot
.016 w
.29334 .15488 m
.29311 .15493 L
s
.008 w
.29311 .15493 Mdot
.016 w
.29311 .15493 m
.29269 .155 L
s
.008 w
.29269 .155 Mdot
.016 w
.29269 .155 m
.29208 .15514 L
s
1 .108 0 r
.008 w
.29208 .15514 Mdot
.016 w
.29208 .15514 m
.29122 .15539 L
s
.008 w
.29122 .15539 Mdot
.016 w
.29122 .15539 m
.29008 .15579 L
s
1 .107 0 r
.008 w
.29008 .15579 Mdot
.016 w
.29008 .15579 m
.28879 .15632 L
s
.008 w
.28879 .15632 Mdot
.016 w
.28879 .15632 m
.2872 .15705 L
s
.008 w
.2872 .15705 Mdot
.016 w
.2872 .15705 m
.28527 .15799 L
s
1 .106 0 r
.008 w
.28527 .15799 Mdot
.016 w
.28527 .15799 m
.28312 .1591 L
s
.008 w
.28312 .1591 Mdot
.016 w
.28312 .1591 m
.28111 .16026 L
s
.008 w
.28111 .16026 Mdot
.016 w
.28111 .16026 m
.27888 .1615 L
s
1 .105 0 r
.008 w
.27888 .1615 Mdot
.016 w
.27888 .1615 m
.2764 .16278 L
s
.008 w
.2764 .16278 Mdot
.016 w
.2764 .16278 m
.27416 .164 L
s
1 .104 0 r
.008 w
.27416 .164 Mdot
.016 w
.27416 .164 m
.27183 .16519 L
s
.008 w
.27183 .16519 Mdot
.016 w
.27183 .16519 m
.26986 .16623 L
s
.008 w
.26986 .16623 Mdot
.016 w
.26986 .16623 m
.26809 .16719 L
s
1 .103 0 r
.008 w
.26809 .16719 Mdot
.016 w
.26809 .16719 m
.26662 .16806 L
s
.008 w
.26662 .16806 Mdot
.016 w
.26662 .16806 m
.26542 .16883 L
s
1 .102 0 r
.008 w
.26542 .16883 Mdot
.016 w
.26542 .16883 m
.26435 .16948 L
s
.008 w
.26435 .16948 Mdot
.016 w
.26435 .16948 m
.26347 .17002 L
s
.008 w
.26347 .17002 Mdot
.016 w
.26347 .17002 m
.26274 .17047 L
s
1 .101 0 r
.008 w
.26274 .17047 Mdot
.016 w
.26274 .17047 m
.26213 .17084 L
s
.008 w
.26213 .17084 Mdot
.016 w
.26213 .17084 m
.26156 .17114 L
s
1 .1 0 r
.008 w
.26156 .17114 Mdot
.016 w
.26156 .17114 m
.26098 .1714 L
s
.008 w
.26098 .1714 Mdot
.016 w
.26098 .1714 m
.26036 .17167 L
s
.008 w
.26036 .17167 Mdot
.016 w
.26036 .17167 m
.25962 .17199 L
s
1 .099 0 r
.008 w
.25962 .17199 Mdot
.016 w
.25962 .17199 m
.2587 .17239 L
s
.008 w
.2587 .17239 Mdot
.016 w
.2587 .17239 m
.25764 .1729 L
s
1 .098 0 r
.008 w
.25764 .1729 Mdot
.016 w
.25764 .1729 m
.25642 .17354 L
s
.008 w
.25642 .17354 Mdot
.016 w
.25642 .17354 m
.25496 .17432 L
s
.008 w
.25496 .17432 Mdot
.016 w
.25496 .17432 m
.25321 .17525 L
s
1 .097 0 r
.008 w
.25321 .17525 Mdot
.016 w
.25321 .17525 m
.25137 .1763 L
s
.008 w
.25137 .1763 Mdot
.016 w
.25137 .1763 m
.24944 .17746 L
s
1 .096 0 r
.008 w
.24944 .17746 Mdot
.016 w
.24944 .17746 m
.24746 .17867 L
s
.008 w
.24746 .17867 Mdot
.016 w
.24746 .17867 m
.24571 .17986 L
s
.008 w
.24571 .17986 Mdot
.016 w
.24571 .17986 m
.24401 .18099 L
s
1 .095 0 r
.008 w
.24401 .18099 Mdot
.016 w
.24401 .18099 m
.2426 .18206 L
s
.008 w
.2426 .18206 Mdot
.016 w
.2426 .18206 m
.24124 .18302 L
s
1 .094 0 r
.008 w
.24124 .18302 Mdot
.016 w
.24124 .18302 m
.24013 .18382 L
s
.008 w
.24013 .18382 Mdot
.016 w
.24013 .18382 m
.23919 .18449 L
s
.008 w
.23919 .18449 Mdot
.016 w
.23919 .18449 m
.23846 .18502 L
s
1 .093 0 r
.008 w
.23846 .18502 Mdot
.016 w
.23846 .18502 m
.23797 .1854 L
s
.008 w
.23797 .1854 Mdot
.016 w
.23797 .1854 m
.23768 .18563 L
s
.008 w
.23768 .18563 Mdot
.016 w
.23768 .18563 m
.23758 .18575 L
s
1 .092 0 r
.008 w
.23758 .18575 Mdot
.016 w
.23758 .18575 m
.23761 .18577 L
s
.008 w
.23761 .18577 Mdot
.016 w
.23761 .18577 m
.23773 .18574 L
s
1 .091 0 r
.008 w
.23773 .18574 Mdot
.016 w
.23773 .18574 m
.23788 .18567 L
s
.008 w
.23788 .18567 Mdot
.016 w
.23788 .18567 m
.23803 .18558 L
s
.008 w
.23803 .18558 Mdot
.016 w
.23803 .18558 m
.23812 .1855 L
s
1 .09 0 r
.008 w
.23812 .1855 Mdot
.016 w
.23812 .1855 m
.23818 .18543 L
s
.008 w
.23818 .18543 Mdot
.016 w
.23818 .18543 m
.23827 .18536 L
s
1 .089 0 r
.008 w
.23827 .18536 Mdot
.016 w
.23827 .18536 m
.23839 .18527 L
s
.008 w
.23839 .18527 Mdot
.016 w
.23839 .18527 m
.23849 .18518 L
s
.008 w
.23849 .18518 Mdot
.016 w
.23849 .18518 m
.23854 .1851 L
s
1 .088 0 r
.008 w
.23854 .1851 Mdot
.016 w
.23854 .1851 m
.23852 .18506 L
s
.008 w
.23852 .18506 Mdot
.016 w
.23852 .18506 m
.23839 .18507 L
s
1 .087 0 r
.008 w
.23839 .18507 Mdot
.016 w
.23839 .18507 m
.23815 .18518 L
s
.008 w
.23815 .18518 Mdot
.016 w
.23815 .18518 m
.23776 .18541 L
s
.008 w
.23776 .18541 Mdot
.016 w
.23776 .18541 m
.23722 .18577 L
s
1 .086 0 r
.008 w
.23722 .18577 Mdot
.016 w
.23722 .18577 m
.23655 .18628 L
s
.008 w
.23655 .18628 Mdot
.016 w
.23655 .18628 m
.23577 .18694 L
s
1 .085 0 r
.008 w
.23577 .18694 Mdot
.016 w
.23577 .18694 m
.23492 .18772 L
s
.008 w
.23492 .18772 Mdot
.016 w
.23492 .18772 m
.23406 .18857 L
s
.008 w
.23406 .18857 Mdot
.016 w
.23406 .18857 m
.23319 .18952 L
s
1 .084 0 r
.008 w
.23319 .18952 Mdot
.016 w
.23319 .18952 m
.23229 .19048 L
s
.008 w
.23229 .19048 Mdot
.016 w
.23229 .19048 m
.2314 .19146 L
s
1 .083 0 r
.008 w
.2314 .19146 Mdot
.016 w
.2314 .19146 m
.23056 .19243 L
s
.008 w
.23056 .19243 Mdot
.016 w
.23056 .19243 m
.22984 .19333 L
s
.008 w
.22984 .19333 Mdot
.016 w
.22984 .19333 m
.22927 .1941 L
s
1 .082 0 r
.008 w
.22927 .1941 Mdot
.016 w
.22927 .1941 m
.22885 .19476 L
s
.008 w
.22885 .19476 Mdot
.016 w
.22885 .19476 m
.22858 .19527 L
s
1 .081 0 r
.008 w
.22858 .19527 Mdot
.016 w
.22858 .19527 m
.22842 .19564 L
s
.008 w
.22842 .19564 Mdot
.016 w
.22842 .19564 m
.22837 .19586 L
s
.008 w
.22837 .19586 Mdot
.016 w
.22837 .19586 m
.22837 .19597 L
s
1 .08 0 r
.008 w
.22837 .19597 Mdot
.016 w
.22837 .19597 m
.2284 .19598 L
s
.008 w
.2284 .19598 Mdot
.016 w
.2284 .19598 m
.22842 .19595 L
s
.008 w
.22842 .19595 Mdot
.016 w
.22842 .19595 m
.22845 .1959 L
s
1 .079 0 r
.008 w
.22845 .1959 Mdot
.016 w
.22845 .1959 m
.22849 .19584 L
s
.008 w
.22849 .19584 Mdot
.016 w
.22849 .19584 m
.22853 .19576 L
s
1 .078 0 r
.008 w
.22853 .19576 Mdot
.016 w
.22853 .19576 m
.2286 .19569 L
s
.008 w
.2286 .19569 Mdot
.016 w
.2286 .19569 m
.22867 .19564 L
s
.008 w
.22867 .19564 Mdot
.016 w
.22867 .19564 m
.22876 .1956 L
s
1 .077 0 r
.008 w
.22876 .1956 Mdot
.016 w
.22876 .1956 m
.22887 .19555 L
s
.008 w
.22887 .19555 Mdot
.016 w
.22887 .19555 m
.22899 .19548 L
s
1 .076 0 r
.008 w
.22899 .19548 Mdot
.016 w
.22899 .19548 m
.22909 .19541 L
s
.008 w
.22909 .19541 Mdot
.016 w
.22909 .19541 m
.22913 .19535 L
s
.008 w
.22913 .19535 Mdot
.016 w
.22913 .19535 m
.22906 .19534 L
s
1 .075 0 r
.008 w
.22906 .19534 Mdot
.016 w
.22906 .19534 m
.22885 .19542 L
s
.008 w
.22885 .19542 Mdot
.016 w
.22885 .19542 m
.22844 .19562 L
s
1 .074 0 r
.008 w
.22844 .19562 Mdot
.016 w
.22844 .19562 m
.22779 .19595 L
s
.008 w
.22779 .19595 Mdot
.016 w
.22779 .19595 m
.22688 .19641 L
s
.008 w
.22688 .19641 Mdot
.016 w
.22688 .19641 m
.22569 .19701 L
s
1 .073 0 r
.008 w
.22569 .19701 Mdot
.016 w
.22569 .19701 m
.22436 .1977 L
s
.008 w
.22436 .1977 Mdot
.016 w
.22436 .1977 m
.22275 .19847 L
s
1 .072 0 r
.008 w
.22275 .19847 Mdot
.016 w
.22275 .19847 m
.22086 .19932 L
s
.008 w
.22086 .19932 Mdot
.016 w
.22086 .19932 m
.21891 .20022 L
s
.008 w
.21891 .20022 Mdot
.016 w
.21891 .20022 m
.21686 .20121 L
s
1 .071 0 r
.008 w
.21686 .20121 Mdot
.016 w
.21686 .20121 m
.21452 .20239 L
s
.008 w
.21452 .20239 Mdot
.016 w
.21452 .20239 m
.21235 .20354 L
s
1 .07 0 r
.008 w
.21235 .20354 Mdot
.016 w
.21235 .20354 m
.21003 .20478 L
s
.008 w
.21003 .20478 Mdot
.016 w
.21003 .20478 m
.20779 .20608 L
s
.008 w
.20779 .20608 Mdot
.016 w
.20779 .20608 m
.20588 .2074 L
s
1 .069 0 r
.008 w
.20588 .2074 Mdot
.016 w
.20588 .2074 m
.20405 .2087 L
s
.008 w
.20405 .2087 Mdot
.016 w
.20405 .2087 m
.2024 .20993 L
s
.008 w
.2024 .20993 Mdot
.016 w
.2024 .20993 m
.20106 .21093 L
s
1 .068 0 r
.008 w
.20106 .21093 Mdot
.016 w
.20106 .21093 m
.19991 .21195 L
s
.008 w
.19991 .21195 Mdot
.016 w
.19991 .21195 m
.19898 .21289 L
s
1 .067 0 r
.008 w
.19898 .21289 Mdot
.016 w
.19898 .21289 m
.1983 .21361 L
s
.008 w
.1983 .21361 Mdot
.016 w
.1983 .21361 m
.19782 .21427 L
s
.008 w
.19782 .21427 Mdot
.016 w
.19782 .21427 m
.1975 .21484 L
s
1 .066 0 r
.008 w
.1975 .21484 Mdot
.016 w
.1975 .21484 m
.1973 .21529 L
s
.008 w
.1973 .21529 Mdot
.016 w
.1973 .21529 m
.19716 .21561 L
s
1 .065 0 r
.008 w
.19716 .21561 Mdot
.016 w
.19716 .21561 m
.19703 .2159 L
s
.008 w
.19703 .2159 Mdot
.016 w
.19703 .2159 m
.19684 .21625 L
s
.008 w
.19684 .21625 Mdot
.016 w
.19684 .21625 m
.19655 .21669 L
s
1 .064 0 r
.008 w
.19655 .21669 Mdot
.016 w
.19655 .21669 m
.19617 .21727 L
s
.008 w
.19617 .21727 Mdot
.016 w
.19617 .21727 m
.19568 .21805 L
s
1 .063 0 r
.008 w
.19568 .21805 Mdot
.016 w
.19568 .21805 m
.19508 .219 L
s
.008 w
.19508 .219 Mdot
.016 w
.19508 .219 m
.1944 .22009 L
s
.008 w
.1944 .22009 Mdot
.016 w
.1944 .22009 m
.19372 .22113 L
s
1 .062 0 r
.008 w
.19372 .22113 Mdot
.016 w
.19372 .22113 m
.19302 .2223 L
s
.008 w
.19302 .2223 Mdot
.016 w
.19302 .2223 m
.19234 .22349 L
s
1 .061 0 r
.008 w
.19234 .22349 Mdot
.016 w
.19234 .22349 m
.19175 .2245 L
s
.008 w
.19175 .2245 Mdot
.016 w
.19175 .2245 m
.19119 .2255 L
s
.008 w
.19119 .2255 Mdot
.016 w
.19119 .2255 m
.19073 .22634 L
s
1 .06 0 r
.008 w
.19073 .22634 Mdot
.016 w
.19073 .22634 m
.19039 .22706 L
s
.008 w
.19039 .22706 Mdot
.016 w
.19039 .22706 m
.19016 .22764 L
s
1 .059 0 r
.008 w
.19016 .22764 Mdot
.016 w
.19016 .22764 m
.18996 .22815 L
s
.008 w
.18996 .22815 Mdot
.016 w
.18996 .22815 m
.18976 .22865 L
s
.008 w
.18976 .22865 Mdot
.016 w
.18976 .22865 m
.18949 .22918 L
s
1 .058 0 r
.008 w
.18949 .22918 Mdot
.016 w
.18949 .22918 m
.18909 .22984 L
s
.008 w
.18909 .22984 Mdot
.016 w
.18909 .22984 m
.18847 .23073 L
s
1 .057 0 r
.008 w
.18847 .23073 Mdot
.016 w
.18847 .23073 m
.18759 .23188 L
s
.008 w
.18759 .23188 Mdot
.016 w
.18759 .23188 m
.18653 .23312 L
s
.008 w
.18653 .23312 Mdot
.016 w
.18653 .23312 m
.18524 .23473 L
s
1 .056 0 r
.008 w
.18524 .23473 Mdot
.016 w
.18524 .23473 m
.18368 .23653 L
s
.008 w
.18368 .23653 Mdot
.016 w
.18368 .23653 m
.18189 .23868 L
s
.008 w
.18189 .23868 Mdot
.016 w
.18189 .23868 m
.17999 .24096 L
s
1 .055 0 r
.008 w
.17999 .24096 Mdot
.016 w
.17999 .24096 m
.17822 .24354 L
s
.008 w
.17822 .24354 Mdot
.016 w
.17822 .24354 m
.17634 .24593 L
s
1 .054 0 r
.008 w
.17634 .24593 Mdot
.016 w
.17634 .24593 m
.17433 .2486 L
s
.008 w
.17433 .2486 Mdot
.016 w
.17433 .2486 m
.17238 .25129 L
s
.008 w
.17238 .25129 Mdot
.016 w
.17238 .25129 m
.17052 .25392 L
s
1 .053 0 r
.008 w
.17052 .25392 Mdot
.016 w
.17052 .25392 m
.16866 .25672 L
s
.008 w
.16866 .25672 Mdot
.016 w
.16866 .25672 m
.16697 .25912 L
s
1 .052 0 r
.008 w
.16697 .25912 Mdot
.016 w
.16697 .25912 m
.16528 .26169 L
s
.008 w
.16528 .26169 Mdot
.016 w
.16528 .26169 m
.16374 .26407 L
s
.008 w
.16374 .26407 Mdot
.016 w
.16374 .26407 m
.16221 .26644 L
s
1 .051 0 r
.008 w
.16221 .26644 Mdot
.016 w
.16221 .26644 m
.16073 .26868 L
s
.008 w
.16073 .26868 Mdot
.016 w
.16073 .26868 m
.15939 .27096 L
s
1 .05 0 r
.008 w
.15939 .27096 Mdot
.016 w
.15939 .27096 m
.15805 .27294 L
s
.008 w
.15805 .27294 Mdot
.016 w
.15805 .27294 m
.15673 .27494 L
s
.008 w
.15673 .27494 Mdot
.016 w
.15673 .27494 m
.1555 .27684 L
s
1 .049 0 r
.008 w
.1555 .27684 Mdot
.016 w
.1555 .27684 m
.15438 .2786 L
s
.008 w
.15438 .2786 Mdot
.016 w
.15438 .2786 m
.15332 .28028 L
s
1 .048 0 r
.008 w
.15332 .28028 Mdot
.016 w
.15332 .28028 m
.15232 .28185 L
s
.008 w
.15232 .28185 Mdot
.016 w
.15232 .28185 m
.15144 .28314 L
s
.008 w
.15144 .28314 Mdot
.016 w
.15144 .28314 m
.15065 .28437 L
s
1 .047 0 r
.008 w
.15065 .28437 Mdot
.016 w
.15065 .28437 m
.14997 .28549 L
s
.008 w
.14997 .28549 Mdot
.016 w
.14997 .28549 m
.14944 .28647 L
s
1 .046 0 r
.008 w
.14944 .28647 Mdot
.016 w
.14944 .28647 m
.14902 .28727 L
s
.008 w
.14902 .28727 Mdot
.016 w
.14902 .28727 m
.14873 .28793 L
s
.008 w
.14873 .28793 Mdot
.016 w
.14873 .28793 m
.14854 .28842 L
s
1 .045 0 r
.008 w
.14854 .28842 Mdot
.016 w
.14854 .28842 m
.14845 .28874 L
s
.008 w
.14845 .28874 Mdot
.016 w
.14845 .28874 m
.14841 .28891 L
s
1 .044 0 r
.008 w
.14841 .28891 Mdot
.016 w
.14841 .28891 m
.1484 .28899 L
s
.008 w
.1484 .28899 Mdot
.016 w
.1484 .28899 m
.14838 .28898 L
s
.008 w
.14838 .28898 Mdot
.016 w
.14838 .28898 m
.14835 .28895 L
s
1 .043 0 r
.008 w
.14835 .28895 Mdot
.016 w
.14835 .28895 m
.14828 .28891 L
s
.008 w
.14828 .28891 Mdot
.016 w
.14828 .28891 m
.14815 .28892 L
s
.008 w
.14815 .28892 Mdot
.016 w
.14815 .28892 m
.14793 .28899 L
s
1 .042 0 r
.008 w
.14793 .28899 Mdot
.016 w
.14793 .28899 m
.14762 .28914 L
s
.008 w
.14762 .28914 Mdot
.016 w
.14762 .28914 m
.1472 .28941 L
s
1 .041 0 r
.008 w
.1472 .28941 Mdot
.016 w
.1472 .28941 m
.14666 .28984 L
s
.008 w
.14666 .28984 Mdot
.016 w
.14666 .28984 m
.14598 .29049 L
s
.008 w
.14598 .29049 Mdot
.016 w
.14598 .29049 m
.1452 .29131 L
s
1 .04 0 r
.008 w
.1452 .29131 Mdot
.016 w
.1452 .29131 m
.1443 .29235 L
s
.008 w
.1443 .29235 Mdot
.016 w
.1443 .29235 m
.14327 .29362 L
s
1 .039 0 r
.008 w
.14327 .29362 Mdot
.016 w
.14327 .29362 m
.1421 .29516 L
s
.008 w
.1421 .29516 Mdot
.016 w
.1421 .29516 m
.14084 .29699 L
s
.008 w
.14084 .29699 Mdot
.016 w
.14084 .29699 m
.1396 .29874 L
s
1 .038 0 r
.008 w
.1396 .29874 Mdot
.016 w
.1396 .29874 m
.1383 .30087 L
s
.008 w
.1383 .30087 Mdot
.016 w
.1383 .30087 m
.13697 .30317 L
s
1 .037 0 r
.008 w
.13697 .30317 Mdot
.016 w
.13697 .30317 m
.13562 .30546 L
s
.008 w
.13562 .30546 Mdot
.016 w
.13562 .30546 m
.13419 .30803 L
s
.008 w
.13419 .30803 Mdot
.016 w
.13419 .30803 m
.13266 .3108 L
s
1 .036 0 r
.008 w
.13266 .3108 Mdot
.016 w
.13266 .3108 m
.13111 .31341 L
s
.008 w
.13111 .31341 Mdot
.016 w
.13111 .31341 m
.12943 .31638 L
s
1 .035 0 r
.008 w
.12943 .31638 Mdot
.016 w
.12943 .31638 m
.12775 .31917 L
s
.008 w
.12775 .31917 Mdot
.016 w
.12775 .31917 m
.12611 .32213 L
s
.008 w
.12611 .32213 Mdot
.016 w
.12611 .32213 m
.12443 .32487 L
s
1 .034 0 r
.008 w
.12443 .32487 Mdot
.016 w
.12443 .32487 m
.1227 .32781 L
s
.008 w
.1227 .32781 Mdot
.016 w
.1227 .32781 m
.12116 .33033 L
s
1 .033 0 r
.008 w
.12116 .33033 Mdot
.016 w
.12116 .33033 m
.11929 .33307 L
s
.008 w
.11929 .33307 Mdot
.016 w
.11929 .33307 m
.1176 .33573 L
s
.008 w
.1176 .33573 Mdot
.016 w
.1176 .33573 m
.1157 .33852 L
s
1 .032 0 r
.008 w
.1157 .33852 Mdot
.016 w
.1157 .33852 m
.11388 .34138 L
s
.008 w
.11388 .34138 Mdot
.016 w
.11388 .34138 m
.11193 .34388 L
s
1 .031 0 r
.008 w
.11193 .34388 Mdot
.016 w
.11193 .34388 m
.10991 .34658 L
s
.008 w
.10991 .34658 Mdot
.016 w
.10991 .34658 m
.10795 .34941 L
s
.008 w
.10795 .34941 Mdot
.016 w
.10795 .34941 m
.10646 .35173 L
s
1 .03 0 r
.008 w
.10646 .35173 Mdot
.016 w
.10646 .35173 m
.10485 .35424 L
s
.008 w
.10485 .35424 Mdot
.016 w
.10485 .35424 m
.10339 .35639 L
s
.008 w
.10339 .35639 Mdot
.016 w
.10339 .35639 m
.10193 .35855 L
s
1 .029 0 r
.008 w
.10193 .35855 Mdot
.016 w
.10193 .35855 m
.10084 .3603 L
s
.008 w
.10084 .3603 Mdot
.016 w
.10084 .3603 m
.09987 .36193 L
s
1 .028 0 r
.008 w
.09987 .36193 Mdot
.016 w
.09987 .36193 m
.09902 .3634 L
s
.008 w
.09902 .3634 Mdot
.016 w
.09902 .3634 m
.09837 .36459 L
s
.008 w
.09837 .36459 Mdot
.016 w
.09837 .36459 m
.09791 .36555 L
s
1 .027 0 r
.008 w
.09791 .36555 Mdot
.016 w
.09791 .36555 m
.09764 .36625 L
s
.008 w
.09764 .36625 Mdot
.016 w
.09764 .36625 m
.09754 .36668 L
s
1 .026 0 r
.008 w
.09754 .36668 Mdot
.016 w
.09754 .36668 m
.09756 .36689 L
s
.008 w
.09756 .36689 Mdot
.016 w
.09756 .36689 m
.09765 .36691 L
s
.008 w
.09765 .36691 Mdot
.016 w
.09765 .36691 m
.09777 .36682 L
s
1 .025 0 r
.008 w
.09777 .36682 Mdot
.016 w
.09777 .36682 m
.0979 .36666 L
s
.008 w
.0979 .36666 Mdot
.016 w
.0979 .36666 m
.098 .3665 L
s
1 .024 0 r
.008 w
.098 .3665 Mdot
.016 w
.098 .3665 m
.09805 .36636 L
s
.008 w
.09805 .36636 Mdot
.016 w
.09805 .36636 m
.09804 .36626 L
s
.008 w
.09804 .36626 Mdot
.016 w
.09804 .36626 m
.09804 .3662 L
s
1 .023 0 r
.008 w
.09804 .3662 Mdot
.016 w
.09804 .3662 m
.09804 .36618 L
s
.008 w
.09804 .36618 Mdot
.016 w
.09804 .36618 m
.09802 .36622 L
s
1 .022 0 r
.008 w
.09802 .36622 Mdot
.016 w
.09802 .36622 m
.09798 .3663 L
s
.008 w
.09798 .3663 Mdot
.016 w
.09798 .3663 m
.0979 .36644 L
s
.008 w
.0979 .36644 Mdot
.016 w
.0979 .36644 m
.09779 .36669 L
s
1 .021 0 r
.008 w
.09779 .36669 Mdot
.016 w
.09779 .36669 m
.09766 .36705 L
s
.008 w
.09766 .36705 Mdot
.016 w
.09766 .36705 m
.09753 .36755 L
s
1 .02 0 r
.008 w
.09753 .36755 Mdot
.016 w
.09753 .36755 m
.09741 .36818 L
s
.008 w
.09741 .36818 Mdot
.016 w
.09741 .36818 m
.09731 .36894 L
s
.008 w
.09731 .36894 Mdot
.016 w
.09731 .36894 m
.09723 .3698 L
s
1 .019 0 r
.008 w
.09723 .3698 Mdot
.016 w
.09723 .3698 m
.0972 .37074 L
s
.008 w
.0972 .37074 Mdot
.016 w
.0972 .37074 m
.09719 .37166 L
s
.008 w
.09719 .37166 Mdot
.016 w
.09719 .37166 m
.09721 .3726 L
s
1 .018 0 r
.008 w
.09721 .3726 Mdot
.016 w
.09721 .3726 m
.09726 .37352 L
s
.008 w
.09726 .37352 Mdot
.016 w
.09726 .37352 m
.09731 .3744 L
s
1 .017 0 r
.008 w
.09731 .3744 Mdot
.016 w
.09731 .3744 m
.0974 .37517 L
s
.008 w
.0974 .37517 Mdot
.016 w
.0974 .37517 m
.09752 .37578 L
s
.008 w
.09752 .37578 Mdot
.016 w
.09752 .37578 m
.09766 .37617 L
s
1 .016 0 r
.008 w
.09766 .37617 Mdot
.016 w
.09766 .37617 m
.09782 .3764 L
s
.008 w
.09782 .3764 Mdot
.016 w
.09782 .3764 m
.09799 .37653 L
s
1 .015 0 r
.008 w
.09799 .37653 Mdot
.016 w
.09799 .37653 m
.09815 .37657 L
s
.008 w
.09815 .37657 Mdot
.016 w
.09815 .37657 m
.09827 .37657 L
s
.008 w
.09827 .37657 Mdot
.016 w
.09827 .37657 m
.09831 .37661 L
s
1 .014 0 r
.008 w
.09831 .37661 Mdot
.016 w
.09831 .37661 m
.09825 .37679 L
s
.008 w
.09825 .37679 Mdot
.016 w
.09825 .37679 m
.0981 .37725 L
s
1 .013 0 r
.008 w
.0981 .37725 Mdot
.016 w
.0981 .37725 m
.09786 .37805 L
s
.008 w
.09786 .37805 Mdot
.016 w
.09786 .37805 m
.09755 .37923 L
s
.008 w
.09755 .37923 Mdot
.016 w
.09755 .37923 m
.09719 .38079 L
s
1 .012 0 r
.008 w
.09719 .38079 Mdot
.016 w
.09719 .38079 m
.09677 .38274 L
s
.008 w
.09677 .38274 Mdot
.016 w
.09677 .38274 m
.09628 .38475 L
s
1 .011 0 r
.008 w
.09628 .38475 Mdot
.016 w
.09628 .38475 m
.0957 .38699 L
s
.008 w
.0957 .38699 Mdot
.016 w
.0957 .38699 m
.09501 .38971 L
s
.008 w
.09501 .38971 Mdot
.016 w
.09501 .38971 m
.09421 .39254 L
s
1 .01 0 r
.008 w
.09421 .39254 Mdot
.016 w
.09421 .39254 m
.09334 .39569 L
s
.008 w
.09334 .39569 Mdot
.016 w
.09334 .39569 m
.09239 .39876 L
s
1 .009 0 r
.008 w
.09239 .39876 Mdot
.016 w
.09239 .39876 m
.09139 .40204 L
s
.008 w
.09139 .40204 Mdot
.016 w
.09139 .40204 m
.09042 .40525 L
s
.008 w
.09042 .40525 Mdot
.016 w
.09042 .40525 m
.08946 .40813 L
s
1 .008 0 r
.008 w
.08946 .40813 Mdot
.016 w
.08946 .40813 m
.08854 .4113 L
s
.008 w
.08854 .4113 Mdot
.016 w
.08854 .4113 m
.08773 .41418 L
s
1 .007 0 r
.008 w
.08773 .41418 Mdot
.016 w
.08773 .41418 m
.08695 .41712 L
s
.008 w
.08695 .41712 Mdot
.016 w
.08695 .41712 m
.08629 .41988 L
s
.008 w
.08629 .41988 Mdot
.016 w
.08629 .41988 m
.08569 .42278 L
s
1 .006 0 r
.008 w
.08569 .42278 Mdot
.016 w
.08569 .42278 m
.08518 .42524 L
s
.008 w
.08518 .42524 Mdot
.016 w
.08518 .42524 m
.08478 .42784 L
s
.008 w
.08478 .42784 Mdot
.016 w
.08478 .42784 m
.08449 .43026 L
s
1 .005 0 r
.008 w
.08449 .43026 Mdot
.016 w
.08449 .43026 m
.08431 .43277 L
s
.008 w
.08431 .43277 Mdot
.016 w
.08431 .43277 m
.08422 .43517 L
s
1 .004 0 r
.008 w
.08422 .43517 Mdot
.016 w
.08422 .43517 m
.08422 .43713 L
s
.008 w
.08422 .43713 Mdot
.016 w
.08422 .43713 m
.08425 .439 L
s
.008 w
.08425 .439 Mdot
.016 w
.08425 .439 m
.08431 .44075 L
s
1 .003 0 r
.008 w
.08431 .44075 Mdot
.016 w
.08431 .44075 m
.08436 .44233 L
s
.008 w
.08436 .44233 Mdot
.016 w
.08436 .44233 m
.08439 .44369 L
s
1 .002 0 r
.008 w
.08439 .44369 Mdot
.016 w
.08439 .44369 m
.08439 .44475 L
s
.008 w
.08439 .44475 Mdot
.016 w
.08439 .44475 m
.08438 .44563 L
s
.008 w
.08438 .44563 Mdot
.016 w
.08438 .44563 m
.08437 .44631 L
s
1 .001 0 r
.008 w
.08437 .44631 Mdot
.016 w
.08437 .44631 m
.08437 .44681 L
s
.008 w
.08437 .44681 Mdot
.016 w
.08437 .44681 m
.08436 .44715 L
s
1 0 0 r
.008 w
.08436 .44715 Mdot
.016 w
.08436 .44715 m
.08436 .44732 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0469921 0.0433155 scale
2.03034 8.78923 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0305782 0.0281858 scale
3.46717 12.6301 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0126156 0.0116286 scale
29.5237 10.7244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0218509 0.0201413 scale
19.0098 5.63221 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0204396 0.0188405 scale
17.0629 6.813 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0160818 0.0148236 scale
17.5428 11.5728 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0388839 0.0358417 scale
4.57593 6.98097 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0183903 0.0169514 scale
11.2734 13.3594 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0141047 0.0130012 scale
17.078 14.7525 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0218509 0.0201413 scale
23.4654 5.56369 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0908631 0.0837541 scale
4.46617 1.28424 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0490632 0.0452246 scale
7.84845 2.39936 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0166889 0.0153832 scale
20.8882 7.93985 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0109254 0.0100706 scale
31.2354 12.7062 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0223015 0.0205566 scale
13.9803 6.98412 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0183903 0.0169514 scale
15.7817 9.05116 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0160818 0.0148236 scale
14.7968 12.5395 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0166889 0.0153832 scale
13.6876 12.736 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0141047 0.0130012 scale
6.92465 28.2275 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001aOol:002UOol006aoo`D0
00Yoo`<00:9oo`00JWoo0P004Woo0P00X7oo001XOol2000FOol3002MOol006Moo`03001oogoo01Uo
o`8009]oo`00IWoo00<007ooOol077oo00<007ooOol0V7oo001TOol2000POol00`00Oomoo`2GOol0
06=oo`03001oogoo025oo`03001oogoo09Ioo`00HWoo00<007ooOol08goo00<007ooOol0UGoo001Q
Ool00`00Oomoo`0UOol00`00Oomoo`2DOol0065oo`03001oogoo02Ioo`03001oogoo09=oo`00H7oo
00<007ooOol02Woo20005Woo00<007ooOol0TWoo001POol00`00Oomoo`07Ool30008Ool2000DOol0
0`00Oomoo`2BOol005moo`03001oogoo00Ioo`8000eoo`03001oogoo019oo`03001oogoo095oo`00
Ggoo00<007ooOol01Goo00<007ooOol03Woo0P004Woo00<007ooOol0TGoo001NOol00`00Oomoo`05
Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`2@Ool005ioo`03001oogoo00Aoo`03001o
ogoo01=oo`03001oogoo00moo`03001oogoo091oo`00GGoo00<007ooOol017oo00<007ooOol057oo
00<007ooOol047oo00<007ooOol0Sgoo001MOol00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomo
o`0@Ool00`00Oomoo`2?Ool005aoo`03001oogoo00Aoo`03001oogoo00moo`D0009oo`03001oogoo
00moo`03001oo`0000D008Yoo`00G7oo00<007ooOol00goo00<007ooOol03goo00<007ooOol00goo
0`004Goo0`001Goo00<007ooOol0Qgoo001LOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomm
H002O@04OolC0002Ool@001oOol005aoo`03001oogoo00=oo`03001oogoo00Qoo`Al`003Ool007d0
00Em00AmX003001mX7fP00emX08000=mX0Ioo`03001oogoo00Ioo`H007Uoo`00G7oo00<007ooOol0
0goo1`001WbP0gc000<007d0O@000gcP0Wd00gfP0P003WfP0P001GfP17oo00<007ooOol037oo1@00
M7oo001LOol00`00Oomoo`03Ool80005O:03O<000`00O>1lh004O>04OJ02000>OJ020006OJ03Ool0
0`00Oomoo`0AOol5001_Ool005aoo`03001oogoo009oo`80009oo`03OP1lX7bP009lX0@00005O:1l
`7c0O>000006O>04OJ02000>OJ020006OJ03Ool00`00Oomoo`0FOol5001ZOol005aoo`04001oogoo
Ool60004O:020002O:0200000gc0O>000006O>04ON020004ON0:OL020006OJ03Ool00`00Oomoo`0K
Ool3001WOol005]oo`<0009oo`@00003O81lX000009lX0<00004O:1l`7cP0002O>000`00O>1lh004
O>04ON000`00ON1mh003ON0;OL000`00OL1mX004OJ03Ool00`00Oomoo`0NOol3001TOol005Qoo`<0
009oo`D00005O80007b0O8000002O:030002OP000ggP001mh002ON001000O>1lh7cP1GgP0P0000=m
h7ooOol017oo2Gg00P001Woo0P0097oo0`00HGoo001GOol00`00Oomoo`03Ool02P00O81lP000O800
07b0001lP0000WbP0`000glP00<007ooON000WgP00<007gPON0017gP0P002Goo17g017oo00@007oo
0000009oo`8002Uoo`8005moo`00EWoo00<007ooOol00Woo00D007b0O80007b000D00003O80007kP
00@00003Ob00000000Ioo`L0015oo`03001oogoo009oo`8002eoo`<005aoo`00Dgoo1P001Gb000<0
07b000001`000Woo0`003Goo00<007ooOol047oo00<007ooOol0=7oo0`00FGoo001BOol00`00Oomo
o`0300000gb0001lP004O8001@00O8000000OP000Woo0P0000=oo`00Ool03Woo00<007ooOol047oo
00<007ooOol0>7oo0P00Egoo001BOol01@00Ool00000O6000Wb000<007b0O8000gb000@007b0001o
o`8000=oo`8000ioo`03001oogoo015oo`03001oogoo03Yoo`8005Eoo`00DGoo0`000WaP00D007aP
O61lH00000ElP08000=oo`D000aoo`8001=oo`03001oogoo03eoo`8005=oo`00D7oo0P0000EoogaP
O61lH00000=lH003001lP7b000=n008000Qoo`@000Eoo`<001Eoo`03001oogoo03moo`80055oo`00
Cgoo00<007oo00001GaP00D007aPO60007b0009n0004Ob1oogoo000<Ool5000GOol00`00Oomoo`12
Ool00`00Oomoo`1>Ool004eoo`800003OomlH00000L00003O60007h0009o8004Ool00000000WOol0
0`00Oomoo`14Ool2001>Ool004]oo`8000=lH003001lH00000AlH006001n0000001o87oo0P000goo
00<007ooOol08goo00<007ooOol0Agoo0P00C7oo0019Ool20005O6000`00O6000004O60300000goo
00000006Ool2000ROol00`00Oomoo`1:Ool2001:Ool004Moo`800003OomlH7aP00=lH004001lH7aP
O60600000gk0Oomoo`09Ool00`00Oomoo`0NOol00`00Oomoo`1=Ool20018Ool004Aoo`<00003Ooml
H00000ElH004001lH7aPO603OP02O/000`00O/1oo`0;Ool00`00Oomoo`0KOol2001BOol20016Ool0
04Aoo`03001oogaP00=lH003001lH7aP00=lH003001n07h000=n0003O/0007oo00ioo`8001Uoo`80
05Ioo`03001oogoo04=oo`00@Woo2@0017aP00=n8000OP000gh000=nX7k000004Goo0P005Goo0P00
FGoo00<007ooOol0@Woo0011Ool3000017a0001l@0000Wa00P0000=lH7hPOR000WhP0P0000An8000
000001Aoo`80011oo`<005aoo`80049oo`00@7oo0P0000=oo`0000000ga000@007a0O60000Mn8003
001oogoo01Moo`D000Uoo`80065oo`03001oogoo03moo`00?goo0P000ga000<007a0O4000Wa000@0
07hP000002Eoo`T006Aoo`8003moo`00?Woo00<007a000000ga000<007a0O4000Wa00P0000=oo`00
Ool0Tgoo00<007ooOol0?7oo000lOol20002O4000`00O41l@002O40200001Ga0000007oo0000UWoo
00<007ooOol0>goo000kOol00`00O41l@002O4000`00O41l@002O403000017i000000000Ugoo00<0
07ooOol0>Woo000jOol00`00O41l@004O4020003O40017i000000000VWoo0P00>Woo000iOol00`00
O41l@0050002O4001000OT000000Wgoo00<007ooOol0=goo000dOol50002O4000`00O41l@003O402
00000gi0001nP02QOol00`00Oomoo`0fOol0039oo`80009oo`03001oogj000<00004O21l@7a0O402
OT000goo001oo`2SOol00`00Oomoo`0eOol0035oo`05001oogooOol00002Ool2O2000`00O2000002
O403OT000goo001oo`2TOol00`00Oomoo`0dOol002moo`8000=oo`04001oogooOX02O2000`00O21l
80020002OT03Ool00`00Oomoo`2SOol00`00Oomoo`0cOol002ioo`04001oogooOol20002Ool01Gj0
O21l87`P00000W`P0Wi000<007i0Ool00Woo00<007ooOol0Y7oo0P00<goo000^Ool01000Oomoo`00
17oo17`P00<007`PO2000gi000@007ooOol00:Uoo`03001oogoo031oo`00;Goo00@007ooOol000Ao
o`03OX1l87`P00=l8003001n@7i000=n@003001oo`000:Yoo`03001oogoo02moo`00;Goo00<007oo
00001Goo1W`P0P000gi000=oo`000000[7oo00<007ooOol0;Woo000/Ool00`00Ool00005Ool7O202
OT05002^Ool00`00Oomoo`0]Ool002aoo`8000Eoo`Ml80An@0=oo`03001oogoo0:eoo`03001oogoo
02aoo`00;7oo00<007ooOol00goo00=oP7`PO2000g`P00=nH7i0OT000Wi017oo00<007ooOol0[Woo
00<007ooOol0:goo000/Ool00`00Oomoo`03Ool6O204OV05Ool00`00Oomoo`2^Ool00`00Oomoo`0[
Ool002]oo`8000Aoo`Ml80AnH0Eoo`03001oogoo0:moo`03001oogoo02Yoo`00:Woo00@007ooOol0
00=oo`Il80Yoo`03001oogoo0;1oo`03001oogoo02Uoo`00:Goo00D007ooOomoo`00009oo`Il80Yo
o`03001oogoo0;9oo`03001oogoo02Qoo`00:7oo00<007ooOol00Woo00<007ooO2001W`P2Woo00<0
07ooOol0/goo00<007ooOol09goo000WOol00`00Oomoo`04Ool00`00O21l8004O20:Ool00`00Oomo
o`2eOol00`00Oomoo`0VOol002Ioo`03001oogoo00Eoo`03O20007`P00=l8003Oh1oogoo00Ioo`80
0;Uoo`03001oogoo02Eoo`009Woo00<007ooOol017oo0g`P0P0000Al87n0?Nlmk`Eoo`800;]oo`03
001oogoo02Eoo`009Goo00<007ooOol01Goo1G`P0P000Sg_0goo0P00_Woo00<007ooOol097oo000T
Ool00`00Oomoo`05Ool6O202Oh050031Ool00`00Oomoo`0SOol002=oo`03001oogoo00Eoo`Ml809o
P<Moo`03001oogoo029oo`008Woo00<007ooOol01Goo1g`P0Wn0bGoo00<007ooOol08Goo000ROol0
0`00Oomoo`05Ool7O202Oh39Ool00`00Oomoo`0QOol0025oo`03001oogoo00Eoo`Il80=oP<]oo`03
001oogoo021oo`0087oo00<007ooOol01Woo1W`P0Wn0cGoo00<007ooOol07goo000OOol00`00Oomo
o`06Ool6O202Oh3?Ool00`00Oomoo`0NOol001moo`03001oogoo00Eoo`Il809oP=1oo`03001oogoo
01ioo`007Woo00<007ooOol01Woo1W`P00=oP7ooOol0d7oo00<007ooOol07Goo000NOol00`00Oomo
o`05Ool6O2000gn0?Nmoo`3AOol00`00Oomoo`0MOol001eoo`03001oogoo00Ioo`Il8003Oh0mkgoo
0=9oo`03001oogoo01aoo`0077oo00<007ooOol01Woo1W`P0Wn0eGoo00<007ooOol06goo000LOol0
0`00Oomoo`090002O202Oh000cg_Oomoo`3COol00`00Oomoo`0KOol001]oo`04001oo`000004Ool5
O2001@00O21oP7n0?Nl0eWoo00<007ooOol06Woo000KOol80005O20017n0001oP3g_egoo00<007oo
Ool06Woo000JOol30005Ool00g`00000000200001G`POh1oP000?Nl0f7oo00<007ooOol06Goo000H
Ool40005Ool5O0001G`P001oP7n00000fGoo00<007ooOol06Goo000GOol01@00Ool007oo00001Goo
1G`000Il87n0000007oo003IOol00`00Oomoo`0HOol001Moo`04001oo`000005Ool6O003Oh000goo
0000003JOol00`00Oomoo`0GOol001Ioo`05001oo`00Ool00004Ool017`0000000000g`00Wn00goo
00<007ooOol0f7oo00<007ooOol05goo000EOol01000Oomoo`000Woo00<007ooOol00P000g`00P00
0Wn017oo00<007ooOol0f7oo00<007ooOol05goo000DOol01000Oomoo`000goo00@007ooOol000El
0003001oX3g_00Aoo`03001oogoo0=Uoo`03001oogoo01Ioo`0057oo00@007ooOol000=oo`03001o
o`0000Il0003000mkgoo00Aoo`800=Yoo`03001oogoo01Ioo`004goo00@007ooOol000Eoo`8000El
0003Oj0007oo00Aoo`03001oo`000=]oo`03001oogoo01Eoo`004goo00@007ooOol000Eoo`03001o
h00000Al0003000mkgoo00Aoo`04001oogoo003JOol00`00Oomoo`0EOol001=oo`03001oo`0000Mo
o`<0009l00800004?NmoogooOol20003Ool00`00Oomoo`3IOol00`00Oomoo`0DOol001=oo`03001o
o`0000Moo`03On1l000000800003O00mkgoo00<000Eoo`03001oogoo0=Uoo`03001oogoo01Aoo`00
4goo0P0027oo00Aoh7`0O01l00@000Qoo`03001oogoo0=Yoo`03001oogoo01=oo`004goo0P0027oo
00=oh7`0O0000g`02Woo00<007ooOol0fWoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6O00:
Ool00`00Oomoo`3JOol00`00Oomoo`0COol001=oo`8000Moo`03On1l07`000=l0003?Nmoogoo00Mo
o`03001oogoo0=aoo`03001oogoo019oo`004goo00<007oo00001Woo00=oh7`0O0000g`02Woo00<0
07ooOol0g7oo00<007ooOol04Woo000COol00`00Ool00006Ool00goPO01l0002O00;Ool00`00Oomo
o`3LOol00`00Oomoo`0BOol0019oo`05001oogooOol00005Ool6O009Ool00`00Oomoo`3NOol00`00
Oomoo`0AOol0019oo`05001oogooOol00005Ool5O009Ool00`00Oomoo`3OOol00`00Oomoo`0AOol0
015oo`03001oogoo00=oo`05001oogooOolmk`05O007Ool2003SOol00`00Oomoo`0@Ool0015oo`03
001oogoo00Aoo`800003Ooml07`000Al00Eoo`800>Eoo`03001oogoo011oo`004Goo00<007ooOol0
1Woo0`000g`017oo0P00igoo00<007ooOol047oo000@Ool00`00Oomoo`08Ool2O007003ZOol00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Al0003On0mkgoo0>aoo`03001oogoo00moo`0047oo00<0
07ooOol027oo17`000=oh7ooOol0k7oo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4O0000cg_
Oomoo`3/Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Al0003?Nmoogoo0>aoo`03001oogoo
00moo`0047oo00<007ooOol027oo17`000<mkgooOol0k7oo00<007ooOol03goo000?Ool00`00Oomo
o`09Ool4O03`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al0?1oo`03001oogoo00ioo`00
3goo00<007ooOol02Goo17`0l7oo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool4?NoaOol00`00
Oomoo`0=Ool000ioo`03001oogoo00Yoo`@mko5oo`03001oogoo00eoo`003Woo00<007ooOol02Woo
13g_lGoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo
0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000=Ool00`00Oomoo`3o
Ool2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007oo
Ool0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03
001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=
Ool00`00Oomoo`09Ool5?NocOol00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`Hmk`Eoo`DmknUo
o`03001oogoo00aoo`003Goo00<007ooOol027oo1Sg_1Goo1Sg_j7oo00<007ooOol037oo000<Ool0
0`00Oomoo`09Ool6?Nl5Ool6?NoYOol00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`Hmk`Eoo`Lm
knQoo`03001oogoo00]oo`0037oo00<007ooOol02Woo2Sg_00=oocg_?Nl013g_j7oo00<007ooOol0
2goo000<Ool00`00Oomoo`0:OolC?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo00Yooa<mknIo
o`03001oogoo00]oo`0037oo00<007ooOol03Goo43g_iWoo00<007ooOol02goo000<Ool00`00Oomo
o`0@Ool=?NoVOol00`00Oomoo`0;Ool000aoo`03001oogoo01Ioo`PmknEoo`03001oogoo00]oo`00
37oo00<007ooOol067oo1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`0IOol6?NoTOol00`00
Oomoo`0;Ool000aoo`03001oogoo01Qoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol067oo
2Sg_hGoo00<007ooOol02goo000<Ool00`00Oomoo`0HOol:?NoQOol00`00Oomoo`0;Ool000aoo`03
001oogoo01Qoo`/mkn1oo`03001oogoo00]oo`0037oo00<007ooOol06Goo2Sg_h7oo00<007ooOol0
2goo000=Ool00`00Oomoo`0KOol8?NoNOol00`00Oomoo`0<Ool000eoo`03001oogoo01]oo`Pmkmio
o`03001oogoo00aoo`003Goo00<007ooOol06goo23g_gWoo00<007ooOol037oo000=Ool00`00Oomo
o`0LOol8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo01aoo`Pmkmeoo`03001oogoo00aoo`00
3Goo00<007ooOol077oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`0LOol;?NoJOol00`00
Oomoo`0<Ool000eoo`03001oogoo01aoo`/mkmYoo`03001oogoo00aoo`003Goo00<007ooOol07Goo
2Sg_fWoo00<007ooOol037oo000>Ool00`00Oomoo`0MOol9?NoIOol00`00Oomoo`0=Ool000ioo`03
001oogoo01ioo`PmkmUoo`03001oogoo00eoo`003Woo00<007ooOol07Woo1Cg_g7oo00<007ooOol0
3Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eo
o`003Woo00<007ooOol0ogoo00<007ooOol03Goo000?Ool00`00Oomoo`3mOol00`00Oomoo`0>Ool0
00moo`03001oogoo0?eoo`03001oogoo00ioo`003goo00<007ooOol0oGoo00<007ooOol03Woo000@
Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03001oogoo0?]oo`03001oogoo00moo`0047oo
00<007ooOol0ngoo00<007ooOol03goo000@Ool00`00Oomoo`3kOol00`00Oomoo`0?Ool0011oo`03
001oogoo0?]oo`03001oogoo00moo`0047oo00<007ooOol0ngoo00<007ooOol03goo000AOol00`00
Oomoo`3iOol00`00Oomoo`0@Ool0015oo`03001oogoo0?Uoo`03001oogoo011oo`004Goo00<007oo
Ool0nGoo00<007ooOol047oo000BOol00`00Oomoo`3gOol00`00Oomoo`0AOol0019oo`03001oogoo
0?Moo`03001oogoo015oo`004goo00<007ooOol0mWoo00<007ooOol04Goo000COol00`00Oomoo`3e
Ool00`00Oomoo`0BOol001=oo`03001oogoo0?Eoo`03001oogoo019oo`0057oo00<007ooOol0lgoo
00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03
001oogoo01=oo`005Goo00<007ooOol0lGoo00<007ooOol057oo000EOol00`00Oomoo`3aOol00`00
Oomoo`0DOol001Ioo`03001oogoo0>moo`03001oogoo01Eoo`005Woo00<007ooOol0kgoo00<007oo
Ool05Goo000GOol00`00Oomoo`3]Ool00`00Oomoo`0FOol001Moo`03001oogoo0>eoo`03001oogoo
01Ioo`0067oo00<007ooOol0jgoo00<007ooOol05goo000HOol00`00Oomoo`3[Ool00`00Oomoo`0G
Ool001Uoo`03001oogoo0>Yoo`03001oogoo01Moo`006Goo00<007ooOol0jGoo00<007ooOol067oo
000JOol00`00Oomoo`3WOol00`00Oomoo`0IOol001Yoo`03001oogoo0>Moo`03001oogoo01Uoo`00
6goo00<007ooOol0iGoo00<007ooOol06Woo000KOol00`00Oomoo`3UOol00`00Oomoo`0JOol001ao
o`03001oogoo0>=oo`03001oogoo01]oo`0077oo00<007ooOol0hgoo00<007ooOol06goo000MOol0
0`00Oomoo`3QOol00`00Oomoo`0LOol001ioo`03001oogoo0=moo`03001oogoo01eoo`007Woo00<0
07ooOol0ggoo00<007ooOol07Goo000OOol00`00Oomoo`3MOol00`00Oomoo`0NOol001moo`03001o
ogoo0=eoo`03001oogoo01ioo`0087oo00<007ooOol0fgoo00<007ooOol07goo000QOol00`00Oomo
o`3IOol00`00Oomoo`0POol0029oo`03001oogoo0=Moo`03001oogoo025oo`008Woo00<007ooOol0
egoo00<007ooOol08Goo000SOol00`00Oomoo`3EOol00`00Oomoo`0ROol002Aoo`03001oogoo0==o
o`03001oogoo02=oo`009Goo00<007ooOol0dGoo00<007ooOol097oo000VOol00`00Oomoo`3?Ool0
0`00Oomoo`0UOol002Ioo`03001oogoo0<moo`03001oogoo02Eoo`009goo00<007ooOol0cGoo00<0
07ooOol09Woo000XOol00`00Oomoo`3;Ool00`00Oomoo`0WOol002Uoo`03001oogoo0<Uoo`03001o
ogoo02Qoo`00:Woo00<007ooOol0agoo00<007ooOol0:Goo000[Ool00`00Oomoo`35Ool00`00Oomo
o`0ZOol002aoo`03001oogoo0<=oo`03001oogoo02]oo`00;7oo00<007ooOol0`goo00<007ooOol0
:goo000]Ool00`00Oomoo`31Ool00`00Oomoo`0/Ool002ioo`03001oogoo0;moo`03001oogoo02eo
o`00;goo00<007ooOol0_Goo00<007ooOol0;Woo000`Ool00`00Oomoo`2kOol00`00Oomoo`0_Ool0
035oo`03001oogoo0;Uoo`03001oogoo031oo`00<Woo0P00]goo0P00<goo000dOol00`00Oomoo`2c
Ool00`00Oomoo`0cOol003Eoo`03001oogoo0;5oo`03001oogoo03Aoo`00=Woo00<007ooOol0[goo
00<007ooOol0=Goo000gOol00`00Oomoo`2]Ool00`00Oomoo`0fOol003Qoo`03001oogoo0:]oo`03
001oogoo03Moo`00>Goo0P00ZGoo0P00>Woo000kOol00`00Oomoo`2UOol00`00Oomoo`0jOol003ao
o`03001oogoo0:=oo`03001oogoo03]oo`00?Goo00<007ooOol0XGoo00<007ooOol0?7oo000nOol2
002OOol2000oOol0041oo`03001oogoo09]oo`03001oogoo03moo`00@Goo0P00VGoo0P00@Woo0013
Ool00`00Oomoo`2EOol00`00Oomoo`12Ool004Aoo`03001oogoo09=oo`03001oogoo04=oo`00AGoo
0P00TGoo0P00AWoo0017Ool2002=Ool20018Ool004Uoo`8008Uoo`8004Yoo`00Bgoo0P00QGoo0P00
C7oo001=Ool20021Ool2001>Ool004moo`03001oogoo07eoo`03001oogoo04ioo`00D7oo0P00Ngoo
0P00DGoo001BOol2001gOol2001COol005Aoo`8007=oo`8005Eoo`00EWoo0P00Kgoo0P00Egoo001H
Ool3001YOol3001IOol005]oo`<006=oo`<005aoo`00GWoo0`00GGoo0`00Ggoo001QOol3001GOol3
001ROol006Aoo`<0055oo`<006Eoo`00Igoo0`00Bgoo0`00J7oo001ZOol50011Ool5001[Ool006mo
o`<003]oo`<0071oo`00LWoo1P00;goo1P00Lgoo001hOol7000QOol7001iOol007moo`h000Eoo`h0
081oo`00SGoo1@00SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002?Ool3002>
Ool0091oo`03001oogoo08eoo`00SGoo1@00SWoo002=Ool01000Oomoo`00Sgoo002>Ool00`00Ool0
002?Ool008moo`8008moo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -208.083, 1.30024, \
1.4106}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.502054 0.00278904 0.467536 0.00261016 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(5)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.474137 0.443727 scale
1.05887 1.05367 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08822 .37002 m
.08833 .3699 L
.08848 .36972 L
.08866 .36947 L
.08886 .36915 L
.08906 .36874 L
.08926 .36824 L
.08946 .36766 L
.08965 .36703 L
.08986 .36632 L
.0901 .36553 L
.09037 .36467 L
.09069 .3638 L
.091 .3629 L
.09127 .362 L
.09155 .36114 L
.09183 .36034 L
.09212 .35953 L
.09242 .35872 L
.09274 .35787 L
.09306 .35698 L
.09334 .3561 L
.09355 .35517 L
.0937 .35418 L
.09375 .35313 L
.09372 .3521 L
.09363 .35097 L
.09353 .34985 L
.09345 .34871 L
.09338 .34749 L
.09334 .34625 L
.09332 .34511 L
.09332 .34399 L
.09331 .34294 L
.09332 .34201 L
.09334 .34119 L
.09341 .34049 L
.09351 .33987 L
.09365 .33932 L
.09382 .33875 L
.09401 .33813 L
.09419 .33743 L
.09437 .33663 L
.09455 .33568 L
.09477 .33458 L
.09508 .33355 L
.09545 .33231 L
.09591 .33102 L
.09645 .32949 L
.09703 .32805 L
Mistroke
.09763 .32641 L
.09822 .3246 L
.0988 .32292 L
.09934 .32117 L
.09985 .31947 L
.10037 .3178 L
.1009 .31644 L
.10144 .31507 L
.10197 .31384 L
.10245 .3128 L
.10286 .31183 L
.10319 .31106 L
.10344 .31043 L
.10365 .30995 L
.10383 .30964 L
.10402 .30949 L
.10422 .30949 L
.1044 .30959 L
.10454 .30976 L
.10461 .30993 L
.10461 .31004 L
.10453 .31005 L
.10439 .30992 L
.10421 .30964 L
.10399 .30922 L
.10375 .30866 L
.10349 .30797 L
.10323 .30719 L
.10297 .30643 L
.10271 .30557 L
.10246 .30466 L
.10223 .30373 L
.10202 .30293 L
.10186 .30221 L
.10173 .30164 L
.10164 .30126 L
.10158 .30113 L
.10155 .30125 L
.10157 .30158 L
.1016 .30206 L
.10166 .30261 L
.10173 .30316 L
.10184 .30365 L
.10201 .30404 L
.10224 .30431 L
.10251 .30443 L
.10285 .30438 L
.10323 .30415 L
.10366 .30375 L
.10414 .3032 L
Mistroke
.10468 .30254 L
.10524 .30178 L
.10579 .30093 L
.10631 .30005 L
.10681 .29924 L
.10729 .29858 L
.10773 .29801 L
.10815 .29752 L
.10855 .29709 L
.10894 .29669 L
.10936 .29631 L
.1098 .2959 L
.11027 .29542 L
.11078 .29485 L
.11132 .29415 L
.11191 .2933 L
.11254 .29227 L
.11319 .29117 L
.11381 .28983 L
.11444 .28832 L
.11505 .28685 L
.11561 .28523 L
.11611 .28361 L
.1165 .282 L
.11682 .28055 L
.11705 .2792 L
.1172 .27799 L
.11728 .27701 L
.1173 .27617 L
.11728 .27547 L
.11724 .27491 L
.11718 .27448 L
.11712 .2742 L
.11705 .27405 L
.11699 .27402 L
.11694 .2741 L
.11688 .27424 L
.11684 .27441 L
.11681 .27457 L
.11681 .27469 L
.11688 .27474 L
.11703 .27472 L
.11733 .2746 L
.11776 .27435 L
.11835 .27398 L
.11907 .27351 L
.11996 .27289 L
.12101 .27216 L
.12212 .27132 L
.12336 .27043 L
Mistroke
.12456 .26946 L
.1258 .26846 L
.12704 .2675 L
.12811 .26667 L
.12915 .26596 L
.13011 .26538 L
.13094 .26491 L
.13162 .26454 L
.13219 .26423 L
.13265 .26393 L
.13302 .26359 L
.13333 .2632 L
.13361 .26271 L
.13391 .26213 L
.13425 .26143 L
.13464 .26062 L
.13507 .25979 L
.13553 .25887 L
.13602 .25793 L
.1365 .25695 L
.13699 .25605 L
.13747 .25521 L
.13792 .25448 L
.13833 .25391 L
.1387 .25351 L
.13901 .2532 L
.13926 .25296 L
.13944 .25275 L
.13957 .25249 L
.13965 .25212 L
.13973 .25163 L
.13981 .25099 L
.13994 .25023 L
.14009 .24941 L
.14026 .24868 L
.14046 .24769 L
.14068 .24676 L
.14089 .24575 L
.14109 .24467 L
.14126 .24351 L
.14139 .24236 L
.14151 .24117 L
.14162 .23992 L
.14175 .23862 L
.14191 .23745 L
.14208 .23608 L
.14228 .23469 L
.14253 .23324 L
.14284 .23172 L
.14324 .23009 L
Mistroke
.14375 .22868 L
.14436 .22729 L
.1451 .22592 L
.14588 .22466 L
.14672 .2235 L
.14761 .22239 L
.14853 .2213 L
.14939 .22025 L
.15028 .21917 L
.15117 .21811 L
.15214 .2171 L
.15309 .21606 L
.15412 .21498 L
.15527 .21389 L
.15644 .21281 L
.15767 .21165 L
.15894 .21051 L
.16007 .20936 L
.16119 .20822 L
.16225 .20712 L
.16324 .2062 L
.16419 .20527 L
.16497 .20442 L
.16566 .20375 L
.16621 .20317 L
.16661 .20268 L
.16689 .20226 L
.16701 .2019 L
.16702 .20158 L
.16697 .20127 L
.16689 .20095 L
.16683 .20058 L
.16679 .2001 L
.16677 .19956 L
.16676 .19903 L
.16675 .19861 L
.16669 .19825 L
.16659 .19803 L
.16644 .19802 L
.16625 .19822 L
.16602 .19865 L
.16575 .19928 L
.16546 .20007 L
.16517 .20088 L
.16488 .20193 L
.16462 .20288 L
.1644 .20383 L
.16424 .20469 L
.16417 .20541 L
.16423 .20594 L
Mistroke
.16443 .20626 L
.16476 .20641 L
.16524 .20643 L
.16583 .20639 L
.16653 .20629 L
.16731 .20619 L
.16811 .20612 L
.16884 .2061 L
.1695 .20611 L
.17006 .20613 L
.17046 .20614 L
.1707 .20614 L
.17076 .20614 L
.17066 .20611 L
.17047 .20605 L
.17021 .20596 L
.16982 .20586 L
.16935 .20575 L
.16877 .20566 L
.16807 .20564 L
.1673 .20571 L
.16646 .20589 L
.16557 .20622 L
.16462 .2067 L
.1636 .20737 L
.16254 .20825 L
.16155 .20928 L
.16046 .21052 L
.15922 .21195 L
.15767 .21351 L
.15629 .21503 L
.15483 .21665 L
.15332 .21835 L
.1519 .21998 L
.15045 .22147 L
.14902 .22294 L
.14773 .22439 L
.14655 .2257 L
.14534 .22702 L
.14411 .22838 L
.14288 .22981 L
.14171 .23124 L
.14062 .23275 L
.13955 .23442 L
.13851 .23623 L
.13756 .23796 L
.13666 .23991 L
.13581 .2418 L
.13501 .24372 L
.1343 .24551 L
Mistroke
.13371 .24706 L
.13324 .24847 L
.13288 .24967 L
.13262 .25058 L
.13242 .2513 L
.13225 .25187 L
.13207 .2523 L
.13185 .25264 L
.13154 .25295 L
.13113 .25327 L
.13063 .25361 L
.13005 .25398 L
.12939 .2544 L
.12876 .25488 L
.12796 .25551 L
.12718 .2562 L
.12632 .25703 L
.12541 .25796 L
.12447 .25897 L
.12356 .26007 L
.1227 .26124 L
.12193 .26239 L
.12116 .26361 L
.12041 .26487 L
.11969 .26616 L
.11899 .26741 L
.11829 .26876 L
.11764 .27022 L
.11713 .27168 L
.11675 .27307 L
.11642 .27442 L
.11611 .27577 L
.11581 .27687 L
.11545 .27804 L
.11497 .2791 L
.11436 .28023 L
.11369 .28143 L
.11282 .28259 L
.11182 .28378 L
.11075 .28499 L
.10972 .28622 L
.10863 .28746 L
.10745 .28862 L
.10619 .2898 L
.10495 .29102 L
.10386 .2923 L
.10289 .29351 L
.10206 .29477 L
.10137 .29609 L
.1008 .29744 L
Mistroke
.10035 .29871 L
.09998 .29996 L
.0997 .30123 L
.09949 .30257 L
.09932 .30394 L
.09917 .30535 L
.09904 .3068 L
.09888 .30826 L
.0987 .30959 L
.0985 .31079 L
.09831 .31185 L
.09813 .31278 L
.09793 .3136 L
.0977 .31428 L
.09743 .31488 L
.09713 .31543 L
.09684 .31593 L
.09655 .31643 L
.09628 .31697 L
.09602 .31759 L
.09576 .31833 L
.0955 .31925 L
.09523 .3203 L
.09492 .3215 L
.09454 .32291 L
.0941 .32461 L
.09362 .32635 L
.09315 .3283 L
.09271 .33042 L
.09231 .33229 L
.09194 .33446 L
.09159 .3364 L
.09125 .3385 L
.09091 .34079 L
.09058 .34309 L
.09025 .34514 L
.08994 .34724 L
.08966 .34948 L
.08943 .35177 L
.08925 .3537 L
.08908 .35576 L
.08892 .35773 L
.08876 .35964 L
.08861 .36147 L
.08849 .36309 L
.08835 .36456 L
.08829 .3658 L
.08825 .36685 L
.08825 .36771 L
.08827 .36839 L
Mistroke
.08829 .36893 L
.08831 .36935 L
.08832 .36972 L
.08831 .37011 L
.08831 .37055 L
.0883 .37106 L
.08828 .37169 L
.08827 .37245 L
.08826 .37324 L
.08824 .37412 L
.08822 .37508 L
.0882 .3761 L
.08819 .37712 L
.08817 .378 L
.08815 .37881 L
.08814 .37954 L
.08813 .38014 L
.08813 .38058 L
.08812 .38085 L
Mfstroke
.08815 .38058 m
.08815 .38042 L
.08815 .38021 L
.08814 .37995 L
.08811 .37961 L
.08807 .37936 L
.08805 .37896 L
.08807 .37855 L
.08811 .37807 L
.08821 .37743 L
.08836 .3768 L
.08857 .37629 L
.08883 .37559 L
.0891 .3749 L
.08937 .37416 L
.08962 .37333 L
.08987 .37236 L
.09012 .37153 L
.09038 .37067 L
.09063 .36967 L
.09084 .36854 L
.09097 .36741 L
.09105 .36649 L
.09109 .36548 L
.0911 .36443 L
.09108 .36353 L
.09105 .36263 L
.09104 .3618 L
.09104 .36108 L
.09105 .36051 L
.09106 .36001 L
.09106 .3596 L
.09107 .35927 L
.09107 .35905 L
.09107 .35892 L
.09107 .35886 L
.09107 .35885 L
.09107 .35888 L
.09107 .35893 L
.09107 .35901 L
.09107 .35907 L
.09107 .35909 L
.09107 .3591 L
.09107 .3591 L
.09107 .35911 L
.09107 .35915 L
.09107 .35922 L
.09106 .35927 L
.09103 .3593 L
.09099 .35928 L
Mistroke
.09096 .3592 L
.09095 .35903 L
.09098 .35878 L
.09103 .35844 L
.09114 .35805 L
.0913 .35762 L
.09151 .35717 L
.09177 .35672 L
.09208 .35627 L
.09242 .35583 L
.09271 .35539 L
.09295 .35501 L
.0932 .35474 L
.09343 .35461 L
.0936 .35465 L
.09364 .35484 L
.09354 .35515 L
.09334 .35556 L
.09309 .35604 L
.09279 .35652 L
.09248 .35688 L
.09218 .35714 L
.09189 .35744 L
.09163 .3578 L
.09143 .35819 L
.09127 .35857 L
.09115 .35892 L
.09107 .35929 L
.09101 .35977 L
.09092 .36044 L
.09077 .36132 L
.09058 .36238 L
.09032 .36357 L
.09009 .36476 L
.08979 .36636 L
.08951 .36844 L
.08926 .37001 L
.08899 .37221 L
.08872 .37398 L
.08846 .37588 L
.08825 .3779 L
.08811 .37931 L
.08803 .38081 L
.08799 .38222 L
.08798 .38315 L
.08799 .38391 L
.08802 .38452 L
.08803 .38495 L
.08804 .3852 L
Mfstroke
.11792 .43861 m
.11811 .4387 L
.11834 .43882 L
.11861 .43898 L
.11894 .43917 L
.11933 .4394 L
.11974 .43967 L
.12026 .44005 L
.12078 .44049 L
.12136 .44103 L
.12201 .4417 L
.12268 .44243 L
.12331 .44311 L
.12396 .44391 L
.12456 .4447 L
.12514 .44549 L
.12568 .44626 L
.12619 .44698 L
.12666 .44759 L
.12709 .44813 L
.12748 .4486 L
.12778 .44897 L
.12798 .44921 L
.12807 .44935 L
.12805 .44945 L
.12797 .4496 L
.12787 .44983 L
.12777 .45014 L
.12772 .45054 L
.12776 .45103 L
.12792 .45161 L
.12823 .45222 L
.12868 .45287 L
.12924 .4535 L
.1299 .45411 L
.13063 .45465 L
.1313 .45511 L
.13198 .45547 L
.13268 .4557 L
.1334 .45583 L
.13403 .45588 L
.13462 .45588 L
.13512 .45589 L
.13555 .45596 L
.1359 .45611 L
.13618 .45636 L
.13643 .45671 L
.13667 .45706 L
.1369 .45746 L
.13712 .45786 L
Mistroke
.13732 .45824 L
.13748 .45862 L
.13759 .45897 L
.13763 .45929 L
.13758 .45955 L
.13745 .45971 L
.13724 .45977 L
.13696 .45975 L
.13665 .4597 L
.13632 .45963 L
.136 .45958 L
.13573 .45967 L
.13553 .45993 L
.13541 .46038 L
.13537 .46101 L
.13542 .4618 L
.13555 .46271 L
.13573 .46372 L
.13596 .46464 L
.1362 .4656 L
.13641 .46655 L
.13661 .46748 L
.13678 .46838 L
.13695 .46903 L
.13711 .46966 L
.13726 .47017 L
.13739 .47059 L
.13752 .47099 L
.13767 .47143 L
.13789 .472 L
.13817 .47274 L
.13855 .47367 L
.139 .47465 L
.13954 .4758 L
.14015 .47711 L
.14079 .47856 L
.14144 .47996 L
.14199 .48124 L
.14252 .48249 L
.14298 .4835 L
.14343 .48439 L
.14387 .48514 L
.1443 .48572 L
.14473 .48613 L
.14518 .48641 L
.14565 .48661 L
.14613 .48675 L
.1466 .48686 L
.14705 .48696 L
.14749 .48708 L
Mistroke
.14796 .48725 L
.14847 .48746 L
.14897 .48767 L
.1494 .48785 L
.14971 .48797 L
.14988 .48801 L
.1499 .48793 L
.14979 .48774 L
.14958 .48745 L
.1493 .48712 L
.14896 .48678 L
.14862 .48646 L
.14829 .48623 L
.14797 .48612 L
.14767 .48616 L
.14743 .48641 L
.14726 .48693 L
.14718 .48775 L
.14717 .48891 L
.14724 .49027 L
.14735 .49183 L
.14751 .49368 L
.14769 .49582 L
.1479 .49776 L
.14812 .50005 L
.14836 .50206 L
.14863 .50415 L
.14888 .50622 L
.14916 .50789 L
.14943 .5094 L
.14968 .51071 L
.1499 .51178 L
.15009 .51257 L
.15028 .51317 L
.15046 .51359 L
.15064 .51386 L
.15082 .51403 L
.15096 .51414 L
.15105 .51419 L
.15107 .51416 L
.15105 .51408 L
.151 .51397 L
.15095 .51385 L
.15091 .51376 L
.15091 .51375 L
.15097 .51383 L
.15108 .514 L
.15128 .51426 L
.15157 .51462 L
.15198 .51506 L
Mistroke
.1525 .51557 L
.15311 .51615 L
.15383 .51677 L
.15464 .51747 L
.15547 .51825 L
.15637 .51904 L
.1573 .51982 L
.15824 .52055 L
.15908 .52124 L
.15989 .52191 L
.16065 .52255 L
.16133 .52318 L
.16191 .5238 L
.16237 .52443 L
.16275 .52511 L
.16303 .52583 L
.16321 .52652 L
.16332 .52713 L
.16336 .52763 L
.16332 .52804 L
.16321 .52836 L
.16302 .52854 L
.16274 .52855 L
.1624 .52842 L
.16204 .52815 L
.1617 .52778 L
.1614 .52734 L
.16115 .52686 L
.161 .52635 L
.161 .52585 L
.1612 .52541 L
.16162 .52507 L
.16228 .52484 L
.16314 .52468 L
.16425 .5246 L
.16554 .52457 L
.16706 .52457 L
.16861 .52459 L
.17024 .52458 L
.17163 .52456 L
.17298 .52451 L
.17401 .52448 L
.17481 .52447 L
.17528 .52448 L
.17539 .52452 L
.17516 .52456 L
.17465 .52461 L
.17391 .52464 L
.17299 .52467 L
.17208 .52472 L
Mistroke
.1711 .52478 L
.17005 .52482 L
.16903 .52481 L
.16816 .5247 L
.16746 .52446 L
.16694 .52402 L
.16652 .52339 L
.16617 .52252 L
.16587 .52139 L
.16556 .51994 L
.16519 .51819 L
.16471 .51646 L
.1641 .51439 L
.16336 .51197 L
.1625 .50964 L
.16162 .50711 L
.16061 .50441 L
.15952 .50185 L
.15844 .49943 L
.15735 .49714 L
.15628 .4949 L
.15535 .49321 L
.15454 .49165 L
.15386 .49035 L
.15334 .4894 L
.15298 .48863 L
.15274 .48806 L
.15255 .48766 L
.15234 .4874 L
.15207 .48725 L
.15167 .48716 L
.15109 .4871 L
.15028 .48706 L
.14924 .48699 L
.14807 .48686 L
.14667 .48665 L
.14504 .48638 L
.14327 .48605 L
.14164 .48569 L
.13999 .48533 L
.13838 .485 L
.13692 .48472 L
.13571 .48446 L
.13477 .48425 L
.13404 .48402 L
.13354 .48374 L
.13325 .48334 L
.13315 .48288 L
.13323 .48244 L
.13341 .48187 L
Mistroke
.13368 .48121 L
.13399 .48043 L
.13431 .47947 L
.13458 .47842 L
.13474 .47719 L
.13474 .47573 L
.13459 .47408 L
.13432 .47236 L
.13399 .47069 L
.1336 .46892 L
.13321 .46747 L
.13281 .46608 L
.13245 .46501 L
.13213 .46412 L
.13188 .46343 L
.1317 .46304 L
.13159 .4628 L
.13155 .4627 L
.13158 .46271 L
.13168 .46288 L
.13185 .46317 L
.13204 .46353 L
.13224 .46392 L
.13242 .46426 L
.13256 .46451 L
.13266 .46466 L
.13272 .46468 L
.13273 .46454 L
.1327 .46425 L
.13267 .46387 L
.13266 .46344 L
.13266 .46299 L
.13267 .46253 L
.13269 .46209 L
.13271 .46166 L
.13273 .46123 L
.13279 .46082 L
.13293 .46046 L
.13315 .46019 L
.13337 .46004 L
.13353 .46 L
.13359 .46003 L
.13351 .46009 L
.13325 .46015 L
.13267 .46017 L
.13171 .46008 L
.13039 .45987 L
.12871 .45955 L
.12667 .45914 L
.12469 .45866 L
Mistroke
.12223 .45811 L
.11961 .45757 L
.11693 .45703 L
.11414 .45649 L
.11145 .456 L
.1085 .45553 L
.10616 .45512 L
.10393 .45474 L
.10164 .45439 L
.09962 .45407 L
.09767 .45375 L
.0958 .45342 L
.09409 .4531 L
.09264 .45277 L
.09163 .45245 L
.0904 .45212 L
.08945 .45178 L
.08852 .45139 L
.08759 .45095 L
.08673 .45048 L
.08593 .45001 L
.08519 .44954 L
.0845 .44904 L
.08388 .44849 L
.08332 .4479 L
.08278 .44729 L
.08213 .4466 L
.08144 .4458 L
.08075 .44489 L
.08008 .44397 L
.07949 .44305 L
.07902 .44219 L
.07867 .44142 L
.07846 .44078 L
.07841 .44025 L
.07848 .43983 L
.07866 .43952 L
.07891 .43932 L
.07919 .4392 L
.07949 .43911 L
.0798 .43902 L
.08008 .43889 L
.08034 .43871 L
.08057 .43845 L
.08081 .43812 L
.08105 .43771 L
.08129 .43726 L
.08153 .43681 L
.08177 .43638 L
.082 .43596 L
Mistroke
.08223 .43555 L
.08246 .43518 L
.0827 .43489 L
.08294 .43469 L
.0832 .43458 L
.08346 .43454 L
.0837 .43456 L
.08391 .43461 L
.08408 .43468 L
Mfstroke
.08813 .37659 m
.08814 .37648 L
.08817 .37627 L
.08821 .37594 L
.08826 .37546 L
.08833 .3748 L
.08843 .37395 L
.08857 .37287 L
.08873 .37155 L
.08894 .37004 L
.08913 .36817 L
.08932 .36618 L
.08954 .36387 L
.08979 .36138 L
.09007 .359 L
.09032 .35609 L
.09061 .35365 L
.09091 .35074 L
.09122 .34807 L
.09157 .34522 L
.09194 .34201 L
.09235 .33951 L
.09277 .33686 L
.09319 .3342 L
.09361 .3315 L
.09404 .32872 L
.09448 .32659 L
.09493 .32413 L
.09538 .32187 L
.09583 .31978 L
.09627 .31772 L
.0967 .31598 L
.09711 .31435 L
.0975 .31303 L
.09787 .3119 L
.09819 .31104 L
.09847 .31036 L
.09871 .30986 L
.09891 .30954 L
.09908 .30936 L
.0992 .30928 L
.09929 .30929 L
.09935 .30936 L
.09936 .30946 L
.09934 .30957 L
.09931 .30966 L
.09926 .30971 L
.09923 .30973 L
.09922 .30974 L
.09922 .30974 L
Mistroke
.09922 .30974 L
.09922 .30974 L
.09922 .30974 L
.09922 .30974 L
.09922 .30974 L
.09922 .30974 L
.09922 .30974 L
.09923 .30976 L
.09926 .30981 L
.0993 .30988 L
.09934 .30994 L
.09935 .30997 L
.09934 .30994 L
.09928 .30985 L
.09918 .30967 L
.09902 .30941 L
.09881 .30906 L
.09855 .30862 L
.09825 .30811 L
.09794 .30758 L
.09766 .30713 L
.09742 .30675 L
.09721 .30645 L
.09707 .30622 L
.097 .30607 L
.09703 .30604 L
.09715 .3061 L
.09734 .30623 L
.09759 .3064 L
.09787 .3066 L
.09817 .30675 L
.09847 .30687 L
.09875 .30689 L
.09898 .30681 L
.09916 .30655 L
.09928 .30614 L
.09935 .30561 L
.09938 .30497 L
.09937 .30429 L
.09934 .30362 L
.0993 .30301 L
.09926 .30247 L
.09925 .30203 L
.09925 .30168 L
.09925 .3014 L
.09925 .30117 L
.09925 .30101 L
.09925 .30091 L
.09925 .30089 L
.09925 .30091 L
Mistroke
.09925 .30098 L
.09925 .30105 L
.09925 .3011 L
.09925 .30113 L
.09925 .30113 L
.09923 .30114 L
.0992 .30116 L
.09916 .3012 L
.09913 .30127 L
.09911 .30133 L
.09912 .30136 L
.09918 .30134 L
.09928 .30125 L
.09943 .30108 L
.09962 .30084 L
.09985 .30051 L
.1001 .30013 L
.10037 .29972 L
.10063 .29928 L
.10089 .29885 L
.10114 .29842 L
.10138 .298 L
.10159 .29761 L
.10176 .29726 L
.10187 .29698 L
.10194 .29679 L
.10196 .29668 L
.10195 .29664 L
.10191 .29667 L
.10187 .29673 L
.10183 .2968 L
.10182 .29685 L
.10182 .29687 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .29688 L
.10182 .2969 L
.10181 .29693 L
.1018 .29698 L
.10176 .29706 L
.10172 .29714 L
.10167 .29719 L
Mistroke
.10163 .2972 L
.10162 .29715 L
.10162 .297 L
.10171 .29673 L
.10186 .29633 L
.10207 .29579 L
.10236 .29512 L
.10273 .29437 L
.10317 .29349 L
.10367 .29252 L
.10423 .29153 L
.10486 .29049 L
.10552 .28943 L
.10617 .2884 L
.10681 .28749 L
.10741 .28666 L
.10795 .28595 L
.1084 .28537 L
.10876 .28493 L
.10905 .2846 L
.10927 .28436 L
.10943 .28418 L
.10954 .28407 L
.10961 .284 L
.10964 .28398 L
.10964 .28398 L
.10961 .284 L
.10958 .28402 L
.10953 .28405 L
.1095 .28409 L
.10948 .28412 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
Mistroke
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10948 .28413 L
.10946 .28413 L
.10943 .28413 L
.10939 .28413 L
.10934 .28413 L
.1093 .28413 L
.1093 .28414 L
.10936 .28417 L
.10946 .28421 L
.10962 .28424 L
.10983 .28425 L
.11009 .28426 L
.1104 .28425 L
.11073 .28422 L
.11104 .28417 L
.11135 .28409 L
.11164 .28398 L
.11194 .28382 L
.11219 .28357 L
.11242 .28322 L
.11267 .2828 L
.11294 .2823 L
.11328 .28168 L
.11376 .28101 L
.1144 .28019 L
.11512 .27923 L
.11609 .27814 L
.11716 .27698 L
.11849 .27573 L
.11985 .27439 L
.12135 .27305 L
.12282 .27175 L
.12426 .27065 L
.12538 .26964 L
.1266 .26867 L
.12757 .26788 L
.1284 .26712 L
.12908 .26634 L
.12966 .26555 L
Mistroke
.13018 .26469 L
.13069 .26372 L
.13121 .26256 L
.13177 .26124 L
.13233 .25988 L
.13281 .25845 L
.13339 .25669 L
.13399 .25498 L
.13468 .2531 L
.13526 .2511 L
.13582 .24939 L
.13633 .24768 L
.1368 .24602 L
.13725 .24445 L
.13772 .24305 L
.13824 .24172 L
.13885 .24039 L
.13954 .23902 L
.14042 .23759 L
.14142 .23632 L
.14259 .23487 L
.1439 .23336 L
.14537 .23188 L
.14685 .23029 L
.14855 .22869 L
.14995 .22714 L
.15134 .22557 L
.15274 .22411 L
.15397 .22268 L
.15515 .2214 L
.1562 .22018 L
.15723 .21902 L
.15811 .21796 L
.15892 .21694 L
.15967 .21591 L
.16038 .21484 L
.16104 .21379 L
.16162 .21265 L
.16218 .21138 L
.1627 .21002 L
.16315 .20852 L
.16359 .20687 L
.16403 .20534 L
.16449 .20353 L
.16498 .20175 L
.16551 .19966 L
.16609 .19758 L
.16674 .19556 L
.16749 .19333 L
.16838 .19106 L
Mistroke
.16929 .18912 L
.17033 .18722 L
.17139 .18531 L
.17255 .18347 L
.1738 .18184 L
.175 .18015 L
.17631 .17844 L
.17772 .17683 L
.17918 .1752 L
.18071 .17367 L
.18216 .17217 L
.18362 .17085 L
.18509 .16956 L
.18646 .16833 L
.1878 .16727 L
.18908 .16629 L
.19021 .16547 L
.19126 .16477 L
.19209 .16422 L
.19277 .16384 L
.19327 .16365 L
.19357 .16362 L
.19368 .16372 L
.19362 .16389 L
.19345 .16409 L
.19325 .16424 L
.19308 .16429 L
.19301 .16417 L
.19308 .16383 L
.19335 .16326 L
.19382 .16243 L
.19449 .16133 L
.19531 .16008 L
.19625 .15852 L
.1973 .15667 L
.19834 .15485 L
.19948 .15276 L
.20084 .15028 L
.20216 .1482 L
.2036 .14608 L
.2049 .14394 L
.20614 .14195 L
.20728 .14014 L
.20826 .13875 L
.20919 .13748 L
.21004 .13651 L
.21088 .1357 L
.21169 .13505 L
.21246 .13452 L
.21317 .1341 L
Mistroke
.21382 .13378 L
.21441 .13353 L
.215 .13336 L
.21561 .13324 L
.21631 .13317 L
.21712 .13309 L
.21808 .13298 L
.21919 .13285 L
.22042 .13272 L
.22158 .13262 L
.22285 .13256 L
.2239 .13254 L
.22504 .13257 L
.22612 .13264 L
.227 .13278 L
.22779 .13295 L
.22844 .13313 L
.2289 .13327 L
.22919 .13333 L
.22935 .1333 L
.22946 .13314 L
.22961 .13283 L
.2299 .13235 L
.23041 .13167 L
.23118 .13079 L
.23224 .12967 L
.23348 .12846 L
.23504 .12689 L
.23674 .12523 L
.23881 .12331 L
.2407 .12122 L
.24284 .11907 L
.24514 .11685 L
.24701 .11474 L
.24897 .11269 L
.25079 .1108 L
.2523 .1092 L
.25368 .10774 L
.25484 .10645 L
.2558 .10542 L
.25662 .10459 L
.25731 .10398 L
.25793 .10359 L
.25851 .10339 L
.25907 .10333 L
.25966 .10338 L
.26026 .10349 L
.26092 .10362 L
.26158 .10374 L
.26219 .10385 L
Mistroke
.26277 .10395 L
.26332 .10402 L
.26381 .10405 L
.26426 .10404 L
.26466 .104 L
.265 .10395 L
.26527 .10387 L
.2655 .10381 L
.2657 .10376 L
.26589 .10373 L
.26607 .10374 L
.26625 .10376 L
.26644 .10396 L
.26665 .10391 L
.26687 .10381 L
.26708 .10367 L
.26727 .10354 L
.26742 .10341 L
.26751 .10327 L
.26755 .10312 L
.26752 .10292 L
.26747 .10272 L
.2674 .10247 L
.26735 .10221 L
.26733 .10193 L
.26737 .1016 L
.26749 .1013 L
.26766 .10103 L
.26789 .10081 L
.26816 .10056 L
.26847 .1003 L
.26881 .10002 L
.2692 .09974 L
.26965 .09946 L
.27017 .09919 L
.27075 .09892 L
.2714 .09863 L
.27213 .09834 L
.27294 .09804 L
.27383 .0977 L
.27475 .0973 L
.27575 .09686 L
.27678 .09641 L
.27789 .09598 L
.27901 .0956 L
.28015 .09523 L
.28124 .09488 L
.28229 .09457 L
.28321 .09433 L
.284 .09416 L
Mistroke
.28464 .09407 L
.28512 .09405 L
.28549 .09403 L
.28581 .09398 L
.28609 .09385 L
.28639 .09363 L
.2867 .09327 L
.28704 .09279 L
.28742 .09222 L
.28782 .0916 L
.28825 .09101 L
.28865 .09039 L
.28903 .08977 L
.28938 .08925 L
.28971 .08879 L
.29001 .0884 L
.2903 .08811 L
.2906 .08791 L
.29094 .08777 L
.29134 .08764 L
.29184 .08747 L
.29246 .08724 L
.29323 .0869 L
.29414 .08643 L
.29529 .08585 L
.29657 .08519 L
.29802 .08444 L
.29966 .08364 L
.30121 .08284 L
.30281 .08204 L
.3044 .08133 L
.30595 .08066 L
.3074 .08005 L
.30882 .07948 L
.31023 .07894 L
.31159 .07841 L
.31299 .07785 L
.31438 .07721 L
.31581 .07645 L
.31727 .07554 L
.3186 .07457 L
.31996 .07344 L
.32123 .07211 L
.32246 .07075 L
.32369 .06931 L
.32486 .06791 L
.32604 .06644 L
.32722 .06505 L
.32838 .06374 L
.3296 .06239 L
Mistroke
.33089 .06125 L
.33234 .06015 L
.33393 .05907 L
.33579 .05801 L
.33773 .05701 L
.33978 .05598 L
.34203 .05498 L
.34445 .05399 L
.34674 .05299 L
.34898 .052 L
.35108 .0511 L
.35283 .05025 L
.35467 .04951 L
.3564 .04891 L
.35803 .0485 L
.35967 .04825 L
.3613 .04816 L
.36301 .0482 L
.36474 .04835 L
.36637 .04857 L
.3677 .04884 L
.36902 .04915 L
.37014 .04947 L
.37128 .04975 L
.37241 .04999 L
.37344 .05018 L
.37423 .05032 L
.37474 .05039 L
.375 .05042 L
.37508 .05044 L
.37499 .05044 L
.37476 .05043 L
.37448 .05041 L
.37425 .05041 L
.3741 .05042 L
.37405 .05041 L
.37412 .05039 L
.37435 .05032 L
.37475 .05017 L
.37533 .04992 L
.37609 .04953 L
.37701 .04901 L
.37806 .04838 L
.37912 .04763 L
.38026 .0468 L
.3815 .04591 L
.38286 .04506 L
.38415 .04416 L
.38546 .04321 L
.38678 .04237 L
Mistroke
.38804 .04157 L
.38928 .04085 L
.39048 .04021 L
.39175 .03969 L
.39315 .03928 L
.39467 .03899 L
.3963 .0388 L
.39813 .03869 L
.40014 .03863 L
.40213 .03858 L
.40416 .03856 L
.40624 .03854 L
.40818 .03855 L
.41004 .0386 L
.41176 .03865 L
.41327 .03873 L
.41466 .03882 L
.41586 .0389 L
.41681 .03896 L
.41744 .03901 L
.41776 .03904 L
.41777 .03906 L
.41751 .03908 L
.41705 .03907 L
.41644 .03906 L
.41574 .03903 L
.41502 .039 L
.4143 .03898 L
.41359 .03896 L
.41288 .03894 L
.4122 .03892 L
.4116 .0389 L
.41113 .03889 L
.41081 .03888 L
.41063 .03888 L
.41057 .03887 L
.4106 .03888 L
.4107 .03888 L
.41081 .03888 L
.41088 .03886 L
.41088 .03882 L
.41083 .03873 L
.41075 .03864 L
.4107 .03857 L
.4107 .03853 L
.41076 .03855 L
.4109 .03867 L
.41113 .0389 L
.41143 .0393 L
.41181 .03984 L
Mistroke
.41223 .04052 L
.41269 .04135 L
.41315 .04222 L
.41363 .04323 L
.41411 .04422 L
.41457 .04524 L
.415 .04621 L
.41536 .04702 L
.41562 .04758 L
.41578 .04792 L
.41581 .04802 L
.41572 .04789 L
.41555 .04751 L
.41534 .04693 L
.41513 .04626 L
.41495 .04546 L
.4148 .04464 L
.41466 .0438 L
.41451 .04306 L
.4143 .04235 L
.41403 .04173 L
.41366 .04123 L
.41317 .04083 L
.41254 .04058 L
.41174 .04045 L
.41072 .04041 L
.40951 .04043 L
.40803 .04045 L
.40632 .04045 L
.40433 .04041 L
.40217 .0403 L
.39998 .04014 L
.39764 .03996 L
.39539 .03976 L
.3933 .03956 L
.39125 .03935 L
.38926 .03915 L
.38763 .03894 L
.38612 .03872 L
.38472 .03848 L
.38341 .03824 L
.38217 .03801 L
.38096 .0378 L
.37977 .03765 L
.37858 .03757 L
.37727 .03756 L
.37584 .03765 L
.37442 .03786 L
.37289 .03819 L
.37119 .0386 L
Mistroke
.36937 .03909 L
.3676 .03965 L
.36603 .0403 L
.36452 .04103 L
.36308 .04179 L
.36178 .04248 L
.36064 .04315 L
.35969 .04391 L
.35888 .0446 L
.35816 .04529 L
.35749 .04602 L
.35686 .04669 L
.35626 .04741 L
.35566 .04815 L
.35504 .04893 L
.35444 .04972 L
.3539 .05051 L
.35343 .05123 L
.35299 .05191 L
.35257 .05255 L
.35217 .05312 L
.35182 .05358 L
.35156 .05391 L
.35139 .05411 L
.35129 .05422 L
.35126 .05425 L
.35129 .0542 L
.35136 .05409 L
.35143 .05397 L
.35147 .05388 L
.35149 .05383 L
.3515 .05377 L
.35151 .05374 L
.35154 .0537 L
.35157 .05363 L
.35161 .05353 L
.35165 .0534 L
.35169 .05325 L
.35175 .0531 L
.35181 .05295 L
.35189 .05281 L
.35197 .05269 L
.35207 .0526 L
.35211 .05255 L
.35207 .05252 L
.35193 .0525 L
.35165 .05248 L
.35124 .0525 L
.35067 .05257 L
.34996 .05273 L
Mistroke
.34914 .05292 L
.3482 .0532 L
.34717 .05355 L
.34605 .05393 L
.34493 .05431 L
.34372 .05469 L
.3424 .05507 L
.34102 .05546 L
.33963 .05586 L
.33819 .05633 L
.33676 .05688 L
.33529 .05749 L
.33376 .05816 L
.33217 .05889 L
.33066 .05968 L
.32912 .06055 L
.32748 .06147 L
.32583 .06238 L
.32428 .06332 L
.32278 .06426 L
.32138 .06517 L
.32015 .06596 L
.31901 .06667 L
.31796 .06724 L
.31703 .06766 L
.31626 .06793 L
.31561 .06808 L
.31504 .06817 L
.31453 .06826 L
.31406 .0684 L
.31362 .06863 L
.31316 .069 L
.31279 .06941 L
.31233 .07003 L
.31183 .07082 L
.31127 .07177 L
.31064 .07278 L
.3099 .07396 L
.30911 .07527 L
.30825 .07653 L
.30738 .07776 L
.30653 .07891 L
.30572 .07997 L
.30497 .0809 L
.3043 .08171 L
.30374 .08243 L
.30327 .08308 L
.30292 .08366 L
.30268 .08421 L
.30254 .08473 L
Mistroke
.30248 .08522 L
.30247 .08568 L
.30251 .08608 L
.30261 .08638 L
.30275 .08663 L
.30289 .08686 L
.30301 .08711 L
.3031 .08737 L
.30314 .08761 L
.30313 .08789 L
.30302 .08824 L
.30278 .08868 L
.30238 .08924 L
.30179 .0899 L
.30101 .09069 L
.30005 .0916 L
.299 .0925 L
.29781 .09348 L
.29659 .09448 L
.29541 .09549 L
.29432 .09636 L
.29322 .09712 L
.2921 .09775 L
.29114 .09821 L
.29026 .09851 L
.28948 .09865 L
.2888 .09866 L
.28825 .0986 L
.28784 .09852 L
.28752 .09844 L
.28729 .09836 L
.28708 .09829 L
.28684 .09824 L
.28655 .0982 L
.28622 .09815 L
.28587 .09808 L
.28555 .09801 L
.28531 .09795 L
.28516 .09788 L
.2851 .09784 L
.28513 .0978 L
.28516 .09778 L
.28518 .09777 L
.28519 .09778 L
.28523 .0978 L
.28533 .09783 L
.28552 .09789 L
.28577 .09798 L
.28604 .09806 L
.28628 .09815 L
Mistroke
.28647 .09822 L
.28655 .09828 L
.2865 .0983 L
.28631 .09827 L
.28599 .09821 L
.28557 .09809 L
.28507 .09791 L
.28449 .09766 L
.2838 .09735 L
.28315 .09701 L
.28238 .0967 L
.28156 .09641 L
.28072 .09618 L
.27994 .09602 L
.27922 .09594 L
.27859 .09591 L
.27806 .09592 L
.27767 .09603 L
.27736 .09618 L
.27717 .09636 L
.27706 .0966 L
.27702 .09686 L
.27701 .09709 L
.27699 .09725 L
.27693 .09738 L
.27677 .09744 L
.27647 .09747 L
.27602 .09751 L
.27542 .09761 L
.27469 .09787 L
.27381 .09832 L
.27287 .09897 L
.2719 .09977 L
.27088 .10067 L
.26979 .10158 L
.26871 .10236 L
.26768 .10312 L
.26673 .10383 L
.26591 .10448 L
.2652 .10495 L
.26461 .1053 L
.26413 .10551 L
.26375 .10559 L
.26345 .10548 L
.26324 .10521 L
.26314 .10484 L
.2631 .10443 L
.26309 .10408 L
.26309 .10382 L
.26305 .10367 L
Mistroke
.26291 .10362 L
.26259 .10372 L
.26206 .10393 L
.26133 .10425 L
.26039 .10465 L
.25919 .10512 L
.25796 .10566 L
.25647 .10627 L
.25486 .10688 L
.25324 .10753 L
.25151 .10819 L
.24978 .10886 L
.2481 .10952 L
.24658 .11019 L
.24503 .1109 L
.2435 .11165 L
.24202 .11244 L
.24064 .11328 L
.23946 .11413 L
.23823 .11505 L
.23704 .11605 L
.23595 .11707 L
.23492 .11818 L
.23391 .11946 L
.23298 .12071 L
.23212 .12202 L
.23137 .12333 L
.23075 .12452 L
.23025 .12552 L
.22989 .12626 L
.22964 .1268 L
.22944 .12712 L
.2293 .12721 L
.2292 .1271 L
.22912 .12684 L
.22906 .1265 L
.22905 .12615 L
.22906 .12582 L
.2291 .12557 L
.22917 .12546 L
.22923 .12555 L
.22929 .12591 L
.22934 .12652 L
.22939 .12731 L
.22945 .12813 L
.22952 .12918 L
.22959 .13009 L
.22964 .13095 L
.22967 .13169 L
.22967 .13225 L
Mistroke
.22966 .13259 L
.22961 .13271 L
.22949 .13268 L
.22928 .13253 L
.22896 .13231 L
.22851 .13208 L
.22793 .13184 L
.22719 .13166 L
.22628 .13153 L
.22519 .13143 L
.22394 .13139 L
.2225 .13144 L
.22088 .13159 L
.21935 .13188 L
.21766 .13231 L
.21574 .13287 L
.21363 .13358 L
.21162 .13441 L
.20972 .13541 L
.20769 .13656 L
.2057 .13779 L
.20371 .13925 L
.20193 .14089 L
.20005 .14265 L
.1985 .14443 L
.19694 .14638 L
.19532 .14834 L
.19379 .15048 L
.19225 .15245 L
.19071 .15452 L
.1892 .15665 L
.18796 .15848 L
.18669 .1604 L
.18557 .16224 L
.18459 .16397 L
.18361 .16574 L
.18277 .16713 L
.18204 .16849 L
.18147 .16983 L
.18107 .17113 L
.18083 .17235 L
.18074 .17338 L
.18078 .17435 L
.18088 .1752 L
.18099 .17591 L
.18109 .17644 L
.18116 .17682 L
.1812 .17706 L
.1812 .1772 L
.18118 .17722 L
Mistroke
.18113 .17714 L
.18107 .1769 L
.181 .17653 L
.18094 .17607 L
.18092 .1756 L
.18098 .17515 L
.18114 .17472 L
.1814 .17436 L
.18178 .17412 L
.18226 .17403 L
.18283 .17406 L
.18345 .17412 L
.18415 .1742 L
.1849 .17427 L
.18571 .17433 L
.18649 .17438 L
.18727 .17442 L
.18803 .17444 L
.18872 .17446 L
.18931 .17447 L
.1898 .17448 L
.19016 .17449 L
.19043 .1745 L
.19062 .17451 L
.19077 .17451 L
.19088 .17451 L
.19097 .17451 L
.19104 .17452 L
.19108 .17452 L
.1911 .17452 L
.19108 .17452 L
.19104 .17452 L
.191 .17452 L
.19097 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
Mistroke
.19095 .17451 L
.19095 .17451 L
.19095 .17451 L
.19093 .17451 L
.19091 .17451 L
.19087 .17451 L
.19083 .17451 L
.19081 .17451 L
.19082 .17451 L
.19088 .17451 L
.19098 .17451 L
.19112 .17452 L
.1913 .17452 L
.19152 .17453 L
.19176 .17453 L
.19201 .17454 L
.19226 .17455 L
.19251 .17458 L
.19274 .17464 L
.19293 .17472 L
.19308 .17481 L
.19317 .17489 L
.19322 .17494 L
.19324 .17492 L
.19324 .17481 L
.19326 .1746 L
.19331 .17428 L
.19346 .17384 L
.19373 .17328 L
.19415 .17258 L
.19472 .17177 L
.19541 .17079 L
.19626 .16962 L
.19726 .16825 L
.19839 .1668 L
.19966 .16521 L
.20097 .16359 L
.20233 .16194 L
.2037 .16045 L
.20495 .15901 L
.20614 .15772 L
.20712 .15667 L
.20801 .15568 L
.20875 .15487 L
.20941 .15415 L
.20987 .15368 L
.21023 .15334 L
.21045 .15317 L
.21056 .15314 L
.21058 .1532 L
Mistroke
.21056 .15331 L
.21051 .15343 L
.21042 .15352 L
.21034 .15358 L
.21027 .15362 L
.21024 .15363 L
.21024 .15364 L
.21024 .15366 L
.21025 .15372 L
.21025 .15379 L
.21023 .15388 L
.2102 .15397 L
.21015 .15405 L
.21009 .15408 L
.21004 .15401 L
.21002 .1538 L
.21006 .15342 L
.21017 .15285 L
.21036 .15207 L
.21063 .15106 L
.21099 .14994 L
.2114 .14859 L
.21186 .14703 L
.21232 .14552 L
.2128 .14386 L
.21328 .14209 L
.21369 .14063 L
.21404 .13922 L
.21435 .13793 L
.21458 .13684 L
.21475 .13599 L
.21488 .13535 L
.21501 .13491 L
.21519 .1346 L
.21543 .13436 L
.21577 .13415 L
.21626 .13393 L
.21691 .13368 L
.21764 .13337 L
.21856 .13302 L
.21955 .13258 L
.22067 .13204 L
.22191 .13137 L
.22307 .13058 L
.2243 .12975 L
.2256 .12889 L
.22687 .12802 L
.22818 .12717 L
.22945 .12636 L
.23076 .12562 L
Mistroke
.232 .12488 L
.23329 .12413 L
.23453 .12341 L
.2358 .12271 L
.23699 .12202 L
.23809 .12137 L
.23915 .12076 L
.24013 .12022 L
.24097 .11979 L
.24171 .11941 L
.24234 .11909 L
.24282 .1188 L
.2432 .11854 L
.24347 .11832 L
.24367 .11816 L
.24379 .11807 L
.24387 .11805 L
.2439 .11808 L
.24391 .11815 L
.24389 .11825 L
.24384 .11835 L
.24375 .11845 L
.24362 .11854 L
.24348 .1186 L
.24337 .11862 L
.24333 .11858 L
.24339 .11845 L
.24357 .1182 L
.24389 .11781 L
.24437 .11729 L
.24502 .11663 L
.24582 .11584 L
.24676 .11502 L
.24766 .11409 L
.24875 .11312 L
.24976 .11215 L
.25084 .1112 L
.25172 .11031 L
.25258 .10956 L
.25341 .10893 L
.25415 .10842 L
.25479 .10806 L
.25537 .10785 L
.25595 .10778 L
.25658 .10782 L
.25728 .10792 L
.25807 .10801 L
.25895 .10804 L
.25986 .10801 L
.26079 .10792 L
Mistroke
.26184 .10775 L
.26301 .10755 L
.26426 .10736 L
.26554 .10722 L
.26683 .10715 L
.26814 .10711 L
.26941 .1071 L
.27065 .10711 L
.27185 .10715 L
.27292 .10721 L
.27393 .10731 L
.27486 .10745 L
.27563 .1076 L
.27623 .10772 L
.27668 .10779 L
.27701 .10778 L
.27721 .10767 L
.27736 .10744 L
.27747 .10704 L
.27756 .10649 L
.27767 .10591 L
.27782 .10526 L
.27806 .1046 L
.27835 .10393 L
.27867 .10327 L
.27905 .10263 L
.27948 .10205 L
.27997 .10152 L
.28046 .10106 L
.28094 .10071 L
.28137 .10049 L
.28173 .10038 L
.28204 .10035 L
.2823 .10039 L
.28254 .10045 L
.28278 .10048 L
.28307 .10043 L
.28341 .10025 L
.28381 .09989 L
.28426 .09932 L
.28479 .0985 L
.28543 .09749 L
.28614 .09621 L
.28701 .0948 L
.28797 .09317 L
.2891 .0914 L
.29039 .08957 L
.29184 .08779 L
.29353 .08594 L
.29515 .0843 L
Mistroke
.297 .0826 L
.29871 .08118 L
.30065 .07979 L
.30258 .07859 L
.30467 .07747 L
.30688 .07643 L
.30898 .07543 L
.31113 .07455 L
.31327 .07365 L
.31534 .0727 L
.31743 .07168 L
.31952 .07062 L
.32158 .06942 L
.32383 .06805 L
.32595 .06662 L
.32819 .0651 L
.33054 .06354 L
.33276 .06184 L
.33509 .06024 L
.33755 .05855 L
.33986 .05682 L
.34227 .05536 L
.34476 .05392 L
.34705 .05251 L
.34934 .05126 L
.35149 .05014 L
.35354 .04912 L
.35521 .04822 L
.35673 .04742 L
.35798 .0467 L
.35902 .04608 L
.35982 .04555 L
.36041 .04511 L
.3608 .04472 L
.36104 .04438 L
.36112 .04411 L
.36108 .04389 L
.36096 .04372 L
.3608 .04359 L
.36063 .04353 L
.36048 .04352 L
.36035 .04356 L
.36027 .04362 L
.36028 .04369 L
.36038 .04375 L
.36061 .04377 L
.36099 .04378 L
.36157 .04378 L
.36235 .04378 L
.36332 .0438 L
Mistroke
.36449 .04383 L
.36586 .04389 L
.36717 .04399 L
.36859 .04408 L
.36993 .04414 L
.37132 .04416 L
.37246 .04412 L
.37353 .04399 L
.37451 .04378 L
.37531 .04349 L
.37601 .04314 L
.37664 .04275 L
.37721 .04234 L
.37776 .04193 L
.37827 .04152 L
.37874 .04112 L
.37925 .04075 L
.37981 .04043 L
.38042 .04016 L
.38106 .03996 L
.38169 .03984 L
.38225 .03979 L
.38275 .0398 L
.38317 .03988 L
.38352 .04002 L
.38379 .0402 L
.38398 .04043 L
.38415 .04071 L
.38434 .04101 L
.38458 .04128 L
.38486 .04148 L
.38516 .04162 L
.3855 .04169 L
.38585 .04175 L
.38621 .04183 L
.38658 .04192 L
.38696 .04202 L
.38736 .04214 L
.3878 .04223 L
.38833 .0423 L
.38895 .04237 L
.38974 .04247 L
.39052 .04261 L
.39151 .04288 L
.39268 .04329 L
.39392 .04382 L
.39537 .04443 L
.3969 .04508 L
.39871 .04574 L
.40075 .04635 L
Mistroke
.40263 .04689 L
.40472 .04734 L
.40683 .04777 L
.40894 .04817 L
.41115 .04856 L
.41319 .04893 L
.4152 .04927 L
.41714 .04956 L
.41888 .04976 L
.42061 .04987 L
.42211 .04987 L
.42341 .04977 L
.4244 .04958 L
.42516 .04934 L
.42569 .04906 L
.42606 .04877 L
.42632 .04848 L
.42653 .04816 L
.42677 .0478 L
.42712 .0474 L
.42764 .04692 L
.42835 .04638 L
.42926 .04577 L
.43031 .04505 L
.43156 .04445 L
.433 .0438 L
.43461 .04318 L
.43626 .04263 L
.43789 .0421 L
.43954 .04157 L
.44083 .04107 L
.442 .0406 L
.44289 .04017 L
.44361 .03984 L
.44413 .03961 L
.44445 .0395 L
.44468 .03949 L
.44493 .03954 L
.44528 .03962 L
.44578 .0397 L
.44648 .03976 L
.44742 .03981 L
.44862 .03984 L
.44987 .03989 L
.45157 .03995 L
.45332 .04005 L
.45534 .04018 L
.45763 .04035 L
.45976 .04056 L
.4621 .04079 L
Mistroke
.4643 .04103 L
.46646 .04129 L
.46853 .04155 L
.47037 .04177 L
.47205 .04196 L
.47357 .04211 L
.47484 .04223 L
.47596 .04236 L
.4769 .0425 L
.47762 .04267 L
.47813 .04288 L
.47845 .04314 L
.47861 .04345 L
.47866 .04381 L
.47863 .0442 L
.47855 .04462 L
.47846 .04505 L
.47837 .04549 L
.47829 .04592 L
.47818 .0463 L
.47805 .04661 L
.4779 .04679 L
.47776 .04682 L
.47769 .0467 L
.47771 .04646 L
.47788 .04612 L
.4782 .04571 L
.47873 .0453 L
.47949 .04488 L
.48051 .0445 L
.4817 .04413 L
.4832 .04379 L
.48468 .04349 L
.48654 .04324 L
.48846 .04304 L
.49037 .04285 L
.49254 .04265 L
.49478 .04241 L
.49706 .04215 L
.49933 .04183 L
.50152 .04146 L
.50359 .04106 L
.50563 .04061 L
.50732 .04013 L
.50884 .03966 L
.51032 .03923 L
.51151 .03881 L
.51256 .03841 L
.51333 .03802 L
.51391 .03775 L
Mistroke
.51428 .03754 L
.51446 .03744 L
.51446 .03745 L
.51431 .03758 L
.51405 .0378 L
.51374 .03807 L
.51345 .03839 L
.51322 .03874 L
.51305 .0391 L
.51293 .0395 L
.51285 .03989 L
.51281 .04029 L
.51281 .0407 L
.51285 .04102 L
.51295 .04132 L
.5131 .04155 L
.51331 .04171 L
.51357 .0418 L
.51388 .04184 L
.51422 .04186 L
.5146 .04189 L
.51496 .04193 L
.51529 .04198 L
.51556 .04201 L
.51574 .04199 L
.51581 .0419 L
.51581 .04173 L
.51576 .0415 L
.51568 .04119 L
.51554 .04084 L
.51532 .04046 L
.51502 .04007 L
.51467 .03969 L
.51426 .03929 L
.51381 .03887 L
.51334 .03843 L
.51285 .038 L
.51236 .03762 L
.51187 .03731 L
.51139 .03706 L
.51097 .03686 L
.51058 .03668 L
.51015 .0365 L
.50971 .03627 L
.50921 .03601 L
.50866 .03571 L
.50802 .03535 L
.50724 .035 L
.50622 .03466 L
.50489 .03438 L
Mistroke
.50325 .0341 L
.5012 .03385 L
.49901 .03361 L
.49638 .03339 L
.49355 .03318 L
.49066 .03297 L
.48738 .03278 L
.48466 .03263 L
.48126 .03254 L
.47853 .03249 L
.47512 .03245 L
.47241 .03241 L
.46958 .03234 L
.4666 .03227 L
.46401 .03219 L
.46122 .03211 L
.4582 .03201 L
.45566 .03188 L
.45236 .03173 L
.44967 .03159 L
.44665 .03147 L
.44308 .03139 L
.43996 .03138 L
.43647 .03145 L
.43311 .0316 L
.42945 .03182 L
.42651 .0321 L
.42345 .03245 L
.42063 .03283 L
.41794 .03323 L
.41563 .03362 L
.41363 .03397 L
.41187 .03425 L
.41053 .03442 L
.40948 .03447 L
.4087 .03441 L
.40817 .03426 L
.40786 .03404 L
.40774 .03379 L
.40777 .03354 L
.40789 .03334 L
.40806 .03319 L
.40824 .03312 L
.40838 .03312 L
.40849 .03316 L
.40856 .03327 L
.40861 .03344 L
.40865 .03368 L
.40868 .03391 L
.4087 .03417 L
Mistroke
.40871 .03441 L
.4087 .0346 L
.40869 .03472 L
.40871 .03478 L
.40878 .03479 L
.40889 .03478 L
.40899 .03477 L
.40903 .03475 L
.409 .03471 L
.40886 .03465 L
.40859 .03458 L
.40819 .03453 L
.40767 .03452 L
.40707 .03455 L
.4064 .03464 L
.4057 .0348 L
.40504 .03501 L
.40444 .03529 L
.40382 .03563 L
.40318 .036 L
.40257 .0364 L
.4021 .03678 L
.40179 .03719 L
.40163 .03754 L
.40157 .0379 L
.40159 .03822 L
.40168 .03848 L
.40179 .03865 L
.40185 .03875 L
.40186 .03879 L
.40183 .03878 L
.40179 .03874 L
.40176 .0387 L
.40174 .03868 L
.40175 .03866 L
.4018 .03864 L
.40189 .03864 L
.40203 .03864 L
.4022 .03864 L
.4024 .03865 L
.40262 .03865 L
.40286 .03866 L
.40309 .03867 L
.40333 .03868 L
.40355 .0387 L
.40376 .03874 L
.40395 .03879 L
.4041 .03884 L
.40421 .03887 L
.40427 .03886 L
Mistroke
.40429 .03882 L
.40427 .0387 L
.40422 .03849 L
.40415 .0382 L
.4041 .03783 L
.40406 .03745 L
.40404 .0371 L
.40403 .03677 L
.40402 .03653 L
.40403 .03641 L
.40404 .03638 L
.40405 .03639 L
.40407 .03644 L
.40409 .03657 L
.4041 .03676 L
.40412 .03704 L
.40415 .03735 L
.40419 .03768 L
.40425 .03801 L
.40434 .0383 L
.40447 .03854 L
.40465 .03868 L
.40488 .03874 L
.40516 .03875 L
.40549 .03872 L
.40584 .03868 L
.40624 .03867 L
.40664 .0387 L
.40706 .03875 L
.40745 .03879 L
.40781 .03883 L
.40812 .03885 L
.40838 .03885 L
.40859 .03884 L
.40874 .03883 L
.40881 .03883 L
.40884 .03883 L
.40883 .03883 L
.4088 .03883 L
.40877 .03882 L
.40873 .03882 L
.4087 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
Mistroke
.40868 .03882 L
.40868 .03882 L
.40868 .03882 L
.40866 .03882 L
.40864 .03882 L
.4086 .03882 L
.40857 .03882 L
.40855 .03882 L
.40856 .03882 L
.40861 .03882 L
.40869 .03883 L
.40882 .03885 L
.40898 .03887 L
.40915 .03888 L
.40933 .03887 L
.40953 .03885 L
.40976 .03883 L
.41001 .03879 L
.41029 .03876 L
.41061 .03874 L
.41096 .03873 L
.41129 .03872 L
.41159 .0387 L
.41183 .03866 L
.41202 .03862 L
.41216 .03858 L
.41227 .03855 L
.41237 .03853 L
.41247 .03853 L
.41257 .03855 L
.41267 .03859 L
.41275 .03864 L
.4128 .03868 L
.41283 .03872 L
.41283 .03875 L
.41285 .03878 L
.41292 .03883 L
.41303 .03893 L
.41318 .03904 L
.41331 .03913 L
.41338 .03916 L
.41335 .0391 L
.41321 .03896 L
.41293 .03872 L
.41252 .03838 L
.41203 .03798 L
.41153 .03754 L
.41107 .0371 L
.41067 .03667 L
.41033 .03625 L
Mistroke
.41002 .03584 L
.40976 .03545 L
.40958 .0351 L
.4095 .03483 L
.40953 .03465 L
.40966 .03455 L
.40986 .03452 L
.41012 .03455 L
.4104 .03462 L
.41067 .03469 L
.41088 .03475 L
.411 .03477 L
.41106 .03477 L
.41107 .03477 L
.41106 .03477 L
.41102 .03478 L
.41098 .03478 L
.41095 .03479 L
.41094 .0348 L
.41094 .0348 L
.41094 .03481 L
.41094 .03482 L
.41094 .03482 L
.41094 .03482 L
.41094 .03482 L
.41094 .03482 L
.41094 .03482 L
.41094 .03482 L
.41094 .03481 L
.41094 .03481 L
.41094 .0348 L
.41094 .03479 L
.41094 .03478 L
.41094 .03477 L
.41094 .03477 L
.41094 .03477 L
.41094 .03477 L
.41094 .03477 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
Mistroke
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41094 .03478 L
.41095 .03478 L
.41096 .03479 L
.41098 .03479 L
.41099 .03478 L
.41097 .03478 L
.41094 .03477 L
.4109 .03476 L
.41084 .03474 L
.41079 .03473 L
.41073 .03473 L
.41069 .03472 L
.41066 .03472 L
.41064 .03472 L
.41063 .03471 L
.41064 .03472 L
.41067 .03472 L
.41071 .03473 L
.41076 .03474 L
.4108 .03475 L
.41081 .03476 L
.41081 .03476 L
.41077 .03476 L
.41072 .03476 L
.41066 .03475 L
.41059 .03474 L
.41052 .03473 L
Mistroke
.41045 .03472 L
.41041 .03473 L
.41039 .03472 L
.41038 .03472 L
.41036 .03473 L
.41037 .03473 L
.4104 .03474 L
.41047 .03475 L
.41058 .03476 L
.41073 .03477 L
.41091 .03478 L
.41112 .03479 L
.41134 .0348 L
.41155 .0348 L
.41175 .0348 L
.41196 .03481 L
.41217 .03481 L
.4124 .03482 L
.41262 .03483 L
.41283 .03483 L
.41301 .03484 L
.41316 .03484 L
.41326 .03484 L
.41332 .03484 L
.41333 .03485 L
.41332 .03484 L
.41328 .03484 L
.41325 .03484 L
.41322 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.41322 .03484 L
.41327 .03484 L
.41334 .03485 L
Mistroke
.4134 .03485 L
.41343 .03485 L
.41341 .03485 L
.41332 .03485 L
.41314 .03484 L
.41288 .03483 L
.41254 .03482 L
.41213 .03481 L
.41168 .0348 L
.41122 .03479 L
.41077 .03477 L
.41033 .03476 L
.40989 .03475 L
.40946 .03473 L
.40906 .03472 L
.40872 .03471 L
.40848 .03471 L
.40835 .0347 L
.40832 .0347 L
.40839 .0347 L
.40854 .03471 L
.40874 .03471 L
.40896 .03472 L
.40918 .03473 L
.40941 .03473 L
.40965 .03474 L
.40989 .03475 L
.41012 .03475 L
.41035 .03476 L
.41056 .03477 L
.41075 .03477 L
.41089 .03478 L
.41099 .03478 L
.41105 .03479 L
.41107 .03478 L
.41106 .03478 L
.41105 .03477 L
.41103 .03477 L
.411 .03476 L
.41097 .03475 L
.41094 .03475 L
.4109 .03474 L
.41084 .03474 L
.41079 .03476 L
.41073 .03477 L
.41069 .03477 L
.41066 .03476 L
.41064 .03474 L
.41063 .03472 L
.41061 .03468 L
Mistroke
.41059 .03465 L
.41057 .03462 L
.41056 .03459 L
.41059 .03458 L
.41066 .03457 L
.41076 .03456 L
.41091 .03457 L
.41109 .03457 L
.4113 .03459 L
.41152 .03461 L
.41173 .03464 L
.41195 .03469 L
.41217 .03474 L
.41239 .03478 L
.41262 .03482 L
.41283 .03486 L
.41301 .03488 L
.41316 .03488 L
.41326 .03487 L
.41332 .03485 L
.41333 .03485 L
.41332 .03484 L
.41328 .03484 L
.41325 .03484 L
.41322 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.4132 .03484 L
.41321 .03482 L
.41323 .03477 L
.41325 .03471 L
.41325 .03465 L
.41324 .03462 L
.4132 .03464 L
.41316 .03473 L
.41311 .03489 L
.41305 .03513 L
.413 .03544 L
.41296 .0358 L
.41293 .0362 L
.41291 .03662 L
.4129 .03704 L
.4129 .03745 L
.4129 .03786 L
.41292 .03824 L
.41295 .03858 L
.41299 .03885 L
.41304 .03903 L
.4131 .03914 L
Mistroke
.41317 .03917 L
.41323 .03914 L
.41331 .03906 L
.41339 .03896 L
.41345 .03886 L
.41346 .03878 L
.41342 .03872 L
.41333 .03871 L
.41315 .03875 L
.41289 .03888 L
.41255 .03911 L
.41214 .03943 L
.41169 .03986 L
.41123 .04036 L
.41078 .04091 L
.41035 .04153 L
.40991 .0422 L
.4095 .04288 L
.40912 .0435 L
.40882 .04406 L
.40861 .04452 L
.40851 .04484 L
.40854 .04499 L
.40865 .04494 L
.40879 .04473 L
.4089 .04437 L
.40895 .04394 L
.4089 .04348 L
.40871 .04301 L
.40843 .04256 L
.40796 .04212 L
.40725 .0417 L
.40632 .04129 L
.40521 .0409 L
.40407 .04055 L
.40288 .04024 L
.40146 .03997 L
.39974 .03974 L
.39823 .03955 L
.39657 .0394 L
.39508 .03926 L
.39356 .03909 L
.39217 .03889 L
.39105 .03867 L
.39004 .03843 L
.38915 .03815 L
.38842 .03783 L
.38787 .03749 L
.38751 .03712 L
.38732 .03674 L
Mistroke
.38728 .03635 L
.38732 .03596 L
.38741 .03557 L
.38751 .03517 L
.3876 .03479 L
.38763 .03445 L
.38759 .03419 L
.38752 .03402 L
.38742 .03392 L
.3873 .03389 L
.38717 .0339 L
.38702 .03396 L
.38683 .03402 L
.38661 .03407 L
.38637 .03409 L
.38615 .03409 L
.38597 .03408 L
.38584 .03407 L
.38575 .03407 L
.38572 .03407 L
.38574 .03407 L
.38581 .03409 L
.38591 .03411 L
.38602 .03414 L
.38611 .03417 L
.38618 .0342 L
.38623 .03424 L
.38627 .03427 L
.3863 .0343 L
.38636 .03433 L
.38644 .03435 L
.38656 .03436 L
.38672 .03436 L
.3869 .03435 L
.38708 .03432 L
.38724 .03427 L
.38737 .03435 L
.38747 .0343 L
.38754 .03428 L
.38758 .03428 L
.38758 .03431 L
.38753 .03437 L
.38742 .03448 L
.38722 .03464 L
.38693 .03488 L
.38655 .03513 L
.3861 .03544 L
.38563 .03578 L
.38517 .03612 L
.38476 .0365 L
Mistroke
.38441 .03685 L
.38411 .03713 L
.38388 .03741 L
.38372 .03765 L
.3836 .03784 L
.38354 .03799 L
.38352 .03811 L
.38355 .03818 L
.38364 .03822 L
.38377 .03824 L
.38391 .03824 L
.38398 .03822 L
.38396 .03818 L
.38383 .03814 L
.38356 .03812 L
.38316 .0381 L
.38264 .03809 L
.38202 .03807 L
.38135 .03805 L
.38065 .03803 L
.37997 .03801 L
.3793 .03799 L
.37864 .03797 L
.378 .03795 L
.37743 .03794 L
.37697 .03792 L
.37666 .03792 L
.37648 .03791 L
.37643 .03791 L
.37646 .03791 L
.37655 .03791 L
.37667 .03792 L
.37675 .03792 L
.37678 .03792 L
.37679 .0379 L
.3768 .03787 L
.37683 .03785 L
.37687 .03784 L
.3769 .03785 L
.37692 .03787 L
.3769 .03793 L
.37682 .03804 L
.37669 .0382 L
.37652 .03838 L
.37633 .03856 L
.37615 .03872 L
.37597 .03887 L
.37583 .03896 L
.37573 .03902 L
.37567 .03908 L
Mistroke
.37564 .03908 L
.37566 .03905 L
.37571 .03896 L
.37579 .03883 L
.37593 .03866 L
.37609 .03847 L
.37629 .03828 L
.37648 .0381 L
.37666 .03795 L
.3768 .03787 L
.37689 .03783 L
.37692 .03782 L
.37691 .03782 L
.37688 .03785 L
.37684 .03788 L
.37681 .03791 L
.37679 .03792 L
.37679 .03792 L
.37679 .03792 L
.37679 .03792 L
.37679 .03792 L
.37679 .03792 L
.37681 .03792 L
.37686 .03792 L
.37693 .03793 L
.377 .03793 L
.37704 .03793 L
.37702 .03793 L
.37694 .03793 L
.37677 .03792 L
.37653 .03791 L
.37623 .03786 L
.3759 .03778 L
.37554 .03766 L
.37517 .03757 L
.37479 .0375 L
.3744 .03748 L
.37396 .03755 L
.37343 .03775 L
.37282 .03809 L
.37213 .03858 L
.37132 .03922 L
.37035 .03999 L
.36923 .04086 L
.36805 .04174 L
.36667 .04265 L
.36508 .04358 L
.3635 .04452 L
.36161 .04541 L
.35992 .04616 L
Mistroke
.35822 .04678 L
.35658 .04727 L
.35513 .04761 L
.35396 .04781 L
.35298 .0479 L
.35221 .0479 L
.35167 .04785 L
.35133 .04779 L
.35113 .04772 L
.35107 .04765 L
.35108 .04759 L
.35115 .04756 L
.35125 .04756 L
.35137 .04756 L
.35147 .04756 L
.35152 .04756 L
.35153 .04756 L
.35154 .04753 L
.35161 .04747 L
.35172 .04738 L
.35183 .04729 L
.35189 .04725 L
.35189 .04729 L
.3518 .04741 L
.35155 .04765 L
.35111 .048 L
.35049 .04847 L
.34975 .04901 L
.34893 .04961 L
.3481 .05024 L
.34727 .05084 L
.34659 .05142 L
.34584 .05199 L
.34512 .05254 L
.3445 .05303 L
.34407 .0534 L
.34385 .05363 L
.34384 .0537 L
.34397 .05367 L
.34418 .05357 L
.34441 .05345 L
.3446 .05335 L
.34467 .05332 L
.34455 .05339 L
.34421 .05355 L
.34365 .05379 L
.34285 .05409 L
.34179 .05447 L
.34065 .05494 L
.33916 .05549 L
Mistroke
.3378 .05613 L
.33633 .05687 L
.33464 .05772 L
.33301 .05866 L
.33132 .05968 L
.32955 .06071 L
.32776 .06172 L
.32605 .06264 L
.32432 .06355 L
.32262 .0644 L
.32123 .06516 L
.31979 .06582 L
.31844 .06639 L
.31737 .06688 L
.31643 .06728 L
.31562 .0676 L
.31495 .06783 L
.31444 .06802 L
.3141 .06818 L
.31393 .06834 L
.31391 .06848 L
.31399 .06863 L
.31412 .06879 L
.31425 .06897 L
.31436 .06916 L
.31442 .06933 L
.31443 .06946 L
.31443 .06956 L
.31443 .06961 L
.31443 .06962 L
.31443 .06961 L
.31443 .06958 L
.31443 .06954 L
.31443 .06952 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31443 .0695 L
.31445 .06948 L
.31452 .06943 L
.31462 .06937 L
.31473 .06931 L
.31478 .06928 L
.31476 .06929 L
Mistroke
.31464 .06937 L
.3144 .06952 L
.31402 .06974 L
.31354 .07001 L
.31299 .07031 L
.31239 .07064 L
.31175 .07099 L
.31106 .07138 L
.31034 .07182 L
.30955 .07232 L
.30871 .07286 L
.30785 .07343 L
.30702 .07401 L
.30629 .07456 L
.3057 .07507 L
.30524 .07553 L
.30486 .07593 L
.3045 .07631 L
.30409 .07666 L
.30359 .07701 L
.30299 .07734 L
.30229 .07761 L
.30155 .07779 L
.30079 .07789 L
.30006 .07791 L
.2994 .07786 L
.29882 .07775 L
.29826 .07763 L
.29765 .07753 L
.29702 .07747 L
.29641 .07746 L
.29586 .07748 L
.29542 .07755 L
.29507 .07765 L
.2948 .07779 L
.29461 .07796 L
.29446 .07815 L
.29433 .07839 L
.29416 .07858 L
.29394 .07882 L
.2937 .07905 L
.29348 .07925 L
.2933 .07941 L
.29318 .07951 L
.29313 .07954 L
.29316 .07951 L
.29327 .07946 L
.29345 .07943 L
.29366 .07943 L
.2939 .07949 L
Mistroke
.29415 .07962 L
.2944 .07984 L
.29464 .0801 L
.2949 .08037 L
.29516 .0806 L
.29544 .08075 L
.29571 .08083 L
.29595 .08086 L
.29616 .08086 L
.29632 .08088 L
.29638 .08097 L
.29629 .08098 L
.29605 .08103 L
.29564 .08111 L
.29503 .08125 L
.29417 .0815 L
.29304 .0819 L
.29176 .08244 L
.29017 .08318 L
.28825 .08413 L
.28611 .08525 L
.28411 .08642 L
.28189 .08768 L
.27942 .08897 L
.27719 .09021 L
.27486 .0914 L
.27291 .09246 L
.27115 .09343 L
.26968 .09431 L
.26849 .09509 L
.26742 .09574 L
.26655 .09629 L
.26582 .09675 L
.2652 .09712 L
.26464 .09742 L
.26406 .09769 L
.26344 .09796 L
.26271 .09828 L
.2618 .09869 L
.26074 .0992 L
.25953 .09985 L
.25807 .10063 L
.25632 .10158 L
.25449 .10264 L
.25258 .10381 L
.2506 .10504 L
.24886 .10624 L
.24717 .10738 L
.24577 .10846 L
.24441 .10943 L
Mistroke
.24331 .11024 L
.24237 .11092 L
.24165 .11145 L
.24115 .11183 L
.24087 .11207 L
.24077 .11219 L
.24079 .11221 L
.24091 .11218 L
.24107 .11211 L
.24121 .11202 L
.2413 .11194 L
.24136 .11187 L
.24145 .1118 L
.24157 .11171 L
.24167 .11161 L
.24172 .11154 L
.2417 .11149 L
.24158 .11151 L
.24133 .11161 L
.24094 .11184 L
.24041 .11221 L
.23974 .11273 L
.23897 .11339 L
.23812 .11419 L
.23726 .11504 L
.23639 .116 L
.2355 .11697 L
.23461 .11797 L
.23377 .11894 L
.23306 .11985 L
.23249 .12064 L
.23208 .1213 L
.2318 .12182 L
.23165 .12219 L
.23159 .12242 L
.2316 .12252 L
.23162 .12254 L
.23165 .12251 L
.23167 .12245 L
.23171 .12239 L
.23176 .12231 L
.23182 .12224 L
.2319 .12219 L
.23199 .12215 L
.23209 .12209 L
.23221 .12203 L
.23231 .12196 L
.23235 .1219 L
.23228 .12189 L
.23207 .12197 L
Mistroke
.23166 .12217 L
.23102 .1225 L
.23011 .12297 L
.22892 .12358 L
.2276 .12427 L
.226 .12505 L
.22412 .12591 L
.22217 .12682 L
.22014 .12782 L
.2178 .12901 L
.21564 .13018 L
.21333 .13143 L
.2111 .13274 L
.2092 .13408 L
.20738 .13539 L
.20574 .13664 L
.2044 .13765 L
.20326 .13867 L
.20233 .13962 L
.20165 .14036 L
.20118 .14102 L
.20086 .1416 L
.20066 .14205 L
.20052 .14238 L
.20039 .14267 L
.2002 .14302 L
.19992 .14347 L
.19954 .14406 L
.19905 .14484 L
.19845 .14581 L
.19777 .14691 L
.1971 .14796 L
.1964 .14914 L
.19573 .15035 L
.19513 .15137 L
.19458 .15237 L
.19411 .15322 L
.19378 .15395 L
.19355 .15454 L
.19335 .15506 L
.19315 .15556 L
.19288 .1561 L
.19248 .15677 L
.19186 .15766 L
.19099 .15883 L
.18994 .16008 L
.18865 .16171 L
.1871 .16352 L
.18531 .1657 L
.18342 .168 L
Mistroke
.18166 .17061 L
.17979 .17302 L
.17779 .17572 L
.17585 .17845 L
.174 .18111 L
.17215 .18394 L
.17046 .18637 L
.16878 .18896 L
.16724 .19137 L
.16572 .19377 L
.16424 .19603 L
.16291 .19833 L
.16158 .20034 L
.16027 .20235 L
.15904 .20428 L
.15793 .20605 L
.15687 .20775 L
.15588 .20934 L
.155 .21065 L
.15421 .21189 L
.15354 .21302 L
.153 .21401 L
.15259 .21482 L
.1523 .21549 L
.15211 .21599 L
.15202 .2163 L
.15198 .21648 L
.15197 .21655 L
.15195 .21655 L
.15192 .21651 L
.15185 .21648 L
.15172 .21649 L
.15151 .21656 L
.1512 .21671 L
.15078 .21698 L
.15024 .21742 L
.14956 .21807 L
.14879 .21891 L
.14789 .21995 L
.14686 .22124 L
.1457 .2228 L
.14444 .22464 L
.14321 .22642 L
.14192 .22857 L
.14059 .23089 L
.13925 .23321 L
.13783 .23581 L
.1363 .23861 L
.13475 .24124 L
.13308 .24424 L
Mistroke
.13141 .24707 L
.12978 .25006 L
.1281 .25283 L
.12638 .2558 L
.12485 .25835 L
.12298 .26112 L
.1213 .2638 L
.11941 .26663 L
.1176 .26952 L
.11566 .27205 L
.11365 .27478 L
.1117 .27764 L
.11021 .27999 L
.1086 .28252 L
.10716 .2847 L
.1057 .28688 L
.10462 .28865 L
.10365 .29029 L
.10281 .29178 L
.10215 .29298 L
.1017 .29396 L
.10143 .29466 L
.10133 .2951 L
.10135 .29531 L
.10144 .29533 L
.10156 .29523 L
.10169 .29508 L
.10179 .29491 L
.10183 .29478 L
.10183 .29468 L
.10183 .29461 L
.10183 .29459 L
.10181 .29463 L
.10177 .29471 L
.10169 .29486 L
.10158 .29511 L
.10145 .29548 L
.10132 .29598 L
.1012 .29662 L
.1011 .29738 L
.10103 .29825 L
.10099 .2992 L
.10098 .30013 L
.101 .30109 L
.10105 .30202 L
.1011 .30291 L
.10119 .30368 L
.1013 .30429 L
.10145 .30469 L
.10161 .30493 L
Mistroke
.10177 .30505 L
.10193 .30509 L
.10205 .30509 L
.10209 .30513 L
.10204 .30532 L
.10189 .30578 L
.10165 .3066 L
.10134 .30779 L
.10098 .30936 L
.10056 .31134 L
.10008 .31336 L
.0995 .31563 L
.09881 .31838 L
.09801 .32124 L
.09715 .32442 L
.0962 .32753 L
.09521 .33084 L
.09424 .33409 L
.09329 .337 L
.09237 .3402 L
.09156 .34311 L
.09079 .34609 L
.09012 .34888 L
.08953 .3518 L
.08903 .3543 L
.08863 .35693 L
.08833 .35938 L
.08815 .36191 L
.08807 .36433 L
.08806 .36632 L
.0881 .3682 L
.08815 .36998 L
.0882 .37157 L
.08824 .37295 L
.08824 .37401 L
.08823 .37491 L
.08822 .37559 L
.08821 .3761 L
.08821 .37644 L
.0882 .37662 L
Mfstroke
1 .999 0 r
.008 w
.07555 .45435 Mdot
.016 w
.07555 .45435 m
.07552 .45458 L
s
1 .998 0 r
.008 w
.07552 .45458 Mdot
.016 w
.07552 .45458 m
.07549 .45492 L
s
1 .997 0 r
.008 w
.07549 .45492 Mdot
.016 w
.07549 .45492 m
.07546 .45536 L
s
1 .996 0 r
.008 w
.07546 .45536 Mdot
.016 w
.07546 .45536 m
.07545 .45584 L
s
1 .995 0 r
.008 w
.07545 .45584 Mdot
.016 w
.07545 .45584 m
.07544 .45635 L
s
1 .994 0 r
.008 w
.07544 .45635 Mdot
.016 w
.07544 .45635 m
.07542 .45689 L
s
1 .993 0 r
.008 w
.07542 .45689 Mdot
.016 w
.07542 .45689 m
.07538 .45749 L
s
.008 w
.07538 .45749 Mdot
.016 w
.07538 .45749 m
.07533 .45814 L
s
1 .992 0 r
.008 w
.07533 .45814 Mdot
.016 w
.07533 .45814 m
.07526 .45887 L
s
1 .991 0 r
.008 w
.07526 .45887 Mdot
.016 w
.07526 .45887 m
.0752 .45966 L
s
1 .99 0 r
.008 w
.0752 .45966 Mdot
.016 w
.0752 .45966 m
.07516 .46048 L
s
1 .989 0 r
.008 w
.07516 .46048 Mdot
.016 w
.07516 .46048 m
.07514 .46135 L
s
1 .988 0 r
.008 w
.07514 .46135 Mdot
.016 w
.07514 .46135 m
.07512 .46227 L
s
1 .987 0 r
.008 w
.07512 .46227 Mdot
.016 w
.07512 .46227 m
.07508 .46325 L
s
1 .986 0 r
.008 w
.07508 .46325 Mdot
.016 w
.07508 .46325 m
.07502 .46432 L
s
1 .985 0 r
.008 w
.07502 .46432 Mdot
.016 w
.07502 .46432 m
.0749 .46549 L
s
1 .984 0 r
.008 w
.0749 .46549 Mdot
.016 w
.0749 .46549 m
.07473 .46683 L
s
1 .983 0 r
.008 w
.07473 .46683 Mdot
.016 w
.07473 .46683 m
.07452 .46842 L
s
1 .982 0 r
.008 w
.07452 .46842 Mdot
.016 w
.07452 .46842 m
.07425 .47033 L
s
1 .981 0 r
.008 w
.07425 .47033 Mdot
.016 w
.07425 .47033 m
.07393 .47244 L
s
1 .98 0 r
.008 w
.07393 .47244 Mdot
.016 w
.07393 .47244 m
.07358 .47488 L
s
1 .979 0 r
.008 w
.07358 .47488 Mdot
.016 w
.07358 .47488 m
.07321 .47754 L
s
1 .978 0 r
.008 w
.07321 .47754 Mdot
.016 w
.07321 .47754 m
.07286 .47996 L
s
.008 w
.07286 .47996 Mdot
.016 w
.07286 .47996 m
.07252 .48237 L
s
1 .977 0 r
.008 w
.07252 .48237 Mdot
.016 w
.07252 .48237 m
.07219 .48496 L
s
1 .976 0 r
.008 w
.07219 .48496 Mdot
.016 w
.07219 .48496 m
.07191 .48741 L
s
1 .975 0 r
.008 w
.07191 .48741 Mdot
.016 w
.07191 .48741 m
.07168 .49005 L
s
1 .974 0 r
.008 w
.07168 .49005 Mdot
.016 w
.07168 .49005 m
.07153 .49228 L
s
1 .973 0 r
.008 w
.07153 .49228 Mdot
.016 w
.07153 .49228 m
.07148 .49454 L
s
1 .972 0 r
.008 w
.07148 .49454 Mdot
.016 w
.07148 .49454 m
.07157 .49673 L
s
1 .971 0 r
.008 w
.07157 .49673 Mdot
.016 w
.07157 .49673 m
.07179 .49871 L
s
1 .97 0 r
.008 w
.07179 .49871 Mdot
.016 w
.07179 .49871 m
.07211 .50058 L
s
1 .969 0 r
.008 w
.07211 .50058 Mdot
.016 w
.07211 .50058 m
.07251 .50222 L
s
1 .968 0 r
.008 w
.07251 .50222 Mdot
.016 w
.07251 .50222 m
.07296 .50368 L
s
1 .967 0 r
.008 w
.07296 .50368 Mdot
.016 w
.07296 .50368 m
.07343 .50497 L
s
1 .966 0 r
.008 w
.07343 .50497 Mdot
.016 w
.07343 .50497 m
.07389 .50611 L
s
1 .965 0 r
.008 w
.07389 .50611 Mdot
.016 w
.07389 .50611 m
.0743 .50707 L
s
1 .964 0 r
.008 w
.0743 .50707 Mdot
.016 w
.0743 .50707 m
.07467 .50786 L
s
1 .963 0 r
.008 w
.07467 .50786 Mdot
.016 w
.07467 .50786 m
.07499 .50852 L
s
.008 w
.07499 .50852 Mdot
.016 w
.07499 .50852 m
.07529 .50907 L
s
1 .962 0 r
.008 w
.07529 .50907 Mdot
.016 w
.07529 .50907 m
.07555 .50952 L
s
1 .961 0 r
.008 w
.07555 .50952 Mdot
.016 w
.07555 .50952 m
.07579 .50987 L
s
1 .96 0 r
.008 w
.07579 .50987 Mdot
.016 w
.07579 .50987 m
.07602 .51014 L
s
1 .959 0 r
.008 w
.07602 .51014 Mdot
.016 w
.07602 .51014 m
.07624 .51036 L
s
1 .958 0 r
.008 w
.07624 .51036 Mdot
.016 w
.07624 .51036 m
.07647 .51052 L
s
1 .957 0 r
.008 w
.07647 .51052 Mdot
.016 w
.07647 .51052 m
.07673 .51065 L
s
1 .956 0 r
.008 w
.07673 .51065 Mdot
.016 w
.07673 .51065 m
.077 .51074 L
s
1 .955 0 r
.008 w
.077 .51074 Mdot
.016 w
.077 .51074 m
.07728 .5108 L
s
1 .954 0 r
.008 w
.07728 .5108 Mdot
.016 w
.07728 .5108 m
.07754 .51083 L
s
1 .953 0 r
.008 w
.07754 .51083 Mdot
.016 w
.07754 .51083 m
.07779 .5109 L
s
1 .952 0 r
.008 w
.07779 .5109 Mdot
.016 w
.07779 .5109 m
.07802 .51102 L
s
1 .951 0 r
.008 w
.07802 .51102 Mdot
.016 w
.07802 .51102 m
.07819 .51121 L
s
1 .95 0 r
.008 w
.07819 .51121 Mdot
.016 w
.07819 .51121 m
.07827 .51149 L
s
1 .949 0 r
.008 w
.07827 .51149 Mdot
.016 w
.07827 .51149 m
.07822 .51187 L
s
.008 w
.07822 .51187 Mdot
.016 w
.07822 .51187 m
.07805 .51236 L
s
1 .948 0 r
.008 w
.07805 .51236 Mdot
.016 w
.07805 .51236 m
.07777 .51299 L
s
1 .947 0 r
.008 w
.07777 .51299 Mdot
.016 w
.07777 .51299 m
.07744 .5138 L
s
1 .946 0 r
.008 w
.07744 .5138 Mdot
.016 w
.07744 .5138 m
.07708 .51483 L
s
1 .945 0 r
.008 w
.07708 .51483 Mdot
.016 w
.07708 .51483 m
.07677 .516 L
s
1 .944 0 r
.008 w
.07677 .516 Mdot
.016 w
.07677 .516 m
.0765 .51742 L
s
1 .943 0 r
.008 w
.0765 .51742 Mdot
.016 w
.0765 .51742 m
.07632 .51907 L
s
1 .942 0 r
.008 w
.07632 .51907 Mdot
.016 w
.07632 .51907 m
.07626 .52084 L
s
1 .941 0 r
.008 w
.07626 .52084 Mdot
.016 w
.07626 .52084 m
.0763 .52285 L
s
1 .94 0 r
.008 w
.0763 .52285 Mdot
.016 w
.0763 .52285 m
.07647 .525 L
s
1 .939 0 r
.008 w
.07647 .525 Mdot
.016 w
.07647 .525 m
.07675 .52712 L
s
1 .938 0 r
.008 w
.07675 .52712 Mdot
.016 w
.07675 .52712 m
.07711 .5294 L
s
1 .937 0 r
.008 w
.07711 .5294 Mdot
.016 w
.07711 .5294 m
.07759 .53165 L
s
1 .936 0 r
.008 w
.07759 .53165 Mdot
.016 w
.07759 .53165 m
.07818 .53398 L
s
1 .935 0 r
.008 w
.07818 .53398 Mdot
.016 w
.07818 .53398 m
.07878 .53611 L
s
1 .934 0 r
.008 w
.07878 .53611 Mdot
.016 w
.07878 .53611 m
.0794 .53826 L
s
.008 w
.0794 .53826 Mdot
.016 w
.0794 .53826 m
.07999 .54037 L
s
1 .933 0 r
.008 w
.07999 .54037 Mdot
.016 w
.07999 .54037 m
.08052 .54214 L
s
1 .932 0 r
.008 w
.08052 .54214 Mdot
.016 w
.08052 .54214 m
.08096 .54385 L
s
1 .931 0 r
.008 w
.08096 .54385 Mdot
.016 w
.08096 .54385 m
.0813 .5454 L
s
1 .93 0 r
.008 w
.0813 .5454 Mdot
.016 w
.0813 .5454 m
.08158 .54671 L
s
1 .929 0 r
.008 w
.08158 .54671 Mdot
.016 w
.08158 .54671 m
.08179 .54783 L
s
1 .928 0 r
.008 w
.08179 .54783 Mdot
.016 w
.08179 .54783 m
.08193 .54881 L
s
1 .927 0 r
.008 w
.08193 .54881 Mdot
.016 w
.08193 .54881 m
.08204 .54946 L
s
1 .926 0 r
.008 w
.08204 .54946 Mdot
.016 w
.08204 .54946 m
.08213 .54998 L
s
1 .925 0 r
.008 w
.08213 .54998 Mdot
.016 w
.08213 .54998 m
.08219 .5503 L
s
1 .924 0 r
.008 w
.08219 .5503 Mdot
.016 w
.08219 .5503 m
.08222 .55045 L
s
1 .923 0 r
.008 w
.08222 .55045 Mdot
.016 w
.08222 .55045 m
.08221 .55045 L
s
1 .922 0 r
.008 w
.08221 .55045 Mdot
.016 w
.08221 .55045 m
.08217 .55038 L
s
1 .921 0 r
.008 w
.08217 .55038 Mdot
.016 w
.08217 .55038 m
.08214 .55032 L
s
1 .92 0 r
.008 w
.08214 .55032 Mdot
.016 w
.08214 .55032 m
.08211 .55033 L
s
1 .919 0 r
.008 w
.08211 .55033 Mdot
.016 w
.08211 .55033 m
.08212 .5504 L
s
.008 w
.08212 .5504 Mdot
.016 w
.08212 .5504 m
.08215 .55054 L
s
1 .918 0 r
.008 w
.08215 .55054 Mdot
.016 w
.08215 .55054 m
.0822 .55074 L
s
1 .917 0 r
.008 w
.0822 .55074 Mdot
.016 w
.0822 .55074 m
.08226 .55097 L
s
1 .916 0 r
.008 w
.08226 .55097 Mdot
.016 w
.08226 .55097 m
.08231 .55123 L
s
1 .915 0 r
.008 w
.08231 .55123 Mdot
.016 w
.08231 .55123 m
.08235 .5515 L
s
1 .914 0 r
.008 w
.08235 .5515 Mdot
.016 w
.08235 .5515 m
.08238 .55178 L
s
1 .913 0 r
.008 w
.08238 .55178 Mdot
.016 w
.08238 .55178 m
.08239 .55208 L
s
1 .912 0 r
.008 w
.08239 .55208 Mdot
.016 w
.08239 .55208 m
.08238 .55244 L
s
1 .911 0 r
.008 w
.08238 .55244 Mdot
.016 w
.08238 .55244 m
.08235 .55292 L
s
1 .91 0 r
.008 w
.08235 .55292 Mdot
.016 w
.08235 .55292 m
.08229 .55357 L
s
1 .909 0 r
.008 w
.08229 .55357 Mdot
.016 w
.08229 .55357 m
.0822 .55429 L
s
1 .908 0 r
.008 w
.0822 .55429 Mdot
.016 w
.0822 .55429 m
.08209 .5552 L
s
1 .907 0 r
.008 w
.08209 .5552 Mdot
.016 w
.08209 .5552 m
.08196 .55625 L
s
1 .906 0 r
.008 w
.08196 .55625 Mdot
.016 w
.08196 .55625 m
.08183 .55747 L
s
1 .905 0 r
.008 w
.08183 .55747 Mdot
.016 w
.08183 .55747 m
.08172 .55879 L
s
1 .904 0 r
.008 w
.08172 .55879 Mdot
.016 w
.08172 .55879 m
.08165 .56037 L
s
.008 w
.08165 .56037 Mdot
.016 w
.08165 .56037 m
.08163 .56217 L
s
1 .903 0 r
.008 w
.08163 .56217 Mdot
.016 w
.08163 .56217 m
.08169 .56421 L
s
1 .902 0 r
.008 w
.08169 .56421 Mdot
.016 w
.08169 .56421 m
.08181 .56657 L
s
1 .901 0 r
.008 w
.08181 .56657 Mdot
.016 w
.08181 .56657 m
.08201 .56893 L
s
1 .9 0 r
.008 w
.08201 .56893 Mdot
.016 w
.08201 .56893 m
.0823 .57156 L
s
1 .899 0 r
.008 w
.0823 .57156 Mdot
.016 w
.0823 .57156 m
.08267 .57434 L
s
1 .898 0 r
.008 w
.08267 .57434 Mdot
.016 w
.08267 .57434 m
.08312 .57734 L
s
1 .897 0 r
.008 w
.08312 .57734 Mdot
.016 w
.08312 .57734 m
.08365 .58012 L
s
1 .896 0 r
.008 w
.08365 .58012 Mdot
.016 w
.08365 .58012 m
.08427 .58296 L
s
1 .895 0 r
.008 w
.08427 .58296 Mdot
.016 w
.08427 .58296 m
.08494 .58592 L
s
1 .894 0 r
.008 w
.08494 .58592 Mdot
.016 w
.08494 .58592 m
.08564 .5887 L
s
1 .893 0 r
.008 w
.08564 .5887 Mdot
.016 w
.08564 .5887 m
.08633 .59163 L
s
1 .892 0 r
.008 w
.08633 .59163 Mdot
.016 w
.08633 .59163 m
.087 .59437 L
s
1 .891 0 r
.008 w
.087 .59437 Mdot
.016 w
.087 .59437 m
.08761 .59711 L
s
1 .89 0 r
.008 w
.08761 .59711 Mdot
.016 w
.08761 .59711 m
.08819 .59955 L
s
.008 w
.08819 .59955 Mdot
.016 w
.08819 .59955 m
.08875 .60187 L
s
1 .889 0 r
.008 w
.08875 .60187 Mdot
.016 w
.08875 .60187 m
.08927 .60384 L
s
1 .888 0 r
.008 w
.08927 .60384 Mdot
.016 w
.08927 .60384 m
.08975 .60559 L
s
1 .887 0 r
.008 w
.08975 .60559 Mdot
.016 w
.08975 .60559 m
.0902 .60713 L
s
1 .886 0 r
.008 w
.0902 .60713 Mdot
.016 w
.0902 .60713 m
.0906 .60848 L
s
1 .885 0 r
.008 w
.0906 .60848 Mdot
.016 w
.0906 .60848 m
.09095 .60971 L
s
1 .884 0 r
.008 w
.09095 .60971 Mdot
.016 w
.09095 .60971 m
.09126 .61087 L
s
1 .883 0 r
.008 w
.09126 .61087 Mdot
.016 w
.09126 .61087 m
.09154 .61199 L
s
1 .882 0 r
.008 w
.09154 .61199 Mdot
.016 w
.09154 .61199 m
.09182 .61307 L
s
1 .881 0 r
.008 w
.09182 .61307 Mdot
.016 w
.09182 .61307 m
.09211 .61411 L
s
1 .88 0 r
.008 w
.09211 .61411 Mdot
.016 w
.09211 .61411 m
.09242 .61512 L
s
1 .879 0 r
.008 w
.09242 .61512 Mdot
.016 w
.09242 .61512 m
.09277 .616 L
s
1 .878 0 r
.008 w
.09277 .616 Mdot
.016 w
.09277 .616 m
.09314 .61686 L
s
1 .877 0 r
.008 w
.09314 .61686 Mdot
.016 w
.09314 .61686 m
.0935 .61762 L
s
1 .876 0 r
.008 w
.0935 .61762 Mdot
.016 w
.0935 .61762 m
.09384 .61834 L
s
1 .875 0 r
.008 w
.09384 .61834 Mdot
.016 w
.09384 .61834 m
.09411 .61894 L
s
.008 w
.09411 .61894 Mdot
.016 w
.09411 .61894 m
.09436 .61946 L
s
1 .874 0 r
.008 w
.09436 .61946 Mdot
.016 w
.09436 .61946 m
.09458 .61993 L
s
1 .873 0 r
.008 w
.09458 .61993 Mdot
.016 w
.09458 .61993 m
.09479 .6203 L
s
1 .872 0 r
.008 w
.09479 .6203 Mdot
.016 w
.09479 .6203 m
.09499 .62065 L
s
1 .871 0 r
.008 w
.09499 .62065 Mdot
.016 w
.09499 .62065 m
.0952 .62106 L
s
1 .87 0 r
.008 w
.0952 .62106 Mdot
.016 w
.0952 .62106 m
.0954 .62154 L
s
1 .869 0 r
.008 w
.0954 .62154 Mdot
.016 w
.0954 .62154 m
.0956 .62212 L
s
1 .868 0 r
.008 w
.0956 .62212 Mdot
.016 w
.0956 .62212 m
.09578 .62295 L
s
1 .867 0 r
.008 w
.09578 .62295 Mdot
.016 w
.09578 .62295 m
.09595 .62404 L
s
1 .866 0 r
.008 w
.09595 .62404 Mdot
.016 w
.09595 .62404 m
.09611 .62535 L
s
1 .865 0 r
.008 w
.09611 .62535 Mdot
.016 w
.09611 .62535 m
.09626 .62674 L
s
1 .864 0 r
.008 w
.09626 .62674 Mdot
.016 w
.09626 .62674 m
.09642 .6283 L
s
1 .863 0 r
.008 w
.09642 .6283 Mdot
.016 w
.09642 .6283 m
.09658 .62996 L
s
1 .862 0 r
.008 w
.09658 .62996 Mdot
.016 w
.09658 .62996 m
.09673 .63155 L
s
1 .861 0 r
.008 w
.09673 .63155 Mdot
.016 w
.09673 .63155 m
.09685 .63329 L
s
1 .86 0 r
.008 w
.09685 .63329 Mdot
.016 w
.09685 .63329 m
.09696 .63488 L
s
.008 w
.09696 .63488 Mdot
.016 w
.09696 .63488 m
.09705 .6365 L
s
1 .859 0 r
.008 w
.09705 .6365 Mdot
.016 w
.09705 .6365 m
.09713 .63812 L
s
1 .858 0 r
.008 w
.09713 .63812 Mdot
.016 w
.09713 .63812 m
.0972 .63976 L
s
1 .857 0 r
.008 w
.0972 .63976 Mdot
.016 w
.0972 .63976 m
.09727 .64144 L
s
1 .856 0 r
.008 w
.09727 .64144 Mdot
.016 w
.09727 .64144 m
.09734 .64314 L
s
1 .855 0 r
.008 w
.09734 .64314 Mdot
.016 w
.09734 .64314 m
.09745 .64471 L
s
1 .854 0 r
.008 w
.09745 .64471 Mdot
.016 w
.09745 .64471 m
.09762 .64639 L
s
1 .853 0 r
.008 w
.09762 .64639 Mdot
.016 w
.09762 .64639 m
.09788 .64818 L
s
1 .852 0 r
.008 w
.09788 .64818 Mdot
.016 w
.09788 .64818 m
.09824 .64992 L
s
1 .851 0 r
.008 w
.09824 .64992 Mdot
.016 w
.09824 .64992 m
.0987 .65176 L
s
1 .85 0 r
.008 w
.0987 .65176 Mdot
.016 w
.0987 .65176 m
.09927 .65361 L
s
1 .849 0 r
.008 w
.09927 .65361 Mdot
.016 w
.09927 .65361 m
.09995 .65529 L
s
1 .848 0 r
.008 w
.09995 .65529 Mdot
.016 w
.09995 .65529 m
.10074 .65688 L
s
1 .847 0 r
.008 w
.10074 .65688 Mdot
.016 w
.10074 .65688 m
.10168 .65831 L
s
1 .846 0 r
.008 w
.10168 .65831 Mdot
.016 w
.10168 .65831 m
.10239 .6593 L
s
.008 w
.10239 .6593 Mdot
.016 w
.10239 .6593 m
.10322 .66024 L
s
1 .845 0 r
.008 w
.10322 .66024 Mdot
.016 w
.10322 .66024 m
.10407 .66098 L
s
1 .844 0 r
.008 w
.10407 .66098 Mdot
.016 w
.10407 .66098 m
.10475 .66155 L
s
1 .843 0 r
.008 w
.10475 .66155 Mdot
.016 w
.10475 .66155 m
.1054 .66199 L
s
1 .842 0 r
.008 w
.1054 .66199 Mdot
.016 w
.1054 .66199 m
.10599 .66234 L
s
1 .841 0 r
.008 w
.10599 .66234 Mdot
.016 w
.10599 .66234 m
.10651 .66262 L
s
1 .84 0 r
.008 w
.10651 .66262 Mdot
.016 w
.10651 .66262 m
.10692 .66284 L
s
1 .839 0 r
.008 w
.10692 .66284 Mdot
.016 w
.10692 .66284 m
.10719 .66307 L
s
1 .838 0 r
.008 w
.10719 .66307 Mdot
.016 w
.10719 .66307 m
.10734 .66336 L
s
1 .837 0 r
.008 w
.10734 .66336 Mdot
.016 w
.10734 .66336 m
.10738 .66376 L
s
1 .836 0 r
.008 w
.10738 .66376 Mdot
.016 w
.10738 .66376 m
.10734 .66429 L
s
1 .835 0 r
.008 w
.10734 .66429 Mdot
.016 w
.10734 .66429 m
.10726 .66499 L
s
1 .834 0 r
.008 w
.10726 .66499 Mdot
.016 w
.10726 .66499 m
.10717 .66588 L
s
1 .833 0 r
.008 w
.10717 .66588 Mdot
.016 w
.10717 .66588 m
.10709 .66689 L
s
1 .832 0 r
.008 w
.10709 .66689 Mdot
.016 w
.10709 .66689 m
.10702 .66801 L
s
1 .831 0 r
.008 w
.10702 .66801 Mdot
.016 w
.10702 .66801 m
.10697 .66921 L
s
.008 w
.10697 .66921 Mdot
.016 w
.10697 .66921 m
.10691 .67046 L
s
1 .83 0 r
.008 w
.10691 .67046 Mdot
.016 w
.10691 .67046 m
.10682 .6718 L
s
1 .829 0 r
.008 w
.10682 .6718 Mdot
.016 w
.10682 .6718 m
.10672 .67325 L
s
1 .828 0 r
.008 w
.10672 .67325 Mdot
.016 w
.10672 .67325 m
.10662 .67496 L
s
1 .827 0 r
.008 w
.10662 .67496 Mdot
.016 w
.10662 .67496 m
.10651 .67651 L
s
1 .826 0 r
.008 w
.10651 .67651 Mdot
.016 w
.10651 .67651 m
.10642 .67826 L
s
1 .825 0 r
.008 w
.10642 .67826 Mdot
.016 w
.10642 .67826 m
.10634 .68007 L
s
1 .824 0 r
.008 w
.10634 .68007 Mdot
.016 w
.10634 .68007 m
.10628 .68179 L
s
1 .823 0 r
.008 w
.10628 .68179 Mdot
.016 w
.10628 .68179 m
.10624 .68338 L
s
1 .822 0 r
.008 w
.10624 .68338 Mdot
.016 w
.10624 .68338 m
.10621 .68483 L
s
1 .821 0 r
.008 w
.10621 .68483 Mdot
.016 w
.10621 .68483 m
.10619 .686 L
s
1 .82 0 r
.008 w
.10619 .686 Mdot
.016 w
.10619 .686 m
.1062 .68701 L
s
1 .819 0 r
.008 w
.1062 .68701 Mdot
.016 w
.1062 .68701 m
.10622 .68787 L
s
1 .818 0 r
.008 w
.10622 .68787 Mdot
.016 w
.10622 .68787 m
.10626 .6886 L
s
1 .817 0 r
.008 w
.10626 .6886 Mdot
.016 w
.10626 .6886 m
.10632 .68919 L
s
1 .816 0 r
.008 w
.10632 .68919 Mdot
.016 w
.10632 .68919 m
.10638 .68962 L
s
.008 w
.10638 .68962 Mdot
.016 w
.10638 .68962 m
.10645 .68988 L
s
1 .815 0 r
.008 w
.10645 .68988 Mdot
.016 w
.10645 .68988 m
.10651 .68999 L
s
1 .814 0 r
.008 w
.10651 .68999 Mdot
.016 w
.10651 .68999 m
.10655 .68998 L
s
1 .813 0 r
.008 w
.10655 .68998 Mdot
.016 w
.10655 .68998 m
.10658 .68991 L
s
1 .812 0 r
.008 w
.10658 .68991 Mdot
.016 w
.10658 .68991 m
.10657 .6898 L
s
1 .811 0 r
.008 w
.10657 .6898 Mdot
.016 w
.10657 .6898 m
.10655 .68969 L
s
1 .81 0 r
.008 w
.10655 .68969 Mdot
.016 w
.10655 .68969 m
.10653 .6896 L
s
1 .809 0 r
.008 w
.10653 .6896 Mdot
.016 w
.10653 .6896 m
.10652 .68955 L
s
1 .808 0 r
.008 w
.10652 .68955 Mdot
.016 w
.10652 .68955 m
.10652 .68952 L
s
1 .807 0 r
.008 w
.10652 .68952 Mdot
.016 w
.10652 .68952 m
.10652 .68948 L
s
1 .806 0 r
.008 w
.10652 .68948 Mdot
.016 w
.10652 .68948 m
.10652 .68942 L
s
1 .805 0 r
.008 w
.10652 .68942 Mdot
.016 w
.10652 .68942 m
.10652 .68934 L
s
1 .804 0 r
.008 w
.10652 .68934 Mdot
.016 w
.10652 .68934 m
.10653 .68923 L
s
1 .803 0 r
.008 w
.10653 .68923 Mdot
.016 w
.10653 .68923 m
.10653 .68911 L
s
1 .802 0 r
.008 w
.10653 .68911 Mdot
.016 w
.10653 .68911 m
.10653 .68899 L
s
1 .801 0 r
.008 w
.10653 .68899 Mdot
.016 w
.10653 .68899 m
.10652 .68891 L
s
.008 w
.10652 .68891 Mdot
.016 w
.10652 .68891 m
.10649 .68888 L
s
1 .8 0 r
.008 w
.10649 .68888 Mdot
.016 w
.10649 .68888 m
.10645 .68888 L
s
1 .799 0 r
.008 w
.10645 .68888 Mdot
.016 w
.10645 .68888 m
.10641 .68888 L
s
1 .798 0 r
.008 w
.10641 .68888 Mdot
.016 w
.10641 .68888 m
.10638 .68888 L
s
1 .797 0 r
.008 w
.10638 .68888 Mdot
.016 w
.10638 .68888 m
.10638 .68889 L
s
1 .796 0 r
.008 w
.10638 .68889 Mdot
.016 w
.10638 .68889 m
.10639 .6889 L
s
1 .795 0 r
.008 w
.10639 .6889 Mdot
.016 w
.10639 .6889 m
.10643 .68897 L
s
1 .794 0 r
.008 w
.10643 .68897 Mdot
.016 w
.10643 .68897 m
.10648 .68908 L
s
1 .793 0 r
.008 w
.10648 .68908 Mdot
.016 w
.10648 .68908 m
.10658 .68928 L
s
1 .792 0 r
.008 w
.10658 .68928 Mdot
.016 w
.10658 .68928 m
.10674 .68959 L
s
1 .791 0 r
.008 w
.10674 .68959 Mdot
.016 w
.10674 .68959 m
.107 .69004 L
s
1 .79 0 r
.008 w
.107 .69004 Mdot
.016 w
.107 .69004 m
.10737 .69062 L
s
1 .789 0 r
.008 w
.10737 .69062 Mdot
.016 w
.10737 .69062 m
.10785 .69133 L
s
1 .788 0 r
.008 w
.10785 .69133 Mdot
.016 w
.10785 .69133 m
.10847 .69218 L
s
1 .787 0 r
.008 w
.10847 .69218 Mdot
.016 w
.10847 .69218 m
.1092 .69318 L
s
.008 w
.1092 .69318 Mdot
.016 w
.1092 .69318 m
.11005 .69424 L
s
1 .786 0 r
.008 w
.11005 .69424 Mdot
.016 w
.11005 .69424 m
.11097 .69541 L
s
1 .785 0 r
.008 w
.11097 .69541 Mdot
.016 w
.11097 .69541 m
.11187 .69665 L
s
1 .784 0 r
.008 w
.11187 .69665 Mdot
.016 w
.11187 .69665 m
.11278 .69793 L
s
1 .783 0 r
.008 w
.11278 .69793 Mdot
.016 w
.11278 .69793 m
.11366 .69925 L
s
1 .782 0 r
.008 w
.11366 .69925 Mdot
.016 w
.11366 .69925 m
.11446 .70048 L
s
1 .781 0 r
.008 w
.11446 .70048 Mdot
.016 w
.11446 .70048 m
.11524 .7017 L
s
1 .78 0 r
.008 w
.11524 .7017 Mdot
.016 w
.11524 .7017 m
.11598 .70285 L
s
1 .779 0 r
.008 w
.11598 .70285 Mdot
.016 w
.11598 .70285 m
.1167 .70391 L
s
1 .778 0 r
.008 w
.1167 .70391 Mdot
.016 w
.1167 .70391 m
.11744 .70491 L
s
1 .777 0 r
.008 w
.11744 .70491 Mdot
.016 w
.11744 .70491 m
.11823 .70588 L
s
1 .776 0 r
.008 w
.11823 .70588 Mdot
.016 w
.11823 .70588 m
.11911 .70695 L
s
1 .775 0 r
.008 w
.11911 .70695 Mdot
.016 w
.11911 .70695 m
.12004 .708 L
s
1 .774 0 r
.008 w
.12004 .708 Mdot
.016 w
.12004 .708 m
.12108 .70924 L
s
1 .773 0 r
.008 w
.12108 .70924 Mdot
.016 w
.12108 .70924 m
.12225 .71063 L
s
1 .772 0 r
.008 w
.12225 .71063 Mdot
.016 w
.12225 .71063 m
.12347 .71206 L
s
.008 w
.12347 .71206 Mdot
.016 w
.12347 .71206 m
.1249 .71362 L
s
1 .771 0 r
.008 w
.1249 .71362 Mdot
.016 w
.1249 .71362 m
.12648 .7153 L
s
1 .77 0 r
.008 w
.12648 .7153 Mdot
.016 w
.12648 .7153 m
.12819 .71705 L
s
1 .769 0 r
.008 w
.12819 .71705 Mdot
.016 w
.12819 .71705 m
.12997 .71863 L
s
1 .768 0 r
.008 w
.12997 .71863 Mdot
.016 w
.12997 .71863 m
.13173 .72027 L
s
1 .767 0 r
.008 w
.13173 .72027 Mdot
.016 w
.13173 .72027 m
.13333 .72162 L
s
1 .766 0 r
.008 w
.13333 .72162 Mdot
.016 w
.13333 .72162 m
.13485 .72281 L
s
1 .765 0 r
.008 w
.13485 .72281 Mdot
.016 w
.13485 .72281 m
.13604 .72382 L
s
1 .764 0 r
.008 w
.13604 .72382 Mdot
.016 w
.13604 .72382 m
.13702 .72456 L
s
1 .763 0 r
.008 w
.13702 .72456 Mdot
.016 w
.13702 .72456 m
.13765 .72502 L
s
1 .762 0 r
.008 w
.13765 .72502 Mdot
.016 w
.13765 .72502 m
.13795 .72524 L
s
1 .761 0 r
.008 w
.13795 .72524 Mdot
.016 w
.13795 .72524 m
.13794 .72525 L
s
1 .76 0 r
.008 w
.13794 .72525 Mdot
.016 w
.13794 .72525 m
.13776 .72512 L
s
1 .759 0 r
.008 w
.13776 .72512 Mdot
.016 w
.13776 .72512 m
.1375 .72492 L
s
1 .758 0 r
.008 w
.1375 .72492 Mdot
.016 w
.1375 .72492 m
.13724 .72469 L
s
1 .757 0 r
.008 w
.13724 .72469 Mdot
.016 w
.13724 .72469 m
.137 .72452 L
s
.008 w
.137 .72452 Mdot
.016 w
.137 .72452 m
.13683 .72449 L
s
1 .756 0 r
.008 w
.13683 .72449 Mdot
.016 w
.13683 .72449 m
.13673 .72464 L
s
1 .755 0 r
.008 w
.13673 .72464 Mdot
.016 w
.13673 .72464 m
.13672 .72501 L
s
1 .754 0 r
.008 w
.13672 .72501 Mdot
.016 w
.13672 .72501 m
.13685 .72551 L
s
1 .753 0 r
.008 w
.13685 .72551 Mdot
.016 w
.13685 .72551 m
.13725 .72616 L
s
1 .752 0 r
.008 w
.13725 .72616 Mdot
.016 w
.13725 .72616 m
.13806 .72694 L
s
1 .751 0 r
.008 w
.13806 .72694 Mdot
.016 w
.13806 .72694 m
.13895 .72773 L
s
1 .75 0 r
.008 w
.13895 .72773 Mdot
.016 w
.13895 .72773 m
.14028 .72861 L
s
1 .749 0 r
.008 w
.14028 .72861 Mdot
.016 w
.14028 .72861 m
.1418 .72954 L
s
1 .748 0 r
.008 w
.1418 .72954 Mdot
.016 w
.1418 .72954 m
.14357 .73051 L
s
1 .747 0 r
.008 w
.14357 .73051 Mdot
.016 w
.14357 .73051 m
.14543 .7315 L
s
1 .746 0 r
.008 w
.14543 .7315 Mdot
.016 w
.14543 .7315 m
.14743 .73243 L
s
1 .745 0 r
.008 w
.14743 .73243 Mdot
.016 w
.14743 .73243 m
.14938 .73333 L
s
1 .744 0 r
.008 w
.14938 .73333 Mdot
.016 w
.14938 .73333 m
.15134 .73414 L
s
1 .743 0 r
.008 w
.15134 .73414 Mdot
.016 w
.15134 .73414 m
.15333 .73486 L
s
.008 w
.15333 .73486 Mdot
.016 w
.15333 .73486 m
.15523 .73546 L
s
1 .742 0 r
.008 w
.15523 .73546 Mdot
.016 w
.15523 .73546 m
.15701 .73596 L
s
1 .741 0 r
.008 w
.15701 .73596 Mdot
.016 w
.15701 .73596 m
.15861 .73637 L
s
1 .74 0 r
.008 w
.15861 .73637 Mdot
.016 w
.15861 .73637 m
.15996 .73672 L
s
1 .739 0 r
.008 w
.15996 .73672 Mdot
.016 w
.15996 .73672 m
.16106 .737 L
s
1 .738 0 r
.008 w
.16106 .737 Mdot
.016 w
.16106 .737 m
.16199 .73728 L
s
1 .737 0 r
.008 w
.16199 .73728 Mdot
.016 w
.16199 .73728 m
.16259 .73751 L
s
1 .736 0 r
.008 w
.16259 .73751 Mdot
.016 w
.16259 .73751 m
.16309 .73779 L
s
1 .735 0 r
.008 w
.16309 .73779 Mdot
.016 w
.16309 .73779 m
.16345 .73813 L
s
1 .734 0 r
.008 w
.16345 .73813 Mdot
.016 w
.16345 .73813 m
.16373 .73853 L
s
1 .733 0 r
.008 w
.16373 .73853 Mdot
.016 w
.16373 .73853 m
.16394 .73904 L
s
1 .732 0 r
.008 w
.16394 .73904 Mdot
.016 w
.16394 .73904 m
.16415 .73967 L
s
1 .731 0 r
.008 w
.16415 .73967 Mdot
.016 w
.16415 .73967 m
.16438 .74048 L
s
1 .73 0 r
.008 w
.16438 .74048 Mdot
.016 w
.16438 .74048 m
.16464 .74138 L
s
1 .729 0 r
.008 w
.16464 .74138 Mdot
.016 w
.16464 .74138 m
.16494 .74255 L
s
1 .728 0 r
.008 w
.16494 .74255 Mdot
.016 w
.16494 .74255 m
.16537 .74395 L
s
.008 w
.16537 .74395 Mdot
.016 w
.16537 .74395 m
.16598 .74551 L
s
1 .727 0 r
.008 w
.16598 .74551 Mdot
.016 w
.16598 .74551 m
.16679 .74723 L
s
1 .726 0 r
.008 w
.16679 .74723 Mdot
.016 w
.16679 .74723 m
.16782 .74918 L
s
1 .725 0 r
.008 w
.16782 .74918 Mdot
.016 w
.16782 .74918 m
.16904 .75135 L
s
1 .724 0 r
.008 w
.16904 .75135 Mdot
.016 w
.16904 .75135 m
.17038 .75358 L
s
1 .723 0 r
.008 w
.17038 .75358 Mdot
.016 w
.17038 .75358 m
.17186 .75583 L
s
1 .722 0 r
.008 w
.17186 .75583 Mdot
.016 w
.17186 .75583 m
.17348 .75824 L
s
1 .721 0 r
.008 w
.17348 .75824 Mdot
.016 w
.17348 .75824 m
.17516 .76061 L
s
1 .72 0 r
.008 w
.17516 .76061 Mdot
.016 w
.17516 .76061 m
.17698 .76304 L
s
1 .719 0 r
.008 w
.17698 .76304 Mdot
.016 w
.17698 .76304 m
.17897 .76548 L
s
1 .718 0 r
.008 w
.17897 .76548 Mdot
.016 w
.17897 .76548 m
.18109 .76784 L
s
1 .717 0 r
.008 w
.18109 .76784 Mdot
.016 w
.18109 .76784 m
.18337 .77015 L
s
1 .716 0 r
.008 w
.18337 .77015 Mdot
.016 w
.18337 .77015 m
.18559 .77235 L
s
1 .715 0 r
.008 w
.18559 .77235 Mdot
.016 w
.18559 .77235 m
.18784 .77438 L
s
1 .714 0 r
.008 w
.18784 .77438 Mdot
.016 w
.18784 .77438 m
.18988 .7762 L
s
1 .713 0 r
.008 w
.18988 .7762 Mdot
.016 w
.18988 .7762 m
.19171 .77769 L
s
.008 w
.19171 .77769 Mdot
.016 w
.19171 .77769 m
.19333 .77899 L
s
1 .712 0 r
.008 w
.19333 .77899 Mdot
.016 w
.19333 .77899 m
.19467 .78 L
s
1 .711 0 r
.008 w
.19467 .78 Mdot
.016 w
.19467 .78 m
.1958 .78081 L
s
1 .71 0 r
.008 w
.1958 .78081 Mdot
.016 w
.1958 .78081 m
.19671 .78147 L
s
1 .709 0 r
.008 w
.19671 .78147 Mdot
.016 w
.19671 .78147 m
.19749 .78201 L
s
1 .708 0 r
.008 w
.19749 .78201 Mdot
.016 w
.19749 .78201 m
.1982 .78251 L
s
1 .707 0 r
.008 w
.1982 .78251 Mdot
.016 w
.1982 .78251 m
.1989 .78306 L
s
1 .706 0 r
.008 w
.1989 .78306 Mdot
.016 w
.1989 .78306 m
.19963 .78369 L
s
1 .705 0 r
.008 w
.19963 .78369 Mdot
.016 w
.19963 .78369 m
.20041 .78443 L
s
1 .704 0 r
.008 w
.20041 .78443 Mdot
.016 w
.20041 .78443 m
.20128 .7853 L
s
1 .703 0 r
.008 w
.20128 .7853 Mdot
.016 w
.20128 .7853 m
.20227 .78629 L
s
1 .702 0 r
.008 w
.20227 .78629 Mdot
.016 w
.20227 .78629 m
.20348 .78746 L
s
1 .701 0 r
.008 w
.20348 .78746 Mdot
.016 w
.20348 .78746 m
.20495 .78885 L
s
1 .7 0 r
.008 w
.20495 .78885 Mdot
.016 w
.20495 .78885 m
.20663 .79047 L
s
1 .699 0 r
.008 w
.20663 .79047 Mdot
.016 w
.20663 .79047 m
.20855 .7922 L
s
.008 w
.20855 .7922 Mdot
.016 w
.20855 .7922 m
.2105 .79399 L
s
1 .698 0 r
.008 w
.2105 .79399 Mdot
.016 w
.2105 .79399 m
.21256 .79576 L
s
1 .697 0 r
.008 w
.21256 .79576 Mdot
.016 w
.21256 .79576 m
.21463 .79759 L
s
1 .696 0 r
.008 w
.21463 .79759 Mdot
.016 w
.21463 .79759 m
.21642 .799 L
s
1 .695 0 r
.008 w
.21642 .799 Mdot
.016 w
.21642 .799 m
.21816 .80041 L
s
1 .694 0 r
.008 w
.21816 .80041 Mdot
.016 w
.21816 .80041 m
.21966 .80166 L
s
1 .693 0 r
.008 w
.21966 .80166 Mdot
.016 w
.21966 .80166 m
.22097 .80269 L
s
1 .692 0 r
.008 w
.22097 .80269 Mdot
.016 w
.22097 .80269 m
.22201 .80354 L
s
1 .691 0 r
.008 w
.22201 .80354 Mdot
.016 w
.22201 .80354 m
.22283 .80423 L
s
1 .69 0 r
.008 w
.22283 .80423 Mdot
.016 w
.22283 .80423 m
.22342 .80475 L
s
1 .689 0 r
.008 w
.22342 .80475 Mdot
.016 w
.22342 .80475 m
.22381 .80512 L
s
1 .688 0 r
.008 w
.22381 .80512 Mdot
.016 w
.22381 .80512 m
.22403 .80539 L
s
1 .687 0 r
.008 w
.22403 .80539 Mdot
.016 w
.22403 .80539 m
.22414 .80561 L
s
1 .686 0 r
.008 w
.22414 .80561 Mdot
.016 w
.22414 .80561 m
.22419 .80579 L
s
1 .685 0 r
.008 w
.22419 .80579 Mdot
.016 w
.22419 .80579 m
.22423 .80599 L
s
1 .684 0 r
.008 w
.22423 .80599 Mdot
.016 w
.22423 .80599 m
.22433 .80622 L
s
.008 w
.22433 .80622 Mdot
.016 w
.22433 .80622 m
.22453 .80652 L
s
1 .683 0 r
.008 w
.22453 .80652 Mdot
.016 w
.22453 .80652 m
.22486 .80687 L
s
1 .682 0 r
.008 w
.22486 .80687 Mdot
.016 w
.22486 .80687 m
.22534 .80728 L
s
1 .681 0 r
.008 w
.22534 .80728 Mdot
.016 w
.22534 .80728 m
.22596 .80773 L
s
1 .68 0 r
.008 w
.22596 .80773 Mdot
.016 w
.22596 .80773 m
.22668 .8082 L
s
1 .679 0 r
.008 w
.22668 .8082 Mdot
.016 w
.22668 .8082 m
.22742 .80869 L
s
1 .678 0 r
.008 w
.22742 .80869 Mdot
.016 w
.22742 .80869 m
.22819 .80909 L
s
1 .677 0 r
.008 w
.22819 .80909 Mdot
.016 w
.22819 .80909 m
.22896 .8095 L
s
1 .676 0 r
.008 w
.22896 .8095 Mdot
.016 w
.22896 .8095 m
.22967 .80983 L
s
1 .675 0 r
.008 w
.22967 .80983 Mdot
.016 w
.22967 .80983 m
.23027 .81008 L
s
1 .674 0 r
.008 w
.23027 .81008 Mdot
.016 w
.23027 .81008 m
.23076 .81024 L
s
1 .673 0 r
.008 w
.23076 .81024 Mdot
.016 w
.23076 .81024 m
.23111 .81033 L
s
1 .672 0 r
.008 w
.23111 .81033 Mdot
.016 w
.23111 .81033 m
.23134 .81036 L
s
1 .671 0 r
.008 w
.23134 .81036 Mdot
.016 w
.23134 .81036 m
.23145 .81036 L
s
1 .67 0 r
.008 w
.23145 .81036 Mdot
.016 w
.23145 .81036 m
.2315 .81036 L
s
1 .669 0 r
.008 w
.2315 .81036 Mdot
.016 w
.2315 .81036 m
.23155 .81041 L
s
.008 w
.23155 .81041 Mdot
.016 w
.23155 .81041 m
.2317 .81056 L
s
1 .668 0 r
.008 w
.2317 .81056 Mdot
.016 w
.2317 .81056 m
.23202 .81085 L
s
1 .667 0 r
.008 w
.23202 .81085 Mdot
.016 w
.23202 .81085 m
.23256 .8113 L
s
1 .666 0 r
.008 w
.23256 .8113 Mdot
.016 w
.23256 .8113 m
.23335 .81191 L
s
1 .665 0 r
.008 w
.23335 .81191 Mdot
.016 w
.23335 .81191 m
.23439 .81268 L
s
1 .664 0 r
.008 w
.23439 .81268 Mdot
.016 w
.23439 .81268 m
.23563 .81365 L
s
1 .663 0 r
.008 w
.23563 .81365 Mdot
.016 w
.23563 .81365 m
.23717 .81477 L
s
1 .662 0 r
.008 w
.23717 .81477 Mdot
.016 w
.23717 .81477 m
.23898 .81607 L
s
1 .661 0 r
.008 w
.23898 .81607 Mdot
.016 w
.23898 .81607 m
.24089 .81748 L
s
1 .66 0 r
.008 w
.24089 .81748 Mdot
.016 w
.24089 .81748 m
.24294 .81894 L
s
1 .659 0 r
.008 w
.24294 .81894 Mdot
.016 w
.24294 .81894 m
.24501 .82044 L
s
1 .658 0 r
.008 w
.24501 .82044 Mdot
.016 w
.24501 .82044 m
.24703 .82182 L
s
1 .657 0 r
.008 w
.24703 .82182 Mdot
.016 w
.24703 .82182 m
.24889 .82303 L
s
1 .656 0 r
.008 w
.24889 .82303 Mdot
.016 w
.24889 .82303 m
.25066 .82429 L
s
1 .655 0 r
.008 w
.25066 .82429 Mdot
.016 w
.25066 .82429 m
.25232 .82553 L
s
1 .654 0 r
.008 w
.25232 .82553 Mdot
.016 w
.25232 .82553 m
.25372 .82671 L
s
.008 w
.25372 .82671 Mdot
.016 w
.25372 .82671 m
.255 .82785 L
s
1 .653 0 r
.008 w
.255 .82785 Mdot
.016 w
.255 .82785 m
.25604 .82885 L
s
1 .652 0 r
.008 w
.25604 .82885 Mdot
.016 w
.25604 .82885 m
.25701 .82978 L
s
1 .651 0 r
.008 w
.25701 .82978 Mdot
.016 w
.25701 .82978 m
.25765 .83063 L
s
1 .65 0 r
.008 w
.25765 .83063 Mdot
.016 w
.25765 .83063 m
.25824 .83136 L
s
1 .649 0 r
.008 w
.25824 .83136 Mdot
.016 w
.25824 .83136 m
.25877 .83197 L
s
1 .648 0 r
.008 w
.25877 .83197 Mdot
.016 w
.25877 .83197 m
.25915 .83263 L
s
1 .647 0 r
.008 w
.25915 .83263 Mdot
.016 w
.25915 .83263 m
.25954 .83331 L
s
1 .646 0 r
.008 w
.25954 .83331 Mdot
.016 w
.25954 .83331 m
.25996 .83404 L
s
1 .645 0 r
.008 w
.25996 .83404 Mdot
.016 w
.25996 .83404 m
.26047 .83485 L
s
1 .644 0 r
.008 w
.26047 .83485 Mdot
.016 w
.26047 .83485 m
.26103 .8356 L
s
1 .643 0 r
.008 w
.26103 .8356 Mdot
.016 w
.26103 .8356 m
.26175 .8364 L
s
1 .642 0 r
.008 w
.26175 .8364 Mdot
.016 w
.26175 .8364 m
.26261 .83719 L
s
1 .641 0 r
.008 w
.26261 .83719 Mdot
.016 w
.26261 .83719 m
.26372 .83795 L
s
1 .64 0 r
.008 w
.26372 .83795 Mdot
.016 w
.26372 .83795 m
.26475 .83868 L
s
.008 w
.26475 .83868 Mdot
.016 w
.26475 .83868 m
.26606 .83942 L
s
1 .639 0 r
.008 w
.26606 .83942 Mdot
.016 w
.26606 .83942 m
.26752 .84022 L
s
1 .638 0 r
.008 w
.26752 .84022 Mdot
.016 w
.26752 .84022 m
.26919 .8411 L
s
1 .637 0 r
.008 w
.26919 .8411 Mdot
.016 w
.26919 .8411 m
.27112 .84208 L
s
1 .636 0 r
.008 w
.27112 .84208 Mdot
.016 w
.27112 .84208 m
.27331 .84313 L
s
1 .635 0 r
.008 w
.27331 .84313 Mdot
.016 w
.27331 .84313 m
.27565 .84422 L
s
1 .634 0 r
.008 w
.27565 .84422 Mdot
.016 w
.27565 .84422 m
.278 .84525 L
s
1 .633 0 r
.008 w
.278 .84525 Mdot
.016 w
.278 .84525 m
.28033 .84624 L
s
1 .632 0 r
.008 w
.28033 .84624 Mdot
.016 w
.28033 .84624 m
.28264 .84716 L
s
1 .631 0 r
.008 w
.28264 .84716 Mdot
.016 w
.28264 .84716 m
.28469 .84803 L
s
1 .63 0 r
.008 w
.28469 .84803 Mdot
.016 w
.28469 .84803 m
.28656 .84878 L
s
1 .629 0 r
.008 w
.28656 .84878 Mdot
.016 w
.28656 .84878 m
.288 .84943 L
s
1 .628 0 r
.008 w
.288 .84943 Mdot
.016 w
.288 .84943 m
.28917 .85001 L
s
1 .627 0 r
.008 w
.28917 .85001 Mdot
.016 w
.28917 .85001 m
.29013 .85049 L
s
1 .626 0 r
.008 w
.29013 .85049 Mdot
.016 w
.29013 .85049 m
.29088 .85083 L
s
1 .625 0 r
.008 w
.29088 .85083 Mdot
.016 w
.29088 .85083 m
.29141 .85099 L
s
.008 w
.29141 .85099 Mdot
.016 w
.29141 .85099 m
.29178 .851 L
s
1 .624 0 r
.008 w
.29178 .851 Mdot
.016 w
.29178 .851 m
.29204 .85085 L
s
1 .623 0 r
.008 w
.29204 .85085 Mdot
.016 w
.29204 .85085 m
.29224 .8506 L
s
1 .622 0 r
.008 w
.29224 .8506 Mdot
.016 w
.29224 .8506 m
.29254 .85029 L
s
1 .621 0 r
.008 w
.29254 .85029 Mdot
.016 w
.29254 .85029 m
.293 .84999 L
s
1 .62 0 r
.008 w
.293 .84999 Mdot
.016 w
.293 .84999 m
.29364 .84973 L
s
1 .619 0 r
.008 w
.29364 .84973 Mdot
.016 w
.29364 .84973 m
.29449 .8495 L
s
1 .618 0 r
.008 w
.29449 .8495 Mdot
.016 w
.29449 .8495 m
.29546 .84932 L
s
1 .617 0 r
.008 w
.29546 .84932 Mdot
.016 w
.29546 .84932 m
.29661 .84916 L
s
1 .616 0 r
.008 w
.29661 .84916 Mdot
.016 w
.29661 .84916 m
.29785 .84899 L
s
1 .615 0 r
.008 w
.29785 .84899 Mdot
.016 w
.29785 .84899 m
.29912 .84879 L
s
1 .614 0 r
.008 w
.29912 .84879 Mdot
.016 w
.29912 .84879 m
.3003 .84857 L
s
1 .613 0 r
.008 w
.3003 .84857 Mdot
.016 w
.3003 .84857 m
.3013 .84832 L
s
1 .612 0 r
.008 w
.3013 .84832 Mdot
.016 w
.3013 .84832 m
.30206 .84803 L
s
1 .611 0 r
.008 w
.30206 .84803 Mdot
.016 w
.30206 .84803 m
.30256 .84772 L
s
1 .61 0 r
.008 w
.30256 .84772 Mdot
.016 w
.30256 .84772 m
.30285 .84744 L
s
.008 w
.30285 .84744 Mdot
.016 w
.30285 .84744 m
.303 .84725 L
s
1 .609 0 r
.008 w
.303 .84725 Mdot
.016 w
.303 .84725 m
.30299 .84715 L
s
1 .608 0 r
.008 w
.30299 .84715 Mdot
.016 w
.30299 .84715 m
.30286 .84712 L
s
1 .607 0 r
.008 w
.30286 .84712 Mdot
.016 w
.30286 .84712 m
.30277 .8472 L
s
1 .606 0 r
.008 w
.30277 .8472 Mdot
.016 w
.30277 .8472 m
.30281 .84742 L
s
1 .605 0 r
.008 w
.30281 .84742 Mdot
.016 w
.30281 .84742 m
.30305 .84775 L
s
1 .604 0 r
.008 w
.30305 .84775 Mdot
.016 w
.30305 .84775 m
.30356 .84823 L
s
1 .603 0 r
.008 w
.30356 .84823 Mdot
.016 w
.30356 .84823 m
.30444 .84899 L
s
1 .602 0 r
.008 w
.30444 .84899 Mdot
.016 w
.30444 .84899 m
.3057 .84998 L
s
1 .601 0 r
.008 w
.3057 .84998 Mdot
.016 w
.3057 .84998 m
.30745 .85117 L
s
1 .6 0 r
.008 w
.30745 .85117 Mdot
.016 w
.30745 .85117 m
.30952 .85251 L
s
1 .599 0 r
.008 w
.30952 .85251 Mdot
.016 w
.30952 .85251 m
.31209 .85394 L
s
1 .598 0 r
.008 w
.31209 .85394 Mdot
.016 w
.31209 .85394 m
.31486 .85549 L
s
1 .597 0 r
.008 w
.31486 .85549 Mdot
.016 w
.31486 .85549 m
.31804 .85713 L
s
1 .596 0 r
.008 w
.31804 .85713 Mdot
.016 w
.31804 .85713 m
.32122 .85878 L
s
.008 w
.32122 .85878 Mdot
.016 w
.32122 .85878 m
.32466 .86039 L
s
1 .595 0 r
.008 w
.32466 .86039 Mdot
.016 w
.32466 .86039 m
.328 .86195 L
s
1 .594 0 r
.008 w
.328 .86195 Mdot
.016 w
.328 .86195 m
.33143 .86341 L
s
1 .593 0 r
.008 w
.33143 .86341 Mdot
.016 w
.33143 .86341 m
.33481 .86468 L
s
1 .592 0 r
.008 w
.33481 .86468 Mdot
.016 w
.33481 .86468 m
.33821 .86589 L
s
1 .591 0 r
.008 w
.33821 .86589 Mdot
.016 w
.33821 .86589 m
.3413 .86694 L
s
1 .59 0 r
.008 w
.3413 .86694 Mdot
.016 w
.3413 .86694 m
.34443 .86789 L
s
1 .589 0 r
.008 w
.34443 .86789 Mdot
.016 w
.34443 .86789 m
.34747 .86876 L
s
1 .588 0 r
.008 w
.34747 .86876 Mdot
.016 w
.34747 .86876 m
.35045 .86956 L
s
1 .587 0 r
.008 w
.35045 .86956 Mdot
.016 w
.35045 .86956 m
.35331 .8703 L
s
1 .586 0 r
.008 w
.35331 .8703 Mdot
.016 w
.35331 .8703 m
.3561 .87099 L
s
1 .585 0 r
.008 w
.3561 .87099 Mdot
.016 w
.3561 .87099 m
.35879 .87165 L
s
1 .584 0 r
.008 w
.35879 .87165 Mdot
.016 w
.35879 .87165 m
.36148 .87231 L
s
1 .583 0 r
.008 w
.36148 .87231 Mdot
.016 w
.36148 .87231 m
.36414 .87296 L
s
1 .582 0 r
.008 w
.36414 .87296 Mdot
.016 w
.36414 .87296 m
.36667 .87363 L
s
1 .581 0 r
.008 w
.36667 .87363 Mdot
.016 w
.36667 .87363 m
.36919 .87434 L
s
.008 w
.36919 .87434 Mdot
.016 w
.36919 .87434 m
.37167 .8751 L
s
1 .58 0 r
.008 w
.37167 .8751 Mdot
.016 w
.37167 .8751 m
.37396 .87588 L
s
1 .579 0 r
.008 w
.37396 .87588 Mdot
.016 w
.37396 .87588 m
.37608 .87666 L
s
1 .578 0 r
.008 w
.37608 .87666 Mdot
.016 w
.37608 .87666 m
.37795 .87738 L
s
1 .577 0 r
.008 w
.37795 .87738 Mdot
.016 w
.37795 .87738 m
.3795 .87803 L
s
1 .576 0 r
.008 w
.3795 .87803 Mdot
.016 w
.3795 .87803 m
.38076 .87858 L
s
1 .575 0 r
.008 w
.38076 .87858 Mdot
.016 w
.38076 .87858 m
.38175 .879 L
s
1 .574 0 r
.008 w
.38175 .879 Mdot
.016 w
.38175 .879 m
.38249 .87926 L
s
1 .573 0 r
.008 w
.38249 .87926 Mdot
.016 w
.38249 .87926 m
.38306 .87938 L
s
1 .572 0 r
.008 w
.38306 .87938 Mdot
.016 w
.38306 .87938 m
.3835 .87936 L
s
1 .571 0 r
.008 w
.3835 .87936 Mdot
.016 w
.3835 .87936 m
.38388 .87918 L
s
1 .57 0 r
.008 w
.38388 .87918 Mdot
.016 w
.38388 .87918 m
.38433 .87882 L
s
1 .569 0 r
.008 w
.38433 .87882 Mdot
.016 w
.38433 .87882 m
.3849 .87832 L
s
1 .568 0 r
.008 w
.3849 .87832 Mdot
.016 w
.3849 .87832 m
.38566 .87769 L
s
1 .567 0 r
.008 w
.38566 .87769 Mdot
.016 w
.38566 .87769 m
.38656 .87695 L
s
1 .566 0 r
.008 w
.38656 .87695 Mdot
.016 w
.38656 .87695 m
.38769 .87611 L
s
.008 w
.38769 .87611 Mdot
.016 w
.38769 .87611 m
.38893 .8752 L
s
1 .565 0 r
.008 w
.38893 .8752 Mdot
.016 w
.38893 .8752 m
.39029 .87427 L
s
1 .564 0 r
.008 w
.39029 .87427 Mdot
.016 w
.39029 .87427 m
.39173 .87337 L
s
1 .563 0 r
.008 w
.39173 .87337 Mdot
.016 w
.39173 .87337 m
.39319 .87245 L
s
1 .562 0 r
.008 w
.39319 .87245 Mdot
.016 w
.39319 .87245 m
.3946 .87187 L
s
1 .561 0 r
.008 w
.3946 .87187 Mdot
.016 w
.3946 .87187 m
.39585 .87124 L
s
1 .56 0 r
.008 w
.39585 .87124 Mdot
.016 w
.39585 .87124 m
.39682 .87079 L
s
1 .559 0 r
.008 w
.39682 .87079 Mdot
.016 w
.39682 .87079 m
.39752 .87052 L
s
1 .558 0 r
.008 w
.39752 .87052 Mdot
.016 w
.39752 .87052 m
.39794 .87048 L
s
1 .557 0 r
.008 w
.39794 .87048 Mdot
.016 w
.39794 .87048 m
.39809 .87064 L
s
1 .556 0 r
.008 w
.39809 .87064 Mdot
.016 w
.39809 .87064 m
.39799 .87097 L
s
1 .555 0 r
.008 w
.39799 .87097 Mdot
.016 w
.39799 .87097 m
.39769 .87142 L
s
1 .554 0 r
.008 w
.39769 .87142 Mdot
.016 w
.39769 .87142 m
.39735 .87203 L
s
1 .553 0 r
.008 w
.39735 .87203 Mdot
.016 w
.39735 .87203 m
.39704 .87272 L
s
1 .552 0 r
.008 w
.39704 .87272 Mdot
.016 w
.39704 .87272 m
.39685 .8734 L
s
1 .551 0 r
.008 w
.39685 .8734 Mdot
.016 w
.39685 .8734 m
.39683 .87401 L
s
.008 w
.39683 .87401 Mdot
.016 w
.39683 .87401 m
.39704 .87452 L
s
1 .55 0 r
.008 w
.39704 .87452 Mdot
.016 w
.39704 .87452 m
.39749 .87499 L
s
1 .549 0 r
.008 w
.39749 .87499 Mdot
.016 w
.39749 .87499 m
.39814 .87542 L
s
1 .548 0 r
.008 w
.39814 .87542 Mdot
.016 w
.39814 .87542 m
.39899 .87576 L
s
1 .547 0 r
.008 w
.39899 .87576 Mdot
.016 w
.39899 .87576 m
.39984 .8761 L
s
1 .546 0 r
.008 w
.39984 .8761 Mdot
.016 w
.39984 .8761 m
.40072 .87647 L
s
1 .545 0 r
.008 w
.40072 .87647 Mdot
.016 w
.40072 .87647 m
.40149 .87686 L
s
1 .544 0 r
.008 w
.40149 .87686 Mdot
.016 w
.40149 .87686 m
.40212 .87724 L
s
1 .543 0 r
.008 w
.40212 .87724 Mdot
.016 w
.40212 .87724 m
.40255 .87761 L
s
1 .542 0 r
.008 w
.40255 .87761 Mdot
.016 w
.40255 .87761 m
.40274 .87799 L
s
1 .541 0 r
.008 w
.40274 .87799 Mdot
.016 w
.40274 .87799 m
.40275 .87824 L
s
1 .54 0 r
.008 w
.40275 .87824 Mdot
.016 w
.40275 .87824 m
.40259 .87839 L
s
1 .539 0 r
.008 w
.40259 .87839 Mdot
.016 w
.40259 .87839 m
.40231 .87837 L
s
1 .538 0 r
.008 w
.40231 .87837 Mdot
.016 w
.40231 .87837 m
.40194 .8782 L
s
1 .537 0 r
.008 w
.40194 .8782 Mdot
.016 w
.40194 .8782 m
.40135 .87786 L
s
.008 w
.40135 .87786 Mdot
.016 w
.40135 .87786 m
.40087 .87722 L
s
1 .536 0 r
.008 w
.40087 .87722 Mdot
.016 w
.40087 .87722 m
.40031 .87642 L
s
1 .535 0 r
.008 w
.40031 .87642 Mdot
.016 w
.40031 .87642 m
.39977 .8756 L
s
1 .534 0 r
.008 w
.39977 .8756 Mdot
.016 w
.39977 .8756 m
.39932 .87447 L
s
1 .533 0 r
.008 w
.39932 .87447 Mdot
.016 w
.39932 .87447 m
.39901 .87325 L
s
1 .532 0 r
.008 w
.39901 .87325 Mdot
.016 w
.39901 .87325 m
.39885 .87187 L
s
1 .531 0 r
.008 w
.39885 .87187 Mdot
.016 w
.39885 .87187 m
.39882 .87062 L
s
1 .53 0 r
.008 w
.39882 .87062 Mdot
.016 w
.39882 .87062 m
.39884 .86945 L
s
1 .529 0 r
.008 w
.39884 .86945 Mdot
.016 w
.39884 .86945 m
.39889 .8685 L
s
1 .528 0 r
.008 w
.39889 .8685 Mdot
.016 w
.39889 .8685 m
.39893 .86779 L
s
1 .527 0 r
.008 w
.39893 .86779 Mdot
.016 w
.39893 .86779 m
.39889 .86734 L
s
1 .526 0 r
.008 w
.39889 .86734 Mdot
.016 w
.39889 .86734 m
.39873 .8671 L
s
1 .525 0 r
.008 w
.39873 .8671 Mdot
.016 w
.39873 .8671 m
.39845 .8671 L
s
1 .524 0 r
.008 w
.39845 .8671 Mdot
.016 w
.39845 .8671 m
.39808 .86738 L
s
1 .523 0 r
.008 w
.39808 .86738 Mdot
.016 w
.39808 .86738 m
.39769 .86788 L
s
1 .522 0 r
.008 w
.39769 .86788 Mdot
.016 w
.39769 .86788 m
.39731 .86852 L
s
.008 w
.39731 .86852 Mdot
.016 w
.39731 .86852 m
.39697 .86928 L
s
1 .521 0 r
.008 w
.39697 .86928 Mdot
.016 w
.39697 .86928 m
.39674 .87019 L
s
1 .52 0 r
.008 w
.39674 .87019 Mdot
.016 w
.39674 .87019 m
.39662 .87117 L
s
1 .519 0 r
.008 w
.39662 .87117 Mdot
.016 w
.39662 .87117 m
.39664 .87227 L
s
1 .518 0 r
.008 w
.39664 .87227 Mdot
.016 w
.39664 .87227 m
.39682 .87343 L
s
1 .517 0 r
.008 w
.39682 .87343 Mdot
.016 w
.39682 .87343 m
.39718 .87465 L
s
1 .516 0 r
.008 w
.39718 .87465 Mdot
.016 w
.39718 .87465 m
.39774 .87596 L
s
1 .515 0 r
.008 w
.39774 .87596 Mdot
.016 w
.39774 .87596 m
.39852 .87734 L
s
1 .514 0 r
.008 w
.39852 .87734 Mdot
.016 w
.39852 .87734 m
.39948 .87876 L
s
1 .513 0 r
.008 w
.39948 .87876 Mdot
.016 w
.39948 .87876 m
.40068 .8802 L
s
1 .512 0 r
.008 w
.40068 .8802 Mdot
.016 w
.40068 .8802 m
.4021 .88163 L
s
1 .511 0 r
.008 w
.4021 .88163 Mdot
.016 w
.4021 .88163 m
.40371 .88307 L
s
1 .51 0 r
.008 w
.40371 .88307 Mdot
.016 w
.40371 .88307 m
.40556 .88451 L
s
1 .509 0 r
.008 w
.40556 .88451 Mdot
.016 w
.40556 .88451 m
.40755 .88591 L
s
1 .508 0 r
.008 w
.40755 .88591 Mdot
.016 w
.40755 .88591 m
.40979 .88731 L
s
1 .507 0 r
.008 w
.40979 .88731 Mdot
.016 w
.40979 .88731 m
.4123 .88864 L
s
.008 w
.4123 .88864 Mdot
.016 w
.4123 .88864 m
.41484 .88981 L
s
1 .506 0 r
.008 w
.41484 .88981 Mdot
.016 w
.41484 .88981 m
.41757 .8909 L
s
1 .505 0 r
.008 w
.41757 .8909 Mdot
.016 w
.41757 .8909 m
.42045 .89193 L
s
1 .504 0 r
.008 w
.42045 .89193 Mdot
.016 w
.42045 .89193 m
.42338 .89293 L
s
1 .503 0 r
.008 w
.42338 .89293 Mdot
.016 w
.42338 .89293 m
.42632 .89387 L
s
1 .502 0 r
.008 w
.42632 .89387 Mdot
.016 w
.42632 .89387 m
.42912 .89479 L
s
1 .501 0 r
.008 w
.42912 .89479 Mdot
.016 w
.42912 .89479 m
.43193 .89565 L
s
1 .5 0 r
.008 w
.43193 .89565 Mdot
.016 w
.43193 .89565 m
.43457 .89644 L
s
1 .499 0 r
.008 w
.43457 .89644 Mdot
.016 w
.43457 .89644 m
.43708 .89716 L
s
1 .498 0 r
.008 w
.43708 .89716 Mdot
.016 w
.43708 .89716 m
.4392 .89778 L
s
1 .497 0 r
.008 w
.4392 .89778 Mdot
.016 w
.4392 .89778 m
.44112 .89827 L
s
1 .496 0 r
.008 w
.44112 .89827 Mdot
.016 w
.44112 .89827 m
.44283 .89863 L
s
1 .495 0 r
.008 w
.44283 .89863 Mdot
.016 w
.44283 .89863 m
.44431 .8989 L
s
1 .494 0 r
.008 w
.44431 .8989 Mdot
.016 w
.44431 .8989 m
.44563 .89916 L
s
1 .493 0 r
.008 w
.44563 .89916 Mdot
.016 w
.44563 .89916 m
.44684 .89943 L
s
.008 w
.44684 .89943 Mdot
.016 w
.44684 .89943 m
.44803 .89971 L
s
1 .492 0 r
.008 w
.44803 .89971 Mdot
.016 w
.44803 .89971 m
.44909 .89995 L
s
1 .491 0 r
.008 w
.44909 .89995 Mdot
.016 w
.44909 .89995 m
.45026 .90018 L
s
1 .49 0 r
.008 w
.45026 .90018 Mdot
.016 w
.45026 .90018 m
.45153 .90034 L
s
1 .489 0 r
.008 w
.45153 .90034 Mdot
.016 w
.45153 .90034 m
.45284 .90039 L
s
1 .488 0 r
.008 w
.45284 .90039 Mdot
.016 w
.45284 .90039 m
.45425 .90033 L
s
1 .487 0 r
.008 w
.45425 .90033 Mdot
.016 w
.45425 .90033 m
.45576 .90018 L
s
1 .486 0 r
.008 w
.45576 .90018 Mdot
.016 w
.45576 .90018 m
.45727 .89999 L
s
1 .485 0 r
.008 w
.45727 .89999 Mdot
.016 w
.45727 .89999 m
.45879 .89985 L
s
1 .484 0 r
.008 w
.45879 .89985 Mdot
.016 w
.45879 .89985 m
.4603 .89982 L
s
1 .483 0 r
.008 w
.4603 .89982 Mdot
.016 w
.4603 .89982 m
.4618 .8999 L
s
1 .482 0 r
.008 w
.4618 .8999 Mdot
.016 w
.4618 .8999 m
.46325 .90005 L
s
1 .481 0 r
.008 w
.46325 .90005 Mdot
.016 w
.46325 .90005 m
.46475 .90013 L
s
1 .48 0 r
.008 w
.46475 .90013 Mdot
.016 w
.46475 .90013 m
.46628 .90021 L
s
1 .479 0 r
.008 w
.46628 .90021 Mdot
.016 w
.46628 .90021 m
.46789 .9003 L
s
1 .478 0 r
.008 w
.46789 .9003 Mdot
.016 w
.46789 .9003 m
.46957 .90041 L
s
.008 w
.46957 .90041 Mdot
.016 w
.46957 .90041 m
.47133 .90054 L
s
1 .477 0 r
.008 w
.47133 .90054 Mdot
.016 w
.47133 .90054 m
.47316 .90068 L
s
1 .476 0 r
.008 w
.47316 .90068 Mdot
.016 w
.47316 .90068 m
.47518 .90087 L
s
1 .475 0 r
.008 w
.47518 .90087 Mdot
.016 w
.47518 .90087 m
.47731 .90112 L
s
1 .474 0 r
.008 w
.47731 .90112 Mdot
.016 w
.47731 .90112 m
.47956 .90137 L
s
1 .473 0 r
.008 w
.47956 .90137 Mdot
.016 w
.47956 .90137 m
.48186 .90156 L
s
1 .472 0 r
.008 w
.48186 .90156 Mdot
.016 w
.48186 .90156 m
.48426 .90165 L
s
1 .471 0 r
.008 w
.48426 .90165 Mdot
.016 w
.48426 .90165 m
.48669 .90161 L
s
1 .47 0 r
.008 w
.48669 .90161 Mdot
.016 w
.48669 .90161 m
.48918 .90145 L
s
1 .469 0 r
.008 w
.48918 .90145 Mdot
.016 w
.48918 .90145 m
.49199 .90124 L
s
1 .468 0 r
.008 w
.49199 .90124 Mdot
.016 w
.49199 .90124 m
.49432 .90106 L
s
1 .467 0 r
.008 w
.49432 .90106 Mdot
.016 w
.49432 .90106 m
.49675 .90089 L
s
1 .466 0 r
.008 w
.49675 .90089 Mdot
.016 w
.49675 .90089 m
.49905 .90075 L
s
1 .465 0 r
.008 w
.49905 .90075 Mdot
.016 w
.49905 .90075 m
.50108 .90067 L
s
1 .464 0 r
.008 w
.50108 .90067 Mdot
.016 w
.50108 .90067 m
.50272 .90063 L
s
1 .463 0 r
.008 w
.50272 .90063 Mdot
.016 w
.50272 .90063 m
.50395 .90063 L
s
.008 w
.50395 .90063 Mdot
.016 w
.50395 .90063 m
.50472 .90064 L
s
1 .462 0 r
.008 w
.50472 .90064 Mdot
.016 w
.50472 .90064 m
.50521 .90063 L
s
1 .461 0 r
.008 w
.50521 .90063 Mdot
.016 w
.50521 .90063 m
.50544 .90061 L
s
1 .46 0 r
.008 w
.50544 .90061 Mdot
.016 w
.50544 .90061 m
.50548 .90062 L
s
1 .459 0 r
.008 w
.50548 .90062 Mdot
.016 w
.50548 .90062 m
.50539 .90067 L
s
1 .458 0 r
.008 w
.50539 .90067 Mdot
.016 w
.50539 .90067 m
.50511 .90072 L
s
1 .457 0 r
.008 w
.50511 .90072 Mdot
.016 w
.50511 .90072 m
.50473 .90076 L
s
1 .456 0 r
.008 w
.50473 .90076 Mdot
.016 w
.50473 .90076 m
.50434 .90073 L
s
1 .455 0 r
.008 w
.50434 .90073 Mdot
.016 w
.50434 .90073 m
.50399 .90063 L
s
1 .454 0 r
.008 w
.50399 .90063 Mdot
.016 w
.50399 .90063 m
.50367 .90043 L
s
1 .453 0 r
.008 w
.50367 .90043 Mdot
.016 w
.50367 .90043 m
.50347 .90011 L
s
1 .452 0 r
.008 w
.50347 .90011 Mdot
.016 w
.50347 .90011 m
.50333 .89969 L
s
1 .451 0 r
.008 w
.50333 .89969 Mdot
.016 w
.50333 .89969 m
.50334 .8992 L
s
1 .45 0 r
.008 w
.50334 .8992 Mdot
.016 w
.50334 .8992 m
.50354 .89867 L
s
1 .449 0 r
.008 w
.50354 .89867 Mdot
.016 w
.50354 .89867 m
.50391 .89814 L
s
.008 w
.50391 .89814 Mdot
.016 w
.50391 .89814 m
.50437 .8976 L
s
1 .448 0 r
.008 w
.50437 .8976 Mdot
.016 w
.50437 .8976 m
.50465 .89702 L
s
1 .447 0 r
.008 w
.50465 .89702 Mdot
.016 w
.50465 .89702 m
.50481 .89636 L
s
1 .446 0 r
.008 w
.50481 .89636 Mdot
.016 w
.50481 .89636 m
.50486 .89569 L
s
1 .445 0 r
.008 w
.50486 .89569 Mdot
.016 w
.50486 .89569 m
.50481 .89504 L
s
1 .444 0 r
.008 w
.50481 .89504 Mdot
.016 w
.50481 .89504 m
.50477 .89442 L
s
1 .443 0 r
.008 w
.50477 .89442 Mdot
.016 w
.50477 .89442 m
.50472 .89389 L
s
1 .442 0 r
.008 w
.50472 .89389 Mdot
.016 w
.50472 .89389 m
.50465 .89344 L
s
1 .441 0 r
.008 w
.50465 .89344 Mdot
.016 w
.50465 .89344 m
.50465 .89314 L
s
1 .44 0 r
.008 w
.50465 .89314 Mdot
.016 w
.50465 .89314 m
.50466 .89295 L
s
1 .439 0 r
.008 w
.50466 .89295 Mdot
.016 w
.50466 .89295 m
.50463 .89288 L
s
1 .438 0 r
.008 w
.50463 .89288 Mdot
.016 w
.50463 .89288 m
.50454 .89294 L
s
1 .437 0 r
.008 w
.50454 .89294 Mdot
.016 w
.50454 .89294 m
.50434 .89308 L
s
1 .436 0 r
.008 w
.50434 .89308 Mdot
.016 w
.50434 .89308 m
.50398 .8932 L
s
1 .435 0 r
.008 w
.50398 .8932 Mdot
.016 w
.50398 .8932 m
.50346 .89323 L
s
1 .434 0 r
.008 w
.50346 .89323 Mdot
.016 w
.50346 .89323 m
.50273 .89322 L
s
.008 w
.50273 .89322 Mdot
.016 w
.50273 .89322 m
.50174 .8932 L
s
1 .433 0 r
.008 w
.50174 .8932 Mdot
.016 w
.50174 .8932 m
.50049 .89319 L
s
1 .432 0 r
.008 w
.50049 .89319 Mdot
.016 w
.50049 .89319 m
.49902 .8932 L
s
1 .431 0 r
.008 w
.49902 .8932 Mdot
.016 w
.49902 .8932 m
.49733 .89329 L
s
1 .43 0 r
.008 w
.49733 .89329 Mdot
.016 w
.49733 .89329 m
.49552 .89346 L
s
1 .429 0 r
.008 w
.49552 .89346 Mdot
.016 w
.49552 .89346 m
.49343 .89364 L
s
1 .428 0 r
.008 w
.49343 .89364 Mdot
.016 w
.49343 .89364 m
.49099 .89381 L
s
1 .427 0 r
.008 w
.49099 .89381 Mdot
.016 w
.49099 .89381 m
.48874 .89395 L
s
1 .426 0 r
.008 w
.48874 .89395 Mdot
.016 w
.48874 .89395 m
.48625 .89411 L
s
1 .425 0 r
.008 w
.48625 .89411 Mdot
.016 w
.48625 .89411 m
.48366 .89426 L
s
1 .424 0 r
.008 w
.48366 .89426 Mdot
.016 w
.48366 .89426 m
.48098 .89438 L
s
1 .423 0 r
.008 w
.48098 .89438 Mdot
.016 w
.48098 .89438 m
.47827 .89457 L
s
1 .422 0 r
.008 w
.47827 .89457 Mdot
.016 w
.47827 .89457 m
.47547 .89483 L
s
1 .421 0 r
.008 w
.47547 .89483 Mdot
.016 w
.47547 .89483 m
.47274 .89516 L
s
1 .42 0 r
.008 w
.47274 .89516 Mdot
.016 w
.47274 .89516 m
.46997 .89545 L
s
1 .419 0 r
.008 w
.46997 .89545 Mdot
.016 w
.46997 .89545 m
.46719 .89584 L
s
.008 w
.46719 .89584 Mdot
.016 w
.46719 .89584 m
.46448 .89609 L
s
1 .418 0 r
.008 w
.46448 .89609 Mdot
.016 w
.46448 .89609 m
.46166 .89625 L
s
1 .417 0 r
.008 w
.46166 .89625 Mdot
.016 w
.46166 .89625 m
.45888 .8963 L
s
1 .416 0 r
.008 w
.45888 .8963 Mdot
.016 w
.45888 .8963 m
.45612 .89633 L
s
1 .415 0 r
.008 w
.45612 .89633 Mdot
.016 w
.45612 .89633 m
.45341 .89635 L
s
1 .414 0 r
.008 w
.45341 .89635 Mdot
.016 w
.45341 .89635 m
.45069 .89639 L
s
1 .413 0 r
.008 w
.45069 .89639 Mdot
.016 w
.45069 .89639 m
.44812 .89645 L
s
1 .412 0 r
.008 w
.44812 .89645 Mdot
.016 w
.44812 .89645 m
.44552 .89651 L
s
1 .411 0 r
.008 w
.44552 .89651 Mdot
.016 w
.44552 .89651 m
.44319 .89657 L
s
1 .41 0 r
.008 w
.44319 .89657 Mdot
.016 w
.44319 .89657 m
.44084 .8965 L
s
1 .409 0 r
.008 w
.44084 .8965 Mdot
.016 w
.44084 .8965 m
.43841 .89631 L
s
1 .408 0 r
.008 w
.43841 .89631 Mdot
.016 w
.43841 .89631 m
.43636 .89597 L
s
1 .407 0 r
.008 w
.43636 .89597 Mdot
.016 w
.43636 .89597 m
.43428 .89552 L
s
1 .406 0 r
.008 w
.43428 .89552 Mdot
.016 w
.43428 .89552 m
.43226 .89497 L
s
1 .405 0 r
.008 w
.43226 .89497 Mdot
.016 w
.43226 .89497 m
.4302 .89435 L
s
1 .404 0 r
.008 w
.4302 .89435 Mdot
.016 w
.4302 .89435 m
.42813 .89368 L
s
.008 w
.42813 .89368 Mdot
.016 w
.42813 .89368 m
.42609 .89301 L
s
1 .403 0 r
.008 w
.42609 .89301 Mdot
.016 w
.42609 .89301 m
.42401 .89231 L
s
1 .402 0 r
.008 w
.42401 .89231 Mdot
.016 w
.42401 .89231 m
.42185 .8916 L
s
1 .401 0 r
.008 w
.42185 .8916 Mdot
.016 w
.42185 .8916 m
.4196 .89087 L
s
1 .4 0 r
.008 w
.4196 .89087 Mdot
.016 w
.4196 .89087 m
.41735 .89009 L
s
1 .399 0 r
.008 w
.41735 .89009 Mdot
.016 w
.41735 .89009 m
.41493 .88925 L
s
1 .398 0 r
.008 w
.41493 .88925 Mdot
.016 w
.41493 .88925 m
.41228 .88836 L
s
1 .397 0 r
.008 w
.41228 .88836 Mdot
.016 w
.41228 .88836 m
.40956 .88745 L
s
1 .396 0 r
.008 w
.40956 .88745 Mdot
.016 w
.40956 .88745 m
.4067 .88655 L
s
1 .395 0 r
.008 w
.4067 .88655 Mdot
.016 w
.4067 .88655 m
.40378 .88565 L
s
1 .394 0 r
.008 w
.40378 .88565 Mdot
.016 w
.40378 .88565 m
.40068 .88475 L
s
1 .393 0 r
.008 w
.40068 .88475 Mdot
.016 w
.40068 .88475 m
.39755 .88386 L
s
1 .392 0 r
.008 w
.39755 .88386 Mdot
.016 w
.39755 .88386 m
.39446 .88294 L
s
1 .391 0 r
.008 w
.39446 .88294 Mdot
.016 w
.39446 .88294 m
.39124 .88197 L
s
1 .39 0 r
.008 w
.39124 .88197 Mdot
.016 w
.39124 .88197 m
.38814 .88097 L
s
.008 w
.38814 .88097 Mdot
.016 w
.38814 .88097 m
.38497 .87994 L
s
1 .389 0 r
.008 w
.38497 .87994 Mdot
.016 w
.38497 .87994 m
.38189 .87886 L
s
1 .388 0 r
.008 w
.38189 .87886 Mdot
.016 w
.38189 .87886 m
.37882 .87778 L
s
1 .387 0 r
.008 w
.37882 .87778 Mdot
.016 w
.37882 .87778 m
.37564 .87671 L
s
1 .386 0 r
.008 w
.37564 .87671 Mdot
.016 w
.37564 .87671 m
.37257 .87567 L
s
1 .385 0 r
.008 w
.37257 .87567 Mdot
.016 w
.37257 .87567 m
.36951 .87475 L
s
1 .384 0 r
.008 w
.36951 .87475 Mdot
.016 w
.36951 .87475 m
.36649 .87386 L
s
1 .383 0 r
.008 w
.36649 .87386 Mdot
.016 w
.36649 .87386 m
.36344 .87301 L
s
1 .382 0 r
.008 w
.36344 .87301 Mdot
.016 w
.36344 .87301 m
.36052 .87217 L
s
1 .381 0 r
.008 w
.36052 .87217 Mdot
.016 w
.36052 .87217 m
.35762 .8713 L
s
1 .38 0 r
.008 w
.35762 .8713 Mdot
.016 w
.35762 .8713 m
.35458 .87037 L
s
1 .379 0 r
.008 w
.35458 .87037 Mdot
.016 w
.35458 .87037 m
.35148 .86941 L
s
1 .378 0 r
.008 w
.35148 .86941 Mdot
.016 w
.35148 .86941 m
.34851 .8684 L
s
1 .377 0 r
.008 w
.34851 .8684 Mdot
.016 w
.34851 .8684 m
.34541 .86736 L
s
1 .376 0 r
.008 w
.34541 .86736 Mdot
.016 w
.34541 .86736 m
.3422 .86632 L
s
1 .375 0 r
.008 w
.3422 .86632 Mdot
.016 w
.3422 .86632 m
.33925 .86535 L
s
.008 w
.33925 .86535 Mdot
.016 w
.33925 .86535 m
.3364 .8644 L
s
1 .374 0 r
.008 w
.3364 .8644 Mdot
.016 w
.3364 .8644 m
.33348 .86349 L
s
1 .373 0 r
.008 w
.33348 .86349 Mdot
.016 w
.33348 .86349 m
.33096 .86264 L
s
1 .372 0 r
.008 w
.33096 .86264 Mdot
.016 w
.33096 .86264 m
.3283 .86184 L
s
1 .371 0 r
.008 w
.3283 .86184 Mdot
.016 w
.3283 .86184 m
.32622 .86114 L
s
1 .37 0 r
.008 w
.32622 .86114 Mdot
.016 w
.32622 .86114 m
.32436 .86056 L
s
1 .369 0 r
.008 w
.32436 .86056 Mdot
.016 w
.32436 .86056 m
.32266 .86012 L
s
1 .368 0 r
.008 w
.32266 .86012 Mdot
.016 w
.32266 .86012 m
.32121 .85983 L
s
1 .367 0 r
.008 w
.32121 .85983 Mdot
.016 w
.32121 .85983 m
.32006 .85966 L
s
1 .366 0 r
.008 w
.32006 .85966 Mdot
.016 w
.32006 .85966 m
.31921 .85961 L
s
1 .365 0 r
.008 w
.31921 .85961 Mdot
.016 w
.31921 .85961 m
.31856 .85958 L
s
1 .364 0 r
.008 w
.31856 .85958 Mdot
.016 w
.31856 .85958 m
.31798 .8595 L
s
1 .363 0 r
.008 w
.31798 .8595 Mdot
.016 w
.31798 .8595 m
.31736 .85931 L
s
1 .362 0 r
.008 w
.31736 .85931 Mdot
.016 w
.31736 .85931 m
.31666 .85896 L
s
1 .361 0 r
.008 w
.31666 .85896 Mdot
.016 w
.31666 .85896 m
.31582 .85845 L
s
1 .36 0 r
.008 w
.31582 .85845 Mdot
.016 w
.31582 .85845 m
.31477 .85777 L
s
.008 w
.31477 .85777 Mdot
.016 w
.31477 .85777 m
.31345 .85695 L
s
1 .359 0 r
.008 w
.31345 .85695 Mdot
.016 w
.31345 .85695 m
.31208 .85607 L
s
1 .358 0 r
.008 w
.31208 .85607 Mdot
.016 w
.31208 .85607 m
.3106 .85514 L
s
1 .357 0 r
.008 w
.3106 .85514 Mdot
.016 w
.3106 .85514 m
.30914 .85418 L
s
1 .356 0 r
.008 w
.30914 .85418 Mdot
.016 w
.30914 .85418 m
.30776 .85325 L
s
1 .355 0 r
.008 w
.30776 .85325 Mdot
.016 w
.30776 .85325 m
.30643 .85238 L
s
1 .354 0 r
.008 w
.30643 .85238 Mdot
.016 w
.30643 .85238 m
.30513 .85163 L
s
1 .353 0 r
.008 w
.30513 .85163 Mdot
.016 w
.30513 .85163 m
.30405 .85102 L
s
1 .352 0 r
.008 w
.30405 .85102 Mdot
.016 w
.30405 .85102 m
.30317 .85057 L
s
1 .351 0 r
.008 w
.30317 .85057 Mdot
.016 w
.30317 .85057 m
.30249 .8503 L
s
1 .35 0 r
.008 w
.30249 .8503 Mdot
.016 w
.30249 .8503 m
.30204 .85017 L
s
1 .349 0 r
.008 w
.30204 .85017 Mdot
.016 w
.30204 .85017 m
.3018 .85012 L
s
1 .348 0 r
.008 w
.3018 .85012 Mdot
.016 w
.3018 .85012 m
.30175 .85012 L
s
1 .347 0 r
.008 w
.30175 .85012 Mdot
.016 w
.30175 .85012 m
.30184 .85008 L
s
1 .346 0 r
.008 w
.30184 .85008 Mdot
.016 w
.30184 .85008 m
.302 .84993 L
s
.008 w
.302 .84993 Mdot
.016 w
.302 .84993 m
.30217 .84962 L
s
1 .345 0 r
.008 w
.30217 .84962 Mdot
.016 w
.30217 .84962 m
.3023 .84919 L
s
1 .344 0 r
.008 w
.3023 .84919 Mdot
.016 w
.3023 .84919 m
.30236 .84867 L
s
1 .343 0 r
.008 w
.30236 .84867 Mdot
.016 w
.30236 .84867 m
.30236 .84807 L
s
1 .342 0 r
.008 w
.30236 .84807 Mdot
.016 w
.30236 .84807 m
.30232 .8475 L
s
1 .341 0 r
.008 w
.30232 .8475 Mdot
.016 w
.30232 .8475 m
.30231 .84703 L
s
1 .34 0 r
.008 w
.30231 .84703 Mdot
.016 w
.30231 .84703 m
.30251 .84668 L
s
1 .339 0 r
.008 w
.30251 .84668 Mdot
.016 w
.30251 .84668 m
.30268 .84648 L
s
1 .338 0 r
.008 w
.30268 .84648 Mdot
.016 w
.30268 .84648 m
.30288 .84642 L
s
1 .337 0 r
.008 w
.30288 .84642 Mdot
.016 w
.30288 .84642 m
.30305 .84653 L
s
1 .336 0 r
.008 w
.30305 .84653 Mdot
.016 w
.30305 .84653 m
.30316 .84682 L
s
1 .335 0 r
.008 w
.30316 .84682 Mdot
.016 w
.30316 .84682 m
.30316 .84721 L
s
1 .334 0 r
.008 w
.30316 .84721 Mdot
.016 w
.30316 .84721 m
.30296 .84766 L
s
1 .333 0 r
.008 w
.30296 .84766 Mdot
.016 w
.30296 .84766 m
.30249 .84812 L
s
1 .332 0 r
.008 w
.30249 .84812 Mdot
.016 w
.30249 .84812 m
.30175 .84862 L
s
1 .331 0 r
.008 w
.30175 .84862 Mdot
.016 w
.30175 .84862 m
.30069 .84906 L
s
.008 w
.30069 .84906 Mdot
.016 w
.30069 .84906 m
.29932 .84935 L
s
1 .33 0 r
.008 w
.29932 .84935 Mdot
.016 w
.29932 .84935 m
.29771 .84942 L
s
1 .329 0 r
.008 w
.29771 .84942 Mdot
.016 w
.29771 .84942 m
.29574 .84922 L
s
1 .328 0 r
.008 w
.29574 .84922 Mdot
.016 w
.29574 .84922 m
.29358 .84874 L
s
1 .327 0 r
.008 w
.29358 .84874 Mdot
.016 w
.29358 .84874 m
.29123 .84808 L
s
1 .326 0 r
.008 w
.29123 .84808 Mdot
.016 w
.29123 .84808 m
.28853 .84724 L
s
1 .325 0 r
.008 w
.28853 .84724 Mdot
.016 w
.28853 .84724 m
.2857 .84628 L
s
1 .324 0 r
.008 w
.2857 .84628 Mdot
.016 w
.2857 .84628 m
.2828 .84535 L
s
1 .323 0 r
.008 w
.2828 .84535 Mdot
.016 w
.2828 .84535 m
.28026 .84441 L
s
1 .322 0 r
.008 w
.28026 .84441 Mdot
.016 w
.28026 .84441 m
.27764 .84355 L
s
1 .321 0 r
.008 w
.27764 .84355 Mdot
.016 w
.27764 .84355 m
.2753 .84287 L
s
1 .32 0 r
.008 w
.2753 .84287 Mdot
.016 w
.2753 .84287 m
.2732 .84224 L
s
1 .319 0 r
.008 w
.2732 .84224 Mdot
.016 w
.2732 .84224 m
.27143 .84171 L
s
1 .318 0 r
.008 w
.27143 .84171 Mdot
.016 w
.27143 .84171 m
.26993 .84124 L
s
1 .317 0 r
.008 w
.26993 .84124 Mdot
.016 w
.26993 .84124 m
.26864 .8408 L
s
1 .316 0 r
.008 w
.26864 .8408 Mdot
.016 w
.26864 .8408 m
.26765 .84037 L
s
.008 w
.26765 .84037 Mdot
.016 w
.26765 .84037 m
.26679 .83995 L
s
1 .315 0 r
.008 w
.26679 .83995 Mdot
.016 w
.26679 .83995 m
.26604 .83954 L
s
1 .314 0 r
.008 w
.26604 .83954 Mdot
.016 w
.26604 .83954 m
.26552 .83916 L
s
1 .313 0 r
.008 w
.26552 .83916 Mdot
.016 w
.26552 .83916 m
.26507 .83876 L
s
1 .312 0 r
.008 w
.26507 .83876 Mdot
.016 w
.26507 .83876 m
.26472 .83836 L
s
1 .311 0 r
.008 w
.26472 .83836 Mdot
.016 w
.26472 .83836 m
.26446 .838 L
s
1 .31 0 r
.008 w
.26446 .838 Mdot
.016 w
.26446 .838 m
.26428 .83767 L
s
1 .309 0 r
.008 w
.26428 .83767 Mdot
.016 w
.26428 .83767 m
.26414 .83733 L
s
1 .308 0 r
.008 w
.26414 .83733 Mdot
.016 w
.26414 .83733 m
.264 .83699 L
s
1 .307 0 r
.008 w
.264 .83699 Mdot
.016 w
.264 .83699 m
.26379 .8367 L
s
1 .306 0 r
.008 w
.26379 .8367 Mdot
.016 w
.26379 .8367 m
.26357 .83646 L
s
1 .305 0 r
.008 w
.26357 .83646 Mdot
.016 w
.26357 .83646 m
.26323 .83626 L
s
1 .304 0 r
.008 w
.26323 .83626 Mdot
.016 w
.26323 .83626 m
.26279 .83607 L
s
1 .303 0 r
.008 w
.26279 .83607 Mdot
.016 w
.26279 .83607 m
.26223 .83586 L
s
1 .302 0 r
.008 w
.26223 .83586 Mdot
.016 w
.26223 .83586 m
.26151 .83558 L
s
1 .301 0 r
.008 w
.26151 .83558 Mdot
.016 w
.26151 .83558 m
.26061 .83516 L
s
.008 w
.26061 .83516 Mdot
.016 w
.26061 .83516 m
.25955 .83459 L
s
1 .3 0 r
.008 w
.25955 .83459 Mdot
.016 w
.25955 .83459 m
.25832 .83383 L
s
1 .299 0 r
.008 w
.25832 .83383 Mdot
.016 w
.25832 .83383 m
.25699 .83291 L
s
1 .298 0 r
.008 w
.25699 .83291 Mdot
.016 w
.25699 .83291 m
.2555 .83179 L
s
1 .297 0 r
.008 w
.2555 .83179 Mdot
.016 w
.2555 .83179 m
.25382 .83052 L
s
1 .296 0 r
.008 w
.25382 .83052 Mdot
.016 w
.25382 .83052 m
.25199 .82914 L
s
1 .295 0 r
.008 w
.25199 .82914 Mdot
.016 w
.25199 .82914 m
.25015 .82771 L
s
1 .294 0 r
.008 w
.25015 .82771 Mdot
.016 w
.25015 .82771 m
.24832 .82624 L
s
1 .293 0 r
.008 w
.24832 .82624 Mdot
.016 w
.24832 .82624 m
.24657 .82478 L
s
1 .292 0 r
.008 w
.24657 .82478 Mdot
.016 w
.24657 .82478 m
.24502 .82338 L
s
1 .291 0 r
.008 w
.24502 .82338 Mdot
.016 w
.24502 .82338 m
.2437 .82218 L
s
1 .29 0 r
.008 w
.2437 .82218 Mdot
.016 w
.2437 .82218 m
.24259 .82119 L
s
1 .289 0 r
.008 w
.24259 .82119 Mdot
.016 w
.24259 .82119 m
.24169 .8204 L
s
1 .288 0 r
.008 w
.24169 .8204 Mdot
.016 w
.24169 .8204 m
.24092 .81972 L
s
1 .287 0 r
.008 w
.24092 .81972 Mdot
.016 w
.24092 .81972 m
.24027 .8192 L
s
.008 w
.24027 .8192 Mdot
.016 w
.24027 .8192 m
.23967 .8187 L
s
1 .286 0 r
.008 w
.23967 .8187 Mdot
.016 w
.23967 .8187 m
.239 .81814 L
s
1 .285 0 r
.008 w
.239 .81814 Mdot
.016 w
.239 .81814 m
.23836 .8176 L
s
1 .284 0 r
.008 w
.23836 .8176 Mdot
.016 w
.23836 .8176 m
.23776 .81709 L
s
1 .283 0 r
.008 w
.23776 .81709 Mdot
.016 w
.23776 .81709 m
.23704 .81644 L
s
1 .282 0 r
.008 w
.23704 .81644 Mdot
.016 w
.23704 .81644 m
.23619 .81569 L
s
1 .281 0 r
.008 w
.23619 .81569 Mdot
.016 w
.23619 .81569 m
.23517 .81477 L
s
1 .28 0 r
.008 w
.23517 .81477 Mdot
.016 w
.23517 .81477 m
.23392 .81372 L
s
1 .279 0 r
.008 w
.23392 .81372 Mdot
.016 w
.23392 .81372 m
.23248 .81248 L
s
1 .278 0 r
.008 w
.23248 .81248 Mdot
.016 w
.23248 .81248 m
.23089 .81116 L
s
1 .277 0 r
.008 w
.23089 .81116 Mdot
.016 w
.23089 .81116 m
.22911 .80968 L
s
1 .276 0 r
.008 w
.22911 .80968 Mdot
.016 w
.22911 .80968 m
.22717 .80807 L
s
1 .275 0 r
.008 w
.22717 .80807 Mdot
.016 w
.22717 .80807 m
.22511 .80632 L
s
1 .274 0 r
.008 w
.22511 .80632 Mdot
.016 w
.22511 .80632 m
.223 .80453 L
s
1 .273 0 r
.008 w
.223 .80453 Mdot
.016 w
.223 .80453 m
.22081 .80265 L
s
1 .272 0 r
.008 w
.22081 .80265 Mdot
.016 w
.22081 .80265 m
.2187 .8008 L
s
.008 w
.2187 .8008 Mdot
.016 w
.2187 .8008 m
.21658 .79894 L
s
1 .271 0 r
.008 w
.21658 .79894 Mdot
.016 w
.21658 .79894 m
.21444 .79708 L
s
1 .27 0 r
.008 w
.21444 .79708 Mdot
.016 w
.21444 .79708 m
.2124 .79542 L
s
1 .269 0 r
.008 w
.2124 .79542 Mdot
.016 w
.2124 .79542 m
.2104 .79376 L
s
1 .268 0 r
.008 w
.2104 .79376 Mdot
.016 w
.2104 .79376 m
.20845 .79206 L
s
1 .267 0 r
.008 w
.20845 .79206 Mdot
.016 w
.20845 .79206 m
.20662 .79048 L
s
1 .266 0 r
.008 w
.20662 .79048 Mdot
.016 w
.20662 .79048 m
.20485 .78884 L
s
1 .265 0 r
.008 w
.20485 .78884 Mdot
.016 w
.20485 .78884 m
.20321 .78714 L
s
1 .264 0 r
.008 w
.20321 .78714 Mdot
.016 w
.20321 .78714 m
.20168 .7855 L
s
1 .263 0 r
.008 w
.20168 .7855 Mdot
.016 w
.20168 .7855 m
.20021 .78383 L
s
1 .262 0 r
.008 w
.20021 .78383 Mdot
.016 w
.20021 .78383 m
.19882 .78218 L
s
1 .261 0 r
.008 w
.19882 .78218 Mdot
.016 w
.19882 .78218 m
.19755 .78066 L
s
1 .26 0 r
.008 w
.19755 .78066 Mdot
.016 w
.19755 .78066 m
.19636 .77919 L
s
1 .259 0 r
.008 w
.19636 .77919 Mdot
.016 w
.19636 .77919 m
.19525 .77798 L
s
1 .258 0 r
.008 w
.19525 .77798 Mdot
.016 w
.19525 .77798 m
.19423 .77678 L
s
1 .257 0 r
.008 w
.19423 .77678 Mdot
.016 w
.19423 .77678 m
.19325 .77576 L
s
.008 w
.19325 .77576 Mdot
.016 w
.19325 .77576 m
.1923 .77478 L
s
1 .256 0 r
.008 w
.1923 .77478 Mdot
.016 w
.1923 .77478 m
.19134 .7738 L
s
1 .255 0 r
.008 w
.19134 .7738 Mdot
.016 w
.19134 .7738 m
.19035 .7729 L
s
1 .254 0 r
.008 w
.19035 .7729 Mdot
.016 w
.19035 .7729 m
.18929 .77205 L
s
1 .253 0 r
.008 w
.18929 .77205 Mdot
.016 w
.18929 .77205 m
.18816 .77126 L
s
1 .252 0 r
.008 w
.18816 .77126 Mdot
.016 w
.18816 .77126 m
.18692 .77048 L
s
1 .251 0 r
.008 w
.18692 .77048 Mdot
.016 w
.18692 .77048 m
.1856 .76968 L
s
1 .25 0 r
.008 w
.1856 .76968 Mdot
.016 w
.1856 .76968 m
.1842 .76883 L
s
1 .249 0 r
.008 w
.1842 .76883 Mdot
.016 w
.1842 .76883 m
.18282 .76787 L
s
1 .248 0 r
.008 w
.18282 .76787 Mdot
.016 w
.18282 .76787 m
.18133 .76687 L
s
1 .247 0 r
.008 w
.18133 .76687 Mdot
.016 w
.18133 .76687 m
.17976 .7656 L
s
1 .246 0 r
.008 w
.17976 .7656 Mdot
.016 w
.17976 .7656 m
.17816 .76424 L
s
1 .245 0 r
.008 w
.17816 .76424 Mdot
.016 w
.17816 .76424 m
.17642 .76268 L
s
1 .244 0 r
.008 w
.17642 .76268 Mdot
.016 w
.17642 .76268 m
.1747 .76104 L
s
1 .243 0 r
.008 w
.1747 .76104 Mdot
.016 w
.1747 .76104 m
.1729 .75925 L
s
.008 w
.1729 .75925 Mdot
.016 w
.1729 .75925 m
.17108 .75735 L
s
1 .242 0 r
.008 w
.17108 .75735 Mdot
.016 w
.17108 .75735 m
.16933 .75546 L
s
1 .241 0 r
.008 w
.16933 .75546 Mdot
.016 w
.16933 .75546 m
.16765 .75363 L
s
1 .24 0 r
.008 w
.16765 .75363 Mdot
.016 w
.16765 .75363 m
.16604 .75175 L
s
1 .239 0 r
.008 w
.16604 .75175 Mdot
.016 w
.16604 .75175 m
.16446 .74983 L
s
1 .238 0 r
.008 w
.16446 .74983 Mdot
.016 w
.16446 .74983 m
.16287 .74791 L
s
1 .237 0 r
.008 w
.16287 .74791 Mdot
.016 w
.16287 .74791 m
.1614 .74604 L
s
1 .236 0 r
.008 w
.1614 .74604 Mdot
.016 w
.1614 .74604 m
.1599 .74414 L
s
1 .235 0 r
.008 w
.1599 .74414 Mdot
.016 w
.1599 .74414 m
.15842 .74228 L
s
1 .234 0 r
.008 w
.15842 .74228 Mdot
.016 w
.15842 .74228 m
.15696 .74053 L
s
1 .233 0 r
.008 w
.15696 .74053 Mdot
.016 w
.15696 .74053 m
.15563 .73892 L
s
1 .232 0 r
.008 w
.15563 .73892 Mdot
.016 w
.15563 .73892 m
.15441 .73746 L
s
1 .231 0 r
.008 w
.15441 .73746 Mdot
.016 w
.15441 .73746 m
.15332 .73614 L
s
1 .23 0 r
.008 w
.15332 .73614 Mdot
.016 w
.15332 .73614 m
.15227 .73494 L
s
1 .229 0 r
.008 w
.15227 .73494 Mdot
.016 w
.15227 .73494 m
.1512 .73382 L
s
1 .228 0 r
.008 w
.1512 .73382 Mdot
.016 w
.1512 .73382 m
.15003 .73277 L
s
.008 w
.15003 .73277 Mdot
.016 w
.15003 .73277 m
.14902 .73177 L
s
1 .227 0 r
.008 w
.14902 .73177 Mdot
.016 w
.14902 .73177 m
.14777 .73076 L
s
1 .226 0 r
.008 w
.14777 .73076 Mdot
.016 w
.14777 .73076 m
.1463 .72969 L
s
1 .225 0 r
.008 w
.1463 .72969 Mdot
.016 w
.1463 .72969 m
.14471 .72848 L
s
1 .224 0 r
.008 w
.14471 .72848 Mdot
.016 w
.14471 .72848 m
.14288 .72729 L
s
1 .223 0 r
.008 w
.14288 .72729 Mdot
.016 w
.14288 .72729 m
.14107 .72596 L
s
1 .222 0 r
.008 w
.14107 .72596 Mdot
.016 w
.14107 .72596 m
.139 .72448 L
s
1 .221 0 r
.008 w
.139 .72448 Mdot
.016 w
.139 .72448 m
.13693 .72288 L
s
1 .22 0 r
.008 w
.13693 .72288 Mdot
.016 w
.13693 .72288 m
.13507 .72112 L
s
1 .219 0 r
.008 w
.13507 .72112 Mdot
.016 w
.13507 .72112 m
.13312 .71927 L
s
1 .218 0 r
.008 w
.13312 .71927 Mdot
.016 w
.13312 .71927 m
.13099 .71729 L
s
1 .217 0 r
.008 w
.13099 .71729 Mdot
.016 w
.13099 .71729 m
.12887 .71526 L
s
1 .216 0 r
.008 w
.12887 .71526 Mdot
.016 w
.12887 .71526 m
.12675 .71319 L
s
1 .215 0 r
.008 w
.12675 .71319 Mdot
.016 w
.12675 .71319 m
.12475 .71111 L
s
1 .214 0 r
.008 w
.12475 .71111 Mdot
.016 w
.12475 .71111 m
.12272 .70905 L
s
1 .213 0 r
.008 w
.12272 .70905 Mdot
.016 w
.12272 .70905 m
.12085 .70716 L
s
.008 w
.12085 .70716 Mdot
.016 w
.12085 .70716 m
.11908 .70536 L
s
1 .212 0 r
.008 w
.11908 .70536 Mdot
.016 w
.11908 .70536 m
.11737 .70373 L
s
1 .211 0 r
.008 w
.11737 .70373 Mdot
.016 w
.11737 .70373 m
.11585 .70224 L
s
1 .21 0 r
.008 w
.11585 .70224 Mdot
.016 w
.11585 .70224 m
.11444 .70089 L
s
1 .209 0 r
.008 w
.11444 .70089 Mdot
.016 w
.11444 .70089 m
.11309 .69969 L
s
1 .208 0 r
.008 w
.11309 .69969 Mdot
.016 w
.11309 .69969 m
.11188 .69861 L
s
1 .207 0 r
.008 w
.11188 .69861 Mdot
.016 w
.11188 .69861 m
.11089 .69764 L
s
1 .206 0 r
.008 w
.11089 .69764 Mdot
.016 w
.11089 .69764 m
.11005 .69675 L
s
1 .205 0 r
.008 w
.11005 .69675 Mdot
.016 w
.11005 .69675 m
.1094 .69598 L
s
1 .204 0 r
.008 w
.1094 .69598 Mdot
.016 w
.1094 .69598 m
.10895 .69536 L
s
1 .203 0 r
.008 w
.10895 .69536 Mdot
.016 w
.10895 .69536 m
.1087 .69492 L
s
1 .202 0 r
.008 w
.1087 .69492 Mdot
.016 w
.1087 .69492 m
.10864 .69461 L
s
1 .201 0 r
.008 w
.10864 .69461 Mdot
.016 w
.10864 .69461 m
.10871 .69438 L
s
1 .2 0 r
.008 w
.10871 .69438 Mdot
.016 w
.10871 .69438 m
.10885 .6942 L
s
1 .199 0 r
.008 w
.10885 .6942 Mdot
.016 w
.10885 .6942 m
.10903 .69404 L
s
.008 w
.10903 .69404 Mdot
.016 w
.10903 .69404 m
.10921 .69391 L
s
1 .198 0 r
.008 w
.10921 .69391 Mdot
.016 w
.10921 .69391 m
.10938 .69377 L
s
1 .197 0 r
.008 w
.10938 .69377 Mdot
.016 w
.10938 .69377 m
.10953 .69362 L
s
1 .196 0 r
.008 w
.10953 .69362 Mdot
.016 w
.10953 .69362 m
.10963 .69345 L
s
1 .195 0 r
.008 w
.10963 .69345 Mdot
.016 w
.10963 .69345 m
.10967 .69332 L
s
1 .194 0 r
.008 w
.10967 .69332 Mdot
.016 w
.10967 .69332 m
.10967 .69323 L
s
1 .193 0 r
.008 w
.10967 .69323 Mdot
.016 w
.10967 .69323 m
.1096 .69318 L
s
1 .192 0 r
.008 w
.1096 .69318 Mdot
.016 w
.1096 .69318 m
.10947 .6931 L
s
1 .191 0 r
.008 w
.10947 .6931 Mdot
.016 w
.10947 .6931 m
.10927 .69295 L
s
1 .19 0 r
.008 w
.10927 .69295 Mdot
.016 w
.10927 .69295 m
.10901 .69271 L
s
1 .189 0 r
.008 w
.10901 .69271 Mdot
.016 w
.10901 .69271 m
.10871 .69233 L
s
1 .188 0 r
.008 w
.10871 .69233 Mdot
.016 w
.10871 .69233 m
.1084 .6918 L
s
1 .187 0 r
.008 w
.1084 .6918 Mdot
.016 w
.1084 .6918 m
.10809 .69108 L
s
1 .186 0 r
.008 w
.10809 .69108 Mdot
.016 w
.10809 .69108 m
.10784 .69039 L
s
1 .185 0 r
.008 w
.10784 .69039 Mdot
.016 w
.10784 .69039 m
.10759 .68955 L
s
1 .184 0 r
.008 w
.10759 .68955 Mdot
.016 w
.10759 .68955 m
.10736 .68866 L
s
.008 w
.10736 .68866 Mdot
.016 w
.10736 .68866 m
.10714 .68771 L
s
1 .183 0 r
.008 w
.10714 .68771 Mdot
.016 w
.10714 .68771 m
.10691 .6866 L
s
1 .182 0 r
.008 w
.10691 .6866 Mdot
.016 w
.10691 .6866 m
.10668 .68525 L
s
1 .181 0 r
.008 w
.10668 .68525 Mdot
.016 w
.10668 .68525 m
.10646 .68366 L
s
1 .18 0 r
.008 w
.10646 .68366 Mdot
.016 w
.10646 .68366 m
.10626 .68186 L
s
1 .179 0 r
.008 w
.10626 .68186 Mdot
.016 w
.10626 .68186 m
.10605 .68005 L
s
1 .178 0 r
.008 w
.10605 .68005 Mdot
.016 w
.10605 .68005 m
.10583 .67825 L
s
1 .177 0 r
.008 w
.10583 .67825 Mdot
.016 w
.10583 .67825 m
.10558 .67653 L
s
1 .176 0 r
.008 w
.10558 .67653 Mdot
.016 w
.10558 .67653 m
.1053 .67497 L
s
1 .175 0 r
.008 w
.1053 .67497 Mdot
.016 w
.1053 .67497 m
.10498 .67359 L
s
1 .174 0 r
.008 w
.10498 .67359 Mdot
.016 w
.10498 .67359 m
.10462 .67241 L
s
1 .173 0 r
.008 w
.10462 .67241 Mdot
.016 w
.10462 .67241 m
.10428 .67145 L
s
1 .172 0 r
.008 w
.10428 .67145 Mdot
.016 w
.10428 .67145 m
.10397 .67069 L
s
1 .171 0 r
.008 w
.10397 .67069 Mdot
.016 w
.10397 .67069 m
.10372 .6701 L
s
1 .17 0 r
.008 w
.10372 .6701 Mdot
.016 w
.10372 .6701 m
.10353 .66963 L
s
1 .169 0 r
.008 w
.10353 .66963 Mdot
.016 w
.10353 .66963 m
.1034 .66928 L
s
.008 w
.1034 .66928 Mdot
.016 w
.1034 .66928 m
.10334 .66911 L
s
1 .168 0 r
.008 w
.10334 .66911 Mdot
.016 w
.10334 .66911 m
.10335 .66907 L
s
1 .167 0 r
.008 w
.10335 .66907 Mdot
.016 w
.10335 .66907 m
.10342 .6691 L
s
1 .166 0 r
.008 w
.10342 .6691 Mdot
.016 w
.10342 .6691 m
.1036 .66912 L
s
1 .165 0 r
.008 w
.1036 .66912 Mdot
.016 w
.1036 .66912 m
.10386 .66908 L
s
1 .164 0 r
.008 w
.10386 .66908 Mdot
.016 w
.10386 .66908 m
.10416 .669 L
s
1 .163 0 r
.008 w
.10416 .669 Mdot
.016 w
.10416 .669 m
.10447 .6689 L
s
1 .162 0 r
.008 w
.10447 .6689 Mdot
.016 w
.10447 .6689 m
.10477 .66876 L
s
1 .161 0 r
.008 w
.10477 .66876 Mdot
.016 w
.10477 .66876 m
.105 .66861 L
s
1 .16 0 r
.008 w
.105 .66861 Mdot
.016 w
.105 .66861 m
.10514 .66851 L
s
1 .159 0 r
.008 w
.10514 .66851 Mdot
.016 w
.10514 .66851 m
.10518 .66855 L
s
1 .158 0 r
.008 w
.10518 .66855 Mdot
.016 w
.10518 .66855 m
.10511 .66866 L
s
1 .157 0 r
.008 w
.10511 .66866 Mdot
.016 w
.10511 .66866 m
.10493 .66881 L
s
1 .156 0 r
.008 w
.10493 .66881 Mdot
.016 w
.10493 .66881 m
.10467 .66891 L
s
1 .155 0 r
.008 w
.10467 .66891 Mdot
.016 w
.10467 .66891 m
.10436 .66885 L
s
1 .154 0 r
.008 w
.10436 .66885 Mdot
.016 w
.10436 .66885 m
.10401 .66855 L
s
.008 w
.10401 .66855 Mdot
.016 w
.10401 .66855 m
.10359 .66807 L
s
1 .153 0 r
.008 w
.10359 .66807 Mdot
.016 w
.10359 .66807 m
.10309 .6675 L
s
1 .152 0 r
.008 w
.10309 .6675 Mdot
.016 w
.10309 .6675 m
.10251 .66666 L
s
1 .151 0 r
.008 w
.10251 .66666 Mdot
.016 w
.10251 .66666 m
.10187 .66558 L
s
1 .15 0 r
.008 w
.10187 .66558 Mdot
.016 w
.10187 .66558 m
.10121 .66421 L
s
1 .149 0 r
.008 w
.10121 .66421 Mdot
.016 w
.10121 .66421 m
.10057 .66261 L
s
1 .148 0 r
.008 w
.10057 .66261 Mdot
.016 w
.10057 .66261 m
.09998 .66078 L
s
1 .147 0 r
.008 w
.09998 .66078 Mdot
.016 w
.09998 .66078 m
.0994 .65894 L
s
1 .146 0 r
.008 w
.0994 .65894 Mdot
.016 w
.0994 .65894 m
.09882 .65678 L
s
1 .145 0 r
.008 w
.09882 .65678 Mdot
.016 w
.09882 .65678 m
.09821 .6542 L
s
1 .144 0 r
.008 w
.09821 .6542 Mdot
.016 w
.09821 .6542 m
.09755 .65148 L
s
1 .143 0 r
.008 w
.09755 .65148 Mdot
.016 w
.09755 .65148 m
.09682 .64842 L
s
1 .142 0 r
.008 w
.09682 .64842 Mdot
.016 w
.09682 .64842 m
.09601 .64511 L
s
1 .141 0 r
.008 w
.09601 .64511 Mdot
.016 w
.09601 .64511 m
.09519 .64135 L
s
1 .14 0 r
.008 w
.09519 .64135 Mdot
.016 w
.09519 .64135 m
.09439 .63753 L
s
.008 w
.09439 .63753 Mdot
.016 w
.09439 .63753 m
.09363 .63336 L
s
1 .139 0 r
.008 w
.09363 .63336 Mdot
.016 w
.09363 .63336 m
.09293 .62981 L
s
1 .138 0 r
.008 w
.09293 .62981 Mdot
.016 w
.09293 .62981 m
.09232 .62613 L
s
1 .137 0 r
.008 w
.09232 .62613 Mdot
.016 w
.09232 .62613 m
.09177 .62303 L
s
1 .136 0 r
.008 w
.09177 .62303 Mdot
.016 w
.09177 .62303 m
.09129 .62026 L
s
1 .135 0 r
.008 w
.09129 .62026 Mdot
.016 w
.09129 .62026 m
.09089 .61758 L
s
1 .134 0 r
.008 w
.09089 .61758 Mdot
.016 w
.09089 .61758 m
.09058 .61511 L
s
1 .133 0 r
.008 w
.09058 .61511 Mdot
.016 w
.09058 .61511 m
.09036 .61318 L
s
1 .132 0 r
.008 w
.09036 .61318 Mdot
.016 w
.09036 .61318 m
.09024 .61198 L
s
1 .131 0 r
.008 w
.09024 .61198 Mdot
.016 w
.09024 .61198 m
.09021 .61136 L
s
1 .13 0 r
.008 w
.09021 .61136 Mdot
.016 w
.09021 .61136 m
.09023 .61098 L
s
1 .129 0 r
.008 w
.09023 .61098 Mdot
.016 w
.09023 .61098 m
.09023 .61061 L
s
1 .128 0 r
.008 w
.09023 .61061 Mdot
.016 w
.09023 .61061 m
.09017 .61017 L
s
1 .127 0 r
.008 w
.09017 .61017 Mdot
.016 w
.09017 .61017 m
.09003 .6096 L
s
1 .126 0 r
.008 w
.09003 .6096 Mdot
.016 w
.09003 .6096 m
.08979 .60856 L
s
1 .125 0 r
.008 w
.08979 .60856 Mdot
.016 w
.08979 .60856 m
.08943 .60682 L
s
.008 w
.08943 .60682 Mdot
.016 w
.08943 .60682 m
.08903 .60465 L
s
1 .124 0 r
.008 w
.08903 .60465 Mdot
.016 w
.08903 .60465 m
.08858 .60216 L
s
1 .123 0 r
.008 w
.08858 .60216 Mdot
.016 w
.08858 .60216 m
.0881 .59952 L
s
1 .122 0 r
.008 w
.0881 .59952 Mdot
.016 w
.0881 .59952 m
.08761 .59678 L
s
1 .121 0 r
.008 w
.08761 .59678 Mdot
.016 w
.08761 .59678 m
.08714 .59403 L
s
1 .12 0 r
.008 w
.08714 .59403 Mdot
.016 w
.08714 .59403 m
.08667 .59135 L
s
1 .119 0 r
.008 w
.08667 .59135 Mdot
.016 w
.08667 .59135 m
.0863 .58894 L
s
1 .118 0 r
.008 w
.0863 .58894 Mdot
.016 w
.0863 .58894 m
.08598 .58677 L
s
1 .117 0 r
.008 w
.08598 .58677 Mdot
.016 w
.08598 .58677 m
.08575 .58497 L
s
1 .116 0 r
.008 w
.08575 .58497 Mdot
.016 w
.08575 .58497 m
.08563 .58358 L
s
1 .115 0 r
.008 w
.08563 .58358 Mdot
.016 w
.08563 .58358 m
.08565 .58258 L
s
1 .114 0 r
.008 w
.08565 .58258 Mdot
.016 w
.08565 .58258 m
.0858 .58198 L
s
1 .113 0 r
.008 w
.0858 .58198 Mdot
.016 w
.0858 .58198 m
.08606 .58173 L
s
1 .112 0 r
.008 w
.08606 .58173 Mdot
.016 w
.08606 .58173 m
.0864 .58174 L
s
1 .111 0 r
.008 w
.0864 .58174 Mdot
.016 w
.0864 .58174 m
.08676 .58192 L
s
1 .11 0 r
.008 w
.08676 .58192 Mdot
.016 w
.08676 .58192 m
.08713 .58222 L
s
.008 w
.08713 .58222 Mdot
.016 w
.08713 .58222 m
.08748 .58259 L
s
1 .109 0 r
.008 w
.08748 .58259 Mdot
.016 w
.08748 .58259 m
.0878 .58299 L
s
1 .108 0 r
.008 w
.0878 .58299 Mdot
.016 w
.0878 .58299 m
.08805 .58336 L
s
1 .107 0 r
.008 w
.08805 .58336 Mdot
.016 w
.08805 .58336 m
.08826 .58367 L
s
1 .106 0 r
.008 w
.08826 .58367 Mdot
.016 w
.08826 .58367 m
.08843 .58391 L
s
1 .105 0 r
.008 w
.08843 .58391 Mdot
.016 w
.08843 .58391 m
.08858 .58408 L
s
1 .104 0 r
.008 w
.08858 .58408 Mdot
.016 w
.08858 .58408 m
.08869 .58418 L
s
1 .103 0 r
.008 w
.08869 .58418 Mdot
.016 w
.08869 .58418 m
.08875 .58423 L
s
1 .102 0 r
.008 w
.08875 .58423 Mdot
.016 w
.08875 .58423 m
.08877 .58425 L
s
1 .101 0 r
.008 w
.08877 .58425 Mdot
.016 w
.08877 .58425 m
.08875 .58424 L
s
1 .1 0 r
.008 w
.08875 .58424 Mdot
.016 w
.08875 .58424 m
.08871 .5842 L
s
1 .099 0 r
.008 w
.08871 .5842 Mdot
.016 w
.08871 .5842 m
.08867 .58417 L
s
1 .098 0 r
.008 w
.08867 .58417 Mdot
.016 w
.08867 .58417 m
.08864 .58414 L
s
1 .097 0 r
.008 w
.08864 .58414 Mdot
.016 w
.08864 .58414 m
.08862 .58412 L
s
1 .096 0 r
.008 w
.08862 .58412 Mdot
.016 w
.08862 .58412 m
.08862 .58412 L
s
.008 w
.08862 .58412 Mdot
.016 w
.08862 .58412 m
.08865 .58413 L
s
1 .095 0 r
.008 w
.08865 .58413 Mdot
.016 w
.08865 .58413 m
.0887 .58416 L
s
1 .094 0 r
.008 w
.0887 .58416 Mdot
.016 w
.0887 .58416 m
.08878 .5842 L
s
1 .093 0 r
.008 w
.08878 .5842 Mdot
.016 w
.08878 .5842 m
.08886 .58426 L
s
1 .092 0 r
.008 w
.08886 .58426 Mdot
.016 w
.08886 .58426 m
.08889 .58437 L
s
1 .091 0 r
.008 w
.08889 .58437 Mdot
.016 w
.08889 .58437 m
.08888 .58453 L
s
1 .09 0 r
.008 w
.08888 .58453 Mdot
.016 w
.08888 .58453 m
.08879 .5847 L
s
1 .089 0 r
.008 w
.08879 .5847 Mdot
.016 w
.08879 .5847 m
.08862 .58484 L
s
1 .088 0 r
.008 w
.08862 .58484 Mdot
.016 w
.08862 .58484 m
.08835 .58489 L
s
1 .087 0 r
.008 w
.08835 .58489 Mdot
.016 w
.08835 .58489 m
.08798 .58478 L
s
1 .086 0 r
.008 w
.08798 .58478 Mdot
.016 w
.08798 .58478 m
.08751 .58443 L
s
1 .085 0 r
.008 w
.08751 .58443 Mdot
.016 w
.08751 .58443 m
.08696 .58378 L
s
1 .084 0 r
.008 w
.08696 .58378 Mdot
.016 w
.08696 .58378 m
.08636 .5828 L
s
1 .083 0 r
.008 w
.08636 .5828 Mdot
.016 w
.08636 .5828 m
.08576 .58148 L
s
1 .082 0 r
.008 w
.08576 .58148 Mdot
.016 w
.08576 .58148 m
.08516 .57978 L
s
1 .081 0 r
.008 w
.08516 .57978 Mdot
.016 w
.08516 .57978 m
.08454 .57769 L
s
.008 w
.08454 .57769 Mdot
.016 w
.08454 .57769 m
.08393 .57545 L
s
1 .08 0 r
.008 w
.08393 .57545 Mdot
.016 w
.08393 .57545 m
.08334 .57288 L
s
1 .079 0 r
.008 w
.08334 .57288 Mdot
.016 w
.08334 .57288 m
.08282 .56993 L
s
1 .078 0 r
.008 w
.08282 .56993 Mdot
.016 w
.08282 .56993 m
.08237 .56703 L
s
1 .077 0 r
.008 w
.08237 .56703 Mdot
.016 w
.08237 .56703 m
.08198 .56388 L
s
1 .076 0 r
.008 w
.08198 .56388 Mdot
.016 w
.08198 .56388 m
.08164 .56071 L
s
1 .075 0 r
.008 w
.08164 .56071 Mdot
.016 w
.08164 .56071 m
.08134 .55747 L
s
1 .074 0 r
.008 w
.08134 .55747 Mdot
.016 w
.08134 .55747 m
.08107 .55437 L
s
1 .073 0 r
.008 w
.08107 .55437 Mdot
.016 w
.08107 .55437 m
.08078 .55129 L
s
1 .072 0 r
.008 w
.08078 .55129 Mdot
.016 w
.08078 .55129 m
.08046 .54826 L
s
1 .071 0 r
.008 w
.08046 .54826 Mdot
.016 w
.08046 .54826 m
.08007 .54523 L
s
1 .07 0 r
.008 w
.08007 .54523 Mdot
.016 w
.08007 .54523 m
.07962 .5422 L
s
1 .069 0 r
.008 w
.07962 .5422 Mdot
.016 w
.07962 .5422 m
.07914 .53911 L
s
1 .068 0 r
.008 w
.07914 .53911 Mdot
.016 w
.07914 .53911 m
.07862 .53589 L
s
1 .067 0 r
.008 w
.07862 .53589 Mdot
.016 w
.07862 .53589 m
.07806 .5324 L
s
1 .066 0 r
.008 w
.07806 .5324 Mdot
.016 w
.07806 .5324 m
.07745 .52909 L
s
.008 w
.07745 .52909 Mdot
.016 w
.07745 .52909 m
.07681 .5256 L
s
1 .065 0 r
.008 w
.07681 .5256 Mdot
.016 w
.07681 .5256 m
.07617 .5221 L
s
1 .064 0 r
.008 w
.07617 .5221 Mdot
.016 w
.07617 .5221 m
.07553 .51861 L
s
1 .063 0 r
.008 w
.07553 .51861 Mdot
.016 w
.07553 .51861 m
.07488 .51525 L
s
1 .062 0 r
.008 w
.07488 .51525 Mdot
.016 w
.07488 .51525 m
.07425 .51205 L
s
1 .061 0 r
.008 w
.07425 .51205 Mdot
.016 w
.07425 .51205 m
.07365 .50886 L
s
1 .06 0 r
.008 w
.07365 .50886 Mdot
.016 w
.07365 .50886 m
.0731 .5059 L
s
1 .059 0 r
.008 w
.0731 .5059 Mdot
.016 w
.0731 .5059 m
.07262 .50298 L
s
1 .058 0 r
.008 w
.07262 .50298 Mdot
.016 w
.07262 .50298 m
.07223 .5002 L
s
1 .057 0 r
.008 w
.07223 .5002 Mdot
.016 w
.07223 .5002 m
.07195 .49751 L
s
1 .056 0 r
.008 w
.07195 .49751 Mdot
.016 w
.07195 .49751 m
.07176 .4949 L
s
1 .055 0 r
.008 w
.07176 .4949 Mdot
.016 w
.07176 .4949 m
.07168 .49224 L
s
1 .054 0 r
.008 w
.07168 .49224 Mdot
.016 w
.07168 .49224 m
.07171 .48954 L
s
1 .053 0 r
.008 w
.07171 .48954 Mdot
.016 w
.07171 .48954 m
.07186 .48661 L
s
1 .052 0 r
.008 w
.07186 .48661 Mdot
.016 w
.07186 .48661 m
.07211 .48371 L
s
1 .051 0 r
.008 w
.07211 .48371 Mdot
.016 w
.07211 .48371 m
.07248 .48058 L
s
.008 w
.07248 .48058 Mdot
.016 w
.07248 .48058 m
.07294 .47738 L
s
1 .05 0 r
.008 w
.07294 .47738 Mdot
.016 w
.07294 .47738 m
.07347 .47403 L
s
1 .049 0 r
.008 w
.07347 .47403 Mdot
.016 w
.07347 .47403 m
.07407 .47083 L
s
1 .048 0 r
.008 w
.07407 .47083 Mdot
.016 w
.07407 .47083 m
.07466 .46776 L
s
1 .047 0 r
.008 w
.07466 .46776 Mdot
.016 w
.07466 .46776 m
.07527 .46501 L
s
1 .046 0 r
.008 w
.07527 .46501 Mdot
.016 w
.07527 .46501 m
.07583 .46254 L
s
1 .045 0 r
.008 w
.07583 .46254 Mdot
.016 w
.07583 .46254 m
.07635 .46037 L
s
1 .044 0 r
.008 w
.07635 .46037 Mdot
.016 w
.07635 .46037 m
.07681 .45857 L
s
1 .043 0 r
.008 w
.07681 .45857 Mdot
.016 w
.07681 .45857 m
.0772 .45708 L
s
1 .042 0 r
.008 w
.0772 .45708 Mdot
.016 w
.0772 .45708 m
.07755 .45582 L
s
1 .041 0 r
.008 w
.07755 .45582 Mdot
.016 w
.07755 .45582 m
.07783 .45475 L
s
1 .04 0 r
.008 w
.07783 .45475 Mdot
.016 w
.07783 .45475 m
.07805 .45384 L
s
1 .039 0 r
.008 w
.07805 .45384 Mdot
.016 w
.07805 .45384 m
.0782 .45305 L
s
1 .038 0 r
.008 w
.0782 .45305 Mdot
.016 w
.0782 .45305 m
.07829 .45235 L
s
1 .037 0 r
.008 w
.07829 .45235 Mdot
.016 w
.07829 .45235 m
.07833 .45169 L
s
.008 w
.07833 .45169 Mdot
.016 w
.07833 .45169 m
.07833 .45103 L
s
1 .036 0 r
.008 w
.07833 .45103 Mdot
.016 w
.07833 .45103 m
.07834 .45036 L
s
1 .035 0 r
.008 w
.07834 .45036 Mdot
.016 w
.07834 .45036 m
.07839 .44959 L
s
1 .034 0 r
.008 w
.07839 .44959 Mdot
.016 w
.07839 .44959 m
.07848 .44874 L
s
1 .033 0 r
.008 w
.07848 .44874 Mdot
.016 w
.07848 .44874 m
.07862 .44784 L
s
1 .032 0 r
.008 w
.07862 .44784 Mdot
.016 w
.07862 .44784 m
.07883 .44693 L
s
1 .031 0 r
.008 w
.07883 .44693 Mdot
.016 w
.07883 .44693 m
.07911 .44612 L
s
1 .03 0 r
.008 w
.07911 .44612 Mdot
.016 w
.07911 .44612 m
.07941 .44543 L
s
1 .029 0 r
.008 w
.07941 .44543 Mdot
.016 w
.07941 .44543 m
.07972 .44487 L
s
1 .028 0 r
.008 w
.07972 .44487 Mdot
.016 w
.07972 .44487 m
.08001 .44444 L
s
1 .027 0 r
.008 w
.08001 .44444 Mdot
.016 w
.08001 .44444 m
.08029 .4441 L
s
1 .026 0 r
.008 w
.08029 .4441 Mdot
.016 w
.08029 .4441 m
.08054 .44381 L
s
1 .025 0 r
.008 w
.08054 .44381 Mdot
.016 w
.08054 .44381 m
.08074 .44352 L
s
1 .024 0 r
.008 w
.08074 .44352 Mdot
.016 w
.08074 .44352 m
.08089 .44321 L
s
1 .023 0 r
.008 w
.08089 .44321 Mdot
.016 w
.08089 .44321 m
.08098 .44283 L
s
1 .022 0 r
.008 w
.08098 .44283 Mdot
.016 w
.08098 .44283 m
.08104 .44241 L
s
.008 w
.08104 .44241 Mdot
.016 w
.08104 .44241 m
.08111 .44198 L
s
1 .021 0 r
.008 w
.08111 .44198 Mdot
.016 w
.08111 .44198 m
.08119 .44156 L
s
1 .02 0 r
.008 w
.08119 .44156 Mdot
.016 w
.08119 .44156 m
.08129 .44117 L
s
1 .019 0 r
.008 w
.08129 .44117 Mdot
.016 w
.08129 .44117 m
.08141 .44079 L
s
1 .018 0 r
.008 w
.08141 .44079 Mdot
.016 w
.08141 .44079 m
.0815 .44041 L
s
1 .017 0 r
.008 w
.0815 .44041 Mdot
.016 w
.0815 .44041 m
.08163 .44002 L
s
1 .016 0 r
.008 w
.08163 .44002 Mdot
.016 w
.08163 .44002 m
.08179 .43962 L
s
1 .015 0 r
.008 w
.08179 .43962 Mdot
.016 w
.08179 .43962 m
.08202 .43922 L
s
1 .014 0 r
.008 w
.08202 .43922 Mdot
.016 w
.08202 .43922 m
.08229 .43883 L
s
1 .013 0 r
.008 w
.08229 .43883 Mdot
.016 w
.08229 .43883 m
.08262 .43847 L
s
1 .012 0 r
.008 w
.08262 .43847 Mdot
.016 w
.08262 .43847 m
.08299 .43812 L
s
1 .011 0 r
.008 w
.08299 .43812 Mdot
.016 w
.08299 .43812 m
.08341 .43778 L
s
1 .01 0 r
.008 w
.08341 .43778 Mdot
.016 w
.08341 .43778 m
.08384 .43744 L
s
1 .009 0 r
.008 w
.08384 .43744 Mdot
.016 w
.08384 .43744 m
.0843 .43709 L
s
1 .008 0 r
.008 w
.0843 .43709 Mdot
.016 w
.0843 .43709 m
.08471 .43671 L
s
1 .007 0 r
.008 w
.08471 .43671 Mdot
.016 w
.08471 .43671 m
.08506 .43629 L
s
.008 w
.08506 .43629 Mdot
.016 w
.08506 .43629 m
.08534 .4359 L
s
1 .006 0 r
.008 w
.08534 .4359 Mdot
.016 w
.08534 .4359 m
.08563 .43552 L
s
1 .005 0 r
.008 w
.08563 .43552 Mdot
.016 w
.08563 .43552 m
.0859 .4352 L
s
1 .004 0 r
.008 w
.0859 .4352 Mdot
.016 w
.0859 .4352 m
.08616 .43495 L
s
1 .003 0 r
.008 w
.08616 .43495 Mdot
.016 w
.08616 .43495 m
.08641 .43476 L
s
1 .002 0 r
.008 w
.08641 .43476 Mdot
.016 w
.08641 .43476 m
.08663 .43465 L
s
1 .001 0 r
.008 w
.08663 .43465 Mdot
.016 w
.08663 .43465 m
.0868 .4346 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0769325 0.0719982 scale
1.38602 9.58427 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0805126 0.0753487 scale
6.28075 11.9556 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0530885 0.0496835 scale
1.94845 13.4717 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0650198 0.0608496 scale
1.3662 9.60253 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0024OolG0025Ool006moo`<m
k`=ooaTmk`eoo`X007]oo`00KGoo9cg_4Goo1P00MGoo001YOol/?NlFOol5001`Ool006Moobhmka]o
o`<006eoo`00IWoo<3g_7Goo1@00J7oo001SOolc?NlROol3001UOol0069ooahmk`9ooa<mkbIoo`<0
069oo`00Ggoo83g_27oo13g_<goo0`00Ggoo001NOolB?Nl3Ool:?Nm4Ool00`00Oomoo`1LOol005ao
o`dmkeUoo`8005aoo`00FGoo00<003g_?Nl02Sg_GWoo0`00FGoo001FOol3000:?NmTOol3001FOol0
05Aoo`800003Oolmkcg_00PmkfUoo`8005Aoo`00DWoo0P003Cg_Jgoo0P00DWoo001@Ool200000goo
?Nlmk`0<?Nm]Ool2001@Ool004ioo`80009oo`hmkg1oo`8004ioo`00CGoo00<007ooOol03Sg_M7oo
00<007ooOol0Bgoo001<Ool00`00Oolmk`0=?NmgOol00`00Oomoo`1:Ool004Yoo`8000lmkgUoo`80
04Yoo`00B7oo0P004Cg_Ngoo0P00B7oo0016Ool200000goo?Nlmk`0??NmnOol20016Ool004Eoo`03
001oocg_014mkh5oo`8004Aoo`00A7oo00<007oo?Nl03cg_QWoo00<007ooOol0@Goo0012Ool20000
0goo?Nlmk`0>?Nn8Ool00`00Oomoo`10Ool0045oo`03001oogoo010mkhYoo`03001oogoo03moo`00
?goo0P000Woo2Sg_TWoo0P00?goo000nOol00`00Oomoo`0;?NnEOol00`00Oomoo`0lOol003eoo`03
001oocg_00/mkiMoo`03001oogoo03]oo`00?7oo00<003g_?Nl02cg_VGoo00<007ooOol0>Woo000j
Ool2000=?NnKOol2000jOol003Uoo`03001oocg_00`mkiioo`03001oogoo03Moo`00>7oo00<007oo
?Nl033g_X7oo00<007ooOol0=Woo000gOol00`00Oolmk`08?NnVOol00`00Oomoo`0eOol003Ioo`03
001oogoo00TmkjMoo`03001oogoo03Aoo`00=Goo00<007ooOol02Sg_Z7oo00<007ooOol0<goo000c
Ool20002Ool;?NnYOol2000cOol0039oo`03001oogoo009oo`/mkj]oo`03001oogoo031oo`00<Goo
00<007ooOol00Woo33g_[7oo00<007ooOol0;goo000`Ool00`00Oomoo`02Ool<?Nn^Ool00`00Oomo
o`0^Ool002moo`03001oogoo00=oo`/mkk1oo`03001oogoo02eoo`00;Woo00<007ooOol00goo2cg_
/Woo00<007ooOol0;7oo000]Ool00`00Oomoo`03Ool;?NndOol00`00Oomoo`0[Ool002eoo`03001o
ogoo00=oo`TmkkIoo`03001oogoo02]oo`00;7oo00<007ooOol00goo1cg_^Woo00<007ooOol0:Woo
000[Ool00`00Oomoo`04Ool6?NnlOol00`00Oomoo`0YOol002Yoo`03001oogoo00Aoo`Hmkkioo`03
001oogoo02Qoo`00:Goo00<007ooOol017oo1cg__goo00<007ooOol09goo000XOol00`00Oomoo`05
Ool6?No1Ool00`00Oomoo`0VOol002Moo`03001oogoo00Eoo`Lmkl9oo`03001oogoo02Eoo`009goo
00<007ooOol017oo2Cg_`Goo00<007ooOol09Goo000VOol00`00Oomoo`05Ool9?No2Ool00`00Oomo
o`0TOol002Eoo`03001oogoo00Eoo`TmklAoo`03001oogoo02=oo`0097oo00<007ooOol01Goo2Cg_
aWoo00<007ooOol08Woo000SOol00`00Oomoo`05Ool9?No8Ool00`00Oomoo`0QOol002=oo`03001o
ogoo00Eoo`TmklQoo`03001oogoo025oo`008Woo00<007ooOol01Goo2Cg_bWoo00<007ooOol087oo
000QOol00`00Oomoo`06Ool8?No<Ool00`00Oomoo`0OOol0021oo`03001oogoo00Ioo`Lmklmoo`03
001oogoo01ioo`0087oo00<007ooOol01Woo1Sg_d7oo00<007ooOol07Woo000OOol00`00Oomoo`06
Ool7?NoAOol00`00Oomoo`0MOol001moo`03001oogoo00Eoo`Pmkm5oo`03001oogoo01eoo`007Woo
00<007ooOol01Woo1cg_dgoo00<007ooOol077oo000NOol00`00Oomoo`05Ool8?NoCOol00`00Oomo
o`0LOol001eoo`03001oogoo00Eoo`TmkmAoo`03001oogoo01]oo`007Goo00<007ooOol01Goo23g_
eWoo00<007ooOol06Woo000LOol00`00Oomoo`05Ool9?NoFOol00`00Oomoo`0JOol001]oo`03001o
ogoo00Eoo`XmkmMoo`03001oogoo01Uoo`006goo00<007ooOol01Goo2Cg_f7oo00<007ooOol06Goo
000JOol00`00Oomoo`05Ool9?NoJOol00`00Oomoo`0HOol001Yoo`03001oogoo00Eoo`Pmkm]oo`03
001oogoo01Qoo`006Goo00<007ooOol01Goo23g_gGoo00<007ooOol05goo000IOol00`00Oomoo`04
Ool8?NoNOol00`00Oomoo`0GOol001Uoo`03001oogoo00Aoo`Lmkn1oo`03001oogoo01Ioo`0067oo
00<007ooOol017oo23g_h7oo00<007ooOol05Woo000HOol00`00Oomoo`04Ool8?NoQOol00`00Oomo
o`0EOol001Moo`03001oogoo00Eoo`Pmkn9oo`03001oogoo01Aoo`005Woo00<007ooOol01Woo1cg_
hgoo00<007ooOol057oo000FOol00`00Oomoo`05Ool7?NoTOol00`00Oomoo`0DOol001Eoo`03001o
ogoo00Ioo`LmknEoo`03001oogoo01=oo`005Goo00<007ooOol01Woo1Sg_iWoo00<007ooOol04goo
000EOol00`00Oomoo`06Ool6?NoVOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`LmknMoo`03
001oogoo019oo`0057oo00<007ooOol01Woo1Sg_j7oo00<007ooOol04Woo000DOol00`00Oomoo`06
Ool6?NoXOol00`00Oomoo`0BOol001=oo`03001oogoo00Moo`DmknYoo`03001oogoo015oo`004goo
00<007ooOol01goo1Cg_jWoo00<007ooOol04Goo000COol00`00Oomoo`06Ool6?NoZOol00`00Oomo
o`0AOol0019oo`03001oogoo00Moo`Dmknaoo`03001oogoo011oo`004Woo00<007ooOol01goo1Cg_
k7oo00<007ooOol047oo000BOol00`00Oomoo`07Ool5?No/Ool00`00Oomoo`0@Ool0015oo`03001o
ogoo00Qoo`Dmkneoo`03001oogoo00moo`004Goo00<007ooOol027oo1Cg_kGoo00<007ooOol03goo
000AOol00`00Oomoo`08Ool5?No]Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Qoo`Dmkneoo`03
001oogoo00moo`004Goo00<007ooOol027oo1Cg_kGoo00<007ooOol03goo000AOol00`00Oomoo`08
Ool5?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Uoo`@mknmoo`03001oogoo00ioo`0047oo
00<007ooOol02Goo13g_kgoo00<007ooOol03Woo000@Ool00`00Oomoo`09Ool4?No_Ool00`00Oomo
o`0>Ool000moo`03001oogoo00Yoo`@mko1oo`03001oogoo00eoo`003goo00<007ooOol02Woo13g_
l7oo00<007ooOol03Goo000?Ool00`00Oomoo`3nOol00`00Oomoo`0=Ool000moo`03001oogoo0?io
o`03001oogoo00eoo`003goo00<007ooOol0oWoo00<007ooOol03Goo000?Ool00`00Oomoo`3oOol0
0`00Oomoo`0<Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Woo00<007ooOol0ogoo
0Goo00<007ooOol037oo000>Ool00`00Oomoo`3oOol1Ool00`00Oomoo`0<Ool000ioo`03001oogoo
0?moo`5oo`03001oogoo00aoo`003Woo00<007ooOol0ogoo0Goo00<007ooOol037oo000>Ool00`00
Oomoo`0;Ool2?NocOol00`00Oomoo`0<Ool000ioo`03001oogoo00Uoo`03?Nml07`000=l0?5oo`03
001oogoo00aoo`003Woo00<007ooOol027oo00<mkg`0O00017`017oo1Cg_j7oo00<007ooOol037oo
000>Ool00`00Oomoo`08Ool00cg_O01l0004O004Ool6?NoWOol00`00Oomoo`0<Ool000ioo`03001o
ogoo00Qoo`Ml00Aoo`HmknQoo`03001oogoo00]oo`003Woo00<007ooOol027oo1W`000<mkgooOol0
0Woo1cg_igoo00<007ooOol02goo000=Ool00`00Oomoo`08Ool00goPO01l0003O00>?NoVOol00`00
Oomoo`0;Ool000eoo`03001oogoo00Qoo`03On1l07`000=l00lmknEoo`03001oogoo00]oo`003Goo
00<007ooOol027oo00=oh7`PO2000W`P43g_iGoo00<007ooOol02goo000=Ool00`00Oomoo`08Ool6
O20??NoUOol00`00Oomoo`0;Ool000eoo`03001oogoo00Qoo`El80Ioo`XmknEoo`03001oogoo00]o
o`003Goo00<007ooOol027oo1G`P2Goo23g_i7oo00<007ooOol02goo000=Ool00`00Oomoo`08Ool4
O20<Ool6?NoTOol00`00Oomoo`0;Ool000eoo`03001oogoo00Qoo`Al80eoo`Hmkn=oo`03001oogoo
00]oo`003Goo00<007ooOol027oo17`P37oo1cg_hgoo00<007ooOol02goo000=Ool00`00Oomoo`07
Ool6O20;Ool:?NoPOol00`00Oomoo`0;Ool000ioo`03001oogoo00Ioo`El80aoo`Xmkn1oo`03001o
ogoo00]oo`003Woo00<007ooOol01Woo1G`P37oo2cg_ggoo00<007ooOol02goo000>Ool00`00Oomo
o`06Ool4O2000goPOomoo`0;Ool:?NoNOol2000=Ool000ioo`03001oogoo00Ioo`El811oo`Pmkmeo
o`03001oogoo00aoo`003Woo00<007ooOol01Woo1W`P3goo23g_gGoo00<007ooOol037oo000>Ool0
0`00Oomoo`06Ool5O2000go0Oomoo`0=Ool8?NoMOol00`00Oomoo`0<Ool000ioo`03001oogoo00Mo
o`Al8003Ol1oogoo00ioo`Pmkmaoo`03001oogoo00aoo`003Woo00<007ooOol01goo17`P00=o`7oo
Ool03Woo23g_g7oo00<007ooOol037oo000>Ool00`00Oomoo`07Ool4O2000go0Oomoo`0>Ool8?NoL
Ool00`00Oomoo`0<Ool000ioo`03001oogoo00Moo`Al8003O41oogoo00ioo`Tmkm]oo`03001oogoo
00aoo`003Woo00<007ooOol01goo0g`P20002Woo2Sg_fWoo00<007ooOol037oo000>Ool00`00Oomo
o`07Ool30002O406Ool30008Ool9?NoJOol00`00Oomoo`0<Ool000moo`03001oogoo00=oo`<00003
Ooml@7a0009l@0Uoo`03001oogoo00Ioo`PmkmUoo`03001oogoo00eoo`003goo00@007ooOomoo`80
00Aoo`Al@003Oj1oogoo00Moo`8000Moo`LmkmUoo`03001oogoo00eoo`003goo00@007ooOol000Io
o`El@0]oo`03001oogoo00Aoo`Dmkm]oo`03001oogoo00eoo`003goo00<007oo00001goo1Ga037oo
0P00i7oo00<007ooOol03Goo000?Ool00`00Ool00007Ool5O40>Ool00`00Oomoo`3QOol00`00Oomo
o`0=Ool000moo`8000Qoo`El@003Oj1oogoo00aoo`03001oogoo0>1oo`03001oogoo00eoo`003goo
0P002Goo17a000=oX7ooOol037oo00<007ooOol0ggoo00<007ooOol03Woo000?Ool20009Ool4O40@
Ool00`00Oomoo`3NOol00`00Oomoo`0>Ool000ioo`03001oo`0000Uoo`Al@15oo`03001oogoo0=eo
o`03001oogoo00ioo`003Goo00D007ooOomoo`0000Qoo`Al@15oo`03001oogoo0=aoo`03001oogoo
00moo`003Goo00D007ooOomoo`0000Qoo`Al@15oo`03001oogoo0=aoo`03001oogoo00moo`003Goo
00D007ooOomoo`0000Qoo`El@15oo`03001oogoo0=]oo`03001oogoo00moo`0037oo00<007ooOol0
0Woo00<007ooOol01Woo1Wa047oo00<007ooOol0fgoo00<007ooOol03goo000<Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool5O4000gaPOomoo`0>Ool00`00Oomoo`3KOol00`00Oomoo`0?Ool000aoo`03
001oogoo009oo`03001oogoo00Ioo`03Oh1l@7a000=l@11oo`03001oogoo0=]oo`03001oogoo00mo
o`0037oo00<007ooOol00goo00<007ooOol01Woo1Ga047oo00<007ooOol0fWoo00<007ooOol047oo
000<Ool00`00Oomoo`03Ool00`00Oomoo`06Ool5O40@Ool00`00Oomoo`3JOol00`00Oomoo`0@Ool0
00aoo`03001oogoo00=oo`03001oogoo00Ioo`El@003O61oogoo00eoo`03001oogoo0=Yoo`03001o
ogoo011oo`003Goo00<007ooOol00goo00<007ooOol01Goo1GaP00=oP7ooOol03Goo00<007ooOol0
fGoo00<007ooOol04Goo000=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00gn0O61lH002O60@Ool0
0`00Oomoo`3IOol00`00Oomoo`0AOol000eoo`03001oogoo00=oo`03001oogoo00Ioo`AlH0moo`03
001oogoo0=Yoo`03001oogoo015oo`003Goo00<007ooOol017oo00<007ooOol01Goo17aP00=oP7oo
Ool037oo00<007ooOol0fGoo00<007ooOol04Woo000>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool4
O6000gb0Oh1oo`0;Ool00`00Oomoo`3JOol00`00Oomoo`0BOol000ioo`03001oogoo00=oo`03001o
ogoo00Eoo`AlH003O81oH7oo00]oo`03001oogoo0=Yoo`03001oogoo019oo`003goo00<007ooOol0
0goo00<007ooOol017oo0gaP2P0017oo00<007ooOol0fWoo00<007ooOol04goo000@Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool=00001Goo000007oo0000gGoo00<007ooOol04goo000AOol00`00Oomo
o`02Ool00`00Oomoo`0300000gooO81lP002O8000gmPOomoo`04Ool2000017oo00000000g7oo00<0
07ooOol04goo000BOol20002Ool00`00Ool000020002Ool4O8000gmPOomoo`06Ool20002Ool00`00
Oomoo`3HOol00`00Oomoo`0DOol001Aoo`03001oo`00008000Aoo`AlP003Of1oogoo00Eoo`<000=o
o`03001oogoo0=Moo`03001oogoo01Aoo`005Goo100017oo1Gb01Goo0P000goo00D007ooOomoo`00
0=Moo`03001oogoo01Eoo`0057oo00<007ooOol00P0017oo1Gb00Woo0`001Woo00@007ooOomoo`80
0=Eoo`03001oogoo01Eoo`004goo00D007ooOol007oo00@0009oo`9lP0@000Yoo`03001oogoo009o
o`03001oogoo0=5oo`03001oogoo01Ioo`004Woo00@007ooOol000=oo`03001oogoo00@000=lP0ao
o`03001oogoo009oo`03001oogoo0=1oo`03001oogoo01Ioo`004Woo00@007ooOol000=oo`03001o
ogoo009oo`ElP0eoo`05001oogooOol0003AOol00`00Oomoo`0GOol0015oo`04001oogoo0004Ool0
0`00Oomoo`02Ool5O8000gmPOomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`3>Ool00`00Oomoo`0G
Ool0011oo`05001oogooOol00005Ool01000Oomoogoo1Gb00Wm02goo00<007ooOol00goo00<007oo
Ool0c7oo00<007ooOol067oo000@Ool01@00Oomoogoo00001Goo00<007ooOol00Woo1Gb000=o@7oo
Ool02Woo00<007ooOol00Woo00<007ooOol0c7oo00<007ooOol067oo000?Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool01000Oomoogoo1Wb037oo00<007ooOol00goo00<007ooOol0bWoo00<007ooOol0
6Goo000?Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06O80<Ool00`00Oomoo`03Ool0
0`00Oomoo`39Ool00`00Oomoo`0JOol000moo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo
Ool5O80<Ool00`00Oomoo`04Ool00`00Oomoo`38Ool00`00Oomoo`0JOol000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00ElP0]oo`8000Ioo`03001oogoo0<Moo`03001oogoo01]oo`00
3Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01GbP2goo00<007ooOol01Goo00<007oo
Ool0agoo00<007ooOol06goo000>Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`04O:0;
Ool00`00Oomoo`05Ool00`00Oomoo`36Ool00`00Oomoo`0LOol000ioo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00AlX0]oo`03001oogoo00Eoo`03001oogoo0<Ioo`03001oogoo01aoo`00
3Woo00<007ooOol017oo00<007ooOol01goo00<007ooO:000gbP00=l`7ooOol027oo00<007ooOol0
1Goo00<007ooOol0aGoo00<007ooOol07Goo000>Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
O:1lX002O:02O<08Ool00`00Oomoo`06Ool00`00Oomoo`35Ool00`00Oomoo`0MOol000ioo`03001o
ogoo00Eoo`03001oogoo00Moo`03001lX7bP009lX0=l`0Ioo`03001oogoo00Moo`03001oogoo0<Ao
o`03001oogoo01ioo`003Woo00<007ooOol01Woo00<007ooOol01goo00<007c0O<0017c01Goo00<0
07ooOol027oo00<007ooOol0`goo00<007ooOol07goo000?Ool00`00Oomoo`05Ool20008Ool00`00
O<1l`005O<03Ool00`00Oomoo`09Ool00`00Oomoo`33Ool00`00Oomoo`0OOol000moo`03001oogoo
00Moo`8000Moo`03001l`7c000Il`003001oogoo00Yoo`03001oogoo0<9oo`03001oogoo021oo`00
3goo00<007ooOol02Goo00<007ooOol01Goo00<007c0O<000gc00P0000=l`7ooOol02Goo00<007oo
Ool0`Woo00<007ooOol08Goo000?Ool00`00Oomoo`0:Ool20006Ool2O`030003O<000gcPOomoo`08
Ool00`00Oomoo`32Ool00`00Oomoo`0QOol0011oo`03001oogoo00]oo`P000Il`09lh0Qoo`03001o
ogoo0<9oo`03001oogoo029oo`0047oo00<007ooOol04Woo00<007l0O<0017c00gcP1goo00<007oo
Ool0`Goo00<007ooOol08goo000AOol00`00Oomoo`0BOol00`00O`1l`003O<05O>04Ool00`00Oomo
o`31Ool00`00Oomoo`0TOol0019oo`03001oogoo019oo`03001o07cP00Qlh09oo`03001oogoo0<5o
o`03001oogoo02Eoo`004Woo0P0057oo00<007l0O>001gcP00=nh000O^00`Woo00<007ooOol09Woo
000DOol00`00Oomoo`0BOol00`00O^1lh007O>000`00O^1oo`30Ool00`00Oomoo`0WOol001Eoo`03
001oogoo015oo`04001oogooO^04O>0200000gcPO^1oo`30Ool00`00Oomoo`0WOol001Eoo`8001=o
o`04001oogooOol2O>000`00O>1lh002O>000gkPOomoo`2mOol00`00Oomoo`0XOol001Moo`03001o
ogoo015oo`05001oogooOol00006O>000gkPOomoo`2kOol00`00Oomoo`0YOol001Qoo`80019oo`04
001oo`00Ool7O>2lOol00`00Oomoo`0ZOol001Yoo`8000ioo`@0009oo`Qlh;Yoo`03001oogoo02]o
o`0077oo10001Woo100017oo00<007ooOol027cP^7oo00<007ooOol0;7oo000POol60009Ool00`00
Oomoo`08O>2fOol00`00Oomoo`0]Ool002moo`04001oogooOol8O>000gd0Oomoo`2bOol00`00Oomo
o`0]Ool0031oo`04001oogooOol7O>02O@2bOol00`00Oomoo`0^Ool0035oo`04001oogooOol6O>03
O@2`Ool00`00Oomoo`0_Ool0039oo`04001oogooOol5O>03O@2_Ool00`00Oomoo`0`Ool003=oo`80
00=oo`Mm0:aoo`8003=oo`00=Goo00@007ooOomn`0Mm0:Yoo`03001oogoo03=oo`00=Woo00@007oo
Oomn`0Mm0:Qoo`03001oogoo03Aoo`00=goo00<007ooOol00Wk01gd0YGoo00<007ooOol0=Goo000h
Ool01000Oomoogoo27d0Xgoo00<007ooOol0=Woo000iOol00`00Oomoo`09O@2QOol00`00Oomoo`0g
Ool003Yoo`80009oo`Qm09ioo`8003Yoo`00?7oo00<007ooOol027d000=nX7ooOol0VGoo00<007oo
Ool0>Woo000mOol00`00Oomoo`09O@2IOol00`00Oomoo`0kOol003ioo`03001oogoo009nX0Im0003
OB1nP7oo09Eoo`03001oogoo03aoo`00?goo0P0000=oogjPOZ001Gd00WdP00=nP7ooOol0TGoo0P00
?goo0011Ool00`00Oomoo`05O@03OB000gj0Oomoo`2?Ool00`00Oomoo`0oOol0049oo`800003Oomm
87dP00Im8003OX1oogoo03eoo`T004Moo`03001oogoo041oo`00A7oo00<007ooOB0027dP>Woo1000
2Goo0`00@goo00<007ooOol0@Goo0015Ool00`00Oomm8008OB0gOol2000@Ool4000mOol20014Ool0
04Ioo`8000Qm809m@3=oo`8001Ioo`03001oogoo03Qoo`8004Ioo`00B7oo00<007dPOB001GdP1Ge0
;Woo0P006Goo00<007ooOol0=Goo0P00B7oo001:Ool00`00OB1m8003OB0;OD0WOol00`00Oomoo`0I
Ool2000dOol2001:Ool004aoo`Am80]m@09nH2Aoo`03001oogoo01aoo`03001oogoo02moo`8004ao
o`00CWoo3Ge00WeP0WiP8Goo00<007ooOol07Woo00<007ooOol0;Goo00<007ooOol0C7oo001?Ool0
0`00OX1m@009OD04OF02OV0NOol00`00Oomoo`0OOol2000/Ool2001?Ool0055oo`03001nP7j000Mm
@0QmH003OommP7oo01Uoo`03001oogoo025oo`03001oogoo02Moo`80055oo`00Dgoo0P000goo3WeP
00=oogf0Ool05Goo00<007ooOol08goo00<007ooOol097oo0P00Dgoo001EOol20002Ool=OF03OH00
0gooOH1oo`05Ool4OP09Ool00`00Oomoo`0SOol00`00Oomoo`0ROol2001EOol005Moo`80009oo`]m
H0ImP005OommP7ooOT1n8004OP08Ool00`00Oomoo`0UOol00`00Oomoo`0OOol2001GOol005Uoo`<0
00=oo`MmH0UmP003OT1mP7h000=n0003OR1oogoo00Eoo`03001oogoo02Eoo`03001oogoo01aoo`<0
05Uoo`00G7oo0`000Woo0Wi03gf00Wh000=mP7h0OR001Goo00<007ooOol09goo00<007ooOol067oo
0`00G7oo001OOol30003Ool00gi0OH1mP00>OH000gh0OH1oo`03Ool00`00Oomoo`0WOol00`00Oomo
o`0FOol2001OOol0069oo`<000Aooa1mP003OP1mP00002Yoo`03001oogoo01=oo`<0065oo`00IGoo
0`0017oo3gf000<007gPOJ001goo0WfP2Goo0Wg057oo00<007ooOol03goo1000I7oo001XOol30004
Ool<OH001P00OH1mP7f0Oommh0=oo`imX003OL1oogoo019oo`03001oogoo00]oo`<006Qoo`00Jgoo
0`001Goo27f000@007f0OH1mP1=mX003OL1oogoo019oo`03001oogoo00Qoo`<006]oo`00KWoo1@00
0goo17f000<007f0OH000Wf04gfP00=m`7ooOol04Woo00<007ooOol017oo1000KWoo001cOol40000
17ooOP1mP00017f04gfP00=m`7ooOol04Woo00<007oo00001000LWoo001gOol400000ggPOJ1mX009
OJ04ON08OL0?Ool7001gOol007]oo`04001oogoo000<ON08OL04Ool;0005Ool00`00Oomoo`1fOol0
07]oo`03001oogoo00]oo`h0011oo`03001oogoo07Ioo`00Ngoo00<007ooOol0:7oo00<007ooOol0
Mgoo001kOol00`00Oomoo`0XOol00`00Oomoo`1gOol007aoo`03001oogoo02Moo`03001oogoo07Mo
o`00O7oo00<007ooOol09goo00<007ooOol0Mgoo001mOol00`00Oomoo`0UOol00`00Oomoo`1hOol0
07eoo`03001oogoo02Eoo`03001oogoo07Qoo`00OWoo00<007ooOol08goo00<007ooOol0NGoo001n
Ool00`00Oomoo`0ROol00`00Oomoo`1jOol007moo`03001oogoo021oo`03001oogoo07]oo`00P7oo
00<007ooOol07Woo00<007ooOol0O7oo0020Ool2000OOol00`00Oomoo`1lOol0089oo`03001oogoo
01Yoo`8007moo`00Pgoo00<007ooOol067oo00<007ooOol0Ogoo0024Ool2000FOol20022Ool008Io
o`03001oogoo015oo`8008Aoo`00Qgoo1@0037oo0P00QWoo002<Ool400000goo000000050028Ool0
091oo`03001oogoo08eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00SWoo0P00
T7oo002=Ool01000Oomoo`00Sgoo002@Ool00`00Oomoo`2=Ool008ioo`80091oo`00SWoo00<007oo
Ool0Sgoo002>Ool3002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-188.129, -179.124, 1.30587, \
1.39536}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.491793 0.00275285 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(6)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.467984 scale
1.05 1.05087 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .38895 m
.08448 .38882 L
.08463 .38863 L
.08481 .38837 L
.08501 .38803 L
.08522 .3876 L
.08542 .38707 L
.08562 .38646 L
.08581 .38579 L
.08602 .38505 L
.08626 .38421 L
.08654 .38331 L
.08686 .38239 L
.08716 .38144 L
.08743 .38049 L
.08772 .37958 L
.088 .37873 L
.08829 .37789 L
.08859 .37703 L
.08891 .37613 L
.08923 .37519 L
.08951 .37426 L
.08973 .37328 L
.08987 .37224 L
.08993 .37113 L
.0899 .37005 L
.08981 .36885 L
.08971 .36767 L
.08963 .36647 L
.08956 .36519 L
.08951 .36388 L
.0895 .36268 L
.0895 .36149 L
.08949 .36038 L
.08949 .35941 L
.08952 .35855 L
.08958 .3578 L
.08969 .35715 L
.08983 .35657 L
.09 .35597 L
.09019 .35531 L
.09037 .35457 L
.09055 .35373 L
.09073 .35273 L
.09096 .35157 L
.09126 .35048 L
.09164 .34917 L
.0921 .34781 L
.09264 .3462 L
.09322 .34468 L
Mistroke
.09382 .34295 L
.09442 .34104 L
.09499 .33927 L
.09554 .33743 L
.09606 .33564 L
.09658 .33387 L
.09711 .33244 L
.09765 .331 L
.09819 .32969 L
.09867 .3286 L
.09908 .32758 L
.09941 .32676 L
.09966 .3261 L
.09987 .3256 L
.10005 .32527 L
.10024 .32511 L
.10045 .32511 L
.10063 .32522 L
.10076 .32539 L
.10083 .32557 L
.10083 .32569 L
.10076 .3257 L
.10062 .32556 L
.10043 .32527 L
.10021 .32482 L
.09997 .32423 L
.09971 .32351 L
.09945 .32269 L
.09919 .32188 L
.09893 .32097 L
.09868 .32001 L
.09844 .31903 L
.09823 .31819 L
.09807 .31743 L
.09794 .31683 L
.09785 .31643 L
.09779 .31629 L
.09776 .31642 L
.09778 .31677 L
.09782 .31728 L
.09787 .31785 L
.09794 .31843 L
.09806 .31894 L
.09823 .31936 L
.09845 .31965 L
.09873 .31977 L
.09906 .31971 L
.09944 .31948 L
.09988 .31906 L
.10037 .31848 L
Mistroke
.1009 .31778 L
.10147 .31698 L
.10202 .31608 L
.10254 .31515 L
.10305 .3143 L
.10353 .3136 L
.10397 .313 L
.10439 .31248 L
.10479 .31202 L
.10519 .31161 L
.1056 .31121 L
.10604 .31078 L
.10652 .31027 L
.10703 .30967 L
.10757 .30893 L
.10816 .30803 L
.1088 .30694 L
.10946 .30579 L
.11008 .30437 L
.1107 .30278 L
.11132 .30123 L
.11189 .29952 L
.11238 .29781 L
.11278 .29611 L
.1131 .29459 L
.11332 .29316 L
.11347 .29188 L
.11356 .29085 L
.11358 .28997 L
.11356 .28923 L
.11352 .28864 L
.11346 .28818 L
.1134 .28789 L
.11333 .28773 L
.11327 .2877 L
.11321 .28778 L
.11316 .28793 L
.11312 .28811 L
.11309 .28828 L
.11309 .2884 L
.11315 .28846 L
.11331 .28843 L
.11361 .28831 L
.11404 .28805 L
.11463 .28766 L
.11536 .28716 L
.11625 .28651 L
.11731 .28573 L
.11842 .28486 L
.11967 .28391 L
Mistroke
.12087 .28289 L
.12212 .28183 L
.12336 .28082 L
.12444 .27994 L
.12548 .2792 L
.12644 .27858 L
.12728 .27809 L
.12797 .2777 L
.12853 .27737 L
.129 .27705 L
.12937 .2767 L
.12968 .27628 L
.12996 .27577 L
.13026 .27515 L
.13061 .27442 L
.131 .27356 L
.13143 .27269 L
.13189 .27172 L
.13238 .27072 L
.13287 .26969 L
.13336 .26874 L
.13384 .26786 L
.13429 .26709 L
.1347 .26649 L
.13507 .26606 L
.13539 .26574 L
.13564 .26549 L
.13582 .26526 L
.13594 .26499 L
.13603 .2646 L
.1361 .26408 L
.13619 .2634 L
.13631 .26261 L
.13647 .26174 L
.13664 .26097 L
.13684 .25993 L
.13706 .25895 L
.13727 .25788 L
.13747 .25674 L
.13764 .25552 L
.13778 .25431 L
.13789 .25305 L
.13801 .25174 L
.13814 .25037 L
.1383 .24913 L
.13846 .24769 L
.13867 .24622 L
.13892 .24469 L
.13923 .24309 L
.13964 .24136 L
Mistroke
.14014 .23988 L
.14076 .23841 L
.1415 .23697 L
.14228 .23564 L
.14313 .23442 L
.14402 .23325 L
.14494 .2321 L
.14581 .23099 L
.14671 .22984 L
.1476 .22874 L
.14857 .22766 L
.14952 .22657 L
.15056 .22543 L
.15171 .22428 L
.15289 .22314 L
.15413 .22192 L
.1554 .22072 L
.15654 .2195 L
.15766 .2183 L
.15872 .21714 L
.15972 .21617 L
.16067 .21519 L
.16146 .21429 L
.16215 .21359 L
.1627 .21298 L
.16311 .21246 L
.16339 .21202 L
.16351 .21163 L
.16352 .21129 L
.16346 .21098 L
.16339 .21064 L
.16332 .21024 L
.16328 .20974 L
.16326 .20917 L
.16326 .20861 L
.16324 .20816 L
.16318 .20778 L
.16308 .20755 L
.16294 .20755 L
.16275 .20775 L
.16251 .2082 L
.16224 .20887 L
.16195 .2097 L
.16165 .21056 L
.16137 .21166 L
.1611 .21267 L
.16088 .21367 L
.16072 .21458 L
.16066 .21533 L
.16071 .21589 L
Mistroke
.16091 .21623 L
.16125 .21639 L
.16173 .21642 L
.16232 .21637 L
.16302 .21627 L
.1638 .21616 L
.16461 .21609 L
.16534 .21607 L
.16601 .21608 L
.16657 .21609 L
.16697 .2161 L
.16721 .21611 L
.16727 .2161 L
.16717 .21607 L
.16698 .21601 L
.16672 .21592 L
.16633 .21581 L
.16586 .2157 L
.16527 .21561 L
.16457 .21558 L
.1638 .21565 L
.16296 .21584 L
.16206 .21619 L
.1611 .2167 L
.16008 .21741 L
.15901 .21833 L
.15802 .21942 L
.15693 .22073 L
.15568 .22224 L
.15413 .22388 L
.15273 .22548 L
.15127 .2272 L
.14976 .22899 L
.14833 .2307 L
.14687 .23228 L
.14544 .23382 L
.14415 .23535 L
.14295 .23673 L
.14174 .23813 L
.14051 .23957 L
.13927 .24108 L
.1381 .24258 L
.137 .24417 L
.13592 .24593 L
.13488 .24784 L
.13392 .24967 L
.13302 .25172 L
.13217 .25371 L
.13136 .25575 L
.13065 .25763 L
Mistroke
.13006 .25927 L
.12958 .26075 L
.12923 .26202 L
.12897 .26298 L
.12877 .26373 L
.12859 .26433 L
.12841 .26479 L
.12819 .26515 L
.12788 .26548 L
.12747 .26581 L
.12697 .26617 L
.12639 .26656 L
.12573 .26701 L
.12509 .26751 L
.12428 .26817 L
.1235 .26891 L
.12264 .26978 L
.12172 .27076 L
.12078 .27183 L
.11987 .27298 L
.119 .27422 L
.11823 .27543 L
.11745 .27672 L
.1167 .27805 L
.11598 .2794 L
.11528 .28073 L
.11457 .28215 L
.11392 .28369 L
.11341 .28523 L
.11302 .2867 L
.11269 .28812 L
.11239 .28954 L
.11208 .29071 L
.11172 .29193 L
.11124 .29305 L
.11062 .29424 L
.10995 .29552 L
.10908 .29674 L
.10808 .29799 L
.107 .29927 L
.10597 .30057 L
.10488 .30188 L
.10369 .30309 L
.10243 .30434 L
.10117 .30562 L
.10008 .30697 L
.09911 .30825 L
.09828 .30959 L
.09758 .31098 L
.09701 .31239 L
Mistroke
.09655 .31374 L
.09619 .31505 L
.09591 .3164 L
.09569 .31781 L
.09552 .31925 L
.09537 .32074 L
.09524 .32227 L
.09508 .32381 L
.0949 .32521 L
.0947 .32647 L
.09451 .3276 L
.09433 .32858 L
.09413 .32944 L
.09389 .33016 L
.09362 .3308 L
.09333 .33137 L
.09303 .3319 L
.09274 .33243 L
.09247 .333 L
.09221 .33365 L
.09195 .33443 L
.09169 .3354 L
.09142 .33651 L
.0911 .33777 L
.09072 .33926 L
.09028 .34105 L
.0898 .34289 L
.08933 .34495 L
.08888 .34718 L
.08848 .34916 L
.08811 .35144 L
.08775 .35349 L
.08741 .35571 L
.08708 .35811 L
.08674 .36054 L
.08641 .3627 L
.0861 .36493 L
.08582 .36729 L
.08559 .36969 L
.08541 .37173 L
.08524 .37391 L
.08507 .37599 L
.08492 .378 L
.08477 .37993 L
.08464 .38164 L
.08451 .38319 L
.08444 .38449 L
.08441 .38561 L
.0844 .38651 L
.08442 .38723 L
Mistroke
.08445 .3878 L
.08447 .38823 L
.08447 .38863 L
.08447 .38904 L
.08446 .3895 L
.08445 .39005 L
.08444 .39071 L
.08443 .39151 L
.08441 .39234 L
.08439 .39327 L
.08438 .39428 L
.08436 .39536 L
.08434 .39643 L
.08432 .39736 L
.08431 .39822 L
.0843 .39899 L
.08429 .39961 L
.08428 .40008 L
.08427 .40037 L
Mfstroke
.0843 .40008 m
.08431 .39992 L
.08431 .3997 L
.08429 .39942 L
.08426 .39906 L
.08422 .39879 L
.08421 .39838 L
.08422 .39794 L
.08427 .39744 L
.08436 .39676 L
.08451 .3961 L
.08473 .39556 L
.08498 .39482 L
.08526 .39409 L
.08553 .39331 L
.08578 .39244 L
.08603 .39141 L
.08628 .39054 L
.08654 .38963 L
.08679 .38858 L
.087 .38739 L
.08714 .3862 L
.08722 .38522 L
.08725 .38416 L
.08726 .38306 L
.08724 .3821 L
.08721 .38116 L
.0872 .38027 L
.08721 .37952 L
.08722 .37891 L
.08723 .37839 L
.08723 .37795 L
.08723 .37761 L
.08724 .37737 L
.08724 .37724 L
.08724 .37718 L
.08724 .37716 L
.08724 .37719 L
.08724 .37726 L
.08724 .37733 L
.08724 .3774 L
.08724 .37742 L
.08724 .37743 L
.08724 .37743 L
.08723 .37744 L
.08723 .37748 L
.08723 .37755 L
.08723 .37761 L
.0872 .37764 L
.08716 .37762 L
Mistroke
.08713 .37753 L
.08712 .37736 L
.08714 .37709 L
.0872 .37674 L
.08731 .37632 L
.08747 .37587 L
.08768 .37539 L
.08794 .37492 L
.08825 .37445 L
.08859 .37398 L
.08888 .37352 L
.08913 .37312 L
.08937 .37283 L
.08961 .37269 L
.08978 .37273 L
.08982 .37294 L
.08972 .37327 L
.08952 .3737 L
.08926 .3742 L
.08897 .37471 L
.08865 .37509 L
.08835 .37536 L
.08806 .37568 L
.0878 .37606 L
.0876 .37647 L
.08744 .37687 L
.08732 .37724 L
.08724 .37763 L
.08718 .37813 L
.08708 .37884 L
.08694 .37977 L
.08675 .38089 L
.08648 .38215 L
.08625 .3834 L
.08595 .38509 L
.08567 .38728 L
.08542 .38893 L
.08515 .39126 L
.08487 .39312 L
.08461 .39513 L
.0844 .39726 L
.08427 .39875 L
.08419 .40033 L
.08414 .40181 L
.08413 .4028 L
.08415 .4036 L
.08417 .40424 L
.08419 .40469 L
.08419 .40496 L
Mfstroke
.11421 .46128 m
.11439 .46138 L
.11462 .46151 L
.1149 .46168 L
.11523 .46188 L
.11562 .46212 L
.11603 .4624 L
.11655 .4628 L
.11707 .46327 L
.11765 .46383 L
.11831 .46454 L
.11899 .46531 L
.11961 .46603 L
.12027 .46688 L
.12087 .46771 L
.12145 .46854 L
.12199 .46935 L
.1225 .47011 L
.12298 .47076 L
.12341 .47133 L
.1238 .47182 L
.12411 .47221 L
.12431 .47247 L
.1244 .47261 L
.12438 .47271 L
.1243 .47287 L
.12419 .47312 L
.12409 .47345 L
.12404 .47387 L
.12408 .47439 L
.12425 .475 L
.12456 .47564 L
.12501 .47632 L
.12557 .47699 L
.12624 .47764 L
.12696 .4782 L
.12764 .47869 L
.12833 .47906 L
.12902 .47931 L
.12975 .47945 L
.13039 .4795 L
.13097 .4795 L
.13148 .47951 L
.13191 .47958 L
.13226 .47974 L
.13254 .48001 L
.1328 .48037 L
.13303 .48074 L
.13327 .48116 L
.13349 .48159 L
Mistroke
.13369 .48199 L
.13385 .48239 L
.13396 .48276 L
.134 .4831 L
.13395 .48337 L
.13382 .48354 L
.13361 .4836 L
.13333 .48359 L
.13301 .48353 L
.13268 .48345 L
.13236 .48341 L
.13209 .4835 L
.13189 .48377 L
.13177 .48425 L
.13173 .48491 L
.13178 .48574 L
.13191 .48671 L
.13209 .48777 L
.13232 .48874 L
.13256 .48975 L
.13277 .49075 L
.13298 .49173 L
.13314 .49268 L
.13331 .49337 L
.13347 .49403 L
.13362 .49457 L
.13375 .49502 L
.13388 .49544 L
.13404 .4959 L
.13426 .4965 L
.13454 .49728 L
.13492 .49826 L
.13538 .49929 L
.13592 .50051 L
.13652 .50189 L
.13717 .50342 L
.13782 .50489 L
.13837 .50625 L
.13891 .50756 L
.13937 .50863 L
.13982 .50957 L
.14026 .51036 L
.14069 .51097 L
.14113 .5114 L
.14158 .5117 L
.14205 .51191 L
.14254 .51206 L
.143 .51217 L
.14346 .51228 L
.1439 .51241 L
Mistroke
.14438 .51259 L
.14489 .5128 L
.14538 .51303 L
.14581 .51322 L
.14613 .51334 L
.1463 .51338 L
.14632 .51331 L
.14621 .5131 L
.146 .51279 L
.14571 .51245 L
.14538 .51209 L
.14503 .51175 L
.1447 .51151 L
.14438 .51139 L
.14409 .51143 L
.14384 .51169 L
.14367 .51224 L
.14358 .51312 L
.14358 .51433 L
.14365 .51577 L
.14376 .51741 L
.14392 .51937 L
.1441 .52162 L
.14431 .52367 L
.14453 .52609 L
.14477 .5282 L
.14504 .53041 L
.1453 .5326 L
.14557 .53435 L
.14584 .53594 L
.1461 .53732 L
.14632 .53845 L
.14652 .53929 L
.1467 .53992 L
.14689 .54036 L
.14707 .54065 L
.14724 .54083 L
.14739 .54095 L
.14747 .541 L
.1475 .54097 L
.14748 .54088 L
.14743 .54077 L
.14737 .54064 L
.14734 .54055 L
.14734 .54053 L
.14739 .54061 L
.14751 .5408 L
.1477 .54107 L
.148 .54145 L
.14841 .54191 L
Mistroke
.14893 .54246 L
.14955 .54306 L
.15027 .54372 L
.15108 .54446 L
.15192 .54528 L
.15282 .54611 L
.15376 .54693 L
.15469 .54771 L
.15554 .54843 L
.15636 .54913 L
.15712 .54981 L
.1578 .55048 L
.15838 .55113 L
.15885 .5518 L
.15922 .55252 L
.1595 .55327 L
.15969 .554 L
.1598 .55465 L
.15984 .55517 L
.1598 .55561 L
.15969 .55594 L
.15949 .55613 L
.15921 .55615 L
.15888 .55601 L
.15851 .55572 L
.15817 .55533 L
.15787 .55487 L
.15762 .55436 L
.15747 .55382 L
.15747 .55329 L
.15767 .55283 L
.15809 .55247 L
.15876 .55223 L
.15962 .55206 L
.16074 .55198 L
.16203 .55194 L
.16355 .55195 L
.16511 .55196 L
.16675 .55196 L
.16815 .55193 L
.1695 .55189 L
.17054 .55185 L
.17134 .55184 L
.17182 .55185 L
.17193 .55189 L
.17169 .55194 L
.17118 .55198 L
.17044 .55202 L
.16952 .55206 L
.1686 .5521 L
Mistroke
.16761 .55216 L
.16655 .55221 L
.16553 .55219 L
.16466 .55208 L
.16396 .55183 L
.16343 .55137 L
.16301 .5507 L
.16267 .54979 L
.16236 .54859 L
.16205 .54706 L
.16168 .54522 L
.16119 .54339 L
.16058 .54121 L
.15984 .53866 L
.15897 .5362 L
.15809 .53353 L
.15707 .53069 L
.15598 .52798 L
.1549 .52543 L
.1538 .52301 L
.15273 .52065 L
.15179 .51888 L
.15098 .51723 L
.1503 .51585 L
.14978 .51486 L
.14942 .51404 L
.14918 .51344 L
.14898 .51302 L
.14877 .51275 L
.1485 .51258 L
.1481 .51249 L
.14751 .51243 L
.1467 .51238 L
.14565 .51231 L
.14448 .51217 L
.14307 .51196 L
.14144 .51167 L
.13966 .51132 L
.13802 .51094 L
.13636 .51056 L
.13475 .51021 L
.13329 .50992 L
.13207 .50964 L
.13112 .50942 L
.13039 .50918 L
.12989 .50888 L
.1296 .50846 L
.1295 .50798 L
.12958 .50751 L
.12976 .50691 L
Mistroke
.13003 .50622 L
.13035 .50539 L
.13066 .50438 L
.13094 .50328 L
.1311 .50198 L
.1311 .50043 L
.13094 .49869 L
.13068 .49688 L
.13034 .49512 L
.12996 .49325 L
.12956 .49172 L
.12916 .49026 L
.12879 .48913 L
.12848 .4882 L
.12822 .48746 L
.12804 .48705 L
.12793 .4868 L
.12789 .48669 L
.12792 .48671 L
.12803 .48688 L
.12819 .48719 L
.12839 .48757 L
.12858 .48798 L
.12876 .48834 L
.12891 .48861 L
.12901 .48876 L
.12907 .48878 L
.12907 .48863 L
.12905 .48833 L
.12902 .48793 L
.129 .48747 L
.12901 .487 L
.12902 .48651 L
.12904 .48604 L
.12906 .48559 L
.12908 .48514 L
.12914 .48471 L
.12928 .48433 L
.1295 .48405 L
.12972 .48389 L
.12988 .48385 L
.12994 .48388 L
.12986 .48394 L
.1296 .48401 L
.12902 .48402 L
.12805 .48393 L
.12672 .48371 L
.12504 .48337 L
.12299 .48294 L
.12101 .48243 L
Mistroke
.11853 .48186 L
.1159 .48129 L
.11321 .48071 L
.11041 .48015 L
.1077 .47962 L
.10474 .47913 L
.10239 .4787 L
.10015 .4783 L
.09785 .47793 L
.09582 .47759 L
.09386 .47725 L
.09199 .47691 L
.09027 .47656 L
.08881 .47622 L
.0878 .47588 L
.08656 .47554 L
.08561 .47517 L
.08467 .47476 L
.08374 .4743 L
.08287 .4738 L
.08207 .47331 L
.08133 .47281 L
.08064 .47228 L
.08002 .47171 L
.07945 .47108 L
.07891 .47044 L
.07826 .46972 L
.07757 .46887 L
.07687 .46791 L
.0762 .46694 L
.07561 .46597 L
.07513 .46506 L
.07478 .46425 L
.07458 .46358 L
.07452 .46301 L
.07459 .46257 L
.07477 .46225 L
.07502 .46204 L
.0753 .4619 L
.07561 .46181 L
.07592 .46171 L
.0762 .46158 L
.07645 .46139 L
.07669 .46112 L
.07693 .46077 L
.07717 .46034 L
.07741 .45986 L
.07765 .45939 L
.07789 .45894 L
.07813 .45849 L
Mistroke
.07836 .45806 L
.07859 .45767 L
.07883 .45736 L
.07907 .45715 L
.07933 .45703 L
.0796 .45699 L
.07984 .45701 L
.08005 .45707 L
.08021 .45714 L
Mfstroke
.08429 .39587 m
.0843 .39576 L
.08432 .39554 L
.08436 .39519 L
.08441 .39468 L
.08449 .39399 L
.08459 .3931 L
.08472 .39196 L
.08489 .39056 L
.0851 .38897 L
.08529 .387 L
.08547 .38489 L
.08569 .38247 L
.08595 .37983 L
.08623 .37732 L
.08648 .37426 L
.08677 .37168 L
.08707 .36861 L
.08739 .3658 L
.08773 .36279 L
.08811 .3594 L
.08852 .35677 L
.08894 .35397 L
.08937 .35117 L
.08979 .34832 L
.09022 .34539 L
.09066 .34315 L
.09111 .34055 L
.09157 .33816 L
.09202 .33596 L
.09246 .33379 L
.09289 .33196 L
.09331 .33023 L
.0937 .32884 L
.09406 .32765 L
.09438 .32675 L
.09467 .32602 L
.09491 .3255 L
.09511 .32516 L
.09528 .32497 L
.09541 .32489 L
.0955 .32489 L
.09555 .32497 L
.09556 .32508 L
.09555 .32519 L
.09551 .32529 L
.09546 .32534 L
.09543 .32536 L
.09542 .32537 L
.09542 .32537 L
Mistroke
.09542 .32537 L
.09542 .32537 L
.09542 .32537 L
.09542 .32537 L
.09542 .32537 L
.09542 .32537 L
.09542 .32537 L
.09543 .32539 L
.09546 .32545 L
.0955 .32552 L
.09554 .32559 L
.09556 .32561 L
.09554 .32559 L
.09548 .32549 L
.09538 .3253 L
.09522 .32502 L
.09501 .32465 L
.09475 .32419 L
.09444 .32366 L
.09413 .3231 L
.09386 .32262 L
.09361 .32222 L
.0934 .3219 L
.09326 .32165 L
.09319 .32151 L
.09322 .32147 L
.09334 .32153 L
.09354 .32167 L
.09378 .32185 L
.09407 .32205 L
.09436 .32222 L
.09467 .32234 L
.09495 .32237 L
.09518 .32228 L
.09536 .322 L
.09548 .32158 L
.09555 .32101 L
.09558 .32034 L
.09557 .31963 L
.09554 .31892 L
.0955 .31828 L
.09546 .31771 L
.09545 .31724 L
.09545 .31687 L
.09545 .31657 L
.09545 .31634 L
.09545 .31616 L
.09545 .31606 L
.09545 .31603 L
.09545 .31606 L
Mistroke
.09545 .31613 L
.09545 .31621 L
.09545 .31626 L
.09545 .31629 L
.09545 .31629 L
.09544 .3163 L
.09541 .31632 L
.09537 .31637 L
.09533 .31644 L
.09531 .3165 L
.09532 .31654 L
.09538 .31651 L
.09548 .31642 L
.09563 .31624 L
.09583 .31598 L
.09606 .31564 L
.09631 .31524 L
.09657 .3148 L
.09684 .31434 L
.09709 .31388 L
.09735 .31343 L
.09759 .31299 L
.0978 .31257 L
.09797 .31221 L
.09809 .31191 L
.09815 .31171 L
.09817 .31159 L
.09816 .31156 L
.09812 .31158 L
.09808 .31165 L
.09805 .31172 L
.09803 .31178 L
.09803 .3118 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31181 L
.09803 .31182 L
.09803 .31186 L
.09801 .31191 L
.09798 .312 L
.09793 .31208 L
.09789 .31214 L
Mistroke
.09785 .31215 L
.09783 .31209 L
.09784 .31194 L
.09792 .31165 L
.09807 .31123 L
.09829 .31066 L
.09858 .30996 L
.09895 .30916 L
.09939 .30823 L
.09989 .30721 L
.10046 .30617 L
.10108 .30507 L
.10175 .30395 L
.1024 .30287 L
.10304 .3019 L
.10364 .30103 L
.10419 .30028 L
.10464 .29967 L
.10501 .29921 L
.1053 .29886 L
.10552 .2986 L
.10567 .29842 L
.10578 .29829 L
.10585 .29823 L
.10588 .2982 L
.10588 .29821 L
.10586 .29822 L
.10582 .29824 L
.10578 .29828 L
.10574 .29832 L
.10573 .29835 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
Mistroke
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10573 .29836 L
.10572 .29836 L
.10571 .29836 L
.10567 .29836 L
.10563 .29836 L
.10559 .29836 L
.10555 .29836 L
.10555 .29837 L
.1056 .29841 L
.10571 .29844 L
.10587 .29847 L
.10608 .29849 L
.10634 .2985 L
.10665 .29849 L
.10698 .29846 L
.1073 .2984 L
.10761 .29832 L
.1079 .2982 L
.10819 .29803 L
.10844 .29778 L
.10868 .2974 L
.10893 .29696 L
.1092 .29643 L
.10954 .29577 L
.11003 .29508 L
.11067 .29421 L
.11139 .2932 L
.11236 .29204 L
.11344 .29082 L
.11477 .2895 L
.11614 .28809 L
.11765 .28668 L
.11913 .28531 L
.12057 .28414 L
.12169 .28308 L
.12292 .28206 L
.12389 .28122 L
.12473 .28042 L
.12541 .2796 L
.12599 .27876 L
Mistroke
.12652 .27786 L
.12703 .27683 L
.12755 .27561 L
.12811 .27421 L
.12868 .27278 L
.12916 .27128 L
.12974 .26942 L
.13035 .26762 L
.13103 .26563 L
.13162 .26353 L
.13218 .26172 L
.1327 .25992 L
.13317 .25817 L
.13362 .25651 L
.13409 .25504 L
.13461 .25363 L
.13522 .25223 L
.13591 .25078 L
.1368 .24928 L
.1378 .24794 L
.13898 .2464 L
.1403 .24481 L
.14177 .24325 L
.14326 .24158 L
.14497 .23989 L
.14637 .23826 L
.14776 .2366 L
.14917 .23506 L
.15041 .23356 L
.1516 .2322 L
.15265 .23092 L
.15369 .22969 L
.15456 .22858 L
.15538 .2275 L
.15614 .22642 L
.15684 .22528 L
.15751 .22418 L
.15809 .22297 L
.15865 .22163 L
.15917 .2202 L
.15963 .21862 L
.16007 .21688 L
.16051 .21526 L
.16097 .21336 L
.16147 .21147 L
.162 .20928 L
.16258 .20708 L
.16323 .20495 L
.16399 .2026 L
.16488 .2002 L
Mistroke
.16579 .19816 L
.16684 .19615 L
.1679 .19414 L
.16907 .1922 L
.17032 .19048 L
.17153 .1887 L
.17285 .18689 L
.17427 .18519 L
.17573 .18348 L
.17727 .18186 L
.17872 .18028 L
.18019 .17888 L
.18167 .17752 L
.18304 .17623 L
.18438 .17511 L
.18567 .17408 L
.1868 .17321 L
.18786 .17247 L
.18869 .17189 L
.18937 .1715 L
.18987 .17129 L
.19018 .17126 L
.19029 .17136 L
.19023 .17155 L
.19006 .17175 L
.18986 .17192 L
.18969 .17197 L
.18961 .17184 L
.18969 .17148 L
.18996 .17088 L
.19043 .17001 L
.1911 .16885 L
.19192 .16753 L
.19287 .16589 L
.19393 .16393 L
.19497 .16201 L
.19612 .15981 L
.19748 .1572 L
.19881 .155 L
.20025 .15277 L
.20156 .15051 L
.20281 .1484 L
.20395 .1465 L
.20494 .14504 L
.20586 .1437 L
.20672 .14267 L
.20757 .14182 L
.20838 .14113 L
.20915 .14057 L
.20987 .14013 L
Mistroke
.21052 .13979 L
.21111 .13953 L
.2117 .13935 L
.21232 .13923 L
.21302 .13915 L
.21384 .13907 L
.2148 .13895 L
.21591 .13881 L
.21715 .13867 L
.21831 .13857 L
.21958 .13851 L
.22064 .13849 L
.22178 .13851 L
.22287 .13859 L
.22376 .13873 L
.22455 .13892 L
.2252 .13911 L
.22566 .13925 L
.22595 .13932 L
.22611 .13929 L
.22622 .13912 L
.22637 .13879 L
.22667 .13828 L
.22718 .13757 L
.22795 .13663 L
.22902 .13546 L
.23027 .13418 L
.23183 .13253 L
.23354 .13078 L
.23562 .12875 L
.23751 .12654 L
.23967 .12427 L
.24197 .12193 L
.24385 .11971 L
.24582 .11755 L
.24764 .11555 L
.24917 .11387 L
.25055 .11233 L
.25172 .11097 L
.25268 .10988 L
.2535 .109 L
.2542 .10836 L
.25482 .10795 L
.2554 .10774 L
.25596 .10768 L
.25655 .10773 L
.25716 .10784 L
.25782 .10798 L
.25848 .10811 L
.2591 .10823 L
Mistroke
.25968 .10833 L
.26023 .10841 L
.26073 .10843 L
.26118 .10843 L
.26158 .10839 L
.26192 .10833 L
.26219 .10825 L
.26243 .10818 L
.26263 .10813 L
.26281 .1081 L
.26299 .10811 L
.26318 .10813 L
.26336 .10834 L
.26357 .10828 L
.2638 .10818 L
.26401 .10804 L
.2642 .1079 L
.26435 .10776 L
.26444 .10761 L
.26448 .10745 L
.26445 .10724 L
.2644 .10704 L
.26433 .10677 L
.26428 .1065 L
.26426 .1062 L
.2643 .10585 L
.26442 .10554 L
.26459 .10525 L
.26482 .10502 L
.26509 .10476 L
.2654 .10448 L
.26574 .10418 L
.26614 .10389 L
.26659 .1036 L
.26711 .10331 L
.26769 .10302 L
.26835 .10272 L
.26908 .10242 L
.2699 .1021 L
.27079 .10174 L
.27171 .10132 L
.27271 .10085 L
.27375 .10038 L
.27486 .09993 L
.27599 .09952 L
.27713 .09913 L
.27823 .09877 L
.27929 .09844 L
.28021 .09818 L
.28101 .098 L
Mistroke
.28164 .09792 L
.28213 .09789 L
.2825 .09787 L
.28282 .09781 L
.2831 .09768 L
.2834 .09744 L
.28371 .09707 L
.28406 .09657 L
.28443 .09596 L
.28484 .09531 L
.28527 .09468 L
.28567 .09403 L
.28606 .09338 L
.28641 .09283 L
.28674 .09234 L
.28704 .09193 L
.28733 .09162 L
.28763 .09141 L
.28797 .09126 L
.28838 .09112 L
.28888 .09095 L
.28949 .09071 L
.29027 .09035 L
.29119 .08986 L
.29234 .08924 L
.29363 .08854 L
.29508 .08775 L
.29673 .08691 L
.29829 .08606 L
.2999 .08522 L
.30149 .08447 L
.30304 .08377 L
.30451 .08312 L
.30593 .08252 L
.30734 .08195 L
.30871 .08139 L
.31011 .0808 L
.31151 .08013 L
.31295 .07932 L
.31441 .07836 L
.31575 .07735 L
.31712 .07615 L
.31839 .07475 L
.31963 .07332 L
.32086 .07179 L
.32204 .07032 L
.32322 .06877 L
.32441 .0673 L
.32557 .06592 L
.3268 .0645 L
Mistroke
.32809 .06329 L
.32955 .06213 L
.33115 .061 L
.33301 .05988 L
.33497 .05882 L
.33703 .05773 L
.33929 .05669 L
.34171 .05564 L
.34402 .05459 L
.34627 .05355 L
.34837 .05259 L
.35013 .0517 L
.35198 .05091 L
.35372 .05029 L
.35535 .04985 L
.357 .04959 L
.35864 .04949 L
.36036 .04954 L
.3621 .04969 L
.36373 .04992 L
.36507 .05021 L
.36639 .05054 L
.36752 .05087 L
.36866 .05117 L
.3698 .05142 L
.37083 .05163 L
.37162 .05176 L
.37213 .05184 L
.3724 .05188 L
.37248 .05189 L
.37239 .05189 L
.37215 .05188 L
.37187 .05187 L
.37164 .05186 L
.37149 .05187 L
.37144 .05187 L
.37152 .05184 L
.37174 .05177 L
.37215 .05162 L
.37273 .05134 L
.37349 .05094 L
.37441 .05039 L
.37547 .04972 L
.37653 .04893 L
.37768 .04806 L
.37893 .04711 L
.38029 .04622 L
.38158 .04527 L
.3829 .04427 L
.38423 .04339 L
Mistroke
.38549 .04255 L
.38673 .04178 L
.38794 .04111 L
.38922 .04056 L
.39063 .04012 L
.39215 .03982 L
.39379 .03962 L
.39563 .0395 L
.39765 .03944 L
.39964 .03939 L
.40168 .03936 L
.40377 .03935 L
.40572 .03936 L
.40759 .03941 L
.40932 .03946 L
.41083 .03955 L
.41223 .03964 L
.41344 .03973 L
.41439 .03979 L
.41502 .03984 L
.41534 .03987 L
.41535 .0399 L
.41509 .03991 L
.41462 .03991 L
.41401 .03989 L
.41332 .03987 L
.41259 .03983 L
.41187 .03981 L
.41115 .03978 L
.41044 .03976 L
.40976 .03974 L
.40915 .03973 L
.40868 .03971 L
.40836 .0397 L
.40818 .0397 L
.40812 .0397 L
.40815 .0397 L
.40825 .0397 L
.40836 .0397 L
.40843 .03969 L
.40843 .03964 L
.40838 .03955 L
.40831 .03945 L
.40825 .03937 L
.40825 .03933 L
.40831 .03936 L
.40845 .03948 L
.40868 .03973 L
.40899 .04014 L
.40936 .04071 L
Mistroke
.40979 .04143 L
.41025 .04231 L
.41071 .04323 L
.41119 .04429 L
.41167 .04534 L
.41214 .04641 L
.41257 .04743 L
.41293 .04829 L
.4132 .04888 L
.41335 .04924 L
.41338 .04934 L
.41329 .0492 L
.41312 .04881 L
.41291 .04819 L
.4127 .04748 L
.41252 .04664 L
.41237 .04578 L
.41223 .04489 L
.41207 .04411 L
.41187 .04337 L
.4116 .04271 L
.41123 .04218 L
.41073 .04177 L
.41009 .04149 L
.4093 .04136 L
.40827 .04132 L
.40705 .04134 L
.40557 .04136 L
.40385 .04136 L
.40185 .04131 L
.39968 .0412 L
.39749 .04104 L
.39513 .04084 L
.39288 .04063 L
.39078 .04042 L
.38872 .0402 L
.38671 .03999 L
.38508 .03977 L
.38356 .03953 L
.38216 .03929 L
.38084 .03903 L
.3796 .03879 L
.37838 .03857 L
.37719 .03841 L
.37599 .03832 L
.37468 .03831 L
.37324 .03841 L
.37181 .03863 L
.37028 .03897 L
.36857 .03941 L
Mistroke
.36675 .03993 L
.36496 .04051 L
.36339 .0412 L
.36187 .04198 L
.36043 .04277 L
.35912 .0435 L
.35797 .04421 L
.35701 .04501 L
.3562 .04573 L
.35548 .04647 L
.35481 .04723 L
.35418 .04794 L
.35358 .0487 L
.35297 .04949 L
.35235 .0503 L
.35175 .05114 L
.3512 .05197 L
.35073 .05273 L
.35029 .05345 L
.34987 .05412 L
.34946 .05472 L
.34912 .0552 L
.34886 .05555 L
.34868 .05576 L
.34858 .05588 L
.34855 .05592 L
.34858 .05587 L
.34865 .05575 L
.34872 .05562 L
.34876 .05552 L
.34878 .05547 L
.34879 .05541 L
.34881 .05537 L
.34883 .05533 L
.34887 .05526 L
.3489 .05515 L
.34894 .05502 L
.34899 .05486 L
.34905 .0547 L
.34911 .05454 L
.34918 .05439 L
.34927 .05427 L
.34936 .05418 L
.34941 .05412 L
.34937 .05409 L
.34922 .05407 L
.34895 .05404 L
.34853 .05406 L
.34796 .05414 L
.34725 .05431 L
Mistroke
.34643 .05451 L
.34548 .05481 L
.34445 .05517 L
.34332 .05557 L
.3422 .05598 L
.34098 .05638 L
.33965 .05678 L
.33827 .05719 L
.33688 .05762 L
.33543 .05811 L
.33399 .05868 L
.33252 .05933 L
.33098 .06003 L
.32938 .06081 L
.32786 .06164 L
.32632 .06256 L
.32467 .06353 L
.32301 .06449 L
.32146 .06548 L
.31995 .06647 L
.31854 .06743 L
.31731 .06827 L
.31616 .06901 L
.31511 .06962 L
.31417 .07006 L
.3134 .07034 L
.31274 .0705 L
.31217 .07059 L
.31166 .07069 L
.31119 .07084 L
.31075 .07108 L
.31029 .07147 L
.30991 .07191 L
.30946 .07256 L
.30895 .07339 L
.30839 .07439 L
.30776 .07546 L
.30702 .0767 L
.30622 .07808 L
.30536 .07941 L
.30449 .08071 L
.30363 .08192 L
.30281 .08304 L
.30206 .08402 L
.30139 .08487 L
.30082 .08563 L
.30036 .08632 L
.3 .08694 L
.29976 .08751 L
.29962 .08806 L
Mistroke
.29956 .08858 L
.29955 .08906 L
.29959 .08948 L
.29969 .0898 L
.29983 .09006 L
.29997 .09031 L
.30009 .09058 L
.30018 .09084 L
.30023 .0911 L
.30021 .09139 L
.3001 .09176 L
.29986 .09223 L
.29946 .09281 L
.29887 .09352 L
.29809 .09435 L
.29712 .0953 L
.29606 .09625 L
.29488 .09728 L
.29364 .09834 L
.29246 .09941 L
.29136 .10032 L
.29026 .10113 L
.28914 .10179 L
.28817 .10228 L
.28729 .10259 L
.28651 .10274 L
.28582 .10276 L
.28527 .10269 L
.28485 .1026 L
.28454 .10252 L
.28431 .10243 L
.2841 .10236 L
.28386 .10231 L
.28357 .10226 L
.28323 .10221 L
.28288 .10214 L
.28256 .10207 L
.28231 .102 L
.28216 .10193 L
.28211 .10188 L
.28214 .10184 L
.28217 .10182 L
.28218 .10181 L
.2822 .10182 L
.28224 .10185 L
.28234 .10188 L
.28253 .10194 L
.28278 .10203 L
.28305 .10212 L
.28329 .10222 L
Mistroke
.28348 .10229 L
.28357 .10235 L
.28352 .10237 L
.28332 .10235 L
.283 .10227 L
.28258 .10216 L
.28208 .10197 L
.28149 .1017 L
.2808 .10137 L
.28015 .10101 L
.27937 .10068 L
.27855 .10038 L
.27771 .10014 L
.27693 .09997 L
.2762 .09988 L
.27557 .09985 L
.27503 .09987 L
.27464 .09998 L
.27433 .10014 L
.27414 .10033 L
.27404 .10058 L
.27399 .10086 L
.27398 .1011 L
.27397 .10127 L
.2739 .10141 L
.27374 .10147 L
.27344 .1015 L
.27298 .10153 L
.27239 .10164 L
.27165 .10192 L
.27077 .10239 L
.26982 .10307 L
.26885 .10392 L
.26782 .10487 L
.26673 .10584 L
.26564 .10665 L
.26461 .10746 L
.26366 .1082 L
.26283 .10889 L
.26212 .10939 L
.26153 .10976 L
.26105 .10998 L
.26066 .11006 L
.26036 .10994 L
.26016 .10966 L
.26005 .10927 L
.26001 .10884 L
.26001 .10847 L
.26 .1082 L
.25996 .10803 L
Mistroke
.25982 .10799 L
.2595 .10808 L
.25897 .10831 L
.25824 .10865 L
.25729 .10907 L
.25609 .10956 L
.25485 .11014 L
.25335 .11078 L
.25173 .11142 L
.25011 .11211 L
.24837 .11281 L
.24663 .11351 L
.24495 .11421 L
.24342 .11491 L
.24187 .11566 L
.24032 .11645 L
.23884 .11729 L
.23745 .11817 L
.23627 .11906 L
.23503 .12004 L
.23384 .12109 L
.23274 .12216 L
.23171 .12334 L
.23069 .12469 L
.22976 .12601 L
.2289 .12739 L
.22815 .12877 L
.22752 .13002 L
.22702 .13108 L
.22666 .13186 L
.2264 .13243 L
.22621 .13276 L
.22606 .13287 L
.22596 .13275 L
.22588 .13247 L
.22583 .13211 L
.22581 .13175 L
.22582 .1314 L
.22587 .13114 L
.22593 .13102 L
.226 .13112 L
.22606 .1315 L
.2261 .13213 L
.22615 .13297 L
.22621 .13383 L
.22629 .13494 L
.22635 .1359 L
.22641 .1368 L
.22643 .13759 L
.22644 .13818 L
Mistroke
.22643 .13853 L
.22638 .13867 L
.22626 .13863 L
.22604 .13847 L
.22572 .13825 L
.22528 .13799 L
.22469 .13775 L
.22395 .13756 L
.22303 .13741 L
.22194 .13731 L
.22068 .13727 L
.21923 .13732 L
.21761 .13749 L
.21608 .13779 L
.21438 .13824 L
.21244 .13883 L
.21033 .13958 L
.20831 .14046 L
.2064 .14151 L
.20437 .14272 L
.20236 .14402 L
.20037 .14556 L
.19858 .14729 L
.19669 .14914 L
.19513 .15102 L
.19357 .15308 L
.19193 .15515 L
.1904 .15741 L
.18885 .15949 L
.18731 .16167 L
.18579 .16391 L
.18455 .16584 L
.18327 .16787 L
.18215 .16981 L
.18116 .17164 L
.18018 .17349 L
.17933 .17497 L
.1786 .1764 L
.17803 .17782 L
.17762 .17918 L
.17738 .18047 L
.1773 .18155 L
.17733 .18258 L
.17743 .18348 L
.17754 .18422 L
.17764 .18478 L
.17772 .18518 L
.17776 .18544 L
.17776 .18559 L
.17773 .18561 L
Mistroke
.17769 .18552 L
.17763 .18527 L
.17756 .18488 L
.1775 .1844 L
.17748 .1839 L
.17754 .18342 L
.1777 .18297 L
.17796 .18259 L
.17834 .18233 L
.17882 .18224 L
.17939 .18227 L
.18001 .18234 L
.18072 .18242 L
.18148 .1825 L
.18229 .18256 L
.18307 .18261 L
.18386 .18265 L
.18461 .18267 L
.18531 .18269 L
.1859 .18271 L
.18639 .18272 L
.18675 .18273 L
.18702 .18274 L
.18722 .18274 L
.18737 .18275 L
.18748 .18275 L
.18756 .18275 L
.18764 .18275 L
.18768 .18276 L
.1877 .18276 L
.18768 .18276 L
.18764 .18275 L
.1876 .18275 L
.18757 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
Mistroke
.18755 .18275 L
.18755 .18275 L
.18755 .18275 L
.18753 .18275 L
.1875 .18275 L
.18746 .18275 L
.18743 .18275 L
.18741 .18275 L
.18742 .18275 L
.18748 .18275 L
.18757 .18275 L
.18772 .18276 L
.1879 .18276 L
.18812 .18277 L
.18836 .18277 L
.18861 .18278 L
.18886 .18279 L
.18912 .18283 L
.18935 .18289 L
.18954 .18297 L
.18968 .18307 L
.18978 .18315 L
.18983 .1832 L
.18985 .18318 L
.18985 .18307 L
.18987 .18285 L
.18992 .18251 L
.19007 .18205 L
.19035 .18146 L
.19077 .18072 L
.19134 .17985 L
.19203 .17883 L
.19288 .17759 L
.19388 .17615 L
.19502 .17462 L
.19629 .17294 L
.19761 .17124 L
.19898 .16949 L
.20035 .16792 L
.20161 .16641 L
.2028 .16504 L
.20379 .16393 L
.20468 .16289 L
.20543 .16203 L
.20609 .16127 L
.20655 .16078 L
.20691 .16042 L
.20713 .16024 L
.20724 .16021 L
.20727 .16028 L
Mistroke
.20725 .16039 L
.20719 .16051 L
.20711 .16061 L
.20702 .16068 L
.20695 .16071 L
.20692 .16073 L
.20692 .16074 L
.20693 .16076 L
.20693 .16082 L
.20693 .1609 L
.20691 .16099 L
.20688 .16109 L
.20683 .16117 L
.20677 .1612 L
.20672 .16113 L
.2067 .1609 L
.20674 .1605 L
.20685 .15991 L
.20704 .15908 L
.20732 .15802 L
.20767 .15684 L
.20809 .15541 L
.20855 .15377 L
.20901 .15217 L
.2095 .15042 L
.20998 .14856 L
.21039 .14701 L
.21074 .14553 L
.21105 .14417 L
.21129 .14302 L
.21145 .14212 L
.21158 .14145 L
.21172 .14098 L
.21189 .14066 L
.21213 .1404 L
.21248 .14018 L
.21297 .13995 L
.21362 .13969 L
.21436 .13936 L
.21528 .13899 L
.21627 .13853 L
.2174 .13796 L
.21865 .13725 L
.21981 .13642 L
.22104 .13554 L
.22235 .13463 L
.22363 .13372 L
.22494 .13283 L
.22621 .13197 L
.22753 .13118 L
Mistroke
.22878 .1304 L
.23007 .12961 L
.23132 .12886 L
.23259 .12812 L
.23379 .12739 L
.23489 .1267 L
.23596 .12606 L
.23694 .12549 L
.23779 .12503 L
.23853 .12464 L
.23916 .1243 L
.23965 .124 L
.24002 .12372 L
.2403 .12348 L
.24049 .12332 L
.24062 .12322 L
.24069 .1232 L
.24073 .12324 L
.24074 .12331 L
.24072 .12341 L
.24067 .12352 L
.24057 .12363 L
.24045 .12372 L
.24031 .12378 L
.2402 .1238 L
.24016 .12376 L
.24022 .12362 L
.2404 .12335 L
.24072 .12295 L
.2412 .1224 L
.24185 .1217 L
.24266 .12087 L
.2436 .12 L
.24451 .11903 L
.24559 .118 L
.24661 .11698 L
.2477 .11598 L
.24858 .11504 L
.24945 .11425 L
.25028 .11358 L
.25103 .11305 L
.25166 .11266 L
.25225 .11244 L
.25283 .11237 L
.25346 .11241 L
.25416 .11252 L
.25496 .11261 L
.25584 .11265 L
.25675 .11262 L
.2577 .11252 L
Mistroke
.25874 .11234 L
.25992 .11212 L
.26117 .11192 L
.26246 .11178 L
.26376 .1117 L
.26507 .11167 L
.26635 .11165 L
.26759 .11166 L
.2688 .11171 L
.26987 .11176 L
.27089 .11188 L
.27182 .11202 L
.2726 .11218 L
.2732 .11231 L
.27365 .11238 L
.27398 .11237 L
.27419 .11225 L
.27433 .11201 L
.27444 .11159 L
.27453 .11101 L
.27464 .11039 L
.2748 .10971 L
.27503 .10901 L
.27533 .10831 L
.27565 .10761 L
.27603 .10694 L
.27646 .10632 L
.27695 .10576 L
.27745 .10528 L
.27793 .10491 L
.27836 .10468 L
.27872 .10456 L
.27903 .10454 L
.27929 .10458 L
.27953 .10464 L
.27978 .10467 L
.28007 .10462 L
.28041 .10443 L
.28081 .10405 L
.28126 .10345 L
.2818 .10258 L
.28244 .10152 L
.28315 .10017 L
.28403 .09868 L
.28499 .09696 L
.28612 .0951 L
.28742 .09317 L
.28888 .09129 L
.29057 .08934 L
.2922 .08761 L
Mistroke
.29406 .08581 L
.29577 .08431 L
.29772 .08285 L
.29967 .08159 L
.30176 .08041 L
.30398 .0793 L
.30609 .07825 L
.30825 .07732 L
.3104 .07637 L
.31248 .07538 L
.31458 .0743 L
.31668 .07318 L
.31875 .07191 L
.32101 .07046 L
.32313 .06897 L
.32538 .06736 L
.32775 .06571 L
.32997 .06392 L
.33231 .06223 L
.33478 .06044 L
.3371 .05862 L
.33952 .05709 L
.34202 .05556 L
.34432 .05408 L
.34663 .05276 L
.34879 .05158 L
.35084 .0505 L
.35252 .04956 L
.35404 .04871 L
.3553 .04795 L
.35635 .0473 L
.35715 .04674 L
.35774 .04627 L
.35814 .04586 L
.35837 .04551 L
.35845 .04522 L
.35841 .04499 L
.35829 .0448 L
.35813 .04468 L
.35797 .04461 L
.35781 .0446 L
.35768 .04463 L
.35761 .0447 L
.35761 .04478 L
.35771 .04484 L
.35794 .04486 L
.35833 .04487 L
.35891 .04487 L
.35969 .04488 L
.36066 .04489 L
Mistroke
.36184 .04492 L
.36321 .04499 L
.36453 .04509 L
.36596 .04518 L
.36731 .04525 L
.3687 .04528 L
.36985 .04523 L
.37092 .0451 L
.37191 .04487 L
.37271 .04456 L
.37341 .04419 L
.37404 .04378 L
.37462 .04335 L
.37517 .04292 L
.37568 .04249 L
.37616 .04207 L
.37666 .04168 L
.37722 .04134 L
.37784 .04105 L
.37848 .04084 L
.37912 .04071 L
.37968 .04066 L
.38018 .04068 L
.3806 .04076 L
.38095 .0409 L
.38122 .0411 L
.38142 .04134 L
.38158 .04163 L
.38178 .04195 L
.38202 .04223 L
.3823 .04245 L
.3826 .04259 L
.38294 .04267 L
.3833 .04274 L
.38366 .04281 L
.38403 .04291 L
.38441 .04302 L
.3848 .04314 L
.38525 .04324 L
.38579 .04332 L
.38641 .04339 L
.3872 .04349 L
.38798 .04364 L
.38898 .04392 L
.39016 .04435 L
.39139 .04491 L
.39285 .04555 L
.39439 .04624 L
.39621 .04694 L
.39826 .04758 L
Mistroke
.40015 .04815 L
.40225 .04863 L
.40436 .04907 L
.40648 .0495 L
.4087 .04991 L
.41075 .0503 L
.41277 .05066 L
.41472 .05096 L
.41647 .05118 L
.4182 .05129 L
.41971 .0513 L
.42102 .05119 L
.42201 .05099 L
.42277 .05073 L
.4233 .05044 L
.42368 .05014 L
.42394 .04983 L
.42415 .04949 L
.42439 .04911 L
.42474 .04869 L
.42526 .04819 L
.42598 .04761 L
.42689 .04697 L
.42794 .04621 L
.4292 .04558 L
.43065 .04489 L
.43227 .04424 L
.43392 .04366 L
.43556 .0431 L
.43721 .04254 L
.43852 .04202 L
.43969 .04151 L
.44058 .04107 L
.4413 .04072 L
.44182 .04048 L
.44214 .04036 L
.44237 .04035 L
.44262 .0404 L
.44298 .04048 L
.44348 .04057 L
.44419 .04063 L
.44513 .04068 L
.44633 .04072 L
.44759 .04077 L
.44929 .04084 L
.45106 .04094 L
.45309 .04108 L
.45538 .04126 L
.45752 .04147 L
.45987 .04171 L
Mistroke
.46208 .04197 L
.46425 .04225 L
.46633 .04252 L
.46818 .04275 L
.46987 .04295 L
.47139 .04311 L
.47267 .04324 L
.4738 .04338 L
.47474 .04352 L
.47546 .0437 L
.47597 .04393 L
.47629 .0442 L
.47646 .04452 L
.47651 .0449 L
.47648 .04532 L
.4764 .04576 L
.4763 .04621 L
.47621 .04667 L
.47613 .04713 L
.47602 .04753 L
.47589 .04785 L
.47574 .04804 L
.4756 .04808 L
.47553 .04795 L
.47556 .04769 L
.47572 .04734 L
.47605 .04691 L
.47658 .04648 L
.47734 .04603 L
.47836 .04563 L
.47955 .04524 L
.48106 .04488 L
.48255 .04457 L
.48442 .04431 L
.48635 .04409 L
.48826 .04389 L
.49045 .04368 L
.4927 .04343 L
.49499 .04315 L
.49727 .04282 L
.49946 .04242 L
.50154 .042 L
.50359 .04152 L
.50529 .04102 L
.50682 .04053 L
.5083 .04007 L
.5095 .03963 L
.51055 .03921 L
.51133 .0388 L
.51191 .03851 L
Mistroke
.51228 .03829 L
.51246 .03818 L
.51246 .0382 L
.51231 .03833 L
.51205 .03856 L
.51174 .03885 L
.51145 .03919 L
.51122 .03955 L
.51105 .03994 L
.51093 .04035 L
.51085 .04076 L
.5108 .04119 L
.5108 .04163 L
.51085 .04197 L
.51094 .04228 L
.51109 .04252 L
.5113 .04269 L
.51157 .04278 L
.51188 .04282 L
.51222 .04285 L
.5126 .04288 L
.51296 .04292 L
.5133 .04297 L
.51357 .043 L
.51374 .04298 L
.51382 .04289 L
.51382 .04271 L
.51377 .04246 L
.51369 .04214 L
.51354 .04177 L
.51332 .04137 L
.51302 .04096 L
.51267 .04055 L
.51226 .04014 L
.51181 .03969 L
.51133 .03923 L
.51085 .03878 L
.51035 .03838 L
.50986 .03804 L
.50938 .03778 L
.50895 .03757 L
.50856 .03738 L
.50813 .03719 L
.50769 .03695 L
.50719 .03668 L
.50664 .03636 L
.50599 .03598 L
.50521 .03561 L
.50418 .03525 L
.50285 .03496 L
Mistroke
.5012 .03467 L
.49914 .0344 L
.49694 .03415 L
.49431 .03391 L
.49146 .03369 L
.48856 .03347 L
.48527 .03327 L
.48253 .03311 L
.47911 .03301 L
.47637 .03296 L
.47295 .03293 L
.47022 .03288 L
.46738 .03281 L
.46439 .03273 L
.4618 .03265 L
.45899 .03256 L
.45596 .03246 L
.4534 .03232 L
.45009 .03217 L
.44739 .03201 L
.44436 .03188 L
.44077 .03181 L
.43764 .0318 L
.43413 .03187 L
.43076 .03202 L
.42708 .03225 L
.42413 .03256 L
.42105 .03292 L
.41822 .03332 L
.41552 .03374 L
.4132 .03416 L
.41119 .03453 L
.40942 .03482 L
.40808 .035 L
.40702 .03506 L
.40624 .03499 L
.4057 .03483 L
.4054 .0346 L
.40528 .03434 L
.40531 .03407 L
.40542 .03386 L
.4056 .03371 L
.40578 .03363 L
.40592 .03363 L
.40603 .03367 L
.40611 .03379 L
.40616 .03396 L
.40619 .03422 L
.40623 .03446 L
.40624 .03474 L
Mistroke
.40625 .03499 L
.40624 .03519 L
.40623 .03532 L
.40625 .03538 L
.40633 .03539 L
.40643 .03538 L
.40653 .03537 L
.40658 .03535 L
.40654 .0353 L
.4064 .03524 L
.40613 .03517 L
.40573 .03511 L
.40521 .0351 L
.4046 .03514 L
.40393 .03524 L
.40323 .0354 L
.40256 .03562 L
.40196 .03592 L
.40134 .03628 L
.4007 .03667 L
.40009 .03708 L
.39961 .03749 L
.3993 .03792 L
.39914 .03829 L
.39908 .03867 L
.3991 .03901 L
.39919 .03928 L
.3993 .03946 L
.39936 .03957 L
.39937 .0396 L
.39934 .0396 L
.39931 .03956 L
.39927 .03952 L
.39925 .03949 L
.39927 .03947 L
.39931 .03945 L
.39941 .03945 L
.39954 .03945 L
.39971 .03945 L
.39992 .03946 L
.40014 .03946 L
.40038 .03947 L
.40061 .03948 L
.40085 .03949 L
.40107 .03951 L
.40128 .03956 L
.40147 .03961 L
.40162 .03966 L
.40173 .03969 L
.4018 .03969 L
Mistroke
.40181 .03964 L
.40179 .03951 L
.40174 .0393 L
.40168 .03898 L
.40162 .0386 L
.40158 .0382 L
.40156 .03782 L
.40155 .03748 L
.40155 .03723 L
.40155 .03709 L
.40156 .03706 L
.40158 .03707 L
.40159 .03713 L
.40161 .03726 L
.40162 .03747 L
.40164 .03776 L
.40168 .03809 L
.40171 .03844 L
.40177 .03878 L
.40186 .03909 L
.40199 .03934 L
.40218 .03949 L
.4024 .03956 L
.40268 .03957 L
.40302 .03953 L
.40337 .03949 L
.40377 .03948 L
.40418 .03951 L
.40459 .03956 L
.40499 .03961 L
.40535 .03965 L
.40566 .03967 L
.40592 .03967 L
.40613 .03966 L
.40628 .03965 L
.40636 .03965 L
.40638 .03965 L
.40637 .03965 L
.40634 .03965 L
.40631 .03965 L
.40627 .03964 L
.40624 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
Mistroke
.40622 .03964 L
.40622 .03964 L
.40622 .03964 L
.40621 .03964 L
.40618 .03964 L
.40614 .03964 L
.40611 .03964 L
.40609 .03964 L
.4061 .03964 L
.40615 .03964 L
.40623 .03965 L
.40636 .03967 L
.40652 .03969 L
.40669 .0397 L
.40688 .0397 L
.40708 .03968 L
.4073 .03965 L
.40755 .03961 L
.40784 .03958 L
.40816 .03956 L
.40851 .03955 L
.40885 .03953 L
.40915 .03951 L
.40939 .03947 L
.40958 .03943 L
.40972 .03939 L
.40983 .03936 L
.40993 .03934 L
.41003 .03934 L
.41013 .03936 L
.41023 .0394 L
.41031 .03945 L
.41036 .0395 L
.41039 .03953 L
.41039 .03957 L
.41041 .0396 L
.41048 .03966 L
.41059 .03976 L
.41074 .03987 L
.41087 .03997 L
.41094 .03999 L
.41092 .03994 L
.41077 .03979 L
.41049 .03953 L
.41008 .03918 L
.40959 .03875 L
.40909 .03829 L
.40862 .03783 L
.40822 .03737 L
.40788 .03693 L
Mistroke
.40756 .03649 L
.4073 .03608 L
.40712 .03572 L
.40704 .03544 L
.40708 .03524 L
.4072 .03513 L
.40741 .0351 L
.40766 .03514 L
.40795 .03521 L
.40822 .03529 L
.40843 .03535 L
.40855 .03537 L
.40861 .03537 L
.40862 .03537 L
.40861 .03537 L
.40857 .03538 L
.40854 .03538 L
.40851 .03539 L
.40849 .0354 L
.40849 .0354 L
.40849 .03541 L
.40849 .03542 L
.40849 .03542 L
.40849 .03542 L
.40849 .03542 L
.40849 .03543 L
.40849 .03542 L
.40849 .03542 L
.40849 .03542 L
.40849 .03541 L
.40849 .0354 L
.40849 .03539 L
.40849 .03538 L
.40849 .03537 L
.40849 .03537 L
.40849 .03537 L
.40849 .03537 L
.40849 .03537 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
Mistroke
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.40849 .03538 L
.4085 .03538 L
.40852 .03539 L
.40853 .03539 L
.40854 .03538 L
.40852 .03538 L
.40849 .03537 L
.40845 .03535 L
.40839 .03534 L
.40834 .03533 L
.40829 .03532 L
.40824 .03532 L
.40821 .03531 L
.40819 .03531 L
.40818 .03531 L
.40819 .03531 L
.40822 .03532 L
.40826 .03533 L
.40831 .03534 L
.40835 .03535 L
.40836 .03536 L
.40836 .03536 L
.40832 .03536 L
.40827 .03535 L
.40821 .03535 L
.40814 .03534 L
.40807 .03533 L
Mistroke
.408 .03532 L
.40796 .03532 L
.40794 .03532 L
.40793 .03532 L
.40791 .03532 L
.40792 .03533 L
.40795 .03533 L
.40802 .03534 L
.40813 .03535 L
.40828 .03537 L
.40846 .03538 L
.40867 .03539 L
.40889 .0354 L
.4091 .0354 L
.40931 .0354 L
.40952 .03541 L
.40973 .03541 L
.40995 .03542 L
.41018 .03543 L
.41039 .03543 L
.41057 .03544 L
.41072 .03544 L
.41082 .03545 L
.41088 .03545 L
.41089 .03545 L
.41088 .03545 L
.41085 .03545 L
.41081 .03545 L
.41078 .03545 L
.41077 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41077 .03544 L
.41078 .03545 L
.41083 .03545 L
.4109 .03545 L
Mistroke
.41096 .03545 L
.41099 .03545 L
.41097 .03545 L
.41088 .03545 L
.41071 .03544 L
.41044 .03544 L
.41009 .03542 L
.40968 .03541 L
.40924 .0354 L
.40877 .03539 L
.40832 .03537 L
.40788 .03536 L
.40744 .03534 L
.407 .03533 L
.4066 .03532 L
.40627 .03531 L
.40603 .0353 L
.40589 .0353 L
.40586 .0353 L
.40593 .0353 L
.40608 .0353 L
.40628 .03531 L
.4065 .03532 L
.40673 .03532 L
.40696 .03533 L
.4072 .03534 L
.40744 .03535 L
.40767 .03535 L
.4079 .03536 L
.40811 .03537 L
.4083 .03537 L
.40844 .03538 L
.40855 .03538 L
.4086 .03539 L
.40862 .03538 L
.40861 .03538 L
.4086 .03537 L
.40858 .03536 L
.40855 .03536 L
.40853 .03535 L
.40849 .03534 L
.40845 .03534 L
.40839 .03534 L
.40834 .03535 L
.40828 .03537 L
.40824 .03537 L
.40821 .03536 L
.40819 .03534 L
.40818 .03531 L
.40816 .03528 L
Mistroke
.40814 .03524 L
.40812 .03521 L
.40811 .03518 L
.40814 .03516 L
.40821 .03516 L
.40831 .03515 L
.40846 .03516 L
.40865 .03516 L
.40885 .03517 L
.40907 .0352 L
.40929 .03524 L
.40951 .03528 L
.40972 .03533 L
.40995 .03538 L
.41018 .03543 L
.41039 .03546 L
.41057 .03548 L
.41072 .03548 L
.41082 .03547 L
.41088 .03546 L
.41089 .03545 L
.41088 .03545 L
.41085 .03545 L
.41081 .03545 L
.41078 .03545 L
.41077 .03544 L
.41076 .03544 L
.41076 .03544 L
.41076 .03544 L
.41077 .03542 L
.41079 .03537 L
.41081 .0353 L
.41081 .03524 L
.4108 .03521 L
.41077 .03523 L
.41072 .03532 L
.41067 .03549 L
.41061 .03575 L
.41056 .03607 L
.41052 .03646 L
.41049 .03688 L
.41047 .03733 L
.41046 .03776 L
.41046 .0382 L
.41046 .03863 L
.41048 .03903 L
.41051 .03938 L
.41055 .03967 L
.41061 .03987 L
.41067 .03998 L
Mistroke
.41073 .04001 L
.41079 .03998 L
.41087 .03989 L
.41095 .03979 L
.41101 .03968 L
.41102 .0396 L
.41099 .03954 L
.41089 .03952 L
.41071 .03957 L
.41045 .03971 L
.4101 .03994 L
.4097 .04029 L
.40925 .04073 L
.40879 .04127 L
.40833 .04185 L
.40789 .0425 L
.40746 .04321 L
.40704 .04392 L
.40667 .04457 L
.40636 .04516 L
.40615 .04565 L
.40606 .04599 L
.40609 .04614 L
.4062 .0461 L
.40633 .04587 L
.40644 .0455 L
.4065 .04504 L
.40645 .04455 L
.40625 .04406 L
.40597 .04358 L
.4055 .04312 L
.40479 .04267 L
.40385 .04224 L
.40274 .04183 L
.40159 .04147 L
.4004 .04114 L
.39897 .04085 L
.39724 .04061 L
.39573 .04041 L
.39406 .04026 L
.39257 .0401 L
.39104 .03993 L
.38964 .03972 L
.38852 .03949 L
.38751 .03923 L
.38661 .03893 L
.38587 .0386 L
.38532 .03824 L
.38496 .03785 L
.38477 .03745 L
Mistroke
.38473 .03703 L
.38477 .03663 L
.38486 .03622 L
.38496 .03579 L
.38505 .03539 L
.38508 .03504 L
.38504 .03476 L
.38497 .03458 L
.38487 .03447 L
.38475 .03444 L
.38462 .03445 L
.38446 .03451 L
.38427 .03458 L
.38405 .03463 L
.38382 .03466 L
.38359 .03465 L
.38341 .03464 L
.38328 .03463 L
.3832 .03463 L
.38316 .03463 L
.38318 .03463 L
.38325 .03465 L
.38335 .03467 L
.38346 .0347 L
.38356 .03474 L
.38363 .03477 L
.38368 .03481 L
.38371 .03484 L
.38375 .03488 L
.3838 .0349 L
.38388 .03493 L
.384 .03494 L
.38416 .03493 L
.38435 .03493 L
.38453 .0349 L
.38469 .03484 L
.38482 .03492 L
.38492 .03488 L
.38499 .03485 L
.38503 .03485 L
.38503 .03488 L
.38498 .03495 L
.38487 .03507 L
.38467 .03523 L
.38438 .03548 L
.384 .03575 L
.38355 .03608 L
.38308 .03643 L
.38261 .0368 L
.3822 .0372 L
Mistroke
.38184 .03756 L
.38155 .03786 L
.38132 .03815 L
.38115 .0384 L
.38104 .03861 L
.38097 .03877 L
.38095 .03889 L
.38098 .03897 L
.38107 .03901 L
.38121 .03903 L
.38134 .03903 L
.38142 .03901 L
.3814 .03897 L
.38126 .03893 L
.381 .0389 L
.3806 .03889 L
.38007 .03887 L
.37945 .03885 L
.37878 .03883 L
.37807 .03881 L
.37739 .03879 L
.37672 .03877 L
.37605 .03875 L
.37541 .03873 L
.37483 .03871 L
.37438 .0387 L
.37406 .03869 L
.37389 .03868 L
.37383 .03868 L
.37386 .03868 L
.37396 .03868 L
.37407 .03869 L
.37415 .03869 L
.37419 .03869 L
.3742 .03867 L
.37421 .03864 L
.37424 .03862 L
.37427 .0386 L
.37431 .03861 L
.37432 .03864 L
.3743 .03871 L
.37422 .03882 L
.37409 .03898 L
.37392 .03918 L
.37374 .03937 L
.37355 .03954 L
.37337 .03969 L
.37323 .03979 L
.37313 .03985 L
.37307 .03992 L
Mistroke
.37304 .03992 L
.37306 .03988 L
.37311 .03979 L
.37319 .03965 L
.37333 .03947 L
.37349 .03927 L
.37369 .03907 L
.37389 .03888 L
.37407 .03873 L
.37421 .03864 L
.3743 .0386 L
.37433 .03858 L
.37431 .03859 L
.37428 .03861 L
.37424 .03865 L
.37421 .03868 L
.3742 .03869 L
.37419 .03869 L
.37419 .03869 L
.37419 .03869 L
.37419 .03869 L
.3742 .03869 L
.37422 .03869 L
.37427 .0387 L
.37434 .0387 L
.37441 .0387 L
.37444 .0387 L
.37443 .0387 L
.37434 .0387 L
.37418 .03869 L
.37393 .03868 L
.37363 .03863 L
.3733 .03854 L
.37294 .03842 L
.37257 .03832 L
.37219 .03825 L
.3718 .03823 L
.37135 .0383 L
.37082 .03851 L
.37021 .03887 L
.36951 .03939 L
.3687 .04006 L
.36773 .04087 L
.3666 .04179 L
.36542 .04272 L
.36403 .04368 L
.36243 .04467 L
.36085 .04566 L
.35895 .04659 L
.35725 .04738 L
Mistroke
.35554 .04804 L
.35389 .04855 L
.35244 .04891 L
.35126 .04913 L
.35028 .04922 L
.34951 .04921 L
.34897 .04916 L
.34862 .0491 L
.34842 .04902 L
.34836 .04895 L
.34838 .04889 L
.34844 .04886 L
.34855 .04886 L
.34867 .04886 L
.34877 .04886 L
.34881 .04886 L
.34882 .04886 L
.34884 .04883 L
.3489 .04876 L
.34902 .04866 L
.34912 .04857 L
.34919 .04853 L
.34919 .04857 L
.34909 .0487 L
.34884 .04895 L
.3484 .04933 L
.34778 .04981 L
.34704 .05038 L
.34622 .05102 L
.34538 .05169 L
.34454 .05232 L
.34387 .05293 L
.34311 .05353 L
.34239 .05411 L
.34177 .05462 L
.34133 .05502 L
.34111 .05526 L
.3411 .05534 L
.34123 .0553 L
.34144 .05519 L
.34167 .05507 L
.34187 .05496 L
.34194 .05493 L
.34181 .05501 L
.34147 .05518 L
.34091 .05543 L
.34011 .05575 L
.33904 .05615 L
.33789 .05664 L
.3364 .05722 L
Mistroke
.33504 .05789 L
.33356 .05868 L
.33186 .05957 L
.33023 .06057 L
.32853 .06164 L
.32675 .06273 L
.32495 .06379 L
.32324 .06477 L
.3215 .06573 L
.31979 .06661 L
.31839 .06742 L
.31694 .06811 L
.31559 .06872 L
.31452 .06924 L
.31358 .06966 L
.31276 .06999 L
.31209 .07024 L
.31157 .07043 L
.31123 .07061 L
.31106 .07077 L
.31104 .07092 L
.31112 .07108 L
.31125 .07125 L
.31139 .07144 L
.3115 .07164 L
.31155 .07182 L
.31156 .07196 L
.31156 .07206 L
.31156 .07211 L
.31156 .07213 L
.31156 .07211 L
.31156 .07208 L
.31156 .07204 L
.31156 .07201 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .072 L
.31156 .07199 L
.31159 .07197 L
.31165 .07193 L
.31176 .07186 L
.31186 .0718 L
.31192 .07176 L
.31189 .07178 L
Mistroke
.31177 .07186 L
.31153 .07202 L
.31115 .07225 L
.31067 .07254 L
.31011 .07286 L
.30952 .0732 L
.30888 .07357 L
.30818 .07398 L
.30745 .07445 L
.30666 .07497 L
.30582 .07555 L
.30495 .07615 L
.30412 .07675 L
.30339 .07733 L
.3028 .07787 L
.30233 .07836 L
.30196 .07878 L
.30159 .07918 L
.30118 .07955 L
.30068 .07992 L
.30007 .08026 L
.29937 .08055 L
.29863 .08074 L
.29786 .08085 L
.29713 .08087 L
.29647 .08081 L
.29589 .0807 L
.29532 .08058 L
.29472 .08047 L
.29408 .08041 L
.29346 .08039 L
.29292 .08042 L
.29247 .08048 L
.29212 .0806 L
.29185 .08074 L
.29165 .08092 L
.29151 .08112 L
.29138 .08137 L
.29121 .08157 L
.29098 .08183 L
.29074 .08207 L
.29052 .08228 L
.29034 .08245 L
.29022 .08255 L
.29017 .08258 L
.29021 .08255 L
.29032 .08251 L
.29049 .08247 L
.29071 .08247 L
.29095 .08253 L
Mistroke
.29119 .08267 L
.29144 .0829 L
.29169 .08318 L
.29195 .08346 L
.29221 .08371 L
.29249 .08386 L
.29276 .08395 L
.293 .08398 L
.29322 .08398 L
.29338 .084 L
.29343 .0841 L
.29334 .08411 L
.29311 .08416 L
.29269 .08424 L
.29208 .08439 L
.29122 .08466 L
.29008 .08508 L
.28879 .08564 L
.2872 .08643 L
.28527 .08742 L
.28312 .08861 L
.28111 .08985 L
.27888 .09117 L
.2764 .09253 L
.27416 .09384 L
.27183 .0951 L
.26986 .09621 L
.26809 .09724 L
.26662 .09816 L
.26542 .09898 L
.26435 .09967 L
.26347 .10026 L
.26274 .10074 L
.26213 .10113 L
.26156 .10144 L
.26098 .10173 L
.26036 .10201 L
.25962 .10235 L
.2587 .10278 L
.25764 .10332 L
.25642 .104 L
.25496 .10483 L
.25321 .10583 L
.25137 .10695 L
.24944 .10818 L
.24746 .10948 L
.24571 .11075 L
.24401 .11195 L
.2426 .11309 L
.24124 .11411 L
Mistroke
.24013 .11496 L
.23919 .11568 L
.23846 .11624 L
.23797 .11665 L
.23768 .1169 L
.23758 .11702 L
.23761 .11705 L
.23773 .11701 L
.23788 .11693 L
.23803 .11684 L
.23812 .11676 L
.23818 .11669 L
.23827 .11661 L
.23839 .11652 L
.23849 .11642 L
.23854 .11633 L
.23852 .11629 L
.23839 .1163 L
.23815 .11641 L
.23776 .11666 L
.23722 .11705 L
.23655 .11759 L
.23577 .11829 L
.23492 .11913 L
.23406 .12003 L
.23319 .12104 L
.23229 .12207 L
.2314 .12311 L
.23056 .12414 L
.22984 .12511 L
.22927 .12593 L
.22885 .12663 L
.22858 .12718 L
.22842 .12757 L
.22837 .12781 L
.22837 .12792 L
.2284 .12793 L
.22842 .1279 L
.22845 .12785 L
.22849 .12778 L
.22853 .1277 L
.2286 .12762 L
.22867 .12757 L
.22876 .12752 L
.22887 .12747 L
.22899 .1274 L
.22909 .12732 L
.22913 .12726 L
.22906 .12725 L
.22885 .12734 L
Mistroke
.22844 .12755 L
.22779 .1279 L
.22688 .12839 L
.22569 .12903 L
.22436 .12976 L
.22275 .13058 L
.22086 .13149 L
.21891 .13245 L
.21686 .1335 L
.21452 .13476 L
.21235 .136 L
.21003 .13732 L
.20779 .1387 L
.20588 .14011 L
.20405 .14149 L
.2024 .14281 L
.20106 .14387 L
.19991 .14495 L
.19898 .14595 L
.1983 .14673 L
.19782 .14743 L
.1975 .14804 L
.1973 .14851 L
.19716 .14886 L
.19703 .14917 L
.19684 .14954 L
.19655 .15001 L
.19617 .15063 L
.19568 .15146 L
.19508 .15248 L
.1944 .15364 L
.19372 .15474 L
.19302 .156 L
.19234 .15726 L
.19175 .15834 L
.19119 .1594 L
.19073 .1603 L
.19039 .16106 L
.19016 .16169 L
.18996 .16223 L
.18976 .16276 L
.18949 .16333 L
.18909 .16404 L
.18847 .16498 L
.18759 .16621 L
.18653 .16753 L
.18524 .16924 L
.18368 .17116 L
.18189 .17346 L
.17999 .17588 L
Mistroke
.17822 .17864 L
.17634 .18118 L
.17433 .18403 L
.17238 .1869 L
.17052 .18971 L
.16866 .19269 L
.16697 .19525 L
.16528 .19799 L
.16374 .20053 L
.16221 .20306 L
.16073 .20544 L
.15939 .20788 L
.15805 .20999 L
.15673 .21211 L
.1555 .21414 L
.15438 .21601 L
.15332 .21781 L
.15232 .21948 L
.15144 .22086 L
.15065 .22217 L
.14997 .22336 L
.14944 .22441 L
.14902 .22526 L
.14873 .22597 L
.14854 .22649 L
.14845 .22683 L
.14841 .22701 L
.1484 .22709 L
.14838 .22709 L
.14835 .22705 L
.14828 .22702 L
.14815 .22703 L
.14793 .2271 L
.14762 .22726 L
.1472 .22754 L
.14666 .228 L
.14598 .22869 L
.1452 .22957 L
.1443 .23068 L
.14327 .23203 L
.1421 .23368 L
.14084 .23562 L
.1396 .2375 L
.1383 .23977 L
.13697 .24221 L
.13562 .24466 L
.13419 .2474 L
.13266 .25035 L
.13111 .25313 L
.12943 .25629 L
Mistroke
.12775 .25928 L
.12611 .26243 L
.12443 .26535 L
.1227 .26849 L
.12116 .27117 L
.11929 .27409 L
.1176 .27692 L
.1157 .27991 L
.11388 .28296 L
.11193 .28562 L
.10991 .2885 L
.10795 .29152 L
.10646 .29399 L
.10485 .29666 L
.10339 .29896 L
.10193 .30126 L
.10084 .30313 L
.09987 .30486 L
.09902 .30643 L
.09837 .3077 L
.09791 .30872 L
.09764 .30947 L
.09754 .30993 L
.09756 .31015 L
.09765 .31017 L
.09777 .31007 L
.0979 .30991 L
.098 .30973 L
.09805 .30959 L
.09804 .30948 L
.09804 .30941 L
.09804 .3094 L
.09802 .30943 L
.09798 .30952 L
.0979 .30968 L
.09779 .30994 L
.09766 .31033 L
.09753 .31086 L
.09741 .31153 L
.09731 .31234 L
.09723 .31326 L
.0972 .31425 L
.09719 .31524 L
.09721 .31624 L
.09726 .31723 L
.09731 .31816 L
.0974 .31898 L
.09752 .31963 L
.09766 .32005 L
.09782 .32029 L
Mistroke
.09799 .32042 L
.09815 .32047 L
.09827 .32047 L
.09831 .32051 L
.09825 .32071 L
.0981 .32119 L
.09786 .32205 L
.09755 .32331 L
.09719 .32498 L
.09677 .32705 L
.09628 .32919 L
.0957 .33159 L
.09501 .33448 L
.09421 .3375 L
.09334 .34085 L
.09239 .34413 L
.09139 .34762 L
.09042 .35105 L
.08946 .35413 L
.08854 .3575 L
.08773 .36057 L
.08695 .36371 L
.08629 .36665 L
.08569 .36974 L
.08518 .37236 L
.08478 .37514 L
.08449 .37772 L
.08431 .38039 L
.08422 .38295 L
.08422 .38504 L
.08425 .38703 L
.08431 .3889 L
.08436 .39058 L
.08439 .39203 L
.08439 .39316 L
.08438 .3941 L
.08437 .39483 L
.08437 .39536 L
.08436 .39572 L
.08436 .39591 L
Mfstroke
.07165 .47788 m
.07162 .47813 L
.07158 .47849 L
.07156 .47895 L
.07155 .47946 L
.07154 .48 L
.07152 .48057 L
.07148 .4812 L
.07143 .48188 L
.07136 .48265 L
.0713 .48348 L
.07126 .48435 L
.07123 .48527 L
.07121 .48624 L
.07118 .48727 L
.07111 .4884 L
.07099 .48964 L
.07082 .49105 L
.07061 .49272 L
.07034 .49475 L
.07002 .49696 L
.06967 .49954 L
.0693 .50234 L
.06895 .5049 L
.0686 .50744 L
.06828 .51017 L
.06799 .51276 L
.06776 .51554 L
.06761 .51789 L
.06756 .52027 L
.06766 .52258 L
.06787 .52467 L
.0682 .52665 L
.0686 .52838 L
.06905 .52992 L
.06952 .53127 L
.06998 .53247 L
.07039 .53349 L
.07076 .53432 L
.07109 .53501 L
.07138 .5356 L
.07165 .53607 L
.07189 .53644 L
.07212 .53673 L
.07234 .53696 L
.07258 .53713 L
.07283 .53726 L
.07311 .53736 L
.07339 .53742 L
.07364 .53745 L
Mistroke
.0739 .53752 L
.07413 .53765 L
.07431 .53785 L
.07438 .53815 L
.07433 .53855 L
.07416 .53907 L
.07388 .53973 L
.07354 .54059 L
.07319 .54167 L
.07287 .5429 L
.07261 .54441 L
.07243 .54614 L
.07236 .54801 L
.07241 .55013 L
.07257 .5524 L
.07285 .55463 L
.07322 .55704 L
.0737 .55941 L
.07429 .56187 L
.0749 .56412 L
.07551 .56639 L
.07611 .56861 L
.07664 .57048 L
.07708 .57228 L
.07743 .57392 L
.07771 .57529 L
.07791 .57647 L
.07806 .57751 L
.07817 .5782 L
.07825 .57875 L
.07832 .57908 L
.07835 .57924 L
.07834 .57924 L
.0783 .57917 L
.07826 .5791 L
.07824 .57911 L
.07824 .57919 L
.07828 .57934 L
.07833 .57954 L
.07839 .57979 L
.07844 .58006 L
.07848 .58034 L
.0785 .58065 L
.07852 .58096 L
.07851 .58134 L
.07847 .58184 L
.07842 .58253 L
.07833 .58329 L
.07821 .58425 L
.07809 .58536 L
Mistroke
.07796 .58664 L
.07784 .58803 L
.07777 .5897 L
.07776 .5916 L
.07781 .59375 L
.07793 .59625 L
.07814 .59873 L
.07843 .6015 L
.0788 .60444 L
.07925 .6076 L
.07979 .61053 L
.08041 .61353 L
.08108 .61664 L
.08178 .61958 L
.08248 .62267 L
.08315 .62556 L
.08376 .62845 L
.08434 .63102 L
.08491 .63347 L
.08543 .63555 L
.08591 .63739 L
.08636 .63902 L
.08676 .64045 L
.08711 .64174 L
.08742 .64297 L
.08771 .64415 L
.08799 .64529 L
.08828 .64638 L
.08859 .64744 L
.08894 .64837 L
.08931 .64928 L
.08968 .65009 L
.09001 .65085 L
.09029 .65147 L
.09054 .65202 L
.09076 .65252 L
.09097 .65291 L
.09117 .65328 L
.09138 .65371 L
.09159 .65421 L
.09179 .65483 L
.09197 .6557 L
.09214 .65685 L
.0923 .65823 L
.09245 .6597 L
.09261 .66135 L
.09277 .66309 L
.09292 .66478 L
.09304 .66661 L
.09315 .66829 L
Mistroke
.09324 .66999 L
.09332 .6717 L
.09339 .67343 L
.09346 .6752 L
.09354 .677 L
.09365 .67865 L
.09381 .68043 L
.09407 .68231 L
.09444 .68415 L
.0949 .68609 L
.09547 .68804 L
.09616 .68981 L
.09695 .69149 L
.0979 .693 L
.09861 .69404 L
.09944 .69503 L
.10029 .69581 L
.10098 .69641 L
.10162 .69688 L
.10222 .69725 L
.10274 .69754 L
.10315 .69778 L
.10343 .69802 L
.10358 .69833 L
.10362 .69875 L
.10358 .6993 L
.1035 .70004 L
.10341 .70098 L
.10332 .70205 L
.10326 .70322 L
.10321 .7045 L
.10314 .70581 L
.10305 .70722 L
.10295 .70876 L
.10285 .71056 L
.10275 .7122 L
.10265 .71404 L
.10258 .71594 L
.10252 .71776 L
.10247 .71944 L
.10245 .72096 L
.10243 .7222 L
.10243 .72326 L
.10245 .72417 L
.10249 .72494 L
.10255 .72556 L
.10261 .72602 L
.10268 .72629 L
.10274 .72641 L
.10279 .7264 L
Mistroke
.10281 .72632 L
.10281 .72621 L
.10279 .72609 L
.10276 .72599 L
.10275 .72594 L
.10275 .72592 L
.10275 .72587 L
.10275 .72581 L
.10276 .72572 L
.10276 .7256 L
.10276 .72548 L
.10276 .72536 L
.10275 .72527 L
.10272 .72524 L
.10268 .72524 L
.10264 .72524 L
.10261 .72523 L
.10261 .72524 L
.10263 .72526 L
.10266 .72533 L
.10272 .72545 L
.10281 .72566 L
.10297 .72599 L
.10324 .72646 L
.10361 .72707 L
.10409 .72782 L
.10471 .72872 L
.10545 .72978 L
.1063 .73089 L
.10723 .73212 L
.10813 .73343 L
.10904 .73479 L
.10992 .73617 L
.11073 .73747 L
.11151 .73876 L
.11225 .73997 L
.11298 .74109 L
.11372 .74215 L
.11451 .74317 L
.1154 .74429 L
.11633 .7454 L
.11737 .74671 L
.11855 .74818 L
.11978 .74969 L
.12121 .75133 L
.1228 .7531 L
.12452 .75495 L
.1263 .75662 L
.12808 .75835 L
.12968 .75977 L
Mistroke
.13121 .76102 L
.13241 .76209 L
.13338 .76287 L
.13402 .76336 L
.13432 .76359 L
.13431 .7636 L
.13413 .76346 L
.13387 .76324 L
.13361 .763 L
.13336 .76282 L
.13319 .76279 L
.13309 .76296 L
.13308 .76334 L
.13322 .76387 L
.13362 .76455 L
.13443 .76538 L
.13532 .76621 L
.13666 .76714 L
.13819 .76812 L
.13996 .76914 L
.14183 .77018 L
.14384 .77117 L
.1458 .77211 L
.14777 .77298 L
.14977 .77373 L
.15167 .77437 L
.15346 .77489 L
.15507 .77532 L
.15643 .77569 L
.15753 .77598 L
.15846 .77628 L
.15907 .77652 L
.15956 .77682 L
.15993 .77718 L
.16021 .77761 L
.16042 .77814 L
.16064 .7788 L
.16086 .77965 L
.16112 .7806 L
.16142 .78184 L
.16186 .78332 L
.16247 .78497 L
.16328 .78678 L
.16432 .78884 L
.16555 .79113 L
.16689 .79347 L
.16837 .79585 L
.17 .79839 L
.17169 .80088 L
.17352 .80345 L
Mistroke
.17552 .80602 L
.17765 .80852 L
.17993 .81095 L
.18217 .81327 L
.18442 .81541 L
.18647 .81734 L
.18831 .8189 L
.18994 .82027 L
.19128 .82134 L
.19242 .8222 L
.19334 .82289 L
.19412 .82346 L
.19483 .82399 L
.19553 .82457 L
.19627 .82523 L
.19704 .82601 L
.19793 .82692 L
.19892 .82797 L
.20013 .82921 L
.20161 .83067 L
.2033 .83239 L
.20522 .8342 L
.20719 .83609 L
.20925 .83796 L
.21133 .83989 L
.21313 .84138 L
.21488 .84287 L
.21639 .84419 L
.2177 .84527 L
.21874 .84616 L
.21956 .84689 L
.22016 .84744 L
.22055 .84783 L
.22078 .84812 L
.22089 .84834 L
.22093 .84854 L
.22097 .84875 L
.22107 .84899 L
.22128 .8493 L
.22161 .84968 L
.22209 .85011 L
.22271 .85059 L
.22343 .85109 L
.22418 .8516 L
.22495 .85202 L
.22572 .85245 L
.22644 .8528 L
.22704 .85306 L
.22753 .85323 L
.22788 .85333 L
Mistroke
.22811 .85336 L
.22823 .85336 L
.22828 .85336 L
.22833 .85342 L
.22848 .85357 L
.2288 .85387 L
.22934 .85435 L
.23013 .855 L
.23117 .85581 L
.23242 .85683 L
.23397 .85801 L
.23579 .85938 L
.2377 .86087 L
.23976 .86241 L
.24184 .86399 L
.24387 .86544 L
.24574 .86672 L
.24752 .86806 L
.24918 .86936 L
.25059 .8706 L
.25188 .8718 L
.25292 .87286 L
.25389 .87384 L
.25454 .87473 L
.25513 .87551 L
.25566 .87615 L
.25604 .87684 L
.25644 .87756 L
.25686 .87834 L
.25737 .87918 L
.25793 .87998 L
.25865 .88082 L
.25952 .88165 L
.26064 .88245 L
.26166 .88322 L
.26298 .88401 L
.26445 .88485 L
.26613 .88578 L
.26807 .88681 L
.27026 .88792 L
.27261 .88907 L
.27497 .89016 L
.27731 .8912 L
.27963 .89217 L
.28169 .89309 L
.28357 .89388 L
.28502 .89456 L
.2862 .89517 L
.28716 .89569 L
.28791 .89604 L
Mistroke
.28844 .89621 L
.28882 .89622 L
.28907 .89607 L
.28928 .8958 L
.28958 .89547 L
.29005 .89515 L
.29068 .89488 L
.29154 .89464 L
.29252 .89444 L
.29367 .89428 L
.29491 .8941 L
.29619 .89389 L
.29738 .89365 L
.29838 .89339 L
.29914 .89309 L
.29964 .89276 L
.29994 .89247 L
.30008 .89226 L
.30008 .89216 L
.29994 .89213 L
.29986 .89222 L
.29989 .89245 L
.30014 .8928 L
.30065 .8933 L
.30153 .8941 L
.3028 .89514 L
.30455 .8964 L
.30663 .89781 L
.30922 .89932 L
.31199 .90096 L
.31519 .90269 L
.31838 .90443 L
.32183 .90613 L
.32519 .90777 L
.32863 .9093 L
.33204 .91065 L
.33545 .91192 L
.33855 .91303 L
.34169 .91403 L
.34475 .91495 L
.34774 .91579 L
.35061 .91657 L
.35341 .9173 L
.35611 .918 L
.35882 .91869 L
.36149 .91938 L
.36403 .92009 L
.36656 .92084 L
.36905 .92164 L
.37135 .92247 L
Mistroke
.37348 .92328 L
.37536 .92405 L
.37692 .92473 L
.37818 .92531 L
.37918 .92575 L
.37992 .92603 L
.38049 .92616 L
.38093 .92613 L
.38132 .92594 L
.38176 .92557 L
.38234 .92503 L
.3831 .92437 L
.384 .92359 L
.38514 .9227 L
.38639 .92175 L
.38775 .92076 L
.38919 .91982 L
.39067 .91885 L
.39208 .91823 L
.39333 .91756 L
.39431 .91709 L
.39501 .91681 L
.39543 .91677 L
.39559 .91694 L
.39548 .91728 L
.39519 .91776 L
.39485 .9184 L
.39454 .91913 L
.39434 .91985 L
.39432 .92049 L
.39453 .92103 L
.39498 .92153 L
.39564 .92197 L
.39649 .92233 L
.39735 .92269 L
.39822 .92309 L
.399 .92349 L
.39964 .92389 L
.40006 .92429 L
.40026 .92469 L
.40026 .92494 L
.40011 .92511 L
.39982 .92508 L
.39945 .92491 L
.39886 .92455 L
.39838 .92387 L
.39781 .92303 L
.39728 .92216 L
.39682 .92097 L
.39651 .91969 L
Mistroke
.39635 .91823 L
.39631 .91692 L
.39634 .91568 L
.39639 .91467 L
.39643 .91393 L
.39639 .91345 L
.39623 .9132 L
.39594 .9132 L
.39558 .9135 L
.39518 .91402 L
.3948 .91469 L
.39446 .9155 L
.39423 .91646 L
.39411 .91749 L
.39413 .91865 L
.39431 .91988 L
.39467 .92116 L
.39524 .92254 L
.39602 .924 L
.39699 .9255 L
.39818 .92702 L
.39961 .92852 L
.40123 .93005 L
.40309 .93156 L
.40509 .93304 L
.40734 .93452 L
.40986 .93591 L
.41241 .93716 L
.41515 .9383 L
.41805 .93939 L
.42099 .94044 L
.42394 .94144 L
.42675 .9424 L
.42957 .94331 L
.43222 .94415 L
.43474 .9449 L
.43688 .94556 L
.43881 .94608 L
.44052 .94645 L
.442 .94674 L
.44333 .94701 L
.44454 .9473 L
.44575 .94759 L
.4468 .94785 L
.44799 .94809 L
.44926 .94826 L
.45057 .94831 L
.45199 .94824 L
.45351 .94809 L
.45502 .94789 L
Mistroke
.45655 .94774 L
.45806 .94771 L
.45957 .94779 L
.46103 .94795 L
.46253 .94804 L
.46407 .94812 L
.46568 .94822 L
.46738 .94834 L
.46915 .94847 L
.47098 .94862 L
.47301 .94882 L
.47515 .94908 L
.47741 .94934 L
.47972 .94955 L
.48213 .94964 L
.48457 .94959 L
.48707 .94943 L
.48989 .94921 L
.49223 .94902 L
.49468 .94884 L
.49698 .94869 L
.49903 .9486 L
.50067 .94856 L
.50191 .94856 L
.50268 .94857 L
.50317 .94857 L
.5034 .94855 L
.50344 .94855 L
.50335 .94861 L
.50307 .94866 L
.50269 .9487 L
.5023 .94867 L
.50194 .94857 L
.50162 .94835 L
.50142 .94801 L
.50128 .94757 L
.50129 .94705 L
.50149 .9465 L
.50186 .94593 L
.50233 .94537 L
.50261 .94475 L
.50277 .94406 L
.50282 .94335 L
.50277 .94267 L
.50273 .94201 L
.50268 .94145 L
.50261 .94098 L
.50261 .94067 L
.50261 .94046 L
.50259 .94039 L
Mistroke
.50249 .94045 L
.50229 .9406 L
.50194 .94073 L
.50141 .94076 L
.50068 .94075 L
.49969 .94073 L
.49843 .94071 L
.49695 .94073 L
.49526 .94082 L
.49344 .941 L
.49134 .94119 L
.48889 .94138 L
.48663 .94152 L
.48413 .94169 L
.48152 .94185 L
.47884 .94197 L
.47611 .94218 L
.4733 .94245 L
.47056 .94279 L
.46778 .9431 L
.46498 .94352 L
.46226 .94378 L
.45944 .94395 L
.45664 .94399 L
.45387 .94403 L
.45114 .94405 L
.44841 .94409 L
.44583 .94415 L
.44322 .94422 L
.44088 .94428 L
.43852 .94421 L
.43608 .944 L
.43402 .94365 L
.43194 .94317 L
.42991 .94259 L
.42783 .94194 L
.42576 .94124 L
.42371 .94053 L
.42162 .93979 L
.41945 .93904 L
.41719 .93827 L
.41493 .93745 L
.4125 .93656 L
.40984 .93562 L
.4071 .93466 L
.40424 .93371 L
.4013 .93276 L
.39819 .93182 L
.39505 .93088 L
.39194 .9299 L
Mistroke
.38871 .92889 L
.38559 .92783 L
.38241 .92674 L
.37931 .92561 L
.37623 .92446 L
.37304 .92333 L
.36996 .92224 L
.36688 .92127 L
.36385 .92033 L
.36079 .91944 L
.35785 .91854 L
.35495 .91763 L
.35189 .91665 L
.34877 .91563 L
.34579 .91457 L
.34267 .91347 L
.33945 .91238 L
.33649 .91135 L
.33362 .91035 L
.3307 .90939 L
.32817 .90849 L
.32549 .90765 L
.32341 .90692 L
.32153 .90631 L
.31982 .90584 L
.31837 .90553 L
.31722 .90536 L
.31637 .9053 L
.31571 .90527 L
.31513 .90519 L
.31451 .90498 L
.3138 .90462 L
.31296 .90408 L
.31191 .90336 L
.31058 .90249 L
.3092 .90157 L
.30772 .90058 L
.30625 .89957 L
.30487 .89859 L
.30353 .89767 L
.30223 .89689 L
.30114 .89624 L
.30026 .89577 L
.29958 .89548 L
.29912 .89534 L
.29888 .8953 L
.29883 .89529 L
.29892 .89525 L
.29908 .89509 L
.29925 .89477 L
Mistroke
.29938 .89431 L
.29944 .89376 L
.29944 .89313 L
.29941 .89253 L
.2994 .89203 L
.29959 .89166 L
.29976 .89145 L
.29997 .89139 L
.30013 .89151 L
.30025 .89181 L
.30024 .89223 L
.30004 .8927 L
.29958 .89318 L
.29883 .89371 L
.29777 .89418 L
.29638 .89448 L
.29477 .89455 L
.29279 .89434 L
.29063 .89384 L
.28826 .89314 L
.28555 .89225 L
.28271 .89124 L
.2798 .89026 L
.27725 .88927 L
.27461 .88837 L
.27226 .88765 L
.27015 .88698 L
.26837 .88642 L
.26687 .88593 L
.26558 .88546 L
.26458 .88501 L
.26372 .88457 L
.26296 .88413 L
.26244 .88374 L
.26199 .88331 L
.26163 .88289 L
.26137 .88251 L
.2612 .88216 L
.26106 .8818 L
.26091 .88145 L
.2607 .88114 L
.26048 .88089 L
.26014 .88067 L
.2597 .88047 L
.25914 .88026 L
.25842 .87996 L
.25751 .87952 L
.25644 .87891 L
.25521 .87811 L
.25388 .87714 L
Mistroke
.25238 .87596 L
.25069 .87462 L
.24885 .87317 L
.24701 .87166 L
.24516 .87011 L
.24341 .86857 L
.24186 .86709 L
.24052 .86583 L
.23942 .86478 L
.23851 .86395 L
.23773 .86323 L
.23709 .86268 L
.23648 .86216 L
.23581 .86157 L
.23517 .86099 L
.23457 .86045 L
.23384 .85977 L
.23299 .85898 L
.23196 .85801 L
.2307 .8569 L
.22925 .8556 L
.22766 .8542 L
.22587 .85265 L
.22392 .85094 L
.22186 .8491 L
.21973 .84721 L
.21754 .84523 L
.21542 .84328 L
.21329 .84131 L
.21114 .83935 L
.20909 .8376 L
.20708 .83585 L
.20513 .83406 L
.20328 .83239 L
.20151 .83066 L
.19986 .82887 L
.19832 .82714 L
.19685 .82538 L
.19546 .82364 L
.19418 .82203 L
.19298 .82049 L
.19186 .8192 L
.19084 .81795 L
.18986 .81687 L
.18891 .81583 L
.18794 .8148 L
.18695 .81385 L
.18589 .81295 L
.18474 .81212 L
.18351 .8113 L
Mistroke
.18218 .81046 L
.18077 .80956 L
.17939 .80855 L
.17788 .8075 L
.17632 .80615 L
.1747 .80472 L
.17295 .80308 L
.17122 .80134 L
.16942 .79945 L
.16759 .79745 L
.16584 .79546 L
.16415 .79352 L
.16253 .79154 L
.16095 .78952 L
.15934 .7875 L
.15787 .78552 L
.15637 .78351 L
.15488 .78156 L
.15341 .77971 L
.15208 .77802 L
.15085 .77647 L
.14976 .77508 L
.1487 .77382 L
.14762 .77264 L
.14645 .77153 L
.14544 .77047 L
.14418 .76941 L
.1427 .76828 L
.14111 .767 L
.13927 .76574 L
.13745 .76434 L
.13538 .76279 L
.13329 .7611 L
.13142 .75924 L
.12947 .75729 L
.12732 .7552 L
.1252 .75306 L
.12307 .75087 L
.12106 .74868 L
.11902 .74651 L
.11715 .74452 L
.11537 .74262 L
.11365 .7409 L
.11213 .73932 L
.1107 .73791 L
.10935 .73664 L
.10813 .7355 L
.10714 .73447 L
.1063 .73354 L
.10565 .73272 L
Mistroke
.10519 .73208 L
.10495 .73161 L
.10488 .73128 L
.10495 .73104 L
.10509 .73085 L
.10527 .73068 L
.10545 .73054 L
.10562 .73039 L
.10577 .73024 L
.10587 .73006 L
.10592 .72992 L
.10591 .72982 L
.10585 .72978 L
.10572 .72969 L
.10551 .72953 L
.10525 .72927 L
.10495 .72887 L
.10464 .72832 L
.10433 .72756 L
.10408 .72683 L
.10383 .72594 L
.1036 .72501 L
.10337 .724 L
.10315 .72283 L
.10291 .72141 L
.10269 .71973 L
.10249 .71784 L
.10228 .71592 L
.10206 .71403 L
.10181 .71222 L
.10153 .71057 L
.10121 .70911 L
.10085 .70787 L
.1005 .70686 L
.10019 .70605 L
.09994 .70543 L
.09975 .70493 L
.09962 .70457 L
.09956 .70439 L
.09957 .70434 L
.09964 .70438 L
.09982 .7044 L
.10008 .70436 L
.10038 .70428 L
.1007 .70416 L
.10099 .70402 L
.10122 .70386 L
.10137 .70376 L
.10141 .70379 L
.10134 .70391 L
Mistroke
.10115 .70407 L
.1009 .70418 L
.10059 .70411 L
.10023 .7038 L
.09981 .70329 L
.09931 .70269 L
.09872 .70181 L
.09808 .70066 L
.09742 .69922 L
.09678 .69753 L
.09619 .6956 L
.0956 .69366 L
.09502 .69138 L
.0944 .68867 L
.09374 .6858 L
.09301 .68256 L
.0922 .67908 L
.09138 .67511 L
.09057 .67108 L
.08981 .66668 L
.08911 .66294 L
.08849 .65905 L
.08794 .65579 L
.08745 .65287 L
.08706 .65004 L
.08674 .64743 L
.08653 .64539 L
.0864 .64414 L
.08637 .64348 L
.08639 .64308 L
.08639 .64269 L
.08633 .64223 L
.08619 .64162 L
.08595 .64053 L
.08559 .6387 L
.08519 .6364 L
.08474 .63378 L
.08425 .631 L
.08377 .6281 L
.08329 .6252 L
.08282 .62237 L
.08244 .61983 L
.08213 .61754 L
.08189 .61565 L
.08177 .61418 L
.08179 .61313 L
.08194 .61249 L
.0822 .61223 L
.08254 .61224 L
.08291 .61243 L
Mistroke
.08328 .61275 L
.08363 .61314 L
.08395 .61356 L
.08421 .61394 L
.08441 .61428 L
.08458 .61453 L
.08473 .6147 L
.08484 .61481 L
.08491 .61487 L
.08493 .61489 L
.08491 .61487 L
.08487 .61484 L
.08483 .6148 L
.08479 .61477 L
.08478 .61475 L
.08478 .61475 L
.0848 .61476 L
.08486 .61479 L
.08494 .61483 L
.08501 .6149 L
.08505 .61502 L
.08503 .61518 L
.08495 .61536 L
.08478 .61551 L
.08451 .61556 L
.08413 .61544 L
.08366 .61507 L
.08311 .61439 L
.08251 .61336 L
.0819 .61197 L
.0813 .61017 L
.08068 .60797 L
.08006 .60561 L
.07948 .60289 L
.07896 .59978 L
.0785 .59673 L
.07811 .5934 L
.07777 .59006 L
.07747 .58664 L
.07719 .58337 L
.0769 .58012 L
.07658 .57693 L
.07619 .57374 L
.07574 .57054 L
.07525 .56728 L
.07473 .56388 L
.07417 .56021 L
.07356 .55672 L
.07291 .55304 L
.07227 .54934 L
Mistroke
.07162 .54566 L
.07097 .54211 L
.07035 .53874 L
.06975 .53537 L
.06919 .53226 L
.0687 .52917 L
.06832 .52624 L
.06803 .5234 L
.06784 .52066 L
.06776 .51785 L
.06779 .515 L
.06794 .51191 L
.0682 .50885 L
.06856 .50555 L
.06903 .50217 L
.06956 .49864 L
.07017 .49527 L
.07076 .49203 L
.07136 .48913 L
.07193 .48653 L
.07245 .48423 L
.07291 .48233 L
.07331 .48077 L
.07365 .47944 L
.07394 .47831 L
.07416 .47734 L
.07431 .47651 L
.0744 .47577 L
.07444 .47508 L
.07444 .47438 L
.07445 .47367 L
.0745 .47286 L
.07459 .47197 L
.07473 .47102 L
.07494 .47006 L
.07522 .4692 L
.07553 .46848 L
.07584 .46789 L
.07613 .46744 L
.07641 .46707 L
.07666 .46677 L
.07686 .46647 L
.07701 .46613 L
.0771 .46574 L
.07716 .4653 L
.07723 .46484 L
.07731 .4644 L
.07742 .46399 L
.07753 .46359 L
.07763 .46318 L
Mistroke
.07775 .46277 L
.07792 .46235 L
.07814 .46193 L
.07842 .46152 L
.07875 .46114 L
.07912 .46077 L
.07954 .46041 L
.07998 .46005 L
.08044 .45968 L
.08085 .45928 L
.0812 .45884 L
.08148 .45843 L
.08177 .45803 L
.08204 .45769 L
.08231 .45742 L
.08256 .45723 L
.08278 .45711 L
.08295 .45705 L
Mfstroke
1 .999 0 r
.008 w
.07677 .48917 Mdot
.016 w
.07677 .48917 m
.07671 .4893 L
s
.008 w
.07671 .4893 Mdot
.016 w
.07671 .4893 m
.07662 .48955 L
s
1 .998 0 r
.008 w
.07662 .48955 Mdot
.016 w
.07662 .48955 m
.07647 .48995 L
s
.008 w
.07647 .48995 Mdot
.016 w
.07647 .48995 m
.07621 .49052 L
s
1 .997 0 r
.008 w
.07621 .49052 Mdot
.016 w
.07621 .49052 m
.07584 .4913 L
s
.008 w
.07584 .4913 Mdot
.016 w
.07584 .4913 m
.07534 .49229 L
s
1 .996 0 r
.008 w
.07534 .49229 Mdot
.016 w
.07534 .49229 m
.0747 .49345 L
s
.008 w
.0747 .49345 Mdot
.016 w
.0747 .49345 m
.07411 .49469 L
s
1 .995 0 r
.008 w
.07411 .49469 Mdot
.016 w
.07411 .49469 m
.07337 .49617 L
s
.008 w
.07337 .49617 Mdot
.016 w
.07337 .49617 m
.07257 .49792 L
s
1 .994 0 r
.008 w
.07257 .49792 Mdot
.016 w
.07257 .49792 m
.07174 .49997 L
s
.008 w
.07174 .49997 Mdot
.016 w
.07174 .49997 m
.071 .50193 L
s
1 .993 0 r
.008 w
.071 .50193 Mdot
.016 w
.071 .50193 m
.07017 .5044 L
s
.008 w
.07017 .5044 Mdot
.016 w
.07017 .5044 m
.06945 .50654 L
s
1 .992 0 r
.008 w
.06945 .50654 Mdot
.016 w
.06945 .50654 m
.06879 .5089 L
s
.008 w
.06879 .5089 Mdot
.016 w
.06879 .5089 m
.0682 .51157 L
s
1 .991 0 r
.008 w
.0682 .51157 Mdot
.016 w
.0682 .51157 m
.06772 .51427 L
s
.008 w
.06772 .51427 Mdot
.016 w
.06772 .51427 m
.06738 .51639 L
s
1 .99 0 r
.008 w
.06738 .51639 Mdot
.016 w
.06738 .51639 m
.06719 .51886 L
s
.008 w
.06719 .51886 Mdot
.016 w
.06719 .51886 m
.06715 .52141 L
s
1 .989 0 r
.008 w
.06715 .52141 Mdot
.016 w
.06715 .52141 m
.06722 .52344 L
s
.008 w
.06722 .52344 Mdot
.016 w
.06722 .52344 m
.06739 .52541 L
s
1 .988 0 r
.008 w
.06739 .52541 Mdot
.016 w
.06739 .52541 m
.06762 .52716 L
s
.008 w
.06762 .52716 Mdot
.016 w
.06762 .52716 m
.06789 .52872 L
s
1 .987 0 r
.008 w
.06789 .52872 Mdot
.016 w
.06789 .52872 m
.06816 .5299 L
s
.008 w
.06816 .5299 Mdot
.016 w
.06816 .5299 m
.06841 .53096 L
s
1 .986 0 r
.008 w
.06841 .53096 Mdot
.016 w
.06841 .53096 m
.06866 .53166 L
s
.008 w
.06866 .53166 Mdot
.016 w
.06866 .53166 m
.06891 .53209 L
s
1 .985 0 r
.008 w
.06891 .53209 Mdot
.016 w
.06891 .53209 m
.06915 .53226 L
s
.008 w
.06915 .53226 Mdot
.016 w
.06915 .53226 m
.06937 .53224 L
s
1 .984 0 r
.008 w
.06937 .53224 Mdot
.016 w
.06937 .53224 m
.06954 .53209 L
s
.008 w
.06954 .53209 Mdot
.016 w
.06954 .53209 m
.06965 .53189 L
s
1 .983 0 r
.008 w
.06965 .53189 Mdot
.016 w
.06965 .53189 m
.06969 .53169 L
s
.008 w
.06969 .53169 Mdot
.016 w
.06969 .53169 m
.06967 .53155 L
s
1 .982 0 r
.008 w
.06967 .53155 Mdot
.016 w
.06967 .53155 m
.06961 .53151 L
s
.008 w
.06961 .53151 Mdot
.016 w
.06961 .53151 m
.06952 .53164 L
s
1 .981 0 r
.008 w
.06952 .53164 Mdot
.016 w
.06952 .53164 m
.06945 .53199 L
s
.008 w
.06945 .53199 Mdot
.016 w
.06945 .53199 m
.06942 .53258 L
s
1 .98 0 r
.008 w
.06942 .53258 Mdot
.016 w
.06942 .53258 m
.06946 .53339 L
s
.008 w
.06946 .53339 Mdot
.016 w
.06946 .53339 m
.0696 .53441 L
s
1 .979 0 r
.008 w
.0696 .53441 Mdot
.016 w
.0696 .53441 m
.06981 .53562 L
s
.008 w
.06981 .53562 Mdot
.016 w
.06981 .53562 m
.07009 .5369 L
s
1 .978 0 r
.008 w
.07009 .5369 Mdot
.016 w
.07009 .5369 m
.07045 .53833 L
s
.008 w
.07045 .53833 Mdot
.016 w
.07045 .53833 m
.07085 .53984 L
s
1 .977 0 r
.008 w
.07085 .53984 Mdot
.016 w
.07085 .53984 m
.07127 .54139 L
s
.008 w
.07127 .54139 Mdot
.016 w
.07127 .54139 m
.07173 .54285 L
s
1 .976 0 r
.008 w
.07173 .54285 Mdot
.016 w
.07173 .54285 m
.0722 .54423 L
s
.008 w
.0722 .54423 Mdot
.016 w
.0722 .54423 m
.07267 .54546 L
s
1 .975 0 r
.008 w
.07267 .54546 Mdot
.016 w
.07267 .54546 m
.07309 .54647 L
s
.008 w
.07309 .54647 Mdot
.016 w
.07309 .54647 m
.07348 .54728 L
s
1 .974 0 r
.008 w
.07348 .54728 Mdot
.016 w
.07348 .54728 m
.07382 .54789 L
s
.008 w
.07382 .54789 Mdot
.016 w
.07382 .54789 m
.07408 .54829 L
s
1 .973 0 r
.008 w
.07408 .54829 Mdot
.016 w
.07408 .54829 m
.07427 .54852 L
s
.008 w
.07427 .54852 Mdot
.016 w
.07427 .54852 m
.07437 .54862 L
s
1 .972 0 r
.008 w
.07437 .54862 Mdot
.016 w
.07437 .54862 m
.07441 .54863 L
s
.008 w
.07441 .54863 Mdot
.016 w
.07441 .54863 m
.0744 .54858 L
s
1 .971 0 r
.008 w
.0744 .54858 Mdot
.016 w
.0744 .54858 m
.07436 .54848 L
s
.008 w
.07436 .54848 Mdot
.016 w
.07436 .54848 m
.07431 .54835 L
s
1 .97 0 r
.008 w
.07431 .54835 Mdot
.016 w
.07431 .54835 m
.07427 .54818 L
s
.008 w
.07427 .54818 Mdot
.016 w
.07427 .54818 m
.07424 .548 L
s
1 .969 0 r
.008 w
.07424 .548 Mdot
.016 w
.07424 .548 m
.07423 .54787 L
s
.008 w
.07423 .54787 Mdot
.016 w
.07423 .54787 m
.07423 .54778 L
s
1 .968 0 r
.008 w
.07423 .54778 Mdot
.016 w
.07423 .54778 m
.07423 .54776 L
s
.008 w
.07423 .54776 Mdot
.016 w
.07423 .54776 m
.07423 .54785 L
s
1 .967 0 r
.008 w
.07423 .54785 Mdot
.016 w
.07423 .54785 m
.07422 .54806 L
s
.008 w
.07422 .54806 Mdot
.016 w
.07422 .54806 m
.07419 .54842 L
s
1 .966 0 r
.008 w
.07419 .54842 Mdot
.016 w
.07419 .54842 m
.07414 .54893 L
s
.008 w
.07414 .54893 Mdot
.016 w
.07414 .54893 m
.07407 .5496 L
s
1 .965 0 r
.008 w
.07407 .5496 Mdot
.016 w
.07407 .5496 m
.074 .55044 L
s
.008 w
.074 .55044 Mdot
.016 w
.074 .55044 m
.07394 .55144 L
s
1 .964 0 r
.008 w
.07394 .55144 Mdot
.016 w
.07394 .55144 m
.0739 .55255 L
s
.008 w
.0739 .55255 Mdot
.016 w
.0739 .55255 m
.07391 .55378 L
s
1 .963 0 r
.008 w
.07391 .55378 Mdot
.016 w
.07391 .55378 m
.07395 .55512 L
s
.008 w
.07395 .55512 Mdot
.016 w
.07395 .55512 m
.07405 .55655 L
s
1 .962 0 r
.008 w
.07405 .55655 Mdot
.016 w
.07405 .55655 m
.07418 .55796 L
s
.008 w
.07418 .55796 Mdot
.016 w
.07418 .55796 m
.07435 .55929 L
s
1 .961 0 r
.008 w
.07435 .55929 Mdot
.016 w
.07435 .55929 m
.07454 .56051 L
s
.008 w
.07454 .56051 Mdot
.016 w
.07454 .56051 m
.07473 .56158 L
s
1 .96 0 r
.008 w
.07473 .56158 Mdot
.016 w
.07473 .56158 m
.07493 .56247 L
s
.008 w
.07493 .56247 Mdot
.016 w
.07493 .56247 m
.07517 .56318 L
s
1 .959 0 r
.008 w
.07517 .56318 Mdot
.016 w
.07517 .56318 m
.07544 .56373 L
s
.008 w
.07544 .56373 Mdot
.016 w
.07544 .56373 m
.07574 .56415 L
s
1 .958 0 r
.008 w
.07574 .56415 Mdot
.016 w
.07574 .56415 m
.07605 .5645 L
s
.008 w
.07605 .5645 Mdot
.016 w
.07605 .5645 m
.07633 .56481 L
s
1 .957 0 r
.008 w
.07633 .56481 Mdot
.016 w
.07633 .56481 m
.07656 .56513 L
s
.008 w
.07656 .56513 Mdot
.016 w
.07656 .56513 m
.07672 .56546 L
s
1 .956 0 r
.008 w
.07672 .56546 Mdot
.016 w
.07672 .56546 m
.07681 .56582 L
s
.008 w
.07681 .56582 Mdot
.016 w
.07681 .56582 m
.07685 .56622 L
s
1 .955 0 r
.008 w
.07685 .56622 Mdot
.016 w
.07685 .56622 m
.07687 .56667 L
s
.008 w
.07687 .56667 Mdot
.016 w
.07687 .56667 m
.0769 .56719 L
s
1 .954 0 r
.008 w
.0769 .56719 Mdot
.016 w
.0769 .56719 m
.07697 .56779 L
s
.008 w
.07697 .56779 Mdot
.016 w
.07697 .56779 m
.07711 .5685 L
s
1 .953 0 r
.008 w
.07711 .5685 Mdot
.016 w
.07711 .5685 m
.07732 .5693 L
s
.008 w
.07732 .5693 Mdot
.016 w
.07732 .5693 m
.07756 .57013 L
s
1 .952 0 r
.008 w
.07756 .57013 Mdot
.016 w
.07756 .57013 m
.07783 .57099 L
s
.008 w
.07783 .57099 Mdot
.016 w
.07783 .57099 m
.07811 .57185 L
s
1 .951 0 r
.008 w
.07811 .57185 Mdot
.016 w
.07811 .57185 m
.07837 .57267 L
s
.008 w
.07837 .57267 Mdot
.016 w
.07837 .57267 m
.07869 .57343 L
s
1 .95 0 r
.008 w
.07869 .57343 Mdot
.016 w
.07869 .57343 m
.07903 .5741 L
s
.008 w
.07903 .5741 Mdot
.016 w
.07903 .5741 m
.07941 .57467 L
s
1 .949 0 r
.008 w
.07941 .57467 Mdot
.016 w
.07941 .57467 m
.07978 .57517 L
s
.008 w
.07978 .57517 Mdot
.016 w
.07978 .57517 m
.08017 .57559 L
s
1 .948 0 r
.008 w
.08017 .57559 Mdot
.016 w
.08017 .57559 m
.08052 .57594 L
s
.008 w
.08052 .57594 Mdot
.016 w
.08052 .57594 m
.08081 .57623 L
s
1 .947 0 r
.008 w
.08081 .57623 Mdot
.016 w
.08081 .57623 m
.08101 .57646 L
s
.008 w
.08101 .57646 Mdot
.016 w
.08101 .57646 m
.08112 .57664 L
s
1 .946 0 r
.008 w
.08112 .57664 Mdot
.016 w
.08112 .57664 m
.08115 .57674 L
s
.008 w
.08115 .57674 Mdot
.016 w
.08115 .57674 m
.08114 .57677 L
s
1 .945 0 r
.008 w
.08114 .57677 Mdot
.016 w
.08114 .57677 m
.0811 .57674 L
s
.008 w
.0811 .57674 Mdot
.016 w
.0811 .57674 m
.08106 .57667 L
s
1 .944 0 r
.008 w
.08106 .57667 Mdot
.016 w
.08106 .57667 m
.08101 .57658 L
s
.008 w
.08101 .57658 Mdot
.016 w
.08101 .57658 m
.08096 .57649 L
s
1 .943 0 r
.008 w
.08096 .57649 Mdot
.016 w
.08096 .57649 m
.08092 .57637 L
s
.008 w
.08092 .57637 Mdot
.016 w
.08092 .57637 m
.08088 .57625 L
s
1 .942 0 r
.008 w
.08088 .57625 Mdot
.016 w
.08088 .57625 m
.08085 .57615 L
s
.008 w
.08085 .57615 Mdot
.016 w
.08085 .57615 m
.08083 .57609 L
s
1 .941 0 r
.008 w
.08083 .57609 Mdot
.016 w
.08083 .57609 m
.08084 .57609 L
s
.008 w
.08084 .57609 Mdot
.016 w
.08084 .57609 m
.08089 .57617 L
s
1 .94 0 r
.008 w
.08089 .57617 Mdot
.016 w
.08089 .57617 m
.08099 .57638 L
s
.008 w
.08099 .57638 Mdot
.016 w
.08099 .57638 m
.08113 .57675 L
s
1 .939 0 r
.008 w
.08113 .57675 Mdot
.016 w
.08113 .57675 m
.0813 .57728 L
s
.008 w
.0813 .57728 Mdot
.016 w
.0813 .57728 m
.08147 .57798 L
s
1 .938 0 r
.008 w
.08147 .57798 Mdot
.016 w
.08147 .57798 m
.08166 .57883 L
s
.008 w
.08166 .57883 Mdot
.016 w
.08166 .57883 m
.08185 .57985 L
s
1 .937 0 r
.008 w
.08185 .57985 Mdot
.016 w
.08185 .57985 m
.08204 .58096 L
s
.008 w
.08204 .58096 Mdot
.016 w
.08204 .58096 m
.08223 .58216 L
s
1 .936 0 r
.008 w
.08223 .58216 Mdot
.016 w
.08223 .58216 m
.0824 .58338 L
s
.008 w
.0824 .58338 Mdot
.016 w
.0824 .58338 m
.08257 .58455 L
s
1 .935 0 r
.008 w
.08257 .58455 Mdot
.016 w
.08257 .58455 m
.08273 .58561 L
s
.008 w
.08273 .58561 Mdot
.016 w
.08273 .58561 m
.08288 .58647 L
s
1 .934 0 r
.008 w
.08288 .58647 Mdot
.016 w
.08288 .58647 m
.08299 .58709 L
s
.008 w
.08299 .58709 Mdot
.016 w
.08299 .58709 m
.08306 .58747 L
s
1 .933 0 r
.008 w
.08306 .58747 Mdot
.016 w
.08306 .58747 m
.0831 .58762 L
s
.008 w
.0831 .58762 Mdot
.016 w
.0831 .58762 m
.08311 .58753 L
s
1 .932 0 r
.008 w
.08311 .58753 Mdot
.016 w
.08311 .58753 m
.08311 .58725 L
s
.008 w
.08311 .58725 Mdot
.016 w
.08311 .58725 m
.08312 .58681 L
s
1 .931 0 r
.008 w
.08312 .58681 Mdot
.016 w
.08312 .58681 m
.08315 .58628 L
s
.008 w
.08315 .58628 Mdot
.016 w
.08315 .58628 m
.0832 .58571 L
s
1 .93 0 r
.008 w
.0832 .58571 Mdot
.016 w
.0832 .58571 m
.08325 .58514 L
s
.008 w
.08325 .58514 Mdot
.016 w
.08325 .58514 m
.0833 .58457 L
s
1 .929 0 r
.008 w
.0833 .58457 Mdot
.016 w
.0833 .58457 m
.08333 .58406 L
s
.008 w
.08333 .58406 Mdot
.016 w
.08333 .58406 m
.08334 .58366 L
s
1 .928 0 r
.008 w
.08334 .58366 Mdot
.016 w
.08334 .58366 m
.08333 .58342 L
s
.008 w
.08333 .58342 Mdot
.016 w
.08333 .58342 m
.08332 .58332 L
s
1 .927 0 r
.008 w
.08332 .58332 Mdot
.016 w
.08332 .58332 m
.08331 .5833 L
s
.008 w
.08331 .5833 Mdot
.016 w
.08331 .5833 m
.08331 .58333 L
s
1 .926 0 r
.008 w
.08331 .58333 Mdot
.016 w
.08331 .58333 m
.08333 .58336 L
s
.008 w
.08333 .58336 Mdot
.016 w
.08333 .58336 m
.08336 .58336 L
s
1 .925 0 r
.008 w
.08336 .58336 Mdot
.016 w
.08336 .58336 m
.0834 .58331 L
s
.008 w
.0834 .58331 Mdot
.016 w
.0834 .58331 m
.08344 .58324 L
s
1 .924 0 r
.008 w
.08344 .58324 Mdot
.016 w
.08344 .58324 m
.08346 .58319 L
s
.008 w
.08346 .58319 Mdot
.016 w
.08346 .58319 m
.08345 .58322 L
s
1 .923 0 r
.008 w
.08345 .58322 Mdot
.016 w
.08345 .58322 m
.08341 .58334 L
s
.008 w
.08341 .58334 Mdot
.016 w
.08341 .58334 m
.08332 .5836 L
s
1 .922 0 r
.008 w
.08332 .5836 Mdot
.016 w
.08332 .5836 m
.08319 .58401 L
s
.008 w
.08319 .58401 Mdot
.016 w
.08319 .58401 m
.08301 .58454 L
s
1 .921 0 r
.008 w
.08301 .58454 Mdot
.016 w
.08301 .58454 m
.08276 .58517 L
s
.008 w
.08276 .58517 Mdot
.016 w
.08276 .58517 m
.08244 .58589 L
s
1 .92 0 r
.008 w
.08244 .58589 Mdot
.016 w
.08244 .58589 m
.08205 .58671 L
s
.008 w
.08205 .58671 Mdot
.016 w
.08205 .58671 m
.08161 .58758 L
s
1 .919 0 r
.008 w
.08161 .58758 Mdot
.016 w
.08161 .58758 m
.08116 .58845 L
s
.008 w
.08116 .58845 Mdot
.016 w
.08116 .58845 m
.08073 .58931 L
s
1 .918 0 r
.008 w
.08073 .58931 Mdot
.016 w
.08073 .58931 m
.08032 .59013 L
s
.008 w
.08032 .59013 Mdot
.016 w
.08032 .59013 m
.07996 .59088 L
s
1 .917 0 r
.008 w
.07996 .59088 Mdot
.016 w
.07996 .59088 m
.07964 .59153 L
s
.008 w
.07964 .59153 Mdot
.016 w
.07964 .59153 m
.07935 .59206 L
s
1 .916 0 r
.008 w
.07935 .59206 Mdot
.016 w
.07935 .59206 m
.07912 .59247 L
s
.008 w
.07912 .59247 Mdot
.016 w
.07912 .59247 m
.07892 .59279 L
s
1 .915 0 r
.008 w
.07892 .59279 Mdot
.016 w
.07892 .59279 m
.07876 .59301 L
s
.008 w
.07876 .59301 Mdot
.016 w
.07876 .59301 m
.07865 .59316 L
s
1 .914 0 r
.008 w
.07865 .59316 Mdot
.016 w
.07865 .59316 m
.07859 .5933 L
s
.008 w
.07859 .5933 Mdot
.016 w
.07859 .5933 m
.07858 .59343 L
s
1 .913 0 r
.008 w
.07858 .59343 Mdot
.016 w
.07858 .59343 m
.07861 .59359 L
s
.008 w
.07861 .59359 Mdot
.016 w
.07861 .59359 m
.07869 .59376 L
s
1 .912 0 r
.008 w
.07869 .59376 Mdot
.016 w
.07869 .59376 m
.0788 .59395 L
s
.008 w
.0788 .59395 Mdot
.016 w
.0788 .59395 m
.07893 .59414 L
s
1 .911 0 r
.008 w
.07893 .59414 Mdot
.016 w
.07893 .59414 m
.07907 .59435 L
s
.008 w
.07907 .59435 Mdot
.016 w
.07907 .59435 m
.07918 .59454 L
s
1 .91 0 r
.008 w
.07918 .59454 Mdot
.016 w
.07918 .59454 m
.0793 .59475 L
s
.008 w
.0793 .59475 Mdot
.016 w
.0793 .59475 m
.07943 .59498 L
s
1 .909 0 r
.008 w
.07943 .59498 Mdot
.016 w
.07943 .59498 m
.07955 .59514 L
s
.008 w
.07955 .59514 Mdot
.016 w
.07955 .59514 m
.07971 .5953 L
s
1 .908 0 r
.008 w
.07971 .5953 Mdot
.016 w
.07971 .5953 m
.0799 .59542 L
s
.008 w
.0799 .59542 Mdot
.016 w
.0799 .59542 m
.08007 .59549 L
s
1 .907 0 r
.008 w
.08007 .59549 Mdot
.016 w
.08007 .59549 m
.0802 .59554 L
s
.008 w
.0802 .59554 Mdot
.016 w
.0802 .59554 m
.08028 .59559 L
s
1 .906 0 r
.008 w
.08028 .59559 Mdot
.016 w
.08028 .59559 m
.08031 .59566 L
s
.008 w
.08031 .59566 Mdot
.016 w
.08031 .59566 m
.0803 .59572 L
s
1 .905 0 r
.008 w
.0803 .59572 Mdot
.016 w
.0803 .59572 m
.08029 .59575 L
s
.008 w
.08029 .59575 Mdot
.016 w
.08029 .59575 m
.08027 .59575 L
s
1 .904 0 r
.008 w
.08027 .59575 Mdot
.016 w
.08027 .59575 m
.08026 .59573 L
s
.008 w
.08026 .59573 Mdot
.016 w
.08026 .59573 m
.08025 .59571 L
s
1 .903 0 r
.008 w
.08025 .59571 Mdot
.016 w
.08025 .59571 m
.08024 .59569 L
s
.008 w
.08024 .59569 Mdot
.016 w
.08024 .59569 m
.08023 .59568 L
s
1 .902 0 r
.008 w
.08023 .59568 Mdot
.016 w
.08023 .59568 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .901 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .9 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .899 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .898 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .897 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .896 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .895 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .894 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .893 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .892 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
1 .891 0 r
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59567 L
s
.008 w
.08023 .59567 Mdot
.016 w
.08023 .59567 m
.08023 .59566 L
s
1 .89 0 r
.008 w
.08023 .59566 Mdot
.016 w
.08023 .59566 m
.08023 .59562 L
s
.008 w
.08023 .59562 Mdot
.016 w
.08023 .59562 m
.08023 .59553 L
s
1 .889 0 r
.008 w
.08023 .59553 Mdot
.016 w
.08023 .59553 m
.08024 .59541 L
s
.008 w
.08024 .59541 Mdot
.016 w
.08024 .59541 m
.08024 .59529 L
s
1 .888 0 r
.008 w
.08024 .59529 Mdot
.016 w
.08024 .59529 m
.08024 .59522 L
s
.008 w
.08024 .59522 Mdot
.016 w
.08024 .59522 m
.08024 .59522 L
s
1 .887 0 r
.008 w
.08024 .59522 Mdot
.016 w
.08024 .59522 m
.08024 .59534 L
s
.008 w
.08024 .59534 Mdot
.016 w
.08024 .59534 m
.08023 .59561 L
s
1 .886 0 r
.008 w
.08023 .59561 Mdot
.016 w
.08023 .59561 m
.08022 .59603 L
s
.008 w
.08022 .59603 Mdot
.016 w
.08022 .59603 m
.08019 .59662 L
s
1 .885 0 r
.008 w
.08019 .59662 Mdot
.016 w
.08019 .59662 m
.08017 .59737 L
s
.008 w
.08017 .59737 Mdot
.016 w
.08017 .59737 m
.08013 .59829 L
s
1 .884 0 r
.008 w
.08013 .59829 Mdot
.016 w
.08013 .59829 m
.08009 .59934 L
s
.008 w
.08009 .59934 Mdot
.016 w
.08009 .59934 m
.08005 .6004 L
s
1 .883 0 r
.008 w
.08005 .6004 Mdot
.016 w
.08005 .6004 m
.08001 .6015 L
s
.008 w
.08001 .6015 Mdot
.016 w
.08001 .6015 m
.07997 .60262 L
s
1 .882 0 r
.008 w
.07997 .60262 Mdot
.016 w
.07997 .60262 m
.07993 .60376 L
s
.008 w
.07993 .60376 Mdot
.016 w
.07993 .60376 m
.07989 .60475 L
s
1 .881 0 r
.008 w
.07989 .60475 Mdot
.016 w
.07989 .60475 m
.07986 .60559 L
s
.008 w
.07986 .60559 Mdot
.016 w
.07986 .60559 m
.07982 .60622 L
s
1 .88 0 r
.008 w
.07982 .60622 Mdot
.016 w
.07982 .60622 m
.07978 .60663 L
s
.008 w
.07978 .60663 Mdot
.016 w
.07978 .60663 m
.07973 .60685 L
s
1 .879 0 r
.008 w
.07973 .60685 Mdot
.016 w
.07973 .60685 m
.07968 .60695 L
s
.008 w
.07968 .60695 Mdot
.016 w
.07968 .60695 m
.07965 .60696 L
s
1 .878 0 r
.008 w
.07965 .60696 Mdot
.016 w
.07965 .60696 m
.07964 .60698 L
s
.008 w
.07964 .60698 Mdot
.016 w
.07964 .60698 m
.07965 .60707 L
s
1 .877 0 r
.008 w
.07965 .60707 Mdot
.016 w
.07965 .60707 m
.07969 .60734 L
s
.008 w
.07969 .60734 Mdot
.016 w
.07969 .60734 m
.07978 .60784 L
s
1 .876 0 r
.008 w
.07978 .60784 Mdot
.016 w
.07978 .60784 m
.07992 .6086 L
s
.008 w
.07992 .6086 Mdot
.016 w
.07992 .6086 m
.08014 .60968 L
s
1 .875 0 r
.008 w
.08014 .60968 Mdot
.016 w
.08014 .60968 m
.08042 .61116 L
s
.008 w
.08042 .61116 Mdot
.016 w
.08042 .61116 m
.08079 .61291 L
s
1 .874 0 r
.008 w
.08079 .61291 Mdot
.016 w
.08079 .61291 m
.0812 .61503 L
s
.008 w
.0812 .61503 Mdot
.016 w
.0812 .61503 m
.08167 .61755 L
s
1 .873 0 r
.008 w
.08167 .61755 Mdot
.016 w
.08167 .61755 m
.0822 .62032 L
s
.008 w
.0822 .62032 Mdot
.016 w
.0822 .62032 m
.08279 .62364 L
s
1 .872 0 r
.008 w
.08279 .62364 Mdot
.016 w
.08279 .62364 m
.0834 .6271 L
s
.008 w
.0834 .6271 Mdot
.016 w
.0834 .6271 m
.08402 .63043 L
s
1 .871 0 r
.008 w
.08402 .63043 Mdot
.016 w
.08402 .63043 m
.08463 .63431 L
s
.008 w
.08463 .63431 Mdot
.016 w
.08463 .63431 m
.08521 .63854 L
s
1 .87 0 r
.008 w
.08521 .63854 Mdot
.016 w
.08521 .63854 m
.08574 .64214 L
s
.008 w
.08574 .64214 Mdot
.016 w
.08574 .64214 m
.08624 .64622 L
s
1 .869 0 r
.008 w
.08624 .64622 Mdot
.016 w
.08624 .64622 m
.08672 .6506 L
s
.008 w
.08672 .6506 Mdot
.016 w
.08672 .6506 m
.08718 .65407 L
s
1 .868 0 r
.008 w
.08718 .65407 Mdot
.016 w
.08718 .65407 m
.08761 .65794 L
s
.008 w
.08761 .65794 Mdot
.016 w
.08761 .65794 m
.08802 .66144 L
s
1 .867 0 r
.008 w
.08802 .66144 Mdot
.016 w
.08802 .66144 m
.08842 .66484 L
s
.008 w
.08842 .66484 Mdot
.016 w
.08842 .66484 m
.08878 .66769 L
s
1 .866 0 r
.008 w
.08878 .66769 Mdot
.016 w
.08878 .66769 m
.08912 .6703 L
s
.008 w
.08912 .6703 Mdot
.016 w
.08912 .6703 m
.08941 .67247 L
s
1 .865 0 r
.008 w
.08941 .67247 Mdot
.016 w
.08941 .67247 m
.08966 .67406 L
s
.008 w
.08966 .67406 Mdot
.016 w
.08966 .67406 m
.08989 .67537 L
s
1 .864 0 r
.008 w
.08989 .67537 Mdot
.016 w
.08989 .67537 m
.0901 .67639 L
s
.008 w
.0901 .67639 Mdot
.016 w
.0901 .67639 m
.09032 .67714 L
s
1 .863 0 r
.008 w
.09032 .67714 Mdot
.016 w
.09032 .67714 m
.09053 .67767 L
s
.008 w
.09053 .67767 Mdot
.016 w
.09053 .67767 m
.09074 .67808 L
s
1 .862 0 r
.008 w
.09074 .67808 Mdot
.016 w
.09074 .67808 m
.09096 .67848 L
s
.008 w
.09096 .67848 Mdot
.016 w
.09096 .67848 m
.09116 .67894 L
s
1 .861 0 r
.008 w
.09116 .67894 Mdot
.016 w
.09116 .67894 m
.09136 .67949 L
s
.008 w
.09136 .67949 Mdot
.016 w
.09136 .67949 m
.09154 .68012 L
s
1 .86 0 r
.008 w
.09154 .68012 Mdot
.016 w
.09154 .68012 m
.09173 .6809 L
s
.008 w
.09173 .6809 Mdot
.016 w
.09173 .6809 m
.09194 .68183 L
s
1 .859 0 r
.008 w
.09194 .68183 Mdot
.016 w
.09194 .68183 m
.0922 .68293 L
s
.008 w
.0922 .68293 Mdot
.016 w
.0922 .68293 m
.09249 .68416 L
s
1 .858 0 r
.008 w
.09249 .68416 Mdot
.016 w
.09249 .68416 m
.09281 .6854 L
s
.008 w
.09281 .6854 Mdot
.016 w
.09281 .6854 m
.09312 .68666 L
s
1 .857 0 r
.008 w
.09312 .68666 Mdot
.016 w
.09312 .68666 m
.09343 .68793 L
s
.008 w
.09343 .68793 Mdot
.016 w
.09343 .68793 m
.09372 .68913 L
s
1 .856 0 r
.008 w
.09372 .68913 Mdot
.016 w
.09372 .68913 m
.094 .69031 L
s
.008 w
.094 .69031 Mdot
.016 w
.094 .69031 m
.09429 .69158 L
s
1 .855 0 r
.008 w
.09429 .69158 Mdot
.016 w
.09429 .69158 m
.09458 .69301 L
s
.008 w
.09458 .69301 Mdot
.016 w
.09458 .69301 m
.0949 .69463 L
s
1 .854 0 r
.008 w
.0949 .69463 Mdot
.016 w
.0949 .69463 m
.0953 .69652 L
s
.008 w
.0953 .69652 Mdot
.016 w
.0953 .69652 m
.0957 .69823 L
s
1 .853 0 r
.008 w
.0957 .69823 Mdot
.016 w
.0957 .69823 m
.09615 .7004 L
s
.008 w
.09615 .7004 Mdot
.016 w
.09615 .7004 m
.09663 .70283 L
s
1 .852 0 r
.008 w
.09663 .70283 Mdot
.016 w
.09663 .70283 m
.09709 .70511 L
s
.008 w
.09709 .70511 Mdot
.016 w
.09709 .70511 m
.09756 .70763 L
s
1 .851 0 r
.008 w
.09756 .70763 Mdot
.016 w
.09756 .70763 m
.09803 .7103 L
s
.008 w
.09803 .7103 Mdot
.016 w
.09803 .7103 m
.09851 .71292 L
s
1 .85 0 r
.008 w
.09851 .71292 Mdot
.016 w
.09851 .71292 m
.099 .71579 L
s
.008 w
.099 .71579 Mdot
.016 w
.099 .71579 m
.09948 .7179 L
s
1 .849 0 r
.008 w
.09948 .7179 Mdot
.016 w
.09948 .7179 m
.09994 .72006 L
s
.008 w
.09994 .72006 Mdot
.016 w
.09994 .72006 m
.10034 .72198 L
s
1 .848 0 r
.008 w
.10034 .72198 Mdot
.016 w
.10034 .72198 m
.10066 .72354 L
s
.008 w
.10066 .72354 Mdot
.016 w
.10066 .72354 m
.10089 .72475 L
s
1 .847 0 r
.008 w
.10089 .72475 Mdot
.016 w
.10089 .72475 m
.10104 .7256 L
s
.008 w
.10104 .7256 Mdot
.016 w
.10104 .7256 m
.10116 .72615 L
s
1 .846 0 r
.008 w
.10116 .72615 Mdot
.016 w
.10116 .72615 m
.10126 .72639 L
s
.008 w
.10126 .72639 Mdot
.016 w
.10126 .72639 m
.10135 .72647 L
s
1 .845 0 r
.008 w
.10135 .72647 Mdot
.016 w
.10135 .72647 m
.10146 .72646 L
s
.008 w
.10146 .72646 Mdot
.016 w
.10146 .72646 m
.10157 .72636 L
s
1 .844 0 r
.008 w
.10157 .72636 Mdot
.016 w
.10157 .72636 m
.10167 .72629 L
s
.008 w
.10167 .72629 Mdot
.016 w
.10167 .72629 m
.10177 .72625 L
s
1 .843 0 r
.008 w
.10177 .72625 Mdot
.016 w
.10177 .72625 m
.10186 .72626 L
s
.008 w
.10186 .72626 Mdot
.016 w
.10186 .72626 m
.10193 .72632 L
s
1 .842 0 r
.008 w
.10193 .72632 Mdot
.016 w
.10193 .72632 m
.102 .72642 L
s
.008 w
.102 .72642 Mdot
.016 w
.102 .72642 m
.10208 .72653 L
s
1 .841 0 r
.008 w
.10208 .72653 Mdot
.016 w
.10208 .72653 m
.10218 .72665 L
s
.008 w
.10218 .72665 Mdot
.016 w
.10218 .72665 m
.10231 .72676 L
s
1 .84 0 r
.008 w
.10231 .72676 Mdot
.016 w
.10231 .72676 m
.10246 .72687 L
s
.008 w
.10246 .72687 Mdot
.016 w
.10246 .72687 m
.10261 .72703 L
s
1 .839 0 r
.008 w
.10261 .72703 Mdot
.016 w
.10261 .72703 m
.10275 .72724 L
s
.008 w
.10275 .72724 Mdot
.016 w
.10275 .72724 m
.10286 .72748 L
s
1 .838 0 r
.008 w
.10286 .72748 Mdot
.016 w
.10286 .72748 m
.10294 .72772 L
s
.008 w
.10294 .72772 Mdot
.016 w
.10294 .72772 m
.10296 .72796 L
s
1 .837 0 r
.008 w
.10296 .72796 Mdot
.016 w
.10296 .72796 m
.10293 .72811 L
s
.008 w
.10293 .72811 Mdot
.016 w
.10293 .72811 m
.10283 .72816 L
s
1 .836 0 r
.008 w
.10283 .72816 Mdot
.016 w
.10283 .72816 m
.10269 .72811 L
s
.008 w
.10269 .72811 Mdot
.016 w
.10269 .72811 m
.10253 .72801 L
s
1 .835 0 r
.008 w
.10253 .72801 Mdot
.016 w
.10253 .72801 m
.10232 .72785 L
s
.008 w
.10232 .72785 Mdot
.016 w
.10232 .72785 m
.10209 .72767 L
s
1 .834 0 r
.008 w
.10209 .72767 Mdot
.016 w
.10209 .72767 m
.10185 .7275 L
s
.008 w
.10185 .7275 Mdot
.016 w
.10185 .7275 m
.10164 .72744 L
s
1 .833 0 r
.008 w
.10164 .72744 Mdot
.016 w
.10164 .72744 m
.10146 .72742 L
s
.008 w
.10146 .72742 Mdot
.016 w
.10146 .72742 m
.10134 .72741 L
s
1 .832 0 r
.008 w
.10134 .72741 Mdot
.016 w
.10134 .72741 m
.10129 .72742 L
s
.008 w
.10129 .72742 Mdot
.016 w
.10129 .72742 m
.10132 .72746 L
s
1 .831 0 r
.008 w
.10132 .72746 Mdot
.016 w
.10132 .72746 m
.10144 .72757 L
s
.008 w
.10144 .72757 Mdot
.016 w
.10144 .72757 m
.10165 .72777 L
s
1 .83 0 r
.008 w
.10165 .72777 Mdot
.016 w
.10165 .72777 m
.10197 .72809 L
s
.008 w
.10197 .72809 Mdot
.016 w
.10197 .72809 m
.10238 .72852 L
s
1 .829 0 r
.008 w
.10238 .72852 Mdot
.016 w
.10238 .72852 m
.10284 .72901 L
s
.008 w
.10284 .72901 Mdot
.016 w
.10284 .72901 m
.10332 .72956 L
s
1 .828 0 r
.008 w
.10332 .72956 Mdot
.016 w
.10332 .72956 m
.10379 .73002 L
s
.008 w
.10379 .73002 Mdot
.016 w
.10379 .73002 m
.10423 .7305 L
s
1 .827 0 r
.008 w
.10423 .7305 Mdot
.016 w
.10423 .7305 m
.10464 .73086 L
s
.008 w
.10464 .73086 Mdot
.016 w
.10464 .73086 m
.10501 .73108 L
s
1 .826 0 r
.008 w
.10501 .73108 Mdot
.016 w
.10501 .73108 m
.10533 .73121 L
s
.008 w
.10533 .73121 Mdot
.016 w
.10533 .73121 m
.10565 .73128 L
s
1 .825 0 r
.008 w
.10565 .73128 Mdot
.016 w
.10565 .73128 m
.10599 .7313 L
s
.008 w
.10599 .7313 Mdot
.016 w
.10599 .7313 m
.10637 .73126 L
s
1 .824 0 r
.008 w
.10637 .73126 Mdot
.016 w
.10637 .73126 m
.10679 .73118 L
s
.008 w
.10679 .73118 Mdot
.016 w
.10679 .73118 m
.10725 .73108 L
s
1 .823 0 r
.008 w
.10725 .73108 Mdot
.016 w
.10725 .73108 m
.10771 .73099 L
s
.008 w
.10771 .73099 Mdot
.016 w
.10771 .73099 m
.10821 .7309 L
s
1 .822 0 r
.008 w
.10821 .7309 Mdot
.016 w
.10821 .7309 m
.10868 .7309 L
s
.008 w
.10868 .7309 Mdot
.016 w
.10868 .7309 m
.10915 .73093 L
s
1 .821 0 r
.008 w
.10915 .73093 Mdot
.016 w
.10915 .73093 m
.10956 .73098 L
s
.008 w
.10956 .73098 Mdot
.016 w
.10956 .73098 m
.1099 .73108 L
s
1 .82 0 r
.008 w
.1099 .73108 Mdot
.016 w
.1099 .73108 m
.11013 .73124 L
s
.008 w
.11013 .73124 Mdot
.016 w
.11013 .73124 m
.11022 .73144 L
s
1 .819 0 r
.008 w
.11022 .73144 Mdot
.016 w
.11022 .73144 m
.11017 .73161 L
s
.008 w
.11017 .73161 Mdot
.016 w
.11017 .73161 m
.10999 .73172 L
s
1 .818 0 r
.008 w
.10999 .73172 Mdot
.016 w
.10999 .73172 m
.10967 .73183 L
s
.008 w
.10967 .73183 Mdot
.016 w
.10967 .73183 m
.10925 .73195 L
s
1 .817 0 r
.008 w
.10925 .73195 Mdot
.016 w
.10925 .73195 m
.10877 .73206 L
s
.008 w
.10877 .73206 Mdot
.016 w
.10877 .73206 m
.10825 .73213 L
s
1 .816 0 r
.008 w
.10825 .73213 Mdot
.016 w
.10825 .73213 m
.10773 .73214 L
s
.008 w
.10773 .73214 Mdot
.016 w
.10773 .73214 m
.10726 .73211 L
s
1 .815 0 r
.008 w
.10726 .73211 Mdot
.016 w
.10726 .73211 m
.10686 .73208 L
s
.008 w
.10686 .73208 Mdot
.016 w
.10686 .73208 m
.10657 .7321 L
s
1 .814 0 r
.008 w
.10657 .7321 Mdot
.016 w
.10657 .7321 m
.1064 .73217 L
s
.008 w
.1064 .73217 Mdot
.016 w
.1064 .73217 m
.10635 .7323 L
s
1 .813 0 r
.008 w
.10635 .7323 Mdot
.016 w
.10635 .7323 m
.10645 .73247 L
s
.008 w
.10645 .73247 Mdot
.016 w
.10645 .73247 m
.10667 .73277 L
s
1 .812 0 r
.008 w
.10667 .73277 Mdot
.016 w
.10667 .73277 m
.10697 .73317 L
s
.008 w
.10697 .73317 Mdot
.016 w
.10697 .73317 m
.10735 .73367 L
s
1 .811 0 r
.008 w
.10735 .73367 Mdot
.016 w
.10735 .73367 m
.10778 .73421 L
s
.008 w
.10778 .73421 Mdot
.016 w
.10778 .73421 m
.10826 .73479 L
s
1 .81 0 r
.008 w
.10826 .73479 Mdot
.016 w
.10826 .73479 m
.10882 .73542 L
s
.008 w
.10882 .73542 Mdot
.016 w
.10882 .73542 m
.10927 .73594 L
s
1 .809 0 r
.008 w
.10927 .73594 Mdot
.016 w
.10927 .73594 m
.10978 .73654 L
s
.008 w
.10978 .73654 Mdot
.016 w
.10978 .73654 m
.11024 .73716 L
s
1 .808 0 r
.008 w
.11024 .73716 Mdot
.016 w
.11024 .73716 m
.11064 .73778 L
s
.008 w
.11064 .73778 Mdot
.016 w
.11064 .73778 m
.11096 .73832 L
s
1 .807 0 r
.008 w
.11096 .73832 Mdot
.016 w
.11096 .73832 m
.11118 .73876 L
s
.008 w
.11118 .73876 Mdot
.016 w
.11118 .73876 m
.11129 .73909 L
s
1 .806 0 r
.008 w
.11129 .73909 Mdot
.016 w
.11129 .73909 m
.11133 .7393 L
s
.008 w
.11133 .7393 Mdot
.016 w
.11133 .7393 m
.11133 .73943 L
s
1 .805 0 r
.008 w
.11133 .73943 Mdot
.016 w
.11133 .73943 m
.11133 .7395 L
s
.008 w
.11133 .7395 Mdot
.016 w
.11133 .7395 m
.11148 .73943 L
s
1 .804 0 r
.008 w
.11148 .73943 Mdot
.016 w
.11148 .73943 m
.11149 .73944 L
s
.008 w
.11149 .73944 Mdot
.016 w
.11149 .73944 m
.11155 .73948 L
s
1 .803 0 r
.008 w
.11155 .73948 Mdot
.016 w
.11155 .73948 m
.11162 .73953 L
s
.008 w
.11162 .73953 Mdot
.016 w
.11162 .73953 m
.11171 .7396 L
s
1 .802 0 r
.008 w
.11171 .7396 Mdot
.016 w
.11171 .7396 m
.11181 .73965 L
s
.008 w
.11181 .73965 Mdot
.016 w
.11181 .73965 m
.11192 .73969 L
s
1 .801 0 r
.008 w
.11192 .73969 Mdot
.016 w
.11192 .73969 m
.11203 .73969 L
s
.008 w
.11203 .73969 Mdot
.016 w
.11203 .73969 m
.11213 .73969 L
s
1 .8 0 r
.008 w
.11213 .73969 Mdot
.016 w
.11213 .73969 m
.11223 .73965 L
s
.008 w
.11223 .73965 Mdot
.016 w
.11223 .73965 m
.11233 .73961 L
s
1 .799 0 r
.008 w
.11233 .73961 Mdot
.016 w
.11233 .73961 m
.11243 .7396 L
s
.008 w
.11243 .7396 Mdot
.016 w
.11243 .7396 m
.1125 .73962 L
s
1 .798 0 r
.008 w
.1125 .73962 Mdot
.016 w
.1125 .73962 m
.11252 .73963 L
s
.008 w
.11252 .73963 Mdot
.016 w
.11252 .73963 m
.11248 .73964 L
s
1 .797 0 r
.008 w
.11248 .73964 Mdot
.016 w
.11248 .73964 m
.11236 .73961 L
s
.008 w
.11236 .73961 Mdot
.016 w
.11236 .73961 m
.11217 .73952 L
s
1 .796 0 r
.008 w
.11217 .73952 Mdot
.016 w
.11217 .73952 m
.11194 .73936 L
s
.008 w
.11194 .73936 Mdot
.016 w
.11194 .73936 m
.11171 .73915 L
s
1 .795 0 r
.008 w
.11171 .73915 Mdot
.016 w
.11171 .73915 m
.11149 .73894 L
s
.008 w
.11149 .73894 Mdot
.016 w
.11149 .73894 m
.11129 .73875 L
s
1 .794 0 r
.008 w
.11129 .73875 Mdot
.016 w
.11129 .73875 m
.11115 .73865 L
s
.008 w
.11115 .73865 Mdot
.016 w
.11115 .73865 m
.11105 .7386 L
s
1 .793 0 r
.008 w
.11105 .7386 Mdot
.016 w
.11105 .7386 m
.11098 .73863 L
s
.008 w
.11098 .73863 Mdot
.016 w
.11098 .73863 m
.11092 .73871 L
s
1 .792 0 r
.008 w
.11092 .73871 Mdot
.016 w
.11092 .73871 m
.11087 .73883 L
s
.008 w
.11087 .73883 Mdot
.016 w
.11087 .73883 m
.11078 .73897 L
s
1 .791 0 r
.008 w
.11078 .73897 Mdot
.016 w
.11078 .73897 m
.11067 .73911 L
s
.008 w
.11067 .73911 Mdot
.016 w
.11067 .73911 m
.11054 .73922 L
s
1 .79 0 r
.008 w
.11054 .73922 Mdot
.016 w
.11054 .73922 m
.11042 .73932 L
s
.008 w
.11042 .73932 Mdot
.016 w
.11042 .73932 m
.11035 .7394 L
s
1 .789 0 r
.008 w
.11035 .7394 Mdot
.016 w
.11035 .7394 m
.11036 .73953 L
s
.008 w
.11036 .73953 Mdot
.016 w
.11036 .73953 m
.11044 .7397 L
s
1 .788 0 r
.008 w
.11044 .7397 Mdot
.016 w
.11044 .7397 m
.1106 .73989 L
s
.008 w
.1106 .73989 Mdot
.016 w
.1106 .73989 m
.1108 .74004 L
s
1 .787 0 r
.008 w
.1108 .74004 Mdot
.016 w
.1108 .74004 m
.11102 .74012 L
s
.008 w
.11102 .74012 Mdot
.016 w
.11102 .74012 m
.11126 .74016 L
s
1 .786 0 r
.008 w
.11126 .74016 Mdot
.016 w
.11126 .74016 m
.11155 .74018 L
s
.008 w
.11155 .74018 Mdot
.016 w
.11155 .74018 m
.11181 .74016 L
s
1 .785 0 r
.008 w
.11181 .74016 Mdot
.016 w
.11181 .74016 m
.1121 .74014 L
s
.008 w
.1121 .74014 Mdot
.016 w
.1121 .74014 m
.11237 .74012 L
s
1 .784 0 r
.008 w
.11237 .74012 Mdot
.016 w
.11237 .74012 m
.11262 .74009 L
s
.008 w
.11262 .74009 Mdot
.016 w
.11262 .74009 m
.11279 .74005 L
s
1 .783 0 r
.008 w
.11279 .74005 Mdot
.016 w
.11279 .74005 m
.11285 .73995 L
s
.008 w
.11285 .73995 Mdot
.016 w
.11285 .73995 m
.11279 .73979 L
s
1 .782 0 r
.008 w
.11279 .73979 Mdot
.016 w
.11279 .73979 m
.11264 .7396 L
s
.008 w
.11264 .7396 Mdot
.016 w
.11264 .7396 m
.11241 .73938 L
s
1 .781 0 r
.008 w
.11241 .73938 Mdot
.016 w
.11241 .73938 m
.11213 .73915 L
s
.008 w
.11213 .73915 Mdot
.016 w
.11213 .73915 m
.11181 .73889 L
s
1 .78 0 r
.008 w
.11181 .73889 Mdot
.016 w
.11181 .73889 m
.1115 .73864 L
s
.008 w
.1115 .73864 Mdot
.016 w
.1115 .73864 m
.11122 .73845 L
s
1 .779 0 r
.008 w
.11122 .73845 Mdot
.016 w
.11122 .73845 m
.11101 .73838 L
s
.008 w
.11101 .73838 Mdot
.016 w
.11101 .73838 m
.11089 .73848 L
s
1 .778 0 r
.008 w
.11089 .73848 Mdot
.016 w
.11089 .73848 m
.11089 .73877 L
s
.008 w
.11089 .73877 Mdot
.016 w
.11089 .73877 m
.11104 .73927 L
s
1 .777 0 r
.008 w
.11104 .73927 Mdot
.016 w
.11104 .73927 m
.11134 .73997 L
s
.008 w
.11134 .73997 Mdot
.016 w
.11134 .73997 m
.11181 .7409 L
s
1 .776 0 r
.008 w
.11181 .7409 Mdot
.016 w
.11181 .7409 m
.11243 .74183 L
s
.008 w
.11243 .74183 Mdot
.016 w
.11243 .74183 m
.11318 .7429 L
s
1 .775 0 r
.008 w
.11318 .7429 Mdot
.016 w
.11318 .7429 m
.114 .74402 L
s
.008 w
.114 .74402 Mdot
.016 w
.114 .74402 m
.11495 .74515 L
s
1 .774 0 r
.008 w
.11495 .74515 Mdot
.016 w
.11495 .74515 m
.116 .74627 L
s
.008 w
.116 .74627 Mdot
.016 w
.116 .74627 m
.11714 .74741 L
s
1 .773 0 r
.008 w
.11714 .74741 Mdot
.016 w
.11714 .74741 m
.11833 .74854 L
s
.008 w
.11833 .74854 Mdot
.016 w
.11833 .74854 m
.11953 .74961 L
s
1 .772 0 r
.008 w
.11953 .74961 Mdot
.016 w
.11953 .74961 m
.12069 .75057 L
s
.008 w
.12069 .75057 Mdot
.016 w
.12069 .75057 m
.12178 .75142 L
s
1 .771 0 r
.008 w
.12178 .75142 Mdot
.016 w
.12178 .75142 m
.12276 .75213 L
s
.008 w
.12276 .75213 Mdot
.016 w
.12276 .75213 m
.12359 .75273 L
s
1 .77 0 r
.008 w
.12359 .75273 Mdot
.016 w
.12359 .75273 m
.12427 .75319 L
s
.008 w
.12427 .75319 Mdot
.016 w
.12427 .75319 m
.1248 .75353 L
s
1 .769 0 r
.008 w
.1248 .75353 Mdot
.016 w
.1248 .75353 m
.12515 .75377 L
s
.008 w
.12515 .75377 Mdot
.016 w
.12515 .75377 m
.12538 .754 L
s
1 .768 0 r
.008 w
.12538 .754 Mdot
.016 w
.12538 .754 m
.12546 .75425 L
s
.008 w
.12546 .75425 Mdot
.016 w
.12546 .75425 m
.12542 .75447 L
s
1 .767 0 r
.008 w
.12542 .75447 Mdot
.016 w
.12542 .75447 m
.12528 .75467 L
s
.008 w
.12528 .75467 Mdot
.016 w
.12528 .75467 m
.12508 .75483 L
s
1 .766 0 r
.008 w
.12508 .75483 Mdot
.016 w
.12508 .75483 m
.12481 .75495 L
s
.008 w
.12481 .75495 Mdot
.016 w
.12481 .75495 m
.12455 .75505 L
s
1 .765 0 r
.008 w
.12455 .75505 Mdot
.016 w
.12455 .75505 m
.1243 .75515 L
s
.008 w
.1243 .75515 Mdot
.016 w
.1243 .75515 m
.12406 .75526 L
s
1 .764 0 r
.008 w
.12406 .75526 Mdot
.016 w
.12406 .75526 m
.12385 .75538 L
s
.008 w
.12385 .75538 Mdot
.016 w
.12385 .75538 m
.12377 .75557 L
s
1 .763 0 r
.008 w
.12377 .75557 Mdot
.016 w
.12377 .75557 m
.12379 .75579 L
s
.008 w
.12379 .75579 Mdot
.016 w
.12379 .75579 m
.12392 .75602 L
s
1 .762 0 r
.008 w
.12392 .75602 Mdot
.016 w
.12392 .75602 m
.12411 .75621 L
s
.008 w
.12411 .75621 Mdot
.016 w
.12411 .75621 m
.12439 .75635 L
s
1 .761 0 r
.008 w
.12439 .75635 Mdot
.016 w
.12439 .75635 m
.12473 .75644 L
s
.008 w
.12473 .75644 Mdot
.016 w
.12473 .75644 m
.12513 .75651 L
s
1 .76 0 r
.008 w
.12513 .75651 Mdot
.016 w
.12513 .75651 m
.12558 .75652 L
s
.008 w
.12558 .75652 Mdot
.016 w
.12558 .75652 m
.12602 .75653 L
s
1 .759 0 r
.008 w
.12602 .75653 Mdot
.016 w
.12602 .75653 m
.12647 .75651 L
s
.008 w
.12647 .75651 Mdot
.016 w
.12647 .75651 m
.12686 .75648 L
s
1 .758 0 r
.008 w
.12686 .75648 Mdot
.016 w
.12686 .75648 m
.12722 .75646 L
s
.008 w
.12722 .75646 Mdot
.016 w
.12722 .75646 m
.12756 .75647 L
s
1 .757 0 r
.008 w
.12756 .75647 Mdot
.016 w
.12756 .75647 m
.12789 .75652 L
s
.008 w
.12789 .75652 Mdot
.016 w
.12789 .75652 m
.12818 .75659 L
s
1 .756 0 r
.008 w
.12818 .75659 Mdot
.016 w
.12818 .75659 m
.12843 .75664 L
s
.008 w
.12843 .75664 Mdot
.016 w
.12843 .75664 m
.12859 .75663 L
s
1 .755 0 r
.008 w
.12859 .75663 Mdot
.016 w
.12859 .75663 m
.12865 .75657 L
s
.008 w
.12865 .75657 Mdot
.016 w
.12865 .75657 m
.12859 .7565 L
s
1 .754 0 r
.008 w
.12859 .7565 Mdot
.016 w
.12859 .7565 m
.12845 .75642 L
s
.008 w
.12845 .75642 Mdot
.016 w
.12845 .75642 m
.12827 .75635 L
s
1 .753 0 r
.008 w
.12827 .75635 Mdot
.016 w
.12827 .75635 m
.12809 .75628 L
s
.008 w
.12809 .75628 Mdot
.016 w
.12809 .75628 m
.12794 .75622 L
s
1 .752 0 r
.008 w
.12794 .75622 Mdot
.016 w
.12794 .75622 m
.12781 .75617 L
s
.008 w
.12781 .75617 Mdot
.016 w
.12781 .75617 m
.12772 .75617 L
s
1 .751 0 r
.008 w
.12772 .75617 Mdot
.016 w
.12772 .75617 m
.12767 .75626 L
s
.008 w
.12767 .75626 Mdot
.016 w
.12767 .75626 m
.12765 .75646 L
s
1 .75 0 r
.008 w
.12765 .75646 Mdot
.016 w
.12765 .75646 m
.12765 .75674 L
s
.008 w
.12765 .75674 Mdot
.016 w
.12765 .75674 m
.12766 .75709 L
s
1 .749 0 r
.008 w
.12766 .75709 Mdot
.016 w
.12766 .75709 m
.12772 .75751 L
s
.008 w
.12772 .75751 Mdot
.016 w
.12772 .75751 m
.1278 .75799 L
s
1 .748 0 r
.008 w
.1278 .75799 Mdot
.016 w
.1278 .75799 m
.12789 .75853 L
s
.008 w
.12789 .75853 Mdot
.016 w
.12789 .75853 m
.128 .7591 L
s
1 .747 0 r
.008 w
.128 .7591 Mdot
.016 w
.128 .7591 m
.12811 .75963 L
s
.008 w
.12811 .75963 Mdot
.016 w
.12811 .75963 m
.12823 .76017 L
s
1 .746 0 r
.008 w
.12823 .76017 Mdot
.016 w
.12823 .76017 m
.12834 .76067 L
s
.008 w
.12834 .76067 Mdot
.016 w
.12834 .76067 m
.12847 .76112 L
s
1 .745 0 r
.008 w
.12847 .76112 Mdot
.016 w
.12847 .76112 m
.12863 .76152 L
s
.008 w
.12863 .76152 Mdot
.016 w
.12863 .76152 m
.12885 .76188 L
s
1 .744 0 r
.008 w
.12885 .76188 Mdot
.016 w
.12885 .76188 m
.12917 .76216 L
s
.008 w
.12917 .76216 Mdot
.016 w
.12917 .76216 m
.1296 .76238 L
s
1 .743 0 r
.008 w
.1296 .76238 Mdot
.016 w
.1296 .76238 m
.13017 .76258 L
s
.008 w
.13017 .76258 Mdot
.016 w
.13017 .76258 m
.13088 .76272 L
s
1 .742 0 r
.008 w
.13088 .76272 Mdot
.016 w
.13088 .76272 m
.13166 .76279 L
s
.008 w
.13166 .76279 Mdot
.016 w
.13166 .76279 m
.13253 .76282 L
s
1 .741 0 r
.008 w
.13253 .76282 Mdot
.016 w
.13253 .76282 m
.13341 .76285 L
s
.008 w
.13341 .76285 Mdot
.016 w
.13341 .76285 m
.13428 .76291 L
s
1 .74 0 r
.008 w
.13428 .76291 Mdot
.016 w
.13428 .76291 m
.13509 .76298 L
s
.008 w
.13509 .76298 Mdot
.016 w
.13509 .76298 m
.13581 .76305 L
s
1 .739 0 r
.008 w
.13581 .76305 Mdot
.016 w
.13581 .76305 m
.13638 .76311 L
s
.008 w
.13638 .76311 Mdot
.016 w
.13638 .76311 m
.13671 .76316 L
s
1 .738 0 r
.008 w
.13671 .76316 Mdot
.016 w
.13671 .76316 m
.13701 .7632 L
s
.008 w
.13701 .7632 Mdot
.016 w
.13701 .7632 m
.13721 .76324 L
s
1 .737 0 r
.008 w
.13721 .76324 Mdot
.016 w
.13721 .76324 m
.13728 .76326 L
s
.008 w
.13728 .76326 Mdot
.016 w
.13728 .76326 m
.13723 .76326 L
s
1 .736 0 r
.008 w
.13723 .76326 Mdot
.016 w
.13723 .76326 m
.13706 .76322 L
s
.008 w
.13706 .76322 Mdot
.016 w
.13706 .76322 m
.1368 .76318 L
s
1 .735 0 r
.008 w
.1368 .76318 Mdot
.016 w
.1368 .76318 m
.13649 .76314 L
s
.008 w
.13649 .76314 Mdot
.016 w
.13649 .76314 m
.13616 .76309 L
s
1 .734 0 r
.008 w
.13616 .76309 Mdot
.016 w
.13616 .76309 m
.1358 .76301 L
s
.008 w
.1358 .76301 Mdot
.016 w
.1358 .76301 m
.13542 .76291 L
s
1 .733 0 r
.008 w
.13542 .76291 Mdot
.016 w
.13542 .76291 m
.13503 .76277 L
s
.008 w
.13503 .76277 Mdot
.016 w
.13503 .76277 m
.13463 .76262 L
s
1 .732 0 r
.008 w
.13463 .76262 Mdot
.016 w
.13463 .76262 m
.13425 .76249 L
s
.008 w
.13425 .76249 Mdot
.016 w
.13425 .76249 m
.13395 .76245 L
s
1 .731 0 r
.008 w
.13395 .76245 Mdot
.016 w
.13395 .76245 m
.13376 .76254 L
s
.008 w
.13376 .76254 Mdot
.016 w
.13376 .76254 m
.13371 .76278 L
s
1 .73 0 r
.008 w
.13371 .76278 Mdot
.016 w
.13371 .76278 m
.13381 .76318 L
s
.008 w
.13381 .76318 Mdot
.016 w
.13381 .76318 m
.13405 .76376 L
s
1 .729 0 r
.008 w
.13405 .76376 Mdot
.016 w
.13405 .76376 m
.13443 .7645 L
s
.008 w
.13443 .7645 Mdot
.016 w
.13443 .7645 m
.13497 .76536 L
s
1 .728 0 r
.008 w
.13497 .76536 Mdot
.016 w
.13497 .76536 m
.13557 .76631 L
s
.008 w
.13557 .76631 Mdot
.016 w
.13557 .76631 m
.13613 .76727 L
s
1 .727 0 r
.008 w
.13613 .76727 Mdot
.016 w
.13613 .76727 m
.13687 .76825 L
s
.008 w
.13687 .76825 Mdot
.016 w
.13687 .76825 m
.13775 .7693 L
s
1 .726 0 r
.008 w
.13775 .7693 Mdot
.016 w
.13775 .7693 m
.13869 .77032 L
s
.008 w
.13869 .77032 Mdot
.016 w
.13869 .77032 m
.13972 .77136 L
s
1 .725 0 r
.008 w
.13972 .77136 Mdot
.016 w
.13972 .77136 m
.14082 .77242 L
s
.008 w
.14082 .77242 Mdot
.016 w
.14082 .77242 m
.14197 .7735 L
s
1 .724 0 r
.008 w
.14197 .7735 Mdot
.016 w
.14197 .7735 m
.14319 .77461 L
s
.008 w
.14319 .77461 Mdot
.016 w
.14319 .77461 m
.14447 .77575 L
s
1 .723 0 r
.008 w
.14447 .77575 Mdot
.016 w
.14447 .77575 m
.14575 .77691 L
s
.008 w
.14575 .77691 Mdot
.016 w
.14575 .77691 m
.14707 .77811 L
s
1 .722 0 r
.008 w
.14707 .77811 Mdot
.016 w
.14707 .77811 m
.14856 .77948 L
s
.008 w
.14856 .77948 Mdot
.016 w
.14856 .77948 m
.14979 .78065 L
s
1 .721 0 r
.008 w
.14979 .78065 Mdot
.016 w
.14979 .78065 m
.15118 .78202 L
s
.008 w
.15118 .78202 Mdot
.016 w
.15118 .78202 m
.15249 .78334 L
s
1 .72 0 r
.008 w
.15249 .78334 Mdot
.016 w
.15249 .78334 m
.15373 .78467 L
s
.008 w
.15373 .78467 Mdot
.016 w
.15373 .78467 m
.15482 .78591 L
s
1 .719 0 r
.008 w
.15482 .78591 Mdot
.016 w
.15482 .78591 m
.15568 .787 L
s
.008 w
.15568 .787 Mdot
.016 w
.15568 .787 m
.15633 .7879 L
s
1 .718 0 r
.008 w
.15633 .7879 Mdot
.016 w
.15633 .7879 m
.15679 .7886 L
s
.008 w
.15679 .7886 Mdot
.016 w
.15679 .7886 m
.15705 .78909 L
s
1 .717 0 r
.008 w
.15705 .78909 Mdot
.016 w
.15705 .78909 m
.15713 .78939 L
s
.008 w
.15713 .78939 Mdot
.016 w
.15713 .78939 m
.15705 .78954 L
s
1 .716 0 r
.008 w
.15705 .78954 Mdot
.016 w
.15705 .78954 m
.15685 .78956 L
s
.008 w
.15685 .78956 Mdot
.016 w
.15685 .78956 m
.15655 .78944 L
s
1 .715 0 r
.008 w
.15655 .78944 Mdot
.016 w
.15655 .78944 m
.1562 .78923 L
s
.008 w
.1562 .78923 Mdot
.016 w
.1562 .78923 m
.15585 .78898 L
s
1 .714 0 r
.008 w
.15585 .78898 Mdot
.016 w
.15585 .78898 m
.15554 .78875 L
s
.008 w
.15554 .78875 Mdot
.016 w
.15554 .78875 m
.15535 .78863 L
s
1 .713 0 r
.008 w
.15535 .78863 Mdot
.016 w
.15535 .78863 m
.15535 .78867 L
s
.008 w
.15535 .78867 Mdot
.016 w
.15535 .78867 m
.15559 .78895 L
s
1 .712 0 r
.008 w
.15559 .78895 Mdot
.016 w
.15559 .78895 m
.1561 .78946 L
s
.008 w
.1561 .78946 Mdot
.016 w
.1561 .78946 m
.15691 .79025 L
s
1 .711 0 r
.008 w
.15691 .79025 Mdot
.016 w
.15691 .79025 m
.15798 .79133 L
s
.008 w
.15798 .79133 Mdot
.016 w
.15798 .79133 m
.15938 .7927 L
s
1 .71 0 r
.008 w
.15938 .7927 Mdot
.016 w
.15938 .7927 m
.16112 .79437 L
s
.008 w
.16112 .79437 Mdot
.016 w
.16112 .79437 m
.16317 .79635 L
s
1 .709 0 r
.008 w
.16317 .79635 Mdot
.016 w
.16317 .79635 m
.16546 .79837 L
s
.008 w
.16546 .79837 Mdot
.016 w
.16546 .79837 m
.16797 .8006 L
s
1 .708 0 r
.008 w
.16797 .8006 Mdot
.016 w
.16797 .8006 m
.17076 .80324 L
s
.008 w
.17076 .80324 Mdot
.016 w
.17076 .80324 m
.1735 .80571 L
s
1 .707 0 r
.008 w
.1735 .80571 Mdot
.016 w
.1735 .80571 m
.17641 .80836 L
s
.008 w
.17641 .80836 Mdot
.016 w
.17641 .80836 m
.17935 .81108 L
s
1 .706 0 r
.008 w
.17935 .81108 Mdot
.016 w
.17935 .81108 m
.18233 .81381 L
s
.008 w
.18233 .81381 Mdot
.016 w
.18233 .81381 m
.18523 .81659 L
s
1 .705 0 r
.008 w
.18523 .81659 Mdot
.016 w
.18523 .81659 m
.18817 .81931 L
s
.008 w
.18817 .81931 Mdot
.016 w
.18817 .81931 m
.19115 .82214 L
s
1 .704 0 r
.008 w
.19115 .82214 Mdot
.016 w
.19115 .82214 m
.1942 .825 L
s
.008 w
.1942 .825 Mdot
.016 w
.1942 .825 m
.19732 .82798 L
s
1 .703 0 r
.008 w
.19732 .82798 Mdot
.016 w
.19732 .82798 m
.2006 .83134 L
s
.008 w
.2006 .83134 Mdot
.016 w
.2006 .83134 m
.20366 .83421 L
s
1 .702 0 r
.008 w
.20366 .83421 Mdot
.016 w
.20366 .83421 m
.20695 .83757 L
s
.008 w
.20695 .83757 Mdot
.016 w
.20695 .83757 m
.21033 .84098 L
s
1 .701 0 r
.008 w
.21033 .84098 Mdot
.016 w
.21033 .84098 m
.21368 .84426 L
s
.008 w
.21368 .84426 Mdot
.016 w
.21368 .84426 m
.21698 .84754 L
s
1 .7 0 r
.008 w
.21698 .84754 Mdot
.016 w
.21698 .84754 m
.22024 .85078 L
s
.008 w
.22024 .85078 Mdot
.016 w
.22024 .85078 m
.22326 .85379 L
s
1 .699 0 r
.008 w
.22326 .85379 Mdot
.016 w
.22326 .85379 m
.22615 .85663 L
s
.008 w
.22615 .85663 Mdot
.016 w
.22615 .85663 m
.22874 .85915 L
s
1 .698 0 r
.008 w
.22874 .85915 Mdot
.016 w
.22874 .85915 m
.23109 .86142 L
s
.008 w
.23109 .86142 Mdot
.016 w
.23109 .86142 m
.23311 .86322 L
s
1 .697 0 r
.008 w
.23311 .86322 Mdot
.016 w
.23311 .86322 m
.23483 .86468 L
s
.008 w
.23483 .86468 Mdot
.016 w
.23483 .86468 m
.23622 .86576 L
s
1 .696 0 r
.008 w
.23622 .86576 Mdot
.016 w
.23622 .86576 m
.23741 .86649 L
s
.008 w
.23741 .86649 Mdot
.016 w
.23741 .86649 m
.23818 .86692 L
s
1 .695 0 r
.008 w
.23818 .86692 Mdot
.016 w
.23818 .86692 m
.23881 .86716 L
s
.008 w
.23881 .86716 Mdot
.016 w
.23881 .86716 m
.23924 .86724 L
s
1 .694 0 r
.008 w
.23924 .86724 Mdot
.016 w
.23924 .86724 m
.23948 .86722 L
s
.008 w
.23948 .86722 Mdot
.016 w
.23948 .86722 m
.23964 .86717 L
s
1 .693 0 r
.008 w
.23964 .86717 Mdot
.016 w
.23964 .86717 m
.2397 .86707 L
s
.008 w
.2397 .86707 Mdot
.016 w
.2397 .86707 m
.23973 .86698 L
s
1 .692 0 r
.008 w
.23973 .86698 Mdot
.016 w
.23973 .86698 m
.23976 .86695 L
s
.008 w
.23976 .86695 Mdot
.016 w
.23976 .86695 m
.23986 .86705 L
s
1 .691 0 r
.008 w
.23986 .86705 Mdot
.016 w
.23986 .86705 m
.24003 .86727 L
s
.008 w
.24003 .86727 Mdot
.016 w
.24003 .86727 m
.24032 .86763 L
s
1 .69 0 r
.008 w
.24032 .86763 Mdot
.016 w
.24032 .86763 m
.24076 .86812 L
s
.008 w
.24076 .86812 Mdot
.016 w
.24076 .86812 m
.24137 .86877 L
s
1 .689 0 r
.008 w
.24137 .86877 Mdot
.016 w
.24137 .86877 m
.24214 .86951 L
s
.008 w
.24214 .86951 Mdot
.016 w
.24214 .86951 m
.24306 .87028 L
s
1 .688 0 r
.008 w
.24306 .87028 Mdot
.016 w
.24306 .87028 m
.2441 .87103 L
s
.008 w
.2441 .87103 Mdot
.016 w
.2441 .87103 m
.24535 .87179 L
s
1 .687 0 r
.008 w
.24535 .87179 Mdot
.016 w
.24535 .87179 m
.24673 .87254 L
s
.008 w
.24673 .87254 Mdot
.016 w
.24673 .87254 m
.24825 .87332 L
s
1 .686 0 r
.008 w
.24825 .87332 Mdot
.016 w
.24825 .87332 m
.24985 .87409 L
s
.008 w
.24985 .87409 Mdot
.016 w
.24985 .87409 m
.25144 .87485 L
s
1 .685 0 r
.008 w
.25144 .87485 Mdot
.016 w
.25144 .87485 m
.253 .87558 L
s
.008 w
.253 .87558 Mdot
.016 w
.253 .87558 m
.2544 .8762 L
s
1 .684 0 r
.008 w
.2544 .8762 Mdot
.016 w
.2544 .8762 m
.25558 .87664 L
s
.008 w
.25558 .87664 Mdot
.016 w
.25558 .87664 m
.25653 .87693 L
s
1 .683 0 r
.008 w
.25653 .87693 Mdot
.016 w
.25653 .87693 m
.25729 .87716 L
s
.008 w
.25729 .87716 Mdot
.016 w
.25729 .87716 m
.25788 .87734 L
s
1 .682 0 r
.008 w
.25788 .87734 Mdot
.016 w
.25788 .87734 m
.2583 .87744 L
s
.008 w
.2583 .87744 Mdot
.016 w
.2583 .87744 m
.25859 .87748 L
s
1 .681 0 r
.008 w
.25859 .87748 Mdot
.016 w
.25859 .87748 m
.25875 .87747 L
s
.008 w
.25875 .87747 Mdot
.016 w
.25875 .87747 m
.25876 .87745 L
s
1 .68 0 r
.008 w
.25876 .87745 Mdot
.016 w
.25876 .87745 m
.25865 .87743 L
s
.008 w
.25865 .87743 Mdot
.016 w
.25865 .87743 m
.25844 .87741 L
s
1 .679 0 r
.008 w
.25844 .87741 Mdot
.016 w
.25844 .87741 m
.25816 .87738 L
s
.008 w
.25816 .87738 Mdot
.016 w
.25816 .87738 m
.25783 .87734 L
s
1 .678 0 r
.008 w
.25783 .87734 Mdot
.016 w
.25783 .87734 m
.25752 .87733 L
s
.008 w
.25752 .87733 Mdot
.016 w
.25752 .87733 m
.25724 .87733 L
s
1 .677 0 r
.008 w
.25724 .87733 Mdot
.016 w
.25724 .87733 m
.25698 .87742 L
s
.008 w
.25698 .87742 Mdot
.016 w
.25698 .87742 m
.25673 .87757 L
s
1 .676 0 r
.008 w
.25673 .87757 Mdot
.016 w
.25673 .87757 m
.25647 .87778 L
s
.008 w
.25647 .87778 Mdot
.016 w
.25647 .87778 m
.25632 .87801 L
s
1 .675 0 r
.008 w
.25632 .87801 Mdot
.016 w
.25632 .87801 m
.25611 .87818 L
s
.008 w
.25611 .87818 Mdot
.016 w
.25611 .87818 m
.25593 .8784 L
s
1 .674 0 r
.008 w
.25593 .8784 Mdot
.016 w
.25593 .8784 m
.25584 .87869 L
s
.008 w
.25584 .87869 Mdot
.016 w
.25584 .87869 m
.25595 .87912 L
s
1 .673 0 r
.008 w
.25595 .87912 Mdot
.016 w
.25595 .87912 m
.25625 .87964 L
s
.008 w
.25625 .87964 Mdot
.016 w
.25625 .87964 m
.25683 .88034 L
s
1 .672 0 r
.008 w
.25683 .88034 Mdot
.016 w
.25683 .88034 m
.25772 .88119 L
s
.008 w
.25772 .88119 Mdot
.016 w
.25772 .88119 m
.2589 .88214 L
s
1 .671 0 r
.008 w
.2589 .88214 Mdot
.016 w
.2589 .88214 m
.26037 .88317 L
s
.008 w
.26037 .88317 Mdot
.016 w
.26037 .88317 m
.26206 .88417 L
s
1 .67 0 r
.008 w
.26206 .88417 Mdot
.016 w
.26206 .88417 m
.26402 .88526 L
s
.008 w
.26402 .88526 Mdot
.016 w
.26402 .88526 m
.26621 .88641 L
s
1 .669 0 r
.008 w
.26621 .88641 Mdot
.016 w
.26621 .88641 m
.26868 .88764 L
s
.008 w
.26868 .88764 Mdot
.016 w
.26868 .88764 m
.27126 .88895 L
s
1 .668 0 r
.008 w
.27126 .88895 Mdot
.016 w
.27126 .88895 m
.27389 .89023 L
s
.008 w
.27389 .89023 Mdot
.016 w
.27389 .89023 m
.27665 .89151 L
s
1 .667 0 r
.008 w
.27665 .89151 Mdot
.016 w
.27665 .89151 m
.27935 .89277 L
s
.008 w
.27935 .89277 Mdot
.016 w
.27935 .89277 m
.28222 .89397 L
s
1 .666 0 r
.008 w
.28222 .89397 Mdot
.016 w
.28222 .89397 m
.28483 .89516 L
s
.008 w
.28483 .89516 Mdot
.016 w
.28483 .89516 m
.28751 .89632 L
s
1 .665 0 r
.008 w
.28751 .89632 Mdot
.016 w
.28751 .89632 m
.29018 .89743 L
s
.008 w
.29018 .89743 Mdot
.016 w
.29018 .89743 m
.29281 .89853 L
s
1 .664 0 r
.008 w
.29281 .89853 Mdot
.016 w
.29281 .89853 m
.29543 .8996 L
s
.008 w
.29543 .8996 Mdot
.016 w
.29543 .8996 m
.29807 .90062 L
s
1 .663 0 r
.008 w
.29807 .90062 Mdot
.016 w
.29807 .90062 m
.30077 .90161 L
s
.008 w
.30077 .90161 Mdot
.016 w
.30077 .90161 m
.30358 .90257 L
s
1 .662 0 r
.008 w
.30358 .90257 Mdot
.016 w
.30358 .90257 m
.30657 .9035 L
s
.008 w
.30657 .9035 Mdot
.016 w
.30657 .9035 m
.3096 .90441 L
s
1 .661 0 r
.008 w
.3096 .90441 Mdot
.016 w
.3096 .90441 m
.31282 .90531 L
s
.008 w
.31282 .90531 Mdot
.016 w
.31282 .90531 m
.31626 .90623 L
s
1 .66 0 r
.008 w
.31626 .90623 Mdot
.016 w
.31626 .90623 m
.31951 .90716 L
s
.008 w
.31951 .90716 Mdot
.016 w
.31951 .90716 m
.32283 .90811 L
s
1 .659 0 r
.008 w
.32283 .90811 Mdot
.016 w
.32283 .90811 m
.3262 .90909 L
s
.008 w
.3262 .90909 Mdot
.016 w
.3262 .90909 m
.32964 .91004 L
s
1 .658 0 r
.008 w
.32964 .91004 Mdot
.016 w
.32964 .91004 m
.3327 .91101 L
s
.008 w
.3327 .91101 Mdot
.016 w
.3327 .91101 m
.33573 .91196 L
s
1 .657 0 r
.008 w
.33573 .91196 Mdot
.016 w
.33573 .91196 m
.33854 .91283 L
s
.008 w
.33854 .91283 Mdot
.016 w
.33854 .91283 m
.34106 .91361 L
s
1 .656 0 r
.008 w
.34106 .91361 Mdot
.016 w
.34106 .91361 m
.3433 .91433 L
s
.008 w
.3433 .91433 Mdot
.016 w
.3433 .91433 m
.34524 .91497 L
s
1 .655 0 r
.008 w
.34524 .91497 Mdot
.016 w
.34524 .91497 m
.34683 .91552 L
s
.008 w
.34683 .91552 Mdot
.016 w
.34683 .91552 m
.34824 .91599 L
s
1 .654 0 r
.008 w
.34824 .91599 Mdot
.016 w
.34824 .91599 m
.34944 .9164 L
s
.008 w
.34944 .9164 Mdot
.016 w
.34944 .9164 m
.35061 .91677 L
s
1 .653 0 r
.008 w
.35061 .91677 Mdot
.016 w
.35061 .91677 m
.35179 .91714 L
s
.008 w
.35179 .91714 Mdot
.016 w
.35179 .91714 m
.35304 .91754 L
s
1 .652 0 r
.008 w
.35304 .91754 Mdot
.016 w
.35304 .91754 m
.35441 .91801 L
s
.008 w
.35441 .91801 Mdot
.016 w
.35441 .91801 m
.35591 .91857 L
s
1 .651 0 r
.008 w
.35591 .91857 Mdot
.016 w
.35591 .91857 m
.35762 .91921 L
s
.008 w
.35762 .91921 Mdot
.016 w
.35762 .91921 m
.35961 .91993 L
s
1 .65 0 r
.008 w
.35961 .91993 Mdot
.016 w
.35961 .91993 m
.36176 .92077 L
s
.008 w
.36176 .92077 Mdot
.016 w
.36176 .92077 m
.36423 .92172 L
s
1 .649 0 r
.008 w
.36423 .92172 Mdot
.016 w
.36423 .92172 m
.36704 .92272 L
s
.008 w
.36704 .92272 Mdot
.016 w
.36704 .92272 m
.37006 .92374 L
s
1 .648 0 r
.008 w
.37006 .92374 Mdot
.016 w
.37006 .92374 m
.37344 .92482 L
s
.008 w
.37344 .92482 Mdot
.016 w
.37344 .92482 m
.37676 .9259 L
s
1 .647 0 r
.008 w
.37676 .9259 Mdot
.016 w
.37676 .9259 m
.38041 .92703 L
s
.008 w
.38041 .92703 Mdot
.016 w
.38041 .92703 m
.38387 .92823 L
s
1 .646 0 r
.008 w
.38387 .92823 Mdot
.016 w
.38387 .92823 m
.38739 .9294 L
s
.008 w
.38739 .9294 Mdot
.016 w
.38739 .9294 m
.39106 .93068 L
s
1 .645 0 r
.008 w
.39106 .93068 Mdot
.016 w
.39106 .93068 m
.39465 .93206 L
s
.008 w
.39465 .93206 Mdot
.016 w
.39465 .93206 m
.39834 .93336 L
s
1 .644 0 r
.008 w
.39834 .93336 Mdot
.016 w
.39834 .93336 m
.4021 .93475 L
s
.008 w
.4021 .93475 Mdot
.016 w
.4021 .93475 m
.40596 .93611 L
s
1 .643 0 r
.008 w
.40596 .93611 Mdot
.016 w
.40596 .93611 m
.40979 .93755 L
s
.008 w
.40979 .93755 Mdot
.016 w
.40979 .93755 m
.41368 .93893 L
s
1 .642 0 r
.008 w
.41368 .93893 Mdot
.016 w
.41368 .93893 m
.41775 .9405 L
s
.008 w
.41775 .9405 Mdot
.016 w
.41775 .9405 m
.42171 .94188 L
s
1 .641 0 r
.008 w
.42171 .94188 Mdot
.016 w
.42171 .94188 m
.42588 .94328 L
s
.008 w
.42588 .94328 Mdot
.016 w
.42588 .94328 m
.42994 .94467 L
s
1 .64 0 r
.008 w
.42994 .94467 Mdot
.016 w
.42994 .94467 m
.4341 .94598 L
s
.008 w
.4341 .94598 Mdot
.016 w
.4341 .94598 m
.43809 .94717 L
s
1 .639 0 r
.008 w
.43809 .94717 Mdot
.016 w
.43809 .94717 m
.44216 .94819 L
s
.008 w
.44216 .94819 Mdot
.016 w
.44216 .94819 m
.44593 .94901 L
s
1 .638 0 r
.008 w
.44593 .94901 Mdot
.016 w
.44593 .94901 m
.44962 .94968 L
s
.008 w
.44962 .94968 Mdot
.016 w
.44962 .94968 m
.45306 .95029 L
s
1 .637 0 r
.008 w
.45306 .95029 Mdot
.016 w
.45306 .95029 m
.45626 .95081 L
s
.008 w
.45626 .95081 Mdot
.016 w
.45626 .95081 m
.45936 .95125 L
s
1 .636 0 r
.008 w
.45936 .95125 Mdot
.016 w
.45936 .95125 m
.46194 .95157 L
s
.008 w
.46194 .95157 Mdot
.016 w
.46194 .95157 m
.46436 .95178 L
s
1 .635 0 r
.008 w
.46436 .95178 Mdot
.016 w
.46436 .95178 m
.46651 .95186 L
s
.008 w
.46651 .95186 Mdot
.016 w
.46651 .95186 m
.46843 .95182 L
s
1 .634 0 r
.008 w
.46843 .95182 Mdot
.016 w
.46843 .95182 m
.47003 .95169 L
s
.008 w
.47003 .95169 Mdot
.016 w
.47003 .95169 m
.47148 .95148 L
s
1 .633 0 r
.008 w
.47148 .95148 Mdot
.016 w
.47148 .95148 m
.47252 .95127 L
s
.008 w
.47252 .95127 Mdot
.016 w
.47252 .95127 m
.47339 .9511 L
s
1 .632 0 r
.008 w
.47339 .9511 Mdot
.016 w
.47339 .9511 m
.47407 .95099 L
s
.008 w
.47407 .95099 Mdot
.016 w
.47407 .95099 m
.47462 .9509 L
s
1 .631 0 r
.008 w
.47462 .9509 Mdot
.016 w
.47462 .9509 m
.47502 .9508 L
s
.008 w
.47502 .9508 Mdot
.016 w
.47502 .9508 m
.47533 .95069 L
s
1 .63 0 r
.008 w
.47533 .95069 Mdot
.016 w
.47533 .95069 m
.47558 .95056 L
s
.008 w
.47558 .95056 Mdot
.016 w
.47558 .95056 m
.47577 .95043 L
s
1 .629 0 r
.008 w
.47577 .95043 Mdot
.016 w
.47577 .95043 m
.47587 .95031 L
s
.008 w
.47587 .95031 Mdot
.016 w
.47587 .95031 m
.4759 .95021 L
s
1 .628 0 r
.008 w
.4759 .95021 Mdot
.016 w
.4759 .95021 m
.47585 .95014 L
s
.008 w
.47585 .95014 Mdot
.016 w
.47585 .95014 m
.47575 .95012 L
s
1 .627 0 r
.008 w
.47575 .95012 Mdot
.016 w
.47575 .95012 m
.47558 .95014 L
s
.008 w
.47558 .95014 Mdot
.016 w
.47558 .95014 m
.4754 .95018 L
s
1 .626 0 r
.008 w
.4754 .95018 Mdot
.016 w
.4754 .95018 m
.47521 .95022 L
s
.008 w
.47521 .95022 Mdot
.016 w
.47521 .95022 m
.47501 .95027 L
s
1 .625 0 r
.008 w
.47501 .95027 Mdot
.016 w
.47501 .95027 m
.47476 .9503 L
s
.008 w
.47476 .9503 Mdot
.016 w
.47476 .9503 m
.47447 .95032 L
s
1 .624 0 r
.008 w
.47447 .95032 Mdot
.016 w
.47447 .95032 m
.47414 .95033 L
s
.008 w
.47414 .95033 Mdot
.016 w
.47414 .95033 m
.47384 .95035 L
s
1 .623 0 r
.008 w
.47384 .95035 Mdot
.016 w
.47384 .95035 m
.47349 .95037 L
s
.008 w
.47349 .95037 Mdot
.016 w
.47349 .95037 m
.47314 .95039 L
s
1 .622 0 r
.008 w
.47314 .95039 Mdot
.016 w
.47314 .95039 m
.47283 .9504 L
s
.008 w
.47283 .9504 Mdot
.016 w
.47283 .9504 m
.47258 .9504 L
s
1 .621 0 r
.008 w
.47258 .9504 Mdot
.016 w
.47258 .9504 m
.47235 .95039 L
s
.008 w
.47235 .95039 Mdot
.016 w
.47235 .95039 m
.47214 .95039 L
s
1 .62 0 r
.008 w
.47214 .95039 Mdot
.016 w
.47214 .95039 m
.47201 .9504 L
s
.008 w
.47201 .9504 Mdot
.016 w
.47201 .9504 m
.47193 .95042 L
s
1 .619 0 r
.008 w
.47193 .95042 Mdot
.016 w
.47193 .95042 m
.4719 .95045 L
s
.008 w
.4719 .95045 Mdot
.016 w
.4719 .95045 m
.47195 .95017 L
s
1 .618 0 r
.008 w
.47195 .95017 Mdot
.016 w
.47195 .95017 m
.47207 .95023 L
s
.008 w
.47207 .95023 Mdot
.016 w
.47207 .95023 m
.47225 .95028 L
s
1 .617 0 r
.008 w
.47225 .95028 Mdot
.016 w
.47225 .95028 m
.47249 .95034 L
s
.008 w
.47249 .95034 Mdot
.016 w
.47249 .95034 m
.47282 .95037 L
s
1 .616 0 r
.008 w
.47282 .95037 Mdot
.016 w
.47282 .95037 m
.4732 .9504 L
s
.008 w
.4732 .9504 Mdot
.016 w
.4732 .9504 m
.47357 .95043 L
s
1 .615 0 r
.008 w
.47357 .95043 Mdot
.016 w
.47357 .95043 m
.47387 .95046 L
s
.008 w
.47387 .95046 Mdot
.016 w
.47387 .95046 m
.47418 .95049 L
s
1 .614 0 r
.008 w
.47418 .95049 Mdot
.016 w
.47418 .95049 m
.47445 .95053 L
s
.008 w
.47445 .95053 Mdot
.016 w
.47445 .95053 m
.47466 .95059 L
s
1 .613 0 r
.008 w
.47466 .95059 Mdot
.016 w
.47466 .95059 m
.47484 .95065 L
s
.008 w
.47484 .95065 Mdot
.016 w
.47484 .95065 m
.47505 .95073 L
s
1 .612 0 r
.008 w
.47505 .95073 Mdot
.016 w
.47505 .95073 m
.47528 .95082 L
s
.008 w
.47528 .95082 Mdot
.016 w
.47528 .95082 m
.47556 .95092 L
s
1 .611 0 r
.008 w
.47556 .95092 Mdot
.016 w
.47556 .95092 m
.47589 .951 L
s
.008 w
.47589 .951 Mdot
.016 w
.47589 .951 m
.47632 .95103 L
s
1 .61 0 r
.008 w
.47632 .95103 Mdot
.016 w
.47632 .95103 m
.47686 .95104 L
s
.008 w
.47686 .95104 Mdot
.016 w
.47686 .95104 m
.47753 .95102 L
s
1 .609 0 r
.008 w
.47753 .95102 Mdot
.016 w
.47753 .95102 m
.47833 .95096 L
s
.008 w
.47833 .95096 Mdot
.016 w
.47833 .95096 m
.47933 .95087 L
s
1 .608 0 r
.008 w
.47933 .95087 Mdot
.016 w
.47933 .95087 m
.48051 .95071 L
s
.008 w
.48051 .95071 Mdot
.016 w
.48051 .95071 m
.48186 .95049 L
s
1 .607 0 r
.008 w
.48186 .95049 Mdot
.016 w
.48186 .95049 m
.48336 .95023 L
s
.008 w
.48336 .95023 Mdot
.016 w
.48336 .95023 m
.48492 .94995 L
s
1 .606 0 r
.008 w
.48492 .94995 Mdot
.016 w
.48492 .94995 m
.48659 .94966 L
s
.008 w
.48659 .94966 Mdot
.016 w
.48659 .94966 m
.48836 .94939 L
s
1 .605 0 r
.008 w
.48836 .94939 Mdot
.016 w
.48836 .94939 m
.49029 .94914 L
s
.008 w
.49029 .94914 Mdot
.016 w
.49029 .94914 m
.4923 .94892 L
s
1 .604 0 r
.008 w
.4923 .94892 Mdot
.016 w
.4923 .94892 m
.49462 .94872 L
s
.008 w
.49462 .94872 Mdot
.016 w
.49462 .94872 m
.49666 .94855 L
s
1 .603 0 r
.008 w
.49666 .94855 Mdot
.016 w
.49666 .94855 m
.49906 .94837 L
s
.008 w
.49906 .94837 Mdot
.016 w
.49906 .94837 m
.50152 .94817 L
s
1 .602 0 r
.008 w
.50152 .94817 Mdot
.016 w
.50152 .94817 m
.5042 .94794 L
s
.008 w
.5042 .94794 Mdot
.016 w
.5042 .94794 m
.50704 .94767 L
s
1 .601 0 r
.008 w
.50704 .94767 Mdot
.016 w
.50704 .94767 m
.51014 .94736 L
s
.008 w
.51014 .94736 Mdot
.016 w
.51014 .94736 m
.51325 .94702 L
s
1 .6 0 r
.008 w
.51325 .94702 Mdot
.016 w
.51325 .94702 m
.51633 .94663 L
s
.008 w
.51633 .94663 Mdot
.016 w
.51633 .94663 m
.51937 .94622 L
s
1 .599 0 r
.008 w
.51937 .94622 Mdot
.016 w
.51937 .94622 m
.52254 .9458 L
s
.008 w
.52254 .9458 Mdot
.016 w
.52254 .9458 m
.52553 .94537 L
s
1 .598 0 r
.008 w
.52553 .94537 Mdot
.016 w
.52553 .94537 m
.52849 .94493 L
s
.008 w
.52849 .94493 Mdot
.016 w
.52849 .94493 m
.53145 .94451 L
s
1 .597 0 r
.008 w
.53145 .94451 Mdot
.016 w
.53145 .94451 m
.53408 .94412 L
s
.008 w
.53408 .94412 Mdot
.016 w
.53408 .94412 m
.53675 .94375 L
s
1 .596 0 r
.008 w
.53675 .94375 Mdot
.016 w
.53675 .94375 m
.53936 .94341 L
s
.008 w
.53936 .94341 Mdot
.016 w
.53936 .94341 m
.54193 .94308 L
s
1 .595 0 r
.008 w
.54193 .94308 Mdot
.016 w
.54193 .94308 m
.54446 .94269 L
s
.008 w
.54446 .94269 Mdot
.016 w
.54446 .94269 m
.54697 .94222 L
s
1 .594 0 r
.008 w
.54697 .94222 Mdot
.016 w
.54697 .94222 m
.54942 .94162 L
s
.008 w
.54942 .94162 Mdot
.016 w
.54942 .94162 m
.55186 .94091 L
s
1 .593 0 r
.008 w
.55186 .94091 Mdot
.016 w
.55186 .94091 m
.5542 .94009 L
s
.008 w
.5542 .94009 Mdot
.016 w
.5542 .94009 m
.55642 .93929 L
s
1 .592 0 r
.008 w
.55642 .93929 Mdot
.016 w
.55642 .93929 m
.55861 .93848 L
s
.008 w
.55861 .93848 Mdot
.016 w
.55861 .93848 m
.56061 .93775 L
s
1 .591 0 r
.008 w
.56061 .93775 Mdot
.016 w
.56061 .93775 m
.56253 .93716 L
s
.008 w
.56253 .93716 Mdot
.016 w
.56253 .93716 m
.56431 .93665 L
s
1 .59 0 r
.008 w
.56431 .93665 Mdot
.016 w
.56431 .93665 m
.56578 .93623 L
s
.008 w
.56578 .93623 Mdot
.016 w
.56578 .93623 m
.56703 .93592 L
s
1 .589 0 r
.008 w
.56703 .93592 Mdot
.016 w
.56703 .93592 m
.5681 .93571 L
s
.008 w
.5681 .93571 Mdot
.016 w
.5681 .93571 m
.56904 .93563 L
s
1 .588 0 r
.008 w
.56904 .93563 Mdot
.016 w
.56904 .93563 m
.56995 .93573 L
s
.008 w
.56995 .93573 Mdot
.016 w
.56995 .93573 m
.57096 .93597 L
s
1 .587 0 r
.008 w
.57096 .93597 Mdot
.016 w
.57096 .93597 m
.57224 .93631 L
s
.008 w
.57224 .93631 Mdot
.016 w
.57224 .93631 m
.57357 .9367 L
s
1 .586 0 r
.008 w
.57357 .9367 Mdot
.016 w
.57357 .9367 m
.5753 .93705 L
s
.008 w
.5753 .93705 Mdot
.016 w
.5753 .93705 m
.5773 .93732 L
s
1 .585 0 r
.008 w
.5773 .93732 Mdot
.016 w
.5773 .93732 m
.57958 .93744 L
s
.008 w
.57958 .93744 Mdot
.016 w
.57958 .93744 m
.58223 .93738 L
s
1 .584 0 r
.008 w
.58223 .93738 Mdot
.016 w
.58223 .93738 m
.58508 .93716 L
s
.008 w
.58508 .93716 Mdot
.016 w
.58508 .93716 m
.5882 .93687 L
s
1 .583 0 r
.008 w
.5882 .93687 Mdot
.016 w
.5882 .93687 m
.59162 .93642 L
s
.008 w
.59162 .93642 Mdot
.016 w
.59162 .93642 m
.59497 .9359 L
s
1 .582 0 r
.008 w
.59497 .9359 Mdot
.016 w
.59497 .9359 m
.5989 .93551 L
s
.008 w
.5989 .93551 Mdot
.016 w
.5989 .93551 m
.60247 .93492 L
s
1 .581 0 r
.008 w
.60247 .93492 Mdot
.016 w
.60247 .93492 m
.60608 .9343 L
s
.008 w
.60608 .9343 Mdot
.016 w
.60608 .9343 m
.60962 .93365 L
s
1 .58 0 r
.008 w
.60962 .93365 Mdot
.016 w
.60962 .93365 m
.61297 .93294 L
s
.008 w
.61297 .93294 Mdot
.016 w
.61297 .93294 m
.6162 .93224 L
s
1 .579 0 r
.008 w
.6162 .93224 Mdot
.016 w
.6162 .93224 m
.61933 .93146 L
s
.008 w
.61933 .93146 Mdot
.016 w
.61933 .93146 m
.62235 .9306 L
s
1 .578 0 r
.008 w
.62235 .9306 Mdot
.016 w
.62235 .9306 m
.62532 .92975 L
s
.008 w
.62532 .92975 Mdot
.016 w
.62532 .92975 m
.62823 .9289 L
s
1 .577 0 r
.008 w
.62823 .9289 Mdot
.016 w
.62823 .9289 m
.63098 .9281 L
s
.008 w
.63098 .9281 Mdot
.016 w
.63098 .9281 m
.63357 .92733 L
s
1 .576 0 r
.008 w
.63357 .92733 Mdot
.016 w
.63357 .92733 m
.63594 .92665 L
s
.008 w
.63594 .92665 Mdot
.016 w
.63594 .92665 m
.63806 .92598 L
s
1 .575 0 r
.008 w
.63806 .92598 Mdot
.016 w
.63806 .92598 m
.63995 .92533 L
s
.008 w
.63995 .92533 Mdot
.016 w
.63995 .92533 m
.64159 .92474 L
s
1 .574 0 r
.008 w
.64159 .92474 Mdot
.016 w
.64159 .92474 m
.64309 .92426 L
s
.008 w
.64309 .92426 Mdot
.016 w
.64309 .92426 m
.64445 .92386 L
s
1 .573 0 r
.008 w
.64445 .92386 Mdot
.016 w
.64445 .92386 m
.64572 .92349 L
s
.008 w
.64572 .92349 Mdot
.016 w
.64572 .92349 m
.64691 .92313 L
s
1 .572 0 r
.008 w
.64691 .92313 Mdot
.016 w
.64691 .92313 m
.64802 .92278 L
s
.008 w
.64802 .92278 Mdot
.016 w
.64802 .92278 m
.64901 .92252 L
s
1 .571 0 r
.008 w
.64901 .92252 Mdot
.016 w
.64901 .92252 m
.64981 .92238 L
s
.008 w
.64981 .92238 Mdot
.016 w
.64981 .92238 m
.65052 .92226 L
s
1 .57 0 r
.008 w
.65052 .92226 Mdot
.016 w
.65052 .92226 m
.65112 .92222 L
s
.008 w
.65112 .92222 Mdot
.016 w
.65112 .92222 m
.65163 .92217 L
s
1 .569 0 r
.008 w
.65163 .92217 Mdot
.016 w
.65163 .92217 m
.6521 .92207 L
s
.008 w
.6521 .92207 Mdot
.016 w
.6521 .92207 m
.65252 .92192 L
s
1 .568 0 r
.008 w
.65252 .92192 Mdot
.016 w
.65252 .92192 m
.65286 .92178 L
s
.008 w
.65286 .92178 Mdot
.016 w
.65286 .92178 m
.65303 .9217 L
s
1 .567 0 r
.008 w
.65303 .9217 Mdot
.016 w
.65303 .9217 m
.65299 .92173 L
s
.008 w
.65299 .92173 Mdot
.016 w
.65299 .92173 m
.65275 .92182 L
s
1 .566 0 r
.008 w
.65275 .92182 Mdot
.016 w
.65275 .92182 m
.65234 .92204 L
s
.008 w
.65234 .92204 Mdot
.016 w
.65234 .92204 m
.65181 .92236 L
s
1 .565 0 r
.008 w
.65181 .92236 Mdot
.016 w
.65181 .92236 m
.65123 .92273 L
s
.008 w
.65123 .92273 Mdot
.016 w
.65123 .92273 m
.65069 .92303 L
s
1 .564 0 r
.008 w
.65069 .92303 Mdot
.016 w
.65069 .92303 m
.65025 .92334 L
s
.008 w
.65025 .92334 Mdot
.016 w
.65025 .92334 m
.6499 .92365 L
s
1 .563 0 r
.008 w
.6499 .92365 Mdot
.016 w
.6499 .92365 m
.64962 .92397 L
s
.008 w
.64962 .92397 Mdot
.016 w
.64962 .92397 m
.64936 .92423 L
s
1 .562 0 r
.008 w
.64936 .92423 Mdot
.016 w
.64936 .92423 m
.64914 .9245 L
s
.008 w
.64914 .9245 Mdot
.016 w
.64914 .9245 m
.64892 .92476 L
s
1 .561 0 r
.008 w
.64892 .92476 Mdot
.016 w
.64892 .92476 m
.64868 .92497 L
s
.008 w
.64868 .92497 Mdot
.016 w
.64868 .92497 m
.6485 .92509 L
s
1 .56 0 r
.008 w
.6485 .92509 Mdot
.016 w
.6485 .92509 m
.64844 .92507 L
s
.008 w
.64844 .92507 Mdot
.016 w
.64844 .92507 m
.64841 .92499 L
s
1 .559 0 r
.008 w
.64841 .92499 Mdot
.016 w
.64841 .92499 m
.64851 .92467 L
s
.008 w
.64851 .92467 Mdot
.016 w
.64851 .92467 m
.64871 .92417 L
s
1 .558 0 r
.008 w
.64871 .92417 Mdot
.016 w
.64871 .92417 m
.64897 .92355 L
s
.008 w
.64897 .92355 Mdot
.016 w
.64897 .92355 m
.64917 .92301 L
s
1 .557 0 r
.008 w
.64917 .92301 Mdot
.016 w
.64917 .92301 m
.64933 .92247 L
s
.008 w
.64933 .92247 Mdot
.016 w
.64933 .92247 m
.64943 .92193 L
s
1 .556 0 r
.008 w
.64943 .92193 Mdot
.016 w
.64943 .92193 m
.64956 .92133 L
s
.008 w
.64956 .92133 Mdot
.016 w
.64956 .92133 m
.64968 .92089 L
s
1 .555 0 r
.008 w
.64968 .92089 Mdot
.016 w
.64968 .92089 m
.64987 .92044 L
s
.008 w
.64987 .92044 Mdot
.016 w
.64987 .92044 m
.65008 .92006 L
s
1 .554 0 r
.008 w
.65008 .92006 Mdot
.016 w
.65008 .92006 m
.6503 .91984 L
s
.008 w
.6503 .91984 Mdot
.016 w
.6503 .91984 m
.65044 .91982 L
s
1 .553 0 r
.008 w
.65044 .91982 Mdot
.016 w
.65044 .91982 m
.65054 .91991 L
s
.008 w
.65054 .91991 Mdot
.016 w
.65054 .91991 m
.65058 .9201 L
s
1 .552 0 r
.008 w
.65058 .9201 Mdot
.016 w
.65058 .9201 m
.65052 .92033 L
s
.008 w
.65052 .92033 Mdot
.016 w
.65052 .92033 m
.65038 .92069 L
s
1 .551 0 r
.008 w
.65038 .92069 Mdot
.016 w
.65038 .92069 m
.65024 .92102 L
s
.008 w
.65024 .92102 Mdot
.016 w
.65024 .92102 m
.65016 .92126 L
s
1 .55 0 r
.008 w
.65016 .92126 Mdot
.016 w
.65016 .92126 m
.65022 .92144 L
s
.008 w
.65022 .92144 Mdot
.016 w
.65022 .92144 m
.6504 .92156 L
s
1 .549 0 r
.008 w
.6504 .92156 Mdot
.016 w
.6504 .92156 m
.65069 .92161 L
s
.008 w
.65069 .92161 Mdot
.016 w
.65069 .92161 m
.65112 .92148 L
s
1 .548 0 r
.008 w
.65112 .92148 Mdot
.016 w
.65112 .92148 m
.65159 .92134 L
s
.008 w
.65159 .92134 Mdot
.016 w
.65159 .92134 m
.65199 .9212 L
s
1 .547 0 r
.008 w
.65199 .9212 Mdot
.016 w
.65199 .9212 m
.6523 .92104 L
s
.008 w
.6523 .92104 Mdot
.016 w
.6523 .92104 m
.65252 .9208 L
s
1 .546 0 r
.008 w
.65252 .9208 Mdot
.016 w
.65252 .9208 m
.65263 .92069 L
s
.008 w
.65263 .92069 Mdot
.016 w
.65263 .92069 m
.65255 .92075 L
s
1 .545 0 r
.008 w
.65255 .92075 Mdot
.016 w
.65255 .92075 m
.65233 .92097 L
s
.008 w
.65233 .92097 Mdot
.016 w
.65233 .92097 m
.65194 .92128 L
s
1 .544 0 r
.008 w
.65194 .92128 Mdot
.016 w
.65194 .92128 m
.65141 .92175 L
s
.008 w
.65141 .92175 Mdot
.016 w
.65141 .92175 m
.65081 .92229 L
s
1 .543 0 r
.008 w
.65081 .92229 Mdot
.016 w
.65081 .92229 m
.65026 .92278 L
s
.008 w
.65026 .92278 Mdot
.016 w
.65026 .92278 m
.64982 .92307 L
s
1 .542 0 r
.008 w
.64982 .92307 Mdot
.016 w
.64982 .92307 m
.64951 .92322 L
s
.008 w
.64951 .92322 Mdot
.016 w
.64951 .92322 m
.64925 .92331 L
s
1 .541 0 r
.008 w
.64925 .92331 Mdot
.016 w
.64925 .92331 m
.64906 .92335 L
s
.008 w
.64906 .92335 Mdot
.016 w
.64906 .92335 m
.64906 .92329 L
s
1 .54 0 r
.008 w
.64906 .92329 Mdot
.016 w
.64906 .92329 m
.64919 .92321 L
s
.008 w
.64919 .92321 Mdot
.016 w
.64919 .92321 m
.64938 .92314 L
s
1 .539 0 r
.008 w
.64938 .92314 Mdot
.016 w
.64938 .92314 m
.6497 .92301 L
s
.008 w
.6497 .92301 Mdot
.016 w
.6497 .92301 m
.65006 .92285 L
s
1 .538 0 r
.008 w
.65006 .92285 Mdot
.016 w
.65006 .92285 m
.65039 .92272 L
s
.008 w
.65039 .92272 Mdot
.016 w
.65039 .92272 m
.65063 .92269 L
s
1 .537 0 r
.008 w
.65063 .92269 Mdot
.016 w
.65063 .92269 m
.65075 .92271 L
s
.008 w
.65075 .92271 Mdot
.016 w
.65075 .92271 m
.65072 .92285 L
s
1 .536 0 r
.008 w
.65072 .92285 Mdot
.016 w
.65072 .92285 m
.65059 .92308 L
s
.008 w
.65059 .92308 Mdot
.016 w
.65059 .92308 m
.65043 .92334 L
s
1 .535 0 r
.008 w
.65043 .92334 Mdot
.016 w
.65043 .92334 m
.65023 .92362 L
s
.008 w
.65023 .92362 Mdot
.016 w
.65023 .92362 m
.65007 .92385 L
s
1 .534 0 r
.008 w
.65007 .92385 Mdot
.016 w
.65007 .92385 m
.64996 .92396 L
s
.008 w
.64996 .92396 Mdot
.016 w
.64996 .92396 m
.64991 .92398 L
s
1 .533 0 r
.008 w
.64991 .92398 Mdot
.016 w
.64991 .92398 m
.65001 .92379 L
s
.008 w
.65001 .92379 Mdot
.016 w
.65001 .92379 m
.65024 .92349 L
s
1 .532 0 r
.008 w
.65024 .92349 Mdot
.016 w
.65024 .92349 m
.65055 .92311 L
s
.008 w
.65055 .92311 Mdot
.016 w
.65055 .92311 m
.65082 .92279 L
s
1 .531 0 r
.008 w
.65082 .92279 Mdot
.016 w
.65082 .92279 m
.65112 .92245 L
s
.008 w
.65112 .92245 Mdot
.016 w
.65112 .92245 m
.65142 .92215 L
s
1 .53 0 r
.008 w
.65142 .92215 Mdot
.016 w
.65142 .92215 m
.65177 .92187 L
s
.008 w
.65177 .92187 Mdot
.016 w
.65177 .92187 m
.65203 .92171 L
s
1 .529 0 r
.008 w
.65203 .92171 Mdot
.016 w
.65203 .92171 m
.65229 .92156 L
s
.008 w
.65229 .92156 Mdot
.016 w
.65229 .92156 m
.6525 .92148 L
s
1 .528 0 r
.008 w
.6525 .92148 Mdot
.016 w
.6525 .92148 m
.65268 .92147 L
s
.008 w
.65268 .92147 Mdot
.016 w
.65268 .92147 m
.65285 .92156 L
s
1 .527 0 r
.008 w
.65285 .92156 Mdot
.016 w
.65285 .92156 m
.65307 .92167 L
s
.008 w
.65307 .92167 Mdot
.016 w
.65307 .92167 m
.65336 .92175 L
s
1 .526 0 r
.008 w
.65336 .92175 Mdot
.016 w
.65336 .92175 m
.65367 .92182 L
s
.008 w
.65367 .92182 Mdot
.016 w
.65367 .92182 m
.65391 .92194 L
s
1 .525 0 r
.008 w
.65391 .92194 Mdot
.016 w
.65391 .92194 m
.65402 .92213 L
s
.008 w
.65402 .92213 Mdot
.016 w
.65402 .92213 m
.65402 .92233 L
s
1 .524 0 r
.008 w
.65402 .92233 Mdot
.016 w
.65402 .92233 m
.65391 .92258 L
s
.008 w
.65391 .92258 Mdot
.016 w
.65391 .92258 m
.65373 .92282 L
s
1 .523 0 r
.008 w
.65373 .92282 Mdot
.016 w
.65373 .92282 m
.65352 .92301 L
s
.008 w
.65352 .92301 Mdot
.016 w
.65352 .92301 m
.65336 .92309 L
s
1 .522 0 r
.008 w
.65336 .92309 Mdot
.016 w
.65336 .92309 m
.65324 .92309 L
s
.008 w
.65324 .92309 Mdot
.016 w
.65324 .92309 m
.65316 .92302 L
s
1 .521 0 r
.008 w
.65316 .92302 Mdot
.016 w
.65316 .92302 m
.65307 .92291 L
s
.008 w
.65307 .92291 Mdot
.016 w
.65307 .92291 m
.65301 .92272 L
s
1 .52 0 r
.008 w
.65301 .92272 Mdot
.016 w
.65301 .92272 m
.65298 .92253 L
s
.008 w
.65298 .92253 Mdot
.016 w
.65298 .92253 m
.65293 .92239 L
s
1 .519 0 r
.008 w
.65293 .92239 Mdot
.016 w
.65293 .92239 m
.6529 .92227 L
s
.008 w
.6529 .92227 Mdot
.016 w
.6529 .92227 m
.65293 .92213 L
s
1 .518 0 r
.008 w
.65293 .92213 Mdot
.016 w
.65293 .92213 m
.6531 .92196 L
s
.008 w
.6531 .92196 Mdot
.016 w
.6531 .92196 m
.65341 .92178 L
s
1 .517 0 r
.008 w
.65341 .92178 Mdot
.016 w
.65341 .92178 m
.65378 .92161 L
s
.008 w
.65378 .92161 Mdot
.016 w
.65378 .92161 m
.65422 .92144 L
s
1 .516 0 r
.008 w
.65422 .92144 Mdot
.016 w
.65422 .92144 m
.65462 .92133 L
s
.008 w
.65462 .92133 Mdot
.016 w
.65462 .92133 m
.6549 .92129 L
s
1 .515 0 r
.008 w
.6549 .92129 Mdot
.016 w
.6549 .92129 m
.65504 .92137 L
s
.008 w
.65504 .92137 Mdot
.016 w
.65504 .92137 m
.65505 .92152 L
s
1 .514 0 r
.008 w
.65505 .92152 Mdot
.016 w
.65505 .92152 m
.65498 .92174 L
s
.008 w
.65498 .92174 Mdot
.016 w
.65498 .92174 m
.65483 .92199 L
s
1 .513 0 r
.008 w
.65483 .92199 Mdot
.016 w
.65483 .92199 m
.65466 .92221 L
s
.008 w
.65466 .92221 Mdot
.016 w
.65466 .92221 m
.65449 .92239 L
s
1 .512 0 r
.008 w
.65449 .92239 Mdot
.016 w
.65449 .92239 m
.6543 .92237 L
s
.008 w
.6543 .92237 Mdot
.016 w
.6543 .92237 m
.65412 .92246 L
s
1 .511 0 r
.008 w
.65412 .92246 Mdot
.016 w
.65412 .92246 m
.65394 .92255 L
s
.008 w
.65394 .92255 Mdot
.016 w
.65394 .92255 m
.6538 .92258 L
s
1 .51 0 r
.008 w
.6538 .92258 Mdot
.016 w
.6538 .92258 m
.65376 .92252 L
s
.008 w
.65376 .92252 Mdot
.016 w
.65376 .92252 m
.65375 .92245 L
s
1 .509 0 r
.008 w
.65375 .92245 Mdot
.016 w
.65375 .92245 m
.65384 .92228 L
s
.008 w
.65384 .92228 Mdot
.016 w
.65384 .92228 m
.65399 .92206 L
s
1 .508 0 r
.008 w
.65399 .92206 Mdot
.016 w
.65399 .92206 m
.65418 .92179 L
s
.008 w
.65418 .92179 Mdot
.016 w
.65418 .92179 m
.65431 .9216 L
s
1 .507 0 r
.008 w
.65431 .9216 Mdot
.016 w
.65431 .9216 m
.65444 .92139 L
s
.008 w
.65444 .92139 Mdot
.016 w
.65444 .92139 m
.65455 .92122 L
s
1 .506 0 r
.008 w
.65455 .92122 Mdot
.016 w
.65455 .92122 m
.65461 .92111 L
s
.008 w
.65461 .92111 Mdot
.016 w
.65461 .92111 m
.65454 .92111 L
s
1 .505 0 r
.008 w
.65454 .92111 Mdot
.016 w
.65454 .92111 m
.65442 .92115 L
s
.008 w
.65442 .92115 Mdot
.016 w
.65442 .92115 m
.65426 .92121 L
s
1 .504 0 r
.008 w
.65426 .92121 Mdot
.016 w
.65426 .92121 m
.65404 .92134 L
s
.008 w
.65404 .92134 Mdot
.016 w
.65404 .92134 m
.65371 .92157 L
s
1 .503 0 r
.008 w
.65371 .92157 Mdot
.016 w
.65371 .92157 m
.65337 .92187 L
s
.008 w
.65337 .92187 Mdot
.016 w
.65337 .92187 m
.65309 .92218 L
s
1 .502 0 r
.008 w
.65309 .92218 Mdot
.016 w
.65309 .92218 m
.65287 .92251 L
s
.008 w
.65287 .92251 Mdot
.016 w
.65287 .92251 m
.65265 .92293 L
s
1 .501 0 r
.008 w
.65265 .92293 Mdot
.016 w
.65265 .92293 m
.65247 .92338 L
s
.008 w
.65247 .92338 Mdot
.016 w
.65247 .92338 m
.65236 .92378 L
s
1 .5 0 r
.008 w
.65236 .92378 Mdot
.016 w
.65236 .92378 m
.65227 .92421 L
s
1 .499 0 r
.008 w
.65227 .92421 Mdot
.016 w
.65227 .92421 m
.65222 .92466 L
s
.008 w
.65222 .92466 Mdot
.016 w
.65222 .92466 m
.65223 .92513 L
s
1 .498 0 r
.008 w
.65223 .92513 Mdot
.016 w
.65223 .92513 m
.65228 .92556 L
s
.008 w
.65228 .92556 Mdot
.016 w
.65228 .92556 m
.65231 .92595 L
s
1 .497 0 r
.008 w
.65231 .92595 Mdot
.016 w
.65231 .92595 m
.65232 .92628 L
s
.008 w
.65232 .92628 Mdot
.016 w
.65232 .92628 m
.65232 .9265 L
s
1 .496 0 r
.008 w
.65232 .9265 Mdot
.016 w
.65232 .9265 m
.65242 .92658 L
s
.008 w
.65242 .92658 Mdot
.016 w
.65242 .92658 m
.6526 .92653 L
s
1 .495 0 r
.008 w
.6526 .92653 Mdot
.016 w
.6526 .92653 m
.65289 .92638 L
s
.008 w
.65289 .92638 Mdot
.016 w
.65289 .92638 m
.65335 .92602 L
s
1 .494 0 r
.008 w
.65335 .92602 Mdot
.016 w
.65335 .92602 m
.65393 .92549 L
s
.008 w
.65393 .92549 Mdot
.016 w
.65393 .92549 m
.65455 .92491 L
s
1 .493 0 r
.008 w
.65455 .92491 Mdot
.016 w
.65455 .92491 m
.65512 .92437 L
s
.008 w
.65512 .92437 Mdot
.016 w
.65512 .92437 m
.65568 .92377 L
s
1 .492 0 r
.008 w
.65568 .92377 Mdot
.016 w
.65568 .92377 m
.65617 .92324 L
s
.008 w
.65617 .92324 Mdot
.016 w
.65617 .92324 m
.65657 .9228 L
s
1 .491 0 r
.008 w
.65657 .9228 Mdot
.016 w
.65657 .9228 m
.65691 .92246 L
s
.008 w
.65691 .92246 Mdot
.016 w
.65691 .92246 m
.6572 .9222 L
s
1 .49 0 r
.008 w
.6572 .9222 Mdot
.016 w
.6572 .9222 m
.6574 .92205 L
s
.008 w
.6574 .92205 Mdot
.016 w
.6574 .92205 m
.65753 .92203 L
s
1 .489 0 r
.008 w
.65753 .92203 Mdot
.016 w
.65753 .92203 m
.65761 .92209 L
s
.008 w
.65761 .92209 Mdot
.016 w
.65761 .92209 m
.65771 .92214 L
s
1 .488 0 r
.008 w
.65771 .92214 Mdot
.016 w
.65771 .92214 m
.65777 .92219 L
s
.008 w
.65777 .92219 Mdot
.016 w
.65777 .92219 m
.65779 .92223 L
s
1 .487 0 r
.008 w
.65779 .92223 Mdot
.016 w
.65779 .92223 m
.6578 .92225 L
s
.008 w
.6578 .92225 Mdot
.016 w
.6578 .92225 m
.65788 .92217 L
s
1 .486 0 r
.008 w
.65788 .92217 Mdot
.016 w
.65788 .92217 m
.65807 .92202 L
s
.008 w
.65807 .92202 Mdot
.016 w
.65807 .92202 m
.65841 .92184 L
s
1 .485 0 r
.008 w
.65841 .92184 Mdot
.016 w
.65841 .92184 m
.65886 .92165 L
s
.008 w
.65886 .92165 Mdot
.016 w
.65886 .92165 m
.65945 .92143 L
s
1 .484 0 r
.008 w
.65945 .92143 Mdot
.016 w
.65945 .92143 m
.66008 .92119 L
s
.008 w
.66008 .92119 Mdot
.016 w
.66008 .92119 m
.66076 .92093 L
s
1 .483 0 r
.008 w
.66076 .92093 Mdot
.016 w
.66076 .92093 m
.66141 .92067 L
s
.008 w
.66141 .92067 Mdot
.016 w
.66141 .92067 m
.66204 .9204 L
s
1 .482 0 r
.008 w
.66204 .9204 Mdot
.016 w
.66204 .9204 m
.66263 .92013 L
s
.008 w
.66263 .92013 Mdot
.016 w
.66263 .92013 m
.66318 .9199 L
s
1 .481 0 r
.008 w
.66318 .9199 Mdot
.016 w
.66318 .9199 m
.66366 .91976 L
s
.008 w
.66366 .91976 Mdot
.016 w
.66366 .91976 m
.664 .91973 L
s
1 .48 0 r
.008 w
.664 .91973 Mdot
.016 w
.664 .91973 m
.66412 .91982 L
s
.008 w
.66412 .91982 Mdot
.016 w
.66412 .91982 m
.66403 .92002 L
s
1 .479 0 r
.008 w
.66403 .92002 Mdot
.016 w
.66403 .92002 m
.66378 .92029 L
s
.008 w
.66378 .92029 Mdot
.016 w
.66378 .92029 m
.66345 .92057 L
s
1 .478 0 r
.008 w
.66345 .92057 Mdot
.016 w
.66345 .92057 m
.66308 .9208 L
s
.008 w
.66308 .9208 Mdot
.016 w
.66308 .9208 m
.66279 .92091 L
s
1 .477 0 r
.008 w
.66279 .92091 Mdot
.016 w
.66279 .92091 m
.66245 .92098 L
s
.008 w
.66245 .92098 Mdot
.016 w
.66245 .92098 m
.66202 .92112 L
s
1 .476 0 r
.008 w
.66202 .92112 Mdot
.016 w
.66202 .92112 m
.6615 .92138 L
s
.008 w
.6615 .92138 Mdot
.016 w
.6615 .92138 m
.66091 .92176 L
s
1 .475 0 r
.008 w
.66091 .92176 Mdot
.016 w
.66091 .92176 m
.66025 .92223 L
s
.008 w
.66025 .92223 Mdot
.016 w
.66025 .92223 m
.65946 .92296 L
s
1 .474 0 r
.008 w
.65946 .92296 Mdot
.016 w
.65946 .92296 m
.65862 .92355 L
s
.008 w
.65862 .92355 Mdot
.016 w
.65862 .92355 m
.65785 .92408 L
s
1 .473 0 r
.008 w
.65785 .92408 Mdot
.016 w
.65785 .92408 m
.65732 .92446 L
s
.008 w
.65732 .92446 Mdot
.016 w
.65732 .92446 m
.657 .92468 L
s
1 .472 0 r
.008 w
.657 .92468 Mdot
.016 w
.657 .92468 m
.65683 .92476 L
s
.008 w
.65683 .92476 Mdot
.016 w
.65683 .92476 m
.65675 .92475 L
s
1 .471 0 r
.008 w
.65675 .92475 Mdot
.016 w
.65675 .92475 m
.65665 .9247 L
s
.008 w
.65665 .9247 Mdot
.016 w
.65665 .9247 m
.65638 .92475 L
s
1 .47 0 r
.008 w
.65638 .92475 Mdot
.016 w
.65638 .92475 m
.65623 .92469 L
s
.008 w
.65623 .92469 Mdot
.016 w
.65623 .92469 m
.65614 .92457 L
s
1 .469 0 r
.008 w
.65614 .92457 Mdot
.016 w
.65614 .92457 m
.65624 .92431 L
s
.008 w
.65624 .92431 Mdot
.016 w
.65624 .92431 m
.65666 .92387 L
s
1 .468 0 r
.008 w
.65666 .92387 Mdot
.016 w
.65666 .92387 m
.6573 .92335 L
s
.008 w
.6573 .92335 Mdot
.016 w
.6573 .92335 m
.65807 .9228 L
s
1 .467 0 r
.008 w
.65807 .9228 Mdot
.016 w
.65807 .9228 m
.65882 .92228 L
s
.008 w
.65882 .92228 Mdot
.016 w
.65882 .92228 m
.65949 .92184 L
s
1 .466 0 r
.008 w
.65949 .92184 Mdot
.016 w
.65949 .92184 m
.65987 .92157 L
s
.008 w
.65987 .92157 Mdot
.016 w
.65987 .92157 m
.65988 .92153 L
s
1 .465 0 r
.008 w
.65988 .92153 Mdot
.016 w
.65988 .92153 m
.65962 .92161 L
s
.008 w
.65962 .92161 Mdot
.016 w
.65962 .92161 m
.6591 .9217 L
s
1 .464 0 r
.008 w
.6591 .9217 Mdot
.016 w
.6591 .9217 m
.65845 .92181 L
s
.008 w
.65845 .92181 Mdot
.016 w
.65845 .92181 m
.65767 .92191 L
s
1 .463 0 r
.008 w
.65767 .92191 Mdot
.016 w
.65767 .92191 m
.65695 .92197 L
s
.008 w
.65695 .92197 Mdot
.016 w
.65695 .92197 m
.65635 .92193 L
s
1 .462 0 r
.008 w
.65635 .92193 Mdot
.016 w
.65635 .92193 m
.65594 .92178 L
s
.008 w
.65594 .92178 Mdot
.016 w
.65594 .92178 m
.65567 .92157 L
s
1 .461 0 r
.008 w
.65567 .92157 Mdot
.016 w
.65567 .92157 m
.65542 .92139 L
s
.008 w
.65542 .92139 Mdot
.016 w
.65542 .92139 m
.65516 .9213 L
s
1 .46 0 r
.008 w
.65516 .9213 Mdot
.016 w
.65516 .9213 m
.65494 .92133 L
s
.008 w
.65494 .92133 Mdot
.016 w
.65494 .92133 m
.65481 .92146 L
s
1 .459 0 r
.008 w
.65481 .92146 Mdot
.016 w
.65481 .92146 m
.65481 .92169 L
s
.008 w
.65481 .92169 Mdot
.016 w
.65481 .92169 m
.65495 .92194 L
s
1 .458 0 r
.008 w
.65495 .92194 Mdot
.016 w
.65495 .92194 m
.65521 .92217 L
s
.008 w
.65521 .92217 Mdot
.016 w
.65521 .92217 m
.6555 .92238 L
s
1 .457 0 r
.008 w
.6555 .92238 Mdot
.016 w
.6555 .92238 m
.65571 .92257 L
s
.008 w
.65571 .92257 Mdot
.016 w
.65571 .92257 m
.65577 .92276 L
s
1 .456 0 r
.008 w
.65577 .92276 Mdot
.016 w
.65577 .92276 m
.65562 .92299 L
s
.008 w
.65562 .92299 Mdot
.016 w
.65562 .92299 m
.65536 .92323 L
s
1 .455 0 r
.008 w
.65536 .92323 Mdot
.016 w
.65536 .92323 m
.65503 .92349 L
s
.008 w
.65503 .92349 Mdot
.016 w
.65503 .92349 m
.65471 .9237 L
s
1 .454 0 r
.008 w
.65471 .9237 Mdot
.016 w
.65471 .9237 m
.65445 .92378 L
s
.008 w
.65445 .92378 Mdot
.016 w
.65445 .92378 m
.65435 .92374 L
s
1 .453 0 r
.008 w
.65435 .92374 Mdot
.016 w
.65435 .92374 m
.65433 .92364 L
s
.008 w
.65433 .92364 Mdot
.016 w
.65433 .92364 m
.65438 .92352 L
s
1 .452 0 r
.008 w
.65438 .92352 Mdot
.016 w
.65438 .92352 m
.6545 .92338 L
s
.008 w
.6545 .92338 Mdot
.016 w
.6545 .92338 m
.65461 .92329 L
s
1 .451 0 r
.008 w
.65461 .92329 Mdot
.016 w
.65461 .92329 m
.65471 .92325 L
s
.008 w
.65471 .92325 Mdot
.016 w
.65471 .92325 m
.65477 .92321 L
s
1 .45 0 r
.008 w
.65477 .92321 Mdot
.016 w
.65477 .92321 m
.65481 .92319 L
s
.008 w
.65481 .92319 Mdot
.016 w
.65481 .92319 m
.65491 .92318 L
s
1 .449 0 r
.008 w
.65491 .92318 Mdot
.016 w
.65491 .92318 m
.65514 .92316 L
s
.008 w
.65514 .92316 Mdot
.016 w
.65514 .92316 m
.65547 .92311 L
s
1 .448 0 r
.008 w
.65547 .92311 Mdot
.016 w
.65547 .92311 m
.65594 .92302 L
s
.008 w
.65594 .92302 Mdot
.016 w
.65594 .92302 m
.65639 .92297 L
s
1 .447 0 r
.008 w
.65639 .92297 Mdot
.016 w
.65639 .92297 m
.65673 .92301 L
s
.008 w
.65673 .92301 Mdot
.016 w
.65673 .92301 m
.65697 .9231 L
s
1 .446 0 r
.008 w
.65697 .9231 Mdot
.016 w
.65697 .9231 m
.65711 .92327 L
s
.008 w
.65711 .92327 Mdot
.016 w
.65711 .92327 m
.65718 .92348 L
s
1 .445 0 r
.008 w
.65718 .92348 Mdot
.016 w
.65718 .92348 m
.65726 .92362 L
s
.008 w
.65726 .92362 Mdot
.016 w
.65726 .92362 m
.65739 .92362 L
s
1 .444 0 r
.008 w
.65739 .92362 Mdot
.016 w
.65739 .92362 m
.65756 .9235 L
s
.008 w
.65756 .9235 Mdot
.016 w
.65756 .9235 m
.65768 .92333 L
s
1 .443 0 r
.008 w
.65768 .92333 Mdot
.016 w
.65768 .92333 m
.65766 .92314 L
s
.008 w
.65766 .92314 Mdot
.016 w
.65766 .92314 m
.65741 .92301 L
s
1 .442 0 r
.008 w
.65741 .92301 Mdot
.016 w
.65741 .92301 m
.65695 .92289 L
s
.008 w
.65695 .92289 Mdot
.016 w
.65695 .92289 m
.65635 .92274 L
s
1 .441 0 r
.008 w
.65635 .92274 Mdot
.016 w
.65635 .92274 m
.65577 .92259 L
s
.008 w
.65577 .92259 Mdot
.016 w
.65577 .92259 m
.65534 .92231 L
s
1 .44 0 r
.008 w
.65534 .92231 Mdot
.016 w
.65534 .92231 m
.65524 .92171 L
s
.008 w
.65524 .92171 Mdot
.016 w
.65524 .92171 m
.65519 .9214 L
s
1 .439 0 r
.008 w
.65519 .9214 Mdot
.016 w
.65519 .9214 m
.65533 .92116 L
s
.008 w
.65533 .92116 Mdot
.016 w
.65533 .92116 m
.65561 .92099 L
s
1 .438 0 r
.008 w
.65561 .92099 Mdot
.016 w
.65561 .92099 m
.65603 .92091 L
s
.008 w
.65603 .92091 Mdot
.016 w
.65603 .92091 m
.65642 .92093 L
s
1 .437 0 r
.008 w
.65642 .92093 Mdot
.016 w
.65642 .92093 m
.65679 .92102 L
s
.008 w
.65679 .92102 Mdot
.016 w
.65679 .92102 m
.65708 .92113 L
s
1 .436 0 r
.008 w
.65708 .92113 Mdot
.016 w
.65708 .92113 m
.65729 .92125 L
s
.008 w
.65729 .92125 Mdot
.016 w
.65729 .92125 m
.65742 .92139 L
s
1 .435 0 r
.008 w
.65742 .92139 Mdot
.016 w
.65742 .92139 m
.65742 .92159 L
s
.008 w
.65742 .92159 Mdot
.016 w
.65742 .92159 m
.65731 .92187 L
s
1 .434 0 r
.008 w
.65731 .92187 Mdot
.016 w
.65731 .92187 m
.65704 .9222 L
s
.008 w
.65704 .9222 Mdot
.016 w
.65704 .9222 m
.65661 .92261 L
s
1 .433 0 r
.008 w
.65661 .92261 Mdot
.016 w
.65661 .92261 m
.656 .92307 L
s
.008 w
.656 .92307 Mdot
.016 w
.656 .92307 m
.65526 .92355 L
s
1 .432 0 r
.008 w
.65526 .92355 Mdot
.016 w
.65526 .92355 m
.65436 .92401 L
s
.008 w
.65436 .92401 Mdot
.016 w
.65436 .92401 m
.65357 .92431 L
s
1 .431 0 r
.008 w
.65357 .92431 Mdot
.016 w
.65357 .92431 m
.65279 .92458 L
s
.008 w
.65279 .92458 Mdot
.016 w
.65279 .92458 m
.65206 .92479 L
s
1 .43 0 r
.008 w
.65206 .92479 Mdot
.016 w
.65206 .92479 m
.65149 .92495 L
s
.008 w
.65149 .92495 Mdot
.016 w
.65149 .92495 m
.65107 .92507 L
s
1 .429 0 r
.008 w
.65107 .92507 Mdot
.016 w
.65107 .92507 m
.65081 .92516 L
s
.008 w
.65081 .92516 Mdot
.016 w
.65081 .92516 m
.65075 .92512 L
s
1 .428 0 r
.008 w
.65075 .92512 Mdot
.016 w
.65075 .92512 m
.65083 .92498 L
s
.008 w
.65083 .92498 Mdot
.016 w
.65083 .92498 m
.65111 .92474 L
s
1 .427 0 r
.008 w
.65111 .92474 Mdot
.016 w
.65111 .92474 m
.65156 .9244 L
s
.008 w
.65156 .9244 Mdot
.016 w
.65156 .9244 m
.65215 .92396 L
s
1 .426 0 r
.008 w
.65215 .92396 Mdot
.016 w
.65215 .92396 m
.65287 .92341 L
s
.008 w
.65287 .92341 Mdot
.016 w
.65287 .92341 m
.65363 .92291 L
s
1 .425 0 r
.008 w
.65363 .92291 Mdot
.016 w
.65363 .92291 m
.65437 .92253 L
s
.008 w
.65437 .92253 Mdot
.016 w
.65437 .92253 m
.65514 .92217 L
s
1 .424 0 r
.008 w
.65514 .92217 Mdot
.016 w
.65514 .92217 m
.65591 .92191 L
s
.008 w
.65591 .92191 Mdot
.016 w
.65591 .92191 m
.65661 .92177 L
s
1 .423 0 r
.008 w
.65661 .92177 Mdot
.016 w
.65661 .92177 m
.65727 .92169 L
s
.008 w
.65727 .92169 Mdot
.016 w
.65727 .92169 m
.65787 .92158 L
s
1 .422 0 r
.008 w
.65787 .92158 Mdot
.016 w
.65787 .92158 m
.6584 .9215 L
s
.008 w
.6584 .9215 Mdot
.016 w
.6584 .9215 m
.65878 .92146 L
s
1 .421 0 r
.008 w
.65878 .92146 Mdot
.016 w
.65878 .92146 m
.65899 .92148 L
s
.008 w
.65899 .92148 Mdot
.016 w
.65899 .92148 m
.65901 .92156 L
s
1 .42 0 r
.008 w
.65901 .92156 Mdot
.016 w
.65901 .92156 m
.65886 .92173 L
s
.008 w
.65886 .92173 Mdot
.016 w
.65886 .92173 m
.65859 .92196 L
s
1 .419 0 r
.008 w
.65859 .92196 Mdot
.016 w
.65859 .92196 m
.65831 .92215 L
s
.008 w
.65831 .92215 Mdot
.016 w
.65831 .92215 m
.65812 .92224 L
s
1 .418 0 r
.008 w
.65812 .92224 Mdot
.016 w
.65812 .92224 m
.65815 .9222 L
s
.008 w
.65815 .9222 Mdot
.016 w
.65815 .9222 m
.65842 .92203 L
s
1 .417 0 r
.008 w
.65842 .92203 Mdot
.016 w
.65842 .92203 m
.65882 .92182 L
s
.008 w
.65882 .92182 Mdot
.016 w
.65882 .92182 m
.65937 .92155 L
s
1 .416 0 r
.008 w
.65937 .92155 Mdot
.016 w
.65937 .92155 m
.66003 .92125 L
s
.008 w
.66003 .92125 Mdot
.016 w
.66003 .92125 m
.6609 .9209 L
s
1 .415 0 r
.008 w
.6609 .9209 Mdot
.016 w
.6609 .9209 m
.66168 .9206 L
s
.008 w
.66168 .9206 Mdot
.016 w
.66168 .9206 m
.66262 .92027 L
s
1 .414 0 r
.008 w
.66262 .92027 Mdot
.016 w
.66262 .92027 m
.66354 .91995 L
s
.008 w
.66354 .91995 Mdot
.016 w
.66354 .91995 m
.66439 .91969 L
s
1 .413 0 r
.008 w
.66439 .91969 Mdot
.016 w
.66439 .91969 m
.6651 .91946 L
s
.008 w
.6651 .91946 Mdot
.016 w
.6651 .91946 m
.66567 .91927 L
s
1 .412 0 r
.008 w
.66567 .91927 Mdot
.016 w
.66567 .91927 m
.66609 .91909 L
s
.008 w
.66609 .91909 Mdot
.016 w
.66609 .91909 m
.66629 .919 L
s
1 .411 0 r
.008 w
.66629 .919 Mdot
.016 w
.66629 .919 m
.6662 .91905 L
s
.008 w
.6662 .91905 Mdot
.016 w
.6662 .91905 m
.66587 .91921 L
s
1 .41 0 r
.008 w
.66587 .91921 Mdot
.016 w
.66587 .91921 m
.66534 .91945 L
s
.008 w
.66534 .91945 Mdot
.016 w
.66534 .91945 m
.66472 .91974 L
s
1 .409 0 r
.008 w
.66472 .91974 Mdot
.016 w
.66472 .91974 m
.66399 .92006 L
s
.008 w
.66399 .92006 Mdot
.016 w
.66399 .92006 m
.66325 .92038 L
s
1 .408 0 r
.008 w
.66325 .92038 Mdot
.016 w
.66325 .92038 m
.66263 .92066 L
s
.008 w
.66263 .92066 Mdot
.016 w
.66263 .92066 m
.66224 .92085 L
s
1 .407 0 r
.008 w
.66224 .92085 Mdot
.016 w
.66224 .92085 m
.66208 .92099 L
s
.008 w
.66208 .92099 Mdot
.016 w
.66208 .92099 m
.66217 .92107 L
s
1 .406 0 r
.008 w
.66217 .92107 Mdot
.016 w
.66217 .92107 m
.66252 .92107 L
s
.008 w
.66252 .92107 Mdot
.016 w
.66252 .92107 m
.66303 .92106 L
s
1 .405 0 r
.008 w
.66303 .92106 Mdot
.016 w
.66303 .92106 m
.66365 .92104 L
s
.008 w
.66365 .92104 Mdot
.016 w
.66365 .92104 m
.66455 .92092 L
s
1 .404 0 r
.008 w
.66455 .92092 Mdot
.016 w
.66455 .92092 m
.66586 .92044 L
s
.008 w
.66586 .92044 Mdot
.016 w
.66586 .92044 m
.66717 .92018 L
s
1 .403 0 r
.008 w
.66717 .92018 Mdot
.016 w
.66717 .92018 m
.66864 .91981 L
s
.008 w
.66864 .91981 Mdot
.016 w
.66864 .91981 m
.67024 .91933 L
s
1 .402 0 r
.008 w
.67024 .91933 Mdot
.016 w
.67024 .91933 m
.67195 .91873 L
s
.008 w
.67195 .91873 Mdot
.016 w
.67195 .91873 m
.67371 .91804 L
s
1 .401 0 r
.008 w
.67371 .91804 Mdot
.016 w
.67371 .91804 m
.67554 .91727 L
s
.008 w
.67554 .91727 Mdot
.016 w
.67554 .91727 m
.67739 .91642 L
s
1 .4 0 r
.008 w
.67739 .91642 Mdot
.016 w
.67739 .91642 m
.6792 .9155 L
s
.008 w
.6792 .9155 Mdot
.016 w
.6792 .9155 m
.68087 .91451 L
s
1 .399 0 r
.008 w
.68087 .91451 Mdot
.016 w
.68087 .91451 m
.68249 .91343 L
s
.008 w
.68249 .91343 Mdot
.016 w
.68249 .91343 m
.68402 .91234 L
s
1 .398 0 r
.008 w
.68402 .91234 Mdot
.016 w
.68402 .91234 m
.68543 .91118 L
s
.008 w
.68543 .91118 Mdot
.016 w
.68543 .91118 m
.68665 .91008 L
s
1 .397 0 r
.008 w
.68665 .91008 Mdot
.016 w
.68665 .91008 m
.68765 .90913 L
s
.008 w
.68765 .90913 Mdot
.016 w
.68765 .90913 m
.68842 .9083 L
s
1 .396 0 r
.008 w
.68842 .9083 Mdot
.016 w
.68842 .9083 m
.68896 .90763 L
s
.008 w
.68896 .90763 Mdot
.016 w
.68896 .90763 m
.68924 .90716 L
s
1 .395 0 r
.008 w
.68924 .90716 Mdot
.016 w
.68924 .90716 m
.68928 .90691 L
s
.008 w
.68928 .90691 Mdot
.016 w
.68928 .90691 m
.68908 .90688 L
s
1 .394 0 r
.008 w
.68908 .90688 Mdot
.016 w
.68908 .90688 m
.68867 .90703 L
s
.008 w
.68867 .90703 Mdot
.016 w
.68867 .90703 m
.68809 .90733 L
s
1 .393 0 r
.008 w
.68809 .90733 Mdot
.016 w
.68809 .90733 m
.68746 .90773 L
s
.008 w
.68746 .90773 Mdot
.016 w
.68746 .90773 m
.68677 .90827 L
s
1 .392 0 r
.008 w
.68677 .90827 Mdot
.016 w
.68677 .90827 m
.68608 .90893 L
s
.008 w
.68608 .90893 Mdot
.016 w
.68608 .90893 m
.68552 .9095 L
s
1 .391 0 r
.008 w
.68552 .9095 Mdot
.016 w
.68552 .9095 m
.68505 .91008 L
s
.008 w
.68505 .91008 Mdot
.016 w
.68505 .91008 m
.68476 .91047 L
s
1 .39 0 r
.008 w
.68476 .91047 Mdot
.016 w
.68476 .91047 m
.6847 .91062 L
s
.008 w
.6847 .91062 Mdot
.016 w
.6847 .91062 m
.68486 .91054 L
s
1 .389 0 r
.008 w
.68486 .91054 Mdot
.016 w
.68486 .91054 m
.68515 .91028 L
s
.008 w
.68515 .91028 Mdot
.016 w
.68515 .91028 m
.68544 .90993 L
s
1 .388 0 r
.008 w
.68544 .90993 Mdot
.016 w
.68544 .90993 m
.68574 .90956 L
s
.008 w
.68574 .90956 Mdot
.016 w
.68574 .90956 m
.68602 .9092 L
s
1 .387 0 r
.008 w
.68602 .9092 Mdot
.016 w
.68602 .9092 m
.68628 .90887 L
s
.008 w
.68628 .90887 Mdot
.016 w
.68628 .90887 m
.68651 .90859 L
s
1 .386 0 r
.008 w
.68651 .90859 Mdot
.016 w
.68651 .90859 m
.6867 .9083 L
s
.008 w
.6867 .9083 Mdot
.016 w
.6867 .9083 m
.68687 .90806 L
s
1 .385 0 r
.008 w
.68687 .90806 Mdot
.016 w
.68687 .90806 m
.687 .9079 L
s
.008 w
.687 .9079 Mdot
.016 w
.687 .9079 m
.68712 .90784 L
s
1 .384 0 r
.008 w
.68712 .90784 Mdot
.016 w
.68712 .90784 m
.68721 .90787 L
s
.008 w
.68721 .90787 Mdot
.016 w
.68721 .90787 m
.68721 .90803 L
s
1 .383 0 r
.008 w
.68721 .90803 Mdot
.016 w
.68721 .90803 m
.68712 .90832 L
s
.008 w
.68712 .90832 Mdot
.016 w
.68712 .90832 m
.687 .9087 L
s
1 .382 0 r
.008 w
.687 .9087 Mdot
.016 w
.687 .9087 m
.68695 .90911 L
s
.008 w
.68695 .90911 Mdot
.016 w
.68695 .90911 m
.68701 .90947 L
s
1 .381 0 r
.008 w
.68701 .90947 Mdot
.016 w
.68701 .90947 m
.6872 .90971 L
s
.008 w
.6872 .90971 Mdot
.016 w
.6872 .90971 m
.68749 .90986 L
s
1 .38 0 r
.008 w
.68749 .90986 Mdot
.016 w
.68749 .90986 m
.6878 .90988 L
s
.008 w
.6878 .90988 Mdot
.016 w
.6878 .90988 m
.6881 .90989 L
s
1 .379 0 r
.008 w
.6881 .90989 Mdot
.016 w
.6881 .90989 m
.68836 .90996 L
s
.008 w
.68836 .90996 Mdot
.016 w
.68836 .90996 m
.68851 .91013 L
s
1 .378 0 r
.008 w
.68851 .91013 Mdot
.016 w
.68851 .91013 m
.68863 .91034 L
s
.008 w
.68863 .91034 Mdot
.016 w
.68863 .91034 m
.68876 .91053 L
s
1 .377 0 r
.008 w
.68876 .91053 Mdot
.016 w
.68876 .91053 m
.68899 .91066 L
s
.008 w
.68899 .91066 Mdot
.016 w
.68899 .91066 m
.68942 .91064 L
s
1 .376 0 r
.008 w
.68942 .91064 Mdot
.016 w
.68942 .91064 m
.69007 .91044 L
s
.008 w
.69007 .91044 Mdot
.016 w
.69007 .91044 m
.69097 .91007 L
s
1 .375 0 r
.008 w
.69097 .91007 Mdot
.016 w
.69097 .91007 m
.69183 .90966 L
s
.008 w
.69183 .90966 Mdot
.016 w
.69183 .90966 m
.69285 .90917 L
s
1 .374 0 r
.008 w
.69285 .90917 Mdot
.016 w
.69285 .90917 m
.69387 .90861 L
s
.008 w
.69387 .90861 Mdot
.016 w
.69387 .90861 m
.69478 .90802 L
s
1 .373 0 r
.008 w
.69478 .90802 Mdot
.016 w
.69478 .90802 m
.69576 .90745 L
s
.008 w
.69576 .90745 Mdot
.016 w
.69576 .90745 m
.69663 .90686 L
s
1 .372 0 r
.008 w
.69663 .90686 Mdot
.016 w
.69663 .90686 m
.69739 .90627 L
s
.008 w
.69739 .90627 Mdot
.016 w
.69739 .90627 m
.69799 .90571 L
s
1 .371 0 r
.008 w
.69799 .90571 Mdot
.016 w
.69799 .90571 m
.69838 .90526 L
s
.008 w
.69838 .90526 Mdot
.016 w
.69838 .90526 m
.69854 .90492 L
s
1 .37 0 r
.008 w
.69854 .90492 Mdot
.016 w
.69854 .90492 m
.69842 .90472 L
s
.008 w
.69842 .90472 Mdot
.016 w
.69842 .90472 m
.69801 .9047 L
s
1 .369 0 r
.008 w
.69801 .9047 Mdot
.016 w
.69801 .9047 m
.69731 .90488 L
s
.008 w
.69731 .90488 Mdot
.016 w
.69731 .90488 m
.69645 .90517 L
s
1 .368 0 r
.008 w
.69645 .90517 Mdot
.016 w
.69645 .90517 m
.69561 .90549 L
s
.008 w
.69561 .90549 Mdot
.016 w
.69561 .90549 m
.6948 .90578 L
s
1 .367 0 r
.008 w
.6948 .90578 Mdot
.016 w
.6948 .90578 m
.69429 .90591 L
s
.008 w
.69429 .90591 Mdot
.016 w
.69429 .90591 m
.69364 .90616 L
s
1 .366 0 r
.008 w
.69364 .90616 Mdot
.016 w
.69364 .90616 m
.69302 .90638 L
s
.008 w
.69302 .90638 Mdot
.016 w
.69302 .90638 m
.69245 .90665 L
s
1 .365 0 r
.008 w
.69245 .90665 Mdot
.016 w
.69245 .90665 m
.6919 .90698 L
s
.008 w
.6919 .90698 Mdot
.016 w
.6919 .90698 m
.6914 .90741 L
s
1 .364 0 r
.008 w
.6914 .90741 Mdot
.016 w
.6914 .90741 m
.6909 .90792 L
s
.008 w
.6909 .90792 Mdot
.016 w
.6909 .90792 m
.69039 .90847 L
s
1 .363 0 r
.008 w
.69039 .90847 Mdot
.016 w
.69039 .90847 m
.68988 .90898 L
s
.008 w
.68988 .90898 Mdot
.016 w
.68988 .90898 m
.6894 .90941 L
s
1 .362 0 r
.008 w
.6894 .90941 Mdot
.016 w
.6894 .90941 m
.68891 .9098 L
s
.008 w
.68891 .9098 Mdot
.016 w
.68891 .9098 m
.68852 .91004 L
s
1 .361 0 r
.008 w
.68852 .91004 Mdot
.016 w
.68852 .91004 m
.68812 .91026 L
s
.008 w
.68812 .91026 Mdot
.016 w
.68812 .91026 m
.68778 .91038 L
s
1 .36 0 r
.008 w
.68778 .91038 Mdot
.016 w
.68778 .91038 m
.6875 .91043 L
s
.008 w
.6875 .91043 Mdot
.016 w
.6875 .91043 m
.68731 .91046 L
s
1 .359 0 r
.008 w
.68731 .91046 Mdot
.016 w
.68731 .91046 m
.68723 .91047 L
s
.008 w
.68723 .91047 Mdot
.016 w
.68723 .91047 m
.68716 .91047 L
s
1 .358 0 r
.008 w
.68716 .91047 Mdot
.016 w
.68716 .91047 m
.68712 .91045 L
s
.008 w
.68712 .91045 Mdot
.016 w
.68712 .91045 m
.6871 .91043 L
s
1 .357 0 r
.008 w
.6871 .91043 Mdot
.016 w
.6871 .91043 m
.68705 .91043 L
s
.008 w
.68705 .91043 Mdot
.016 w
.68705 .91043 m
.68698 .91043 L
s
1 .356 0 r
.008 w
.68698 .91043 Mdot
.016 w
.68698 .91043 m
.68682 .91054 L
s
.008 w
.68682 .91054 Mdot
.016 w
.68682 .91054 m
.68657 .91081 L
s
1 .355 0 r
.008 w
.68657 .91081 Mdot
.016 w
.68657 .91081 m
.68625 .91117 L
s
.008 w
.68625 .91117 Mdot
.016 w
.68625 .91117 m
.68589 .91155 L
s
1 .354 0 r
.008 w
.68589 .91155 Mdot
.016 w
.68589 .91155 m
.68548 .9119 L
s
.008 w
.68548 .9119 Mdot
.016 w
.68548 .9119 m
.68501 .9122 L
s
1 .353 0 r
.008 w
.68501 .9122 Mdot
.016 w
.68501 .9122 m
.68446 .91243 L
s
.008 w
.68446 .91243 Mdot
.016 w
.68446 .91243 m
.68386 .91257 L
s
1 .352 0 r
.008 w
.68386 .91257 Mdot
.016 w
.68386 .91257 m
.68322 .91262 L
s
.008 w
.68322 .91262 Mdot
.016 w
.68322 .91262 m
.68258 .9126 L
s
1 .351 0 r
.008 w
.68258 .9126 Mdot
.016 w
.68258 .9126 m
.68202 .9126 L
s
.008 w
.68202 .9126 Mdot
.016 w
.68202 .9126 m
.68143 .91264 L
s
1 .35 0 r
.008 w
.68143 .91264 Mdot
.016 w
.68143 .91264 m
.6809 .91275 L
s
.008 w
.6809 .91275 Mdot
.016 w
.6809 .91275 m
.68045 .91294 L
s
1 .349 0 r
.008 w
.68045 .91294 Mdot
.016 w
.68045 .91294 m
.68006 .9132 L
s
.008 w
.68006 .9132 Mdot
.016 w
.68006 .9132 m
.6797 .91352 L
s
1 .348 0 r
.008 w
.6797 .91352 Mdot
.016 w
.6797 .91352 m
.67938 .9139 L
s
.008 w
.67938 .9139 Mdot
.016 w
.67938 .9139 m
.67913 .91432 L
s
1 .347 0 r
.008 w
.67913 .91432 Mdot
.016 w
.67913 .91432 m
.67894 .91476 L
s
.008 w
.67894 .91476 Mdot
.016 w
.67894 .91476 m
.67878 .91521 L
s
1 .346 0 r
.008 w
.67878 .91521 Mdot
.016 w
.67878 .91521 m
.67862 .91565 L
s
.008 w
.67862 .91565 Mdot
.016 w
.67862 .91565 m
.67843 .9161 L
s
1 .345 0 r
.008 w
.67843 .9161 Mdot
.016 w
.67843 .9161 m
.6782 .91652 L
s
.008 w
.6782 .91652 Mdot
.016 w
.6782 .91652 m
.67793 .91689 L
s
1 .344 0 r
.008 w
.67793 .91689 Mdot
.016 w
.67793 .91689 m
.67762 .9172 L
s
.008 w
.67762 .9172 Mdot
.016 w
.67762 .9172 m
.67733 .91745 L
s
1 .343 0 r
.008 w
.67733 .91745 Mdot
.016 w
.67733 .91745 m
.67707 .91762 L
s
.008 w
.67707 .91762 Mdot
.016 w
.67707 .91762 m
.67686 .91772 L
s
1 .342 0 r
.008 w
.67686 .91772 Mdot
.016 w
.67686 .91772 m
.67668 .91776 L
s
.008 w
.67668 .91776 Mdot
.016 w
.67668 .91776 m
.67659 .91775 L
s
1 .341 0 r
.008 w
.67659 .91775 Mdot
.016 w
.67659 .91775 m
.67654 .91771 L
s
.008 w
.67654 .91771 Mdot
.016 w
.67654 .91771 m
.67652 .91765 L
s
1 .34 0 r
.008 w
.67652 .91765 Mdot
.016 w
.67652 .91765 m
.67654 .9176 L
s
.008 w
.67654 .9176 Mdot
.016 w
.67654 .9176 m
.67658 .91759 L
s
1 .339 0 r
.008 w
.67658 .91759 Mdot
.016 w
.67658 .91759 m
.67662 .91763 L
s
.008 w
.67662 .91763 Mdot
.016 w
.67662 .91763 m
.67665 .91769 L
s
1 .338 0 r
.008 w
.67665 .91769 Mdot
.016 w
.67665 .91769 m
.67667 .91776 L
s
.008 w
.67667 .91776 Mdot
.016 w
.67667 .91776 m
.67667 .91778 L
s
1 .337 0 r
.008 w
.67667 .91778 Mdot
.016 w
.67667 .91778 m
.67669 .91772 L
s
.008 w
.67669 .91772 Mdot
.016 w
.67669 .91772 m
.67669 .91758 L
s
1 .336 0 r
.008 w
.67669 .91758 Mdot
.016 w
.67669 .91758 m
.67667 .91737 L
s
.008 w
.67667 .91737 Mdot
.016 w
.67667 .91737 m
.67661 .91714 L
s
1 .335 0 r
.008 w
.67661 .91714 Mdot
.016 w
.67661 .91714 m
.67651 .91692 L
s
.008 w
.67651 .91692 Mdot
.016 w
.67651 .91692 m
.67636 .91669 L
s
1 .334 0 r
.008 w
.67636 .91669 Mdot
.016 w
.67636 .91669 m
.67622 .91645 L
s
.008 w
.67622 .91645 Mdot
.016 w
.67622 .91645 m
.67615 .91616 L
s
1 .333 0 r
.008 w
.67615 .91616 Mdot
.016 w
.67615 .91616 m
.67616 .91582 L
s
.008 w
.67616 .91582 Mdot
.016 w
.67616 .91582 m
.67624 .91547 L
s
1 .332 0 r
.008 w
.67624 .91547 Mdot
.016 w
.67624 .91547 m
.67636 .91514 L
s
.008 w
.67636 .91514 Mdot
.016 w
.67636 .91514 m
.67647 .91486 L
s
1 .331 0 r
.008 w
.67647 .91486 Mdot
.016 w
.67647 .91486 m
.67654 .91466 L
s
.008 w
.67654 .91466 Mdot
.016 w
.67654 .91466 m
.67654 .91459 L
s
1 .33 0 r
.008 w
.67654 .91459 Mdot
.016 w
.67654 .91459 m
.67649 .91466 L
s
.008 w
.67649 .91466 Mdot
.016 w
.67649 .91466 m
.67641 .91489 L
s
1 .329 0 r
.008 w
.67641 .91489 Mdot
.016 w
.67641 .91489 m
.67631 .91522 L
s
.008 w
.67631 .91522 Mdot
.016 w
.67631 .91522 m
.67619 .91559 L
s
1 .328 0 r
.008 w
.67619 .91559 Mdot
.016 w
.67619 .91559 m
.67611 .91592 L
s
.008 w
.67611 .91592 Mdot
.016 w
.67611 .91592 m
.67607 .91615 L
s
1 .327 0 r
.008 w
.67607 .91615 Mdot
.016 w
.67607 .91615 m
.67612 .91628 L
s
.008 w
.67612 .91628 Mdot
.016 w
.67612 .91628 m
.67608 .91637 L
s
1 .326 0 r
.008 w
.67608 .91637 Mdot
.016 w
.67608 .91637 m
.676 .91644 L
s
.008 w
.676 .91644 Mdot
.016 w
.676 .91644 m
.67586 .91652 L
s
1 .325 0 r
.008 w
.67586 .91652 Mdot
.016 w
.67586 .91652 m
.67568 .91665 L
s
.008 w
.67568 .91665 Mdot
.016 w
.67568 .91665 m
.67547 .91679 L
s
1 .324 0 r
.008 w
.67547 .91679 Mdot
.016 w
.67547 .91679 m
.6753 .9169 L
s
.008 w
.6753 .9169 Mdot
.016 w
.6753 .9169 m
.6752 .91697 L
s
1 .323 0 r
.008 w
.6752 .91697 Mdot
.016 w
.6752 .91697 m
.67521 .91696 L
s
.008 w
.67521 .91696 Mdot
.016 w
.67521 .91696 m
.67527 .91691 L
s
1 .322 0 r
.008 w
.67527 .91691 Mdot
.016 w
.67527 .91691 m
.67534 .91689 L
s
.008 w
.67534 .91689 Mdot
.016 w
.67534 .91689 m
.67536 .91696 L
s
1 .321 0 r
.008 w
.67536 .91696 Mdot
.016 w
.67536 .91696 m
.67536 .91711 L
s
.008 w
.67536 .91711 Mdot
.016 w
.67536 .91711 m
.67535 .91728 L
s
1 .32 0 r
.008 w
.67535 .91728 Mdot
.016 w
.67535 .91728 m
.67537 .91744 L
s
.008 w
.67537 .91744 Mdot
.016 w
.67537 .91744 m
.6754 .91755 L
s
1 .319 0 r
.008 w
.6754 .91755 Mdot
.016 w
.6754 .91755 m
.67545 .9176 L
s
.008 w
.67545 .9176 Mdot
.016 w
.67545 .9176 m
.67549 .91758 L
s
1 .318 0 r
.008 w
.67549 .91758 Mdot
.016 w
.67549 .91758 m
.67549 .91749 L
s
.008 w
.67549 .91749 Mdot
.016 w
.67549 .91749 m
.67549 .91733 L
s
1 .317 0 r
.008 w
.67549 .91733 Mdot
.016 w
.67549 .91733 m
.67547 .91714 L
s
.008 w
.67547 .91714 Mdot
.016 w
.67547 .91714 m
.67541 .91699 L
s
1 .316 0 r
.008 w
.67541 .91699 Mdot
.016 w
.67541 .91699 m
.67529 .91691 L
s
.008 w
.67529 .91691 Mdot
.016 w
.67529 .91691 m
.67515 .91695 L
s
1 .315 0 r
.008 w
.67515 .91695 Mdot
.016 w
.67515 .91695 m
.67504 .91706 L
s
.008 w
.67504 .91706 Mdot
.016 w
.67504 .91706 m
.67498 .9172 L
s
1 .314 0 r
.008 w
.67498 .9172 Mdot
.016 w
.67498 .9172 m
.67494 .91737 L
s
.008 w
.67494 .91737 Mdot
.016 w
.67494 .91737 m
.67494 .91754 L
s
1 .313 0 r
.008 w
.67494 .91754 Mdot
.016 w
.67494 .91754 m
.67496 .91767 L
s
.008 w
.67496 .91767 Mdot
.016 w
.67496 .91767 m
.67498 .91774 L
s
1 .312 0 r
.008 w
.67498 .91774 Mdot
.016 w
.67498 .91774 m
.67497 .91773 L
s
.008 w
.67497 .91773 Mdot
.016 w
.67497 .91773 m
.67489 .91761 L
s
1 .311 0 r
.008 w
.67489 .91761 Mdot
.016 w
.67489 .91761 m
.67471 .91737 L
s
.008 w
.67471 .91737 Mdot
.016 w
.67471 .91737 m
.67441 .91713 L
s
1 .31 0 r
.008 w
.67441 .91713 Mdot
.016 w
.67441 .91713 m
.67402 .9168 L
s
.008 w
.67402 .9168 Mdot
.016 w
.67402 .9168 m
.6736 .9164 L
s
1 .309 0 r
.008 w
.6736 .9164 Mdot
.016 w
.6736 .9164 m
.67317 .91595 L
s
.008 w
.67317 .91595 Mdot
.016 w
.67317 .91595 m
.67267 .91549 L
s
1 .308 0 r
.008 w
.67267 .91549 Mdot
.016 w
.67267 .91549 m
.67215 .91507 L
s
.008 w
.67215 .91507 Mdot
.016 w
.67215 .91507 m
.67167 .91471 L
s
1 .307 0 r
.008 w
.67167 .91471 Mdot
.016 w
.67167 .91471 m
.67132 .91438 L
s
.008 w
.67132 .91438 Mdot
.016 w
.67132 .91438 m
.67108 .91408 L
s
1 .306 0 r
.008 w
.67108 .91408 Mdot
.016 w
.67108 .91408 m
.67092 .91383 L
s
.008 w
.67092 .91383 Mdot
.016 w
.67092 .91383 m
.6708 .91367 L
s
1 .305 0 r
.008 w
.6708 .91367 Mdot
.016 w
.6708 .91367 m
.67068 .91364 L
s
.008 w
.67068 .91364 Mdot
.016 w
.67068 .91364 m
.67048 .91373 L
s
1 .304 0 r
.008 w
.67048 .91373 Mdot
.016 w
.67048 .91373 m
.67022 .9139 L
s
.008 w
.67022 .9139 Mdot
.016 w
.67022 .9139 m
.66989 .91409 L
s
1 .303 0 r
.008 w
.66989 .91409 Mdot
.016 w
.66989 .91409 m
.66951 .91428 L
s
.008 w
.66951 .91428 Mdot
.016 w
.66951 .91428 m
.66906 .91442 L
s
1 .302 0 r
.008 w
.66906 .91442 Mdot
.016 w
.66906 .91442 m
.66858 .91452 L
s
.008 w
.66858 .91452 Mdot
.016 w
.66858 .91452 m
.66814 .91461 L
s
1 .301 0 r
.008 w
.66814 .91461 Mdot
.016 w
.66814 .91461 m
.66783 .91469 L
s
.008 w
.66783 .91469 Mdot
.016 w
.66783 .91469 m
.66757 .91475 L
s
1 .3 0 r
.008 w
.66757 .91475 Mdot
.016 w
.66757 .91475 m
.66737 .91479 L
s
.008 w
.66737 .91479 Mdot
.016 w
.66737 .91479 m
.66726 .91484 L
s
1 .299 0 r
.008 w
.66726 .91484 Mdot
.016 w
.66726 .91484 m
.66721 .91491 L
s
.008 w
.66721 .91491 Mdot
.016 w
.66721 .91491 m
.66727 .91494 L
s
1 .298 0 r
.008 w
.66727 .91494 Mdot
.016 w
.66727 .91494 m
.66741 .91496 L
s
.008 w
.66741 .91496 Mdot
.016 w
.66741 .91496 m
.66757 .91502 L
s
1 .297 0 r
.008 w
.66757 .91502 Mdot
.016 w
.66757 .91502 m
.66763 .9152 L
s
.008 w
.66763 .9152 Mdot
.016 w
.66763 .9152 m
.66757 .91549 L
s
1 .296 0 r
.008 w
.66757 .91549 Mdot
.016 w
.66757 .91549 m
.66733 .91587 L
s
.008 w
.66733 .91587 Mdot
.016 w
.66733 .91587 m
.66696 .91628 L
s
1 .295 0 r
.008 w
.66696 .91628 Mdot
.016 w
.66696 .91628 m
.66646 .91672 L
s
.008 w
.66646 .91672 Mdot
.016 w
.66646 .91672 m
.66589 .91717 L
s
1 .294 0 r
.008 w
.66589 .91717 Mdot
.016 w
.66589 .91717 m
.66515 .91761 L
s
.008 w
.66515 .91761 Mdot
.016 w
.66515 .91761 m
.66457 .91793 L
s
1 .293 0 r
.008 w
.66457 .91793 Mdot
.016 w
.66457 .91793 m
.66399 .91815 L
s
.008 w
.66399 .91815 Mdot
.016 w
.66399 .91815 m
.66341 .91832 L
s
1 .292 0 r
.008 w
.66341 .91832 Mdot
.016 w
.66341 .91832 m
.66282 .9184 L
s
.008 w
.66282 .9184 Mdot
.016 w
.66282 .9184 m
.66231 .9184 L
s
1 .291 0 r
.008 w
.66231 .9184 Mdot
.016 w
.66231 .9184 m
.66188 .91837 L
s
.008 w
.66188 .91837 Mdot
.016 w
.66188 .91837 m
.66148 .91826 L
s
1 .29 0 r
.008 w
.66148 .91826 Mdot
.016 w
.66148 .91826 m
.66125 .91845 L
s
.008 w
.66125 .91845 Mdot
.016 w
.66125 .91845 m
.66102 .91822 L
s
1 .289 0 r
.008 w
.66102 .91822 Mdot
.016 w
.66102 .91822 m
.66088 .91791 L
s
.008 w
.66088 .91791 Mdot
.016 w
.66088 .91791 m
.66072 .91759 L
s
1 .288 0 r
.008 w
.66072 .91759 Mdot
.016 w
.66072 .91759 m
.66038 .91724 L
s
.008 w
.66038 .91724 Mdot
.016 w
.66038 .91724 m
.65997 .91696 L
s
1 .287 0 r
.008 w
.65997 .91696 Mdot
.016 w
.65997 .91696 m
.65955 .91676 L
s
.008 w
.65955 .91676 Mdot
.016 w
.65955 .91676 m
.65908 .91656 L
s
1 .286 0 r
.008 w
.65908 .91656 Mdot
.016 w
.65908 .91656 m
.65866 .91643 L
s
.008 w
.65866 .91643 Mdot
.016 w
.65866 .91643 m
.65832 .91629 L
s
1 .285 0 r
.008 w
.65832 .91629 Mdot
.016 w
.65832 .91629 m
.65824 .91626 L
s
.008 w
.65824 .91626 Mdot
.016 w
.65824 .91626 m
.65835 .91627 L
s
1 .284 0 r
.008 w
.65835 .91627 Mdot
.016 w
.65835 .91627 m
.6587 .91637 L
s
.008 w
.6587 .91637 Mdot
.016 w
.6587 .91637 m
.65924 .91653 L
s
1 .283 0 r
.008 w
.65924 .91653 Mdot
.016 w
.65924 .91653 m
.6599 .91674 L
s
.008 w
.6599 .91674 Mdot
.016 w
.6599 .91674 m
.66057 .91693 L
s
1 .282 0 r
.008 w
.66057 .91693 Mdot
.016 w
.66057 .91693 m
.66125 .9171 L
s
.008 w
.66125 .9171 Mdot
.016 w
.66125 .9171 m
.66193 .91722 L
s
1 .281 0 r
.008 w
.66193 .91722 Mdot
.016 w
.66193 .91722 m
.66271 .91728 L
s
.008 w
.66271 .91728 Mdot
.016 w
.66271 .91728 m
.66352 .91726 L
s
1 .28 0 r
.008 w
.66352 .91726 Mdot
.016 w
.66352 .91726 m
.66433 .91723 L
s
.008 w
.66433 .91723 Mdot
.016 w
.66433 .91723 m
.66508 .91717 L
s
1 .279 0 r
.008 w
.66508 .91717 Mdot
.016 w
.66508 .91717 m
.66576 .91705 L
s
.008 w
.66576 .91705 Mdot
.016 w
.66576 .91705 m
.66634 .91682 L
s
1 .278 0 r
.008 w
.66634 .91682 Mdot
.016 w
.66634 .91682 m
.66684 .91646 L
s
.008 w
.66684 .91646 Mdot
.016 w
.66684 .91646 m
.66729 .91604 L
s
1 .277 0 r
.008 w
.66729 .91604 Mdot
.016 w
.66729 .91604 m
.66769 .91561 L
s
.008 w
.66769 .91561 Mdot
.016 w
.66769 .91561 m
.66807 .91522 L
s
1 .276 0 r
.008 w
.66807 .91522 Mdot
.016 w
.66807 .91522 m
.66851 .91489 L
s
.008 w
.66851 .91489 Mdot
.016 w
.66851 .91489 m
.66909 .91468 L
s
1 .275 0 r
.008 w
.66909 .91468 Mdot
.016 w
.66909 .91468 m
.66985 .91459 L
s
.008 w
.66985 .91459 Mdot
.016 w
.66985 .91459 m
.67071 .91458 L
s
1 .274 0 r
.008 w
.67071 .91458 Mdot
.016 w
.67071 .91458 m
.67163 .91459 L
s
.008 w
.67163 .91459 Mdot
.016 w
.67163 .91459 m
.67273 .91457 L
s
1 .273 0 r
.008 w
.67273 .91457 Mdot
.016 w
.67273 .91457 m
.67398 .91447 L
s
.008 w
.67398 .91447 Mdot
.016 w
.67398 .91447 m
.67538 .91427 L
s
1 .272 0 r
.008 w
.67538 .91427 Mdot
.016 w
.67538 .91427 m
.67688 .91396 L
s
.008 w
.67688 .91396 Mdot
.016 w
.67688 .91396 m
.67848 .91359 L
s
1 .271 0 r
.008 w
.67848 .91359 Mdot
.016 w
.67848 .91359 m
.68014 .91314 L
s
.008 w
.68014 .91314 Mdot
.016 w
.68014 .91314 m
.68186 .91262 L
s
1 .27 0 r
.008 w
.68186 .91262 Mdot
.016 w
.68186 .91262 m
.68359 .91206 L
s
.008 w
.68359 .91206 Mdot
.016 w
.68359 .91206 m
.68533 .91146 L
s
1 .269 0 r
.008 w
.68533 .91146 Mdot
.016 w
.68533 .91146 m
.68709 .9108 L
s
.008 w
.68709 .9108 Mdot
.016 w
.68709 .9108 m
.68869 .91006 L
s
1 .268 0 r
.008 w
.68869 .91006 Mdot
.016 w
.68869 .91006 m
.69041 .90922 L
s
.008 w
.69041 .90922 Mdot
.016 w
.69041 .90922 m
.69213 .9083 L
s
1 .267 0 r
.008 w
.69213 .9083 Mdot
.016 w
.69213 .9083 m
.69393 .90729 L
s
.008 w
.69393 .90729 Mdot
.016 w
.69393 .90729 m
.69577 .90617 L
s
1 .266 0 r
.008 w
.69577 .90617 Mdot
.016 w
.69577 .90617 m
.69764 .90494 L
s
.008 w
.69764 .90494 Mdot
.016 w
.69764 .90494 m
.69954 .90356 L
s
1 .265 0 r
.008 w
.69954 .90356 Mdot
.016 w
.69954 .90356 m
.70148 .90203 L
s
.008 w
.70148 .90203 Mdot
.016 w
.70148 .90203 m
.70346 .90034 L
s
1 .264 0 r
.008 w
.70346 .90034 Mdot
.016 w
.70346 .90034 m
.70546 .89854 L
s
.008 w
.70546 .89854 Mdot
.016 w
.70546 .89854 m
.70746 .89665 L
s
1 .263 0 r
.008 w
.70746 .89665 Mdot
.016 w
.70746 .89665 m
.70946 .89469 L
s
.008 w
.70946 .89469 Mdot
.016 w
.70946 .89469 m
.71144 .8927 L
s
1 .262 0 r
.008 w
.71144 .8927 Mdot
.016 w
.71144 .8927 m
.71342 .89072 L
s
.008 w
.71342 .89072 Mdot
.016 w
.71342 .89072 m
.71557 .88849 L
s
1 .261 0 r
.008 w
.71557 .88849 Mdot
.016 w
.71557 .88849 m
.71726 .8868 L
s
.008 w
.71726 .8868 Mdot
.016 w
.71726 .8868 m
.71893 .88497 L
s
1 .26 0 r
.008 w
.71893 .88497 Mdot
.016 w
.71893 .88497 m
.72039 .8834 L
s
.008 w
.72039 .8834 Mdot
.016 w
.72039 .8834 m
.72161 .88207 L
s
1 .259 0 r
.008 w
.72161 .88207 Mdot
.016 w
.72161 .88207 m
.72259 .88106 L
s
.008 w
.72259 .88106 Mdot
.016 w
.72259 .88106 m
.72335 .88037 L
s
1 .258 0 r
.008 w
.72335 .88037 Mdot
.016 w
.72335 .88037 m
.7239 .87996 L
s
.008 w
.7239 .87996 Mdot
.016 w
.7239 .87996 m
.72425 .87976 L
s
1 .257 0 r
.008 w
.72425 .87976 Mdot
.016 w
.72425 .87976 m
.72443 .87972 L
s
.008 w
.72443 .87972 Mdot
.016 w
.72443 .87972 m
.72448 .8798 L
s
1 .256 0 r
.008 w
.72448 .8798 Mdot
.016 w
.72448 .8798 m
.72441 .87993 L
s
.008 w
.72441 .87993 Mdot
.016 w
.72441 .87993 m
.72423 .88008 L
s
1 .255 0 r
.008 w
.72423 .88008 Mdot
.016 w
.72423 .88008 m
.72397 .8802 L
s
.008 w
.72397 .8802 Mdot
.016 w
.72397 .8802 m
.72368 .88021 L
s
1 .254 0 r
.008 w
.72368 .88021 Mdot
.016 w
.72368 .88021 m
.72336 .88009 L
s
.008 w
.72336 .88009 Mdot
.016 w
.72336 .88009 m
.72304 .87985 L
s
1 .253 0 r
.008 w
.72304 .87985 Mdot
.016 w
.72304 .87985 m
.72275 .87949 L
s
.008 w
.72275 .87949 Mdot
.016 w
.72275 .87949 m
.72247 .87901 L
s
1 .252 0 r
.008 w
.72247 .87901 Mdot
.016 w
.72247 .87901 m
.72222 .87839 L
s
.008 w
.72222 .87839 Mdot
.016 w
.72222 .87839 m
.72198 .87769 L
s
1 .251 0 r
.008 w
.72198 .87769 Mdot
.016 w
.72198 .87769 m
.72173 .87703 L
s
.008 w
.72173 .87703 Mdot
.016 w
.72173 .87703 m
.72146 .87647 L
s
1 .25 0 r
.008 w
.72146 .87647 Mdot
.016 w
.72146 .87647 m
.72114 .87604 L
s
.008 w
.72114 .87604 Mdot
.016 w
.72114 .87604 m
.72078 .87578 L
s
1 .249 0 r
.008 w
.72078 .87578 Mdot
.016 w
.72078 .87578 m
.72042 .87573 L
s
.008 w
.72042 .87573 Mdot
.016 w
.72042 .87573 m
.72009 .87592 L
s
1 .248 0 r
.008 w
.72009 .87592 Mdot
.016 w
.72009 .87592 m
.71981 .87633 L
s
.008 w
.71981 .87633 Mdot
.016 w
.71981 .87633 m
.71959 .87671 L
s
1 .247 0 r
.008 w
.71959 .87671 Mdot
.016 w
.71959 .87671 m
.71941 .87746 L
s
.008 w
.71941 .87746 Mdot
.016 w
.71941 .87746 m
.71923 .87827 L
s
1 .246 0 r
.008 w
.71923 .87827 Mdot
.016 w
.71923 .87827 m
.71902 .87934 L
s
.008 w
.71902 .87934 Mdot
.016 w
.71902 .87934 m
.71874 .88036 L
s
1 .245 0 r
.008 w
.71874 .88036 Mdot
.016 w
.71874 .88036 m
.71836 .88137 L
s
.008 w
.71836 .88137 Mdot
.016 w
.71836 .88137 m
.71784 .8826 L
s
1 .244 0 r
.008 w
.71784 .8826 Mdot
.016 w
.71784 .8826 m
.71721 .88369 L
s
.008 w
.71721 .88369 Mdot
.016 w
.71721 .88369 m
.71643 .88483 L
s
1 .243 0 r
.008 w
.71643 .88483 Mdot
.016 w
.71643 .88483 m
.7155 .88601 L
s
.008 w
.7155 .88601 Mdot
.016 w
.7155 .88601 m
.71446 .88706 L
s
1 .242 0 r
.008 w
.71446 .88706 Mdot
.016 w
.71446 .88706 m
.71326 .88813 L
s
.008 w
.71326 .88813 Mdot
.016 w
.71326 .88813 m
.71191 .88912 L
s
1 .241 0 r
.008 w
.71191 .88912 Mdot
.016 w
.71191 .88912 m
.71051 .89003 L
s
.008 w
.71051 .89003 Mdot
.016 w
.71051 .89003 m
.70897 .89089 L
s
1 .24 0 r
.008 w
.70897 .89089 Mdot
.016 w
.70897 .89089 m
.70744 .89176 L
s
.008 w
.70744 .89176 Mdot
.016 w
.70744 .89176 m
.70583 .89264 L
s
1 .239 0 r
.008 w
.70583 .89264 Mdot
.016 w
.70583 .89264 m
.70429 .89351 L
s
.008 w
.70429 .89351 Mdot
.016 w
.70429 .89351 m
.70279 .89443 L
s
1 .238 0 r
.008 w
.70279 .89443 Mdot
.016 w
.70279 .89443 m
.70133 .89545 L
s
.008 w
.70133 .89545 Mdot
.016 w
.70133 .89545 m
.69987 .89659 L
s
1 .237 0 r
.008 w
.69987 .89659 Mdot
.016 w
.69987 .89659 m
.69834 .89785 L
s
.008 w
.69834 .89785 Mdot
.016 w
.69834 .89785 m
.69678 .89918 L
s
1 .236 0 r
.008 w
.69678 .89918 Mdot
.016 w
.69678 .89918 m
.69513 .90058 L
s
.008 w
.69513 .90058 Mdot
.016 w
.69513 .90058 m
.69334 .90197 L
s
1 .235 0 r
.008 w
.69334 .90197 Mdot
.016 w
.69334 .90197 m
.69159 .90347 L
s
.008 w
.69159 .90347 Mdot
.016 w
.69159 .90347 m
.68969 .90506 L
s
1 .234 0 r
.008 w
.68969 .90506 Mdot
.016 w
.68969 .90506 m
.68765 .90672 L
s
.008 w
.68765 .90672 Mdot
.016 w
.68765 .90672 m
.68554 .90837 L
s
1 .233 0 r
.008 w
.68554 .90837 Mdot
.016 w
.68554 .90837 m
.68344 .90991 L
s
.008 w
.68344 .90991 Mdot
.016 w
.68344 .90991 m
.68134 .91133 L
s
1 .232 0 r
.008 w
.68134 .91133 Mdot
.016 w
.68134 .91133 m
.6793 .91258 L
s
.008 w
.6793 .91258 Mdot
.016 w
.6793 .91258 m
.67746 .91365 L
s
1 .231 0 r
.008 w
.67746 .91365 Mdot
.016 w
.67746 .91365 m
.67572 .91451 L
s
.008 w
.67572 .91451 Mdot
.016 w
.67572 .91451 m
.67418 .91514 L
s
1 .23 0 r
.008 w
.67418 .91514 Mdot
.016 w
.67418 .91514 m
.67286 .91559 L
s
.008 w
.67286 .91559 Mdot
.016 w
.67286 .91559 m
.67184 .91593 L
s
1 .229 0 r
.008 w
.67184 .91593 Mdot
.016 w
.67184 .91593 m
.67088 .91625 L
s
.008 w
.67088 .91625 Mdot
.016 w
.67088 .91625 m
.67005 .91656 L
s
1 .228 0 r
.008 w
.67005 .91656 Mdot
.016 w
.67005 .91656 m
.66925 .91683 L
s
.008 w
.66925 .91683 Mdot
.016 w
.66925 .91683 m
.66837 .91716 L
s
1 .227 0 r
.008 w
.66837 .91716 Mdot
.016 w
.66837 .91716 m
.66739 .91758 L
s
.008 w
.66739 .91758 Mdot
.016 w
.66739 .91758 m
.6663 .91807 L
s
1 .226 0 r
.008 w
.6663 .91807 Mdot
.016 w
.6663 .91807 m
.66495 .91856 L
s
.008 w
.66495 .91856 Mdot
.016 w
.66495 .91856 m
.66326 .91914 L
s
1 .225 0 r
.008 w
.66326 .91914 Mdot
.016 w
.66326 .91914 m
.6612 .91982 L
s
.008 w
.6612 .91982 Mdot
.016 w
.6612 .91982 m
.65894 .9206 L
s
1 .224 0 r
.008 w
.65894 .9206 Mdot
.016 w
.65894 .9206 m
.65598 .92152 L
s
.008 w
.65598 .92152 Mdot
.016 w
.65598 .92152 m
.65306 .92247 L
s
1 .223 0 r
.008 w
.65306 .92247 Mdot
.016 w
.65306 .92247 m
.64948 .92349 L
s
.008 w
.64948 .92349 Mdot
.016 w
.64948 .92349 m
.64585 .92451 L
s
1 .222 0 r
.008 w
.64585 .92451 Mdot
.016 w
.64585 .92451 m
.6418 .92546 L
s
.008 w
.6418 .92546 Mdot
.016 w
.6418 .92546 m
.63809 .92641 L
s
1 .221 0 r
.008 w
.63809 .92641 Mdot
.016 w
.63809 .92641 m
.63415 .92737 L
s
.008 w
.63415 .92737 Mdot
.016 w
.63415 .92737 m
.63044 .92826 L
s
1 .22 0 r
.008 w
.63044 .92826 Mdot
.016 w
.63044 .92826 m
.6265 .92908 L
s
.008 w
.6265 .92908 Mdot
.016 w
.6265 .92908 m
.62301 .92983 L
s
1 .219 0 r
.008 w
.62301 .92983 Mdot
.016 w
.62301 .92983 m
.61935 .93056 L
s
.008 w
.61935 .93056 Mdot
.016 w
.61935 .93056 m
.61592 .93118 L
s
1 .218 0 r
.008 w
.61592 .93118 Mdot
.016 w
.61592 .93118 m
.6128 .93173 L
s
.008 w
.6128 .93173 Mdot
.016 w
.6128 .93173 m
.60952 .93214 L
s
1 .217 0 r
.008 w
.60952 .93214 Mdot
.016 w
.60952 .93214 m
.60637 .93243 L
s
.008 w
.60637 .93243 Mdot
.016 w
.60637 .93243 m
.60325 .93256 L
s
1 .216 0 r
.008 w
.60325 .93256 Mdot
.016 w
.60325 .93256 m
.60011 .93265 L
s
.008 w
.60011 .93265 Mdot
.016 w
.60011 .93265 m
.59719 .93275 L
s
1 .215 0 r
.008 w
.59719 .93275 Mdot
.016 w
.59719 .93275 m
.59405 .93287 L
s
.008 w
.59405 .93287 Mdot
.016 w
.59405 .93287 m
.59111 .93295 L
s
1 .214 0 r
.008 w
.59111 .93295 Mdot
.016 w
.59111 .93295 m
.5879 .93308 L
s
.008 w
.5879 .93308 Mdot
.016 w
.5879 .93308 m
.58464 .93329 L
s
1 .213 0 r
.008 w
.58464 .93329 Mdot
.016 w
.58464 .93329 m
.58097 .93363 L
s
.008 w
.58097 .93363 Mdot
.016 w
.58097 .93363 m
.57748 .93405 L
s
1 .212 0 r
.008 w
.57748 .93405 Mdot
.016 w
.57748 .93405 m
.5737 .93454 L
s
.008 w
.5737 .93454 Mdot
.016 w
.5737 .93454 m
.56945 .93512 L
s
1 .211 0 r
.008 w
.56945 .93512 Mdot
.016 w
.56945 .93512 m
.56576 .93573 L
s
.008 w
.56576 .93573 Mdot
.016 w
.56576 .93573 m
.56162 .93649 L
s
1 .21 0 r
.008 w
.56162 .93649 Mdot
.016 w
.56162 .93649 m
.55779 .93733 L
s
.008 w
.55779 .93733 Mdot
.016 w
.55779 .93733 m
.55372 .93822 L
s
1 .209 0 r
.008 w
.55372 .93822 Mdot
.016 w
.55372 .93822 m
.54998 .93905 L
s
.008 w
.54998 .93905 Mdot
.016 w
.54998 .93905 m
.54616 .93978 L
s
1 .208 0 r
.008 w
.54616 .93978 Mdot
.016 w
.54616 .93978 m
.54233 .94039 L
s
.008 w
.54233 .94039 Mdot
.016 w
.54233 .94039 m
.53887 .94086 L
s
1 .207 0 r
.008 w
.53887 .94086 Mdot
.016 w
.53887 .94086 m
.53545 .94123 L
s
.008 w
.53545 .94123 Mdot
.016 w
.53545 .94123 m
.53219 .9415 L
s
1 .206 0 r
.008 w
.53219 .9415 Mdot
.016 w
.53219 .9415 m
.5292 .94172 L
s
.008 w
.5292 .94172 Mdot
.016 w
.5292 .94172 m
.52645 .94195 L
s
1 .205 0 r
.008 w
.52645 .94195 Mdot
.016 w
.52645 .94195 m
.52404 .94224 L
s
.008 w
.52404 .94224 Mdot
.016 w
.52404 .94224 m
.52211 .94263 L
s
1 .204 0 r
.008 w
.52211 .94263 Mdot
.016 w
.52211 .94263 m
.52016 .94305 L
s
.008 w
.52016 .94305 Mdot
.016 w
.52016 .94305 m
.51855 .94349 L
s
1 .203 0 r
.008 w
.51855 .94349 Mdot
.016 w
.51855 .94349 m
.51704 .94394 L
s
.008 w
.51704 .94394 Mdot
.016 w
.51704 .94394 m
.51571 .94435 L
s
1 .202 0 r
.008 w
.51571 .94435 Mdot
.016 w
.51571 .94435 m
.51459 .94471 L
s
.008 w
.51459 .94471 Mdot
.016 w
.51459 .94471 m
.51368 .94501 L
s
1 .201 0 r
.008 w
.51368 .94501 Mdot
.016 w
.51368 .94501 m
.51301 .9452 L
s
.008 w
.51301 .9452 Mdot
.016 w
.51301 .9452 m
.51253 .94525 L
s
1 .2 0 r
.008 w
.51253 .94525 Mdot
.016 w
.51253 .94525 m
.51222 .9452 L
s
.008 w
.51222 .9452 Mdot
.016 w
.51222 .9452 m
.51206 .94506 L
s
1 .199 0 r
.008 w
.51206 .94506 Mdot
.016 w
.51206 .94506 m
.512 .94482 L
s
.008 w
.512 .94482 Mdot
.016 w
.512 .94482 m
.51195 .9445 L
s
1 .198 0 r
.008 w
.51195 .9445 Mdot
.016 w
.51195 .9445 m
.51185 .94406 L
s
.008 w
.51185 .94406 Mdot
.016 w
.51185 .94406 m
.5117 .94354 L
s
1 .197 0 r
.008 w
.5117 .94354 Mdot
.016 w
.5117 .94354 m
.51149 .943 L
s
.008 w
.51149 .943 Mdot
.016 w
.51149 .943 m
.51123 .9425 L
s
1 .196 0 r
.008 w
.51123 .9425 Mdot
.016 w
.51123 .9425 m
.51094 .9421 L
s
.008 w
.51094 .9421 Mdot
.016 w
.51094 .9421 m
.51063 .94186 L
s
1 .195 0 r
.008 w
.51063 .94186 Mdot
.016 w
.51063 .94186 m
.51033 .9418 L
s
.008 w
.51033 .9418 Mdot
.016 w
.51033 .9418 m
.51002 .94189 L
s
1 .194 0 r
.008 w
.51002 .94189 Mdot
.016 w
.51002 .94189 m
.50971 .94209 L
s
.008 w
.50971 .94209 Mdot
.016 w
.50971 .94209 m
.50939 .94235 L
s
1 .193 0 r
.008 w
.50939 .94235 Mdot
.016 w
.50939 .94235 m
.50909 .94262 L
s
.008 w
.50909 .94262 Mdot
.016 w
.50909 .94262 m
.50875 .94285 L
s
1 .192 0 r
.008 w
.50875 .94285 Mdot
.016 w
.50875 .94285 m
.50843 .94304 L
s
.008 w
.50843 .94304 Mdot
.016 w
.50843 .94304 m
.50814 .9432 L
s
1 .191 0 r
.008 w
.50814 .9432 Mdot
.016 w
.50814 .9432 m
.50784 .94334 L
s
.008 w
.50784 .94334 Mdot
.016 w
.50784 .94334 m
.50752 .94344 L
s
1 .19 0 r
.008 w
.50752 .94344 Mdot
.016 w
.50752 .94344 m
.50722 .94349 L
s
.008 w
.50722 .94349 Mdot
.016 w
.50722 .94349 m
.50688 .9435 L
s
1 .189 0 r
.008 w
.50688 .9435 Mdot
.016 w
.50688 .9435 m
.50645 .94346 L
s
.008 w
.50645 .94346 Mdot
.016 w
.50645 .94346 m
.50588 .94338 L
s
1 .188 0 r
.008 w
.50588 .94338 Mdot
.016 w
.50588 .94338 m
.50517 .94325 L
s
.008 w
.50517 .94325 Mdot
.016 w
.50517 .94325 m
.50437 .94306 L
s
1 .187 0 r
.008 w
.50437 .94306 Mdot
.016 w
.50437 .94306 m
.5034 .94284 L
s
.008 w
.5034 .94284 Mdot
.016 w
.5034 .94284 m
.50229 .94258 L
s
1 .186 0 r
.008 w
.50229 .94258 Mdot
.016 w
.50229 .94258 m
.50111 .94228 L
s
.008 w
.50111 .94228 Mdot
.016 w
.50111 .94228 m
.4999 .94196 L
s
1 .185 0 r
.008 w
.4999 .94196 Mdot
.016 w
.4999 .94196 m
.49874 .94162 L
s
.008 w
.49874 .94162 Mdot
.016 w
.49874 .94162 m
.49762 .94127 L
s
1 .184 0 r
.008 w
.49762 .94127 Mdot
.016 w
.49762 .94127 m
.49655 .94089 L
s
.008 w
.49655 .94089 Mdot
.016 w
.49655 .94089 m
.49569 .94058 L
s
1 .183 0 r
.008 w
.49569 .94058 Mdot
.016 w
.49569 .94058 m
.49489 .94026 L
s
.008 w
.49489 .94026 Mdot
.016 w
.49489 .94026 m
.49424 .93992 L
s
1 .182 0 r
.008 w
.49424 .93992 Mdot
.016 w
.49424 .93992 m
.4938 .93959 L
s
.008 w
.4938 .93959 Mdot
.016 w
.4938 .93959 m
.49359 .93933 L
s
1 .181 0 r
.008 w
.49359 .93933 Mdot
.016 w
.49359 .93933 m
.49363 .93918 L
s
.008 w
.49363 .93918 Mdot
.016 w
.49363 .93918 m
.49388 .93915 L
s
1 .18 0 r
.008 w
.49388 .93915 Mdot
.016 w
.49388 .93915 m
.49428 .93918 L
s
.008 w
.49428 .93918 Mdot
.016 w
.49428 .93918 m
.4948 .93928 L
s
1 .179 0 r
.008 w
.4948 .93928 Mdot
.016 w
.4948 .93928 m
.49533 .93942 L
s
.008 w
.49533 .93942 Mdot
.016 w
.49533 .93942 m
.49578 .93958 L
s
1 .178 0 r
.008 w
.49578 .93958 Mdot
.016 w
.49578 .93958 m
.49609 .93974 L
s
.008 w
.49609 .93974 Mdot
.016 w
.49609 .93974 m
.49625 .93979 L
s
1 .177 0 r
.008 w
.49625 .93979 Mdot
.016 w
.49625 .93979 m
.49628 .93983 L
s
.008 w
.49628 .93983 Mdot
.016 w
.49628 .93983 m
.49624 .93991 L
s
1 .176 0 r
.008 w
.49624 .93991 Mdot
.016 w
.49624 .93991 m
.49613 .94001 L
s
.008 w
.49613 .94001 Mdot
.016 w
.49613 .94001 m
.49597 .94014 L
s
1 .175 0 r
.008 w
.49597 .94014 Mdot
.016 w
.49597 .94014 m
.49578 .94028 L
s
.008 w
.49578 .94028 Mdot
.016 w
.49578 .94028 m
.49553 .94043 L
s
1 .174 0 r
.008 w
.49553 .94043 Mdot
.016 w
.49553 .94043 m
.49528 .94056 L
s
.008 w
.49528 .94056 Mdot
.016 w
.49528 .94056 m
.4951 .94067 L
s
1 .173 0 r
.008 w
.4951 .94067 Mdot
.016 w
.4951 .94067 m
.49504 .94075 L
s
.008 w
.49504 .94075 Mdot
.016 w
.49504 .94075 m
.4951 .9408 L
s
1 .172 0 r
.008 w
.4951 .9408 Mdot
.016 w
.4951 .9408 m
.4953 .94079 L
s
.008 w
.4953 .94079 Mdot
.016 w
.4953 .94079 m
.49564 .94074 L
s
1 .171 0 r
.008 w
.49564 .94074 Mdot
.016 w
.49564 .94074 m
.49609 .94068 L
s
.008 w
.49609 .94068 Mdot
.016 w
.49609 .94068 m
.4965 .94066 L
s
1 .17 0 r
.008 w
.4965 .94066 Mdot
.016 w
.4965 .94066 m
.49695 .94061 L
s
.008 w
.49695 .94061 Mdot
.016 w
.49695 .94061 m
.49735 .94041 L
s
1 .169 0 r
.008 w
.49735 .94041 Mdot
.016 w
.49735 .94041 m
.49765 .94021 L
s
.008 w
.49765 .94021 Mdot
.016 w
.49765 .94021 m
.4978 .9399 L
s
1 .168 0 r
.008 w
.4978 .9399 Mdot
.016 w
.4978 .9399 m
.49783 .93958 L
s
.008 w
.49783 .93958 Mdot
.016 w
.49783 .93958 m
.49781 .93929 L
s
1 .167 0 r
.008 w
.49781 .93929 Mdot
.016 w
.49781 .93929 m
.49782 .93909 L
s
.008 w
.49782 .93909 Mdot
.016 w
.49782 .93909 m
.4978 .93899 L
s
1 .166 0 r
.008 w
.4978 .93899 Mdot
.016 w
.4978 .93899 m
.49779 .939 L
s
.008 w
.49779 .939 Mdot
.016 w
.49779 .939 m
.4978 .93915 L
s
1 .165 0 r
.008 w
.4978 .93915 Mdot
.016 w
.4978 .93915 m
.49781 .93933 L
s
.008 w
.49781 .93933 Mdot
.016 w
.49781 .93933 m
.49776 .93955 L
s
1 .164 0 r
.008 w
.49776 .93955 Mdot
.016 w
.49776 .93955 m
.49765 .93977 L
s
.008 w
.49765 .93977 Mdot
.016 w
.49765 .93977 m
.49755 .93996 L
s
1 .163 0 r
.008 w
.49755 .93996 Mdot
.016 w
.49755 .93996 m
.4975 .94021 L
s
.008 w
.4975 .94021 Mdot
.016 w
.4975 .94021 m
.49749 .94047 L
s
1 .162 0 r
.008 w
.49749 .94047 Mdot
.016 w
.49749 .94047 m
.49751 .94076 L
s
.008 w
.49751 .94076 Mdot
.016 w
.49751 .94076 m
.49756 .94109 L
s
1 .161 0 r
.008 w
.49756 .94109 Mdot
.016 w
.49756 .94109 m
.49757 .9414 L
s
.008 w
.49757 .9414 Mdot
.016 w
.49757 .9414 m
.49751 .94164 L
s
1 .16 0 r
.008 w
.49751 .94164 Mdot
.016 w
.49751 .94164 m
.49733 .94174 L
s
.008 w
.49733 .94174 Mdot
.016 w
.49733 .94174 m
.49709 .94175 L
s
1 .159 0 r
.008 w
.49709 .94175 Mdot
.016 w
.49709 .94175 m
.4969 .9417 L
s
.008 w
.4969 .9417 Mdot
.016 w
.4969 .9417 m
.4968 .94163 L
s
1 .158 0 r
.008 w
.4968 .94163 Mdot
.016 w
.4968 .94163 m
.49682 .94154 L
s
.008 w
.49682 .94154 Mdot
.016 w
.49682 .94154 m
.497 .94146 L
s
1 .157 0 r
.008 w
.497 .94146 Mdot
.016 w
.497 .94146 m
.49732 .94145 L
s
.008 w
.49732 .94145 Mdot
.016 w
.49732 .94145 m
.49775 .94152 L
s
1 .156 0 r
.008 w
.49775 .94152 Mdot
.016 w
.49775 .94152 m
.49817 .94159 L
s
.008 w
.49817 .94159 Mdot
.016 w
.49817 .94159 m
.4985 .94172 L
s
1 .155 0 r
.008 w
.4985 .94172 Mdot
.016 w
.4985 .94172 m
.49853 .94192 L
s
.008 w
.49853 .94192 Mdot
.016 w
.49853 .94192 m
.49818 .9422 L
s
1 .154 0 r
.008 w
.49818 .9422 Mdot
.016 w
.49818 .9422 m
.49744 .94253 L
s
.008 w
.49744 .94253 Mdot
.016 w
.49744 .94253 m
.4964 .94298 L
s
1 .153 0 r
.008 w
.4964 .94298 Mdot
.016 w
.4964 .94298 m
.49502 .94353 L
s
.008 w
.49502 .94353 Mdot
.016 w
.49502 .94353 m
.49344 .94416 L
s
1 .152 0 r
.008 w
.49344 .94416 Mdot
.016 w
.49344 .94416 m
.49156 .94469 L
s
.008 w
.49156 .94469 Mdot
.016 w
.49156 .94469 m
.48951 .94524 L
s
1 .151 0 r
.008 w
.48951 .94524 Mdot
.016 w
.48951 .94524 m
.48741 .94579 L
s
.008 w
.48741 .94579 Mdot
.016 w
.48741 .94579 m
.48504 .94633 L
s
1 .15 0 r
.008 w
.48504 .94633 Mdot
.016 w
.48504 .94633 m
.48234 .94672 L
s
.008 w
.48234 .94672 Mdot
.016 w
.48234 .94672 m
.47988 .94707 L
s
1 .149 0 r
.008 w
.47988 .94707 Mdot
.016 w
.47988 .94707 m
.47752 .94739 L
s
.008 w
.47752 .94739 Mdot
.016 w
.47752 .94739 m
.47529 .94769 L
s
1 .148 0 r
.008 w
.47529 .94769 Mdot
.016 w
.47529 .94769 m
.47335 .94801 L
s
.008 w
.47335 .94801 Mdot
.016 w
.47335 .94801 m
.47179 .94836 L
s
1 .147 0 r
.008 w
.47179 .94836 Mdot
.016 w
.47179 .94836 m
.47064 .94876 L
s
.008 w
.47064 .94876 Mdot
.016 w
.47064 .94876 m
.46972 .94909 L
s
1 .146 0 r
.008 w
.46972 .94909 Mdot
.016 w
.46972 .94909 m
.46896 .94936 L
s
.008 w
.46896 .94936 Mdot
.016 w
.46896 .94936 m
.46829 .94954 L
s
1 .145 0 r
.008 w
.46829 .94954 Mdot
.016 w
.46829 .94954 m
.46766 .94959 L
s
.008 w
.46766 .94959 Mdot
.016 w
.46766 .94959 m
.467 .94951 L
s
1 .144 0 r
.008 w
.467 .94951 Mdot
.016 w
.467 .94951 m
.46627 .94928 L
s
.008 w
.46627 .94928 Mdot
.016 w
.46627 .94928 m
.46544 .94894 L
s
1 .143 0 r
.008 w
.46544 .94894 Mdot
.016 w
.46544 .94894 m
.46464 .94849 L
s
.008 w
.46464 .94849 Mdot
.016 w
.46464 .94849 m
.46373 .94792 L
s
1 .142 0 r
.008 w
.46373 .94792 Mdot
.016 w
.46373 .94792 m
.46277 .94729 L
s
.008 w
.46277 .94729 Mdot
.016 w
.46277 .94729 m
.46171 .94661 L
s
1 .141 0 r
.008 w
.46171 .94661 Mdot
.016 w
.46171 .94661 m
.46057 .94591 L
s
.008 w
.46057 .94591 Mdot
.016 w
.46057 .94591 m
.45927 .94524 L
s
1 .14 0 r
.008 w
.45927 .94524 Mdot
.016 w
.45927 .94524 m
.45783 .94457 L
s
.008 w
.45783 .94457 Mdot
.016 w
.45783 .94457 m
.45627 .94387 L
s
1 .139 0 r
.008 w
.45627 .94387 Mdot
.016 w
.45627 .94387 m
.45474 .94329 L
s
.008 w
.45474 .94329 Mdot
.016 w
.45474 .94329 m
.45316 .94273 L
s
1 .138 0 r
.008 w
.45316 .94273 Mdot
.016 w
.45316 .94273 m
.45168 .94226 L
s
.008 w
.45168 .94226 Mdot
.016 w
.45168 .94226 m
.45033 .94197 L
s
1 .137 0 r
.008 w
.45033 .94197 Mdot
.016 w
.45033 .94197 m
.44914 .94183 L
s
.008 w
.44914 .94183 Mdot
.016 w
.44914 .94183 m
.44806 .94183 L
s
1 .136 0 r
.008 w
.44806 .94183 Mdot
.016 w
.44806 .94183 m
.44703 .94187 L
s
.008 w
.44703 .94187 Mdot
.016 w
.44703 .94187 m
.44593 .94186 L
s
1 .135 0 r
.008 w
.44593 .94186 Mdot
.016 w
.44593 .94186 m
.44477 .94178 L
s
.008 w
.44477 .94178 Mdot
.016 w
.44477 .94178 m
.44346 .94163 L
s
1 .134 0 r
.008 w
.44346 .94163 Mdot
.016 w
.44346 .94163 m
.44185 .9414 L
s
.008 w
.44185 .9414 Mdot
.016 w
.44185 .9414 m
.44027 .94114 L
s
1 .133 0 r
.008 w
.44027 .94114 Mdot
.016 w
.44027 .94114 m
.43843 .94082 L
s
.008 w
.43843 .94082 Mdot
.016 w
.43843 .94082 m
.4363 .94046 L
s
1 .132 0 r
.008 w
.4363 .94046 Mdot
.016 w
.4363 .94046 m
.43394 .93995 L
s
.008 w
.43394 .93995 Mdot
.016 w
.43394 .93995 m
.4316 .93937 L
s
1 .131 0 r
.008 w
.4316 .93937 Mdot
.016 w
.4316 .93937 m
.42907 .93868 L
s
.008 w
.42907 .93868 Mdot
.016 w
.42907 .93868 m
.42626 .93787 L
s
1 .13 0 r
.008 w
.42626 .93787 Mdot
.016 w
.42626 .93787 m
.42289 .93708 L
s
.008 w
.42289 .93708 Mdot
.016 w
.42289 .93708 m
.41986 .93618 L
s
1 .129 0 r
.008 w
.41986 .93618 Mdot
.016 w
.41986 .93618 m
.41636 .93517 L
s
.008 w
.41636 .93517 Mdot
.016 w
.41636 .93517 m
.41291 .93423 L
s
1 .128 0 r
.008 w
.41291 .93423 Mdot
.016 w
.41291 .93423 m
.4092 .93325 L
s
.008 w
.4092 .93325 Mdot
.016 w
.4092 .93325 m
.40526 .93228 L
s
1 .127 0 r
.008 w
.40526 .93228 Mdot
.016 w
.40526 .93228 m
.40175 .93129 L
s
.008 w
.40175 .93129 Mdot
.016 w
.40175 .93129 m
.39779 .93032 L
s
1 .126 0 r
.008 w
.39779 .93032 Mdot
.016 w
.39779 .93032 m
.39402 .92927 L
s
.008 w
.39402 .92927 Mdot
.016 w
.39402 .92927 m
.38991 .92812 L
s
1 .125 0 r
.008 w
.38991 .92812 Mdot
.016 w
.38991 .92812 m
.38574 .92686 L
s
.008 w
.38574 .92686 Mdot
.016 w
.38574 .92686 m
.38198 .92557 L
s
1 .124 0 r
.008 w
.38198 .92557 Mdot
.016 w
.38198 .92557 m
.37798 .9242 L
s
.008 w
.37798 .9242 Mdot
.016 w
.37798 .9242 m
.37405 .92277 L
s
1 .123 0 r
.008 w
.37405 .92277 Mdot
.016 w
.37405 .92277 m
.36999 .92138 L
s
.008 w
.36999 .92138 Mdot
.016 w
.36999 .92138 m
.3664 .91996 L
s
1 .122 0 r
.008 w
.3664 .91996 Mdot
.016 w
.3664 .91996 m
.36266 .91854 L
s
.008 w
.36266 .91854 Mdot
.016 w
.36266 .91854 m
.35895 .91717 L
s
1 .121 0 r
.008 w
.35895 .91717 Mdot
.016 w
.35895 .91717 m
.35535 .9158 L
s
.008 w
.35535 .9158 Mdot
.016 w
.35535 .9158 m
.35181 .91444 L
s
1 .12 0 r
.008 w
.35181 .91444 Mdot
.016 w
.35181 .91444 m
.34811 .91308 L
s
.008 w
.34811 .91308 Mdot
.016 w
.34811 .91308 m
.34452 .91174 L
s
1 .119 0 r
.008 w
.34452 .91174 Mdot
.016 w
.34452 .91174 m
.34113 .91043 L
s
.008 w
.34113 .91043 Mdot
.016 w
.34113 .91043 m
.33751 .90912 L
s
1 .118 0 r
.008 w
.33751 .90912 Mdot
.016 w
.33751 .90912 m
.33396 .90787 L
s
.008 w
.33396 .90787 Mdot
.016 w
.33396 .90787 m
.33016 .90668 L
s
1 .117 0 r
.008 w
.33016 .90668 Mdot
.016 w
.33016 .90668 m
.32675 .90553 L
s
.008 w
.32675 .90553 Mdot
.016 w
.32675 .90553 m
.32316 .90444 L
s
1 .116 0 r
.008 w
.32316 .90444 Mdot
.016 w
.32316 .90444 m
.31946 .90339 L
s
.008 w
.31946 .90339 Mdot
.016 w
.31946 .90339 m
.31611 .9024 L
s
1 .115 0 r
.008 w
.31611 .9024 Mdot
.016 w
.31611 .9024 m
.31286 .90144 L
s
.008 w
.31286 .90144 Mdot
.016 w
.31286 .90144 m
.30948 .90049 L
s
1 .114 0 r
.008 w
.30948 .90049 Mdot
.016 w
.30948 .90049 m
.30623 .89951 L
s
.008 w
.30623 .89951 Mdot
.016 w
.30623 .89951 m
.30289 .89852 L
s
1 .113 0 r
.008 w
.30289 .89852 Mdot
.016 w
.30289 .89852 m
.29969 .8975 L
s
.008 w
.29969 .8975 Mdot
.016 w
.29969 .8975 m
.29639 .89639 L
s
1 .112 0 r
.008 w
.29639 .89639 Mdot
.016 w
.29639 .89639 m
.29311 .89522 L
s
.008 w
.29311 .89522 Mdot
.016 w
.29311 .89522 m
.29022 .89395 L
s
1 .111 0 r
.008 w
.29022 .89395 Mdot
.016 w
.29022 .89395 m
.28712 .89261 L
s
.008 w
.28712 .89261 Mdot
.016 w
.28712 .89261 m
.28418 .89131 L
s
1 .11 0 r
.008 w
.28418 .89131 Mdot
.016 w
.28418 .89131 m
.2812 .88995 L
s
.008 w
.2812 .88995 Mdot
.016 w
.2812 .88995 m
.27837 .88859 L
s
1 .109 0 r
.008 w
.27837 .88859 Mdot
.016 w
.27837 .88859 m
.27567 .88728 L
s
.008 w
.27567 .88728 Mdot
.016 w
.27567 .88728 m
.27293 .88597 L
s
1 .108 0 r
.008 w
.27293 .88597 Mdot
.016 w
.27293 .88597 m
.27039 .88468 L
s
.008 w
.27039 .88468 Mdot
.016 w
.27039 .88468 m
.26783 .8834 L
s
1 .107 0 r
.008 w
.26783 .8834 Mdot
.016 w
.26783 .8834 m
.26554 .88214 L
s
.008 w
.26554 .88214 Mdot
.016 w
.26554 .88214 m
.26334 .88095 L
s
1 .106 0 r
.008 w
.26334 .88095 Mdot
.016 w
.26334 .88095 m
.26132 .8798 L
s
.008 w
.26132 .8798 Mdot
.016 w
.26132 .8798 m
.25954 .8787 L
s
1 .105 0 r
.008 w
.25954 .8787 Mdot
.016 w
.25954 .8787 m
.25799 .87767 L
s
.008 w
.25799 .87767 Mdot
.016 w
.25799 .87767 m
.25671 .87675 L
s
1 .104 0 r
.008 w
.25671 .87675 Mdot
.016 w
.25671 .87675 m
.25569 .87587 L
s
.008 w
.25569 .87587 Mdot
.016 w
.25569 .87587 m
.25489 .87508 L
s
1 .103 0 r
.008 w
.25489 .87508 Mdot
.016 w
.25489 .87508 m
.25434 .87439 L
s
.008 w
.25434 .87439 Mdot
.016 w
.25434 .87439 m
.254 .87385 L
s
1 .102 0 r
.008 w
.254 .87385 Mdot
.016 w
.254 .87385 m
.25383 .8734 L
s
.008 w
.25383 .8734 Mdot
.016 w
.25383 .8734 m
.25374 .87301 L
s
1 .101 0 r
.008 w
.25374 .87301 Mdot
.016 w
.25374 .87301 m
.25367 .87269 L
s
.008 w
.25367 .87269 Mdot
.016 w
.25367 .87269 m
.25351 .87238 L
s
1 .1 0 r
.008 w
.25351 .87238 Mdot
.016 w
.25351 .87238 m
.2532 .87207 L
s
.008 w
.2532 .87207 Mdot
.016 w
.2532 .87207 m
.25268 .87172 L
s
1 .099 0 r
.008 w
.25268 .87172 Mdot
.016 w
.25268 .87172 m
.25194 .87132 L
s
.008 w
.25194 .87132 Mdot
.016 w
.25194 .87132 m
.25088 .87068 L
s
1 .098 0 r
.008 w
.25088 .87068 Mdot
.016 w
.25088 .87068 m
.24946 .86977 L
s
.008 w
.24946 .86977 Mdot
.016 w
.24946 .86977 m
.24763 .86856 L
s
1 .097 0 r
.008 w
.24763 .86856 Mdot
.016 w
.24763 .86856 m
.24546 .86709 L
s
.008 w
.24546 .86709 Mdot
.016 w
.24546 .86709 m
.243 .86533 L
s
1 .096 0 r
.008 w
.243 .86533 Mdot
.016 w
.243 .86533 m
.24014 .8632 L
s
.008 w
.24014 .8632 Mdot
.016 w
.24014 .8632 m
.23704 .86089 L
s
1 .095 0 r
.008 w
.23704 .86089 Mdot
.016 w
.23704 .86089 m
.23376 .85836 L
s
.008 w
.23376 .85836 Mdot
.016 w
.23376 .85836 m
.23027 .85558 L
s
1 .094 0 r
.008 w
.23027 .85558 Mdot
.016 w
.23027 .85558 m
.2269 .85287 L
s
.008 w
.2269 .85287 Mdot
.016 w
.2269 .85287 m
.22342 .84998 L
s
1 .093 0 r
.008 w
.22342 .84998 Mdot
.016 w
.22342 .84998 m
.22008 .84704 L
s
.008 w
.22008 .84704 Mdot
.016 w
.22008 .84704 m
.21679 .84443 L
s
1 .092 0 r
.008 w
.21679 .84443 Mdot
.016 w
.21679 .84443 m
.21358 .84165 L
s
.008 w
.21358 .84165 Mdot
.016 w
.21358 .84165 m
.21055 .83888 L
s
1 .091 0 r
.008 w
.21055 .83888 Mdot
.016 w
.21055 .83888 m
.20758 .83616 L
s
.008 w
.20758 .83616 Mdot
.016 w
.20758 .83616 m
.20474 .83345 L
s
1 .09 0 r
.008 w
.20474 .83345 Mdot
.016 w
.20474 .83345 m
.20196 .83091 L
s
.008 w
.20196 .83091 Mdot
.016 w
.20196 .83091 m
.19926 .82834 L
s
1 .089 0 r
.008 w
.19926 .82834 Mdot
.016 w
.19926 .82834 m
.19661 .82587 L
s
.008 w
.19661 .82587 Mdot
.016 w
.19661 .82587 m
.19399 .82336 L
s
1 .088 0 r
.008 w
.19399 .82336 Mdot
.016 w
.19399 .82336 m
.19131 .82074 L
s
.008 w
.19131 .82074 Mdot
.016 w
.19131 .82074 m
.18869 .81817 L
s
1 .087 0 r
.008 w
.18869 .81817 Mdot
.016 w
.18869 .81817 m
.18614 .8157 L
s
.008 w
.18614 .8157 Mdot
.016 w
.18614 .8157 m
.18368 .81315 L
s
1 .086 0 r
.008 w
.18368 .81315 Mdot
.016 w
.18368 .81315 m
.18136 .81065 L
s
.008 w
.18136 .81065 Mdot
.016 w
.18136 .81065 m
.17913 .80836 L
s
1 .085 0 r
.008 w
.17913 .80836 Mdot
.016 w
.17913 .80836 m
.17715 .80614 L
s
.008 w
.17715 .80614 Mdot
.016 w
.17715 .80614 m
.17523 .80405 L
s
1 .084 0 r
.008 w
.17523 .80405 Mdot
.016 w
.17523 .80405 m
.17373 .80222 L
s
.008 w
.17373 .80222 Mdot
.016 w
.17373 .80222 m
.17241 .80049 L
s
1 .083 0 r
.008 w
.17241 .80049 Mdot
.016 w
.17241 .80049 m
.1713 .79891 L
s
.008 w
.1713 .79891 Mdot
.016 w
.1713 .79891 m
.17041 .79755 L
s
1 .082 0 r
.008 w
.17041 .79755 Mdot
.016 w
.17041 .79755 m
.16965 .79631 L
s
.008 w
.16965 .79631 Mdot
.016 w
.16965 .79631 m
.16899 .79518 L
s
1 .081 0 r
.008 w
.16899 .79518 Mdot
.016 w
.16899 .79518 m
.1683 .79412 L
s
.008 w
.1683 .79412 Mdot
.016 w
.1683 .79412 m
.16751 .7931 L
s
1 .08 0 r
.008 w
.16751 .7931 Mdot
.016 w
.16751 .7931 m
.16656 .79204 L
s
.008 w
.16656 .79204 Mdot
.016 w
.16656 .79204 m
.16536 .79088 L
s
1 .079 0 r
.008 w
.16536 .79088 Mdot
.016 w
.16536 .79088 m
.16393 .78959 L
s
.008 w
.16393 .78959 Mdot
.016 w
.16393 .78959 m
.16216 .78809 L
s
1 .078 0 r
.008 w
.16216 .78809 Mdot
.016 w
.16216 .78809 m
.16001 .78632 L
s
.008 w
.16001 .78632 Mdot
.016 w
.16001 .78632 m
.15801 .78444 L
s
1 .077 0 r
.008 w
.15801 .78444 Mdot
.016 w
.15801 .78444 m
.15564 .78231 L
s
.008 w
.15564 .78231 Mdot
.016 w
.15564 .78231 m
.1529 .7801 L
s
1 .076 0 r
.008 w
.1529 .7801 Mdot
.016 w
.1529 .7801 m
.15054 .77784 L
s
.008 w
.15054 .77784 Mdot
.016 w
.15054 .77784 m
.1479 .77542 L
s
1 .075 0 r
.008 w
.1479 .77542 Mdot
.016 w
.1479 .77542 m
.1451 .77288 L
s
.008 w
.1451 .77288 Mdot
.016 w
.1451 .77288 m
.1427 .77055 L
s
1 .074 0 r
.008 w
.1427 .77055 Mdot
.016 w
.1427 .77055 m
.14006 .76805 L
s
.008 w
.14006 .76805 Mdot
.016 w
.14006 .76805 m
.13736 .76544 L
s
1 .073 0 r
.008 w
.13736 .76544 Mdot
.016 w
.13736 .76544 m
.13506 .76285 L
s
.008 w
.13506 .76285 Mdot
.016 w
.13506 .76285 m
.13267 .76031 L
s
1 .072 0 r
.008 w
.13267 .76031 Mdot
.016 w
.13267 .76031 m
.13026 .75775 L
s
.008 w
.13026 .75775 Mdot
.016 w
.13026 .75775 m
.12824 .75545 L
s
1 .071 0 r
.008 w
.12824 .75545 Mdot
.016 w
.12824 .75545 m
.12613 .75314 L
s
.008 w
.12613 .75314 Mdot
.016 w
.12613 .75314 m
.12404 .75088 L
s
1 .07 0 r
.008 w
.12404 .75088 Mdot
.016 w
.12404 .75088 m
.12207 .74868 L
s
.008 w
.12207 .74868 Mdot
.016 w
.12207 .74868 m
.12011 .74654 L
s
1 .069 0 r
.008 w
.12011 .74654 Mdot
.016 w
.12011 .74654 m
.11823 .74441 L
s
.008 w
.11823 .74441 Mdot
.016 w
.11823 .74441 m
.11656 .74261 L
s
1 .068 0 r
.008 w
.11656 .74261 Mdot
.016 w
.11656 .74261 m
.11496 .74092 L
s
.008 w
.11496 .74092 Mdot
.016 w
.11496 .74092 m
.1135 .73938 L
s
1 .067 0 r
.008 w
.1135 .73938 Mdot
.016 w
.1135 .73938 m
.11222 .73802 L
s
.008 w
.11222 .73802 Mdot
.016 w
.11222 .73802 m
.11123 .73688 L
s
1 .066 0 r
.008 w
.11123 .73688 Mdot
.016 w
.11123 .73688 m
.11031 .73587 L
s
.008 w
.11031 .73587 Mdot
.016 w
.11031 .73587 m
.10955 .73495 L
s
1 .065 0 r
.008 w
.10955 .73495 Mdot
.016 w
.10955 .73495 m
.10885 .73399 L
s
.008 w
.10885 .73399 Mdot
.016 w
.10885 .73399 m
.10818 .73292 L
s
1 .064 0 r
.008 w
.10818 .73292 Mdot
.016 w
.10818 .73292 m
.10753 .73174 L
s
.008 w
.10753 .73174 Mdot
.016 w
.10753 .73174 m
.1069 .73044 L
s
1 .063 0 r
.008 w
.1069 .73044 Mdot
.016 w
.1069 .73044 m
.10629 .729 L
s
.008 w
.10629 .729 Mdot
.016 w
.10629 .729 m
.10574 .72759 L
s
1 .062 0 r
.008 w
.10574 .72759 Mdot
.016 w
.10574 .72759 m
.10529 .72606 L
s
.008 w
.10529 .72606 Mdot
.016 w
.10529 .72606 m
.10489 .72458 L
s
1 .061 0 r
.008 w
.10489 .72458 Mdot
.016 w
.10489 .72458 m
.10456 .72321 L
s
.008 w
.10456 .72321 Mdot
.016 w
.10456 .72321 m
.10426 .72194 L
s
1 .06 0 r
.008 w
.10426 .72194 Mdot
.016 w
.10426 .72194 m
.10396 .72058 L
s
.008 w
.10396 .72058 Mdot
.016 w
.10396 .72058 m
.10367 .71936 L
s
1 .059 0 r
.008 w
.10367 .71936 Mdot
.016 w
.10367 .71936 m
.10338 .71815 L
s
.008 w
.10338 .71815 Mdot
.016 w
.10338 .71815 m
.1031 .71697 L
s
1 .058 0 r
.008 w
.1031 .71697 Mdot
.016 w
.1031 .71697 m
.1028 .71577 L
s
.008 w
.1028 .71577 Mdot
.016 w
.1028 .71577 m
.10246 .71452 L
s
1 .057 0 r
.008 w
.10246 .71452 Mdot
.016 w
.10246 .71452 m
.10207 .71318 L
s
.008 w
.10207 .71318 Mdot
.016 w
.10207 .71318 m
.10161 .71161 L
s
1 .056 0 r
.008 w
.10161 .71161 Mdot
.016 w
.10161 .71161 m
.10108 .70979 L
s
.008 w
.10108 .70979 Mdot
.016 w
.10108 .70979 m
.10045 .7077 L
s
1 .055 0 r
.008 w
.10045 .7077 Mdot
.016 w
.10045 .7077 m
.09977 .7057 L
s
.008 w
.09977 .7057 Mdot
.016 w
.09977 .7057 m
.09902 .70329 L
s
1 .054 0 r
.008 w
.09902 .70329 Mdot
.016 w
.09902 .70329 m
.0982 .70068 L
s
.008 w
.0982 .70068 Mdot
.016 w
.0982 .70068 m
.09736 .69784 L
s
1 .053 0 r
.008 w
.09736 .69784 Mdot
.016 w
.09736 .69784 m
.09655 .6948 L
s
.008 w
.09655 .6948 Mdot
.016 w
.09655 .6948 m
.09579 .69186 L
s
1 .052 0 r
.008 w
.09579 .69186 Mdot
.016 w
.09579 .69186 m
.09512 .68897 L
s
.008 w
.09512 .68897 Mdot
.016 w
.09512 .68897 m
.09458 .68601 L
s
1 .051 0 r
.008 w
.09458 .68601 Mdot
.016 w
.09458 .68601 m
.09418 .68333 L
s
.008 w
.09418 .68333 Mdot
.016 w
.09418 .68333 m
.09391 .68088 L
s
1 .05 0 r
.008 w
.09391 .68088 Mdot
.016 w
.09391 .68088 m
.09373 .67851 L
s
.008 w
.09373 .67851 Mdot
.016 w
.09373 .67851 m
.0936 .67628 L
s
1 .049 0 r
.008 w
.0936 .67628 Mdot
.016 w
.0936 .67628 m
.09346 .67419 L
s
.008 w
.09346 .67419 Mdot
.016 w
.09346 .67419 m
.0933 .67221 L
s
1 .048 0 r
.008 w
.0933 .67221 Mdot
.016 w
.0933 .67221 m
.0931 .67025 L
s
.008 w
.0931 .67025 Mdot
.016 w
.0931 .67025 m
.09286 .66842 L
s
1 .047 0 r
.008 w
.09286 .66842 Mdot
.016 w
.09286 .66842 m
.09259 .66656 L
s
.008 w
.09259 .66656 Mdot
.016 w
.09259 .66656 m
.09229 .6647 L
s
1 .046 0 r
.008 w
.09229 .6647 Mdot
.016 w
.09229 .6647 m
.09195 .66279 L
s
.008 w
.09195 .66279 Mdot
.016 w
.09195 .66279 m
.09158 .66091 L
s
1 .045 0 r
.008 w
.09158 .66091 Mdot
.016 w
.09158 .66091 m
.09113 .65882 L
s
.008 w
.09113 .65882 Mdot
.016 w
.09113 .65882 m
.09059 .65658 L
s
1 .044 0 r
.008 w
.09059 .65658 Mdot
.016 w
.09059 .65658 m
.08999 .65401 L
s
.008 w
.08999 .65401 Mdot
.016 w
.08999 .65401 m
.0893 .65143 L
s
1 .043 0 r
.008 w
.0893 .65143 Mdot
.016 w
.0893 .65143 m
.08854 .64846 L
s
.008 w
.08854 .64846 Mdot
.016 w
.08854 .64846 m
.08772 .64527 L
s
1 .042 0 r
.008 w
.08772 .64527 Mdot
.016 w
.08772 .64527 m
.08688 .64193 L
s
.008 w
.08688 .64193 Mdot
.016 w
.08688 .64193 m
.08604 .63855 L
s
1 .041 0 r
.008 w
.08604 .63855 Mdot
.016 w
.08604 .63855 m
.08526 .63474 L
s
.008 w
.08526 .63474 Mdot
.016 w
.08526 .63474 m
.08457 .63134 L
s
1 .04 0 r
.008 w
.08457 .63134 Mdot
.016 w
.08457 .63134 m
.08395 .62778 L
s
.008 w
.08395 .62778 Mdot
.016 w
.08395 .62778 m
.08338 .62413 L
s
1 .039 0 r
.008 w
.08338 .62413 Mdot
.016 w
.08338 .62413 m
.08288 .6211 L
s
.008 w
.08288 .6211 Mdot
.016 w
.08288 .6211 m
.08242 .61809 L
s
1 .038 0 r
.008 w
.08242 .61809 Mdot
.016 w
.08242 .61809 m
.08202 .61538 L
s
.008 w
.08202 .61538 Mdot
.016 w
.08202 .61538 m
.08169 .61308 L
s
1 .037 0 r
.008 w
.08169 .61308 Mdot
.016 w
.08169 .61308 m
.08141 .61107 L
s
.008 w
.08141 .61107 Mdot
.016 w
.08141 .61107 m
.0812 .60958 L
s
1 .036 0 r
.008 w
.0812 .60958 Mdot
.016 w
.0812 .60958 m
.08104 .60844 L
s
.008 w
.08104 .60844 Mdot
.016 w
.08104 .60844 m
.08095 .60764 L
s
1 .035 0 r
.008 w
.08095 .60764 Mdot
.016 w
.08095 .60764 m
.08091 .60711 L
s
.008 w
.08091 .60711 Mdot
.016 w
.08091 .60711 m
.08096 .60683 L
s
1 .034 0 r
.008 w
.08096 .60683 Mdot
.016 w
.08096 .60683 m
.08098 .60672 L
s
.008 w
.08098 .60672 Mdot
.016 w
.08098 .60672 m
.08103 .60674 L
s
1 .033 0 r
.008 w
.08103 .60674 Mdot
.016 w
.08103 .60674 m
.08107 .60685 L
s
.008 w
.08107 .60685 Mdot
.016 w
.08107 .60685 m
.08111 .60695 L
s
1 .032 0 r
.008 w
.08111 .60695 Mdot
.016 w
.08111 .60695 m
.08113 .60704 L
s
.008 w
.08113 .60704 Mdot
.016 w
.08113 .60704 m
.08116 .60704 L
s
1 .031 0 r
.008 w
.08116 .60704 Mdot
.016 w
.08116 .60704 m
.08121 .6069 L
s
.008 w
.08121 .6069 Mdot
.016 w
.08121 .6069 m
.08127 .60657 L
s
1 .03 0 r
.008 w
.08127 .60657 Mdot
.016 w
.08127 .60657 m
.08132 .60606 L
s
.008 w
.08132 .60606 Mdot
.016 w
.08132 .60606 m
.08133 .60535 L
s
1 .029 0 r
.008 w
.08133 .60535 Mdot
.016 w
.08133 .60535 m
.08128 .60439 L
s
.008 w
.08128 .60439 Mdot
.016 w
.08128 .60439 m
.08115 .60326 L
s
1 .028 0 r
.008 w
.08115 .60326 Mdot
.016 w
.08115 .60326 m
.08092 .60178 L
s
.008 w
.08092 .60178 Mdot
.016 w
.08092 .60178 m
.08057 .60001 L
s
1 .027 0 r
.008 w
.08057 .60001 Mdot
.016 w
.08057 .60001 m
.08023 .59785 L
s
.008 w
.08023 .59785 Mdot
.016 w
.08023 .59785 m
.0798 .59542 L
s
1 .026 0 r
.008 w
.0798 .59542 Mdot
.016 w
.0798 .59542 m
.07933 .59254 L
s
.008 w
.07933 .59254 Mdot
.016 w
.07933 .59254 m
.07886 .58958 L
s
1 .025 0 r
.008 w
.07886 .58958 Mdot
.016 w
.07886 .58958 m
.07837 .58616 L
s
.008 w
.07837 .58616 Mdot
.016 w
.07837 .58616 m
.07787 .58259 L
s
1 .024 0 r
.008 w
.07787 .58259 Mdot
.016 w
.07787 .58259 m
.07735 .57878 L
s
.008 w
.07735 .57878 Mdot
.016 w
.07735 .57878 m
.07681 .57474 L
s
1 .023 0 r
.008 w
.07681 .57474 Mdot
.016 w
.07681 .57474 m
.07625 .57065 L
s
.008 w
.07625 .57065 Mdot
.016 w
.07625 .57065 m
.07565 .56683 L
s
1 .022 0 r
.008 w
.07565 .56683 Mdot
.016 w
.07565 .56683 m
.07504 .56285 L
s
.008 w
.07504 .56285 Mdot
.016 w
.07504 .56285 m
.07446 .55904 L
s
1 .021 0 r
.008 w
.07446 .55904 Mdot
.016 w
.07446 .55904 m
.07392 .55584 L
s
.008 w
.07392 .55584 Mdot
.016 w
.07392 .55584 m
.07342 .55292 L
s
1 .02 0 r
.008 w
.07342 .55292 Mdot
.016 w
.07342 .55292 m
.07297 .55043 L
s
.008 w
.07297 .55043 Mdot
.016 w
.07297 .55043 m
.07258 .5483 L
s
1 .019 0 r
.008 w
.07258 .5483 Mdot
.016 w
.07258 .5483 m
.07226 .54678 L
s
.008 w
.07226 .54678 Mdot
.016 w
.07226 .54678 m
.07201 .54563 L
s
1 .018 0 r
.008 w
.07201 .54563 Mdot
.016 w
.07201 .54563 m
.07184 .54485 L
s
.008 w
.07184 .54485 Mdot
.016 w
.07184 .54485 m
.07174 .54435 L
s
1 .017 0 r
.008 w
.07174 .54435 Mdot
.016 w
.07174 .54435 m
.07169 .54408 L
s
.008 w
.07169 .54408 Mdot
.016 w
.07169 .54408 m
.07169 .54389 L
s
1 .016 0 r
.008 w
.07169 .54389 Mdot
.016 w
.07169 .54389 m
.07169 .54362 L
s
.008 w
.07169 .54362 Mdot
.016 w
.07169 .54362 m
.07168 .54319 L
s
1 .015 0 r
.008 w
.07168 .54319 Mdot
.016 w
.07168 .54319 m
.07162 .54256 L
s
.008 w
.07162 .54256 Mdot
.016 w
.07162 .54256 m
.07149 .5418 L
s
1 .014 0 r
.008 w
.07149 .5418 Mdot
.016 w
.07149 .5418 m
.07129 .54066 L
s
.008 w
.07129 .54066 Mdot
.016 w
.07129 .54066 m
.071 .53916 L
s
1 .013 0 r
.008 w
.071 .53916 Mdot
.016 w
.071 .53916 m
.07064 .53711 L
s
.008 w
.07064 .53711 Mdot
.016 w
.07064 .53711 m
.07023 .53467 L
s
1 .012 0 r
.008 w
.07023 .53467 Mdot
.016 w
.07023 .53467 m
.06981 .53207 L
s
.008 w
.06981 .53207 Mdot
.016 w
.06981 .53207 m
.0694 .52901 L
s
1 .011 0 r
.008 w
.0694 .52901 Mdot
.016 w
.0694 .52901 m
.06902 .52606 L
s
.008 w
.06902 .52606 Mdot
.016 w
.06902 .52606 m
.06871 .52235 L
s
1 .01 0 r
.008 w
.06871 .52235 Mdot
.016 w
.06871 .52235 m
.06848 .51922 L
s
.008 w
.06848 .51922 Mdot
.016 w
.06848 .51922 m
.06832 .51587 L
s
1 .009 0 r
.008 w
.06832 .51587 Mdot
.016 w
.06832 .51587 m
.06827 .51225 L
s
.008 w
.06827 .51225 Mdot
.016 w
.06827 .51225 m
.06832 .50859 L
s
1 .008 0 r
.008 w
.06832 .50859 Mdot
.016 w
.06832 .50859 m
.06849 .50458 L
s
.008 w
.06849 .50458 Mdot
.016 w
.06849 .50458 m
.06876 .50098 L
s
1 .007 0 r
.008 w
.06876 .50098 Mdot
.016 w
.06876 .50098 m
.06916 .49721 L
s
.008 w
.06916 .49721 Mdot
.016 w
.06916 .49721 m
.06961 .49352 L
s
1 .006 0 r
.008 w
.06961 .49352 Mdot
.016 w
.06961 .49352 m
.07013 .48999 L
s
.008 w
.07013 .48999 Mdot
.016 w
.07013 .48999 m
.07072 .48676 L
s
1 .005 0 r
.008 w
.07072 .48676 Mdot
.016 w
.07072 .48676 m
.07126 .48369 L
s
.008 w
.07126 .48369 Mdot
.016 w
.07126 .48369 m
.07183 .48111 L
s
1 .004 0 r
.008 w
.07183 .48111 Mdot
.016 w
.07183 .48111 m
.07235 .47878 L
s
.008 w
.07235 .47878 Mdot
.016 w
.07235 .47878 m
.07281 .47682 L
s
1 .003 0 r
.008 w
.07281 .47682 Mdot
.016 w
.07281 .47682 m
.07321 .47534 L
s
.008 w
.07321 .47534 Mdot
.016 w
.07321 .47534 m
.07355 .4742 L
s
1 .002 0 r
.008 w
.07355 .4742 Mdot
.016 w
.07355 .4742 m
.07384 .47341 L
s
.008 w
.07384 .47341 Mdot
.016 w
.07384 .47341 m
.07409 .47295 L
s
1 .001 0 r
.008 w
.07409 .47295 Mdot
.016 w
.07409 .47295 m
.07431 .47272 L
s
.008 w
.07431 .47272 Mdot
.016 w
.07431 .47272 m
.07448 .47267 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0187462 0.0184232 scale
3.97307 29.7848 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195798 0.0192424 scale
4.15581 29.9797 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0252774 0.0248418 scale
3.29029 23.6573 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0361917 0.035568 scale
2.21763 16.7473 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0631935 0.0621045 scale
1.60681 11.7005 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0169566 0.0166644 scale
7.5935 45.4142 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0149543 0.0146966 scale
10.5067 53.7274 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0259016 0.0254553 scale
18.373 37.3334 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0374925 0.0368463 scale
17.4251 25.0223 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0536215 0.0526974 scale
12.1116 17.5244 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0374925 0.0368463 scale
17.6022 25.0131 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0265112 0.0260543 scale
24.5587 35.5189 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0187462 0.0184232 scale
36.5338 49.4372 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0619168 0.0608497 scale
11.1009 14.9626 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.034381 0.0337885 scale
14.4408 27.821 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool006moo`8m
k`Aoo`8mk`03Oolmkcg_00dmka=oo`X007aoo`00KWoo9Sg_47oo1@00Mgoo001XOol]?NlDOol5001b
Ool006IooblmkaUoo`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3001WOol0065ooc<m
kbEoo`<006Aoo`00H7oo7Cg_2Goo23g_;Woo0`00HGoo001NOol@?Nl3Ool<?Nm2Ool2001OOol005]o
o`03000mkcg_00Xmk`03Oolmkcg_00<mk`Eoo`03?Nmoogoo00@mkdMoo`<005aoo`00FGoo00<003g_
?Nl033g_G7oo0P00FWoo001GOol2000;?NmROol2001HOol005Eoo`8000/mkfIoo`8005Ioo`00Dgoo
0P0000=oocg_?Nl02Sg_J7oo0P00E7oo001AOol200000goo?Nlmk`0:?Nm/Ool2001BOol004moo`80
009oo``mkfmoo`80051oo`00CWoo00<007ooOol033g_Lgoo00<007ooOol0CGoo001<Ool200000goo
?Nlmk`0;?NmeOol2001=Ool004]oo`03001oocg_00dmkgQoo`03001oogoo04Yoo`00BGoo0P003cg_
NWoo0P00BWoo0017Ool200000goo?Nlmk`0=?NmmOol20018Ool004Eoo`800003Oolmkcg_00hmkh1o
o`8004Ioo`00A7oo00<007ooOol043g_Pgoo00<007ooOol0@goo0013Ool00`00Oolmk`0A?Nn4Ool0
0`00Oomoo`12Ool0045oo`800003Oolmkcg_00hmkhQoo`80049oo`00@7oo00<007ooOol043g_Rgoo
00<007ooOol0?goo000oOol00`00Oomoo`0;?NnBOol2000oOol003ioo`03001oogoo00TmkiMoo`03
001oogoo03aoo`00?7oo0P0000=oocg_?Nl02Cg_V7oo00<007ooOol0>goo000kOol00`00Oolmk`0<
?NnIOol00`00Oomoo`0jOol003Yoo`03001oocg_00/mkiaoo`8003Yoo`00>Goo00<007oo?Nl02cg_
Wgoo00<007ooOol0=goo000gOol200000goo?Nlmk`0;?NnPOol00`00Oomoo`0fOol003Ioo`03001o
ogoo00dmkj9oo`03001oogoo03Eoo`00=Goo00<007ooOol02Cg_Z7oo00<007ooOol0=7oo000eOol0
0`00Oomoo`09?NnXOol00`00Oomoo`0dOol003Aoo`03001oogoo00XmkjUoo`03001oogoo03=oo`00
<Woo0P000Woo2cg_ZWoo0P00<goo000aOol00`00Oomoo`02Ool;?Nn/Ool00`00Oomoo`0`Ool0031o
o`03001oogoo009oo``mkjeoo`03001oogoo02moo`00;goo00<007ooOol00goo2cg_[goo00<007oo
Ool0;Woo000^Ool00`00Oomoo`03Ool;?NnaOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`Xm
kk9oo`03001oogoo02eoo`00;7oo00<007ooOol017oo2Cg_]Goo00<007ooOol0;7oo000/Ool00`00
Oomoo`03Ool:?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo009oo`03?Nmoocg_00TmkkMoo`03
001oogoo02Yoo`00:Woo00<007ooOol00goo1cg__Goo00<007ooOol0:Goo000YOol00`00Oomoo`04
Ool7?NnnOol00`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`00:7oo
00<007ooOol017oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00Oomo
o`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Woo00<007ooOol017oo2Cg_
`Woo00<007ooOol09Goo000UOol00`00Oomoo`05Ool8?No4Ool00`00Oomoo`0TOol002Aoo`03001o
ogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo00<007ooOol01Goo2Cg_agoo00<007ooOol08Woo
000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03
001oogoo025oo`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomoo`06
Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo
00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo000OOol00`00Oomoo`05Ool7?NoBOol00`00Oomo
o`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo23g_
dgoo00<007ooOol077oo000MOol00`00Oomoo`05Ool9?NoCOol00`00Oomoo`0LOol001aoo`03001o
ogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo
000KOol00`00Oomoo`05Ool:?NoFOol00`00Oomoo`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03
001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_f7oo00<007ooOol06Goo000JOol00`00Oomoo`05
Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001oogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`006Goo
00<007ooOol01Goo23g_g7oo00<007ooOol067oo000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomo
o`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`0067oo00<007ooOol017oo1cg_
h7oo00<007ooOol05goo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Moo`03001o
ogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo00<007ooOol01Goo23g_hWoo00<007ooOol05Goo
000FOol00`00Oomoo`05Ool7?NoSOol00`00Oomoo`0EOol001Eoo`03001oogoo00Ioo`HmknEoo`03
001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_iGoo00<007ooOol057oo000DOol00`00Oomoo`06
Ool6?NoWOol00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo
00<007ooOol01Woo1Cg_j7oo00<007ooOol04goo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomo
o`0BOol001=oo`03001oogoo00Ioo`HmknUoo`03001oogoo019oo`004goo00<007ooOol01Woo1Cg_
jWoo00<007ooOol04Woo000COol00`00Oomoo`06Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001o
ogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Sg_jgoo00<007ooOol04Goo
000BOol00`00Oomoo`06Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Dmkneoo`03
001oogoo011oo`004Goo00<007ooOol01goo1Sg_k7oo00<007ooOol047oo000AOol00`00Oomoo`07
Ool6?No]Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo
00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomo
o`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`003goo00<007ooOol02Goo1Cg_
kgoo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool5?No_Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00Uoo`@mko1oo`03001oogoo00ioo`003goo00<007ooOol02Goo13g_l7oo00<007ooOol03Woo
000?Ool00`00Oomoo`09Ool4?No`Ool00`00Oomoo`0>Ool000ioo`03001oogoo00Yoo`@mko5oo`03
001oogoo00eoo`003Woo00<007ooOol02Woo13g_lGoo00<007ooOol03Goo000>Ool00`00Oomoo`3o
Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo
0Goo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo
0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00
Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo
00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool0
00eoo`03001oogoo00Uoo`Dmko=oo`03001oogoo00aoo`003Goo00<007ooOol027oo1Sg_1Goo1Cg_
jGoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool6?Nl5Ool6?NoXOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Qoo`Hmk`Eoo`HmknQoo`03001oogoo00aoo`0037oo00<007ooOol02Goo17`00Sg_
1Goo1cg_j7oo00<007ooOol02goo000<Ool00`00Oomoo`09Ool4O005?Nl3Ool6?NoXOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Qoo`03?Nml07`0009l010mknIoo`03001oogoo00]oo`0037oo00<0
07ooOol027oo1W`03cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5O00@?NoVOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Qoo`El0003On0mkcg_00dmknIoo`03001oogoo00]oo`0037oo
00<007ooOol027oo17`00goP1goo1cg_iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool4O002
On0:Ool6?NoUOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Al009oh0Yoo`HmknEoo`03001o
ogoo00]oo`0037oo00<007ooOol027oo17`000=oh7ooOol02Goo1cg_i7oo00<007ooOol02goo000<
Ool00`00Oomoo`07Ool6O00;Ool7?NoTOol00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`El0003
On1oogoo00Uoo`Xmkn5oo`03001oogoo00]oo`0037oo00<007ooOol01goo1G`037oo2Sg_hGoo00<0
07ooOol02goo000<Ool00`00Oomoo`07Ool5O00<Ool;?NoPOol00`00Oomoo`0;Ool000eoo`03001o
ogoo00Ioo`Il00aoo`Xmkn1oo`03001oogoo00]oo`003Goo00<007ooOol01Woo1G`047oo23g_gWoo
00<007ooOol037oo000=Ool00`00Oomoo`06Ool00goPO01l0002O00@Ool8?NoNOol00`00Oomoo`0<
Ool000eoo`03001oogoo00Ioo`03On1l000000@000ioo`Pmkmioo`03001oogoo00aoo`003Goo00<0
07ooOol01Woo00=oh000O0000W`000<mkgoo00003Goo2Cg_gGoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool00goP001l0002O00013g_Oomoo`0037oo2Cg_gGoo00<007ooOol037oo000=Ool00`00
Oomoo`06Ool00`00O01l0002O0001GoPOomoogoo000037oo23g_gGoo00<007ooOol037oo000=Ool0
0`00Oomoo`06Ool00`00O01l0003O003Ool00`00Oomoo`0:Ool8?NoMOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Eoo`03001oog`000El009oo`03001oogoo00Yoo`Xmkm]oo`03001oogoo00aoo`00
3Goo00<007ooOol01Goo00<007ooO00017`00goo00<007ooOol02goo2Sg_fWoo00<007ooOol037oo
000=Ool00`00Oomoo`05Ool00`00Oomoo`04O003Ool00`00Oomoo`0<Ool9?NoJOol00`00Oomoo`0<
Ool000ioo`03001oogoo00Eoo`04001oog`0O006000?Ool7?NoKOol00`00Oomoo`0<Ool000ioo`03
001oogoo00Eoo``000eoo`Dmkmaoo`03001oogoo00eoo`003Woo00<007ooOol01Goo1`000Woo1000
kGoo00<007ooOol03Goo000>Ool00`00Oomoo`04Ool01000Ool000001G`00goo0`00k7oo00<007oo
Ool03Goo000>Ool00`00Oomoo`03Ool01000Oomoo`001G`000Ao`7ooOomoo`<00>aoo`03001oogoo
00eoo`003goo00<007ooOol00Woo00D007oo000007oo00Al0006Oj1oogooOol007oo0P00jWoo00<0
07ooOol03Woo000?Ool01@00Oomoogoo00000Woo0P0000=oog`0O0000W`00WnP0Woo00D007oo001o
o`000>Uoo`03001oogoo00ioo`003goo00D007ooOomoo`00009oo`800003Ooml07`0009l009oX09o
o`05001oo`00Ool0003YOol00`00Oomoo`0>Ool000moo`04001oogoo0003Ool00`00Ool00005O000
1WnPOomoo`00Ool0009oo`03001oogoo0>Ioo`03001oogoo00ioo`003goo00@007ooOol000=oo`04
001oogoo0005O0020002Ool01000Oomoo`00j7oo00<007ooOol03Woo000@Ool00`00Ool00003Ool0
1000Oomoog`01@0017oo00@007ooOol00>Moo`03001oogoo00moo`0047oo00<007oo000017oo00<0
07ooOj0017`01Goo00@007ooOol00>Moo`03001oogoo00moo`0047oo00<007oo000017oo00<007oo
Oj0017`017oo00@007ooOol00>Qoo`03001oogoo00moo`0047oo00<007oo00001Goo0P0017`00Woo
0P000goo00<007ooOol0iWoo00<007ooOol03goo000AOol00`00Ool00005Ool00cg_00000002O002
0005Ool00`00Oomoo`3VOol00`00Oomoo`0?Ool0015oo`03001oo`0000Ioo`9l0080008mk`Eoo`03
001oogoo0>Eoo`03001oogoo011oo`004Goo00@007ooOol000Eoo`Al808mk`Aoo`03001oogoo0>Io
o`03001oogoo011oo`004Woo00@007oo000000Aoo`El80=oo`800>Uoo`03001oogoo011oo`004Woo
00@007ooOomoo`80009oo`Il80800>Yoo`03001oogoo015oo`004Woo00<007ooOol00goo0P0017`P
0P00k7oo00<007ooOol04Goo000COol00`00Oomoo`04Ool400000g`POomoo`3[Ool00`00Oomoo`0A
Ool001=oo`03001oogoo00Eoo`Al8003?Nmoogoo0>Uoo`03001oogoo019oo`004goo00<007ooOol0
1Goo1G`Pjgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool6O23ZOol00`00Oomoo`0BOol001Ao
o`03001oogoo00Aoo`El8003?Nmoogoo0>Moo`03001oogoo01=oo`0057oo00<007ooOol017oo00=o
H7`PO2000W`P00=oH7ooOol0igoo00<007ooOol04goo000DOol00`00Oomoo`04Ool00gmPO21l8003
O23YOol00`00Oomoo`0COol001Eoo`03001oogoo00Aoo`Il8>Moo`03001oogoo01Aoo`005Goo00<0
07ooOol017oo1G`Pj7oo00<007ooOol057oo000FOol00`00Oomoo`03Ool00gmP00000007003ROol0
0`00Oomoo`0EOol001Ioo`04001oogooOol30004O205Ool4003NOol00`00Oomoo`0EOol001Moo`03
001oo`00009oo`03Of1l87`P009l80Uoo`03001oogoo0=Yoo`03001oogoo01Ioo`005goo0P000goo
00=oH7`PO2000g`P2Goo00<007ooOol0fGoo00<007ooOol05Woo000FOol00`00Ool00003Ool00gmP
O21l8003O20:Ool00`00Oomoo`3GOol00`00Oomoo`0GOol001Eoo`04001oogoo0003Ool00gmPO21l
8003O20;Ool2003GOol00`00Oomoo`0GOol001Eoo`04001oogoo0004Ool5O20=Ool00`00Oomoo`3D
Ool00`00Oomoo`0GOol001Aoo`03001oogoo009oo`05001oogooOomoH004O2000cg_Oomoo`0;Ool0
0`00Oomoo`3BOol00`00Oomoo`0HOol001=oo`03001oogoo00=oo`05001oogooOomoH004O202?Nl<
Ool00`00Oomoo`3BOol00`00Oomoo`0HOol001=oo`03001oogoo00Aoo`04001oogooOf05O2000cg_
Oomoo`0;Ool00`00Oomoo`3@Ool00`00Oomoo`0IOol0019oo`03001oogoo00Eoo`04001oogooOol6
O20>Ool00`00Oomoo`3?Ool00`00Oomoo`0IOol0015oo`03001oogoo00Moo`03001oogoo00El8003
?Nmoogoo00aoo`03001oogoo0<ioo`03001oogoo01Yoo`004Goo00<007ooOol01goo00@007ooOomo
H0El80ioo`03001oogoo0<ioo`03001oogoo01Yoo`004Goo00<007ooOol027oo00<007ooOf001W`P
3Woo00<007ooOol0c7oo00<007ooOol06goo000@Ool00`00Oomoo`09Ool00`00Oomoo`05O20?Ool0
0`00Oomoo`3<Ool00`00Oomoo`0KOol0011oo`03001oogoo00Yoo`03001oogmP00El80ioo`03001o
ogoo0<]oo`03001oogoo01aoo`0047oo00<007ooOol02Woo00<007ooOf001G`P3Woo00<007ooOol0
bgoo00<007ooOol077oo000@Ool00`00Oomoo`0;Ool00`00Of1l8004O2000gm0Oomoo`0;Ool00`00
Oomoo`3:Ool00`00Oomoo`0MOol0011oo`03001oogoo00]oo`03001oH7`P00Al8003O41o@7oo00]o
o`03001oogoo0<Yoo`03001oogoo01eoo`0047oo00<007ooOol037oo00=oH7m0O2000g`P0Wa037oo
00<007ooOol0bGoo00<007ooOol07Woo000@Ool00`00Oomoo`0<Ool00`00Od1l@006O40;Ool00`00
Oomoo`39Ool00`00Oomoo`0NOol0015oo`03001oogoo00aoo`03001l@7a000Al@0H000Ioo`03001o
ogoo0<Qoo`03001oogoo01moo`004Goo00<007ooOol03Goo00<007a0O4000Wa000<007a0O40017oo
00<007ooOol00Woo00<007ooOol0b7oo00<007ooOol087oo000AOol00`00Oomoo`0>Ool017l0O41l
@00017a017oo00D007ooOomoo`000<Uoo`03001oogoo025oo`004Woo00<007ooOol03Goo00@007l0
O40000El@0=oo`05001oogooOol00039Ool00`00Oomoo`0QOol001=oo`03001oogoo00eoo`8000Ml
@09oo`04001oogoo0039Ool00`00Oomoo`0ROol001=oo`03001oogoo00ioo`800003O`1l@7a000Al
@005Ool007ooOol00038Ool00`00Oomoo`0SOol001Aoo`03001oogoo00eoo`800003O`1l@7a000Al
@004000mkgoo0039Ool00`00Oomoo`0SOol001Aoo`03001oogoo00ioo`8000Il@003001l@0000<Uo
o`03001oogoo02Aoo`005Goo00<007ooOol03Woo0`000ga000@007a0001l@0<mklEoo`03001oogoo
02Eoo`005Woo00<007ooOol03Woo00<007oo000010000Wa00P000Sg_`goo00<007ooOol09Woo000G
Ool00`00Oomoo`0>Ool01000Oomnh0000Wa00P000Wa00P00`Woo00<007ooOol09goo000HOol2000>
Ool30002O^000ga0001l@004O4000`00Oomoo`2oOol00`00Oomoo`0WOol001Yoo`@000Qoo`@000=o
o`03001l@7a000Al@003001oogoo0;ioo`03001oogoo02Qoo`007Woo200017oo00D007ooOol007k0
00Il@003001oogoo0;aoo`03001oogoo02Uoo`00:goo00@007oo001n`0Il@003001l@7oo0;]oo`03
001oogoo02Yoo`00;7oo00@007oo001n`0Al@003001l@7a00;]oo`03001oogoo02]oo`00;7oo00D0
07oo000007k0009l@08000=l@;Yoo`03001oogoo02]oo`00;Goo00<007ooOol00`001Wa0^7oo00<0
07ooOol0;7oo000^Ool00`00Oomoo`02O/07O42fOol00`00Oomoo`0]Ool002moo`04001oogooOol8
O4000cg_Oomoo`2aOol00`00Oomoo`0^Ool0031oo`04001oogooO/08O42bOol00`00Oomoo`0_Ool0
035oo`05001oogooOolmk`07O42`Ool00`00Oomoo`0`Ool0039oo`04001oogooOol8O42^Ool00`00
Oomoo`0aOol003=oo`03001oogoo009oo`Ml@:aoo`03001oogoo039oo`00=7oo00@007ooOomoo`Ql
@:Yoo`03001oogoo03=oo`00=Goo00@007ooOomoo`Ql@:Qoo`03001oogoo03Aoo`00=Woo00@007oo
Oomoo`Ql@:Ioo`03001oogoo03Eoo`00=goo00@007ooOomoo`Ql@:Aoo`03001oogoo03Ioo`00>7oo
00@007ooOomoo`9n`0Il@:9oo`03001oogoo03Moo`00>Goo0P000Woo00=n`7a0O4001Ga000=lH7oo
Ool0W7oo0P00>Woo000kOol00`00Oomoo`08O4000gaPOomoo`1eOol;000JOol00`00Oomoo`0jOol0
03aoo`05001oogoo?Nmn`004O403O61dOol2000;Ool00`00Oomoo`0FOol00`00Oomoo`0kOol003eo
o`05001oogoo?Nmn`002O405O6000cg_Oomoo`1^Ool2000>Ool2000EOol00`00Oomoo`0lOol003io
o`80009oo`UlH6eoo`80019oo`80015oo`8003moo`00@7oo00<007ooO/000Wk01gaPJgoo00<007oo
Ool057oo00<007ooOol03Goo00<007ooOol0?goo0011Ool20003O/07O61YOol00`00Oomoo`0EOol0
0`00Oomoo`0;Ool20012Ool004=oo`04001n`7k0O/08O61TOol;000;Ool5O>000goo001oo`0:Ool0
0`00Oomoo`12Ool004Aoo`03001n`7k000YlH65oo`03001oo`0000Uoo`8000Uoo`Elh003O@1oo`00
00Uoo`03001oogoo04=oo`00AGoo0P000gjP2GaPGGoo0P000Woo00<007ooOol02Goo00<007ooOol0
1Goo1WcP00Am07ooOol000Ioo`8004Ioo`00Agoo0P0000=nX7aPO6002GaPFGoo0P000goo00<007oo
Ool01Goo0`000goo00<007ooOol017oo1WcP00Em07ooOomoo`0000=oo`8004Qoo`00BGoo00<007jP
O6002gaP00=oocg_?Nl0Dgoo00<007ooOol00goo00<007oo00002P000Woo00@007ooOomoo`Mlh09m
00=oo`04001oo`00001:Ool004]oo`9nX0]lH08mk`03O61oogoo04moo`03001oogoo00=oo`D000Mo
o`<0009oo`03001lh7cP00Mlh003O@1oogoo00=oo`03001oogoo04Yoo`00C7oo0gjP3GaP00<mkgoo
Ool0CGoo00<007ooOol00goo00<007oo00002Woo1`001WcP00=m07ooOol00Woo0`00C7oo001>Ool3
OZ0>O6000gooO61oo`19Ool00`00Oomoo`04Ool20004Ool30003Ool01`00Oomoo`00O>0007cP0080
00Alh004O@1oogooOol20002Ool00`00Oomoo`1:Ool0051oo`=nX0mlH003OomlH7oo00ioo`03?Nmo
ogoo03Eoo`03001oogoo00=oo`<00004Ool000000003Ool30003Ool00gcP001lh002000017cP001l
h7cP17oo00<007ooOol00Woo00<007ooOol0BWoo001AOol20002OZ0AO60<Ool2?NlHOol5000JOol0
0`00Oomoo`02Ool01@00Ool007oo000027oo00<007ooO>000WcP00@007cP001lh080009m009oo`80
00Eoo`03001oogoo04Yoo`00Dgoo0P0000AoogjPOZ1nX0ilH003OomlH7oo00Ioo`DmkaEoo`8000Eo
o`8001Moo`03001oogoo00=oo`@000Qoo`03OB00000000Alh003001lh00000800004O@1oo`000007
Ool00`00Oomoo`1:Ool005Eoo`800004OomnX7jPOZ0?O6000gooO61oo`03Ool5?NlDOol00`00Oomo
o`07Ool00`00Oomoo`0DOol00`00Oomoo`02Ool01000Ool000001Goo00=m87d0O>000WcP00<007cP
00000gcP00<007cP000010002Goo00<007ooOol0BWoo001GOol20002Ool4OZ0?O607?NlCOol00`00
Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`03Ool01000Ool000000Woo00An@7cPO>1m80Alh003
001lh00000=lh005001m0000OF00000;Ool00`00Oomoo`1:Ool005Uoo`8000Aoo`=nX0mlH003O80m
kcg_008mka5oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00=oo`06001oo`00001lh7i0
2GcP0P000gcP00<007f000000P002goo00<007ooOol0BWoo001KOol30004Ool2OX0?O602?Nl00gb0
Oomoo`0?Ool4000;Ool00`00Oomoo`0@Ool00`00Oomoo`02O<000gi0001oo`02000;O>0300001ge0
OH0007oo001oo`0000]oo`03001oogoo04Yoo`00GWoo0`0017oo0Wj037aP17b000=oogb0Ool02goo
0`000goo0P002Woo00<007ooOol01Woo0Wc000=n@7ooOol00goo00=n@000Ool017c000@007c00000
00alh004OH000000Ool300000goo001oo`0:Ool00`00Oomoo`1:Ool0065oo`<000Aoo`9nP0UlH0Ml
P09oo`03O81oogoo00Eoo`8000Moo`03001oogoo00Moo`03001oogoo009oo`9l`003Ooml`7c000Ql
`003001l`7c000=l`004001l`0000009O>001WfP001oogoo001oo`800004Ool00000000;Ool00`00
Oomoo`1:Ool006Aoo`<000Aoo`9nP0IlH0]lP0Eoo`03001oo`0000Eoo`=lX003001lX7c000=oo`9l
`005Ool007ooOomnH00>O<000`00O<1l`003O<000`00O<0000020004O>02OJ000ggPOomoo`02Ool0
1000Oomoogoo0P0000=oo`00Ool02Woo00<007ooOol0Bgoo001WOol30004Ool2OX0BO8001000O81l
P0000cg_0Wb000MlX7b0O81lP000O81lX005O<000`00O<1l`00@O<000`00O<1l`003O<001@00O>00
0000Ool00`001goo00@007ooOomoo`800003Ool007oo00Uoo`03001oogoo04aoo`00JWoo0`0017oo
0gj03Wb000@007b0O800008mk`MlP003001lP7bP00El`003001l`7c0011l`004001l`7c0O<02OT00
0`00Ool000020009Ool01000Oomoogoo0P000Woo00<007ooOol027oo00<007ooOol0C7oo001]Ool5
00000gooOX1nP002OX0:O8001@00O81lP7b000002Gb000<007b0O:001Gc000<007c0O<0027c027i0
00<007ooOol01@0000Aoo`00000000Moo`80009oo`03001oo`00009oo`03001oogoo00Moo`03001o
ogoo04eoo`00LWoo10001Gj01Wb000D007b0O81lP00000UlP003001lP7bP00El`003001l`7c000Al
`09n@0Qoo`D000Eoo`03001oo`00008000=oo`<000=oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo04ioo`00Mgoo0`001gj000D007b0O81lP00000UlP003001l`7c000Al`003OV0007iP00=n
H0Moo`D000=oo`03001oogoo00Eoo`L000Aoo`@0009oo`03001oogoo00Moo`03001oogoo04moo`00
O7oo1Wj000D007b0O81lP00000AlP0AnH003001nH7iP00=nH09oo`04001oogooOol80009Ool00`00
Oomoo`06Ool600000goo000000020003Ool00`00Oomoo`07Ool00`00Oomoo`1@Ool0085oo`03OX00
07j0009nP003OV0007iP00=nH0l0019oo`03001oogoo00Moo`L000Aoo`03001oogoo00Qoo`03001o
ogoo051oo`00Pgoo00D007ooOomoo`0000Ioo`03001oogoo00=oo`8001Qoo`03001oogoo00Uoo`03
001oogoo00Aoo`03001oogoo00Ioo`<005=oo`00Pgoo00<007ooOol00Woo0P000goo00<007ooOol0
0Woo0P006goo0P002Woo100000=oo`00Ool01Woo0P00EWoo0024Ool00`00Oomoo`03Ool30004Ool0
0`00Oomoo`0MOol3000:Ool:001HOol008Eoo``002=oo`<000=oo`@0069oo`00]goo0`00IWoo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002=Ool3002@Ool008eoo`04001oogoo002?
Ool008eoo`04001oogoo002?Ool008eoo`<0091oo`00SWoo00<007ooOol0Sgoo002>Ool3002?Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.651, 1.30024, \
1.32304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.482365 0.00269739 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(7)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.458556 scale
1.05 1.05193 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .38159 m
.08448 .38147 L
.08463 .38128 L
.08481 .38102 L
.08501 .38069 L
.08522 .38027 L
.08542 .37975 L
.08562 .37915 L
.08581 .3785 L
.08602 .37777 L
.08626 .37695 L
.08654 .37607 L
.08686 .37516 L
.08716 .37423 L
.08743 .3733 L
.08772 .37241 L
.088 .37158 L
.08829 .37075 L
.08859 .36991 L
.08891 .36903 L
.08923 .36811 L
.08951 .3672 L
.08973 .36624 L
.08987 .36522 L
.08993 .36413 L
.0899 .36307 L
.08981 .3619 L
.08971 .36075 L
.08963 .35956 L
.08956 .35831 L
.08951 .35703 L
.0895 .35585 L
.0895 .35469 L
.08949 .3536 L
.08949 .35265 L
.08952 .3518 L
.08958 .35108 L
.08969 .35044 L
.08983 .34986 L
.09 .34927 L
.09019 .34863 L
.09037 .34791 L
.09055 .34708 L
.09073 .3461 L
.09096 .34497 L
.09126 .3439 L
.09164 .34262 L
.0921 .34128 L
.09264 .3397 L
.09322 .33822 L
Mistroke
.09382 .33652 L
.09442 .33465 L
.09499 .33291 L
.09554 .33111 L
.09606 .32935 L
.09658 .32762 L
.09711 .32622 L
.09765 .32481 L
.09819 .32353 L
.09867 .32246 L
.09908 .32146 L
.09941 .32066 L
.09966 .32001 L
.09987 .31952 L
.10005 .3192 L
.10024 .31904 L
.10045 .31904 L
.10063 .31915 L
.10076 .31932 L
.10083 .31949 L
.10083 .31961 L
.10076 .31962 L
.10062 .31948 L
.10043 .3192 L
.10021 .31876 L
.09997 .31818 L
.09971 .31747 L
.09945 .31666 L
.09919 .31587 L
.09893 .31499 L
.09868 .31405 L
.09844 .31308 L
.09823 .31226 L
.09807 .31152 L
.09794 .31092 L
.09785 .31054 L
.09779 .3104 L
.09776 .31052 L
.09778 .31087 L
.09782 .31136 L
.09787 .31193 L
.09794 .3125 L
.09806 .313 L
.09823 .31341 L
.09845 .31369 L
.09873 .3138 L
.09906 .31375 L
.09944 .31352 L
.09988 .31311 L
.10037 .31254 L
Mistroke
.1009 .31186 L
.10147 .31107 L
.10202 .31019 L
.10254 .30928 L
.10305 .30845 L
.10353 .30776 L
.10397 .30717 L
.10439 .30666 L
.10479 .30622 L
.10519 .30581 L
.1056 .30542 L
.10604 .305 L
.10652 .3045 L
.10703 .30391 L
.10757 .30319 L
.10816 .30231 L
.1088 .30124 L
.10946 .30011 L
.11008 .29872 L
.1107 .29716 L
.11132 .29564 L
.11189 .29397 L
.11238 .29229 L
.11278 .29063 L
.1131 .28913 L
.11332 .28773 L
.11347 .28648 L
.11356 .28547 L
.11358 .28461 L
.11356 .28388 L
.11352 .2833 L
.11346 .28286 L
.1134 .28257 L
.11333 .28242 L
.11327 .28239 L
.11321 .28246 L
.11316 .28261 L
.11312 .28279 L
.11309 .28295 L
.11309 .28307 L
.11315 .28313 L
.11331 .2831 L
.11361 .28298 L
.11404 .28273 L
.11463 .28234 L
.11536 .28185 L
.11625 .28122 L
.11731 .28046 L
.11842 .2796 L
.11967 .27867 L
Mistroke
.12087 .27767 L
.12212 .27664 L
.12336 .27564 L
.12444 .27478 L
.12548 .27405 L
.12644 .27345 L
.12728 .27296 L
.12797 .27258 L
.12853 .27227 L
.129 .27195 L
.12937 .27161 L
.12968 .2712 L
.12996 .27069 L
.13026 .27009 L
.13061 .26937 L
.131 .26853 L
.13143 .26767 L
.13189 .26673 L
.13238 .26575 L
.13287 .26474 L
.13336 .26381 L
.13384 .26294 L
.13429 .26219 L
.1347 .2616 L
.13507 .26118 L
.13539 .26087 L
.13564 .26062 L
.13582 .2604 L
.13594 .26013 L
.13603 .25975 L
.1361 .25924 L
.13619 .25858 L
.13631 .2578 L
.13647 .25695 L
.13664 .2562 L
.13684 .25517 L
.13706 .25421 L
.13727 .25317 L
.13747 .25205 L
.13764 .25085 L
.13778 .24967 L
.13789 .24843 L
.13801 .24715 L
.13814 .2458 L
.1383 .24459 L
.13846 .24318 L
.13867 .24174 L
.13892 .24024 L
.13923 .23867 L
.13964 .23698 L
Mistroke
.14014 .23553 L
.14076 .23409 L
.1415 .23268 L
.14228 .23137 L
.14313 .23018 L
.14402 .22903 L
.14494 .2279 L
.14581 .22682 L
.14671 .22569 L
.1476 .22461 L
.14857 .22356 L
.14952 .22248 L
.15056 .22137 L
.15171 .22024 L
.15289 .21912 L
.15413 .21793 L
.1554 .21675 L
.15654 .21556 L
.15766 .21438 L
.15872 .21325 L
.15972 .21229 L
.16067 .21133 L
.16146 .21045 L
.16215 .20976 L
.1627 .20917 L
.16311 .20866 L
.16339 .20822 L
.16351 .20785 L
.16352 .20752 L
.16346 .20721 L
.16339 .20687 L
.16332 .20648 L
.16328 .20599 L
.16326 .20543 L
.16326 .20489 L
.16324 .20445 L
.16318 .20408 L
.16308 .20385 L
.16294 .20384 L
.16275 .20405 L
.16251 .20449 L
.16224 .20514 L
.16195 .20596 L
.16165 .2068 L
.16137 .20788 L
.1611 .20886 L
.16088 .20984 L
.16072 .21074 L
.16066 .21148 L
.16071 .21202 L
Mistroke
.16091 .21236 L
.16125 .21251 L
.16173 .21254 L
.16232 .21249 L
.16302 .21239 L
.1638 .21228 L
.16461 .21222 L
.16534 .21219 L
.16601 .21221 L
.16657 .21222 L
.16697 .21223 L
.16721 .21223 L
.16727 .21223 L
.16717 .2122 L
.16698 .21214 L
.16672 .21205 L
.16633 .21195 L
.16586 .21183 L
.16527 .21174 L
.16457 .21172 L
.1638 .21179 L
.16296 .21198 L
.16206 .21231 L
.1611 .21282 L
.16008 .21351 L
.15901 .21441 L
.15802 .21548 L
.15693 .21676 L
.15568 .21824 L
.15413 .21985 L
.15273 .22142 L
.15127 .2231 L
.14976 .22485 L
.14833 .22654 L
.14687 .22808 L
.14544 .22959 L
.14415 .23109 L
.14295 .23244 L
.14174 .23381 L
.14051 .23522 L
.13927 .2367 L
.1381 .23817 L
.137 .23973 L
.13592 .24146 L
.13488 .24333 L
.13392 .24512 L
.13302 .24713 L
.13217 .24908 L
.13136 .25107 L
.13065 .25292 L
Mistroke
.13006 .25452 L
.12958 .25597 L
.12923 .25722 L
.12897 .25816 L
.12877 .2589 L
.12859 .25949 L
.12841 .25994 L
.12819 .26029 L
.12788 .26061 L
.12747 .26094 L
.12697 .26129 L
.12639 .26167 L
.12573 .26211 L
.12509 .2626 L
.12428 .26325 L
.1235 .26397 L
.12264 .26482 L
.12172 .26578 L
.12078 .26683 L
.11987 .26796 L
.119 .26918 L
.11823 .27036 L
.11745 .27162 L
.1167 .27292 L
.11598 .27425 L
.11528 .27555 L
.11457 .27695 L
.11392 .27845 L
.11341 .27996 L
.11302 .2814 L
.11269 .2828 L
.11239 .28419 L
.11208 .28533 L
.11172 .28653 L
.11124 .28763 L
.11062 .2888 L
.10995 .29004 L
.10908 .29124 L
.10808 .29247 L
.107 .29372 L
.10597 .29499 L
.10488 .29628 L
.10369 .29747 L
.10243 .29868 L
.10117 .29995 L
.10008 .30127 L
.09911 .30252 L
.09828 .30383 L
.09758 .30519 L
.09701 .30658 L
Mistroke
.09655 .3079 L
.09619 .30919 L
.09591 .31051 L
.09569 .31189 L
.09552 .3133 L
.09537 .31475 L
.09524 .31626 L
.09508 .31777 L
.0949 .31914 L
.0947 .32038 L
.09451 .32148 L
.09433 .32244 L
.09413 .32328 L
.09389 .32399 L
.09362 .32461 L
.09333 .32517 L
.09303 .32569 L
.09274 .32621 L
.09247 .32677 L
.09221 .32741 L
.09195 .32818 L
.09169 .32913 L
.09142 .33021 L
.0911 .33145 L
.09072 .33291 L
.09028 .33466 L
.0898 .33646 L
.08933 .33848 L
.08888 .34066 L
.08848 .3426 L
.08811 .34484 L
.08775 .34685 L
.08741 .34902 L
.08708 .35138 L
.08674 .35376 L
.08641 .35587 L
.0861 .35805 L
.08582 .36037 L
.08559 .36273 L
.08541 .36472 L
.08524 .36685 L
.08507 .36889 L
.08492 .37086 L
.08477 .37276 L
.08464 .37443 L
.08451 .37595 L
.08444 .37723 L
.08441 .37832 L
.0844 .37921 L
.08442 .37991 L
Mistroke
.08445 .38046 L
.08447 .38089 L
.08447 .38128 L
.08447 .38168 L
.08446 .38213 L
.08445 .38267 L
.08444 .38332 L
.08443 .38411 L
.08441 .38492 L
.08439 .38583 L
.08438 .38682 L
.08436 .38787 L
.08434 .38892 L
.08432 .38984 L
.08431 .39068 L
.0843 .39143 L
.08429 .39204 L
.08428 .3925 L
.08427 .39278 L
Mfstroke
.0843 .3925 m
.08431 .39234 L
.08431 .39212 L
.08429 .39186 L
.08426 .3915 L
.08422 .39124 L
.08421 .39083 L
.08422 .3904 L
.08427 .38991 L
.08436 .38925 L
.08451 .3886 L
.08473 .38807 L
.08498 .38734 L
.08526 .38663 L
.08553 .38587 L
.08578 .38502 L
.08603 .384 L
.08628 .38315 L
.08654 .38226 L
.08679 .38123 L
.087 .38006 L
.08714 .3789 L
.08722 .37794 L
.08725 .3769 L
.08726 .37582 L
.08724 .37488 L
.08721 .37396 L
.0872 .37309 L
.08721 .37235 L
.08722 .37176 L
.08723 .37125 L
.08723 .37082 L
.08723 .37048 L
.08724 .37025 L
.08724 .37012 L
.08724 .37006 L
.08724 .37004 L
.08724 .37007 L
.08724 .37013 L
.08724 .37021 L
.08724 .37027 L
.08724 .3703 L
.08724 .3703 L
.08724 .3703 L
.08723 .37032 L
.08723 .37036 L
.08723 .37043 L
.08723 .37049 L
.0872 .37051 L
.08716 .37049 L
Mistroke
.08713 .3704 L
.08712 .37024 L
.08714 .36997 L
.0872 .36963 L
.08731 .36922 L
.08747 .36878 L
.08768 .36831 L
.08794 .36784 L
.08825 .36738 L
.08859 .36692 L
.08888 .36648 L
.08913 .36608 L
.08937 .3658 L
.08961 .36566 L
.08978 .3657 L
.08982 .3659 L
.08972 .36623 L
.08952 .36665 L
.08926 .36714 L
.08897 .36764 L
.08865 .36801 L
.08835 .36828 L
.08806 .36859 L
.0878 .36896 L
.0876 .36937 L
.08744 .36976 L
.08732 .37012 L
.08724 .3705 L
.08718 .37099 L
.08708 .37169 L
.08694 .3726 L
.08675 .3737 L
.08648 .37493 L
.08625 .37616 L
.08595 .37781 L
.08567 .37996 L
.08542 .38158 L
.08515 .38386 L
.08487 .38568 L
.08461 .38765 L
.0844 .38973 L
.08427 .39119 L
.08419 .39274 L
.08414 .39419 L
.08413 .39516 L
.08415 .39594 L
.08417 .39657 L
.08419 .39702 L
.08419 .39728 L
Mfstroke
.11421 .45247 m
.11439 .45256 L
.11462 .45269 L
.1149 .45286 L
.11523 .45305 L
.11562 .45329 L
.11603 .45357 L
.11655 .45396 L
.11707 .45441 L
.11765 .45497 L
.11831 .45566 L
.11899 .45642 L
.11961 .45713 L
.12027 .45795 L
.12087 .45876 L
.12145 .45958 L
.12199 .46037 L
.1225 .46112 L
.12298 .46175 L
.12341 .46231 L
.1238 .4628 L
.12411 .46318 L
.12431 .46343 L
.1244 .46357 L
.12438 .46367 L
.1243 .46383 L
.12419 .46407 L
.12409 .46439 L
.12404 .4648 L
.12408 .46531 L
.12425 .46591 L
.12456 .46654 L
.12501 .46721 L
.12557 .46786 L
.12624 .46849 L
.12696 .46905 L
.12764 .46952 L
.12833 .46989 L
.12902 .47014 L
.12975 .47027 L
.13039 .47032 L
.13097 .47032 L
.13148 .47033 L
.13191 .4704 L
.13226 .47056 L
.13254 .47082 L
.1328 .47118 L
.13303 .47154 L
.13327 .47195 L
.13349 .47237 L
Mistroke
.13369 .47275 L
.13385 .47315 L
.13396 .47352 L
.134 .47385 L
.13395 .47411 L
.13382 .47428 L
.13361 .47433 L
.13333 .47432 L
.13301 .47427 L
.13268 .47419 L
.13236 .47415 L
.13209 .47424 L
.13189 .47451 L
.13177 .47497 L
.13173 .47562 L
.13178 .47643 L
.13191 .47738 L
.13209 .47843 L
.13232 .47937 L
.13256 .48036 L
.13277 .48134 L
.13298 .48231 L
.13314 .48323 L
.13331 .48391 L
.13347 .48456 L
.13362 .48509 L
.13375 .48553 L
.13388 .48593 L
.13404 .48639 L
.13426 .48698 L
.13454 .48774 L
.13492 .4887 L
.13538 .48971 L
.13592 .49091 L
.13652 .49226 L
.13717 .49376 L
.13782 .4952 L
.13837 .49653 L
.13891 .49782 L
.13937 .49886 L
.13982 .49978 L
.14026 .50055 L
.14069 .50115 L
.14113 .50158 L
.14158 .50187 L
.14205 .50207 L
.14254 .50222 L
.143 .50234 L
.14346 .50244 L
.1439 .50256 L
Mistroke
.14438 .50274 L
.14489 .50295 L
.14538 .50317 L
.14581 .50336 L
.14613 .50348 L
.1463 .50352 L
.14632 .50345 L
.14621 .50324 L
.146 .50294 L
.14571 .5026 L
.14538 .50225 L
.14503 .50192 L
.1447 .50168 L
.14438 .50157 L
.14409 .50161 L
.14384 .50187 L
.14367 .5024 L
.14358 .50326 L
.14358 .50445 L
.14365 .50586 L
.14376 .50747 L
.14392 .50938 L
.1441 .51159 L
.14431 .5136 L
.14453 .51597 L
.14477 .51804 L
.14504 .5202 L
.1453 .52234 L
.14557 .52406 L
.14584 .52562 L
.1461 .52698 L
.14632 .52808 L
.14652 .5289 L
.1467 .52952 L
.14689 .52995 L
.14707 .53023 L
.14724 .53042 L
.14739 .53053 L
.14747 .53058 L
.1475 .53055 L
.14748 .53047 L
.14743 .53035 L
.14737 .53023 L
.14734 .53014 L
.14734 .53012 L
.14739 .5302 L
.14751 .53038 L
.1477 .53065 L
.148 .53102 L
.14841 .53148 L
Mistroke
.14893 .53201 L
.14955 .5326 L
.15027 .53324 L
.15108 .53397 L
.15192 .53477 L
.15282 .53559 L
.15376 .53639 L
.15469 .53715 L
.15554 .53786 L
.15636 .53855 L
.15712 .53922 L
.1578 .53987 L
.15838 .54051 L
.15885 .54116 L
.15922 .54187 L
.1595 .5426 L
.15969 .54332 L
.1598 .54396 L
.15984 .54447 L
.1598 .5449 L
.15969 .54522 L
.15949 .5454 L
.15921 .54542 L
.15888 .54528 L
.15851 .54501 L
.15817 .54463 L
.15787 .54417 L
.15762 .54368 L
.15747 .54315 L
.15747 .54263 L
.15767 .54217 L
.15809 .54182 L
.15876 .54158 L
.15962 .54142 L
.16074 .54133 L
.16203 .5413 L
.16355 .54131 L
.16511 .54132 L
.16675 .54132 L
.16815 .54129 L
.1695 .54125 L
.17054 .54121 L
.17134 .5412 L
.17182 .54121 L
.17193 .54125 L
.17169 .5413 L
.17118 .54134 L
.17044 .54138 L
.16952 .54141 L
.1686 .54146 L
Mistroke
.16761 .54152 L
.16655 .54156 L
.16553 .54155 L
.16466 .54144 L
.16396 .54119 L
.16343 .54074 L
.16301 .54008 L
.16267 .53919 L
.16236 .53801 L
.16205 .53652 L
.16168 .53471 L
.16119 .53292 L
.16058 .53079 L
.15984 .52829 L
.15897 .52587 L
.15809 .52326 L
.15707 .52048 L
.15598 .51783 L
.1549 .51532 L
.1538 .51296 L
.15273 .51064 L
.15179 .5089 L
.15098 .50729 L
.1503 .50594 L
.14978 .50496 L
.14942 .50417 L
.14918 .50357 L
.14898 .50317 L
.14877 .5029 L
.1485 .50273 L
.1481 .50264 L
.14751 .50259 L
.1467 .50254 L
.14565 .50247 L
.14448 .50233 L
.14307 .50212 L
.14144 .50184 L
.13966 .5015 L
.13802 .50113 L
.13636 .50076 L
.13475 .50041 L
.13329 .50012 L
.13207 .49985 L
.13112 .49963 L
.13039 .4994 L
.12989 .49911 L
.1296 .4987 L
.1295 .49823 L
.12958 .49777 L
.12976 .49718 L
Mistroke
.13003 .4965 L
.13035 .49569 L
.13066 .4947 L
.13094 .49362 L
.1311 .49234 L
.1311 .49083 L
.13094 .48912 L
.13068 .48735 L
.13034 .48563 L
.12996 .48379 L
.12956 .4823 L
.12916 .48086 L
.12879 .47975 L
.12848 .47884 L
.12822 .47812 L
.12804 .47772 L
.12793 .47747 L
.12789 .47736 L
.12792 .47738 L
.12803 .47755 L
.12819 .47785 L
.12839 .47823 L
.12858 .47863 L
.12876 .47898 L
.12891 .47924 L
.12901 .47939 L
.12907 .47941 L
.12907 .47927 L
.12905 .47897 L
.12902 .47858 L
.129 .47813 L
.12901 .47766 L
.12902 .47719 L
.12904 .47673 L
.12906 .47629 L
.12908 .47585 L
.12914 .47543 L
.12928 .47505 L
.1295 .47478 L
.12972 .47462 L
.12988 .47458 L
.12994 .47461 L
.12986 .47467 L
.1296 .47474 L
.12902 .47475 L
.12805 .47466 L
.12672 .47445 L
.12504 .47412 L
.12299 .47369 L
.12101 .47319 L
Mistroke
.11853 .47263 L
.1159 .47207 L
.11321 .4715 L
.11041 .47095 L
.1077 .47044 L
.10474 .46996 L
.10239 .46953 L
.10015 .46914 L
.09785 .46878 L
.09582 .46845 L
.09386 .46812 L
.09199 .46778 L
.09027 .46744 L
.08881 .46711 L
.0878 .46677 L
.08656 .46644 L
.08561 .46608 L
.08467 .46568 L
.08374 .46522 L
.08287 .46474 L
.08207 .46425 L
.08133 .46377 L
.08064 .46325 L
.08002 .46269 L
.07945 .46207 L
.07891 .46144 L
.07826 .46073 L
.07757 .45991 L
.07687 .45896 L
.0762 .45801 L
.07561 .45707 L
.07513 .45617 L
.07478 .45537 L
.07458 .45472 L
.07452 .45416 L
.07459 .45373 L
.07477 .45342 L
.07502 .45321 L
.0753 .45308 L
.07561 .45298 L
.07592 .45289 L
.0762 .45276 L
.07645 .45257 L
.07669 .45231 L
.07693 .45196 L
.07717 .45154 L
.07741 .45108 L
.07765 .45062 L
.07789 .45017 L
.07813 .44973 L
Mistroke
.07836 .44931 L
.07859 .44893 L
.07883 .44863 L
.07907 .44842 L
.07933 .4483 L
.0796 .44826 L
.07984 .44828 L
.08005 .44834 L
.08021 .44841 L
Mfstroke
.08429 .38838 m
.0843 .38826 L
.08432 .38805 L
.08436 .3877 L
.08441 .38721 L
.08449 .38653 L
.08459 .38566 L
.08472 .38454 L
.08489 .38317 L
.0851 .38161 L
.08529 .37968 L
.08547 .37762 L
.08569 .37524 L
.08595 .37266 L
.08623 .3702 L
.08648 .3672 L
.08677 .36467 L
.08707 .36166 L
.08739 .35891 L
.08773 .35596 L
.08811 .35264 L
.08852 .35006 L
.08894 .34732 L
.08937 .34457 L
.08979 .34178 L
.09022 .33891 L
.09066 .33671 L
.09111 .33417 L
.09157 .33183 L
.09202 .32967 L
.09246 .32755 L
.09289 .32575 L
.09331 .32405 L
.0937 .3227 L
.09406 .32153 L
.09438 .32064 L
.09467 .31994 L
.09491 .31942 L
.09511 .31909 L
.09528 .31891 L
.09541 .31882 L
.0955 .31883 L
.09555 .3189 L
.09556 .31901 L
.09555 .31912 L
.09551 .31921 L
.09546 .31927 L
.09543 .31929 L
.09542 .31929 L
.09542 .31929 L
Mistroke
.09542 .31929 L
.09542 .31929 L
.09542 .31929 L
.09542 .31929 L
.09542 .31929 L
.09542 .31929 L
.09542 .31929 L
.09543 .31932 L
.09546 .31937 L
.0955 .31944 L
.09554 .31951 L
.09556 .31953 L
.09554 .31951 L
.09548 .31941 L
.09538 .31922 L
.09522 .31895 L
.09501 .31859 L
.09475 .31814 L
.09444 .31762 L
.09413 .31707 L
.09386 .3166 L
.09361 .31621 L
.0934 .31589 L
.09326 .31565 L
.09319 .31551 L
.09322 .31547 L
.09334 .31553 L
.09354 .31567 L
.09378 .31584 L
.09407 .31605 L
.09436 .31621 L
.09467 .31633 L
.09495 .31636 L
.09518 .31626 L
.09536 .316 L
.09548 .31558 L
.09555 .31502 L
.09558 .31437 L
.09557 .31367 L
.09554 .31297 L
.0955 .31234 L
.09546 .31179 L
.09545 .31133 L
.09545 .31097 L
.09545 .31068 L
.09545 .31044 L
.09545 .31027 L
.09545 .31018 L
.09545 .31015 L
.09545 .31017 L
Mistroke
.09545 .31024 L
.09545 .31031 L
.09545 .31037 L
.09545 .3104 L
.09545 .3104 L
.09544 .3104 L
.09541 .31043 L
.09537 .31047 L
.09533 .31054 L
.09531 .31061 L
.09532 .31064 L
.09538 .31062 L
.09548 .31052 L
.09563 .31035 L
.09583 .31009 L
.09606 .30976 L
.09631 .30937 L
.09657 .30894 L
.09684 .30848 L
.09709 .30804 L
.09735 .3076 L
.09759 .30717 L
.0978 .30676 L
.09797 .3064 L
.09809 .30611 L
.09815 .30591 L
.09817 .3058 L
.09816 .30576 L
.09812 .30578 L
.09808 .30585 L
.09805 .30592 L
.09803 .30598 L
.09803 .306 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30601 L
.09803 .30602 L
.09803 .30605 L
.09801 .30611 L
.09798 .30619 L
.09793 .30627 L
.09789 .30633 L
Mistroke
.09785 .30634 L
.09783 .30628 L
.09784 .30613 L
.09792 .30585 L
.09807 .30544 L
.09829 .30488 L
.09858 .30419 L
.09895 .30342 L
.09939 .3025 L
.09989 .3015 L
.10046 .30048 L
.10108 .2994 L
.10175 .2983 L
.1024 .29725 L
.10304 .2963 L
.10364 .29544 L
.10419 .29471 L
.10464 .29411 L
.10501 .29366 L
.1053 .29332 L
.10552 .29306 L
.10567 .29288 L
.10578 .29276 L
.10585 .2927 L
.10588 .29267 L
.10588 .29268 L
.10586 .29269 L
.10582 .29272 L
.10578 .29275 L
.10574 .29279 L
.10573 .29282 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
Mistroke
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10573 .29283 L
.10572 .29283 L
.10571 .29283 L
.10567 .29283 L
.10563 .29283 L
.10559 .29283 L
.10555 .29283 L
.10555 .29284 L
.1056 .29287 L
.10571 .29291 L
.10587 .29294 L
.10608 .29296 L
.10634 .29297 L
.10665 .29296 L
.10698 .29293 L
.1073 .29287 L
.10761 .29279 L
.1079 .29268 L
.10819 .29251 L
.10844 .29226 L
.10868 .29189 L
.10893 .29146 L
.1092 .29094 L
.10954 .2903 L
.11003 .28961 L
.11067 .28876 L
.11139 .28777 L
.11236 .28664 L
.11344 .28544 L
.11477 .28415 L
.11614 .28276 L
.11765 .28138 L
.11913 .28004 L
.12057 .2789 L
.12169 .27786 L
.12292 .27686 L
.12389 .27604 L
.12473 .27525 L
.12541 .27445 L
.12599 .27363 L
Mistroke
.12652 .27274 L
.12703 .27173 L
.12755 .27054 L
.12811 .26917 L
.12868 .26776 L
.12916 .26629 L
.12974 .26447 L
.13035 .2627 L
.13103 .26076 L
.13162 .2587 L
.13218 .25693 L
.1327 .25516 L
.13317 .25345 L
.13362 .25182 L
.13409 .25038 L
.13461 .249 L
.13522 .24763 L
.13591 .24621 L
.1368 .24473 L
.1378 .24342 L
.13898 .24192 L
.1403 .24036 L
.14177 .23883 L
.14326 .23719 L
.14497 .23554 L
.14637 .23394 L
.14776 .23231 L
.14917 .2308 L
.15041 .22933 L
.1516 .228 L
.15265 .22674 L
.15369 .22554 L
.15456 .22445 L
.15538 .22339 L
.15614 .22233 L
.15684 .22122 L
.15751 .22014 L
.15809 .21896 L
.15865 .21764 L
.15917 .21624 L
.15963 .21469 L
.16007 .21299 L
.16051 .21141 L
.16097 .20954 L
.16147 .20769 L
.162 .20554 L
.16258 .20339 L
.16323 .2013 L
.16399 .19899 L
.16488 .19665 L
Mistroke
.16579 .19464 L
.16684 .19268 L
.1679 .19071 L
.16907 .18881 L
.17032 .18712 L
.17153 .18538 L
.17285 .18361 L
.17427 .18194 L
.17573 .18026 L
.17727 .17868 L
.17872 .17713 L
.18019 .17576 L
.18167 .17443 L
.18304 .17316 L
.18438 .17206 L
.18567 .17105 L
.1868 .1702 L
.18786 .16948 L
.18869 .16891 L
.18937 .16852 L
.18987 .16832 L
.19018 .16829 L
.19029 .16839 L
.19023 .16857 L
.19006 .16877 L
.18986 .16894 L
.18969 .16899 L
.18961 .16886 L
.18969 .16851 L
.18996 .16792 L
.19043 .16706 L
.1911 .16593 L
.19192 .16463 L
.19287 .16302 L
.19393 .16111 L
.19497 .15923 L
.19612 .15707 L
.19748 .15451 L
.19881 .15236 L
.20025 .15017 L
.20156 .14796 L
.20281 .14589 L
.20395 .14403 L
.20494 .14259 L
.20586 .14128 L
.20672 .14027 L
.20757 .13944 L
.20838 .13876 L
.20915 .13822 L
.20987 .13778 L
Mistroke
.21052 .13745 L
.21111 .1372 L
.2117 .13702 L
.21232 .1369 L
.21302 .13683 L
.21384 .13675 L
.2148 .13663 L
.21591 .13649 L
.21715 .13636 L
.21831 .13626 L
.21958 .1362 L
.22064 .13618 L
.22178 .1362 L
.22287 .13628 L
.22376 .13642 L
.22455 .1366 L
.2252 .13678 L
.22566 .13693 L
.22595 .13699 L
.22611 .13696 L
.22622 .13679 L
.22637 .13647 L
.22667 .13597 L
.22718 .13528 L
.22795 .13436 L
.22902 .13321 L
.23027 .13196 L
.23183 .13034 L
.23354 .12862 L
.23562 .12664 L
.23751 .12447 L
.23967 .12225 L
.24197 .11996 L
.24385 .11778 L
.24582 .11566 L
.24764 .1137 L
.24917 .11205 L
.25055 .11055 L
.25172 .10921 L
.25268 .10815 L
.2535 .10729 L
.2542 .10666 L
.25482 .10625 L
.2554 .10605 L
.25596 .10599 L
.25655 .10604 L
.25716 .10615 L
.25782 .10628 L
.25848 .10641 L
.2591 .10653 L
Mistroke
.25968 .10663 L
.26023 .1067 L
.26073 .10673 L
.26118 .10672 L
.26158 .10668 L
.26192 .10662 L
.26219 .10655 L
.26243 .10648 L
.26263 .10643 L
.26281 .1064 L
.26299 .10641 L
.26318 .10643 L
.26336 .10664 L
.26357 .10658 L
.2638 .10648 L
.26401 .10634 L
.2642 .1062 L
.26435 .10607 L
.26444 .10592 L
.26448 .10577 L
.26445 .10556 L
.2644 .10536 L
.26433 .1051 L
.26428 .10483 L
.26426 .10454 L
.2643 .1042 L
.26442 .10389 L
.26459 .10361 L
.26482 .10339 L
.26509 .10312 L
.2654 .10285 L
.26574 .10257 L
.26614 .10228 L
.26659 .10199 L
.26711 .10171 L
.26769 .10143 L
.26835 .10113 L
.26908 .10083 L
.2699 .10052 L
.27079 .10017 L
.27171 .09975 L
.27271 .0993 L
.27375 .09884 L
.27486 .0984 L
.27599 .098 L
.27713 .09762 L
.27823 .09726 L
.27929 .09694 L
.28021 .09668 L
.28101 .09651 L
Mistroke
.28164 .09642 L
.28213 .09639 L
.2825 .09637 L
.28282 .09632 L
.2831 .0962 L
.2834 .09596 L
.28371 .09559 L
.28406 .0951 L
.28443 .09451 L
.28484 .09387 L
.28527 .09325 L
.28567 .09261 L
.28606 .09197 L
.28641 .09144 L
.28674 .09096 L
.28704 .09056 L
.28733 .09026 L
.28763 .09005 L
.28797 .0899 L
.28838 .08977 L
.28888 .0896 L
.28949 .08936 L
.29027 .08901 L
.29119 .08853 L
.29234 .08792 L
.29363 .08724 L
.29508 .08646 L
.29673 .08564 L
.29829 .08481 L
.2999 .08398 L
.30149 .08325 L
.30304 .08256 L
.30451 .08193 L
.30593 .08134 L
.30734 .08078 L
.30871 .08023 L
.31011 .07965 L
.31151 .07899 L
.31295 .07821 L
.31441 .07726 L
.31575 .07627 L
.31712 .07509 L
.31839 .07372 L
.31963 .07232 L
.32086 .07083 L
.32204 .06938 L
.32322 .06787 L
.32441 .06643 L
.32557 .06507 L
.3268 .06368 L
Mistroke
.32809 .0625 L
.32955 .06136 L
.33115 .06025 L
.33301 .05915 L
.33497 .05812 L
.33703 .05705 L
.33929 .05603 L
.34171 .055 L
.34402 .05397 L
.34627 .05295 L
.34837 .05201 L
.35013 .05114 L
.35198 .05037 L
.35372 .04975 L
.35535 .04932 L
.357 .04907 L
.35864 .04898 L
.36036 .04902 L
.3621 .04917 L
.36373 .0494 L
.36507 .04968 L
.36639 .05 L
.36752 .05032 L
.36866 .05062 L
.3698 .05087 L
.37083 .05107 L
.37162 .0512 L
.37213 .05128 L
.3724 .05131 L
.37248 .05133 L
.37239 .05133 L
.37215 .05132 L
.37187 .0513 L
.37164 .0513 L
.37149 .0513 L
.37144 .0513 L
.37152 .05128 L
.37174 .05121 L
.37215 .05106 L
.37273 .05079 L
.37349 .05039 L
.37441 .04986 L
.37547 .0492 L
.37653 .04843 L
.37768 .04757 L
.37893 .04664 L
.38029 .04577 L
.38158 .04484 L
.3829 .04386 L
.38423 .04299 L
Mistroke
.38549 .04217 L
.38673 .04142 L
.38794 .04076 L
.38922 .04022 L
.39063 .03979 L
.39215 .0395 L
.39379 .0393 L
.39563 .03919 L
.39765 .03912 L
.39964 .03908 L
.40168 .03905 L
.40377 .03904 L
.40572 .03904 L
.40759 .03909 L
.40932 .03915 L
.41083 .03923 L
.41223 .03932 L
.41344 .03941 L
.41439 .03947 L
.41502 .03952 L
.41534 .03955 L
.41535 .03957 L
.41509 .03959 L
.41462 .03958 L
.41401 .03957 L
.41332 .03954 L
.41259 .03951 L
.41187 .03948 L
.41115 .03946 L
.41044 .03944 L
.40976 .03942 L
.40915 .03941 L
.40868 .03939 L
.40836 .03938 L
.40818 .03938 L
.40812 .03938 L
.40815 .03938 L
.40825 .03938 L
.40836 .03938 L
.40843 .03937 L
.40843 .03932 L
.40838 .03923 L
.40831 .03914 L
.40825 .03906 L
.40825 .03902 L
.40831 .03904 L
.40845 .03916 L
.40868 .03941 L
.40899 .03981 L
.40936 .04037 L
Mistroke
.40979 .04108 L
.41025 .04193 L
.41071 .04284 L
.41119 .04387 L
.41167 .0449 L
.41214 .04596 L
.41257 .04695 L
.41293 .0478 L
.4132 .04837 L
.41335 .04872 L
.41338 .04883 L
.41329 .04869 L
.41312 .04831 L
.41291 .0477 L
.4127 .04701 L
.41252 .04618 L
.41237 .04533 L
.41223 .04447 L
.41207 .0437 L
.41187 .04297 L
.4116 .04233 L
.41123 .04181 L
.41073 .0414 L
.41009 .04114 L
.4093 .041 L
.40827 .04097 L
.40705 .04099 L
.40557 .04101 L
.40385 .04101 L
.40185 .04096 L
.39968 .04085 L
.39749 .04069 L
.39513 .0405 L
.39288 .04029 L
.39078 .04008 L
.38872 .03987 L
.38671 .03966 L
.38508 .03945 L
.38356 .03922 L
.38216 .03898 L
.38084 .03873 L
.3796 .03848 L
.37838 .03827 L
.37719 .03811 L
.37599 .03803 L
.37468 .03802 L
.37324 .03811 L
.37181 .03833 L
.37028 .03867 L
.36857 .0391 L
Mistroke
.36675 .0396 L
.36496 .04018 L
.36339 .04085 L
.36187 .04161 L
.36043 .04239 L
.35912 .0431 L
.35797 .04379 L
.35701 .04458 L
.3562 .04529 L
.35548 .04601 L
.35481 .04676 L
.35418 .04745 L
.35358 .0482 L
.35297 .04897 L
.35235 .04977 L
.35175 .05059 L
.3512 .0514 L
.35073 .05215 L
.35029 .05285 L
.34987 .05351 L
.34946 .0541 L
.34912 .05457 L
.34886 .05491 L
.34868 .05512 L
.34858 .05524 L
.34855 .05527 L
.34858 .05522 L
.34865 .05511 L
.34872 .05498 L
.34876 .05488 L
.34878 .05483 L
.34879 .05478 L
.34881 .05474 L
.34883 .05469 L
.34887 .05462 L
.3489 .05452 L
.34894 .05439 L
.34899 .05423 L
.34905 .05408 L
.34911 .05392 L
.34918 .05378 L
.34927 .05366 L
.34936 .05357 L
.34941 .05351 L
.34937 .05348 L
.34922 .05346 L
.34895 .05343 L
.34853 .05345 L
.34796 .05353 L
.34725 .0537 L
Mistroke
.34643 .05389 L
.34548 .05419 L
.34445 .05454 L
.34332 .05493 L
.3422 .05533 L
.34098 .05572 L
.33965 .05612 L
.33827 .05651 L
.33688 .05694 L
.33543 .05742 L
.33399 .05798 L
.33252 .05861 L
.33098 .0593 L
.32938 .06006 L
.32786 .06088 L
.32632 .06178 L
.32467 .06273 L
.32301 .06367 L
.32146 .06464 L
.31995 .06561 L
.31854 .06655 L
.31731 .06737 L
.31616 .0681 L
.31511 .06869 L
.31417 .06913 L
.3134 .06941 L
.31274 .06956 L
.31217 .06965 L
.31166 .06974 L
.31119 .06989 L
.31075 .07013 L
.31029 .07051 L
.30991 .07094 L
.30946 .07158 L
.30895 .07239 L
.30839 .07337 L
.30776 .07441 L
.30702 .07564 L
.30622 .07699 L
.30536 .07829 L
.30449 .07956 L
.30363 .08075 L
.30281 .08185 L
.30206 .08281 L
.30139 .08364 L
.30082 .08438 L
.30036 .08506 L
.3 .08566 L
.29976 .08623 L
.29962 .08677 L
Mistroke
.29956 .08727 L
.29955 .08774 L
.29959 .08816 L
.29969 .08847 L
.29983 .08873 L
.29997 .08897 L
.30009 .08923 L
.30018 .08949 L
.30023 .08975 L
.30021 .09003 L
.3001 .09039 L
.29986 .09085 L
.29946 .09142 L
.29887 .09211 L
.29809 .09293 L
.29712 .09386 L
.29606 .09479 L
.29488 .0958 L
.29364 .09684 L
.29246 .09788 L
.29136 .09878 L
.29026 .09957 L
.28914 .10022 L
.28817 .1007 L
.28729 .101 L
.28651 .10115 L
.28582 .10116 L
.28527 .1011 L
.28485 .10101 L
.28454 .10093 L
.28431 .10085 L
.2841 .10078 L
.28386 .10073 L
.28357 .10068 L
.28323 .10063 L
.28288 .10057 L
.28256 .10049 L
.28231 .10042 L
.28216 .10036 L
.28211 .10031 L
.28214 .10027 L
.28217 .10025 L
.28218 .10024 L
.2822 .10025 L
.28224 .10028 L
.28234 .1003 L
.28253 .10037 L
.28278 .10045 L
.28305 .10055 L
.28329 .10064 L
Mistroke
.28348 .10071 L
.28357 .10076 L
.28352 .10079 L
.28332 .10076 L
.283 .10069 L
.28258 .10058 L
.28208 .10039 L
.28149 .10013 L
.2808 .09981 L
.28015 .09945 L
.27937 .09914 L
.27855 .09884 L
.27771 .0986 L
.27693 .09844 L
.2762 .09835 L
.27557 .09832 L
.27503 .09833 L
.27464 .09844 L
.27433 .0986 L
.27414 .09879 L
.27404 .09904 L
.27399 .09931 L
.27398 .09954 L
.27397 .09971 L
.2739 .09984 L
.27374 .0999 L
.27344 .09993 L
.27298 .09997 L
.27239 .10008 L
.27165 .10034 L
.27077 .10081 L
.26982 .10148 L
.26885 .10231 L
.26782 .10324 L
.26673 .10418 L
.26564 .10498 L
.26461 .10577 L
.26366 .1065 L
.26283 .10717 L
.26212 .10766 L
.26153 .10803 L
.26105 .10824 L
.26066 .10832 L
.26036 .10821 L
.26016 .10793 L
.26005 .10754 L
.26001 .10712 L
.26001 .10676 L
.26 .1065 L
.25996 .10634 L
Mistroke
.25982 .10629 L
.2595 .10639 L
.25897 .10661 L
.25824 .10694 L
.25729 .10735 L
.25609 .10784 L
.25485 .1084 L
.25335 .10902 L
.25173 .10965 L
.25011 .11033 L
.24837 .11101 L
.24663 .1117 L
.24495 .11239 L
.24342 .11308 L
.24187 .11381 L
.24032 .11459 L
.23884 .11541 L
.23745 .11627 L
.23627 .11714 L
.23503 .1181 L
.23384 .11913 L
.23274 .12018 L
.23171 .12134 L
.23069 .12266 L
.22976 .12395 L
.2289 .12531 L
.22815 .12665 L
.22752 .12788 L
.22702 .12892 L
.22666 .12969 L
.2264 .13025 L
.22621 .13057 L
.22606 .13067 L
.22596 .13056 L
.22588 .13029 L
.22583 .12993 L
.22581 .12957 L
.22582 .12923 L
.22587 .12898 L
.22593 .12886 L
.226 .12895 L
.22606 .12933 L
.2261 .12995 L
.22615 .13077 L
.22621 .13162 L
.22629 .1327 L
.22635 .13364 L
.22641 .13453 L
.22643 .1353 L
.22644 .13588 L
Mistroke
.22643 .13622 L
.22638 .13635 L
.22626 .13631 L
.22604 .13616 L
.22572 .13594 L
.22528 .13569 L
.22469 .13545 L
.22395 .13527 L
.22303 .13513 L
.22194 .13502 L
.22068 .13499 L
.21923 .13503 L
.21761 .1352 L
.21608 .1355 L
.21438 .13593 L
.21244 .13651 L
.21033 .13725 L
.20831 .13811 L
.2064 .13913 L
.20437 .14033 L
.20236 .1416 L
.20037 .14311 L
.19858 .14481 L
.19669 .14662 L
.19513 .14846 L
.19357 .15048 L
.19193 .1525 L
.1904 .15472 L
.18885 .15675 L
.18731 .15889 L
.18579 .16109 L
.18455 .16298 L
.18327 .16497 L
.18215 .16687 L
.18116 .16866 L
.18018 .17048 L
.17933 .17192 L
.1786 .17333 L
.17803 .17471 L
.17762 .17605 L
.17738 .17731 L
.1773 .17837 L
.17733 .17938 L
.17743 .18026 L
.17754 .18099 L
.17764 .18154 L
.17772 .18193 L
.17776 .18218 L
.17776 .18233 L
.17773 .18235 L
Mistroke
.17769 .18227 L
.17763 .18202 L
.17756 .18164 L
.1775 .18116 L
.17748 .18068 L
.17754 .18021 L
.1777 .17976 L
.17796 .17939 L
.17834 .17914 L
.17882 .17905 L
.17939 .17908 L
.18001 .17915 L
.18072 .17923 L
.18148 .1793 L
.18229 .17936 L
.18307 .17941 L
.18386 .17945 L
.18461 .17947 L
.18531 .17949 L
.1859 .17951 L
.18639 .17952 L
.18675 .17953 L
.18702 .17954 L
.18722 .17954 L
.18737 .17954 L
.18748 .17955 L
.18756 .17955 L
.18764 .17955 L
.18768 .17955 L
.1877 .17955 L
.18768 .17955 L
.18764 .17955 L
.1876 .17955 L
.18757 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
Mistroke
.18755 .17955 L
.18755 .17955 L
.18755 .17955 L
.18753 .17955 L
.1875 .17955 L
.18746 .17955 L
.18743 .17955 L
.18741 .17955 L
.18742 .17955 L
.18748 .17955 L
.18757 .17955 L
.18772 .17955 L
.1879 .17956 L
.18812 .17957 L
.18836 .17957 L
.18861 .17958 L
.18886 .17959 L
.18912 .17962 L
.18935 .17968 L
.18954 .17977 L
.18968 .17986 L
.18978 .17994 L
.18983 .17999 L
.18985 .17997 L
.18985 .17986 L
.18987 .17964 L
.18992 .17931 L
.19007 .17886 L
.19035 .17828 L
.19077 .17756 L
.19134 .17671 L
.19203 .1757 L
.19288 .1745 L
.19388 .17308 L
.19502 .17158 L
.19629 .16994 L
.19761 .16827 L
.19898 .16656 L
.20035 .16502 L
.20161 .16353 L
.2028 .16219 L
.20379 .16111 L
.20468 .16009 L
.20543 .15925 L
.20609 .1585 L
.20655 .15802 L
.20691 .15767 L
.20713 .15749 L
.20724 .15746 L
.20727 .15753 L
Mistroke
.20725 .15764 L
.20719 .15776 L
.20711 .15785 L
.20702 .15792 L
.20695 .15796 L
.20692 .15797 L
.20692 .15798 L
.20693 .158 L
.20693 .15806 L
.20693 .15814 L
.20691 .15823 L
.20688 .15832 L
.20683 .1584 L
.20677 .15843 L
.20672 .15836 L
.2067 .15814 L
.20674 .15775 L
.20685 .15716 L
.20704 .15636 L
.20732 .15531 L
.20767 .15416 L
.20809 .15276 L
.20855 .15115 L
.20901 .14958 L
.2095 .14787 L
.20998 .14605 L
.21039 .14453 L
.21074 .14308 L
.21105 .14175 L
.21129 .14062 L
.21145 .13974 L
.21158 .13908 L
.21172 .13862 L
.21189 .1383 L
.21213 .13805 L
.21248 .13784 L
.21297 .13761 L
.21362 .13735 L
.21436 .13704 L
.21528 .13667 L
.21627 .13622 L
.2174 .13566 L
.21865 .13496 L
.21981 .13415 L
.22104 .13329 L
.22235 .1324 L
.22363 .1315 L
.22494 .13063 L
.22621 .12979 L
.22753 .12902 L
Mistroke
.22878 .12826 L
.23007 .12748 L
.23132 .12674 L
.23259 .12601 L
.23379 .12531 L
.23489 .12463 L
.23596 .124 L
.23694 .12344 L
.23779 .123 L
.23853 .12261 L
.23916 .12228 L
.23965 .12198 L
.24002 .1217 L
.2403 .12147 L
.24049 .12131 L
.24062 .12122 L
.24069 .1212 L
.24073 .12123 L
.24074 .12131 L
.24072 .1214 L
.24067 .12151 L
.24057 .12162 L
.24045 .1217 L
.24031 .12176 L
.2402 .12178 L
.24016 .12174 L
.24022 .12161 L
.2404 .12135 L
.24072 .12095 L
.2412 .12041 L
.24185 .11973 L
.24266 .11892 L
.2436 .11806 L
.24451 .11711 L
.24559 .1161 L
.24661 .1151 L
.2477 .11412 L
.24858 .1132 L
.24945 .11243 L
.25028 .11177 L
.25103 .11125 L
.25166 .11087 L
.25225 .11065 L
.25283 .11059 L
.25346 .11063 L
.25416 .11073 L
.25496 .11082 L
.25584 .11086 L
.25675 .11083 L
.2577 .11073 L
Mistroke
.25874 .11056 L
.25992 .11035 L
.26117 .11015 L
.26246 .11001 L
.26376 .10993 L
.26507 .1099 L
.26635 .10988 L
.26759 .10989 L
.2688 .10993 L
.26987 .10999 L
.27089 .1101 L
.27182 .11025 L
.2726 .1104 L
.2732 .11052 L
.27365 .11059 L
.27398 .11058 L
.27419 .11047 L
.27433 .11024 L
.27444 .10982 L
.27453 .10925 L
.27464 .10865 L
.2748 .10798 L
.27503 .1073 L
.27533 .10661 L
.27565 .10592 L
.27603 .10526 L
.27646 .10466 L
.27695 .10411 L
.27745 .10364 L
.27793 .10328 L
.27836 .10305 L
.27872 .10294 L
.27903 .10291 L
.27929 .10295 L
.27953 .10302 L
.27978 .10304 L
.28007 .10299 L
.28041 .1028 L
.28081 .10244 L
.28126 .10184 L
.2818 .101 L
.28244 .09995 L
.28315 .09863 L
.28403 .09717 L
.28499 .09549 L
.28612 .09366 L
.28742 .09177 L
.28888 .08993 L
.29057 .08802 L
.2922 .08632 L
Mistroke
.29406 .08456 L
.29577 .08309 L
.29772 .08166 L
.29967 .08042 L
.30176 .07927 L
.30398 .07818 L
.30609 .07716 L
.30825 .07624 L
.3104 .07531 L
.31248 .07434 L
.31458 .07328 L
.31668 .07219 L
.31875 .07095 L
.32101 .06952 L
.32313 .06806 L
.32538 .06648 L
.32775 .06486 L
.32997 .06311 L
.33231 .06145 L
.33478 .05971 L
.3371 .05792 L
.33952 .05642 L
.34202 .05492 L
.34432 .05347 L
.34663 .05217 L
.34879 .05102 L
.35084 .04996 L
.35252 .04904 L
.35404 .0482 L
.3553 .04747 L
.35635 .04683 L
.35715 .04627 L
.35774 .04582 L
.35814 .04542 L
.35837 .04507 L
.35845 .04479 L
.35841 .04456 L
.35829 .04438 L
.35813 .04426 L
.35797 .04419 L
.35781 .04418 L
.35768 .04422 L
.35761 .04428 L
.35761 .04436 L
.35771 .04441 L
.35794 .04444 L
.35833 .04445 L
.35891 .04445 L
.35969 .04445 L
.36066 .04446 L
Mistroke
.36184 .0445 L
.36321 .04457 L
.36453 .04466 L
.36596 .04475 L
.36731 .04482 L
.3687 .04484 L
.36985 .0448 L
.37092 .04467 L
.37191 .04444 L
.37271 .04414 L
.37341 .04378 L
.37404 .04338 L
.37462 .04296 L
.37517 .04253 L
.37568 .04211 L
.37616 .0417 L
.37666 .04132 L
.37722 .04098 L
.37784 .04071 L
.37848 .0405 L
.37912 .04037 L
.37968 .04032 L
.38018 .04034 L
.3806 .04042 L
.38095 .04056 L
.38122 .04075 L
.38142 .04099 L
.38158 .04127 L
.38178 .04158 L
.38202 .04186 L
.3823 .04207 L
.3826 .04221 L
.38294 .04229 L
.3833 .04235 L
.38366 .04243 L
.38403 .04252 L
.38441 .04263 L
.3848 .04275 L
.38525 .04285 L
.38579 .04292 L
.38641 .04299 L
.3872 .04309 L
.38798 .04324 L
.38898 .04352 L
.39016 .04394 L
.39139 .04449 L
.39285 .04512 L
.39439 .04579 L
.39621 .04647 L
.39826 .0471 L
Mistroke
.40015 .04766 L
.40225 .04813 L
.40436 .04857 L
.40648 .04898 L
.4087 .04938 L
.41075 .04977 L
.41277 .05012 L
.41472 .05042 L
.41647 .05063 L
.4182 .05074 L
.41971 .05074 L
.42102 .05064 L
.42201 .05045 L
.42277 .05019 L
.4233 .04991 L
.42368 .04961 L
.42394 .0493 L
.42415 .04898 L
.42439 .0486 L
.42474 .04819 L
.42526 .0477 L
.42598 .04713 L
.42689 .0465 L
.42794 .04576 L
.4292 .04514 L
.43065 .04447 L
.43227 .04383 L
.43392 .04326 L
.43556 .04271 L
.43721 .04216 L
.43852 .04165 L
.43969 .04116 L
.44058 .04072 L
.4413 .04038 L
.44182 .04014 L
.44214 .04002 L
.44237 .04001 L
.44262 .04007 L
.44298 .04015 L
.44348 .04023 L
.44419 .0403 L
.44513 .04034 L
.44633 .04038 L
.44759 .04042 L
.44929 .04049 L
.45106 .04059 L
.45309 .04073 L
.45538 .04091 L
.45752 .04112 L
.45987 .04135 L
Mistroke
.46208 .04161 L
.46425 .04188 L
.46633 .04214 L
.46818 .04237 L
.46987 .04256 L
.47139 .04272 L
.47267 .04285 L
.4738 .04298 L
.47474 .04313 L
.47546 .0433 L
.47597 .04352 L
.47629 .04379 L
.47646 .04411 L
.47651 .04448 L
.47648 .04488 L
.4764 .04532 L
.4763 .04576 L
.47621 .04621 L
.47613 .04666 L
.47602 .04706 L
.47589 .04737 L
.47574 .04756 L
.4756 .04759 L
.47553 .04747 L
.47556 .04721 L
.47572 .04687 L
.47605 .04644 L
.47658 .04602 L
.47734 .04558 L
.47836 .04519 L
.47955 .04481 L
.48106 .04446 L
.48255 .04415 L
.48442 .04389 L
.48635 .04368 L
.48826 .04349 L
.49045 .04328 L
.4927 .04303 L
.49499 .04276 L
.49727 .04244 L
.49946 .04205 L
.50154 .04164 L
.50359 .04117 L
.50529 .04068 L
.50682 .04019 L
.5083 .03974 L
.5095 .03931 L
.51055 .0389 L
.51133 .03849 L
.51191 .03821 L
Mistroke
.51228 .038 L
.51246 .03789 L
.51246 .03791 L
.51231 .03804 L
.51205 .03826 L
.51174 .03855 L
.51145 .03888 L
.51122 .03923 L
.51105 .03961 L
.51093 .04002 L
.51085 .04042 L
.5108 .04084 L
.5108 .04127 L
.51085 .0416 L
.51094 .04191 L
.51109 .04214 L
.5113 .0423 L
.51157 .0424 L
.51188 .04244 L
.51222 .04246 L
.5126 .0425 L
.51296 .04254 L
.5133 .04259 L
.51357 .04262 L
.51374 .0426 L
.51382 .0425 L
.51382 .04233 L
.51377 .04209 L
.51369 .04177 L
.51354 .0414 L
.51332 .04101 L
.51302 .04061 L
.51267 .04022 L
.51226 .03981 L
.51181 .03937 L
.51133 .03892 L
.51085 .03848 L
.51035 .03808 L
.50986 .03776 L
.50938 .0375 L
.50895 .03729 L
.50856 .03711 L
.50813 .03692 L
.50769 .03669 L
.50719 .03642 L
.50664 .0361 L
.50599 .03574 L
.50521 .03537 L
.50418 .03502 L
.50285 .03474 L
Mistroke
.5012 .03445 L
.49914 .03418 L
.49694 .03394 L
.49431 .03371 L
.49146 .03349 L
.48856 .03328 L
.48527 .03308 L
.48253 .03293 L
.47911 .03283 L
.47637 .03278 L
.47295 .03274 L
.47022 .0327 L
.46738 .03263 L
.46439 .03255 L
.4618 .03247 L
.45899 .03239 L
.45596 .03228 L
.4534 .03215 L
.45009 .032 L
.44739 .03185 L
.44436 .03172 L
.44077 .03165 L
.43764 .03164 L
.43413 .03171 L
.43076 .03186 L
.42708 .03208 L
.42413 .03238 L
.42105 .03273 L
.41822 .03313 L
.41552 .03354 L
.4132 .03395 L
.41119 .03431 L
.40942 .03459 L
.40808 .03477 L
.40702 .03483 L
.40624 .03477 L
.4057 .03461 L
.4054 .03438 L
.40528 .03413 L
.40531 .03386 L
.40542 .03366 L
.4056 .03351 L
.40578 .03343 L
.40592 .03343 L
.40603 .03347 L
.40611 .03359 L
.40616 .03376 L
.40619 .03401 L
.40623 .03425 L
.40624 .03452 L
Mistroke
.40625 .03477 L
.40624 .03496 L
.40623 .03509 L
.40625 .03514 L
.40633 .03516 L
.40643 .03515 L
.40653 .03513 L
.40658 .03511 L
.40654 .03507 L
.4064 .03501 L
.40613 .03494 L
.40573 .03489 L
.40521 .03487 L
.4046 .03491 L
.40393 .03501 L
.40323 .03516 L
.40256 .03538 L
.40196 .03568 L
.40134 .03603 L
.4007 .03641 L
.40009 .03682 L
.39961 .03721 L
.3993 .03764 L
.39914 .038 L
.39908 .03837 L
.3991 .0387 L
.39919 .03897 L
.3993 .03915 L
.39936 .03925 L
.39937 .03929 L
.39934 .03928 L
.39931 .03924 L
.39927 .0392 L
.39925 .03917 L
.39927 .03915 L
.39931 .03914 L
.39941 .03913 L
.39954 .03913 L
.39971 .03914 L
.39992 .03914 L
.40014 .03915 L
.40038 .03916 L
.40061 .03916 L
.40085 .03917 L
.40107 .0392 L
.40128 .03924 L
.40147 .03929 L
.40162 .03934 L
.40173 .03937 L
.4018 .03937 L
Mistroke
.40181 .03932 L
.40179 .0392 L
.40174 .03898 L
.40168 .03868 L
.40162 .0383 L
.40158 .03791 L
.40156 .03754 L
.40155 .03721 L
.40155 .03696 L
.40155 .03683 L
.40156 .0368 L
.40158 .03681 L
.40159 .03686 L
.40161 .03699 L
.40162 .0372 L
.40164 .03748 L
.40168 .0378 L
.40171 .03814 L
.40177 .03848 L
.40186 .03878 L
.40199 .03903 L
.40218 .03917 L
.4024 .03924 L
.40268 .03925 L
.40302 .03921 L
.40337 .03917 L
.40377 .03917 L
.40418 .0392 L
.40459 .03925 L
.40499 .03929 L
.40535 .03933 L
.40566 .03935 L
.40592 .03935 L
.40613 .03934 L
.40628 .03933 L
.40636 .03933 L
.40638 .03933 L
.40637 .03933 L
.40634 .03933 L
.40631 .03933 L
.40627 .03933 L
.40624 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
Mistroke
.40622 .03932 L
.40622 .03932 L
.40622 .03932 L
.40621 .03932 L
.40618 .03932 L
.40614 .03932 L
.40611 .03932 L
.40609 .03932 L
.4061 .03932 L
.40615 .03932 L
.40623 .03933 L
.40636 .03935 L
.40652 .03937 L
.40669 .03938 L
.40688 .03938 L
.40708 .03936 L
.4073 .03933 L
.40755 .03929 L
.40784 .03926 L
.40816 .03924 L
.40851 .03923 L
.40885 .03922 L
.40915 .03919 L
.40939 .03915 L
.40958 .03911 L
.40972 .03908 L
.40983 .03904 L
.40993 .03903 L
.41003 .03903 L
.41013 .03905 L
.41023 .03908 L
.41031 .03913 L
.41036 .03918 L
.41039 .03922 L
.41039 .03925 L
.41041 .03928 L
.41048 .03934 L
.41059 .03943 L
.41074 .03955 L
.41087 .03964 L
.41094 .03967 L
.41092 .03961 L
.41077 .03946 L
.41049 .03922 L
.41008 .03887 L
.40959 .03845 L
.40909 .038 L
.40862 .03754 L
.40822 .0371 L
.40788 .03667 L
Mistroke
.40756 .03624 L
.4073 .03584 L
.40712 .03548 L
.40704 .0352 L
.40708 .03501 L
.4072 .03491 L
.40741 .03488 L
.40766 .03491 L
.40795 .03498 L
.40822 .03505 L
.40843 .03511 L
.40855 .03514 L
.40861 .03514 L
.40862 .03514 L
.40861 .03514 L
.40857 .03514 L
.40854 .03515 L
.40851 .03515 L
.40849 .03516 L
.40849 .03517 L
.40849 .03518 L
.40849 .03518 L
.40849 .03519 L
.40849 .03519 L
.40849 .03519 L
.40849 .03519 L
.40849 .03519 L
.40849 .03519 L
.40849 .03518 L
.40849 .03517 L
.40849 .03516 L
.40849 .03516 L
.40849 .03515 L
.40849 .03514 L
.40849 .03514 L
.40849 .03513 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
Mistroke
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03514 L
.40849 .03515 L
.4085 .03515 L
.40852 .03515 L
.40853 .03515 L
.40854 .03515 L
.40852 .03514 L
.40849 .03513 L
.40845 .03512 L
.40839 .03511 L
.40834 .0351 L
.40829 .03509 L
.40824 .03508 L
.40821 .03508 L
.40819 .03508 L
.40818 .03508 L
.40819 .03508 L
.40822 .03509 L
.40826 .0351 L
.40831 .03511 L
.40835 .03512 L
.40836 .03512 L
.40836 .03513 L
.40832 .03513 L
.40827 .03512 L
.40821 .03511 L
.40814 .03511 L
.40807 .0351 L
Mistroke
.408 .03509 L
.40796 .03509 L
.40794 .03509 L
.40793 .03509 L
.40791 .03509 L
.40792 .0351 L
.40795 .0351 L
.40802 .03511 L
.40813 .03512 L
.40828 .03513 L
.40846 .03514 L
.40867 .03515 L
.40889 .03516 L
.4091 .03517 L
.40931 .03517 L
.40952 .03517 L
.40973 .03518 L
.40995 .03519 L
.41018 .03519 L
.41039 .0352 L
.41057 .0352 L
.41072 .03521 L
.41082 .03521 L
.41088 .03521 L
.41089 .03521 L
.41088 .03521 L
.41085 .03521 L
.41081 .03521 L
.41078 .03521 L
.41077 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41077 .03521 L
.41078 .03521 L
.41083 .03521 L
.4109 .03521 L
Mistroke
.41096 .03522 L
.41099 .03522 L
.41097 .03522 L
.41088 .03521 L
.41071 .03521 L
.41044 .0352 L
.41009 .03519 L
.40968 .03518 L
.40924 .03517 L
.40877 .03515 L
.40832 .03514 L
.40788 .03512 L
.40744 .03511 L
.407 .0351 L
.4066 .03509 L
.40627 .03508 L
.40603 .03507 L
.40589 .03507 L
.40586 .03507 L
.40593 .03507 L
.40608 .03507 L
.40628 .03508 L
.4065 .03509 L
.40673 .03509 L
.40696 .0351 L
.4072 .03511 L
.40744 .03511 L
.40767 .03512 L
.4079 .03513 L
.40811 .03513 L
.4083 .03514 L
.40844 .03515 L
.40855 .03515 L
.4086 .03515 L
.40862 .03515 L
.40861 .03515 L
.4086 .03514 L
.40858 .03513 L
.40855 .03512 L
.40853 .03512 L
.40849 .03511 L
.40845 .03511 L
.40839 .03511 L
.40834 .03512 L
.40828 .03513 L
.40824 .03514 L
.40821 .03513 L
.40819 .03511 L
.40818 .03508 L
.40816 .03505 L
Mistroke
.40814 .03501 L
.40812 .03498 L
.40811 .03495 L
.40814 .03494 L
.40821 .03493 L
.40831 .03492 L
.40846 .03493 L
.40865 .03493 L
.40885 .03495 L
.40907 .03497 L
.40929 .03501 L
.40951 .03505 L
.40972 .0351 L
.40995 .03515 L
.41018 .03519 L
.41039 .03523 L
.41057 .03525 L
.41072 .03525 L
.41082 .03524 L
.41088 .03522 L
.41089 .03522 L
.41088 .03521 L
.41085 .03521 L
.41081 .03521 L
.41078 .03521 L
.41077 .03521 L
.41076 .03521 L
.41076 .03521 L
.41076 .03521 L
.41077 .03519 L
.41079 .03514 L
.41081 .03507 L
.41081 .03501 L
.4108 .03498 L
.41077 .035 L
.41072 .03509 L
.41067 .03526 L
.41061 .0355 L
.41056 .03583 L
.41052 .0362 L
.41049 .03662 L
.41047 .03705 L
.41046 .03748 L
.41046 .03791 L
.41046 .03833 L
.41048 .03872 L
.41051 .03907 L
.41055 .03935 L
.41061 .03954 L
.41067 .03965 L
Mistroke
.41073 .03968 L
.41079 .03965 L
.41087 .03957 L
.41095 .03946 L
.41101 .03936 L
.41102 .03928 L
.41099 .03922 L
.41089 .0392 L
.41071 .03925 L
.41045 .03939 L
.4101 .03962 L
.4097 .03995 L
.40925 .04039 L
.40879 .04092 L
.40833 .04148 L
.40789 .04213 L
.40746 .04282 L
.40704 .04352 L
.40667 .04416 L
.40636 .04473 L
.40615 .04521 L
.40606 .04554 L
.40609 .04569 L
.4062 .04565 L
.40633 .04542 L
.40644 .04506 L
.4065 .04462 L
.40645 .04414 L
.40625 .04365 L
.40597 .04318 L
.4055 .04273 L
.40479 .04229 L
.40385 .04187 L
.40274 .04147 L
.40159 .04111 L
.4004 .04079 L
.39897 .04051 L
.39724 .04027 L
.39573 .04008 L
.39406 .03992 L
.39257 .03977 L
.39104 .0396 L
.38964 .0394 L
.38852 .03917 L
.38751 .03892 L
.38661 .03863 L
.38587 .0383 L
.38532 .03795 L
.38496 .03757 L
.38477 .03717 L
Mistroke
.38473 .03676 L
.38477 .03637 L
.38486 .03597 L
.38496 .03555 L
.38505 .03516 L
.38508 .03481 L
.38504 .03454 L
.38497 .03436 L
.38487 .03426 L
.38475 .03422 L
.38462 .03424 L
.38446 .0343 L
.38427 .03436 L
.38405 .03442 L
.38382 .03444 L
.38359 .03443 L
.38341 .03442 L
.38328 .03442 L
.3832 .03441 L
.38316 .03441 L
.38318 .03441 L
.38325 .03443 L
.38335 .03446 L
.38346 .03448 L
.38356 .03452 L
.38363 .03455 L
.38368 .03459 L
.38371 .03462 L
.38375 .03466 L
.3838 .03468 L
.38388 .0347 L
.384 .03471 L
.38416 .03471 L
.38435 .0347 L
.38453 .03467 L
.38469 .03462 L
.38482 .0347 L
.38492 .03465 L
.38499 .03463 L
.38503 .03462 L
.38503 .03466 L
.38498 .03473 L
.38487 .03484 L
.38467 .035 L
.38438 .03525 L
.384 .03551 L
.38355 .03583 L
.38308 .03618 L
.38261 .03653 L
.3822 .03693 L
Mistroke
.38184 .03729 L
.38155 .03758 L
.38132 .03786 L
.38115 .03811 L
.38104 .03831 L
.38097 .03847 L
.38095 .03858 L
.38098 .03866 L
.38107 .0387 L
.38121 .03872 L
.38134 .03872 L
.38142 .0387 L
.3814 .03866 L
.38126 .03862 L
.381 .0386 L
.3806 .03858 L
.38007 .03857 L
.37945 .03855 L
.37878 .03853 L
.37807 .03851 L
.37739 .03849 L
.37672 .03847 L
.37605 .03844 L
.37541 .03843 L
.37483 .03841 L
.37438 .0384 L
.37406 .03839 L
.37389 .03838 L
.37383 .03838 L
.37386 .03838 L
.37396 .03839 L
.37407 .03839 L
.37415 .03839 L
.37419 .03839 L
.3742 .03837 L
.37421 .03834 L
.37424 .03832 L
.37427 .03831 L
.37431 .03831 L
.37432 .03834 L
.3743 .03841 L
.37422 .03852 L
.37409 .03868 L
.37392 .03887 L
.37374 .03905 L
.37355 .03922 L
.37337 .03937 L
.37323 .03947 L
.37313 .03953 L
.37307 .03959 L
Mistroke
.37304 .03959 L
.37306 .03956 L
.37311 .03946 L
.37319 .03933 L
.37333 .03915 L
.37349 .03896 L
.37369 .03877 L
.37389 .03858 L
.37407 .03843 L
.37421 .03834 L
.3743 .0383 L
.37433 .03829 L
.37431 .03829 L
.37428 .03832 L
.37424 .03835 L
.37421 .03838 L
.3742 .03839 L
.37419 .03839 L
.37419 .03839 L
.37419 .03839 L
.37419 .03839 L
.3742 .03839 L
.37422 .03839 L
.37427 .0384 L
.37434 .0384 L
.37441 .0384 L
.37444 .0384 L
.37443 .0384 L
.37434 .0384 L
.37418 .03839 L
.37393 .03838 L
.37363 .03833 L
.3733 .03824 L
.37294 .03813 L
.37257 .03803 L
.37219 .03795 L
.3718 .03794 L
.37135 .03801 L
.37082 .03821 L
.37021 .03857 L
.36951 .03908 L
.3687 .03974 L
.36773 .04053 L
.3666 .04143 L
.36542 .04234 L
.36403 .04328 L
.36243 .04425 L
.36085 .04522 L
.35895 .04613 L
.35725 .0469 L
Mistroke
.35554 .04755 L
.35389 .04805 L
.35244 .04841 L
.35126 .04862 L
.35028 .0487 L
.34951 .0487 L
.34897 .04865 L
.34862 .04859 L
.34842 .04852 L
.34836 .04844 L
.34838 .04838 L
.34844 .04835 L
.34855 .04835 L
.34867 .04835 L
.34877 .04836 L
.34881 .04836 L
.34882 .04835 L
.34884 .04833 L
.3489 .04826 L
.34902 .04816 L
.34912 .04808 L
.34919 .04804 L
.34919 .04807 L
.34909 .0482 L
.34884 .04845 L
.3484 .04881 L
.34778 .04929 L
.34704 .04985 L
.34622 .05047 L
.34538 .05113 L
.34454 .05175 L
.34387 .05234 L
.34311 .05293 L
.34239 .0535 L
.34177 .054 L
.34133 .05439 L
.34111 .05462 L
.3411 .0547 L
.34123 .05467 L
.34144 .05456 L
.34167 .05444 L
.34187 .05434 L
.34194 .05431 L
.34181 .05438 L
.34147 .05455 L
.34091 .05479 L
.34011 .05511 L
.33904 .0555 L
.33789 .05598 L
.3364 .05655 L
Mistroke
.33504 .05721 L
.33356 .05798 L
.33186 .05885 L
.33023 .05983 L
.32853 .06088 L
.32675 .06195 L
.32495 .06298 L
.32324 .06394 L
.3215 .06488 L
.31979 .06575 L
.31839 .06654 L
.31694 .06722 L
.31559 .06782 L
.31452 .06832 L
.31358 .06873 L
.31276 .06906 L
.31209 .0693 L
.31157 .06949 L
.31123 .06966 L
.31106 .06982 L
.31104 .06998 L
.31112 .07012 L
.31125 .07029 L
.31139 .07048 L
.3115 .07068 L
.31155 .07085 L
.31156 .07099 L
.31156 .07108 L
.31156 .07114 L
.31156 .07116 L
.31156 .07114 L
.31156 .07111 L
.31156 .07107 L
.31156 .07104 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07103 L
.31156 .07102 L
.31159 .071 L
.31165 .07096 L
.31176 .07089 L
.31186 .07083 L
.31192 .0708 L
.31189 .07082 L
Mistroke
.31177 .0709 L
.31153 .07105 L
.31115 .07128 L
.31067 .07156 L
.31011 .07187 L
.30952 .0722 L
.30888 .07257 L
.30818 .07297 L
.30745 .07343 L
.30666 .07394 L
.30582 .0745 L
.30495 .07509 L
.30412 .07569 L
.30339 .07625 L
.3028 .07678 L
.30233 .07726 L
.30196 .07768 L
.30159 .07806 L
.30118 .07843 L
.30068 .07879 L
.30007 .07912 L
.29937 .0794 L
.29863 .0796 L
.29786 .0797 L
.29713 .07972 L
.29647 .07966 L
.29589 .07955 L
.29532 .07943 L
.29472 .07933 L
.29408 .07927 L
.29346 .07925 L
.29292 .07927 L
.29247 .07934 L
.29212 .07945 L
.29185 .0796 L
.29165 .07977 L
.29151 .07997 L
.29138 .08021 L
.29121 .08041 L
.29098 .08066 L
.29074 .08089 L
.29052 .0811 L
.29034 .08127 L
.29022 .08137 L
.29017 .0814 L
.29021 .08137 L
.29032 .08132 L
.29049 .08129 L
.29071 .08129 L
.29095 .08135 L
Mistroke
.29119 .08149 L
.29144 .08171 L
.29169 .08198 L
.29195 .08226 L
.29221 .0825 L
.29249 .08265 L
.29276 .08274 L
.293 .08276 L
.29322 .08277 L
.29338 .08278 L
.29343 .08288 L
.29334 .0829 L
.29311 .08295 L
.29269 .08302 L
.29208 .08317 L
.29122 .08343 L
.29008 .08384 L
.28879 .08439 L
.2872 .08517 L
.28527 .08614 L
.28312 .0873 L
.28111 .08852 L
.27888 .08981 L
.2764 .09115 L
.27416 .09243 L
.27183 .09366 L
.26986 .09475 L
.26809 .09576 L
.26662 .09666 L
.26542 .09747 L
.26435 .09815 L
.26347 .09871 L
.26274 .09919 L
.26213 .09957 L
.26156 .09988 L
.26098 .10016 L
.26036 .10044 L
.25962 .10077 L
.2587 .10119 L
.25764 .10172 L
.25642 .10239 L
.25496 .1032 L
.25321 .10418 L
.25137 .10527 L
.24944 .10648 L
.24746 .10775 L
.24571 .109 L
.24401 .11017 L
.2426 .11129 L
.24124 .11229 L
Mistroke
.24013 .11313 L
.23919 .11383 L
.23846 .11438 L
.23797 .11478 L
.23768 .11502 L
.23758 .11514 L
.23761 .11517 L
.23773 .11513 L
.23788 .11506 L
.23803 .11497 L
.23812 .11489 L
.23818 .11481 L
.23827 .11474 L
.23839 .11465 L
.23849 .11455 L
.23854 .11447 L
.23852 .11442 L
.23839 .11444 L
.23815 .11455 L
.23776 .11479 L
.23722 .11517 L
.23655 .1157 L
.23577 .11639 L
.23492 .11721 L
.23406 .11809 L
.23319 .11908 L
.23229 .12009 L
.2314 .12111 L
.23056 .12212 L
.22984 .12306 L
.22927 .12387 L
.22885 .12456 L
.22858 .12509 L
.22842 .12548 L
.22837 .12571 L
.22837 .12582 L
.2284 .12584 L
.22842 .12581 L
.22845 .12575 L
.22849 .12568 L
.22853 .1256 L
.2286 .12553 L
.22867 .12548 L
.22876 .12543 L
.22887 .12538 L
.22899 .12531 L
.22909 .12524 L
.22913 .12518 L
.22906 .12517 L
.22885 .12525 L
Mistroke
.22844 .12546 L
.22779 .1258 L
.22688 .12629 L
.22569 .12691 L
.22436 .12763 L
.22275 .12843 L
.22086 .12932 L
.21891 .13026 L
.21686 .1313 L
.21452 .13253 L
.21235 .13374 L
.21003 .13503 L
.20779 .13638 L
.20588 .13777 L
.20405 .13912 L
.2024 .14041 L
.20106 .14146 L
.19991 .14251 L
.19898 .14349 L
.1983 .14426 L
.19782 .14494 L
.1975 .14554 L
.1973 .146 L
.19716 .14634 L
.19703 .14665 L
.19684 .147 L
.19655 .14746 L
.19617 .14808 L
.19568 .14889 L
.19508 .14989 L
.1944 .15102 L
.19372 .15211 L
.19302 .15333 L
.19234 .15458 L
.19175 .15563 L
.19119 .15667 L
.19073 .15755 L
.19039 .1583 L
.19016 .15891 L
.18996 .15944 L
.18976 .15996 L
.18949 .16052 L
.18909 .16121 L
.18847 .16214 L
.18759 .16334 L
.18653 .16463 L
.18524 .16631 L
.18368 .16819 L
.18189 .17044 L
.17999 .17282 L
Mistroke
.17822 .17552 L
.17634 .17801 L
.17433 .1808 L
.17238 .18361 L
.17052 .18636 L
.16866 .18929 L
.16697 .1918 L
.16528 .19448 L
.16374 .19697 L
.16221 .19945 L
.16073 .20178 L
.15939 .20417 L
.15805 .20624 L
.15673 .20832 L
.1555 .21031 L
.15438 .21214 L
.15332 .2139 L
.15232 .21554 L
.15144 .21689 L
.15065 .21818 L
.14997 .21934 L
.14944 .22037 L
.14902 .22121 L
.14873 .2219 L
.14854 .22241 L
.14845 .22274 L
.14841 .22292 L
.1484 .223 L
.14838 .22299 L
.14835 .22295 L
.14828 .22292 L
.14815 .22293 L
.14793 .223 L
.14762 .22316 L
.1472 .22344 L
.14666 .22389 L
.14598 .22456 L
.1452 .22543 L
.1443 .22651 L
.14327 .22784 L
.1421 .22945 L
.14084 .23135 L
.1396 .23319 L
.1383 .23542 L
.13697 .23781 L
.13562 .24021 L
.13419 .24289 L
.13266 .24579 L
.13111 .24851 L
.12943 .25161 L
Mistroke
.12775 .25453 L
.12611 .25762 L
.12443 .26049 L
.1227 .26356 L
.12116 .26619 L
.11929 .26905 L
.1176 .27183 L
.1157 .27475 L
.11388 .27774 L
.11193 .28034 L
.10991 .28317 L
.10795 .28613 L
.10646 .28855 L
.10485 .29117 L
.10339 .29342 L
.10193 .29567 L
.10084 .2975 L
.09987 .2992 L
.09902 .30074 L
.09837 .30198 L
.09791 .30298 L
.09764 .30371 L
.09754 .30416 L
.09756 .30438 L
.09765 .30441 L
.09777 .30431 L
.0979 .30414 L
.098 .30397 L
.09805 .30383 L
.09804 .30373 L
.09804 .30366 L
.09804 .30364 L
.09802 .30368 L
.09798 .30376 L
.0979 .30392 L
.09779 .30417 L
.09766 .30456 L
.09753 .30507 L
.09741 .30573 L
.09731 .30652 L
.09723 .30742 L
.0972 .3084 L
.09719 .30937 L
.09721 .31035 L
.09726 .31131 L
.09731 .31223 L
.0974 .31303 L
.09752 .31367 L
.09766 .31408 L
.09782 .31432 L
Mistroke
.09799 .31445 L
.09815 .31449 L
.09827 .31449 L
.09831 .31454 L
.09825 .31472 L
.0981 .3152 L
.09786 .31605 L
.09755 .31728 L
.09719 .31891 L
.09677 .32094 L
.09628 .32304 L
.0957 .32539 L
.09501 .32822 L
.09421 .33118 L
.09334 .33447 L
.09239 .33768 L
.09139 .3411 L
.09042 .34446 L
.08946 .34747 L
.08854 .35078 L
.08773 .35378 L
.08695 .35686 L
.08629 .35974 L
.08569 .36277 L
.08518 .36534 L
.08478 .36806 L
.08449 .37059 L
.08431 .3732 L
.08422 .37571 L
.08422 .37777 L
.08425 .37971 L
.08431 .38154 L
.08436 .38319 L
.08439 .38461 L
.08439 .38572 L
.08438 .38664 L
.08437 .38735 L
.08437 .38787 L
.08436 .38823 L
.08436 .38841 L
Mfstroke
.07165 .46874 m
.07162 .46897 L
.07158 .46933 L
.07156 .46978 L
.07155 .47028 L
.07154 .47081 L
.07152 .47137 L
.07148 .47198 L
.07143 .47265 L
.07136 .47341 L
.0713 .47422 L
.07126 .47507 L
.07123 .47597 L
.07121 .47693 L
.07118 .47794 L
.07111 .47904 L
.07099 .48025 L
.07082 .48163 L
.07061 .48328 L
.07034 .48526 L
.07002 .48743 L
.06967 .48996 L
.0693 .4927 L
.06895 .4952 L
.0686 .4977 L
.06828 .50037 L
.06799 .50291 L
.06776 .50564 L
.06761 .50794 L
.06756 .51027 L
.06766 .51253 L
.06787 .51458 L
.0682 .51652 L
.0686 .51821 L
.06905 .51972 L
.06952 .52105 L
.06998 .52222 L
.07039 .52322 L
.07076 .52404 L
.07109 .52472 L
.07138 .52529 L
.07165 .52575 L
.07189 .52611 L
.07212 .5264 L
.07234 .52662 L
.07258 .52679 L
.07283 .52692 L
.07311 .52701 L
.07339 .52707 L
.07364 .52711 L
Mistroke
.0739 .52717 L
.07413 .5273 L
.07431 .5275 L
.07438 .52778 L
.07433 .52818 L
.07416 .52869 L
.07388 .52934 L
.07354 .53018 L
.07319 .53124 L
.07287 .53244 L
.07261 .53392 L
.07243 .53562 L
.07236 .53745 L
.07241 .53953 L
.07257 .54175 L
.07285 .54394 L
.07322 .54629 L
.0737 .54862 L
.07429 .55103 L
.0749 .55324 L
.07551 .55546 L
.07611 .55763 L
.07664 .55946 L
.07708 .56123 L
.07743 .56284 L
.07771 .56418 L
.07791 .56534 L
.07806 .56636 L
.07817 .56703 L
.07825 .56757 L
.07832 .5679 L
.07835 .56805 L
.07834 .56805 L
.0783 .56798 L
.07826 .56792 L
.07824 .56792 L
.07824 .568 L
.07828 .56815 L
.07833 .56835 L
.07839 .56858 L
.07844 .56885 L
.07848 .56913 L
.0785 .56943 L
.07852 .56973 L
.07851 .57011 L
.07847 .5706 L
.07842 .57127 L
.07833 .57202 L
.07821 .57296 L
.07809 .57404 L
Mistroke
.07796 .5753 L
.07784 .57666 L
.07777 .5783 L
.07776 .58016 L
.07781 .58227 L
.07793 .58471 L
.07814 .58715 L
.07843 .58987 L
.0788 .59274 L
.07925 .59583 L
.07979 .59871 L
.08041 .60165 L
.08108 .6047 L
.08178 .60758 L
.08248 .61061 L
.08315 .61343 L
.08376 .61627 L
.08434 .61879 L
.08491 .62119 L
.08543 .62322 L
.08591 .62503 L
.08636 .62662 L
.08676 .62802 L
.08711 .62929 L
.08742 .63049 L
.08771 .63165 L
.08799 .63276 L
.08828 .63384 L
.08859 .63488 L
.08894 .63579 L
.08931 .63668 L
.08968 .63747 L
.09001 .63821 L
.09029 .63882 L
.09054 .63937 L
.09076 .63985 L
.09097 .64024 L
.09117 .6406 L
.09138 .64102 L
.09159 .64151 L
.09179 .64211 L
.09197 .64297 L
.09214 .6441 L
.0923 .64545 L
.09245 .64689 L
.09261 .6485 L
.09277 .65021 L
.09292 .65187 L
.09304 .65366 L
.09315 .6553 L
Mistroke
.09324 .65698 L
.09332 .65865 L
.09339 .66034 L
.09346 .66208 L
.09354 .66384 L
.09365 .66546 L
.09381 .6672 L
.09407 .66904 L
.09444 .67085 L
.0949 .67274 L
.09547 .67465 L
.09616 .67639 L
.09695 .67804 L
.0979 .67952 L
.09861 .68054 L
.09944 .6815 L
.10029 .68227 L
.10098 .68286 L
.10162 .68332 L
.10222 .68368 L
.10274 .68396 L
.10315 .6842 L
.10343 .68444 L
.10358 .68474 L
.10362 .68515 L
.10358 .68569 L
.1035 .68642 L
.10341 .68733 L
.10332 .68838 L
.10326 .68954 L
.10321 .69078 L
.10314 .69207 L
.10305 .69345 L
.10295 .69496 L
.10285 .69673 L
.10275 .69833 L
.10265 .70013 L
.10258 .702 L
.10252 .70378 L
.10247 .70543 L
.10245 .70692 L
.10243 .70813 L
.10243 .70917 L
.10245 .71006 L
.10249 .71081 L
.10255 .71142 L
.10261 .71187 L
.10268 .71214 L
.10274 .71225 L
.10279 .71225 L
Mistroke
.10281 .71217 L
.10281 .71206 L
.10279 .71194 L
.10276 .71185 L
.10275 .7118 L
.10275 .71177 L
.10275 .71173 L
.10275 .71166 L
.10276 .71158 L
.10276 .71147 L
.10276 .71134 L
.10276 .71122 L
.10275 .71114 L
.10272 .71111 L
.10268 .7111 L
.10264 .71111 L
.10261 .7111 L
.10261 .71111 L
.10263 .71113 L
.10266 .7112 L
.10272 .71132 L
.10281 .71152 L
.10297 .71184 L
.10324 .71231 L
.10361 .7129 L
.10409 .71364 L
.10471 .71452 L
.10545 .71555 L
.1063 .71664 L
.10723 .71785 L
.10813 .71914 L
.10904 .72046 L
.10992 .72182 L
.11073 .7231 L
.11151 .72435 L
.11225 .72554 L
.11298 .72664 L
.11372 .72767 L
.11451 .72867 L
.1154 .72978 L
.11633 .73087 L
.11737 .73215 L
.11855 .73358 L
.11978 .73507 L
.12121 .73667 L
.1228 .73841 L
.12452 .74022 L
.1263 .74185 L
.12808 .74355 L
.12968 .74494 L
Mistroke
.13121 .74617 L
.13241 .74721 L
.13338 .74798 L
.13402 .74846 L
.13432 .74868 L
.13431 .74869 L
.13413 .74856 L
.13387 .74835 L
.13361 .74811 L
.13336 .74794 L
.13319 .74791 L
.13309 .74807 L
.13308 .74844 L
.13322 .74896 L
.13362 .74963 L
.13443 .75044 L
.13532 .75125 L
.13666 .75216 L
.13819 .75313 L
.13996 .75413 L
.14183 .75515 L
.14384 .75612 L
.1458 .75704 L
.14777 .75788 L
.14977 .75863 L
.15167 .75925 L
.15346 .75976 L
.15507 .76018 L
.15643 .76054 L
.15753 .76083 L
.15846 .76112 L
.15907 .76136 L
.15956 .76165 L
.15993 .762 L
.16021 .76242 L
.16042 .76294 L
.16064 .76359 L
.16086 .76443 L
.16112 .76536 L
.16142 .76657 L
.16186 .76802 L
.16247 .76963 L
.16328 .77141 L
.16432 .77342 L
.16555 .77567 L
.16689 .77796 L
.16837 .7803 L
.17 .78278 L
.17169 .78523 L
.17352 .78774 L
Mistroke
.17552 .79026 L
.17765 .79271 L
.17993 .79509 L
.18217 .79736 L
.18442 .79946 L
.18647 .80135 L
.18831 .80288 L
.18994 .80423 L
.19128 .80527 L
.19242 .80611 L
.19334 .80679 L
.19412 .80735 L
.19483 .80787 L
.19553 .80843 L
.19627 .80909 L
.19704 .80985 L
.19793 .81074 L
.19892 .81177 L
.20013 .81298 L
.20161 .81442 L
.2033 .8161 L
.20522 .81787 L
.20719 .81973 L
.20925 .82155 L
.21133 .82345 L
.21313 .8249 L
.21488 .82637 L
.21639 .82766 L
.2177 .82872 L
.21874 .82959 L
.21956 .83031 L
.22016 .83085 L
.22055 .83123 L
.22078 .83151 L
.22089 .83173 L
.22093 .83193 L
.22097 .83213 L
.22107 .83237 L
.22128 .83267 L
.22161 .83304 L
.22209 .83346 L
.22271 .83393 L
.22343 .83442 L
.22418 .83492 L
.22495 .83533 L
.22572 .83575 L
.22644 .8361 L
.22704 .83636 L
.22753 .83652 L
.22788 .83661 L
Mistroke
.22811 .83665 L
.22823 .83665 L
.22828 .83665 L
.22833 .8367 L
.22848 .83686 L
.2288 .83715 L
.22934 .83762 L
.23013 .83825 L
.23117 .83905 L
.23242 .84005 L
.23397 .8412 L
.23579 .84254 L
.2377 .844 L
.23976 .84551 L
.24184 .84706 L
.24387 .84848 L
.24574 .84974 L
.24752 .85105 L
.24918 .85233 L
.25059 .85354 L
.25188 .85472 L
.25292 .85576 L
.25389 .85672 L
.25454 .85759 L
.25513 .85835 L
.25566 .85898 L
.25604 .85966 L
.25644 .86036 L
.25686 .86112 L
.25737 .86195 L
.25793 .86273 L
.25865 .86356 L
.25952 .86437 L
.26064 .86515 L
.26166 .86591 L
.26298 .86668 L
.26445 .8675 L
.26613 .86841 L
.26807 .86942 L
.27026 .87052 L
.27261 .87164 L
.27497 .87271 L
.27731 .87373 L
.27963 .87468 L
.28169 .87558 L
.28357 .87635 L
.28502 .87702 L
.2862 .87762 L
.28716 .87812 L
.28791 .87846 L
Mistroke
.28844 .87864 L
.28882 .87864 L
.28907 .87849 L
.28928 .87823 L
.28958 .87791 L
.29005 .8776 L
.29068 .87733 L
.29154 .87709 L
.29252 .8769 L
.29367 .87675 L
.29491 .87657 L
.29619 .87636 L
.29738 .87613 L
.29838 .87587 L
.29914 .87558 L
.29964 .87526 L
.29994 .87496 L
.30008 .87477 L
.30008 .87467 L
.29994 .87464 L
.29986 .87472 L
.29989 .87495 L
.30014 .87529 L
.30065 .87579 L
.30153 .87657 L
.3028 .87759 L
.30455 .87882 L
.30663 .8802 L
.30922 .88168 L
.31199 .88329 L
.31519 .88498 L
.31838 .88669 L
.32183 .88835 L
.32519 .88996 L
.32863 .89147 L
.33204 .89278 L
.33545 .89403 L
.33855 .89512 L
.34169 .8961 L
.34475 .897 L
.34774 .89782 L
.35061 .89859 L
.35341 .8993 L
.35611 .89998 L
.35882 .90067 L
.36149 .90134 L
.36403 .90203 L
.36656 .90276 L
.36905 .90355 L
.37135 .90436 L
Mistroke
.37348 .90516 L
.37536 .90591 L
.37692 .90658 L
.37818 .90714 L
.37918 .90758 L
.37992 .90785 L
.38049 .90798 L
.38093 .90796 L
.38132 .90777 L
.38176 .9074 L
.38234 .90687 L
.3831 .90623 L
.384 .90546 L
.38514 .90459 L
.38639 .90366 L
.38775 .90269 L
.38919 .90177 L
.39067 .90081 L
.39208 .90021 L
.39333 .89956 L
.39431 .89909 L
.39501 .89882 L
.39543 .89878 L
.39559 .89895 L
.39548 .89928 L
.39519 .89975 L
.39485 .90037 L
.39454 .90109 L
.39434 .9018 L
.39432 .90242 L
.39453 .90295 L
.39498 .90344 L
.39564 .90388 L
.39649 .90423 L
.39735 .90458 L
.39822 .90497 L
.399 .90537 L
.39964 .90576 L
.40006 .90615 L
.40026 .90654 L
.40026 .90679 L
.40011 .90695 L
.39982 .90692 L
.39945 .90676 L
.39886 .9064 L
.39838 .90574 L
.39781 .90491 L
.39728 .90406 L
.39682 .90289 L
.39651 .90164 L
Mistroke
.39635 .90021 L
.39631 .89892 L
.39634 .89772 L
.39639 .89673 L
.39643 .896 L
.39639 .89553 L
.39623 .89529 L
.39594 .89529 L
.39558 .89557 L
.39518 .89609 L
.3948 .89675 L
.39446 .89753 L
.39423 .89848 L
.39411 .89949 L
.39413 .90063 L
.39431 .90183 L
.39467 .90308 L
.39524 .90443 L
.39602 .90586 L
.39699 .90733 L
.39818 .90882 L
.39961 .9103 L
.40123 .91179 L
.40309 .91328 L
.40509 .91472 L
.40734 .91617 L
.40986 .91754 L
.41241 .91876 L
.41515 .91987 L
.41805 .92094 L
.42099 .92198 L
.42394 .92295 L
.42675 .92389 L
.42957 .92479 L
.43222 .9256 L
.43474 .92634 L
.43688 .92699 L
.43881 .9275 L
.44052 .92786 L
.442 .92815 L
.44333 .92841 L
.44454 .92869 L
.44575 .92898 L
.4468 .92924 L
.44799 .92947 L
.44926 .92964 L
.45057 .92969 L
.45199 .92962 L
.45351 .92946 L
.45502 .92927 L
Mistroke
.45655 .92913 L
.45806 .9291 L
.45957 .92917 L
.46103 .92933 L
.46253 .92942 L
.46407 .9295 L
.46568 .92959 L
.46738 .92971 L
.46915 .92984 L
.47098 .92999 L
.47301 .93018 L
.47515 .93044 L
.47741 .9307 L
.47972 .9309 L
.48213 .93099 L
.48457 .93094 L
.48707 .93078 L
.48989 .93056 L
.49223 .93038 L
.49468 .9302 L
.49698 .93006 L
.49903 .92997 L
.50067 .92993 L
.50191 .92993 L
.50268 .92994 L
.50317 .92994 L
.5034 .92992 L
.50344 .92992 L
.50335 .92998 L
.50307 .93003 L
.50269 .93006 L
.5023 .93004 L
.50194 .92994 L
.50162 .92973 L
.50142 .9294 L
.50128 .92896 L
.50129 .92845 L
.50149 .92791 L
.50186 .92736 L
.50233 .9268 L
.50261 .9262 L
.50277 .92552 L
.50282 .92483 L
.50277 .92416 L
.50273 .92351 L
.50268 .92296 L
.50261 .9225 L
.50261 .92219 L
.50261 .92199 L
.50259 .92192 L
Mistroke
.50249 .92198 L
.50229 .92213 L
.50194 .92226 L
.50141 .92229 L
.50068 .92227 L
.49969 .92226 L
.49843 .92224 L
.49695 .92226 L
.49526 .92235 L
.49344 .92252 L
.49134 .92271 L
.48889 .92289 L
.48663 .92303 L
.48413 .92319 L
.48152 .92335 L
.47884 .92347 L
.47611 .92367 L
.4733 .92394 L
.47056 .92428 L
.46778 .92458 L
.46498 .92499 L
.46226 .92524 L
.45944 .92541 L
.45664 .92546 L
.45387 .92549 L
.45114 .92551 L
.44841 .92555 L
.44583 .92561 L
.44322 .92568 L
.44088 .92573 L
.43852 .92567 L
.43608 .92546 L
.43402 .92512 L
.43194 .92465 L
.42991 .92408 L
.42783 .92344 L
.42576 .92275 L
.42371 .92206 L
.42162 .92134 L
.41945 .9206 L
.41719 .91984 L
.41493 .91904 L
.4125 .91817 L
.40984 .91725 L
.4071 .91631 L
.40424 .91538 L
.4013 .91445 L
.39819 .91352 L
.39505 .9126 L
.39194 .91165 L
Mistroke
.38871 .91065 L
.38559 .90962 L
.38241 .90855 L
.37931 .90744 L
.37623 .90632 L
.37304 .90521 L
.36996 .90414 L
.36688 .90318 L
.36385 .90227 L
.36079 .90139 L
.35785 .90052 L
.35495 .89962 L
.35189 .89867 L
.34877 .89767 L
.34579 .89662 L
.34267 .89555 L
.33945 .89448 L
.33649 .89347 L
.33362 .89249 L
.3307 .89155 L
.32817 .89067 L
.32549 .88984 L
.32341 .88913 L
.32153 .88853 L
.31982 .88807 L
.31837 .88776 L
.31722 .8876 L
.31637 .88754 L
.31571 .88751 L
.31513 .88743 L
.31451 .88723 L
.3138 .88687 L
.31296 .88635 L
.31191 .88564 L
.31058 .88479 L
.3092 .88389 L
.30772 .88292 L
.30625 .88193 L
.30487 .88097 L
.30353 .88007 L
.30223 .8793 L
.30114 .87867 L
.30026 .8782 L
.29958 .87792 L
.29912 .87778 L
.29888 .87774 L
.29883 .87773 L
.29892 .8777 L
.29908 .87754 L
.29925 .87722 L
Mistroke
.29938 .87678 L
.29944 .87624 L
.29944 .87562 L
.29941 .87503 L
.2994 .87454 L
.29959 .87418 L
.29976 .87397 L
.29997 .87391 L
.30013 .87403 L
.30025 .87432 L
.30024 .87473 L
.30004 .8752 L
.29958 .87567 L
.29883 .87619 L
.29777 .87664 L
.29638 .87694 L
.29477 .87701 L
.29279 .8768 L
.29063 .87631 L
.28826 .87563 L
.28555 .87476 L
.28271 .87376 L
.2798 .8728 L
.27725 .87184 L
.27461 .87095 L
.27226 .87024 L
.27015 .86959 L
.26837 .86904 L
.26687 .86856 L
.26558 .8681 L
.26458 .86766 L
.26372 .86723 L
.26296 .8668 L
.26244 .86641 L
.26199 .866 L
.26163 .86558 L
.26137 .86521 L
.2612 .86487 L
.26106 .86451 L
.26091 .86417 L
.2607 .86387 L
.26048 .86362 L
.26014 .86341 L
.2597 .86322 L
.25914 .863 L
.25842 .86271 L
.25751 .86228 L
.25644 .86169 L
.25521 .8609 L
.25388 .85995 L
Mistroke
.25238 .8588 L
.25069 .85747 L
.24885 .85606 L
.24701 .85457 L
.24516 .85306 L
.24341 .85155 L
.24186 .85011 L
.24052 .84887 L
.23942 .84784 L
.23851 .84702 L
.23773 .84632 L
.23709 .84578 L
.23648 .84527 L
.23581 .84469 L
.23517 .84412 L
.23457 .8436 L
.23384 .84293 L
.23299 .84215 L
.23196 .84121 L
.2307 .84012 L
.22925 .83884 L
.22766 .83747 L
.22587 .83595 L
.22392 .83428 L
.22186 .83247 L
.21973 .83062 L
.21754 .82868 L
.21542 .82677 L
.21329 .82484 L
.21114 .82292 L
.20909 .8212 L
.20708 .81949 L
.20513 .81774 L
.20328 .8161 L
.20151 .8144 L
.19986 .81265 L
.19832 .81095 L
.19685 .80923 L
.19546 .80753 L
.19418 .80595 L
.19298 .80444 L
.19186 .80318 L
.19084 .80195 L
.18986 .80089 L
.18891 .79987 L
.18794 .79886 L
.18695 .79793 L
.18589 .79706 L
.18474 .79624 L
.18351 .79543 L
Mistroke
.18218 .79461 L
.18077 .79373 L
.17939 .79274 L
.17788 .79171 L
.17632 .79039 L
.1747 .78899 L
.17295 .78738 L
.17122 .78568 L
.16942 .78383 L
.16759 .78186 L
.16584 .77991 L
.16415 .77802 L
.16253 .77608 L
.16095 .77409 L
.15934 .77211 L
.15787 .77018 L
.15637 .76821 L
.15488 .76629 L
.15341 .76448 L
.15208 .76282 L
.15085 .76131 L
.14976 .75994 L
.1487 .75871 L
.14762 .75755 L
.14645 .75647 L
.14544 .75543 L
.14418 .75438 L
.1427 .75328 L
.14111 .75202 L
.13927 .7508 L
.13745 .74942 L
.13538 .7479 L
.13329 .74624 L
.13142 .74443 L
.12947 .74251 L
.12732 .74047 L
.1252 .73837 L
.12307 .73623 L
.12106 .73408 L
.11902 .73195 L
.11715 .73 L
.11537 .72814 L
.11365 .72646 L
.11213 .72491 L
.1107 .72352 L
.10935 .72228 L
.10813 .72116 L
.10714 .72016 L
.1063 .71924 L
.10565 .71844 L
Mistroke
.10519 .71781 L
.10495 .71735 L
.10488 .71702 L
.10495 .71679 L
.10509 .7166 L
.10527 .71644 L
.10545 .7163 L
.10562 .71616 L
.10577 .716 L
.10587 .71583 L
.10592 .71569 L
.10591 .7156 L
.10585 .71555 L
.10572 .71547 L
.10551 .71532 L
.10525 .71506 L
.10495 .71467 L
.10464 .71413 L
.10433 .71338 L
.10408 .71266 L
.10383 .7118 L
.1036 .71088 L
.10337 .70989 L
.10315 .70875 L
.10291 .70736 L
.10269 .70571 L
.10249 .70385 L
.10228 .70198 L
.10206 .70012 L
.10181 .69835 L
.10153 .69673 L
.10121 .6953 L
.10085 .69409 L
.1005 .6931 L
.10019 .69231 L
.09994 .69169 L
.09975 .69121 L
.09962 .69086 L
.09956 .69068 L
.09957 .69063 L
.09964 .69067 L
.09982 .69068 L
.10008 .69065 L
.10038 .69057 L
.1007 .69046 L
.10099 .69031 L
.10122 .69016 L
.10137 .69006 L
.10141 .69009 L
.10134 .69021 L
Mistroke
.10115 .69037 L
.1009 .69047 L
.10059 .69041 L
.10023 .6901 L
.09981 .6896 L
.09931 .68901 L
.09872 .68815 L
.09808 .68702 L
.09742 .68561 L
.09678 .68396 L
.09619 .68207 L
.0956 .68016 L
.09502 .67793 L
.0944 .67527 L
.09374 .67246 L
.09301 .66929 L
.0922 .66588 L
.09138 .66199 L
.09057 .65804 L
.08981 .65373 L
.08911 .65007 L
.08849 .64625 L
.08794 .64306 L
.08745 .6402 L
.08706 .63742 L
.08674 .63487 L
.08653 .63287 L
.0864 .63164 L
.08637 .63099 L
.08639 .6306 L
.08639 .63022 L
.08633 .62977 L
.08619 .62918 L
.08595 .6281 L
.08559 .62631 L
.08519 .62406 L
.08474 .62149 L
.08425 .61876 L
.08377 .61592 L
.08329 .61309 L
.08282 .61031 L
.08244 .60782 L
.08213 .60558 L
.08189 .60373 L
.08177 .60229 L
.08179 .60126 L
.08194 .60063 L
.0822 .60038 L
.08254 .60039 L
.08291 .60057 L
Mistroke
.08328 .60088 L
.08363 .60127 L
.08395 .60167 L
.08421 .60206 L
.08441 .60238 L
.08458 .60263 L
.08473 .6028 L
.08484 .6029 L
.08491 .60296 L
.08493 .60298 L
.08491 .60297 L
.08487 .60293 L
.08483 .60289 L
.08479 .60286 L
.08478 .60285 L
.08478 .60285 L
.0848 .60286 L
.08486 .60288 L
.08494 .60292 L
.08501 .60299 L
.08505 .60311 L
.08503 .60327 L
.08495 .60344 L
.08478 .60359 L
.08451 .60364 L
.08413 .60352 L
.08366 .60316 L
.08311 .6025 L
.08251 .60148 L
.0819 .60012 L
.0813 .59836 L
.08068 .5962 L
.08006 .59388 L
.07948 .59123 L
.07896 .58818 L
.0785 .58519 L
.07811 .58193 L
.07777 .57865 L
.07747 .5753 L
.07719 .5721 L
.0769 .56892 L
.07658 .56579 L
.07619 .56266 L
.07574 .55953 L
.07525 .55633 L
.07473 .553 L
.07417 .5494 L
.07356 .54598 L
.07291 .54237 L
.07227 .53875 L
Mistroke
.07162 .53515 L
.07097 .53167 L
.07035 .52837 L
.06975 .52507 L
.06919 .52201 L
.0687 .51899 L
.06832 .51612 L
.06803 .51334 L
.06784 .51065 L
.06776 .50789 L
.06779 .50511 L
.06794 .50208 L
.0682 .49908 L
.06856 .49585 L
.06903 .49253 L
.06956 .48908 L
.07017 .48577 L
.07076 .4826 L
.07136 .47976 L
.07193 .47721 L
.07245 .47496 L
.07291 .4731 L
.07331 .47156 L
.07365 .47026 L
.07394 .46915 L
.07416 .46821 L
.07431 .46739 L
.0744 .46667 L
.07444 .46599 L
.07444 .46531 L
.07445 .46461 L
.0745 .46382 L
.07459 .46294 L
.07473 .46201 L
.07494 .46107 L
.07522 .46023 L
.07553 .45952 L
.07584 .45895 L
.07613 .4585 L
.07641 .45814 L
.07666 .45784 L
.07686 .45755 L
.07701 .45722 L
.0771 .45684 L
.07716 .4564 L
.07723 .45596 L
.07731 .45553 L
.07742 .45512 L
.07753 .45473 L
.07763 .45433 L
Mistroke
.07775 .45393 L
.07792 .45351 L
.07814 .4531 L
.07842 .4527 L
.07875 .45233 L
.07912 .45196 L
.07954 .45161 L
.07998 .45126 L
.08044 .4509 L
.08085 .45051 L
.0812 .45007 L
.08148 .44967 L
.08177 .44928 L
.08204 .44895 L
.08231 .44869 L
.08256 .4485 L
.08278 .44838 L
.08295 .44833 L
Mfstroke
.07677 .47979 m
.07671 .47992 L
.07662 .48017 L
.07647 .48056 L
.07621 .48112 L
.07584 .48188 L
.07534 .48286 L
.0747 .48399 L
.07411 .48521 L
.07337 .48665 L
.07257 .48837 L
.07174 .49037 L
.071 .4923 L
.07017 .49472 L
.06945 .49681 L
.06879 .49913 L
.0682 .50174 L
.06772 .50439 L
.06738 .50647 L
.06719 .50889 L
.06715 .51138 L
.06722 .51337 L
.06739 .51531 L
.06762 .51701 L
.06789 .51855 L
.06816 .51971 L
.06841 .52075 L
.06866 .52143 L
.06891 .52185 L
.06915 .52202 L
.06937 .52199 L
.06954 .52185 L
.06965 .52166 L
.06969 .52146 L
.06967 .52132 L
.06961 .52128 L
.06952 .52141 L
.06945 .52176 L
.06942 .52233 L
.06946 .52313 L
.0696 .52412 L
.06981 .52531 L
.07009 .52657 L
.07045 .52796 L
.07085 .52945 L
.07127 .53096 L
.07173 .53239 L
.0722 .53375 L
.07267 .53495 L
.07309 .53594 L
Mistroke
.07348 .53674 L
.07382 .53733 L
.07408 .53773 L
.07427 .53795 L
.07437 .53805 L
.07441 .53806 L
.0744 .53801 L
.07436 .53791 L
.07431 .53778 L
.07427 .53762 L
.07424 .53744 L
.07423 .53731 L
.07423 .53722 L
.07423 .53721 L
.07423 .53729 L
.07422 .5375 L
.07419 .53785 L
.07414 .53835 L
.07407 .53901 L
.074 .53983 L
.07394 .54081 L
.0739 .5419 L
.07391 .5431 L
.07395 .54442 L
.07405 .54581 L
.07418 .5472 L
.07435 .5485 L
.07454 .5497 L
.07473 .55075 L
.07493 .55162 L
.07517 .55231 L
.07544 .55285 L
.07574 .55327 L
.07605 .5536 L
.07633 .55391 L
.07656 .55422 L
.07672 .55455 L
.07681 .5549 L
.07685 .5553 L
.07687 .55573 L
.0769 .55624 L
.07697 .55683 L
.07711 .55753 L
.07732 .55831 L
.07756 .55913 L
.07783 .55997 L
.07811 .56081 L
.07837 .56161 L
.07869 .56236 L
.07903 .56302 L
Mistroke
.07941 .56357 L
.07978 .56406 L
.08017 .56447 L
.08052 .56482 L
.08081 .5651 L
.08101 .56533 L
.08112 .5655 L
.08115 .5656 L
.08114 .56563 L
.0811 .5656 L
.08106 .56553 L
.08101 .56545 L
.08096 .56535 L
.08092 .56524 L
.08088 .56512 L
.08085 .56502 L
.08083 .56497 L
.08084 .56497 L
.08089 .56505 L
.08099 .56525 L
.08113 .56561 L
.0813 .56613 L
.08147 .56681 L
.08166 .56765 L
.08185 .56865 L
.08204 .56974 L
.08223 .57091 L
.0824 .5721 L
.08257 .57325 L
.08273 .57429 L
.08288 .57514 L
.08299 .57574 L
.08306 .57611 L
.0831 .57626 L
.08311 .57618 L
.08311 .5759 L
.08312 .57547 L
.08315 .57494 L
.0832 .57439 L
.08325 .57383 L
.0833 .57328 L
.08333 .57277 L
.08334 .57238 L
.08333 .57215 L
.08332 .57205 L
.08331 .57203 L
.08331 .57206 L
.08333 .57209 L
.08336 .57209 L
.0834 .57204 L
Mistroke
.08344 .57197 L
.08346 .57192 L
.08345 .57195 L
.08341 .57207 L
.08332 .57232 L
.08319 .57272 L
.08301 .57324 L
.08276 .57386 L
.08244 .57457 L
.08205 .57537 L
.08161 .57622 L
.08116 .57708 L
.08073 .57792 L
.08032 .57872 L
.07996 .57946 L
.07964 .58009 L
.07935 .58062 L
.07912 .58102 L
.07892 .58132 L
.07876 .58154 L
.07865 .58169 L
.07859 .58182 L
.07858 .58195 L
.07861 .58211 L
.07869 .58228 L
.0788 .58246 L
.07893 .58265 L
.07907 .58286 L
.07918 .58304 L
.0793 .58325 L
.07943 .58347 L
.07955 .58363 L
.07971 .58378 L
.0799 .5839 L
.08007 .58397 L
.0802 .58402 L
.08028 .58407 L
.08031 .58414 L
.0803 .5842 L
.08029 .58422 L
.08027 .58422 L
.08026 .58421 L
.08025 .58419 L
.08024 .58417 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
Mistroke
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58415 L
.08023 .58414 L
.08023 .5841 L
.08023 .58401 L
.08024 .58389 L
.08024 .58378 L
.08024 .58371 L
.08024 .58371 L
.08024 .58383 L
.08023 .58409 L
.08022 .5845 L
.08019 .58508 L
.08017 .58582 L
.08013 .58671 L
.08009 .58774 L
.08005 .58878 L
.08001 .58986 L
.07997 .59096 L
.07993 .59208 L
.07989 .59304 L
.07986 .59387 L
.07982 .59448 L
.07978 .59488 L
.07973 .59511 L
.07968 .5952 L
.07965 .59521 L
.07964 .59523 L
.07965 .59532 L
.07969 .59559 L
.07978 .59607 L
.07992 .59682 L
.08014 .59788 L
.08042 .59933 L
Mistroke
.08079 .60104 L
.0812 .60312 L
.08167 .60559 L
.0822 .6083 L
.08279 .61155 L
.0834 .61495 L
.08402 .61821 L
.08463 .62201 L
.08521 .62616 L
.08574 .62968 L
.08624 .63368 L
.08672 .63797 L
.08718 .64138 L
.08761 .64516 L
.08802 .64859 L
.08842 .65193 L
.08878 .65472 L
.08912 .65727 L
.08941 .6594 L
.08966 .66095 L
.08989 .66224 L
.0901 .66325 L
.09032 .66398 L
.09053 .6645 L
.09074 .6649 L
.09096 .66529 L
.09116 .66575 L
.09136 .66628 L
.09154 .6669 L
.09173 .66767 L
.09194 .66857 L
.0922 .66965 L
.09249 .67085 L
.09281 .67207 L
.09312 .67331 L
.09343 .67456 L
.09372 .67572 L
.094 .67689 L
.09429 .67813 L
.09458 .67953 L
.0949 .68111 L
.0953 .68297 L
.0957 .68464 L
.09615 .68677 L
.09663 .68915 L
.09709 .69138 L
.09756 .69386 L
.09803 .69647 L
.09851 .69904 L
.099 .70185 L
Mistroke
.09948 .70391 L
.09994 .70604 L
.10034 .70791 L
.10066 .70944 L
.10089 .71063 L
.10104 .71146 L
.10116 .712 L
.10126 .71223 L
.10135 .71231 L
.10146 .7123 L
.10157 .71221 L
.10167 .71214 L
.10177 .7121 L
.10186 .71211 L
.10193 .71217 L
.102 .71226 L
.10208 .71237 L
.10218 .71249 L
.10231 .71259 L
.10246 .71271 L
.10261 .71287 L
.10275 .71306 L
.10286 .7133 L
.10294 .71354 L
.10296 .71377 L
.10293 .71392 L
.10283 .71397 L
.10269 .71393 L
.10253 .71382 L
.10232 .71367 L
.10209 .71349 L
.10185 .71332 L
.10164 .71326 L
.10146 .71324 L
.10134 .71324 L
.10129 .71324 L
.10132 .71328 L
.10144 .71339 L
.10165 .71359 L
.10197 .7139 L
.10238 .71432 L
.10284 .7148 L
.10332 .71534 L
.10379 .71579 L
.10423 .71626 L
.10464 .71662 L
.10501 .71683 L
.10533 .71696 L
.10565 .71703 L
.10599 .71705 L
Mistroke
.10637 .71701 L
.10679 .71693 L
.10725 .71683 L
.10771 .71674 L
.10821 .71665 L
.10868 .71665 L
.10915 .71669 L
.10956 .71673 L
.1099 .71683 L
.11013 .71698 L
.11022 .71718 L
.11017 .71735 L
.10999 .71746 L
.10967 .71757 L
.10925 .71769 L
.10877 .71779 L
.10825 .71786 L
.10773 .71787 L
.10726 .71784 L
.10686 .71781 L
.10657 .71783 L
.1064 .7179 L
.10635 .71802 L
.10645 .7182 L
.10667 .71848 L
.10697 .71888 L
.10735 .71937 L
.10778 .7199 L
.10826 .72047 L
.10882 .72108 L
.10927 .72159 L
.10978 .72218 L
.11024 .72279 L
.11064 .72339 L
.11096 .72393 L
.11118 .72436 L
.11129 .72468 L
.11133 .72489 L
.11133 .72502 L
.11133 .72508 L
.11148 .72502 L
.11149 .72503 L
.11155 .72506 L
.11162 .72511 L
.11171 .72518 L
.11181 .72523 L
.11192 .72527 L
.11203 .72527 L
.11213 .72526 L
.11223 .72523 L
Mistroke
.11233 .72519 L
.11243 .72518 L
.1125 .72519 L
.11252 .72521 L
.11248 .72522 L
.11236 .72519 L
.11217 .7251 L
.11194 .72494 L
.11171 .72473 L
.11149 .72453 L
.11129 .72435 L
.11115 .72424 L
.11105 .7242 L
.11098 .72423 L
.11092 .72431 L
.11087 .72443 L
.11078 .72456 L
.11067 .72469 L
.11054 .72481 L
.11042 .7249 L
.11035 .72498 L
.11036 .72511 L
.11044 .72528 L
.1106 .72546 L
.1108 .72561 L
.11102 .72569 L
.11126 .72573 L
.11155 .72574 L
.11181 .72573 L
.1121 .72571 L
.11237 .72569 L
.11262 .72566 L
.11279 .72562 L
.11285 .72553 L
.11279 .72537 L
.11264 .72518 L
.11241 .72497 L
.11213 .72473 L
.11181 .72448 L
.1115 .72424 L
.11122 .72406 L
.11101 .72399 L
.11089 .72408 L
.11089 .72436 L
.11104 .72486 L
.11134 .72554 L
.11181 .72645 L
.11243 .72737 L
.11318 .72841 L
.114 .72951 L
Mistroke
.11495 .73062 L
.116 .73172 L
.11714 .73283 L
.11833 .73394 L
.11953 .73498 L
.12069 .73593 L
.12178 .73676 L
.12276 .73746 L
.12359 .73805 L
.12427 .7385 L
.1248 .73883 L
.12515 .73907 L
.12538 .73929 L
.12546 .73954 L
.12542 .73975 L
.12528 .73995 L
.12508 .7401 L
.12481 .74022 L
.12455 .74031 L
.1243 .74042 L
.12406 .74052 L
.12385 .74064 L
.12377 .74082 L
.12379 .74104 L
.12392 .74126 L
.12411 .74145 L
.12439 .74159 L
.12473 .74168 L
.12513 .74175 L
.12558 .74176 L
.12602 .74177 L
.12647 .74175 L
.12686 .74172 L
.12722 .7417 L
.12756 .74171 L
.12789 .74176 L
.12818 .74183 L
.12843 .74188 L
.12859 .74187 L
.12865 .74181 L
.12859 .74174 L
.12845 .74166 L
.12827 .74159 L
.12809 .74153 L
.12794 .74146 L
.12781 .74141 L
.12772 .74141 L
.12767 .7415 L
.12765 .7417 L
.12765 .74198 L
Mistroke
.12766 .74232 L
.12772 .74273 L
.1278 .74319 L
.12789 .74373 L
.128 .74429 L
.12811 .74481 L
.12823 .74534 L
.12834 .74582 L
.12847 .74626 L
.12863 .74666 L
.12885 .74701 L
.12917 .74729 L
.1296 .7475 L
.13017 .7477 L
.13088 .74783 L
.13166 .7479 L
.13253 .74793 L
.13341 .74796 L
.13428 .74802 L
.13509 .74809 L
.13581 .74816 L
.13638 .74821 L
.13671 .74827 L
.13701 .74831 L
.13721 .74834 L
.13728 .74836 L
.13723 .74836 L
.13706 .74833 L
.1368 .74828 L
.13649 .74824 L
.13616 .74819 L
.1358 .74812 L
.13542 .74802 L
.13503 .74788 L
.13463 .74773 L
.13425 .74761 L
.13395 .74757 L
.13376 .74765 L
.13371 .74789 L
.13381 .74829 L
.13405 .74886 L
.13443 .74957 L
.13497 .75042 L
.13557 .75135 L
.13613 .75229 L
.13687 .75325 L
.13775 .75428 L
.13869 .75528 L
.13972 .7563 L
.14082 .75734 L
Mistroke
.14197 .7584 L
.14319 .75948 L
.14447 .7606 L
.14575 .76173 L
.14707 .76292 L
.14856 .76426 L
.14979 .76541 L
.15118 .76674 L
.15249 .76804 L
.15373 .76934 L
.15482 .77056 L
.15568 .77163 L
.15633 .77251 L
.15679 .77319 L
.15705 .77367 L
.15713 .77397 L
.15705 .77412 L
.15685 .77413 L
.15655 .77402 L
.1562 .77381 L
.15585 .77357 L
.15554 .77334 L
.15535 .77322 L
.15535 .77326 L
.15559 .77354 L
.1561 .77403 L
.15691 .77481 L
.15798 .77587 L
.15938 .77721 L
.16112 .77885 L
.16317 .78079 L
.16546 .78276 L
.16797 .78496 L
.17076 .78754 L
.1735 .78996 L
.17641 .79256 L
.17935 .79522 L
.18233 .79789 L
.18523 .80061 L
.18817 .80329 L
.19115 .80605 L
.1942 .80886 L
.19732 .81178 L
.2006 .81507 L
.20366 .81789 L
.20695 .82118 L
.21033 .82452 L
.21368 .82773 L
.21698 .83095 L
.22024 .83412 L
Mistroke
.22326 .83707 L
.22615 .83985 L
.22874 .84232 L
.23109 .84454 L
.23311 .84631 L
.23483 .84774 L
.23622 .8488 L
.23741 .84952 L
.23818 .84993 L
.23881 .85017 L
.23924 .85025 L
.23948 .85023 L
.23964 .85017 L
.2397 .85008 L
.23973 .85 L
.23976 .84996 L
.23986 .85006 L
.24003 .85028 L
.24032 .85063 L
.24076 .85111 L
.24137 .85174 L
.24214 .85247 L
.24306 .85322 L
.2441 .85396 L
.24535 .85471 L
.24673 .85544 L
.24825 .85621 L
.24985 .85696 L
.25144 .85771 L
.253 .85842 L
.2544 .85903 L
.25558 .85946 L
.25653 .85975 L
.25729 .85997 L
.25788 .86014 L
.2583 .86025 L
.25859 .86028 L
.25875 .86027 L
.25876 .86025 L
.25865 .86023 L
.25844 .86021 L
.25816 .86018 L
.25783 .86014 L
.25752 .86013 L
.25724 .86013 L
.25698 .86023 L
.25673 .86037 L
.25647 .86058 L
.25632 .8608 L
.25611 .86097 L
Mistroke
.25593 .86119 L
.25584 .86147 L
.25595 .86189 L
.25625 .8624 L
.25683 .86308 L
.25772 .86391 L
.2589 .86485 L
.26037 .86585 L
.26206 .86684 L
.26402 .86791 L
.26621 .86903 L
.26868 .87024 L
.27126 .87152 L
.27389 .87278 L
.27665 .87403 L
.27935 .87527 L
.28222 .87644 L
.28483 .8776 L
.28751 .87874 L
.29018 .87983 L
.29281 .88091 L
.29543 .88195 L
.29807 .88296 L
.30077 .88393 L
.30358 .88487 L
.30657 .88578 L
.3096 .88667 L
.31282 .88755 L
.31626 .88845 L
.31951 .88936 L
.32283 .8903 L
.3262 .89125 L
.32964 .89219 L
.3327 .89314 L
.33573 .89406 L
.33854 .89492 L
.34106 .89569 L
.3433 .89639 L
.34524 .89702 L
.34683 .89756 L
.34824 .89802 L
.34944 .89842 L
.35061 .89878 L
.35179 .89914 L
.35304 .89954 L
.35441 .9 L
.35591 .90055 L
.35762 .90117 L
.35961 .90188 L
.36176 .9027 L
Mistroke
.36423 .90363 L
.36704 .90461 L
.37006 .90561 L
.37344 .90666 L
.37676 .90773 L
.38041 .90883 L
.38387 .91 L
.38739 .91116 L
.39106 .91241 L
.39465 .91377 L
.39834 .91504 L
.4021 .9164 L
.40596 .91773 L
.40979 .91915 L
.41368 .9205 L
.41775 .92203 L
.42171 .92339 L
.42588 .92475 L
.42994 .92611 L
.4341 .9274 L
.43809 .92857 L
.44216 .92957 L
.44593 .93037 L
.44962 .93103 L
.45306 .93163 L
.45626 .93214 L
.45936 .93256 L
.46194 .93288 L
.46436 .93308 L
.46651 .93316 L
.46843 .93312 L
.47003 .933 L
.47148 .93279 L
.47252 .93259 L
.47339 .93242 L
.47407 .93231 L
.47462 .93223 L
.47502 .93213 L
.47533 .93201 L
.47558 .93189 L
.47577 .93176 L
.47587 .93165 L
.4759 .93155 L
.47585 .93148 L
.47575 .93146 L
.47558 .93147 L
.4754 .93151 L
.47521 .93156 L
.47501 .9316 L
.47476 .93163 L
Mistroke
.47447 .93165 L
.47414 .93167 L
.47384 .93169 L
.47349 .9317 L
.47314 .93172 L
.47283 .93173 L
.47258 .93173 L
.47235 .93172 L
.47214 .93172 L
.47201 .93173 L
.47193 .93175 L
.4719 .93179 L
.47195 .93151 L
.47207 .93156 L
.47225 .93162 L
.47249 .93167 L
.47282 .93171 L
.4732 .93174 L
.47357 .93176 L
.47387 .93179 L
.47418 .93182 L
.47445 .93186 L
.47466 .93191 L
.47484 .93198 L
.47505 .93206 L
.47528 .93215 L
.47556 .93224 L
.47589 .93232 L
.47632 .93235 L
.47686 .93236 L
.47753 .93234 L
.47833 .93228 L
.47933 .93219 L
.48051 .93204 L
.48186 .93182 L
.48336 .93157 L
.48492 .93129 L
.48659 .93101 L
.48836 .93074 L
.49029 .9305 L
.4923 .93028 L
.49462 .93008 L
.49666 .92992 L
.49906 .92974 L
.50152 .92954 L
.5042 .92932 L
.50704 .92906 L
.51014 .92876 L
.51325 .92842 L
.51633 .92803 L
Mistroke
.51937 .92764 L
.52254 .92723 L
.52553 .9268 L
.52849 .92637 L
.53145 .92596 L
.53408 .92558 L
.53675 .92522 L
.53936 .92488 L
.54193 .92456 L
.54446 .92418 L
.54697 .92372 L
.54942 .92313 L
.55186 .92244 L
.5542 .92163 L
.55642 .92085 L
.55861 .92005 L
.56061 .91933 L
.56253 .91876 L
.56431 .91826 L
.56578 .91785 L
.56703 .91754 L
.5681 .91734 L
.56904 .91726 L
.56995 .91736 L
.57096 .91759 L
.57224 .91792 L
.57357 .91831 L
.5753 .91865 L
.5773 .91892 L
.57958 .91903 L
.58223 .91897 L
.58508 .91876 L
.5882 .91848 L
.59162 .91804 L
.59497 .91752 L
.5989 .91714 L
.60247 .91656 L
.60608 .91596 L
.60962 .91532 L
.61297 .91463 L
.6162 .91394 L
.61933 .91317 L
.62235 .91233 L
.62532 .9115 L
.62823 .91066 L
.63098 .90988 L
.63357 .90912 L
.63594 .90846 L
.63806 .90781 L
.63995 .90717 L
Mistroke
.64159 .90659 L
.64309 .90612 L
.64445 .90572 L
.64572 .90537 L
.64691 .90501 L
.64802 .90467 L
.64901 .90442 L
.64981 .90428 L
.65052 .90416 L
.65112 .90412 L
.65163 .90408 L
.6521 .90397 L
.65252 .90383 L
.65286 .90369 L
.65303 .90361 L
.65299 .90364 L
.65275 .90373 L
.65234 .90394 L
.65181 .90426 L
.65123 .90462 L
.65069 .90492 L
.65025 .90521 L
.6499 .90552 L
.64962 .90583 L
.64936 .90609 L
.64914 .90635 L
.64892 .90661 L
.64868 .90682 L
.6485 .90693 L
.64844 .90691 L
.64841 .90683 L
.64851 .90652 L
.64871 .90603 L
.64897 .90543 L
.64917 .90489 L
.64933 .90437 L
.64943 .90383 L
.64956 .90325 L
.64968 .90282 L
.64987 .90237 L
.65008 .90201 L
.6503 .90179 L
.65044 .90176 L
.65054 .90185 L
.65058 .90204 L
.65052 .90227 L
.65038 .90262 L
.65024 .90295 L
.65016 .90318 L
.65022 .90336 L
Mistroke
.6504 .90347 L
.65069 .90352 L
.65112 .90339 L
.65159 .90326 L
.65199 .90312 L
.6523 .90296 L
.65252 .90273 L
.65263 .90262 L
.65255 .90268 L
.65233 .9029 L
.65194 .9032 L
.65141 .90366 L
.65081 .90419 L
.65026 .90467 L
.64982 .90495 L
.64951 .9051 L
.64925 .90519 L
.64906 .90523 L
.64906 .90517 L
.64919 .90509 L
.64938 .90502 L
.6497 .9049 L
.65006 .90474 L
.65039 .90461 L
.65063 .90458 L
.65075 .9046 L
.65072 .90474 L
.65059 .90497 L
.65043 .90522 L
.65023 .90549 L
.65007 .90572 L
.64996 .90582 L
.64991 .90584 L
.65001 .90566 L
.65024 .90537 L
.65055 .90499 L
.65082 .90468 L
.65112 .90435 L
.65142 .90406 L
.65177 .90378 L
.65203 .90362 L
.65229 .90347 L
.6525 .9034 L
.65268 .90339 L
.65285 .90347 L
.65307 .90358 L
.65336 .90366 L
.65367 .90373 L
.65391 .90385 L
.65402 .90403 L
Mistroke
.65402 .90423 L
.65391 .90447 L
.65373 .90471 L
.65352 .90489 L
.65336 .90497 L
.65324 .90497 L
.65316 .90491 L
.65307 .90479 L
.65301 .90461 L
.65298 .90443 L
.65293 .90429 L
.6529 .90417 L
.65293 .90403 L
.6531 .90387 L
.65341 .90369 L
.65378 .90353 L
.65422 .90336 L
.65462 .90324 L
.6549 .90321 L
.65504 .90328 L
.65505 .90344 L
.65498 .90365 L
.65483 .9039 L
.65466 .90411 L
.65449 .90428 L
.6543 .90426 L
.65412 .90436 L
.65394 .90444 L
.6538 .90447 L
.65376 .90441 L
.65375 .90434 L
.65384 .90418 L
.65399 .90396 L
.65418 .9037 L
.65431 .90351 L
.65444 .90331 L
.65455 .90314 L
.65461 .90303 L
.65454 .90303 L
.65442 .90308 L
.65426 .90313 L
.65404 .90325 L
.65371 .90349 L
.65337 .90378 L
.65309 .90408 L
.65287 .90441 L
.65265 .90482 L
.65247 .90525 L
.65236 .90565 L
.65227 .90607 L
Mistroke
.65222 .90651 L
.65223 .90697 L
.65228 .9074 L
.65231 .90778 L
.65232 .9081 L
.65232 .90832 L
.65242 .9084 L
.6526 .90835 L
.65289 .90819 L
.65335 .90784 L
.65393 .90732 L
.65455 .90675 L
.65512 .90622 L
.65568 .90564 L
.65617 .90512 L
.65657 .90469 L
.65691 .90436 L
.6572 .9041 L
.6574 .90395 L
.65753 .90393 L
.65761 .90399 L
.65771 .90404 L
.65777 .90409 L
.65779 .90413 L
.6578 .90415 L
.65788 .90407 L
.65807 .90393 L
.65841 .90375 L
.65886 .90356 L
.65945 .90334 L
.66008 .90311 L
.66076 .90286 L
.66141 .90261 L
.66204 .90234 L
.66263 .90207 L
.66318 .90185 L
.66366 .90171 L
.664 .90168 L
.66412 .90177 L
.66403 .90196 L
.66378 .90223 L
.66345 .90251 L
.66308 .90273 L
.66279 .90284 L
.66245 .90291 L
.66202 .90304 L
.6615 .9033 L
.66091 .90367 L
.66025 .90413 L
.65946 .90484 L
Mistroke
.65862 .90543 L
.65785 .90594 L
.65732 .90631 L
.657 .90653 L
.65683 .9066 L
.65675 .9066 L
.65665 .90655 L
.65638 .9066 L
.65623 .90654 L
.65614 .90642 L
.65624 .90617 L
.65666 .90574 L
.6573 .90522 L
.65807 .90469 L
.65882 .90418 L
.65949 .90374 L
.65987 .90349 L
.65988 .90344 L
.65962 .90353 L
.6591 .90362 L
.65845 .90372 L
.65767 .90382 L
.65695 .90388 L
.65635 .90384 L
.65594 .90369 L
.65567 .90348 L
.65542 .90331 L
.65516 .90322 L
.65494 .90324 L
.65481 .90338 L
.65481 .9036 L
.65495 .90385 L
.65521 .90408 L
.6555 .90428 L
.65571 .90446 L
.65577 .90465 L
.65562 .90487 L
.65536 .90511 L
.65503 .90536 L
.65471 .90557 L
.65445 .90565 L
.65435 .90561 L
.65433 .90551 L
.65438 .90539 L
.6545 .90525 L
.65461 .90517 L
.65471 .90513 L
.65477 .90509 L
.65481 .90508 L
.65491 .90507 L
Mistroke
.65514 .90504 L
.65547 .90499 L
.65594 .90491 L
.65639 .90486 L
.65673 .90489 L
.65697 .90498 L
.65711 .90515 L
.65718 .90535 L
.65726 .90549 L
.65739 .90549 L
.65756 .90538 L
.65768 .90521 L
.65766 .90502 L
.65741 .90489 L
.65695 .90478 L
.65635 .90463 L
.65577 .90448 L
.65534 .90421 L
.65524 .90362 L
.65519 .90332 L
.65533 .90308 L
.65561 .90291 L
.65603 .90284 L
.65642 .90285 L
.65679 .90294 L
.65708 .90305 L
.65729 .90317 L
.65742 .90331 L
.65742 .90351 L
.65731 .90377 L
.65704 .9041 L
.65661 .9045 L
.656 .90495 L
.65526 .90542 L
.65436 .90587 L
.65357 .90617 L
.65279 .90643 L
.65206 .90664 L
.65149 .90679 L
.65107 .90691 L
.65081 .907 L
.65075 .90696 L
.65083 .90683 L
.65111 .90659 L
.65156 .90626 L
.65215 .90583 L
.65287 .90529 L
.65363 .9048 L
.65437 .90442 L
.65514 .90408 L
Mistroke
.65591 .90382 L
.65661 .90368 L
.65727 .9036 L
.65787 .9035 L
.6584 .90341 L
.65878 .90338 L
.65899 .90339 L
.65901 .90348 L
.65886 .90364 L
.65859 .90386 L
.65831 .90405 L
.65812 .90414 L
.65815 .9041 L
.65842 .90393 L
.65882 .90373 L
.65937 .90346 L
.66003 .90317 L
.6609 .90283 L
.66168 .90254 L
.66262 .90221 L
.66354 .9019 L
.66439 .90164 L
.6651 .90142 L
.66567 .90123 L
.66609 .90105 L
.66629 .90097 L
.6662 .90101 L
.66587 .90117 L
.66534 .90141 L
.66472 .90169 L
.66399 .90201 L
.66325 .90232 L
.66263 .90259 L
.66224 .90278 L
.66208 .90291 L
.66217 .90299 L
.66252 .90299 L
.66303 .90298 L
.66365 .90297 L
.66455 .90284 L
.66586 .90237 L
.66717 .90212 L
.66864 .90176 L
.67024 .90129 L
.67195 .9007 L
.67371 .90002 L
.67554 .89927 L
.67739 .89844 L
.6792 .89754 L
.68087 .89657 L
Mistroke
.68249 .8955 L
.68402 .89444 L
.68543 .8933 L
.68665 .89223 L
.68765 .89129 L
.68842 .89048 L
.68896 .88982 L
.68924 .88936 L
.68928 .88912 L
.68908 .88909 L
.68867 .88924 L
.68809 .88953 L
.68746 .88992 L
.68677 .89045 L
.68608 .8911 L
.68552 .89166 L
.68505 .89223 L
.68476 .89261 L
.6847 .89275 L
.68486 .89267 L
.68515 .89242 L
.68544 .89208 L
.68574 .89171 L
.68602 .89136 L
.68628 .89104 L
.68651 .89076 L
.6867 .89049 L
.68687 .89025 L
.687 .89009 L
.68712 .89003 L
.68721 .89006 L
.68721 .89022 L
.68712 .8905 L
.687 .89088 L
.68695 .89128 L
.68701 .89162 L
.6872 .89186 L
.68749 .89201 L
.6878 .89203 L
.6881 .89204 L
.68836 .89211 L
.68851 .89227 L
.68863 .89248 L
.68876 .89267 L
.68899 .89279 L
.68942 .89277 L
.69007 .89258 L
.69097 .89221 L
.69183 .89182 L
.69285 .89133 L
Mistroke
.69387 .89079 L
.69478 .89021 L
.69576 .88965 L
.69663 .88907 L
.69739 .88849 L
.69799 .88795 L
.69838 .8875 L
.69854 .88717 L
.69842 .88697 L
.69801 .88695 L
.69731 .88713 L
.69645 .88742 L
.69561 .88773 L
.6948 .88802 L
.69429 .88813 L
.69364 .88838 L
.69302 .8886 L
.69245 .88886 L
.6919 .88918 L
.6914 .88961 L
.6909 .89011 L
.69039 .89065 L
.68988 .89115 L
.6894 .89157 L
.68891 .89195 L
.68852 .89219 L
.68812 .8924 L
.68778 .89252 L
.6875 .89257 L
.68731 .8926 L
.68723 .89261 L
.68716 .89261 L
.68712 .89259 L
.6871 .89257 L
.68705 .89257 L
.68698 .89256 L
.68682 .89268 L
.68657 .89294 L
.68625 .89329 L
.68589 .89367 L
.68548 .89401 L
.68501 .8943 L
.68446 .89452 L
.68386 .89466 L
.68322 .89471 L
.68258 .8947 L
.68202 .89469 L
.68143 .89473 L
.6809 .89484 L
.68045 .89503 L
Mistroke
.68006 .89528 L
.6797 .8956 L
.67938 .89597 L
.67913 .89638 L
.67894 .89681 L
.67878 .89725 L
.67862 .89768 L
.67843 .89812 L
.6782 .89853 L
.67793 .8989 L
.67762 .89921 L
.67733 .89944 L
.67707 .89961 L
.67686 .89971 L
.67668 .89975 L
.67659 .89974 L
.67654 .8997 L
.67652 .89964 L
.67654 .89959 L
.67658 .89958 L
.67662 .89962 L
.67665 .89969 L
.67667 .89975 L
.67667 .89977 L
.67669 .89971 L
.67669 .89957 L
.67667 .89937 L
.67661 .89915 L
.67651 .89892 L
.67636 .89871 L
.67622 .89846 L
.67615 .89818 L
.67616 .89785 L
.67624 .89751 L
.67636 .89718 L
.67647 .8969 L
.67654 .89671 L
.67654 .89664 L
.67649 .89671 L
.67641 .89693 L
.67631 .89726 L
.67619 .89762 L
.67611 .89795 L
.67607 .89817 L
.67612 .8983 L
.67608 .89839 L
.676 .89845 L
.67586 .89854 L
.67568 .89866 L
.67547 .89879 L
Mistroke
.6753 .89891 L
.6752 .89897 L
.67521 .89896 L
.67527 .89892 L
.67534 .89889 L
.67536 .89897 L
.67536 .89911 L
.67535 .89928 L
.67537 .89944 L
.6754 .89955 L
.67545 .89959 L
.67549 .89957 L
.67549 .89949 L
.67549 .89933 L
.67547 .89915 L
.67541 .89899 L
.67529 .89892 L
.67515 .89896 L
.67504 .89906 L
.67498 .8992 L
.67494 .89937 L
.67494 .89953 L
.67496 .89966 L
.67498 .89973 L
.67497 .89972 L
.67489 .8996 L
.67471 .89937 L
.67441 .89913 L
.67402 .89881 L
.6736 .89842 L
.67317 .89798 L
.67267 .89753 L
.67215 .89712 L
.67167 .89676 L
.67132 .89644 L
.67108 .89615 L
.67092 .8959 L
.6708 .89574 L
.67068 .89571 L
.67048 .8958 L
.67022 .89597 L
.66989 .89616 L
.66951 .89634 L
.66906 .89648 L
.66858 .89658 L
.66814 .89667 L
.66783 .89674 L
.66757 .8968 L
.66737 .89684 L
.66726 .89689 L
Mistroke
.66721 .89696 L
.66727 .89699 L
.66741 .897 L
.66757 .89706 L
.66763 .89724 L
.66757 .89752 L
.66733 .8979 L
.66696 .8983 L
.66646 .89873 L
.66589 .89917 L
.66515 .8996 L
.66457 .89991 L
.66399 .90014 L
.66341 .9003 L
.66282 .90038 L
.66231 .90038 L
.66188 .90035 L
.66148 .90024 L
.66125 .90043 L
.66102 .9002 L
.66088 .89989 L
.66072 .89958 L
.66038 .89924 L
.65997 .89897 L
.65955 .89877 L
.65908 .89858 L
.65866 .89845 L
.65832 .89831 L
.65824 .89828 L
.65835 .89829 L
.6587 .89839 L
.65924 .89855 L
.6599 .89875 L
.66057 .89894 L
.66125 .8991 L
.66193 .89922 L
.66271 .89928 L
.66352 .89927 L
.66433 .89923 L
.66508 .89917 L
.66576 .89906 L
.66634 .89882 L
.66684 .89848 L
.66729 .89807 L
.66769 .89764 L
.66807 .89726 L
.66851 .89694 L
.66909 .89673 L
.66985 .89664 L
.67071 .89663 L
Mistroke
.67163 .89664 L
.67273 .89662 L
.67398 .89653 L
.67538 .89633 L
.67688 .89603 L
.67848 .89567 L
.68014 .89522 L
.68186 .89472 L
.68359 .89417 L
.68533 .89358 L
.68709 .89293 L
.68869 .8922 L
.69041 .89139 L
.69213 .89048 L
.69393 .88949 L
.69577 .8884 L
.69764 .88719 L
.69954 .88584 L
.70148 .88434 L
.70346 .88268 L
.70546 .88092 L
.70746 .87906 L
.70946 .87714 L
.71144 .8752 L
.71342 .87326 L
.71557 .87107 L
.71726 .86941 L
.71893 .86762 L
.72039 .86608 L
.72161 .86478 L
.72259 .86379 L
.72335 .86311 L
.7239 .86271 L
.72425 .86252 L
.72443 .86248 L
.72448 .86255 L
.72441 .86268 L
.72423 .86283 L
.72397 .86294 L
.72368 .86295 L
.72336 .86284 L
.72304 .8626 L
.72275 .86225 L
.72247 .86178 L
.72222 .86117 L
.72198 .86049 L
.72173 .85984 L
.72146 .8593 L
.72114 .85887 L
.72078 .85862 L
Mistroke
.72042 .85857 L
.72009 .85876 L
.71981 .85915 L
.71959 .85953 L
.71941 .86026 L
.71923 .86105 L
.71902 .86211 L
.71874 .8631 L
.71836 .8641 L
.71784 .8653 L
.71721 .86636 L
.71643 .86748 L
.7155 .86864 L
.71446 .86967 L
.71326 .87072 L
.71191 .87168 L
.71051 .87258 L
.70897 .87342 L
.70744 .87427 L
.70583 .87513 L
.70429 .87599 L
.70279 .87689 L
.70133 .87789 L
.69987 .87901 L
.69834 .88024 L
.69678 .88155 L
.69513 .88292 L
.69334 .88428 L
.69159 .88575 L
.68969 .88731 L
.68765 .88893 L
.68554 .89055 L
.68344 .89206 L
.68134 .89345 L
.6793 .89468 L
.67746 .89572 L
.67572 .89656 L
.67418 .89719 L
.67286 .89762 L
.67184 .89795 L
.67088 .89828 L
.67005 .89857 L
.66925 .89884 L
.66837 .89917 L
.66739 .89957 L
.6663 .90005 L
.66495 .90054 L
.66326 .9011 L
.6612 .90177 L
.65894 .90253 L
Mistroke
.65598 .90343 L
.65306 .90436 L
.64948 .90537 L
.64585 .90636 L
.6418 .90729 L
.63809 .90823 L
.63415 .90917 L
.63044 .91004 L
.6265 .91084 L
.62301 .91158 L
.61935 .91229 L
.61592 .9129 L
.6128 .91344 L
.60952 .91384 L
.60637 .91412 L
.60325 .91425 L
.60011 .91434 L
.59719 .91444 L
.59405 .91455 L
.59111 .91463 L
.5879 .91476 L
.58464 .91497 L
.58097 .9153 L
.57748 .91571 L
.5737 .9162 L
.56945 .91676 L
.56576 .91736 L
.56162 .9181 L
.55779 .91893 L
.55372 .9198 L
.54998 .92061 L
.54616 .92132 L
.54233 .92192 L
.53887 .92238 L
.53545 .92275 L
.53219 .92301 L
.5292 .92323 L
.52645 .92345 L
.52404 .92374 L
.52211 .92412 L
.52016 .92453 L
.51855 .92497 L
.51704 .9254 L
.51571 .92581 L
.51459 .92616 L
.51368 .92645 L
.51301 .92664 L
.51253 .92669 L
.51222 .92664 L
.51206 .9265 L
Mistroke
.512 .92627 L
.51195 .92595 L
.51185 .92552 L
.5117 .92501 L
.51149 .92449 L
.51123 .92399 L
.51094 .9236 L
.51063 .92337 L
.51033 .9233 L
.51002 .92339 L
.50971 .92359 L
.50939 .92384 L
.50909 .92411 L
.50875 .92434 L
.50843 .92453 L
.50814 .92468 L
.50784 .92482 L
.50752 .92492 L
.50722 .92497 L
.50688 .92497 L
.50645 .92493 L
.50588 .92485 L
.50517 .92473 L
.50437 .92454 L
.5034 .92432 L
.50229 .92407 L
.50111 .92378 L
.4999 .92347 L
.49874 .92313 L
.49762 .92279 L
.49655 .92242 L
.49569 .92211 L
.49489 .9218 L
.49424 .92146 L
.4938 .92114 L
.49359 .92089 L
.49363 .92074 L
.49388 .92071 L
.49428 .92074 L
.4948 .92084 L
.49533 .92097 L
.49578 .92113 L
.49609 .92128 L
.49625 .92134 L
.49628 .92138 L
.49624 .92145 L
.49613 .92155 L
.49597 .92168 L
.49578 .92182 L
.49553 .92197 L
Mistroke
.49528 .92209 L
.4951 .9222 L
.49504 .92228 L
.4951 .92233 L
.4953 .92231 L
.49564 .92227 L
.49609 .92221 L
.4965 .92218 L
.49695 .92214 L
.49735 .92194 L
.49765 .92175 L
.4978 .92145 L
.49783 .92113 L
.49781 .92085 L
.49782 .92065 L
.4978 .92055 L
.49779 .92057 L
.4978 .92071 L
.49781 .92088 L
.49776 .9211 L
.49765 .92131 L
.49755 .92151 L
.4975 .92175 L
.49749 .922 L
.49751 .92229 L
.49756 .92261 L
.49757 .92292 L
.49751 .92315 L
.49733 .92325 L
.49709 .92326 L
.4969 .9232 L
.4968 .92314 L
.49682 .92305 L
.497 .92297 L
.49732 .92296 L
.49775 .92303 L
.49817 .9231 L
.4985 .92322 L
.49853 .92343 L
.49818 .92369 L
.49744 .92402 L
.4964 .92446 L
.49502 .925 L
.49344 .92562 L
.49156 .92614 L
.48951 .92667 L
.48741 .92722 L
.48504 .92774 L
.48234 .92813 L
.47988 .92847 L
Mistroke
.47752 .92878 L
.47529 .92907 L
.47335 .92939 L
.47179 .92974 L
.47064 .93012 L
.46972 .93045 L
.46896 .93072 L
.46829 .93089 L
.46766 .93094 L
.467 .93086 L
.46627 .93064 L
.46544 .9303 L
.46464 .92986 L
.46373 .92931 L
.46277 .92869 L
.46171 .92802 L
.46057 .92733 L
.45927 .92667 L
.45783 .92602 L
.45627 .92533 L
.45474 .92477 L
.45316 .92421 L
.45168 .92376 L
.45033 .92347 L
.44914 .92334 L
.44806 .92334 L
.44703 .92337 L
.44593 .92337 L
.44477 .92329 L
.44346 .92314 L
.44185 .92292 L
.44027 .92266 L
.43843 .92234 L
.4363 .92199 L
.43394 .9215 L
.4316 .92092 L
.42907 .92025 L
.42626 .91946 L
.42289 .91868 L
.41986 .9178 L
.41636 .91681 L
.41291 .91589 L
.4092 .91492 L
.40526 .91397 L
.40175 .913 L
.39779 .91206 L
.39402 .91103 L
.38991 .9099 L
.38574 .90866 L
.38198 .9074 L
Mistroke
.37798 .90606 L
.37405 .90466 L
.36999 .90329 L
.3664 .90191 L
.36266 .90052 L
.35895 .89917 L
.35535 .89782 L
.35181 .8965 L
.34811 .89516 L
.34452 .89385 L
.34113 .89257 L
.33751 .89129 L
.33396 .89006 L
.33016 .88889 L
.32675 .88777 L
.32316 .8867 L
.31946 .88567 L
.31611 .8847 L
.31286 .88376 L
.30948 .88283 L
.30623 .88187 L
.30289 .8809 L
.29969 .8799 L
.29639 .87881 L
.29311 .87766 L
.29022 .87642 L
.28712 .87511 L
.28418 .87383 L
.2812 .8725 L
.27837 .87117 L
.27567 .86989 L
.27293 .8686 L
.27039 .86734 L
.26783 .86609 L
.26554 .86485 L
.26334 .86368 L
.26132 .86256 L
.25954 .86148 L
.25799 .86047 L
.25671 .85957 L
.25569 .85871 L
.25489 .85793 L
.25434 .85726 L
.254 .85672 L
.25383 .85629 L
.25374 .8559 L
.25367 .85559 L
.25351 .85528 L
.2532 .85498 L
.25268 .85464 L
Mistroke
.25194 .85425 L
.25088 .85362 L
.24946 .85273 L
.24763 .85154 L
.24546 .8501 L
.243 .84838 L
.24014 .84629 L
.23704 .84402 L
.23376 .84155 L
.23027 .83882 L
.2269 .83617 L
.22342 .83334 L
.22008 .83046 L
.21679 .8279 L
.21358 .82517 L
.21055 .82246 L
.20758 .8198 L
.20474 .81714 L
.20196 .81465 L
.19926 .81213 L
.19661 .80971 L
.19399 .80725 L
.19131 .80468 L
.18869 .80217 L
.18614 .79974 L
.18368 .79725 L
.18136 .7948 L
.17913 .79255 L
.17715 .79037 L
.17523 .78833 L
.17373 .78653 L
.17241 .78485 L
.1713 .7833 L
.17041 .78196 L
.16965 .78075 L
.16899 .77964 L
.1683 .7786 L
.16751 .7776 L
.16656 .77656 L
.16536 .77543 L
.16393 .77416 L
.16216 .77269 L
.16001 .77095 L
.15801 .76912 L
.15564 .76703 L
.1529 .76487 L
.15054 .76265 L
.1479 .76028 L
.1451 .75779 L
.1427 .75551 L
Mistroke
.14006 .75306 L
.13736 .7505 L
.13506 .74796 L
.13267 .74547 L
.13026 .74296 L
.12824 .74071 L
.12613 .73845 L
.12404 .73623 L
.12207 .73408 L
.12011 .73198 L
.11823 .72989 L
.11656 .72813 L
.11496 .72647 L
.1135 .72496 L
.11222 .72363 L
.11123 .72251 L
.11031 .72152 L
.10955 .72062 L
.10885 .71968 L
.10818 .71863 L
.10753 .71748 L
.1069 .7162 L
.10629 .7148 L
.10574 .71342 L
.10529 .71191 L
.10489 .71046 L
.10456 .70912 L
.10426 .70787 L
.10396 .70654 L
.10367 .70534 L
.10338 .70417 L
.1031 .70301 L
.1028 .70183 L
.10246 .70061 L
.10207 .69929 L
.10161 .69776 L
.10108 .69597 L
.10045 .69393 L
.09977 .69196 L
.09902 .6896 L
.0982 .68705 L
.09736 .68426 L
.09655 .68128 L
.09579 .6784 L
.09512 .67557 L
.09458 .67267 L
.09418 .67004 L
.09391 .66764 L
.09373 .66532 L
.0936 .66313 L
Mistroke
.09346 .66109 L
.0933 .65914 L
.0931 .65723 L
.09286 .65543 L
.09259 .65361 L
.09229 .65179 L
.09195 .64992 L
.09158 .64807 L
.09113 .64602 L
.09059 .64383 L
.08999 .64131 L
.0893 .63878 L
.08854 .63587 L
.08772 .63275 L
.08688 .62948 L
.08604 .62617 L
.08526 .62243 L
.08457 .6191 L
.08395 .61562 L
.08338 .61203 L
.08288 .60907 L
.08242 .60611 L
.08202 .60346 L
.08169 .60121 L
.08141 .59924 L
.0812 .59777 L
.08104 .59667 L
.08095 .59587 L
.08091 .59536 L
.08096 .59508 L
.08098 .59498 L
.08103 .595 L
.08107 .5951 L
.08111 .5952 L
.08113 .59529 L
.08116 .59529 L
.08121 .59515 L
.08127 .59483 L
.08132 .59433 L
.08133 .59363 L
.08128 .5927 L
.08115 .59159 L
.08092 .59014 L
.08057 .5884 L
.08023 .58628 L
.0798 .58391 L
.07933 .58108 L
.07886 .57818 L
.07837 .57483 L
.07787 .57133 L
Mistroke
.07735 .5676 L
.07681 .56364 L
.07625 .55963 L
.07565 .55589 L
.07504 .55199 L
.07446 .54825 L
.07392 .54512 L
.07342 .54226 L
.07297 .53982 L
.07258 .53773 L
.07226 .53624 L
.07201 .53512 L
.07184 .53435 L
.07174 .53387 L
.07169 .5336 L
.07169 .53342 L
.07169 .53315 L
.07168 .53272 L
.07162 .53211 L
.07149 .53137 L
.07129 .53024 L
.071 .52877 L
.07064 .52677 L
.07023 .52438 L
.06981 .52183 L
.0694 .51884 L
.06902 .51594 L
.06871 .51231 L
.06848 .50924 L
.06832 .50596 L
.06827 .50241 L
.06832 .49883 L
.06849 .49489 L
.06876 .49137 L
.06916 .48767 L
.06961 .48405 L
.07013 .4806 L
.07072 .47743 L
.07126 .47442 L
.07183 .47189 L
.07235 .46961 L
.07281 .46769 L
.07321 .46624 L
.07355 .46513 L
.07384 .46436 L
.07409 .4639 L
.07431 .46368 L
.07448 .46363 L
Mfstroke
1 1 0 r
.008 w
.07141 .47512 Mdot
.016 w
.07141 .47512 m
.07125 .47526 L
s
1 .999 0 r
.008 w
.07125 .47526 Mdot
.016 w
.07125 .47526 m
.07104 .47563 L
s
.008 w
.07104 .47563 Mdot
.016 w
.07104 .47563 m
.07078 .47632 L
s
1 .998 0 r
.008 w
.07078 .47632 Mdot
.016 w
.07078 .47632 m
.07048 .47739 L
s
.008 w
.07048 .47739 Mdot
.016 w
.07048 .47739 m
.07015 .47889 L
s
1 .997 0 r
.008 w
.07015 .47889 Mdot
.016 w
.07015 .47889 m
.06979 .48076 L
s
.008 w
.06979 .48076 Mdot
.016 w
.06979 .48076 m
.0694 .48297 L
s
.008 w
.0694 .48297 Mdot
.016 w
.0694 .48297 m
.069 .48574 L
s
1 .996 0 r
.008 w
.069 .48574 Mdot
.016 w
.069 .48574 m
.06859 .48906 L
s
.008 w
.06859 .48906 Mdot
.016 w
.06859 .48906 m
.0682 .49195 L
s
1 .995 0 r
.008 w
.0682 .49195 Mdot
.016 w
.0682 .49195 m
.06786 .49578 L
s
.008 w
.06786 .49578 Mdot
.016 w
.06786 .49578 m
.0676 .49939 L
s
1 .994 0 r
.008 w
.0676 .49939 Mdot
.016 w
.0676 .49939 m
.06745 .50343 L
s
.008 w
.06745 .50343 Mdot
.016 w
.06745 .50343 m
.0674 .50746 L
s
1 .993 0 r
.008 w
.0674 .50746 Mdot
.016 w
.0674 .50746 m
.06747 .51147 L
s
.008 w
.06747 .51147 Mdot
.016 w
.06747 .51147 m
.06763 .51513 L
s
.008 w
.06763 .51513 Mdot
.016 w
.06763 .51513 m
.06788 .51892 L
s
1 .992 0 r
.008 w
.06788 .51892 Mdot
.016 w
.06788 .51892 m
.06822 .52257 L
s
.008 w
.06822 .52257 Mdot
.016 w
.06822 .52257 m
.06861 .52585 L
s
1 .991 0 r
.008 w
.06861 .52585 Mdot
.016 w
.06861 .52585 m
.06909 .52903 L
s
.008 w
.06909 .52903 Mdot
.016 w
.06909 .52903 m
.06964 .53212 L
s
1 .99 0 r
.008 w
.06964 .53212 Mdot
.016 w
.06964 .53212 m
.07026 .53518 L
s
.008 w
.07026 .53518 Mdot
.016 w
.07026 .53518 m
.07091 .53801 L
s
.008 w
.07091 .53801 Mdot
.016 w
.07091 .53801 m
.07159 .54108 L
s
1 .989 0 r
.008 w
.07159 .54108 Mdot
.016 w
.07159 .54108 m
.0723 .54391 L
s
.008 w
.0723 .54391 Mdot
.016 w
.0723 .54391 m
.07296 .54706 L
s
1 .988 0 r
.008 w
.07296 .54706 Mdot
.016 w
.07296 .54706 m
.07362 .55014 L
s
.008 w
.07362 .55014 Mdot
.016 w
.07362 .55014 m
.07426 .55368 L
s
1 .987 0 r
.008 w
.07426 .55368 Mdot
.016 w
.07426 .55368 m
.07488 .55704 L
s
.008 w
.07488 .55704 Mdot
.016 w
.07488 .55704 m
.07545 .56026 L
s
.008 w
.07545 .56026 Mdot
.016 w
.07545 .56026 m
.076 .56422 L
s
1 .986 0 r
.008 w
.076 .56422 Mdot
.016 w
.076 .56422 m
.07651 .56778 L
s
.008 w
.07651 .56778 Mdot
.016 w
.07651 .56778 m
.07697 .57221 L
s
1 .985 0 r
.008 w
.07697 .57221 Mdot
.016 w
.07697 .57221 m
.0774 .57578 L
s
.008 w
.0774 .57578 Mdot
.016 w
.0774 .57578 m
.07783 .58015 L
s
1 .984 0 r
.008 w
.07783 .58015 Mdot
.016 w
.07783 .58015 m
.07826 .58443 L
s
.008 w
.07826 .58443 Mdot
.016 w
.07826 .58443 m
.0787 .58839 L
s
1 .983 0 r
.008 w
.0787 .58839 Mdot
.016 w
.0787 .58839 m
.07915 .5926 L
s
.008 w
.07915 .5926 Mdot
.016 w
.07915 .5926 m
.07966 .59683 L
s
.008 w
.07966 .59683 Mdot
.016 w
.07966 .59683 m
.08024 .6011 L
s
1 .982 0 r
.008 w
.08024 .6011 Mdot
.016 w
.08024 .6011 m
.08089 .60539 L
s
.008 w
.08089 .60539 Mdot
.016 w
.08089 .60539 m
.0816 .60964 L
s
1 .981 0 r
.008 w
.0816 .60964 Mdot
.016 w
.0816 .60964 m
.08226 .61386 L
s
.008 w
.08226 .61386 Mdot
.016 w
.08226 .61386 m
.08301 .61819 L
s
1 .98 0 r
.008 w
.08301 .61819 Mdot
.016 w
.08301 .61819 m
.08373 .62278 L
s
.008 w
.08373 .62278 Mdot
.016 w
.08373 .62278 m
.08447 .62686 L
s
.008 w
.08447 .62686 Mdot
.016 w
.08447 .62686 m
.08519 .63155 L
s
1 .979 0 r
.008 w
.08519 .63155 Mdot
.016 w
.08519 .63155 m
.08587 .63533 L
s
.008 w
.08587 .63533 Mdot
.016 w
.08587 .63533 m
.08652 .63978 L
s
1 .978 0 r
.008 w
.08652 .63978 Mdot
.016 w
.08652 .63978 m
.08715 .64358 L
s
.008 w
.08715 .64358 Mdot
.016 w
.08715 .64358 m
.08769 .64742 L
s
1 .977 0 r
.008 w
.08769 .64742 Mdot
.016 w
.08769 .64742 m
.08818 .6507 L
s
.008 w
.08818 .6507 Mdot
.016 w
.08818 .6507 m
.0886 .65371 L
s
1 .976 0 r
.008 w
.0886 .65371 Mdot
.016 w
.0886 .65371 m
.08895 .65663 L
s
.008 w
.08895 .65663 Mdot
.016 w
.08895 .65663 m
.08925 .65916 L
s
.008 w
.08925 .65916 Mdot
.016 w
.08925 .65916 m
.08952 .66146 L
s
1 .975 0 r
.008 w
.08952 .66146 Mdot
.016 w
.08952 .66146 m
.08977 .66349 L
s
.008 w
.08977 .66349 Mdot
.016 w
.08977 .66349 m
.09003 .66511 L
s
1 .974 0 r
.008 w
.09003 .66511 Mdot
.016 w
.09003 .66511 m
.0903 .66653 L
s
.008 w
.0903 .66653 Mdot
.016 w
.0903 .66653 m
.09059 .66774 L
s
1 .973 0 r
.008 w
.09059 .66774 Mdot
.016 w
.09059 .66774 m
.0909 .66873 L
s
.008 w
.0909 .66873 Mdot
.016 w
.0909 .66873 m
.09122 .66957 L
s
.008 w
.09122 .66957 Mdot
.016 w
.09122 .66957 m
.09153 .67019 L
s
1 .972 0 r
.008 w
.09153 .67019 Mdot
.016 w
.09153 .67019 m
.09183 .67078 L
s
.008 w
.09183 .67078 Mdot
.016 w
.09183 .67078 m
.09209 .67126 L
s
1 .971 0 r
.008 w
.09209 .67126 Mdot
.016 w
.09209 .67126 m
.0923 .67159 L
s
.008 w
.0923 .67159 Mdot
.016 w
.0923 .67159 m
.09249 .67175 L
s
1 .97 0 r
.008 w
.09249 .67175 Mdot
.016 w
.09249 .67175 m
.09267 .67176 L
s
.008 w
.09267 .67176 Mdot
.016 w
.09267 .67176 m
.09284 .67163 L
s
.008 w
.09284 .67163 Mdot
.016 w
.09284 .67163 m
.09299 .67145 L
s
1 .969 0 r
.008 w
.09299 .67145 Mdot
.016 w
.09299 .67145 m
.0931 .67126 L
s
.008 w
.0931 .67126 Mdot
.016 w
.0931 .67126 m
.09317 .6711 L
s
1 .968 0 r
.008 w
.09317 .6711 Mdot
.016 w
.09317 .6711 m
.09319 .67102 L
s
.008 w
.09319 .67102 Mdot
.016 w
.09319 .67102 m
.09317 .67109 L
s
1 .967 0 r
.008 w
.09317 .67109 Mdot
.016 w
.09317 .67109 m
.09312 .67134 L
s
.008 w
.09312 .67134 Mdot
.016 w
.09312 .67134 m
.09306 .6718 L
s
1 .966 0 r
.008 w
.09306 .6718 Mdot
.016 w
.09306 .6718 m
.093 .67247 L
s
.008 w
.093 .67247 Mdot
.016 w
.093 .67247 m
.09298 .67333 L
s
.008 w
.09298 .67333 Mdot
.016 w
.09298 .67333 m
.09302 .6744 L
s
1 .965 0 r
.008 w
.09302 .6744 Mdot
.016 w
.09302 .6744 m
.09312 .67569 L
s
.008 w
.09312 .67569 Mdot
.016 w
.09312 .67569 m
.0933 .67723 L
s
1 .964 0 r
.008 w
.0933 .67723 Mdot
.016 w
.0933 .67723 m
.09359 .67912 L
s
.008 w
.09359 .67912 Mdot
.016 w
.09359 .67912 m
.09402 .68139 L
s
1 .963 0 r
.008 w
.09402 .68139 Mdot
.016 w
.09402 .68139 m
.09455 .68398 L
s
.008 w
.09455 .68398 Mdot
.016 w
.09455 .68398 m
.09519 .68666 L
s
.008 w
.09519 .68666 Mdot
.016 w
.09519 .68666 m
.09592 .68967 L
s
1 .962 0 r
.008 w
.09592 .68967 Mdot
.016 w
.09592 .68967 m
.09674 .69281 L
s
.008 w
.09674 .69281 Mdot
.016 w
.09674 .69281 m
.09757 .69588 L
s
1 .961 0 r
.008 w
.09757 .69588 Mdot
.016 w
.09757 .69588 m
.09842 .6991 L
s
.008 w
.09842 .6991 Mdot
.016 w
.09842 .6991 m
.09925 .70182 L
s
1 .96 0 r
.008 w
.09925 .70182 Mdot
.016 w
.09925 .70182 m
.1 .7045 L
s
.008 w
.1 .7045 Mdot
.016 w
.1 .7045 m
.10072 .7071 L
s
.008 w
.10072 .7071 Mdot
.016 w
.10072 .7071 m
.10131 .70912 L
s
1 .959 0 r
.008 w
.10131 .70912 Mdot
.016 w
.10131 .70912 m
.10187 .71095 L
s
.008 w
.10187 .71095 Mdot
.016 w
.10187 .71095 m
.10225 .71253 L
s
1 .958 0 r
.008 w
.10225 .71253 Mdot
.016 w
.10225 .71253 m
.10258 .71377 L
s
.008 w
.10258 .71377 Mdot
.016 w
.10258 .71377 m
.1028 .71462 L
s
1 .957 0 r
.008 w
.1028 .71462 Mdot
.016 w
.1028 .71462 m
.10292 .71511 L
s
.008 w
.10292 .71511 Mdot
.016 w
.10292 .71511 m
.10295 .71532 L
s
1 .956 0 r
.008 w
.10295 .71532 Mdot
.016 w
.10295 .71532 m
.10291 .71532 L
s
.008 w
.10291 .71532 Mdot
.016 w
.10291 .71532 m
.10286 .71518 L
s
.008 w
.10286 .71518 Mdot
.016 w
.10286 .71518 m
.1028 .71497 L
s
1 .955 0 r
.008 w
.1028 .71497 Mdot
.016 w
.1028 .71497 m
.10275 .71482 L
s
.008 w
.10275 .71482 Mdot
.016 w
.10275 .71482 m
.10272 .71475 L
s
1 .954 0 r
.008 w
.10272 .71475 Mdot
.016 w
.10272 .71475 m
.10272 .71482 L
s
.008 w
.10272 .71482 Mdot
.016 w
.10272 .71482 m
.10275 .71504 L
s
1 .953 0 r
.008 w
.10275 .71504 Mdot
.016 w
.10275 .71504 m
.10277 .71527 L
s
.008 w
.10277 .71527 Mdot
.016 w
.10277 .71527 m
.10277 .71549 L
s
.008 w
.10277 .71549 Mdot
.016 w
.10277 .71549 m
.10272 .71565 L
s
1 .952 0 r
.008 w
.10272 .71565 Mdot
.016 w
.10272 .71565 m
.10263 .71572 L
s
.008 w
.10263 .71572 Mdot
.016 w
.10263 .71572 m
.10253 .71572 L
s
1 .951 0 r
.008 w
.10253 .71572 Mdot
.016 w
.10253 .71572 m
.10241 .71566 L
s
.008 w
.10241 .71566 Mdot
.016 w
.10241 .71566 m
.10229 .71559 L
s
1 .95 0 r
.008 w
.10229 .71559 Mdot
.016 w
.10229 .71559 m
.10218 .71555 L
s
.008 w
.10218 .71555 Mdot
.016 w
.10218 .71555 m
.1021 .71555 L
s
1 .949 0 r
.008 w
.1021 .71555 Mdot
.016 w
.1021 .71555 m
.10204 .71562 L
s
.008 w
.10204 .71562 Mdot
.016 w
.10204 .71562 m
.102 .71573 L
s
.008 w
.102 .71573 Mdot
.016 w
.102 .71573 m
.10199 .71589 L
s
1 .948 0 r
.008 w
.10199 .71589 Mdot
.016 w
.10199 .71589 m
.10199 .71608 L
s
.008 w
.10199 .71608 Mdot
.016 w
.10199 .71608 m
.102 .71631 L
s
1 .947 0 r
.008 w
.102 .71631 Mdot
.016 w
.102 .71631 m
.10205 .71658 L
s
.008 w
.10205 .71658 Mdot
.016 w
.10205 .71658 m
.10213 .71686 L
s
1 .946 0 r
.008 w
.10213 .71686 Mdot
.016 w
.10213 .71686 m
.10223 .7172 L
s
.008 w
.10223 .7172 Mdot
.016 w
.10223 .7172 m
.10234 .71756 L
s
.008 w
.10234 .71756 Mdot
.016 w
.10234 .71756 m
.10247 .71794 L
s
1 .945 0 r
.008 w
.10247 .71794 Mdot
.016 w
.10247 .71794 m
.10258 .71833 L
s
.008 w
.10258 .71833 Mdot
.016 w
.10258 .71833 m
.10266 .71867 L
s
1 .944 0 r
.008 w
.10266 .71867 Mdot
.016 w
.10266 .71867 m
.10272 .71889 L
s
.008 w
.10272 .71889 Mdot
.016 w
.10272 .71889 m
.10273 .71899 L
s
1 .943 0 r
.008 w
.10273 .71899 Mdot
.016 w
.10273 .71899 m
.10271 .719 L
s
.008 w
.10271 .719 Mdot
.016 w
.10271 .719 m
.10267 .71895 L
s
.008 w
.10267 .71895 Mdot
.016 w
.10267 .71895 m
.10264 .71888 L
s
1 .942 0 r
.008 w
.10264 .71888 Mdot
.016 w
.10264 .71888 m
.10263 .71876 L
s
.008 w
.10263 .71876 Mdot
.016 w
.10263 .71876 m
.10263 .71862 L
s
1 .941 0 r
.008 w
.10263 .71862 Mdot
.016 w
.10263 .71862 m
.10264 .71845 L
s
.008 w
.10264 .71845 Mdot
.016 w
.10264 .71845 m
.10264 .71827 L
s
1 .94 0 r
.008 w
.10264 .71827 Mdot
.016 w
.10264 .71827 m
.10264 .71807 L
s
.008 w
.10264 .71807 Mdot
.016 w
.10264 .71807 m
.10265 .71786 L
s
1 .939 0 r
.008 w
.10265 .71786 Mdot
.016 w
.10265 .71786 m
.10265 .71768 L
s
.008 w
.10265 .71768 Mdot
.016 w
.10265 .71768 m
.10265 .71753 L
s
.008 w
.10265 .71753 Mdot
.016 w
.10265 .71753 m
.10265 .71743 L
s
1 .938 0 r
.008 w
.10265 .71743 Mdot
.016 w
.10265 .71743 m
.10266 .71737 L
s
.008 w
.10266 .71737 Mdot
.016 w
.10266 .71737 m
.10266 .71736 L
s
1 .937 0 r
.008 w
.10266 .71736 Mdot
.016 w
.10266 .71736 m
.10265 .71738 L
s
.008 w
.10265 .71738 Mdot
.016 w
.10265 .71738 m
.10265 .71745 L
s
1 .936 0 r
.008 w
.10265 .71745 Mdot
.016 w
.10265 .71745 m
.10265 .71755 L
s
.008 w
.10265 .71755 Mdot
.016 w
.10265 .71755 m
.10265 .71773 L
s
.008 w
.10265 .71773 Mdot
.016 w
.10265 .71773 m
.10264 .71795 L
s
1 .935 0 r
.008 w
.10264 .71795 Mdot
.016 w
.10264 .71795 m
.10264 .71819 L
s
.008 w
.10264 .71819 Mdot
.016 w
.10264 .71819 m
.10263 .71843 L
s
1 .934 0 r
.008 w
.10263 .71843 Mdot
.016 w
.10263 .71843 m
.10263 .71866 L
s
.008 w
.10263 .71866 Mdot
.016 w
.10263 .71866 m
.10262 .71886 L
s
1 .933 0 r
.008 w
.10262 .71886 Mdot
.016 w
.10262 .71886 m
.1026 .71901 L
s
.008 w
.1026 .71901 Mdot
.016 w
.1026 .71901 m
.10256 .71909 L
s
.008 w
.10256 .71909 Mdot
.016 w
.10256 .71909 m
.10249 .71907 L
s
1 .932 0 r
.008 w
.10249 .71907 Mdot
.016 w
.10249 .71907 m
.10237 .71891 L
s
.008 w
.10237 .71891 Mdot
.016 w
.10237 .71891 m
.10224 .71867 L
s
1 .931 0 r
.008 w
.10224 .71867 Mdot
.016 w
.10224 .71867 m
.10213 .71842 L
s
.008 w
.10213 .71842 Mdot
.016 w
.10213 .71842 m
.10207 .71822 L
s
1 .93 0 r
.008 w
.10207 .71822 Mdot
.016 w
.10207 .71822 m
.10208 .71812 L
s
.008 w
.10208 .71812 Mdot
.016 w
.10208 .71812 m
.10222 .71817 L
s
1 .929 0 r
.008 w
.10222 .71817 Mdot
.016 w
.10222 .71817 m
.10255 .71845 L
s
.008 w
.10255 .71845 Mdot
.016 w
.10255 .71845 m
.10309 .71898 L
s
.008 w
.10309 .71898 Mdot
.016 w
.10309 .71898 m
.10387 .71982 L
s
1 .928 0 r
.008 w
.10387 .71982 Mdot
.016 w
.10387 .71982 m
.10491 .72097 L
s
.008 w
.10491 .72097 Mdot
.016 w
.10491 .72097 m
.1061 .72244 L
s
1 .927 0 r
.008 w
.1061 .72244 Mdot
.016 w
.1061 .72244 m
.10765 .7242 L
s
.008 w
.10765 .7242 Mdot
.016 w
.10765 .7242 m
.10928 .726 L
s
1 .926 0 r
.008 w
.10928 .726 Mdot
.016 w
.10928 .726 m
.11123 .72821 L
s
.008 w
.11123 .72821 Mdot
.016 w
.11123 .72821 m
.11329 .73055 L
s
.008 w
.11329 .73055 Mdot
.016 w
.11329 .73055 m
.11555 .73311 L
s
1 .925 0 r
.008 w
.11555 .73311 Mdot
.016 w
.11555 .73311 m
.1181 .73574 L
s
.008 w
.1181 .73574 Mdot
.016 w
.1181 .73574 m
.12056 .73848 L
s
1 .924 0 r
.008 w
.12056 .73848 Mdot
.016 w
.12056 .73848 m
.12299 .74099 L
s
.008 w
.12299 .74099 Mdot
.016 w
.12299 .74099 m
.12546 .74359 L
s
1 .923 0 r
.008 w
.12546 .74359 Mdot
.016 w
.12546 .74359 m
.1279 .74611 L
s
.008 w
.1279 .74611 Mdot
.016 w
.1279 .74611 m
.13033 .74848 L
s
.008 w
.13033 .74848 Mdot
.016 w
.13033 .74848 m
.13281 .75093 L
s
1 .922 0 r
.008 w
.13281 .75093 Mdot
.016 w
.13281 .75093 m
.13527 .75325 L
s
.008 w
.13527 .75325 Mdot
.016 w
.13527 .75325 m
.13794 .75571 L
s
1 .921 0 r
.008 w
.13794 .75571 Mdot
.016 w
.13794 .75571 m
.1405 .75815 L
s
.008 w
.1405 .75815 Mdot
.016 w
.1405 .75815 m
.14329 .76078 L
s
1 .92 0 r
.008 w
.14329 .76078 Mdot
.016 w
.14329 .76078 m
.14612 .76331 L
s
.008 w
.14612 .76331 Mdot
.016 w
.14612 .76331 m
.14897 .76609 L
s
1 .919 0 r
.008 w
.14897 .76609 Mdot
.016 w
.14897 .76609 m
.15184 .76873 L
s
.008 w
.15184 .76873 Mdot
.016 w
.15184 .76873 m
.15482 .7716 L
s
.008 w
.15482 .7716 Mdot
.016 w
.15482 .7716 m
.15782 .77443 L
s
1 .918 0 r
.008 w
.15782 .77443 Mdot
.016 w
.15782 .77443 m
.16092 .77741 L
s
.008 w
.16092 .77741 Mdot
.016 w
.16092 .77741 m
.16378 .78022 L
s
1 .917 0 r
.008 w
.16378 .78022 Mdot
.016 w
.16378 .78022 m
.16678 .78325 L
s
.008 w
.16678 .78325 Mdot
.016 w
.16678 .78325 m
.16984 .78611 L
s
1 .916 0 r
.008 w
.16984 .78611 Mdot
.016 w
.16984 .78611 m
.17281 .78907 L
s
.008 w
.17281 .78907 Mdot
.016 w
.17281 .78907 m
.17586 .79195 L
s
.008 w
.17586 .79195 Mdot
.016 w
.17586 .79195 m
.17901 .79505 L
s
1 .915 0 r
.008 w
.17901 .79505 Mdot
.016 w
.17901 .79505 m
.18199 .79787 L
s
.008 w
.18199 .79787 Mdot
.016 w
.18199 .79787 m
.1853 .80099 L
s
1 .914 0 r
.008 w
.1853 .80099 Mdot
.016 w
.1853 .80099 m
.18853 .80431 L
s
.008 w
.18853 .80431 Mdot
.016 w
.18853 .80431 m
.19195 .80745 L
s
1 .913 0 r
.008 w
.19195 .80745 Mdot
.016 w
.19195 .80745 m
.19552 .81085 L
s
.008 w
.19552 .81085 Mdot
.016 w
.19552 .81085 m
.19943 .81455 L
s
1 .912 0 r
.008 w
.19943 .81455 Mdot
.016 w
.19943 .81455 m
.20307 .81783 L
s
.008 w
.20307 .81783 Mdot
.016 w
.20307 .81783 m
.20682 .82133 L
s
.008 w
.20682 .82133 Mdot
.016 w
.20682 .82133 m
.21074 .82505 L
s
1 .911 0 r
.008 w
.21074 .82505 Mdot
.016 w
.21074 .82505 m
.21449 .82841 L
s
.008 w
.21449 .82841 Mdot
.016 w
.21449 .82841 m
.21837 .83187 L
s
1 .91 0 r
.008 w
.21837 .83187 Mdot
.016 w
.21837 .83187 m
.22202 .83573 L
s
.008 w
.22202 .83573 Mdot
.016 w
.22202 .83573 m
.22571 .83886 L
s
1 .909 0 r
.008 w
.22571 .83886 Mdot
.016 w
.22571 .83886 m
.22917 .84213 L
s
.008 w
.22917 .84213 Mdot
.016 w
.22917 .84213 m
.23245 .8454 L
s
.008 w
.23245 .8454 Mdot
.016 w
.23245 .8454 m
.23554 .84833 L
s
1 .908 0 r
.008 w
.23554 .84833 Mdot
.016 w
.23554 .84833 m
.23847 .85117 L
s
.008 w
.23847 .85117 Mdot
.016 w
.23847 .85117 m
.241 .85347 L
s
1 .907 0 r
.008 w
.241 .85347 Mdot
.016 w
.241 .85347 m
.24336 .85557 L
s
.008 w
.24336 .85557 Mdot
.016 w
.24336 .85557 m
.24531 .85721 L
s
1 .906 0 r
.008 w
.24531 .85721 Mdot
.016 w
.24531 .85721 m
.24703 .85855 L
s
.008 w
.24703 .85855 Mdot
.016 w
.24703 .85855 m
.24845 .85959 L
s
.008 w
.24845 .85959 Mdot
.016 w
.24845 .85959 m
.2496 .86035 L
s
1 .905 0 r
.008 w
.2496 .86035 Mdot
.016 w
.2496 .86035 m
.25049 .86083 L
s
.008 w
.25049 .86083 Mdot
.016 w
.25049 .86083 m
.25114 .86105 L
s
1 .904 0 r
.008 w
.25114 .86105 Mdot
.016 w
.25114 .86105 m
.25156 .86105 L
s
.008 w
.25156 .86105 Mdot
.016 w
.25156 .86105 m
.25181 .86085 L
s
1 .903 0 r
.008 w
.25181 .86085 Mdot
.016 w
.25181 .86085 m
.25193 .86052 L
s
.008 w
.25193 .86052 Mdot
.016 w
.25193 .86052 m
.25193 .86009 L
s
1 .902 0 r
.008 w
.25193 .86009 Mdot
.016 w
.25193 .86009 m
.25186 .85967 L
s
.008 w
.25186 .85967 Mdot
.016 w
.25186 .85967 m
.25176 .8593 L
s
.008 w
.25176 .8593 Mdot
.016 w
.25176 .8593 m
.25167 .85904 L
s
1 .901 0 r
.008 w
.25167 .85904 Mdot
.016 w
.25167 .85904 m
.25158 .85886 L
s
.008 w
.25158 .85886 Mdot
.016 w
.25158 .85886 m
.2515 .85876 L
s
1 .9 0 r
.008 w
.2515 .85876 Mdot
.016 w
.2515 .85876 m
.25145 .85873 L
s
.008 w
.25145 .85873 Mdot
.016 w
.25145 .85873 m
.25143 .85876 L
s
1 .899 0 r
.008 w
.25143 .85876 Mdot
.016 w
.25143 .85876 m
.25142 .85883 L
s
.008 w
.25142 .85883 Mdot
.016 w
.25142 .85883 m
.25142 .85888 L
s
.008 w
.25142 .85888 Mdot
.016 w
.25142 .85888 m
.2514 .85889 L
s
1 .898 0 r
.008 w
.2514 .85889 Mdot
.016 w
.2514 .85889 m
.25135 .85888 L
s
.008 w
.25135 .85888 Mdot
.016 w
.25135 .85888 m
.2513 .85886 L
s
1 .897 0 r
.008 w
.2513 .85886 Mdot
.016 w
.2513 .85886 m
.25124 .85883 L
s
.008 w
.25124 .85883 Mdot
.016 w
.25124 .85883 m
.2512 .85881 L
s
1 .896 0 r
.008 w
.2512 .85881 Mdot
.016 w
.2512 .85881 m
.25117 .85878 L
s
.008 w
.25117 .85878 Mdot
.016 w
.25117 .85878 m
.25118 .85878 L
s
.008 w
.25118 .85878 Mdot
.016 w
.25118 .85878 m
.25127 .85882 L
s
1 .895 0 r
.008 w
.25127 .85882 Mdot
.016 w
.25127 .85882 m
.25146 .85891 L
s
.008 w
.25146 .85891 Mdot
.016 w
.25146 .85891 m
.25175 .85907 L
s
1 .894 0 r
.008 w
.25175 .85907 Mdot
.016 w
.25175 .85907 m
.25215 .8593 L
s
.008 w
.25215 .8593 Mdot
.016 w
.25215 .8593 m
.25268 .85961 L
s
1 .893 0 r
.008 w
.25268 .85961 Mdot
.016 w
.25268 .85961 m
.25333 .85997 L
s
.008 w
.25333 .85997 Mdot
.016 w
.25333 .85997 m
.25403 .86036 L
s
1 .892 0 r
.008 w
.25403 .86036 Mdot
.016 w
.25403 .86036 m
.25474 .86075 L
s
.008 w
.25474 .86075 Mdot
.016 w
.25474 .86075 m
.25547 .86115 L
s
.008 w
.25547 .86115 Mdot
.016 w
.25547 .86115 m
.25617 .86151 L
s
1 .891 0 r
.008 w
.25617 .86151 Mdot
.016 w
.25617 .86151 m
.25686 .86187 L
s
.008 w
.25686 .86187 Mdot
.016 w
.25686 .86187 m
.25747 .8622 L
s
1 .89 0 r
.008 w
.25747 .8622 Mdot
.016 w
.25747 .8622 m
.25801 .86248 L
s
.008 w
.25801 .86248 Mdot
.016 w
.25801 .86248 m
.25846 .86271 L
s
1 .889 0 r
.008 w
.25846 .86271 Mdot
.016 w
.25846 .86271 m
.25881 .86288 L
s
.008 w
.25881 .86288 Mdot
.016 w
.25881 .86288 m
.25906 .863 L
s
.008 w
.25906 .863 Mdot
.016 w
.25906 .863 m
.25922 .86307 L
s
1 .888 0 r
.008 w
.25922 .86307 Mdot
.016 w
.25922 .86307 m
.2593 .86309 L
s
.008 w
.2593 .86309 Mdot
.016 w
.2593 .86309 m
.25929 .86308 L
s
1 .887 0 r
.008 w
.25929 .86308 Mdot
.016 w
.25929 .86308 m
.25925 .86305 L
s
.008 w
.25925 .86305 Mdot
.016 w
.25925 .86305 m
.25919 .86302 L
s
1 .886 0 r
.008 w
.25919 .86302 Mdot
.016 w
.25919 .86302 m
.25914 .86301 L
s
.008 w
.25914 .86301 Mdot
.016 w
.25914 .86301 m
.25912 .86303 L
s
.008 w
.25912 .86303 Mdot
.016 w
.25912 .86303 m
.25913 .86307 L
s
1 .885 0 r
.008 w
.25913 .86307 Mdot
.016 w
.25913 .86307 m
.25914 .86311 L
s
.008 w
.25914 .86311 Mdot
.016 w
.25914 .86311 m
.25915 .86315 L
s
1 .884 0 r
.008 w
.25915 .86315 Mdot
.016 w
.25915 .86315 m
.25914 .8632 L
s
.008 w
.25914 .8632 Mdot
.016 w
.25914 .8632 m
.25911 .86325 L
s
1 .883 0 r
.008 w
.25911 .86325 Mdot
.016 w
.25911 .86325 m
.25908 .86332 L
s
.008 w
.25908 .86332 Mdot
.016 w
.25908 .86332 m
.25904 .86337 L
s
1 .882 0 r
.008 w
.25904 .86337 Mdot
.016 w
.25904 .86337 m
.25903 .86341 L
s
.008 w
.25903 .86341 Mdot
.016 w
.25903 .86341 m
.25904 .86339 L
s
.008 w
.25904 .86339 Mdot
.016 w
.25904 .86339 m
.25908 .86329 L
s
1 .881 0 r
.008 w
.25908 .86329 Mdot
.016 w
.25908 .86329 m
.25913 .86312 L
s
.008 w
.25913 .86312 Mdot
.016 w
.25913 .86312 m
.2592 .86287 L
s
1 .88 0 r
.008 w
.2592 .86287 Mdot
.016 w
.2592 .86287 m
.25927 .86254 L
s
.008 w
.25927 .86254 Mdot
.016 w
.25927 .86254 m
.25935 .86215 L
s
1 .879 0 r
.008 w
.25935 .86215 Mdot
.016 w
.25935 .86215 m
.25942 .86171 L
s
.008 w
.25942 .86171 Mdot
.016 w
.25942 .86171 m
.25949 .86123 L
s
.008 w
.25949 .86123 Mdot
.016 w
.25949 .86123 m
.25953 .86074 L
s
1 .878 0 r
.008 w
.25953 .86074 Mdot
.016 w
.25953 .86074 m
.25957 .86027 L
s
.008 w
.25957 .86027 Mdot
.016 w
.25957 .86027 m
.2596 .85979 L
s
1 .877 0 r
.008 w
.2596 .85979 Mdot
.016 w
.2596 .85979 m
.25966 .85926 L
s
.008 w
.25966 .85926 Mdot
.016 w
.25966 .85926 m
.25974 .85887 L
s
1 .876 0 r
.008 w
.25974 .85887 Mdot
.016 w
.25974 .85887 m
.25984 .85852 L
s
.008 w
.25984 .85852 Mdot
.016 w
.25984 .85852 m
.25993 .85826 L
s
1 .875 0 r
.008 w
.25993 .85826 Mdot
.016 w
.25993 .85826 m
.25997 .85812 L
s
.008 w
.25997 .85812 Mdot
.016 w
.25997 .85812 m
.25995 .85809 L
s
.008 w
.25995 .85809 Mdot
.016 w
.25995 .85809 m
.25987 .85816 L
s
1 .874 0 r
.008 w
.25987 .85816 Mdot
.016 w
.25987 .85816 m
.25966 .85831 L
s
.008 w
.25966 .85831 Mdot
.016 w
.25966 .85831 m
.25953 .85847 L
s
1 .873 0 r
.008 w
.25953 .85847 Mdot
.016 w
.25953 .85847 m
.25937 .85868 L
s
.008 w
.25937 .85868 Mdot
.016 w
.25937 .85868 m
.25921 .85893 L
s
1 .872 0 r
.008 w
.25921 .85893 Mdot
.016 w
.25921 .85893 m
.25906 .85925 L
s
.008 w
.25906 .85925 Mdot
.016 w
.25906 .85925 m
.25896 .85967 L
s
.008 w
.25896 .85967 Mdot
.016 w
.25896 .85967 m
.2589 .86016 L
s
1 .871 0 r
.008 w
.2589 .86016 Mdot
.016 w
.2589 .86016 m
.25895 .86075 L
s
.008 w
.25895 .86075 Mdot
.016 w
.25895 .86075 m
.25916 .86144 L
s
1 .87 0 r
.008 w
.25916 .86144 Mdot
.016 w
.25916 .86144 m
.25952 .8622 L
s
.008 w
.25952 .8622 Mdot
.016 w
.25952 .8622 m
.26017 .86311 L
s
1 .869 0 r
.008 w
.26017 .86311 Mdot
.016 w
.26017 .86311 m
.26111 .86414 L
s
.008 w
.26111 .86414 Mdot
.016 w
.26111 .86414 m
.26243 .8653 L
s
.008 w
.26243 .8653 Mdot
.016 w
.26243 .8653 m
.26419 .86659 L
s
1 .868 0 r
.008 w
.26419 .86659 Mdot
.016 w
.26419 .86659 m
.26647 .86805 L
s
.008 w
.26647 .86805 Mdot
.016 w
.26647 .86805 m
.26912 .86962 L
s
1 .867 0 r
.008 w
.26912 .86962 Mdot
.016 w
.26912 .86962 m
.27223 .87131 L
s
.008 w
.27223 .87131 Mdot
.016 w
.27223 .87131 m
.27572 .87302 L
s
1 .866 0 r
.008 w
.27572 .87302 Mdot
.016 w
.27572 .87302 m
.27961 .8748 L
s
.008 w
.27961 .8748 Mdot
.016 w
.27961 .8748 m
.28376 .87658 L
s
1 .865 0 r
.008 w
.28376 .87658 Mdot
.016 w
.28376 .87658 m
.2881 .87836 L
s
.008 w
.2881 .87836 Mdot
.016 w
.2881 .87836 m
.29294 .88014 L
s
.008 w
.29294 .88014 Mdot
.016 w
.29294 .88014 m
.29777 .88195 L
s
1 .864 0 r
.008 w
.29777 .88195 Mdot
.016 w
.29777 .88195 m
.30286 .88373 L
s
.008 w
.30286 .88373 Mdot
.016 w
.30286 .88373 m
.30825 .88553 L
s
1 .863 0 r
.008 w
.30825 .88553 Mdot
.016 w
.30825 .88553 m
.31339 .88728 L
s
.008 w
.31339 .88728 Mdot
.016 w
.31339 .88728 m
.31875 .88908 L
s
1 .862 0 r
.008 w
.31875 .88908 Mdot
.016 w
.31875 .88908 m
.32402 .89084 L
s
.008 w
.32402 .89084 Mdot
.016 w
.32402 .89084 m
.32933 .89258 L
s
.008 w
.32933 .89258 Mdot
.016 w
.32933 .89258 m
.33439 .89435 L
s
1 .861 0 r
.008 w
.33439 .89435 Mdot
.016 w
.33439 .89435 m
.33904 .89611 L
s
.008 w
.33904 .89611 Mdot
.016 w
.33904 .89611 m
.34355 .89783 L
s
1 .86 0 r
.008 w
.34355 .89783 Mdot
.016 w
.34355 .89783 m
.34753 .89946 L
s
.008 w
.34753 .89946 Mdot
.016 w
.34753 .89946 m
.35119 .90098 L
s
1 .859 0 r
.008 w
.35119 .90098 Mdot
.016 w
.35119 .90098 m
.35482 .90228 L
s
.008 w
.35482 .90228 Mdot
.016 w
.35482 .90228 m
.3578 .90346 L
s
.008 w
.3578 .90346 Mdot
.016 w
.3578 .90346 m
.36042 .90443 L
s
1 .858 0 r
.008 w
.36042 .90443 Mdot
.016 w
.36042 .90443 m
.3629 .90526 L
s
.008 w
.3629 .90526 Mdot
.016 w
.3629 .90526 m
.36524 .90597 L
s
1 .857 0 r
.008 w
.36524 .90597 Mdot
.016 w
.36524 .90597 m
.36746 .90659 L
s
.008 w
.36746 .90659 Mdot
.016 w
.36746 .90659 m
.36957 .90713 L
s
1 .856 0 r
.008 w
.36957 .90713 Mdot
.016 w
.36957 .90713 m
.37146 .90761 L
s
.008 w
.37146 .90761 Mdot
.016 w
.37146 .90761 m
.37346 .90808 L
s
1 .855 0 r
.008 w
.37346 .90808 Mdot
.016 w
.37346 .90808 m
.3756 .90856 L
s
.008 w
.3756 .90856 Mdot
.016 w
.3756 .90856 m
.37782 .90904 L
s
.008 w
.37782 .90904 Mdot
.016 w
.37782 .90904 m
.38008 .90956 L
s
1 .854 0 r
.008 w
.38008 .90956 Mdot
.016 w
.38008 .90956 m
.38238 .91011 L
s
.008 w
.38238 .91011 Mdot
.016 w
.38238 .91011 m
.38469 .91073 L
s
1 .853 0 r
.008 w
.38469 .91073 Mdot
.016 w
.38469 .91073 m
.38691 .91139 L
s
.008 w
.38691 .91139 Mdot
.016 w
.38691 .91139 m
.38884 .91207 L
s
1 .852 0 r
.008 w
.38884 .91207 Mdot
.016 w
.38884 .91207 m
.39051 .91266 L
s
.008 w
.39051 .91266 Mdot
.016 w
.39051 .91266 m
.3919 .91323 L
s
.008 w
.3919 .91323 Mdot
.016 w
.3919 .91323 m
.39301 .91373 L
s
1 .851 0 r
.008 w
.39301 .91373 Mdot
.016 w
.39301 .91373 m
.3939 .91412 L
s
.008 w
.3939 .91412 Mdot
.016 w
.3939 .91412 m
.39451 .91441 L
s
1 .85 0 r
.008 w
.39451 .91441 Mdot
.016 w
.39451 .91441 m
.39491 .91458 L
s
.008 w
.39491 .91458 Mdot
.016 w
.39491 .91458 m
.3951 .91461 L
s
1 .849 0 r
.008 w
.3951 .91461 Mdot
.016 w
.3951 .91461 m
.39511 .91453 L
s
.008 w
.39511 .91453 Mdot
.016 w
.39511 .91453 m
.39504 .91442 L
s
1 .848 0 r
.008 w
.39504 .91442 Mdot
.016 w
.39504 .91442 m
.39492 .91428 L
s
.008 w
.39492 .91428 Mdot
.016 w
.39492 .91428 m
.39477 .91406 L
s
.008 w
.39477 .91406 Mdot
.016 w
.39477 .91406 m
.3947 .91382 L
s
1 .847 0 r
.008 w
.3947 .91382 Mdot
.016 w
.3947 .91382 m
.39476 .91358 L
s
.008 w
.39476 .91358 Mdot
.016 w
.39476 .91358 m
.39495 .91336 L
s
1 .846 0 r
.008 w
.39495 .91336 Mdot
.016 w
.39495 .91336 m
.39521 .91311 L
s
.008 w
.39521 .91311 Mdot
.016 w
.39521 .91311 m
.39556 .91282 L
s
1 .845 0 r
.008 w
.39556 .91282 Mdot
.016 w
.39556 .91282 m
.39597 .91252 L
s
.008 w
.39597 .91252 Mdot
.016 w
.39597 .91252 m
.39638 .91217 L
s
.008 w
.39638 .91217 Mdot
.016 w
.39638 .91217 m
.39678 .91184 L
s
1 .844 0 r
.008 w
.39678 .91184 Mdot
.016 w
.39678 .91184 m
.39715 .91149 L
s
.008 w
.39715 .91149 Mdot
.016 w
.39715 .91149 m
.39751 .91116 L
s
1 .843 0 r
.008 w
.39751 .91116 Mdot
.016 w
.39751 .91116 m
.39782 .91081 L
s
.008 w
.39782 .91081 Mdot
.016 w
.39782 .91081 m
.39803 .91051 L
s
1 .842 0 r
.008 w
.39803 .91051 Mdot
.016 w
.39803 .91051 m
.39814 .91024 L
s
.008 w
.39814 .91024 Mdot
.016 w
.39814 .91024 m
.39813 .91011 L
s
.008 w
.39813 .91011 Mdot
.016 w
.39813 .91011 m
.39795 .9099 L
s
1 .841 0 r
.008 w
.39795 .9099 Mdot
.016 w
.39795 .9099 m
.3976 .90969 L
s
.008 w
.3976 .90969 Mdot
.016 w
.3976 .90969 m
.39712 .90949 L
s
1 .84 0 r
.008 w
.39712 .90949 Mdot
.016 w
.39712 .90949 m
.39664 .90938 L
s
.008 w
.39664 .90938 Mdot
.016 w
.39664 .90938 m
.39614 .9094 L
s
1 .839 0 r
.008 w
.39614 .9094 Mdot
.016 w
.39614 .9094 m
.39566 .90951 L
s
.008 w
.39566 .90951 Mdot
.016 w
.39566 .90951 m
.39522 .90971 L
s
1 .838 0 r
.008 w
.39522 .90971 Mdot
.016 w
.39522 .90971 m
.39487 .91001 L
s
.008 w
.39487 .91001 Mdot
.016 w
.39487 .91001 m
.39455 .91027 L
s
.008 w
.39455 .91027 Mdot
.016 w
.39455 .91027 m
.39427 .91054 L
s
1 .837 0 r
.008 w
.39427 .91054 Mdot
.016 w
.39427 .91054 m
.39403 .91078 L
s
.008 w
.39403 .91078 Mdot
.016 w
.39403 .91078 m
.39382 .91096 L
s
1 .836 0 r
.008 w
.39382 .91096 Mdot
.016 w
.39382 .91096 m
.39358 .91105 L
s
.008 w
.39358 .91105 Mdot
.016 w
.39358 .91105 m
.39331 .91111 L
s
1 .835 0 r
.008 w
.39331 .91111 Mdot
.016 w
.39331 .91111 m
.39306 .91119 L
s
.008 w
.39306 .91119 Mdot
.016 w
.39306 .91119 m
.39289 .91129 L
s
.008 w
.39289 .91129 Mdot
.016 w
.39289 .91129 m
.3928 .9114 L
s
1 .834 0 r
.008 w
.3928 .9114 Mdot
.016 w
.3928 .9114 m
.39282 .91152 L
s
.008 w
.39282 .91152 Mdot
.016 w
.39282 .91152 m
.39305 .91169 L
s
1 .833 0 r
.008 w
.39305 .91169 Mdot
.016 w
.39305 .91169 m
.39353 .91199 L
s
.008 w
.39353 .91199 Mdot
.016 w
.39353 .91199 m
.39433 .91243 L
s
1 .832 0 r
.008 w
.39433 .91243 Mdot
.016 w
.39433 .91243 m
.3955 .91305 L
s
.008 w
.3955 .91305 Mdot
.016 w
.3955 .91305 m
.39708 .91385 L
s
.008 w
.39708 .91385 Mdot
.016 w
.39708 .91385 m
.39918 .91481 L
s
1 .831 0 r
.008 w
.39918 .91481 Mdot
.016 w
.39918 .91481 m
.40186 .91594 L
s
.008 w
.40186 .91594 Mdot
.016 w
.40186 .91594 m
.40469 .9172 L
s
1 .83 0 r
.008 w
.40469 .9172 Mdot
.016 w
.40469 .9172 m
.40827 .91859 L
s
.008 w
.40827 .91859 Mdot
.016 w
.40827 .91859 m
.41221 .92008 L
s
1 .829 0 r
.008 w
.41221 .92008 Mdot
.016 w
.41221 .92008 m
.4167 .92155 L
s
.008 w
.4167 .92155 Mdot
.016 w
.4167 .92155 m
.42162 .92311 L
s
1 .828 0 r
.008 w
.42162 .92311 Mdot
.016 w
.42162 .92311 m
.42624 .92457 L
s
.008 w
.42624 .92457 Mdot
.016 w
.42624 .92457 m
.43109 .926 L
s
.008 w
.43109 .926 Mdot
.016 w
.43109 .926 m
.43619 .92734 L
s
1 .827 0 r
.008 w
.43619 .92734 Mdot
.016 w
.43619 .92734 m
.44068 .92854 L
s
.008 w
.44068 .92854 Mdot
.016 w
.44068 .92854 m
.44519 .9296 L
s
1 .826 0 r
.008 w
.44519 .9296 Mdot
.016 w
.44519 .9296 m
.44911 .93052 L
s
.008 w
.44911 .93052 Mdot
.016 w
.44911 .93052 m
.45276 .93127 L
s
1 .825 0 r
.008 w
.45276 .93127 Mdot
.016 w
.45276 .93127 m
.4562 .93188 L
s
.008 w
.4562 .93188 Mdot
.016 w
.4562 .93188 m
.45876 .93235 L
s
.008 w
.45876 .93235 Mdot
.016 w
.45876 .93235 m
.46102 .9327 L
s
1 .824 0 r
.008 w
.46102 .9327 Mdot
.016 w
.46102 .9327 m
.46297 .93296 L
s
.008 w
.46297 .93296 Mdot
.016 w
.46297 .93296 m
.46459 .93315 L
s
1 .823 0 r
.008 w
.46459 .93315 Mdot
.016 w
.46459 .93315 m
.46591 .93327 L
s
.008 w
.46591 .93327 Mdot
.016 w
.46591 .93327 m
.46707 .9333 L
s
1 .822 0 r
.008 w
.46707 .9333 Mdot
.016 w
.46707 .9333 m
.46797 .93324 L
s
.008 w
.46797 .93324 Mdot
.016 w
.46797 .93324 m
.46876 .93311 L
s
.008 w
.46876 .93311 Mdot
.016 w
.46876 .93311 m
.46954 .93294 L
s
1 .821 0 r
.008 w
.46954 .93294 Mdot
.016 w
.46954 .93294 m
.4703 .93277 L
s
.008 w
.4703 .93277 Mdot
.016 w
.4703 .93277 m
.47102 .93261 L
s
1 .82 0 r
.008 w
.47102 .93261 Mdot
.016 w
.47102 .93261 m
.47171 .93247 L
s
.008 w
.47171 .93247 Mdot
.016 w
.47171 .93247 m
.47238 .93233 L
s
1 .819 0 r
.008 w
.47238 .93233 Mdot
.016 w
.47238 .93233 m
.47306 .93219 L
s
.008 w
.47306 .93219 Mdot
.016 w
.47306 .93219 m
.4737 .93205 L
s
1 .818 0 r
.008 w
.4737 .93205 Mdot
.016 w
.4737 .93205 m
.47431 .93191 L
s
.008 w
.47431 .93191 Mdot
.016 w
.47431 .93191 m
.47491 .93181 L
s
.008 w
.47491 .93181 Mdot
.016 w
.47491 .93181 m
.47555 .93175 L
s
1 .817 0 r
.008 w
.47555 .93175 Mdot
.016 w
.47555 .93175 m
.47623 .93174 L
s
.008 w
.47623 .93174 Mdot
.016 w
.47623 .93174 m
.47704 .93171 L
s
1 .816 0 r
.008 w
.47704 .93171 Mdot
.016 w
.47704 .93171 m
.47801 .93166 L
s
.008 w
.47801 .93166 Mdot
.016 w
.47801 .93166 m
.47923 .93157 L
s
1 .815 0 r
.008 w
.47923 .93157 Mdot
.016 w
.47923 .93157 m
.48065 .93138 L
s
.008 w
.48065 .93138 Mdot
.016 w
.48065 .93138 m
.48216 .93105 L
s
.008 w
.48216 .93105 Mdot
.016 w
.48216 .93105 m
.48399 .93059 L
s
1 .814 0 r
.008 w
.48399 .93059 Mdot
.016 w
.48399 .93059 m
.48607 .93 L
s
.008 w
.48607 .93 Mdot
.016 w
.48607 .93 m
.48836 .92934 L
s
1 .813 0 r
.008 w
.48836 .92934 Mdot
.016 w
.48836 .92934 m
.49075 .92863 L
s
.008 w
.49075 .92863 Mdot
.016 w
.49075 .92863 m
.49311 .92791 L
s
1 .812 0 r
.008 w
.49311 .92791 Mdot
.016 w
.49311 .92791 m
.49536 .92717 L
s
.008 w
.49536 .92717 Mdot
.016 w
.49536 .92717 m
.49745 .92655 L
s
1 .811 0 r
.008 w
.49745 .92655 Mdot
.016 w
.49745 .92655 m
.49921 .92596 L
s
.008 w
.49921 .92596 Mdot
.016 w
.49921 .92596 m
.50064 .92543 L
s
.008 w
.50064 .92543 Mdot
.016 w
.50064 .92543 m
.50167 .92492 L
s
1 .81 0 r
.008 w
.50167 .92492 Mdot
.016 w
.50167 .92492 m
.50241 .92449 L
s
.008 w
.50241 .92449 Mdot
.016 w
.50241 .92449 m
.50284 .92411 L
s
1 .809 0 r
.008 w
.50284 .92411 Mdot
.016 w
.50284 .92411 m
.50307 .9239 L
s
.008 w
.50307 .9239 Mdot
.016 w
.50307 .9239 m
.50325 .92377 L
s
1 .808 0 r
.008 w
.50325 .92377 Mdot
.016 w
.50325 .92377 m
.50345 .92375 L
s
.008 w
.50345 .92375 Mdot
.016 w
.50345 .92375 m
.50371 .92379 L
s
.008 w
.50371 .92379 Mdot
.016 w
.50371 .92379 m
.50414 .92392 L
s
1 .807 0 r
.008 w
.50414 .92392 Mdot
.016 w
.50414 .92392 m
.5048 .92413 L
s
.008 w
.5048 .92413 Mdot
.016 w
.5048 .92413 m
.50582 .92442 L
s
1 .806 0 r
.008 w
.50582 .92442 Mdot
.016 w
.50582 .92442 m
.50712 .92474 L
s
.008 w
.50712 .92474 Mdot
.016 w
.50712 .92474 m
.50889 .92512 L
s
1 .805 0 r
.008 w
.50889 .92512 Mdot
.016 w
.50889 .92512 m
.51084 .92551 L
s
.008 w
.51084 .92551 Mdot
.016 w
.51084 .92551 m
.51322 .92589 L
s
.008 w
.51322 .92589 Mdot
.016 w
.51322 .92589 m
.51621 .92636 L
s
1 .804 0 r
.008 w
.51621 .92636 Mdot
.016 w
.51621 .92636 m
.51915 .92673 L
s
.008 w
.51915 .92673 Mdot
.016 w
.51915 .92673 m
.52243 .92701 L
s
1 .803 0 r
.008 w
.52243 .92701 Mdot
.016 w
.52243 .92701 m
.52588 .92715 L
s
.008 w
.52588 .92715 Mdot
.016 w
.52588 .92715 m
.52941 .92714 L
s
1 .802 0 r
.008 w
.52941 .92714 Mdot
.016 w
.52941 .92714 m
.53313 .92701 L
s
.008 w
.53313 .92701 Mdot
.016 w
.53313 .92701 m
.53676 .92677 L
s
1 .801 0 r
.008 w
.53676 .92677 Mdot
.016 w
.53676 .92677 m
.54057 .92636 L
s
.008 w
.54057 .92636 Mdot
.016 w
.54057 .92636 m
.54439 .92578 L
s
.008 w
.54439 .92578 Mdot
.016 w
.54439 .92578 m
.54832 .92508 L
s
1 .8 0 r
.008 w
.54832 .92508 Mdot
.016 w
.54832 .92508 m
.5524 .92429 L
s
.008 w
.5524 .92429 Mdot
.016 w
.5524 .92429 m
.55669 .92345 L
s
1 .799 0 r
.008 w
.55669 .92345 Mdot
.016 w
.55669 .92345 m
.56105 .92259 L
s
.008 w
.56105 .92259 Mdot
.016 w
.56105 .92259 m
.56552 .9218 L
s
1 .798 0 r
.008 w
.56552 .9218 Mdot
.016 w
.56552 .9218 m
.57004 .9211 L
s
.008 w
.57004 .9211 Mdot
.016 w
.57004 .9211 m
.57449 .92051 L
s
.008 w
.57449 .92051 Mdot
.016 w
.57449 .92051 m
.57883 .91999 L
s
1 .797 0 r
.008 w
.57883 .91999 Mdot
.016 w
.57883 .91999 m
.58311 .91954 L
s
.008 w
.58311 .91954 Mdot
.016 w
.58311 .91954 m
.58732 .91915 L
s
1 .796 0 r
.008 w
.58732 .91915 Mdot
.016 w
.58732 .91915 m
.59149 .91878 L
s
.008 w
.59149 .91878 Mdot
.016 w
.59149 .91878 m
.59543 .91841 L
s
1 .795 0 r
.008 w
.59543 .91841 Mdot
.016 w
.59543 .91841 m
.59943 .91804 L
s
.008 w
.59943 .91804 Mdot
.016 w
.59943 .91804 m
.60314 .91767 L
s
.008 w
.60314 .91767 Mdot
.016 w
.60314 .91767 m
.60679 .91726 L
s
1 .794 0 r
.008 w
.60679 .91726 Mdot
.016 w
.60679 .91726 m
.61047 .9168 L
s
.008 w
.61047 .9168 Mdot
.016 w
.61047 .9168 m
.61406 .91625 L
s
1 .793 0 r
.008 w
.61406 .91625 Mdot
.016 w
.61406 .91625 m
.61761 .9156 L
s
.008 w
.61761 .9156 Mdot
.016 w
.61761 .9156 m
.6212 .91482 L
s
1 .792 0 r
.008 w
.6212 .91482 Mdot
.016 w
.6212 .91482 m
.6246 .9139 L
s
.008 w
.6246 .9139 Mdot
.016 w
.6246 .9139 m
.62791 .9129 L
s
1 .791 0 r
.008 w
.62791 .9129 Mdot
.016 w
.62791 .9129 m
.63109 .91184 L
s
.008 w
.63109 .91184 Mdot
.016 w
.63109 .91184 m
.63408 .91075 L
s
.008 w
.63408 .91075 Mdot
.016 w
.63408 .91075 m
.63696 .90965 L
s
1 .79 0 r
.008 w
.63696 .90965 Mdot
.016 w
.63696 .90965 m
.63958 .90864 L
s
.008 w
.63958 .90864 Mdot
.016 w
.63958 .90864 m
.64193 .90772 L
s
1 .789 0 r
.008 w
.64193 .90772 Mdot
.016 w
.64193 .90772 m
.64393 .90696 L
s
.008 w
.64393 .90696 Mdot
.016 w
.64393 .90696 m
.64555 .90634 L
s
1 .788 0 r
.008 w
.64555 .90634 Mdot
.016 w
.64555 .90634 m
.64674 .9059 L
s
.008 w
.64674 .9059 Mdot
.016 w
.64674 .9059 m
.64761 .90564 L
s
.008 w
.64761 .90564 Mdot
.016 w
.64761 .90564 m
.64821 .90556 L
s
1 .787 0 r
.008 w
.64821 .90556 Mdot
.016 w
.64821 .90556 m
.64856 .90563 L
s
.008 w
.64856 .90563 Mdot
.016 w
.64856 .90563 m
.64884 .90568 L
s
1 .786 0 r
.008 w
.64884 .90568 Mdot
.016 w
.64884 .90568 m
.64911 .90578 L
s
.008 w
.64911 .90578 Mdot
.016 w
.64911 .90578 m
.64939 .90586 L
s
1 .785 0 r
.008 w
.64939 .90586 Mdot
.016 w
.64939 .90586 m
.64974 .90586 L
s
.008 w
.64974 .90586 Mdot
.016 w
.64974 .90586 m
.65014 .90577 L
s
.008 w
.65014 .90577 Mdot
.016 w
.65014 .90577 m
.65051 .90567 L
s
1 .784 0 r
.008 w
.65051 .90567 Mdot
.016 w
.65051 .90567 m
.65101 .90543 L
s
.008 w
.65101 .90543 Mdot
.016 w
.65101 .90543 m
.65145 .90511 L
s
1 .783 0 r
.008 w
.65145 .90511 Mdot
.016 w
.65145 .90511 m
.65202 .90459 L
s
.008 w
.65202 .90459 Mdot
.016 w
.65202 .90459 m
.65265 .90395 L
s
1 .782 0 r
.008 w
.65265 .90395 Mdot
.016 w
.65265 .90395 m
.65331 .90321 L
s
.008 w
.65331 .90321 Mdot
.016 w
.65331 .90321 m
.654 .90242 L
s
1 .781 0 r
.008 w
.654 .90242 Mdot
.016 w
.654 .90242 m
.65468 .90162 L
s
.008 w
.65468 .90162 Mdot
.016 w
.65468 .90162 m
.65538 .90083 L
s
.008 w
.65538 .90083 Mdot
.016 w
.65538 .90083 m
.65606 .90006 L
s
1 .78 0 r
.008 w
.65606 .90006 Mdot
.016 w
.65606 .90006 m
.65664 .89936 L
s
.008 w
.65664 .89936 Mdot
.016 w
.65664 .89936 m
.65709 .89871 L
s
1 .779 0 r
.008 w
.65709 .89871 Mdot
.016 w
.65709 .89871 m
.65733 .89828 L
s
.008 w
.65733 .89828 Mdot
.016 w
.65733 .89828 m
.65755 .89791 L
s
1 .778 0 r
.008 w
.65755 .89791 Mdot
.016 w
.65755 .89791 m
.65774 .89766 L
s
.008 w
.65774 .89766 Mdot
.016 w
.65774 .89766 m
.658 .89748 L
s
.008 w
.658 .89748 Mdot
.016 w
.658 .89748 m
.65826 .89748 L
s
1 .777 0 r
.008 w
.65826 .89748 Mdot
.016 w
.65826 .89748 m
.65861 .89758 L
s
.008 w
.65861 .89758 Mdot
.016 w
.65861 .89758 m
.65899 .8978 L
s
1 .776 0 r
.008 w
.65899 .8978 Mdot
.016 w
.65899 .8978 m
.65941 .89811 L
s
.008 w
.65941 .89811 Mdot
.016 w
.65941 .89811 m
.65987 .89843 L
s
1 .775 0 r
.008 w
.65987 .89843 Mdot
.016 w
.65987 .89843 m
.66034 .89874 L
s
.008 w
.66034 .89874 Mdot
.016 w
.66034 .89874 m
.66082 .89902 L
s
1 .774 0 r
.008 w
.66082 .89902 Mdot
.016 w
.66082 .89902 m
.66138 .89929 L
s
.008 w
.66138 .89929 Mdot
.016 w
.66138 .89929 m
.66206 .89958 L
s
.008 w
.66206 .89958 Mdot
.016 w
.66206 .89958 m
.6629 .89983 L
s
1 .773 0 r
.008 w
.6629 .89983 Mdot
.016 w
.6629 .89983 m
.66385 .90002 L
s
.008 w
.66385 .90002 Mdot
.016 w
.66385 .90002 m
.66486 .90011 L
s
1 .772 0 r
.008 w
.66486 .90011 Mdot
.016 w
.66486 .90011 m
.66586 .90014 L
s
.008 w
.66586 .90014 Mdot
.016 w
.66586 .90014 m
.66685 .90012 L
s
1 .771 0 r
.008 w
.66685 .90012 Mdot
.016 w
.66685 .90012 m
.66778 .90003 L
s
.008 w
.66778 .90003 Mdot
.016 w
.66778 .90003 m
.66864 .89992 L
s
.008 w
.66864 .89992 Mdot
.016 w
.66864 .89992 m
.66937 .89982 L
s
1 .77 0 r
.008 w
.66937 .89982 Mdot
.016 w
.66937 .89982 m
.67 .89976 L
s
.008 w
.67 .89976 Mdot
.016 w
.67 .89976 m
.67046 .89978 L
s
1 .769 0 r
.008 w
.67046 .89978 Mdot
.016 w
.67046 .89978 m
.67091 .89985 L
s
.008 w
.67091 .89985 Mdot
.016 w
.67091 .89985 m
.67133 .89996 L
s
1 .768 0 r
.008 w
.67133 .89996 Mdot
.016 w
.67133 .89996 m
.6717 .90007 L
s
.008 w
.6717 .90007 Mdot
.016 w
.6717 .90007 m
.67197 .90015 L
s
.008 w
.67197 .90015 Mdot
.016 w
.67197 .90015 m
.67217 .90021 L
s
1 .767 0 r
.008 w
.67217 .90021 Mdot
.016 w
.67217 .90021 m
.67231 .90022 L
s
.008 w
.67231 .90022 Mdot
.016 w
.67231 .90022 m
.67241 .9002 L
s
1 .766 0 r
.008 w
.67241 .9002 Mdot
.016 w
.67241 .9002 m
.67247 .90018 L
s
.008 w
.67247 .90018 Mdot
.016 w
.67247 .90018 m
.6725 .90019 L
s
1 .765 0 r
.008 w
.6725 .90019 Mdot
.016 w
.6725 .90019 m
.67252 .90021 L
s
.008 w
.67252 .90021 Mdot
.016 w
.67252 .90021 m
.67253 .90023 L
s
1 .764 0 r
.008 w
.67253 .90023 Mdot
.016 w
.67253 .90023 m
.67247 .90024 L
s
.008 w
.67247 .90024 Mdot
.016 w
.67247 .90024 m
.67244 .90023 L
s
.008 w
.67244 .90023 Mdot
.016 w
.67244 .90023 m
.67245 .9002 L
s
1 .763 0 r
.008 w
.67245 .9002 Mdot
.016 w
.67245 .9002 m
.67241 .90016 L
s
.008 w
.67241 .90016 Mdot
.016 w
.67241 .90016 m
.6724 .90012 L
s
1 .762 0 r
.008 w
.6724 .90012 Mdot
.016 w
.6724 .90012 m
.67248 .9001 L
s
.008 w
.67248 .9001 Mdot
.016 w
.67248 .9001 m
.67269 .90011 L
s
1 .761 0 r
.008 w
.67269 .90011 Mdot
.016 w
.67269 .90011 m
.67295 .90013 L
s
.008 w
.67295 .90013 Mdot
.016 w
.67295 .90013 m
.67328 .90014 L
s
.008 w
.67328 .90014 Mdot
.016 w
.67328 .90014 m
.67366 .90013 L
s
1 .76 0 r
.008 w
.67366 .90013 Mdot
.016 w
.67366 .90013 m
.67414 .90007 L
s
.008 w
.67414 .90007 Mdot
.016 w
.67414 .90007 m
.67467 .89994 L
s
1 .759 0 r
.008 w
.67467 .89994 Mdot
.016 w
.67467 .89994 m
.67527 .89974 L
s
.008 w
.67527 .89974 Mdot
.016 w
.67527 .89974 m
.67593 .89947 L
s
1 .758 0 r
.008 w
.67593 .89947 Mdot
.016 w
.67593 .89947 m
.6767 .89916 L
s
.008 w
.6767 .89916 Mdot
.016 w
.6767 .89916 m
.67757 .89878 L
s
.008 w
.67757 .89878 Mdot
.016 w
.67757 .89878 m
.67854 .89832 L
s
1 .757 0 r
.008 w
.67854 .89832 Mdot
.016 w
.67854 .89832 m
.67961 .89779 L
s
.008 w
.67961 .89779 Mdot
.016 w
.67961 .89779 m
.68079 .89716 L
s
1 .756 0 r
.008 w
.68079 .89716 Mdot
.016 w
.68079 .89716 m
.68205 .89642 L
s
.008 w
.68205 .89642 Mdot
.016 w
.68205 .89642 m
.68339 .89556 L
s
1 .755 0 r
.008 w
.68339 .89556 Mdot
.016 w
.68339 .89556 m
.68494 .89457 L
s
.008 w
.68494 .89457 Mdot
.016 w
.68494 .89457 m
.68666 .89346 L
s
1 .754 0 r
.008 w
.68666 .89346 Mdot
.016 w
.68666 .89346 m
.68859 .89224 L
s
.008 w
.68859 .89224 Mdot
.016 w
.68859 .89224 m
.69072 .89091 L
s
.008 w
.69072 .89091 Mdot
.016 w
.69072 .89091 m
.69309 .88952 L
s
1 .753 0 r
.008 w
.69309 .88952 Mdot
.016 w
.69309 .88952 m
.69558 .88799 L
s
.008 w
.69558 .88799 Mdot
.016 w
.69558 .88799 m
.69824 .88643 L
s
1 .752 0 r
.008 w
.69824 .88643 Mdot
.016 w
.69824 .88643 m
.70102 .88482 L
s
.008 w
.70102 .88482 Mdot
.016 w
.70102 .88482 m
.70364 .88318 L
s
1 .751 0 r
.008 w
.70364 .88318 Mdot
.016 w
.70364 .88318 m
.70632 .88151 L
s
.008 w
.70632 .88151 Mdot
.016 w
.70632 .88151 m
.70905 .87979 L
s
.008 w
.70905 .87979 Mdot
.016 w
.70905 .87979 m
.71186 .87803 L
s
1 .75 0 r
.008 w
.71186 .87803 Mdot
.016 w
.71186 .87803 m
.71459 .87635 L
s
.008 w
.71459 .87635 Mdot
.016 w
.71459 .87635 m
.71726 .87467 L
s
1 .749 0 r
.008 w
.71726 .87467 Mdot
.016 w
.71726 .87467 m
.71992 .87301 L
s
.008 w
.71992 .87301 Mdot
.016 w
.71992 .87301 m
.72256 .87132 L
s
1 .748 0 r
.008 w
.72256 .87132 Mdot
.016 w
.72256 .87132 m
.7251 .8697 L
s
.008 w
.7251 .8697 Mdot
.016 w
.7251 .8697 m
.72746 .86815 L
s
1 .747 0 r
.008 w
.72746 .86815 Mdot
.016 w
.72746 .86815 m
.72932 .86688 L
s
.008 w
.72932 .86688 Mdot
.016 w
.72932 .86688 m
.73122 .86558 L
s
.008 w
.73122 .86558 Mdot
.016 w
.73122 .86558 m
.73297 .86444 L
s
1 .746 0 r
.008 w
.73297 .86444 Mdot
.016 w
.73297 .86444 m
.73451 .8634 L
s
.008 w
.73451 .8634 Mdot
.016 w
.73451 .8634 m
.73591 .86245 L
s
1 .745 0 r
.008 w
.73591 .86245 Mdot
.016 w
.73591 .86245 m
.73712 .86161 L
s
.008 w
.73712 .86161 Mdot
.016 w
.73712 .86161 m
.73813 .86089 L
s
1 .744 0 r
.008 w
.73813 .86089 Mdot
.016 w
.73813 .86089 m
.73897 .86026 L
s
.008 w
.73897 .86026 Mdot
.016 w
.73897 .86026 m
.73966 .85971 L
s
.008 w
.73966 .85971 Mdot
.016 w
.73966 .85971 m
.74023 .85921 L
s
1 .743 0 r
.008 w
.74023 .85921 Mdot
.016 w
.74023 .85921 m
.74073 .85874 L
s
.008 w
.74073 .85874 Mdot
.016 w
.74073 .85874 m
.74122 .85826 L
s
1 .742 0 r
.008 w
.74122 .85826 Mdot
.016 w
.74122 .85826 m
.74177 .85771 L
s
.008 w
.74177 .85771 Mdot
.016 w
.74177 .85771 m
.74238 .85707 L
s
1 .741 0 r
.008 w
.74238 .85707 Mdot
.016 w
.74238 .85707 m
.74303 .85633 L
s
.008 w
.74303 .85633 Mdot
.016 w
.74303 .85633 m
.74371 .85554 L
s
.008 w
.74371 .85554 Mdot
.016 w
.74371 .85554 m
.7444 .85472 L
s
1 .74 0 r
.008 w
.7444 .85472 Mdot
.016 w
.7444 .85472 m
.74505 .85391 L
s
.008 w
.74505 .85391 Mdot
.016 w
.74505 .85391 m
.74563 .85313 L
s
1 .739 0 r
.008 w
.74563 .85313 Mdot
.016 w
.74563 .85313 m
.74615 .85243 L
s
.008 w
.74615 .85243 Mdot
.016 w
.74615 .85243 m
.74655 .85182 L
s
1 .738 0 r
.008 w
.74655 .85182 Mdot
.016 w
.74655 .85182 m
.74683 .85132 L
s
.008 w
.74683 .85132 Mdot
.016 w
.74683 .85132 m
.74696 .85093 L
s
1 .737 0 r
.008 w
.74696 .85093 Mdot
.016 w
.74696 .85093 m
.74697 .85064 L
s
.008 w
.74697 .85064 Mdot
.016 w
.74697 .85064 m
.74687 .85045 L
s
.008 w
.74687 .85045 Mdot
.016 w
.74687 .85045 m
.7467 .85035 L
s
1 .736 0 r
.008 w
.7467 .85035 Mdot
.016 w
.7467 .85035 m
.74649 .85031 L
s
.008 w
.74649 .85031 Mdot
.016 w
.74649 .85031 m
.74633 .85034 L
s
1 .735 0 r
.008 w
.74633 .85034 Mdot
.016 w
.74633 .85034 m
.74622 .85042 L
s
.008 w
.74622 .85042 Mdot
.016 w
.74622 .85042 m
.7462 .85053 L
s
1 .734 0 r
.008 w
.7462 .85053 Mdot
.016 w
.7462 .85053 m
.74634 .85063 L
s
.008 w
.74634 .85063 Mdot
.016 w
.74634 .85063 m
.74669 .85068 L
s
.008 w
.74669 .85068 Mdot
.016 w
.74669 .85068 m
.74724 .85065 L
s
1 .733 0 r
.008 w
.74724 .85065 Mdot
.016 w
.74724 .85065 m
.74796 .85055 L
s
.008 w
.74796 .85055 Mdot
.016 w
.74796 .85055 m
.74892 .85036 L
s
1 .732 0 r
.008 w
.74892 .85036 Mdot
.016 w
.74892 .85036 m
.75009 .85004 L
s
.008 w
.75009 .85004 Mdot
.016 w
.75009 .85004 m
.75147 .84958 L
s
1 .731 0 r
.008 w
.75147 .84958 Mdot
.016 w
.75147 .84958 m
.75304 .84893 L
s
.008 w
.75304 .84893 Mdot
.016 w
.75304 .84893 m
.75481 .84812 L
s
.008 w
.75481 .84812 Mdot
.016 w
.75481 .84812 m
.75672 .84716 L
s
1 .73 0 r
.008 w
.75672 .84716 Mdot
.016 w
.75672 .84716 m
.75878 .84608 L
s
.008 w
.75878 .84608 Mdot
.016 w
.75878 .84608 m
.76091 .84488 L
s
1 .729 0 r
.008 w
.76091 .84488 Mdot
.016 w
.76091 .84488 m
.76314 .84358 L
s
.008 w
.76314 .84358 Mdot
.016 w
.76314 .84358 m
.76545 .84216 L
s
1 .728 0 r
.008 w
.76545 .84216 Mdot
.016 w
.76545 .84216 m
.76785 .84062 L
s
.008 w
.76785 .84062 Mdot
.016 w
.76785 .84062 m
.77021 .83898 L
s
1 .727 0 r
.008 w
.77021 .83898 Mdot
.016 w
.77021 .83898 m
.77261 .83724 L
s
.008 w
.77261 .83724 Mdot
.016 w
.77261 .83724 m
.77503 .83547 L
s
.008 w
.77503 .83547 Mdot
.016 w
.77503 .83547 m
.77745 .83366 L
s
1 .726 0 r
.008 w
.77745 .83366 Mdot
.016 w
.77745 .83366 m
.77973 .83188 L
s
.008 w
.77973 .83188 Mdot
.016 w
.77973 .83188 m
.78192 .83017 L
s
1 .725 0 r
.008 w
.78192 .83017 Mdot
.016 w
.78192 .83017 m
.78391 .82867 L
s
.008 w
.78391 .82867 Mdot
.016 w
.78391 .82867 m
.78563 .82727 L
s
1 .724 0 r
.008 w
.78563 .82727 Mdot
.016 w
.78563 .82727 m
.78705 .82607 L
s
.008 w
.78705 .82607 Mdot
.016 w
.78705 .82607 m
.78815 .82507 L
s
.008 w
.78815 .82507 Mdot
.016 w
.78815 .82507 m
.78896 .82428 L
s
1 .723 0 r
.008 w
.78896 .82428 Mdot
.016 w
.78896 .82428 m
.78949 .82369 L
s
.008 w
.78949 .82369 Mdot
.016 w
.78949 .82369 m
.7898 .82327 L
s
1 .722 0 r
.008 w
.7898 .82327 Mdot
.016 w
.7898 .82327 m
.78995 .82298 L
s
.008 w
.78995 .82298 Mdot
.016 w
.78995 .82298 m
.79003 .82278 L
s
1 .721 0 r
.008 w
.79003 .82278 Mdot
.016 w
.79003 .82278 m
.79001 .82263 L
s
.008 w
.79001 .82263 Mdot
.016 w
.79001 .82263 m
.78993 .82244 L
s
.008 w
.78993 .82244 Mdot
.016 w
.78993 .82244 m
.7899 .8221 L
s
1 .72 0 r
.008 w
.7899 .8221 Mdot
.016 w
.7899 .8221 m
.78996 .82159 L
s
.008 w
.78996 .82159 Mdot
.016 w
.78996 .82159 m
.79011 .82083 L
s
1 .719 0 r
.008 w
.79011 .82083 Mdot
.016 w
.79011 .82083 m
.79042 .81981 L
s
.008 w
.79042 .81981 Mdot
.016 w
.79042 .81981 m
.79088 .81855 L
s
1 .718 0 r
.008 w
.79088 .81855 Mdot
.016 w
.79088 .81855 m
.7915 .81716 L
s
.008 w
.7915 .81716 Mdot
.016 w
.7915 .81716 m
.7922 .81562 L
s
1 .717 0 r
.008 w
.7922 .81562 Mdot
.016 w
.7922 .81562 m
.7929 .81408 L
s
.008 w
.7929 .81408 Mdot
.016 w
.7929 .81408 m
.7935 .81262 L
s
.008 w
.7935 .81262 Mdot
.016 w
.7935 .81262 m
.79394 .81137 L
s
1 .716 0 r
.008 w
.79394 .81137 Mdot
.016 w
.79394 .81137 m
.79419 .81046 L
s
.008 w
.79419 .81046 Mdot
.016 w
.79419 .81046 m
.79426 .80992 L
s
1 .715 0 r
.008 w
.79426 .80992 Mdot
.016 w
.79426 .80992 m
.7942 .80979 L
s
.008 w
.7942 .80979 Mdot
.016 w
.7942 .80979 m
.7941 .81003 L
s
1 .714 0 r
.008 w
.7941 .81003 Mdot
.016 w
.7941 .81003 m
.79401 .81053 L
s
.008 w
.79401 .81053 Mdot
.016 w
.79401 .81053 m
.79407 .81115 L
s
.008 w
.79407 .81115 Mdot
.016 w
.79407 .81115 m
.79436 .81185 L
s
1 .713 0 r
.008 w
.79436 .81185 Mdot
.016 w
.79436 .81185 m
.79484 .81233 L
s
.008 w
.79484 .81233 Mdot
.016 w
.79484 .81233 m
.79558 .81283 L
s
1 .712 0 r
.008 w
.79558 .81283 Mdot
.016 w
.79558 .81283 m
.79657 .81319 L
s
.008 w
.79657 .81319 Mdot
.016 w
.79657 .81319 m
.79779 .81331 L
s
1 .711 0 r
.008 w
.79779 .81331 Mdot
.016 w
.79779 .81331 m
.79933 .81318 L
s
.008 w
.79933 .81318 Mdot
.016 w
.79933 .81318 m
.80117 .81274 L
s
1 .71 0 r
.008 w
.80117 .81274 Mdot
.016 w
.80117 .81274 m
.80328 .81189 L
s
.008 w
.80328 .81189 Mdot
.016 w
.80328 .81189 m
.80571 .81063 L
s
.008 w
.80571 .81063 Mdot
.016 w
.80571 .81063 m
.80829 .80907 L
s
1 .709 0 r
.008 w
.80829 .80907 Mdot
.016 w
.80829 .80907 m
.81103 .80719 L
s
.008 w
.81103 .80719 Mdot
.016 w
.81103 .80719 m
.81381 .8051 L
s
1 .708 0 r
.008 w
.81381 .8051 Mdot
.016 w
.81381 .8051 m
.81662 .80276 L
s
.008 w
.81662 .80276 Mdot
.016 w
.81662 .80276 m
.81948 .80037 L
s
1 .707 0 r
.008 w
.81948 .80037 Mdot
.016 w
.81948 .80037 m
.82226 .79802 L
s
.008 w
.82226 .79802 Mdot
.016 w
.82226 .79802 m
.82515 .79558 L
s
.008 w
.82515 .79558 Mdot
.016 w
.82515 .79558 m
.82802 .79316 L
s
1 .706 0 r
.008 w
.82802 .79316 Mdot
.016 w
.82802 .79316 m
.83096 .79076 L
s
.008 w
.83096 .79076 Mdot
.016 w
.83096 .79076 m
.83384 .78846 L
s
1 .705 0 r
.008 w
.83384 .78846 Mdot
.016 w
.83384 .78846 m
.83663 .78618 L
s
.008 w
.83663 .78618 Mdot
.016 w
.83663 .78618 m
.83932 .78405 L
s
1 .704 0 r
.008 w
.83932 .78405 Mdot
.016 w
.83932 .78405 m
.84185 .78205 L
s
.008 w
.84185 .78205 Mdot
.016 w
.84185 .78205 m
.84424 .78022 L
s
.008 w
.84424 .78022 Mdot
.016 w
.84424 .78022 m
.8465 .77852 L
s
1 .703 0 r
.008 w
.8465 .77852 Mdot
.016 w
.8465 .77852 m
.84849 .77697 L
s
.008 w
.84849 .77697 Mdot
.016 w
.84849 .77697 m
.85041 .77549 L
s
1 .702 0 r
.008 w
.85041 .77549 Mdot
.016 w
.85041 .77549 m
.85224 .77395 L
s
.008 w
.85224 .77395 Mdot
.016 w
.85224 .77395 m
.85416 .77231 L
s
1 .701 0 r
.008 w
.85416 .77231 Mdot
.016 w
.85416 .77231 m
.85591 .7705 L
s
.008 w
.85591 .7705 Mdot
.016 w
.85591 .7705 m
.85731 .76878 L
s
1 .7 0 r
.008 w
.85731 .76878 Mdot
.016 w
.85731 .76878 m
.85884 .76678 L
s
.008 w
.85884 .76678 Mdot
.016 w
.85884 .76678 m
.86016 .76481 L
s
.008 w
.86016 .76481 Mdot
.016 w
.86016 .76481 m
.86162 .76256 L
s
1 .699 0 r
.008 w
.86162 .76256 Mdot
.016 w
.86162 .76256 m
.86277 .76054 L
s
.008 w
.86277 .76054 Mdot
.016 w
.86277 .76054 m
.86402 .75838 L
s
1 .698 0 r
.008 w
.86402 .75838 Mdot
.016 w
.86402 .75838 m
.86526 .75614 L
s
.008 w
.86526 .75614 Mdot
.016 w
.86526 .75614 m
.86644 .75385 L
s
1 .697 0 r
.008 w
.86644 .75385 Mdot
.016 w
.86644 .75385 m
.86752 .7515 L
s
.008 w
.86752 .7515 Mdot
.016 w
.86752 .7515 m
.86846 .74918 L
s
.008 w
.86846 .74918 Mdot
.016 w
.86846 .74918 m
.86926 .74687 L
s
1 .696 0 r
.008 w
.86926 .74687 Mdot
.016 w
.86926 .74687 m
.86994 .74437 L
s
.008 w
.86994 .74437 Mdot
.016 w
.86994 .74437 m
.87038 .74224 L
s
1 .695 0 r
.008 w
.87038 .74224 Mdot
.016 w
.87038 .74224 m
.87077 .74002 L
s
.008 w
.87077 .74002 Mdot
.016 w
.87077 .74002 m
.87109 .73811 L
s
1 .694 0 r
.008 w
.87109 .73811 Mdot
.016 w
.87109 .73811 m
.87137 .73627 L
s
.008 w
.87137 .73627 Mdot
.016 w
.87137 .73627 m
.87155 .73461 L
s
.008 w
.87155 .73461 Mdot
.016 w
.87155 .73461 m
.87167 .73321 L
s
1 .693 0 r
.008 w
.87167 .73321 Mdot
.016 w
.87167 .73321 m
.87174 .73203 L
s
.008 w
.87174 .73203 Mdot
.016 w
.87174 .73203 m
.87175 .73104 L
s
1 .692 0 r
.008 w
.87175 .73104 Mdot
.016 w
.87175 .73104 m
.87174 .73025 L
s
.008 w
.87174 .73025 Mdot
.016 w
.87174 .73025 m
.87173 .7296 L
s
1 .691 0 r
.008 w
.87173 .7296 Mdot
.016 w
.87173 .7296 m
.87173 .72911 L
s
.008 w
.87173 .72911 Mdot
.016 w
.87173 .72911 m
.87176 .72883 L
s
1 .69 0 r
.008 w
.87176 .72883 Mdot
.016 w
.87176 .72883 m
.87188 .7287 L
s
.008 w
.87188 .7287 Mdot
.016 w
.87188 .7287 m
.87213 .72859 L
s
.008 w
.87213 .72859 Mdot
.016 w
.87213 .72859 m
.87254 .72833 L
s
1 .689 0 r
.008 w
.87254 .72833 Mdot
.016 w
.87254 .72833 m
.87309 .72776 L
s
.008 w
.87309 .72776 Mdot
.016 w
.87309 .72776 m
.8738 .72686 L
s
1 .688 0 r
.008 w
.8738 .72686 Mdot
.016 w
.8738 .72686 m
.87466 .72558 L
s
.008 w
.87466 .72558 Mdot
.016 w
.87466 .72558 m
.87566 .72391 L
s
1 .687 0 r
.008 w
.87566 .72391 Mdot
.016 w
.87566 .72391 m
.87681 .72187 L
s
.008 w
.87681 .72187 Mdot
.016 w
.87681 .72187 m
.87806 .71952 L
s
.008 w
.87806 .71952 Mdot
.016 w
.87806 .71952 m
.87939 .71684 L
s
1 .686 0 r
.008 w
.87939 .71684 Mdot
.016 w
.87939 .71684 m
.88075 .71401 L
s
.008 w
.88075 .71401 Mdot
.016 w
.88075 .71401 m
.88211 .71092 L
s
1 .685 0 r
.008 w
.88211 .71092 Mdot
.016 w
.88211 .71092 m
.88344 .70773 L
s
.008 w
.88344 .70773 Mdot
.016 w
.88344 .70773 m
.88474 .70433 L
s
1 .684 0 r
.008 w
.88474 .70433 Mdot
.016 w
.88474 .70433 m
.88598 .7009 L
s
.008 w
.88598 .7009 Mdot
.016 w
.88598 .7009 m
.88715 .69738 L
s
.008 w
.88715 .69738 Mdot
.016 w
.88715 .69738 m
.88822 .69387 L
s
1 .683 0 r
.008 w
.88822 .69387 Mdot
.016 w
.88822 .69387 m
.88919 .69044 L
s
.008 w
.88919 .69044 Mdot
.016 w
.88919 .69044 m
.89007 .68724 L
s
1 .682 0 r
.008 w
.89007 .68724 Mdot
.016 w
.89007 .68724 m
.89083 .68423 L
s
.008 w
.89083 .68423 Mdot
.016 w
.89083 .68423 m
.89147 .68159 L
s
1 .681 0 r
.008 w
.89147 .68159 Mdot
.016 w
.89147 .68159 m
.89195 .67925 L
s
.008 w
.89195 .67925 Mdot
.016 w
.89195 .67925 m
.89231 .67726 L
s
1 .68 0 r
.008 w
.89231 .67726 Mdot
.016 w
.89231 .67726 m
.89258 .67558 L
s
.008 w
.89258 .67558 Mdot
.016 w
.89258 .67558 m
.89279 .6742 L
s
.008 w
.89279 .6742 Mdot
.016 w
.89279 .6742 m
.89297 .67306 L
s
1 .679 0 r
.008 w
.89297 .67306 Mdot
.016 w
.89297 .67306 m
.89316 .67219 L
s
.008 w
.89316 .67219 Mdot
.016 w
.89316 .67219 m
.89338 .67148 L
s
1 .678 0 r
.008 w
.89338 .67148 Mdot
.016 w
.89338 .67148 m
.89361 .67093 L
s
.008 w
.89361 .67093 Mdot
.016 w
.89361 .67093 m
.89389 .67038 L
s
1 .677 0 r
.008 w
.89389 .67038 Mdot
.016 w
.89389 .67038 m
.89425 .66979 L
s
.008 w
.89425 .66979 Mdot
.016 w
.89425 .66979 m
.89471 .669 L
s
.008 w
.89471 .669 Mdot
.016 w
.89471 .669 m
.89521 .66821 L
s
1 .676 0 r
.008 w
.89521 .66821 Mdot
.016 w
.89521 .66821 m
.89579 .66709 L
s
.008 w
.89579 .66709 Mdot
.016 w
.89579 .66709 m
.89653 .6656 L
s
1 .675 0 r
.008 w
.89653 .6656 Mdot
.016 w
.89653 .6656 m
.89712 .66409 L
s
.008 w
.89712 .66409 Mdot
.016 w
.89712 .66409 m
.89769 .66241 L
s
1 .674 0 r
.008 w
.89769 .66241 Mdot
.016 w
.89769 .66241 m
.89821 .66051 L
s
.008 w
.89821 .66051 Mdot
.016 w
.89821 .66051 m
.89864 .65843 L
s
1 .673 0 r
.008 w
.89864 .65843 Mdot
.016 w
.89864 .65843 m
.89898 .65622 L
s
.008 w
.89898 .65622 Mdot
.016 w
.89898 .65622 m
.89921 .65401 L
s
.008 w
.89921 .65401 Mdot
.016 w
.89921 .65401 m
.89931 .65196 L
s
1 .672 0 r
.008 w
.89931 .65196 Mdot
.016 w
.89931 .65196 m
.8993 .65007 L
s
.008 w
.8993 .65007 Mdot
.016 w
.8993 .65007 m
.8992 .64844 L
s
1 .671 0 r
.008 w
.8992 .64844 Mdot
.016 w
.8992 .64844 m
.89902 .64716 L
s
.008 w
.89902 .64716 Mdot
.016 w
.89902 .64716 m
.89884 .64622 L
s
1 .67 0 r
.008 w
.89884 .64622 Mdot
.016 w
.89884 .64622 m
.89871 .64554 L
s
.008 w
.89871 .64554 Mdot
.016 w
.89871 .64554 m
.89865 .64512 L
s
.008 w
.89865 .64512 Mdot
.016 w
.89865 .64512 m
.89864 .64497 L
s
1 .669 0 r
.008 w
.89864 .64497 Mdot
.016 w
.89864 .64497 m
.89868 .64501 L
s
.008 w
.89868 .64501 Mdot
.016 w
.89868 .64501 m
.89875 .64521 L
s
1 .668 0 r
.008 w
.89875 .64521 Mdot
.016 w
.89875 .64521 m
.89879 .64555 L
s
.008 w
.89879 .64555 Mdot
.016 w
.89879 .64555 m
.89879 .64605 L
s
1 .667 0 r
.008 w
.89879 .64605 Mdot
.016 w
.89879 .64605 m
.89871 .64672 L
s
.008 w
.89871 .64672 Mdot
.016 w
.89871 .64672 m
.89852 .64749 L
s
.008 w
.89852 .64749 Mdot
.016 w
.89852 .64749 m
.89821 .64831 L
s
1 .666 0 r
.008 w
.89821 .64831 Mdot
.016 w
.89821 .64831 m
.89779 .64905 L
s
.008 w
.89779 .64905 Mdot
.016 w
.89779 .64905 m
.89725 .64962 L
s
1 .665 0 r
.008 w
.89725 .64962 Mdot
.016 w
.89725 .64962 m
.89665 .65002 L
s
.008 w
.89665 .65002 Mdot
.016 w
.89665 .65002 m
.89594 .65027 L
s
1 .664 0 r
.008 w
.89594 .65027 Mdot
.016 w
.89594 .65027 m
.89506 .65044 L
s
.008 w
.89506 .65044 Mdot
.016 w
.89506 .65044 m
.89403 .65057 L
s
1 .663 0 r
.008 w
.89403 .65057 Mdot
.016 w
.89403 .65057 m
.89287 .65069 L
s
.008 w
.89287 .65069 Mdot
.016 w
.89287 .65069 m
.89153 .65086 L
s
.008 w
.89153 .65086 Mdot
.016 w
.89153 .65086 m
.89011 .65098 L
s
1 .662 0 r
.008 w
.89011 .65098 Mdot
.016 w
.89011 .65098 m
.88868 .65099 L
s
.008 w
.88868 .65099 Mdot
.016 w
.88868 .65099 m
.88726 .65084 L
s
1 .661 0 r
.008 w
.88726 .65084 Mdot
.016 w
.88726 .65084 m
.88593 .65059 L
s
.008 w
.88593 .65059 Mdot
.016 w
.88593 .65059 m
.88482 .65025 L
s
1 .66 0 r
.008 w
.88482 .65025 Mdot
.016 w
.88482 .65025 m
.88381 .64988 L
s
.008 w
.88381 .64988 Mdot
.016 w
.88381 .64988 m
.88286 .64956 L
s
.008 w
.88286 .64956 Mdot
.016 w
.88286 .64956 m
.88199 .64929 L
s
1 .659 0 r
.008 w
.88199 .64929 Mdot
.016 w
.88199 .64929 m
.88127 .64907 L
s
.008 w
.88127 .64907 Mdot
.016 w
.88127 .64907 m
.8808 .64887 L
s
1 .658 0 r
.008 w
.8808 .64887 Mdot
.016 w
.8808 .64887 m
.88045 .64871 L
s
.008 w
.88045 .64871 Mdot
.016 w
.88045 .64871 m
.88024 .64862 L
s
1 .657 0 r
.008 w
.88024 .64862 Mdot
.016 w
.88024 .64862 m
.88019 .64862 L
s
.008 w
.88019 .64862 Mdot
.016 w
.88019 .64862 m
.88027 .64876 L
s
.008 w
.88027 .64876 Mdot
.016 w
.88027 .64876 m
.88044 .6491 L
s
1 .656 0 r
.008 w
.88044 .6491 Mdot
.016 w
.88044 .6491 m
.88064 .64973 L
s
.008 w
.88064 .64973 Mdot
.016 w
.88064 .64973 m
.88084 .65074 L
s
1 .655 0 r
.008 w
.88084 .65074 Mdot
.016 w
.88084 .65074 m
.881 .65215 L
s
.008 w
.881 .65215 Mdot
.016 w
.881 .65215 m
.88113 .65398 L
s
1 .654 0 r
.008 w
.88113 .65398 Mdot
.016 w
.88113 .65398 m
.88125 .65624 L
s
.008 w
.88125 .65624 Mdot
.016 w
.88125 .65624 m
.88132 .65872 L
s
1 .653 0 r
.008 w
.88132 .65872 Mdot
.016 w
.88132 .65872 m
.88131 .6616 L
s
.008 w
.88131 .6616 Mdot
.016 w
.88131 .6616 m
.88126 .66461 L
s
.008 w
.88126 .66461 Mdot
.016 w
.88126 .66461 m
.88121 .66788 L
s
1 .652 0 r
.008 w
.88121 .66788 Mdot
.016 w
.88121 .66788 m
.88118 .67084 L
s
.008 w
.88118 .67084 Mdot
.016 w
.88118 .67084 m
.88115 .67379 L
s
1 .651 0 r
.008 w
.88115 .67379 Mdot
.016 w
.88115 .67379 m
.88114 .67662 L
s
.008 w
.88114 .67662 Mdot
.016 w
.88114 .67662 m
.88113 .67914 L
s
1 .65 0 r
.008 w
.88113 .67914 Mdot
.016 w
.88113 .67914 m
.88111 .68128 L
s
.008 w
.88111 .68128 Mdot
.016 w
.88111 .68128 m
.8811 .68312 L
s
.008 w
.8811 .68312 Mdot
.016 w
.8811 .68312 m
.88108 .68462 L
s
1 .649 0 r
.008 w
.88108 .68462 Mdot
.016 w
.88108 .68462 m
.88107 .68574 L
s
.008 w
.88107 .68574 Mdot
.016 w
.88107 .68574 m
.88105 .68655 L
s
1 .648 0 r
.008 w
.88105 .68655 Mdot
.016 w
.88105 .68655 m
.88103 .68713 L
s
.008 w
.88103 .68713 Mdot
.016 w
.88103 .68713 m
.88101 .68749 L
s
1 .647 0 r
.008 w
.88101 .68749 Mdot
.016 w
.88101 .68749 m
.88099 .68769 L
s
.008 w
.88099 .68769 Mdot
.016 w
.88099 .68769 m
.88098 .68777 L
s
1 .646 0 r
.008 w
.88098 .68777 Mdot
.016 w
.88098 .68777 m
.88097 .68779 L
s
.008 w
.88097 .68779 Mdot
.016 w
.88097 .68779 m
.88099 .68775 L
s
.008 w
.88099 .68775 Mdot
.016 w
.88099 .68775 m
.88103 .6877 L
s
1 .645 0 r
.008 w
.88103 .6877 Mdot
.016 w
.88103 .6877 m
.88108 .68768 L
s
.008 w
.88108 .68768 Mdot
.016 w
.88108 .68768 m
.88112 .68771 L
s
1 .644 0 r
.008 w
.88112 .68771 Mdot
.016 w
.88112 .68771 m
.88114 .6878 L
s
.008 w
.88114 .6878 Mdot
.016 w
.88114 .6878 m
.88112 .68794 L
s
1 .643 0 r
.008 w
.88112 .68794 Mdot
.016 w
.88112 .68794 m
.88107 .68811 L
s
.008 w
.88107 .68811 Mdot
.016 w
.88107 .68811 m
.88098 .68829 L
s
.008 w
.88098 .68829 Mdot
.016 w
.88098 .68829 m
.88087 .6885 L
s
1 .642 0 r
.008 w
.88087 .6885 Mdot
.016 w
.88087 .6885 m
.88072 .68877 L
s
.008 w
.88072 .68877 Mdot
.016 w
.88072 .68877 m
.88055 .68916 L
s
1 .641 0 r
.008 w
.88055 .68916 Mdot
.016 w
.88055 .68916 m
.88038 .68969 L
s
.008 w
.88038 .68969 Mdot
.016 w
.88038 .68969 m
.88021 .69034 L
s
1 .64 0 r
.008 w
.88021 .69034 Mdot
.016 w
.88021 .69034 m
.88007 .69115 L
s
.008 w
.88007 .69115 Mdot
.016 w
.88007 .69115 m
.87997 .69212 L
s
.008 w
.87997 .69212 Mdot
.016 w
.87997 .69212 m
.87991 .6933 L
s
1 .639 0 r
.008 w
.87991 .6933 Mdot
.016 w
.87991 .6933 m
.87991 .69467 L
s
.008 w
.87991 .69467 Mdot
.016 w
.87991 .69467 m
.88 .69621 L
s
1 .638 0 r
.008 w
.88 .69621 Mdot
.016 w
.88 .69621 m
.88016 .6979 L
s
.008 w
.88016 .6979 Mdot
.016 w
.88016 .6979 m
.88037 .69963 L
s
1 .637 0 r
.008 w
.88037 .69963 Mdot
.016 w
.88037 .69963 m
.88061 .7015 L
s
.008 w
.88061 .7015 Mdot
.016 w
.88061 .7015 m
.88082 .70354 L
s
1 .636 0 r
.008 w
.88082 .70354 Mdot
.016 w
.88082 .70354 m
.88098 .70575 L
s
.008 w
.88098 .70575 Mdot
.016 w
.88098 .70575 m
.88104 .70815 L
s
.008 w
.88104 .70815 Mdot
.016 w
.88104 .70815 m
.88098 .71068 L
s
1 .635 0 r
.008 w
.88098 .71068 Mdot
.016 w
.88098 .71068 m
.88077 .71314 L
s
.008 w
.88077 .71314 Mdot
.016 w
.88077 .71314 m
.88043 .71565 L
s
1 .634 0 r
.008 w
.88043 .71565 Mdot
.016 w
.88043 .71565 m
.87998 .71808 L
s
.008 w
.87998 .71808 Mdot
.016 w
.87998 .71808 m
.87947 .72029 L
s
1 .633 0 r
.008 w
.87947 .72029 Mdot
.016 w
.87947 .72029 m
.87896 .72208 L
s
.008 w
.87896 .72208 Mdot
.016 w
.87896 .72208 m
.87844 .72366 L
s
.008 w
.87844 .72366 Mdot
.016 w
.87844 .72366 m
.87794 .725 L
s
1 .632 0 r
.008 w
.87794 .725 Mdot
.016 w
.87794 .725 m
.8775 .726 L
s
.008 w
.8775 .726 Mdot
.016 w
.8775 .726 m
.87714 .72677 L
s
1 .631 0 r
.008 w
.87714 .72677 Mdot
.016 w
.87714 .72677 m
.87689 .72738 L
s
.008 w
.87689 .72738 Mdot
.016 w
.87689 .72738 m
.87676 .72767 L
s
1 .63 0 r
.008 w
.87676 .72767 Mdot
.016 w
.87676 .72767 m
.87674 .72772 L
s
.008 w
.87674 .72772 Mdot
.016 w
.87674 .72772 m
.87686 .72756 L
s
.008 w
.87686 .72756 Mdot
.016 w
.87686 .72756 m
.8771 .7272 L
s
1 .629 0 r
.008 w
.8771 .7272 Mdot
.016 w
.8771 .7272 m
.87742 .72673 L
s
.008 w
.87742 .72673 Mdot
.016 w
.87742 .72673 m
.87776 .72623 L
s
1 .628 0 r
.008 w
.87776 .72623 Mdot
.016 w
.87776 .72623 m
.87806 .72581 L
s
.008 w
.87806 .72581 Mdot
.016 w
.87806 .72581 m
.87829 .72557 L
s
1 .627 0 r
.008 w
.87829 .72557 Mdot
.016 w
.87829 .72557 m
.87837 .72558 L
s
.008 w
.87837 .72558 Mdot
.016 w
.87837 .72558 m
.87828 .72586 L
s
1 .626 0 r
.008 w
.87828 .72586 Mdot
.016 w
.87828 .72586 m
.87801 .72639 L
s
.008 w
.87801 .72639 Mdot
.016 w
.87801 .72639 m
.87754 .72716 L
s
.008 w
.87754 .72716 Mdot
.016 w
.87754 .72716 m
.87688 .72818 L
s
1 .625 0 r
.008 w
.87688 .72818 Mdot
.016 w
.87688 .72818 m
.87604 .72945 L
s
.008 w
.87604 .72945 Mdot
.016 w
.87604 .72945 m
.87505 .73095 L
s
1 .624 0 r
.008 w
.87505 .73095 Mdot
.016 w
.87505 .73095 m
.87401 .73253 L
s
.008 w
.87401 .73253 Mdot
.016 w
.87401 .73253 m
.87288 .73415 L
s
1 .623 0 r
.008 w
.87288 .73415 Mdot
.016 w
.87288 .73415 m
.87172 .73572 L
s
.008 w
.87172 .73572 Mdot
.016 w
.87172 .73572 m
.87054 .7372 L
s
.008 w
.87054 .7372 Mdot
.016 w
.87054 .7372 m
.86939 .73863 L
s
1 .622 0 r
.008 w
.86939 .73863 Mdot
.016 w
.86939 .73863 m
.86836 .73984 L
s
.008 w
.86836 .73984 Mdot
.016 w
.86836 .73984 m
.86747 .74088 L
s
1 .621 0 r
.008 w
.86747 .74088 Mdot
.016 w
.86747 .74088 m
.86677 .74165 L
s
.008 w
.86677 .74165 Mdot
.016 w
.86677 .74165 m
.86628 .74213 L
s
1 .62 0 r
.008 w
.86628 .74213 Mdot
.016 w
.86628 .74213 m
.866 .74234 L
s
.008 w
.866 .74234 Mdot
.016 w
.866 .74234 m
.86594 .74228 L
s
.008 w
.86594 .74228 Mdot
.016 w
.86594 .74228 m
.86605 .74198 L
s
1 .619 0 r
.008 w
.86605 .74198 Mdot
.016 w
.86605 .74198 m
.86629 .74155 L
s
.008 w
.86629 .74155 Mdot
.016 w
.86629 .74155 m
.86661 .74105 L
s
1 .618 0 r
.008 w
.86661 .74105 Mdot
.016 w
.86661 .74105 m
.86691 .74069 L
s
.008 w
.86691 .74069 Mdot
.016 w
.86691 .74069 m
.86721 .7404 L
s
1 .617 0 r
.008 w
.86721 .7404 Mdot
.016 w
.86721 .7404 m
.86747 .74028 L
s
.008 w
.86747 .74028 Mdot
.016 w
.86747 .74028 m
.86764 .74043 L
s
1 .616 0 r
.008 w
.86764 .74043 Mdot
.016 w
.86764 .74043 m
.86772 .74079 L
s
.008 w
.86772 .74079 Mdot
.016 w
.86772 .74079 m
.86776 .74132 L
s
.008 w
.86776 .74132 Mdot
.016 w
.86776 .74132 m
.86774 .74197 L
s
1 .615 0 r
.008 w
.86774 .74197 Mdot
.016 w
.86774 .74197 m
.86767 .74277 L
s
.008 w
.86767 .74277 Mdot
.016 w
.86767 .74277 m
.86757 .74366 L
s
1 .614 0 r
.008 w
.86757 .74366 Mdot
.016 w
.86757 .74366 m
.86746 .74461 L
s
.008 w
.86746 .74461 Mdot
.016 w
.86746 .74461 m
.86733 .74566 L
s
1 .613 0 r
.008 w
.86733 .74566 Mdot
.016 w
.86733 .74566 m
.86718 .74671 L
s
.008 w
.86718 .74671 Mdot
.016 w
.86718 .74671 m
.86701 .74787 L
s
.008 w
.86701 .74787 Mdot
.016 w
.86701 .74787 m
.86689 .74899 L
s
1 .612 0 r
.008 w
.86689 .74899 Mdot
.016 w
.86689 .74899 m
.86683 .74996 L
s
.008 w
.86683 .74996 Mdot
.016 w
.86683 .74996 m
.8668 .75076 L
s
1 .611 0 r
.008 w
.8668 .75076 Mdot
.016 w
.8668 .75076 m
.86676 .75143 L
s
.008 w
.86676 .75143 Mdot
.016 w
.86676 .75143 m
.86669 .752 L
s
1 .61 0 r
.008 w
.86669 .752 Mdot
.016 w
.86669 .752 m
.86656 .75249 L
s
.008 w
.86656 .75249 Mdot
.016 w
.86656 .75249 m
.8664 .75286 L
s
1 .609 0 r
.008 w
.8664 .75286 Mdot
.016 w
.8664 .75286 m
.86622 .7531 L
s
.008 w
.86622 .7531 Mdot
.016 w
.86622 .7531 m
.86607 .75317 L
s
.008 w
.86607 .75317 Mdot
.016 w
.86607 .75317 m
.86594 .75307 L
s
1 .608 0 r
.008 w
.86594 .75307 Mdot
.016 w
.86594 .75307 m
.86589 .75283 L
s
.008 w
.86589 .75283 Mdot
.016 w
.86589 .75283 m
.86585 .75251 L
s
1 .607 0 r
.008 w
.86585 .75251 Mdot
.016 w
.86585 .75251 m
.86584 .75214 L
s
.008 w
.86584 .75214 Mdot
.016 w
.86584 .75214 m
.86586 .75171 L
s
1 .606 0 r
.008 w
.86586 .75171 Mdot
.016 w
.86586 .75171 m
.86592 .75132 L
s
.008 w
.86592 .75132 Mdot
.016 w
.86592 .75132 m
.86599 .751 L
s
.008 w
.86599 .751 Mdot
.016 w
.86599 .751 m
.86609 .75067 L
s
1 .605 0 r
.008 w
.86609 .75067 Mdot
.016 w
.86609 .75067 m
.86622 .75033 L
s
.008 w
.86622 .75033 Mdot
.016 w
.86622 .75033 m
.86634 .74995 L
s
1 .604 0 r
.008 w
.86634 .74995 Mdot
.016 w
.86634 .74995 m
.86644 .74958 L
s
.008 w
.86644 .74958 Mdot
.016 w
.86644 .74958 m
.86651 .74926 L
s
1 .603 0 r
.008 w
.86651 .74926 Mdot
.016 w
.86651 .74926 m
.86655 .74901 L
s
.008 w
.86655 .74901 Mdot
.016 w
.86655 .74901 m
.86655 .74889 L
s
.008 w
.86655 .74889 Mdot
.016 w
.86655 .74889 m
.86651 .74892 L
s
1 .602 0 r
.008 w
.86651 .74892 Mdot
.016 w
.86651 .74892 m
.86635 .74916 L
s
.008 w
.86635 .74916 Mdot
.016 w
.86635 .74916 m
.86609 .74963 L
s
1 .601 0 r
.008 w
.86609 .74963 Mdot
.016 w
.86609 .74963 m
.86572 .75035 L
s
.008 w
.86572 .75035 Mdot
.016 w
.86572 .75035 m
.86526 .75126 L
s
1 .6 0 r
.008 w
.86526 .75126 Mdot
.016 w
.86526 .75126 m
.86472 .75239 L
s
.008 w
.86472 .75239 Mdot
.016 w
.86472 .75239 m
.86408 .75373 L
s
1 .599 0 r
.008 w
.86408 .75373 Mdot
.016 w
.86408 .75373 m
.86333 .75518 L
s
.008 w
.86333 .75518 Mdot
.016 w
.86333 .75518 m
.86243 .7569 L
s
.008 w
.86243 .7569 Mdot
.016 w
.86243 .7569 m
.8614 .75878 L
s
1 .598 0 r
.008 w
.8614 .75878 Mdot
.016 w
.8614 .75878 m
.86027 .76079 L
s
.008 w
.86027 .76079 Mdot
.016 w
.86027 .76079 m
.85908 .76282 L
s
1 .597 0 r
.008 w
.85908 .76282 Mdot
.016 w
.85908 .76282 m
.85799 .7647 L
s
.008 w
.85799 .7647 Mdot
.016 w
.85799 .7647 m
.85693 .76642 L
s
1 .596 0 r
.008 w
.85693 .76642 Mdot
.016 w
.85693 .76642 m
.85597 .76793 L
s
.008 w
.85597 .76793 Mdot
.016 w
.85597 .76793 m
.85512 .76916 L
s
.008 w
.85512 .76916 Mdot
.016 w
.85512 .76916 m
.85444 .77006 L
s
1 .595 0 r
.008 w
.85444 .77006 Mdot
.016 w
.85444 .77006 m
.85391 .77067 L
s
.008 w
.85391 .77067 Mdot
.016 w
.85391 .77067 m
.8535 .77107 L
s
1 .594 0 r
.008 w
.8535 .77107 Mdot
.016 w
.8535 .77107 m
.85322 .77131 L
s
.008 w
.85322 .77131 Mdot
.016 w
.85322 .77131 m
.85306 .77144 L
s
1 .593 0 r
.008 w
.85306 .77144 Mdot
.016 w
.85306 .77144 m
.85302 .77147 L
s
.008 w
.85302 .77147 Mdot
.016 w
.85302 .77147 m
.85303 .77144 L
s
.008 w
.85303 .77144 Mdot
.016 w
.85303 .77144 m
.85303 .77141 L
s
1 .592 0 r
.008 w
.85303 .77141 Mdot
.016 w
.85303 .77141 m
.85299 .77142 L
s
.008 w
.85299 .77142 Mdot
.016 w
.85299 .77142 m
.85296 .77143 L
s
1 .591 0 r
.008 w
.85296 .77143 Mdot
.016 w
.85296 .77143 m
.85297 .77141 L
s
.008 w
.85297 .77141 Mdot
.016 w
.85297 .77141 m
.85296 .77138 L
s
1 .59 0 r
.008 w
.85296 .77138 Mdot
.016 w
.85296 .77138 m
.8529 .77139 L
s
.008 w
.8529 .77139 Mdot
.016 w
.8529 .77139 m
.85276 .77146 L
s
1 .589 0 r
.008 w
.85276 .77146 Mdot
.016 w
.85276 .77146 m
.85257 .77156 L
s
.008 w
.85257 .77156 Mdot
.016 w
.85257 .77156 m
.8524 .77164 L
s
.008 w
.8524 .77164 Mdot
.016 w
.8524 .77164 m
.85223 .77172 L
s
1 .588 0 r
.008 w
.85223 .77172 Mdot
.016 w
.85223 .77172 m
.85208 .77176 L
s
.008 w
.85208 .77176 Mdot
.016 w
.85208 .77176 m
.85195 .77173 L
s
1 .587 0 r
.008 w
.85195 .77173 Mdot
.016 w
.85195 .77173 m
.8518 .7717 L
s
.008 w
.8518 .7717 Mdot
.016 w
.8518 .7717 m
.8515 .77169 L
s
1 .586 0 r
.008 w
.8515 .77169 Mdot
.016 w
.8515 .77169 m
.85105 .77175 L
s
.008 w
.85105 .77175 Mdot
.016 w
.85105 .77175 m
.85047 .77176 L
s
.008 w
.85047 .77176 Mdot
.016 w
.85047 .77176 m
.84977 .77189 L
s
1 .585 0 r
.008 w
.84977 .77189 Mdot
.016 w
.84977 .77189 m
.84892 .77206 L
s
.008 w
.84892 .77206 Mdot
.016 w
.84892 .77206 m
.8479 .77217 L
s
1 .584 0 r
.008 w
.8479 .77217 Mdot
.016 w
.8479 .77217 m
.84685 .77219 L
s
.008 w
.84685 .77219 Mdot
.016 w
.84685 .77219 m
.84583 .77213 L
s
1 .583 0 r
.008 w
.84583 .77213 Mdot
.016 w
.84583 .77213 m
.84492 .77204 L
s
.008 w
.84492 .77204 Mdot
.016 w
.84492 .77204 m
.844 .77194 L
s
1 .582 0 r
.008 w
.844 .77194 Mdot
.016 w
.844 .77194 m
.84313 .77184 L
s
.008 w
.84313 .77184 Mdot
.016 w
.84313 .77184 m
.84251 .77173 L
s
.008 w
.84251 .77173 Mdot
.016 w
.84251 .77173 m
.84208 .77164 L
s
1 .581 0 r
.008 w
.84208 .77164 Mdot
.016 w
.84208 .77164 m
.84173 .77156 L
s
.008 w
.84173 .77156 Mdot
.016 w
.84173 .77156 m
.84151 .77153 L
s
1 .58 0 r
.008 w
.84151 .77153 Mdot
.016 w
.84151 .77153 m
.84149 .77153 L
s
.008 w
.84149 .77153 Mdot
.016 w
.84149 .77153 m
.84159 .77161 L
s
1 .579 0 r
.008 w
.84159 .77161 Mdot
.016 w
.84159 .77161 m
.84192 .77162 L
s
.008 w
.84192 .77162 Mdot
.016 w
.84192 .77162 m
.8424 .77157 L
s
.008 w
.8424 .77157 Mdot
.016 w
.8424 .77157 m
.84301 .77146 L
s
1 .578 0 r
.008 w
.84301 .77146 Mdot
.016 w
.84301 .77146 m
.84366 .77133 L
s
.008 w
.84366 .77133 Mdot
.016 w
.84366 .77133 m
.84437 .77115 L
s
1 .577 0 r
.008 w
.84437 .77115 Mdot
.016 w
.84437 .77115 m
.84509 .77091 L
s
.008 w
.84509 .77091 Mdot
.016 w
.84509 .77091 m
.84591 .77051 L
s
1 .576 0 r
.008 w
.84591 .77051 Mdot
.016 w
.84591 .77051 m
.84668 .7701 L
s
.008 w
.84668 .7701 Mdot
.016 w
.84668 .7701 m
.8475 .76955 L
s
.008 w
.8475 .76955 Mdot
.016 w
.8475 .76955 m
.84821 .76899 L
s
1 .575 0 r
.008 w
.84821 .76899 Mdot
.016 w
.84821 .76899 m
.8489 .76843 L
s
.008 w
.8489 .76843 Mdot
.016 w
.8489 .76843 m
.84949 .76789 L
s
1 .574 0 r
.008 w
.84949 .76789 Mdot
.016 w
.84949 .76789 m
.85 .76738 L
s
.008 w
.85 .76738 Mdot
.016 w
.85 .76738 m
.85046 .7669 L
s
1 .573 0 r
.008 w
.85046 .7669 Mdot
.016 w
.85046 .7669 m
.85084 .7665 L
s
.008 w
.85084 .7665 Mdot
.016 w
.85084 .7665 m
.85119 .76616 L
s
1 .572 0 r
.008 w
.85119 .76616 Mdot
.016 w
.85119 .76616 m
.85151 .76585 L
s
.008 w
.85151 .76585 Mdot
.016 w
.85151 .76585 m
.85182 .76553 L
s
.008 w
.85182 .76553 Mdot
.016 w
.85182 .76553 m
.85209 .76524 L
s
1 .571 0 r
.008 w
.85209 .76524 Mdot
.016 w
.85209 .76524 m
.85224 .76507 L
s
.008 w
.85224 .76507 Mdot
.016 w
.85224 .76507 m
.85228 .76503 L
s
1 .57 0 r
.008 w
.85228 .76503 Mdot
.016 w
.85228 .76503 m
.85228 .76505 L
s
.008 w
.85228 .76505 Mdot
.016 w
.85228 .76505 m
.85232 .76509 L
s
1 .569 0 r
.008 w
.85232 .76509 Mdot
.016 w
.85232 .76509 m
.85238 .76513 L
s
.008 w
.85238 .76513 Mdot
.016 w
.85238 .76513 m
.85244 .7652 L
s
.008 w
.85244 .7652 Mdot
.016 w
.85244 .7652 m
.85248 .76529 L
s
1 .568 0 r
.008 w
.85248 .76529 Mdot
.016 w
.85248 .76529 m
.85249 .76541 L
s
.008 w
.85249 .76541 Mdot
.016 w
.85249 .76541 m
.8525 .76553 L
s
1 .567 0 r
.008 w
.8525 .76553 Mdot
.016 w
.8525 .76553 m
.85249 .76565 L
s
.008 w
.85249 .76565 Mdot
.016 w
.85249 .76565 m
.85245 .76576 L
s
1 .566 0 r
.008 w
.85245 .76576 Mdot
.016 w
.85245 .76576 m
.85238 .76589 L
s
.008 w
.85238 .76589 Mdot
.016 w
.85238 .76589 m
.85228 .76604 L
s
.008 w
.85228 .76604 Mdot
.016 w
.85228 .76604 m
.85219 .76616 L
s
1 .565 0 r
.008 w
.85219 .76616 Mdot
.016 w
.85219 .76616 m
.85218 .76614 L
s
.008 w
.85218 .76614 Mdot
.016 w
.85218 .76614 m
.85228 .76602 L
s
1 .564 0 r
.008 w
.85228 .76602 Mdot
.016 w
.85228 .76602 m
.85249 .76579 L
s
.008 w
.85249 .76579 Mdot
.016 w
.85249 .76579 m
.85268 .76557 L
s
1 .563 0 r
.008 w
.85268 .76557 Mdot
.016 w
.85268 .76557 m
.85294 .7653 L
s
.008 w
.85294 .7653 Mdot
.016 w
.85294 .7653 m
.85318 .76504 L
s
1 .562 0 r
.008 w
.85318 .76504 Mdot
.016 w
.85318 .76504 m
.85339 .76483 L
s
.008 w
.85339 .76483 Mdot
.016 w
.85339 .76483 m
.85353 .76468 L
s
.008 w
.85353 .76468 Mdot
.016 w
.85353 .76468 m
.8536 .76462 L
s
1 .561 0 r
.008 w
.8536 .76462 Mdot
.016 w
.8536 .76462 m
.8536 .76466 L
s
.008 w
.8536 .76466 Mdot
.016 w
.8536 .76466 m
.85357 .76475 L
s
1 .56 0 r
.008 w
.85357 .76475 Mdot
.016 w
.85357 .76475 m
.85354 .76481 L
s
.008 w
.85354 .76481 Mdot
.016 w
.85354 .76481 m
.85352 .76485 L
s
1 .559 0 r
.008 w
.85352 .76485 Mdot
.016 w
.85352 .76485 m
.85348 .76488 L
s
.008 w
.85348 .76488 Mdot
.016 w
.85348 .76488 m
.85343 .76491 L
s
.008 w
.85343 .76491 Mdot
.016 w
.85343 .76491 m
.85338 .76494 L
s
1 .558 0 r
.008 w
.85338 .76494 Mdot
.016 w
.85338 .76494 m
.85335 .76494 L
s
.008 w
.85335 .76494 Mdot
.016 w
.85335 .76494 m
.85334 .76489 L
s
1 .557 0 r
.008 w
.85334 .76489 Mdot
.016 w
.85334 .76489 m
.85334 .76485 L
s
.008 w
.85334 .76485 Mdot
.016 w
.85334 .76485 m
.85335 .76477 L
s
1 .556 0 r
.008 w
.85335 .76477 Mdot
.016 w
.85335 .76477 m
.85336 .76468 L
s
.008 w
.85336 .76468 Mdot
.016 w
.85336 .76468 m
.85339 .76459 L
s
.008 w
.85339 .76459 Mdot
.016 w
.85339 .76459 m
.85343 .76451 L
s
1 .555 0 r
.008 w
.85343 .76451 Mdot
.016 w
.85343 .76451 m
.85347 .76445 L
s
.008 w
.85347 .76445 Mdot
.016 w
.85347 .76445 m
.85352 .76441 L
s
1 .554 0 r
.008 w
.85352 .76441 Mdot
.016 w
.85352 .76441 m
.85356 .7644 L
s
.008 w
.85356 .7644 Mdot
.016 w
.85356 .7644 m
.8536 .76441 L
s
1 .553 0 r
.008 w
.8536 .76441 Mdot
.016 w
.8536 .76441 m
.85362 .76442 L
s
.008 w
.85362 .76442 Mdot
.016 w
.85362 .76442 m
.85363 .76442 L
s
1 .552 0 r
.008 w
.85363 .76442 Mdot
.016 w
.85363 .76442 m
.85362 .76443 L
s
.008 w
.85362 .76443 Mdot
.016 w
.85362 .76443 m
.8536 .76444 L
s
.008 w
.8536 .76444 Mdot
.016 w
.8536 .76444 m
.85359 .76444 L
s
1 .551 0 r
.008 w
.85359 .76444 Mdot
.016 w
.85359 .76444 m
.85358 .76444 L
s
.008 w
.85358 .76444 Mdot
.016 w
.85358 .76444 m
.85358 .76442 L
s
1 .55 0 r
.008 w
.85358 .76442 Mdot
.016 w
.85358 .76442 m
.85359 .76438 L
s
.008 w
.85359 .76438 Mdot
.016 w
.85359 .76438 m
.85361 .76432 L
s
1 .549 0 r
.008 w
.85361 .76432 Mdot
.016 w
.85361 .76432 m
.85368 .76423 L
s
.008 w
.85368 .76423 Mdot
.016 w
.85368 .76423 m
.85376 .76414 L
s
.008 w
.85376 .76414 Mdot
.016 w
.85376 .76414 m
.85381 .76412 L
s
1 .548 0 r
.008 w
.85381 .76412 Mdot
.016 w
.85381 .76412 m
.85382 .76417 L
s
.008 w
.85382 .76417 Mdot
.016 w
.85382 .76417 m
.8538 .7643 L
s
1 .547 0 r
.008 w
.8538 .7643 Mdot
.016 w
.8538 .7643 m
.8537 .76456 L
s
.008 w
.8537 .76456 Mdot
.016 w
.8537 .76456 m
.85349 .76497 L
s
1 .546 0 r
.008 w
.85349 .76497 Mdot
.016 w
.85349 .76497 m
.85317 .76553 L
s
.008 w
.85317 .76553 Mdot
.016 w
.85317 .76553 m
.85274 .76617 L
s
1 .545 0 r
.008 w
.85274 .76617 Mdot
.016 w
.85274 .76617 m
.85225 .76682 L
s
.008 w
.85225 .76682 Mdot
.016 w
.85225 .76682 m
.85175 .76744 L
s
.008 w
.85175 .76744 Mdot
.016 w
.85175 .76744 m
.85128 .76801 L
s
1 .544 0 r
.008 w
.85128 .76801 Mdot
.016 w
.85128 .76801 m
.85083 .7685 L
s
.008 w
.85083 .7685 Mdot
.016 w
.85083 .7685 m
.85048 .76885 L
s
1 .543 0 r
.008 w
.85048 .76885 Mdot
.016 w
.85048 .76885 m
.85018 .76909 L
s
.008 w
.85018 .76909 Mdot
.016 w
.85018 .76909 m
.84993 .76926 L
s
1 .542 0 r
.008 w
.84993 .76926 Mdot
.016 w
.84993 .76926 m
.84979 .76924 L
s
.008 w
.84979 .76924 Mdot
.016 w
.84979 .76924 m
.84976 .76908 L
s
.008 w
.84976 .76908 Mdot
.016 w
.84976 .76908 m
.84985 .7688 L
s
1 .541 0 r
.008 w
.84985 .7688 Mdot
.016 w
.84985 .7688 m
.85015 .76828 L
s
.008 w
.85015 .76828 Mdot
.016 w
.85015 .76828 m
.85062 .76759 L
s
1 .54 0 r
.008 w
.85062 .76759 Mdot
.016 w
.85062 .76759 m
.85129 .76676 L
s
.008 w
.85129 .76676 Mdot
.016 w
.85129 .76676 m
.85212 .76589 L
s
1 .539 0 r
.008 w
.85212 .76589 Mdot
.016 w
.85212 .76589 m
.85312 .76495 L
s
.008 w
.85312 .76495 Mdot
.016 w
.85312 .76495 m
.85427 .76394 L
s
.008 w
.85427 .76394 Mdot
.016 w
.85427 .76394 m
.85557 .76284 L
s
1 .538 0 r
.008 w
.85557 .76284 Mdot
.016 w
.85557 .76284 m
.857 .76156 L
s
.008 w
.857 .76156 Mdot
.016 w
.857 .76156 m
.85859 .76003 L
s
1 .537 0 r
.008 w
.85859 .76003 Mdot
.016 w
.85859 .76003 m
.8603 .75823 L
s
.008 w
.8603 .75823 Mdot
.016 w
.8603 .75823 m
.86208 .75618 L
s
1 .536 0 r
.008 w
.86208 .75618 Mdot
.016 w
.86208 .75618 m
.86386 .75399 L
s
.008 w
.86386 .75399 Mdot
.016 w
.86386 .75399 m
.8657 .75151 L
s
1 .535 0 r
.008 w
.8657 .75151 Mdot
.016 w
.8657 .75151 m
.86746 .74891 L
s
.008 w
.86746 .74891 Mdot
.016 w
.86746 .74891 m
.86907 .7466 L
s
.008 w
.86907 .7466 Mdot
.016 w
.86907 .7466 m
.87049 .74423 L
s
1 .534 0 r
.008 w
.87049 .74423 Mdot
.016 w
.87049 .74423 m
.87167 .74215 L
s
.008 w
.87167 .74215 Mdot
.016 w
.87167 .74215 m
.87269 .74016 L
s
1 .533 0 r
.008 w
.87269 .74016 Mdot
.016 w
.87269 .74016 m
.87349 .73845 L
s
.008 w
.87349 .73845 Mdot
.016 w
.87349 .73845 m
.87409 .73707 L
s
1 .532 0 r
.008 w
.87409 .73707 Mdot
.016 w
.87409 .73707 m
.87452 .73594 L
s
.008 w
.87452 .73594 Mdot
.016 w
.87452 .73594 m
.87482 .7351 L
s
.008 w
.87482 .7351 Mdot
.016 w
.87482 .7351 m
.87503 .73457 L
s
1 .531 0 r
.008 w
.87503 .73457 Mdot
.016 w
.87503 .73457 m
.87517 .73431 L
s
.008 w
.87517 .73431 Mdot
.016 w
.87517 .73431 m
.87528 .73425 L
s
1 .53 0 r
.008 w
.87528 .73425 Mdot
.016 w
.87528 .73425 m
.87537 .73431 L
s
.008 w
.87537 .73431 Mdot
.016 w
.87537 .73431 m
.87547 .73444 L
s
1 .529 0 r
.008 w
.87547 .73444 Mdot
.016 w
.87547 .73444 m
.8756 .73459 L
s
.008 w
.8756 .73459 Mdot
.016 w
.8756 .73459 m
.87575 .73471 L
s
.008 w
.87575 .73471 Mdot
.016 w
.87575 .73471 m
.8759 .7348 L
s
1 .528 0 r
.008 w
.8759 .7348 Mdot
.016 w
.8759 .7348 m
.87604 .73484 L
s
.008 w
.87604 .73484 Mdot
.016 w
.87604 .73484 m
.87616 .73485 L
s
1 .527 0 r
.008 w
.87616 .73485 Mdot
.016 w
.87616 .73485 m
.87624 .73484 L
s
.008 w
.87624 .73484 Mdot
.016 w
.87624 .73484 m
.87629 .73484 L
s
1 .526 0 r
.008 w
.87629 .73484 Mdot
.016 w
.87629 .73484 m
.8763 .73487 L
s
.008 w
.8763 .73487 Mdot
.016 w
.8763 .73487 m
.87629 .73492 L
s
1 .525 0 r
.008 w
.87629 .73492 Mdot
.016 w
.87629 .73492 m
.87626 .73499 L
s
.008 w
.87626 .73499 Mdot
.016 w
.87626 .73499 m
.87623 .73506 L
s
.008 w
.87623 .73506 Mdot
.016 w
.87623 .73506 m
.87621 .73512 L
s
1 .524 0 r
.008 w
.87621 .73512 Mdot
.016 w
.87621 .73512 m
.8762 .73515 L
s
.008 w
.8762 .73515 Mdot
.016 w
.8762 .73515 m
.87619 .73512 L
s
1 .523 0 r
.008 w
.87619 .73512 Mdot
.016 w
.87619 .73512 m
.87618 .73501 L
s
.008 w
.87618 .73501 Mdot
.016 w
.87618 .73501 m
.87615 .73481 L
s
1 .522 0 r
.008 w
.87615 .73481 Mdot
.016 w
.87615 .73481 m
.87612 .73449 L
s
.008 w
.87612 .73449 Mdot
.016 w
.87612 .73449 m
.87608 .73406 L
s
.008 w
.87608 .73406 Mdot
.016 w
.87608 .73406 m
.87606 .73351 L
s
1 .521 0 r
.008 w
.87606 .73351 Mdot
.016 w
.87606 .73351 m
.87606 .73284 L
s
.008 w
.87606 .73284 Mdot
.016 w
.87606 .73284 m
.87608 .73208 L
s
1 .52 0 r
.008 w
.87608 .73208 Mdot
.016 w
.87608 .73208 m
.87615 .73122 L
s
.008 w
.87615 .73122 Mdot
.016 w
.87615 .73122 m
.87624 .7303 L
s
1 .519 0 r
.008 w
.87624 .7303 Mdot
.016 w
.87624 .7303 m
.87637 .72934 L
s
.008 w
.87637 .72934 Mdot
.016 w
.87637 .72934 m
.87652 .72839 L
s
.008 w
.87652 .72839 Mdot
.016 w
.87652 .72839 m
.8767 .72749 L
s
1 .518 0 r
.008 w
.8767 .72749 Mdot
.016 w
.8767 .72749 m
.87688 .72665 L
s
.008 w
.87688 .72665 Mdot
.016 w
.87688 .72665 m
.87706 .72592 L
s
1 .517 0 r
.008 w
.87706 .72592 Mdot
.016 w
.87706 .72592 m
.87725 .72531 L
s
.008 w
.87725 .72531 Mdot
.016 w
.87725 .72531 m
.87744 .72483 L
s
1 .516 0 r
.008 w
.87744 .72483 Mdot
.016 w
.87744 .72483 m
.87761 .72447 L
s
.008 w
.87761 .72447 Mdot
.016 w
.87761 .72447 m
.87776 .72422 L
s
1 .515 0 r
.008 w
.87776 .72422 Mdot
.016 w
.87776 .72422 m
.87788 .72407 L
s
.008 w
.87788 .72407 Mdot
.016 w
.87788 .72407 m
.87796 .72398 L
s
.008 w
.87796 .72398 Mdot
.016 w
.87796 .72398 m
.87803 .72395 L
s
1 .514 0 r
.008 w
.87803 .72395 Mdot
.016 w
.87803 .72395 m
.87808 .72396 L
s
.008 w
.87808 .72396 Mdot
.016 w
.87808 .72396 m
.87814 .72399 L
s
1 .513 0 r
.008 w
.87814 .72399 Mdot
.016 w
.87814 .72399 m
.87817 .72403 L
s
.008 w
.87817 .72403 Mdot
.016 w
.87817 .72403 m
.87817 .72407 L
s
1 .512 0 r
.008 w
.87817 .72407 Mdot
.016 w
.87817 .72407 m
.87812 .72411 L
s
.008 w
.87812 .72411 Mdot
.016 w
.87812 .72411 m
.87801 .72415 L
s
.008 w
.87801 .72415 Mdot
.016 w
.87801 .72415 m
.87785 .72419 L
s
1 .511 0 r
.008 w
.87785 .72419 Mdot
.016 w
.87785 .72419 m
.8776 .72422 L
s
.008 w
.8776 .72422 Mdot
.016 w
.8776 .72422 m
.87729 .72425 L
s
1 .51 0 r
.008 w
.87729 .72425 Mdot
.016 w
.87729 .72425 m
.87693 .72429 L
s
.008 w
.87693 .72429 Mdot
.016 w
.87693 .72429 m
.87654 .72432 L
s
1 .509 0 r
.008 w
.87654 .72432 Mdot
.016 w
.87654 .72432 m
.87614 .72436 L
s
.008 w
.87614 .72436 Mdot
.016 w
.87614 .72436 m
.87573 .7244 L
s
1 .508 0 r
.008 w
.87573 .7244 Mdot
.016 w
.87573 .7244 m
.87532 .72444 L
s
.008 w
.87532 .72444 Mdot
.016 w
.87532 .72444 m
.87494 .72448 L
s
.008 w
.87494 .72448 Mdot
.016 w
.87494 .72448 m
.87456 .72451 L
s
1 .507 0 r
.008 w
.87456 .72451 Mdot
.016 w
.87456 .72451 m
.87422 .72454 L
s
.008 w
.87422 .72454 Mdot
.016 w
.87422 .72454 m
.87397 .72455 L
s
1 .506 0 r
.008 w
.87397 .72455 Mdot
.016 w
.87397 .72455 m
.87382 .72457 L
s
.008 w
.87382 .72457 Mdot
.016 w
.87382 .72457 m
.8738 .7246 L
s
1 .505 0 r
.008 w
.8738 .7246 Mdot
.016 w
.8738 .7246 m
.87388 .72465 L
s
.008 w
.87388 .72465 Mdot
.016 w
.87388 .72465 m
.87405 .72474 L
s
.008 w
.87405 .72474 Mdot
.016 w
.87405 .72474 m
.8743 .72483 L
s
1 .504 0 r
.008 w
.8743 .72483 Mdot
.016 w
.8743 .72483 m
.87461 .72489 L
s
.008 w
.87461 .72489 Mdot
.016 w
.87461 .72489 m
.87496 .72486 L
s
1 .503 0 r
.008 w
.87496 .72486 Mdot
.016 w
.87496 .72486 m
.87532 .72471 L
s
.008 w
.87532 .72471 Mdot
.016 w
.87532 .72471 m
.87572 .72442 L
s
1 .502 0 r
.008 w
.87572 .72442 Mdot
.016 w
.87572 .72442 m
.87617 .72397 L
s
.008 w
.87617 .72397 Mdot
.016 w
.87617 .72397 m
.87664 .72337 L
s
.008 w
.87664 .72337 Mdot
.016 w
.87664 .72337 m
.87712 .72264 L
s
1 .501 0 r
.008 w
.87712 .72264 Mdot
.016 w
.87712 .72264 m
.87759 .72181 L
s
.008 w
.87759 .72181 Mdot
.016 w
.87759 .72181 m
.87801 .72093 L
s
1 .5 0 r
.008 w
.87801 .72093 Mdot
.016 w
.87801 .72093 m
.87839 .7201 L
s
.008 w
.87839 .7201 Mdot
.016 w
.87839 .7201 m
.87871 .71917 L
s
1 .499 0 r
.008 w
.87871 .71917 Mdot
.016 w
.87871 .71917 m
.87898 .71832 L
s
.008 w
.87898 .71832 Mdot
.016 w
.87898 .71832 m
.87923 .71752 L
s
1 .498 0 r
.008 w
.87923 .71752 Mdot
.016 w
.87923 .71752 m
.87944 .71682 L
s
.008 w
.87944 .71682 Mdot
.016 w
.87944 .71682 m
.87962 .71628 L
s
.008 w
.87962 .71628 Mdot
.016 w
.87962 .71628 m
.87978 .71592 L
s
1 .497 0 r
.008 w
.87978 .71592 Mdot
.016 w
.87978 .71592 m
.87992 .71575 L
s
.008 w
.87992 .71575 Mdot
.016 w
.87992 .71575 m
.88006 .71572 L
s
1 .496 0 r
.008 w
.88006 .71572 Mdot
.016 w
.88006 .71572 m
.88021 .71576 L
s
.008 w
.88021 .71576 Mdot
.016 w
.88021 .71576 m
.88037 .7158 L
s
1 .495 0 r
.008 w
.88037 .7158 Mdot
.016 w
.88037 .7158 m
.88057 .71573 L
s
.008 w
.88057 .71573 Mdot
.016 w
.88057 .71573 m
.88082 .71545 L
s
.008 w
.88082 .71545 Mdot
.016 w
.88082 .71545 m
.88115 .71486 L
s
1 .494 0 r
.008 w
.88115 .71486 Mdot
.016 w
.88115 .71486 m
.88155 .71394 L
s
.008 w
.88155 .71394 Mdot
.016 w
.88155 .71394 m
.88204 .71265 L
s
1 .493 0 r
.008 w
.88204 .71265 Mdot
.016 w
.88204 .71265 m
.8826 .71111 L
s
.008 w
.8826 .71111 Mdot
.016 w
.8826 .71111 m
.88321 .70933 L
s
1 .492 0 r
.008 w
.88321 .70933 Mdot
.016 w
.88321 .70933 m
.88389 .70723 L
s
.008 w
.88389 .70723 Mdot
.016 w
.88389 .70723 m
.88461 .705 L
s
.008 w
.88461 .705 Mdot
.016 w
.88461 .705 m
.88537 .70258 L
s
1 .491 0 r
.008 w
.88537 .70258 Mdot
.016 w
.88537 .70258 m
.88614 .70024 L
s
.008 w
.88614 .70024 Mdot
.016 w
.88614 .70024 m
.88688 .69793 L
s
1 .49 0 r
.008 w
.88688 .69793 Mdot
.016 w
.88688 .69793 m
.88765 .69573 L
s
.008 w
.88765 .69573 Mdot
.016 w
.88765 .69573 m
.8883 .69367 L
s
1 .489 0 r
.008 w
.8883 .69367 Mdot
.016 w
.8883 .69367 m
.88893 .69198 L
s
.008 w
.88893 .69198 Mdot
.016 w
.88893 .69198 m
.88946 .69048 L
s
1 .488 0 r
.008 w
.88946 .69048 Mdot
.016 w
.88946 .69048 m
.88989 .6892 L
s
.008 w
.88989 .6892 Mdot
.016 w
.88989 .6892 m
.89021 .68817 L
s
.008 w
.89021 .68817 Mdot
.016 w
.89021 .68817 m
.89044 .68731 L
s
1 .487 0 r
.008 w
.89044 .68731 Mdot
.016 w
.89044 .68731 m
.89058 .68657 L
s
.008 w
.89058 .68657 Mdot
.016 w
.89058 .68657 m
.89065 .68586 L
s
1 .486 0 r
.008 w
.89065 .68586 Mdot
.016 w
.89065 .68586 m
.89065 .68512 L
s
.008 w
.89065 .68512 Mdot
.016 w
.89065 .68512 m
.89062 .6843 L
s
1 .485 0 r
.008 w
.89062 .6843 Mdot
.016 w
.89062 .6843 m
.89055 .68334 L
s
.008 w
.89055 .68334 Mdot
.016 w
.89055 .68334 m
.89048 .6822 L
s
.008 w
.89048 .6822 Mdot
.016 w
.89048 .6822 m
.89041 .68084 L
s
1 .484 0 r
.008 w
.89041 .68084 Mdot
.016 w
.89041 .68084 m
.89035 .67935 L
s
.008 w
.89035 .67935 Mdot
.016 w
.89035 .67935 m
.89029 .67772 L
s
1 .483 0 r
.008 w
.89029 .67772 Mdot
.016 w
.89029 .67772 m
.89024 .67613 L
s
.008 w
.89024 .67613 Mdot
.016 w
.89024 .67613 m
.89021 .67461 L
s
1 .482 0 r
.008 w
.89021 .67461 Mdot
.016 w
.89021 .67461 m
.89018 .67334 L
s
.008 w
.89018 .67334 Mdot
.016 w
.89018 .67334 m
.89015 .67219 L
s
1 .481 0 r
.008 w
.89015 .67219 Mdot
.016 w
.89015 .67219 m
.89013 .67135 L
s
.008 w
.89013 .67135 Mdot
.016 w
.89013 .67135 m
.89012 .67072 L
s
.008 w
.89012 .67072 Mdot
.016 w
.89012 .67072 m
.89012 .67032 L
s
1 .48 0 r
.008 w
.89012 .67032 Mdot
.016 w
.89012 .67032 m
.89014 .67013 L
s
.008 w
.89014 .67013 Mdot
.016 w
.89014 .67013 m
.8902 .67014 L
s
1 .479 0 r
.008 w
.8902 .67014 Mdot
.016 w
.8902 .67014 m
.8903 .67034 L
s
.008 w
.8903 .67034 Mdot
.016 w
.8903 .67034 m
.89039 .6707 L
s
1 .478 0 r
.008 w
.89039 .6707 Mdot
.016 w
.89039 .6707 m
.89044 .67116 L
s
.008 w
.89044 .67116 Mdot
.016 w
.89044 .67116 m
.89045 .67168 L
s
.008 w
.89045 .67168 Mdot
.016 w
.89045 .67168 m
.89039 .6722 L
s
1 .477 0 r
.008 w
.89039 .6722 Mdot
.016 w
.89039 .6722 m
.89024 .67266 L
s
.008 w
.89024 .67266 Mdot
.016 w
.89024 .67266 m
.88997 .67298 L
s
1 .476 0 r
.008 w
.88997 .67298 Mdot
.016 w
.88997 .67298 m
.88958 .67314 L
s
.008 w
.88958 .67314 Mdot
.016 w
.88958 .67314 m
.88907 .67318 L
s
1 .475 0 r
.008 w
.88907 .67318 Mdot
.016 w
.88907 .67318 m
.88846 .67315 L
s
.008 w
.88846 .67315 Mdot
.016 w
.88846 .67315 m
.88779 .67313 L
s
.008 w
.88779 .67313 Mdot
.016 w
.88779 .67313 m
.88707 .67314 L
s
1 .474 0 r
.008 w
.88707 .67314 Mdot
.016 w
.88707 .67314 m
.88632 .67323 L
s
.008 w
.88632 .67323 Mdot
.016 w
.88632 .67323 m
.8855 .67342 L
s
1 .473 0 r
.008 w
.8855 .67342 Mdot
.016 w
.8855 .67342 m
.88462 .6737 L
s
.008 w
.88462 .6737 Mdot
.016 w
.88462 .6737 m
.88369 .67403 L
s
1 .472 0 r
.008 w
.88369 .67403 Mdot
.016 w
.88369 .67403 m
.88274 .6744 L
s
.008 w
.88274 .6744 Mdot
.016 w
.88274 .6744 m
.88182 .6748 L
s
1 .471 0 r
.008 w
.88182 .6748 Mdot
.016 w
.88182 .6748 m
.88091 .6752 L
s
.008 w
.88091 .6752 Mdot
.016 w
.88091 .6752 m
.87998 .67562 L
s
.008 w
.87998 .67562 Mdot
.016 w
.87998 .67562 m
.87907 .67608 L
s
1 .47 0 r
.008 w
.87907 .67608 Mdot
.016 w
.87907 .67608 m
.87815 .6766 L
s
.008 w
.87815 .6766 Mdot
.016 w
.87815 .6766 m
.87727 .67718 L
s
1 .469 0 r
.008 w
.87727 .67718 Mdot
.016 w
.87727 .67718 m
.87634 .6778 L
s
.008 w
.87634 .6778 Mdot
.016 w
.87634 .6778 m
.87532 .67845 L
s
1 .468 0 r
.008 w
.87532 .67845 Mdot
.016 w
.87532 .67845 m
.87419 .67913 L
s
.008 w
.87419 .67913 Mdot
.016 w
.87419 .67913 m
.87302 .67983 L
s
.008 w
.87302 .67983 Mdot
.016 w
.87302 .67983 m
.87183 .68055 L
s
1 .467 0 r
.008 w
.87183 .68055 Mdot
.016 w
.87183 .68055 m
.8706 .68133 L
s
.008 w
.8706 .68133 Mdot
.016 w
.8706 .68133 m
.86934 .68219 L
s
1 .466 0 r
.008 w
.86934 .68219 Mdot
.016 w
.86934 .68219 m
.86822 .68312 L
s
.008 w
.86822 .68312 Mdot
.016 w
.86822 .68312 m
.86712 .68411 L
s
1 .465 0 r
.008 w
.86712 .68411 Mdot
.016 w
.86712 .68411 m
.8661 .68515 L
s
.008 w
.8661 .68515 Mdot
.016 w
.8661 .68515 m
.86516 .68619 L
s
.008 w
.86516 .68619 Mdot
.016 w
.86516 .68619 m
.86437 .68717 L
s
1 .464 0 r
.008 w
.86437 .68717 Mdot
.016 w
.86437 .68717 m
.86363 .68802 L
s
.008 w
.86363 .68802 Mdot
.016 w
.86363 .68802 m
.86294 .68874 L
s
1 .463 0 r
.008 w
.86294 .68874 Mdot
.016 w
.86294 .68874 m
.86231 .68931 L
s
.008 w
.86231 .68931 Mdot
.016 w
.86231 .68931 m
.86176 .68974 L
s
1 .462 0 r
.008 w
.86176 .68974 Mdot
.016 w
.86176 .68974 m
.86127 .69004 L
s
.008 w
.86127 .69004 Mdot
.016 w
.86127 .69004 m
.86083 .69026 L
s
1 .461 0 r
.008 w
.86083 .69026 Mdot
.016 w
.86083 .69026 m
.86039 .69042 L
s
.008 w
.86039 .69042 Mdot
.016 w
.86039 .69042 m
.85988 .69053 L
s
.008 w
.85988 .69053 Mdot
.016 w
.85988 .69053 m
.85927 .69062 L
s
1 .46 0 r
.008 w
.85927 .69062 Mdot
.016 w
.85927 .69062 m
.85853 .69071 L
s
.008 w
.85853 .69071 Mdot
.016 w
.85853 .69071 m
.85761 .69081 L
s
1 .459 0 r
.008 w
.85761 .69081 Mdot
.016 w
.85761 .69081 m
.85666 .69094 L
s
.008 w
.85666 .69094 Mdot
.016 w
.85666 .69094 m
.85549 .69111 L
s
1 .458 0 r
.008 w
.85549 .69111 Mdot
.016 w
.85549 .69111 m
.85423 .69134 L
s
.008 w
.85423 .69134 Mdot
.016 w
.85423 .69134 m
.85307 .69161 L
s
.008 w
.85307 .69161 Mdot
.016 w
.85307 .69161 m
.85189 .69191 L
s
1 .457 0 r
.008 w
.85189 .69191 Mdot
.016 w
.85189 .69191 m
.85074 .69221 L
s
.008 w
.85074 .69221 Mdot
.016 w
.85074 .69221 m
.84968 .69251 L
s
1 .456 0 r
.008 w
.84968 .69251 Mdot
.016 w
.84968 .69251 m
.84877 .69278 L
s
.008 w
.84877 .69278 Mdot
.016 w
.84877 .69278 m
.84796 .69296 L
s
1 .455 0 r
.008 w
.84796 .69296 Mdot
.016 w
.84796 .69296 m
.84728 .69306 L
s
.008 w
.84728 .69306 Mdot
.016 w
.84728 .69306 m
.84675 .69307 L
s
.008 w
.84675 .69307 Mdot
.016 w
.84675 .69307 m
.84643 .69301 L
s
1 .454 0 r
.008 w
.84643 .69301 Mdot
.016 w
.84643 .69301 m
.84633 .69288 L
s
.008 w
.84633 .69288 Mdot
.016 w
.84633 .69288 m
.84644 .69272 L
s
1 .453 0 r
.008 w
.84644 .69272 Mdot
.016 w
.84644 .69272 m
.84667 .69261 L
s
.008 w
.84667 .69261 Mdot
.016 w
.84667 .69261 m
.84697 .6926 L
s
1 .452 0 r
.008 w
.84697 .6926 Mdot
.016 w
.84697 .6926 m
.84725 .69278 L
s
.008 w
.84725 .69278 Mdot
.016 w
.84725 .69278 m
.84746 .69316 L
s
1 .451 0 r
.008 w
.84746 .69316 Mdot
.016 w
.84746 .69316 m
.84758 .69375 L
s
.008 w
.84758 .69375 Mdot
.016 w
.84758 .69375 m
.84756 .69462 L
s
.008 w
.84756 .69462 Mdot
.016 w
.84756 .69462 m
.8474 .69578 L
s
1 .45 0 r
.008 w
.8474 .69578 Mdot
.016 w
.8474 .69578 m
.84714 .69714 L
s
.008 w
.84714 .69714 Mdot
.016 w
.84714 .69714 m
.84679 .69876 L
s
1 .449 0 r
.008 w
.84679 .69876 Mdot
.016 w
.84679 .69876 m
.84634 .70062 L
s
.008 w
.84634 .70062 Mdot
.016 w
.84634 .70062 m
.84585 .70251 L
s
1 .448 0 r
.008 w
.84585 .70251 Mdot
.016 w
.84585 .70251 m
.84524 .70462 L
s
.008 w
.84524 .70462 Mdot
.016 w
.84524 .70462 m
.8446 .70662 L
s
.008 w
.8446 .70662 Mdot
.016 w
.8446 .70662 m
.84391 .7086 L
s
1 .447 0 r
.008 w
.84391 .7086 Mdot
.016 w
.84391 .7086 m
.84322 .71047 L
s
.008 w
.84322 .71047 Mdot
.016 w
.84322 .71047 m
.84259 .71211 L
s
1 .446 0 r
.008 w
.84259 .71211 Mdot
.016 w
.84259 .71211 m
.84207 .71355 L
s
.008 w
.84207 .71355 Mdot
.016 w
.84207 .71355 m
.8417 .71476 L
s
1 .445 0 r
.008 w
.8417 .71476 Mdot
.016 w
.8417 .71476 m
.84147 .71567 L
s
.008 w
.84147 .71567 Mdot
.016 w
.84147 .71567 m
.84136 .71641 L
s
1 .444 0 r
.008 w
.84136 .71641 Mdot
.016 w
.84136 .71641 m
.84137 .71697 L
s
.008 w
.84137 .71697 Mdot
.016 w
.84137 .71697 m
.84146 .71739 L
s
.008 w
.84146 .71739 Mdot
.016 w
.84146 .71739 m
.84159 .71771 L
s
1 .443 0 r
.008 w
.84159 .71771 Mdot
.016 w
.84159 .71771 m
.84175 .71796 L
s
.008 w
.84175 .71796 Mdot
.016 w
.84175 .71796 m
.84192 .71816 L
s
1 .442 0 r
.008 w
.84192 .71816 Mdot
.016 w
.84192 .71816 m
.84212 .7183 L
s
.008 w
.84212 .7183 Mdot
.016 w
.84212 .7183 m
.84234 .71841 L
s
1 .441 0 r
.008 w
.84234 .71841 Mdot
.016 w
.84234 .71841 m
.84257 .7185 L
s
.008 w
.84257 .7185 Mdot
.016 w
.84257 .7185 m
.84279 .7186 L
s
.008 w
.84279 .7186 Mdot
.016 w
.84279 .7186 m
.84297 .7187 L
s
1 .44 0 r
.008 w
.84297 .7187 Mdot
.016 w
.84297 .7187 m
.84311 .7188 L
s
.008 w
.84311 .7188 Mdot
.016 w
.84311 .7188 m
.84321 .71888 L
s
1 .439 0 r
.008 w
.84321 .71888 Mdot
.016 w
.84321 .71888 m
.84326 .71893 L
s
.008 w
.84326 .71893 Mdot
.016 w
.84326 .71893 m
.84327 .71894 L
s
1 .438 0 r
.008 w
.84327 .71894 Mdot
.016 w
.84327 .71894 m
.84326 .71892 L
s
.008 w
.84326 .71892 Mdot
.016 w
.84326 .71892 m
.84326 .71884 L
s
.008 w
.84326 .71884 Mdot
.016 w
.84326 .71884 m
.84327 .7187 L
s
1 .437 0 r
.008 w
.84327 .7187 Mdot
.016 w
.84327 .7187 m
.84331 .71852 L
s
.008 w
.84331 .71852 Mdot
.016 w
.84331 .71852 m
.84337 .71835 L
s
1 .436 0 r
.008 w
.84337 .71835 Mdot
.016 w
.84337 .71835 m
.84344 .71822 L
s
.008 w
.84344 .71822 Mdot
.016 w
.84344 .71822 m
.84347 .71817 L
s
1 .435 0 r
.008 w
.84347 .71817 Mdot
.016 w
.84347 .71817 m
.84345 .71825 L
s
.008 w
.84345 .71825 Mdot
.016 w
.84345 .71825 m
.84334 .71849 L
s
1 .434 0 r
.008 w
.84334 .71849 Mdot
.016 w
.84334 .71849 m
.84315 .71892 L
s
.008 w
.84315 .71892 Mdot
.016 w
.84315 .71892 m
.84284 .71959 L
s
.008 w
.84284 .71959 Mdot
.016 w
.84284 .71959 m
.8424 .72051 L
s
1 .433 0 r
.008 w
.8424 .72051 Mdot
.016 w
.8424 .72051 m
.84184 .72168 L
s
.008 w
.84184 .72168 Mdot
.016 w
.84184 .72168 m
.84115 .72314 L
s
1 .432 0 r
.008 w
.84115 .72314 Mdot
.016 w
.84115 .72314 m
.84038 .72478 L
s
.008 w
.84038 .72478 Mdot
.016 w
.84038 .72478 m
.83951 .72668 L
s
1 .431 0 r
.008 w
.83951 .72668 Mdot
.016 w
.83951 .72668 m
.83855 .72886 L
s
.008 w
.83855 .72886 Mdot
.016 w
.83855 .72886 m
.83754 .73127 L
s
.008 w
.83754 .73127 Mdot
.016 w
.83754 .73127 m
.83652 .73365 L
s
1 .43 0 r
.008 w
.83652 .73365 Mdot
.016 w
.83652 .73365 m
.83549 .73616 L
s
.008 w
.83549 .73616 Mdot
.016 w
.83549 .73616 m
.83448 .73866 L
s
1 .429 0 r
.008 w
.83448 .73866 Mdot
.016 w
.83448 .73866 m
.83354 .74089 L
s
.008 w
.83354 .74089 Mdot
.016 w
.83354 .74089 m
.83271 .74285 L
s
1 .428 0 r
.008 w
.83271 .74285 Mdot
.016 w
.83271 .74285 m
.832 .74463 L
s
.008 w
.832 .74463 Mdot
.016 w
.832 .74463 m
.83142 .74618 L
s
.008 w
.83142 .74618 Mdot
.016 w
.83142 .74618 m
.83099 .74745 L
s
1 .427 0 r
.008 w
.83099 .74745 Mdot
.016 w
.83099 .74745 m
.83071 .74835 L
s
.008 w
.83071 .74835 Mdot
.016 w
.83071 .74835 m
.83057 .74906 L
s
1 .426 0 r
.008 w
.83057 .74906 Mdot
.016 w
.83057 .74906 m
.83057 .74958 L
s
.008 w
.83057 .74958 Mdot
.016 w
.83057 .74958 m
.83067 .74993 L
s
1 .425 0 r
.008 w
.83067 .74993 Mdot
.016 w
.83067 .74993 m
.83081 .75016 L
s
.008 w
.83081 .75016 Mdot
.016 w
.83081 .75016 m
.83093 .7503 L
s
1 .424 0 r
.008 w
.83093 .7503 Mdot
.016 w
.83093 .7503 m
.83104 .7504 L
s
.008 w
.83104 .7504 Mdot
.016 w
.83104 .7504 m
.83112 .75049 L
s
.008 w
.83112 .75049 Mdot
.016 w
.83112 .75049 m
.83114 .75054 L
s
1 .423 0 r
.008 w
.83114 .75054 Mdot
.016 w
.83114 .75054 m
.83109 .75057 L
s
.008 w
.83109 .75057 Mdot
.016 w
.83109 .75057 m
.83098 .7506 L
s
1 .422 0 r
.008 w
.83098 .7506 Mdot
.016 w
.83098 .7506 m
.83081 .75071 L
s
.008 w
.83081 .75071 Mdot
.016 w
.83081 .75071 m
.83054 .75093 L
s
1 .421 0 r
.008 w
.83054 .75093 Mdot
.016 w
.83054 .75093 m
.8301 .75127 L
s
.008 w
.8301 .75127 Mdot
.016 w
.8301 .75127 m
.82956 .75176 L
s
.008 w
.82956 .75176 Mdot
.016 w
.82956 .75176 m
.8289 .75238 L
s
1 .42 0 r
.008 w
.8289 .75238 Mdot
.016 w
.8289 .75238 m
.82818 .75314 L
s
.008 w
.82818 .75314 Mdot
.016 w
.82818 .75314 m
.82738 .75408 L
s
1 .419 0 r
.008 w
.82738 .75408 Mdot
.016 w
.82738 .75408 m
.82656 .7552 L
s
.008 w
.82656 .7552 Mdot
.016 w
.82656 .7552 m
.82573 .75652 L
s
1 .418 0 r
.008 w
.82573 .75652 Mdot
.016 w
.82573 .75652 m
.82488 .75795 L
s
.008 w
.82488 .75795 Mdot
.016 w
.82488 .75795 m
.82418 .75965 L
s
.008 w
.82418 .75965 Mdot
.016 w
.82418 .75965 m
.82343 .76162 L
s
1 .417 0 r
.008 w
.82343 .76162 Mdot
.016 w
.82343 .76162 m
.82266 .76383 L
s
.008 w
.82266 .76383 Mdot
.016 w
.82266 .76383 m
.82182 .76629 L
s
1 .416 0 r
.008 w
.82182 .76629 Mdot
.016 w
.82182 .76629 m
.82096 .76885 L
s
.008 w
.82096 .76885 Mdot
.016 w
.82096 .76885 m
.82006 .77148 L
s
1 .415 0 r
.008 w
.82006 .77148 Mdot
.016 w
.82006 .77148 m
.8191 .77378 L
s
.008 w
.8191 .77378 Mdot
.016 w
.8191 .77378 m
.81829 .77622 L
s
1 .414 0 r
.008 w
.81829 .77622 Mdot
.016 w
.81829 .77622 m
.81754 .77807 L
s
.008 w
.81754 .77807 Mdot
.016 w
.81754 .77807 m
.81694 .77992 L
s
.008 w
.81694 .77992 Mdot
.016 w
.81694 .77992 m
.81642 .78153 L
s
1 .413 0 r
.008 w
.81642 .78153 Mdot
.016 w
.81642 .78153 m
.81597 .78288 L
s
.008 w
.81597 .78288 Mdot
.016 w
.81597 .78288 m
.81561 .78399 L
s
1 .412 0 r
.008 w
.81561 .78399 Mdot
.016 w
.81561 .78399 m
.8153 .78485 L
s
.008 w
.8153 .78485 Mdot
.016 w
.8153 .78485 m
.81508 .78543 L
s
1 .411 0 r
.008 w
.81508 .78543 Mdot
.016 w
.81508 .78543 m
.81497 .78577 L
s
.008 w
.81497 .78577 Mdot
.016 w
.81497 .78577 m
.81498 .7859 L
s
.008 w
.81498 .7859 Mdot
.016 w
.81498 .7859 m
.81509 .78586 L
s
1 .41 0 r
.008 w
.81509 .78586 Mdot
.016 w
.81509 .78586 m
.81524 .78572 L
s
.008 w
.81524 .78572 Mdot
.016 w
.81524 .78572 m
.81541 .78558 L
s
1 .409 0 r
.008 w
.81541 .78558 Mdot
.016 w
.81541 .78558 m
.81555 .78546 L
s
.008 w
.81555 .78546 Mdot
.016 w
.81555 .78546 m
.81564 .78537 L
s
1 .408 0 r
.008 w
.81564 .78537 Mdot
.016 w
.81564 .78537 m
.81567 .7853 L
s
.008 w
.81567 .7853 Mdot
.016 w
.81567 .7853 m
.81565 .78526 L
s
1 .407 0 r
.008 w
.81565 .78526 Mdot
.016 w
.81565 .78526 m
.81559 .78526 L
s
.008 w
.81559 .78526 Mdot
.016 w
.81559 .78526 m
.81548 .78528 L
s
.008 w
.81548 .78528 Mdot
.016 w
.81548 .78528 m
.81532 .7853 L
s
1 .406 0 r
.008 w
.81532 .7853 Mdot
.016 w
.81532 .7853 m
.81517 .78531 L
s
.008 w
.81517 .78531 Mdot
.016 w
.81517 .78531 m
.81506 .78532 L
s
1 .405 0 r
.008 w
.81506 .78532 Mdot
.016 w
.81506 .78532 m
.81497 .78532 L
s
.008 w
.81497 .78532 Mdot
.016 w
.81497 .78532 m
.81489 .78532 L
s
1 .404 0 r
.008 w
.81489 .78532 Mdot
.016 w
.81489 .78532 m
.81483 .78533 L
s
.008 w
.81483 .78533 Mdot
.016 w
.81483 .78533 m
.81476 .78533 L
s
.008 w
.81476 .78533 Mdot
.016 w
.81476 .78533 m
.81469 .78534 L
s
1 .403 0 r
.008 w
.81469 .78534 Mdot
.016 w
.81469 .78534 m
.81462 .78534 L
s
.008 w
.81462 .78534 Mdot
.016 w
.81462 .78534 m
.81456 .78535 L
s
1 .402 0 r
.008 w
.81456 .78535 Mdot
.016 w
.81456 .78535 m
.81454 .78534 L
s
.008 w
.81454 .78534 Mdot
.016 w
.81454 .78534 m
.81454 .78534 L
s
1 .401 0 r
.008 w
.81454 .78534 Mdot
.016 w
.81454 .78534 m
.81452 .78532 L
s
.008 w
.81452 .78532 Mdot
.016 w
.81452 .78532 m
.81448 .7853 L
s
.008 w
.81448 .7853 Mdot
.016 w
.81448 .7853 m
.81444 .78529 L
s
1 .4 0 r
.008 w
.81444 .78529 Mdot
.016 w
.81444 .78529 m
.81435 .78528 L
s
.008 w
.81435 .78528 Mdot
.016 w
.81435 .78528 m
.81425 .78527 L
s
1 .399 0 r
.008 w
.81425 .78527 Mdot
.016 w
.81425 .78527 m
.81415 .78527 L
s
.008 w
.81415 .78527 Mdot
.016 w
.81415 .78527 m
.81405 .78527 L
s
1 .398 0 r
.008 w
.81405 .78527 Mdot
.016 w
.81405 .78527 m
.81397 .78525 L
s
.008 w
.81397 .78525 Mdot
.016 w
.81397 .78525 m
.8139 .78523 L
s
1 .397 0 r
.008 w
.8139 .78523 Mdot
.016 w
.8139 .78523 m
.81384 .78523 L
s
.008 w
.81384 .78523 Mdot
.016 w
.81384 .78523 m
.8138 .78531 L
s
.008 w
.8138 .78531 Mdot
.016 w
.8138 .78531 m
.81371 .78552 L
s
1 .396 0 r
.008 w
.81371 .78552 Mdot
.016 w
.81371 .78552 m
.81362 .78591 L
s
.008 w
.81362 .78591 Mdot
.016 w
.81362 .78591 m
.81347 .78655 L
s
1 .395 0 r
.008 w
.81347 .78655 Mdot
.016 w
.81347 .78655 m
.8133 .78735 L
s
.008 w
.8133 .78735 Mdot
.016 w
.8133 .78735 m
.81308 .78837 L
s
1 .394 0 r
.008 w
.81308 .78837 Mdot
.016 w
.81308 .78837 m
.81285 .78968 L
s
.008 w
.81285 .78968 Mdot
.016 w
.81285 .78968 m
.81262 .79074 L
s
.008 w
.81262 .79074 Mdot
.016 w
.81262 .79074 m
.81239 .79224 L
s
1 .393 0 r
.008 w
.81239 .79224 Mdot
.016 w
.81239 .79224 m
.81214 .79369 L
s
.008 w
.81214 .79369 Mdot
.016 w
.81214 .79369 m
.81188 .79492 L
s
1 .392 0 r
.008 w
.81188 .79492 Mdot
.016 w
.81188 .79492 m
.81159 .79652 L
s
.008 w
.81159 .79652 Mdot
.016 w
.81159 .79652 m
.81126 .79797 L
s
1 .391 0 r
.008 w
.81126 .79797 Mdot
.016 w
.81126 .79797 m
.81091 .7994 L
s
.008 w
.81091 .7994 Mdot
.016 w
.81091 .7994 m
.81055 .80075 L
s
.008 w
.81055 .80075 Mdot
.016 w
.81055 .80075 m
.81021 .80192 L
s
1 .39 0 r
.008 w
.81021 .80192 Mdot
.016 w
.81021 .80192 m
.80989 .80289 L
s
.008 w
.80989 .80289 Mdot
.016 w
.80989 .80289 m
.8096 .80362 L
s
1 .389 0 r
.008 w
.8096 .80362 Mdot
.016 w
.8096 .80362 m
.80937 .80418 L
s
.008 w
.80937 .80418 Mdot
.016 w
.80937 .80418 m
.80916 .80458 L
s
1 .388 0 r
.008 w
.80916 .80458 Mdot
.016 w
.80916 .80458 m
.80899 .80487 L
s
.008 w
.80899 .80487 Mdot
.016 w
.80899 .80487 m
.80887 .80508 L
s
1 .387 0 r
.008 w
.80887 .80508 Mdot
.016 w
.80887 .80508 m
.80878 .80524 L
s
.008 w
.80878 .80524 Mdot
.016 w
.80878 .80524 m
.80874 .80535 L
s
.008 w
.80874 .80535 Mdot
.016 w
.80874 .80535 m
.80875 .80541 L
s
1 .386 0 r
.008 w
.80875 .80541 Mdot
.016 w
.80875 .80541 m
.80881 .80541 L
s
.008 w
.80881 .80541 Mdot
.016 w
.80881 .80541 m
.80889 .80537 L
s
1 .385 0 r
.008 w
.80889 .80537 Mdot
.016 w
.80889 .80537 m
.80898 .80529 L
s
.008 w
.80898 .80529 Mdot
.016 w
.80898 .80529 m
.80905 .80521 L
s
1 .384 0 r
.008 w
.80905 .80521 Mdot
.016 w
.80905 .80521 m
.80908 .80515 L
s
.008 w
.80908 .80515 Mdot
.016 w
.80908 .80515 m
.80906 .80513 L
s
.008 w
.80906 .80513 Mdot
.016 w
.80906 .80513 m
.80898 .80513 L
s
1 .383 0 r
.008 w
.80898 .80513 Mdot
.016 w
.80898 .80513 m
.80888 .80515 L
s
.008 w
.80888 .80515 Mdot
.016 w
.80888 .80515 m
.80874 .80516 L
s
1 .382 0 r
.008 w
.80874 .80516 Mdot
.016 w
.80874 .80516 m
.80857 .80517 L
s
.008 w
.80857 .80517 Mdot
.016 w
.80857 .80517 m
.80837 .80519 L
s
1 .381 0 r
.008 w
.80837 .80519 Mdot
.016 w
.80837 .80519 m
.80814 .80521 L
s
.008 w
.80814 .80521 Mdot
.016 w
.80814 .80521 m
.80792 .80523 L
s
1 .38 0 r
.008 w
.80792 .80523 Mdot
.016 w
.80792 .80523 m
.8077 .80526 L
s
.008 w
.8077 .80526 Mdot
.016 w
.8077 .80526 m
.80749 .80528 L
s
.008 w
.80749 .80528 Mdot
.016 w
.80749 .80528 m
.80735 .80529 L
s
1 .379 0 r
.008 w
.80735 .80529 Mdot
.016 w
.80735 .80529 m
.80724 .8053 L
s
.008 w
.80724 .8053 Mdot
.016 w
.80724 .8053 m
.80721 .8053 L
s
1 .378 0 r
.008 w
.80721 .8053 Mdot
.016 w
.80721 .8053 m
.80724 .8053 L
s
.008 w
.80724 .8053 Mdot
.016 w
.80724 .8053 m
.80736 .80529 L
s
1 .377 0 r
.008 w
.80736 .80529 Mdot
.016 w
.80736 .80529 m
.80752 .80527 L
s
.008 w
.80752 .80527 Mdot
.016 w
.80752 .80527 m
.80773 .80525 L
s
.008 w
.80773 .80525 Mdot
.016 w
.80773 .80525 m
.80796 .80523 L
s
1 .376 0 r
.008 w
.80796 .80523 Mdot
.016 w
.80796 .80523 m
.80818 .80521 L
s
.008 w
.80818 .80521 Mdot
.016 w
.80818 .80521 m
.80838 .80519 L
s
1 .375 0 r
.008 w
.80838 .80519 Mdot
.016 w
.80838 .80519 m
.80855 .80518 L
s
.008 w
.80855 .80518 Mdot
.016 w
.80855 .80518 m
.80871 .80516 L
s
1 .374 0 r
.008 w
.80871 .80516 Mdot
.016 w
.80871 .80516 m
.80886 .80515 L
s
.008 w
.80886 .80515 Mdot
.016 w
.80886 .80515 m
.80898 .80513 L
s
.008 w
.80898 .80513 Mdot
.016 w
.80898 .80513 m
.80907 .80512 L
s
1 .373 0 r
.008 w
.80907 .80512 Mdot
.016 w
.80907 .80512 m
.80913 .80511 L
s
.008 w
.80913 .80511 Mdot
.016 w
.80913 .80511 m
.80917 .80511 L
s
1 .372 0 r
.008 w
.80917 .80511 Mdot
.016 w
.80917 .80511 m
.80919 .80508 L
s
.008 w
.80919 .80508 Mdot
.016 w
.80919 .80508 m
.80918 .80502 L
s
1 .371 0 r
.008 w
.80918 .80502 Mdot
.016 w
.80918 .80502 m
.80915 .80494 L
s
.008 w
.80915 .80494 Mdot
.016 w
.80915 .80494 m
.80909 .80488 L
s
1 .37 0 r
.008 w
.80909 .80488 Mdot
.016 w
.80909 .80488 m
.80898 .80485 L
s
.008 w
.80898 .80485 Mdot
.016 w
.80898 .80485 m
.80878 .80489 L
s
.008 w
.80878 .80489 Mdot
.016 w
.80878 .80489 m
.80846 .805 L
s
1 .369 0 r
.008 w
.80846 .805 Mdot
.016 w
.80846 .805 m
.80798 .80519 L
s
.008 w
.80798 .80519 Mdot
.016 w
.80798 .80519 m
.80728 .80548 L
s
1 .368 0 r
.008 w
.80728 .80548 Mdot
.016 w
.80728 .80548 m
.80647 .80591 L
s
.008 w
.80647 .80591 Mdot
.016 w
.80647 .80591 m
.80541 .80648 L
s
1 .367 0 r
.008 w
.80541 .80648 Mdot
.016 w
.80541 .80648 m
.80412 .8072 L
s
.008 w
.80412 .8072 Mdot
.016 w
.80412 .8072 m
.80272 .80805 L
s
.008 w
.80272 .80805 Mdot
.016 w
.80272 .80805 m
.80112 .80903 L
s
1 .366 0 r
.008 w
.80112 .80903 Mdot
.016 w
.80112 .80903 m
.79932 .81007 L
s
.008 w
.79932 .81007 Mdot
.016 w
.79932 .81007 m
.79746 .81123 L
s
1 .365 0 r
.008 w
.79746 .81123 Mdot
.016 w
.79746 .81123 m
.79551 .81237 L
s
.008 w
.79551 .81237 Mdot
.016 w
.79551 .81237 m
.79362 .81355 L
s
1 .364 0 r
.008 w
.79362 .81355 Mdot
.016 w
.79362 .81355 m
.79172 .8147 L
s
.008 w
.79172 .8147 Mdot
.016 w
.79172 .8147 m
.78992 .81574 L
s
.008 w
.78992 .81574 Mdot
.016 w
.78992 .81574 m
.78836 .81665 L
s
1 .363 0 r
.008 w
.78836 .81665 Mdot
.016 w
.78836 .81665 m
.78693 .81743 L
s
.008 w
.78693 .81743 Mdot
.016 w
.78693 .81743 m
.7857 .81808 L
s
1 .362 0 r
.008 w
.7857 .81808 Mdot
.016 w
.7857 .81808 m
.78471 .81859 L
s
.008 w
.78471 .81859 Mdot
.016 w
.78471 .81859 m
.784 .81896 L
s
1 .361 0 r
.008 w
.784 .81896 Mdot
.016 w
.784 .81896 m
.78345 .8192 L
s
.008 w
.78345 .8192 Mdot
.016 w
.78345 .8192 m
.78309 .81929 L
s
1 .36 0 r
.008 w
.78309 .81929 Mdot
.016 w
.78309 .81929 m
.7829 .81925 L
s
.008 w
.7829 .81925 Mdot
.016 w
.7829 .81925 m
.78282 .81912 L
s
.008 w
.78282 .81912 Mdot
.016 w
.78282 .81912 m
.78279 .81898 L
s
1 .359 0 r
.008 w
.78279 .81898 Mdot
.016 w
.78279 .81898 m
.78274 .81892 L
s
.008 w
.78274 .81892 Mdot
.016 w
.78274 .81892 m
.78267 .81894 L
s
1 .358 0 r
.008 w
.78267 .81894 Mdot
.016 w
.78267 .81894 m
.78252 .8191 L
s
.008 w
.78252 .8191 Mdot
.016 w
.78252 .8191 m
.7823 .81936 L
s
1 .357 0 r
.008 w
.7823 .81936 Mdot
.016 w
.7823 .81936 m
.78199 .81973 L
s
.008 w
.78199 .81973 Mdot
.016 w
.78199 .81973 m
.78163 .82018 L
s
.008 w
.78163 .82018 Mdot
.016 w
.78163 .82018 m
.78115 .82075 L
s
1 .356 0 r
.008 w
.78115 .82075 Mdot
.016 w
.78115 .82075 m
.7806 .8214 L
s
.008 w
.7806 .8214 Mdot
.016 w
.7806 .8214 m
.77998 .8221 L
s
1 .355 0 r
.008 w
.77998 .8221 Mdot
.016 w
.77998 .8221 m
.77932 .82288 L
s
.008 w
.77932 .82288 Mdot
.016 w
.77932 .82288 m
.77867 .82371 L
s
1 .354 0 r
.008 w
.77867 .82371 Mdot
.016 w
.77867 .82371 m
.77799 .82459 L
s
.008 w
.77799 .82459 Mdot
.016 w
.77799 .82459 m
.77723 .82554 L
s
.008 w
.77723 .82554 Mdot
.016 w
.77723 .82554 m
.77643 .82655 L
s
1 .353 0 r
.008 w
.77643 .82655 Mdot
.016 w
.77643 .82655 m
.77557 .82759 L
s
.008 w
.77557 .82759 Mdot
.016 w
.77557 .82759 m
.77459 .82865 L
s
1 .352 0 r
.008 w
.77459 .82865 Mdot
.016 w
.77459 .82865 m
.77362 .8298 L
s
.008 w
.77362 .8298 Mdot
.016 w
.77362 .8298 m
.77249 .83104 L
s
1 .351 0 r
.008 w
.77249 .83104 Mdot
.016 w
.77249 .83104 m
.77119 .83241 L
s
.008 w
.77119 .83241 Mdot
.016 w
.77119 .83241 m
.7697 .83391 L
s
1 .35 0 r
.008 w
.7697 .83391 Mdot
.016 w
.7697 .83391 m
.76818 .83546 L
s
.008 w
.76818 .83546 Mdot
.016 w
.76818 .83546 m
.76647 .83712 L
s
.008 w
.76647 .83712 Mdot
.016 w
.76647 .83712 m
.76459 .83881 L
s
1 .349 0 r
.008 w
.76459 .83881 Mdot
.016 w
.76459 .83881 m
.76277 .84043 L
s
.008 w
.76277 .84043 Mdot
.016 w
.76277 .84043 m
.76105 .8419 L
s
1 .348 0 r
.008 w
.76105 .8419 Mdot
.016 w
.76105 .8419 m
.75941 .84323 L
s
.008 w
.75941 .84323 Mdot
.016 w
.75941 .84323 m
.75786 .84441 L
s
1 .347 0 r
.008 w
.75786 .84441 Mdot
.016 w
.75786 .84441 m
.75649 .84542 L
s
.008 w
.75649 .84542 Mdot
.016 w
.75649 .84542 m
.75514 .84634 L
s
.008 w
.75514 .84634 Mdot
.016 w
.75514 .84634 m
.75393 .84717 L
s
1 .346 0 r
.008 w
.75393 .84717 Mdot
.016 w
.75393 .84717 m
.75276 .84791 L
s
.008 w
.75276 .84791 Mdot
.016 w
.75276 .84791 m
.75167 .84857 L
s
1 .345 0 r
.008 w
.75167 .84857 Mdot
.016 w
.75167 .84857 m
.75064 .84918 L
s
.008 w
.75064 .84918 Mdot
.016 w
.75064 .84918 m
.74961 .84975 L
s
1 .344 0 r
.008 w
.74961 .84975 Mdot
.016 w
.74961 .84975 m
.74863 .85036 L
s
.008 w
.74863 .85036 Mdot
.016 w
.74863 .85036 m
.74758 .85102 L
s
1 .343 0 r
.008 w
.74758 .85102 Mdot
.016 w
.74758 .85102 m
.74646 .85173 L
s
.008 w
.74646 .85173 Mdot
.016 w
.74646 .85173 m
.74527 .85253 L
s
.008 w
.74527 .85253 Mdot
.016 w
.74527 .85253 m
.74408 .85335 L
s
1 .342 0 r
.008 w
.74408 .85335 Mdot
.016 w
.74408 .85335 m
.7428 .85424 L
s
.008 w
.7428 .85424 Mdot
.016 w
.7428 .85424 m
.74143 .8552 L
s
1 .341 0 r
.008 w
.74143 .8552 Mdot
.016 w
.74143 .8552 m
.74004 .85615 L
s
.008 w
.74004 .85615 Mdot
.016 w
.74004 .85615 m
.73868 .85709 L
s
1 .34 0 r
.008 w
.73868 .85709 Mdot
.016 w
.73868 .85709 m
.73734 .85798 L
s
.008 w
.73734 .85798 Mdot
.016 w
.73734 .85798 m
.73614 .85873 L
s
.008 w
.73614 .85873 Mdot
.016 w
.73614 .85873 m
.73504 .85936 L
s
1 .339 0 r
.008 w
.73504 .85936 Mdot
.016 w
.73504 .85936 m
.73402 .8599 L
s
.008 w
.73402 .8599 Mdot
.016 w
.73402 .8599 m
.73304 .86044 L
s
1 .338 0 r
.008 w
.73304 .86044 Mdot
.016 w
.73304 .86044 m
.73211 .86099 L
s
.008 w
.73211 .86099 Mdot
.016 w
.73211 .86099 m
.73119 .86156 L
s
1 .337 0 r
.008 w
.73119 .86156 Mdot
.016 w
.73119 .86156 m
.73031 .86216 L
s
.008 w
.73031 .86216 Mdot
.016 w
.73031 .86216 m
.72936 .86283 L
s
.008 w
.72936 .86283 Mdot
.016 w
.72936 .86283 m
.72831 .86362 L
s
1 .336 0 r
.008 w
.72831 .86362 Mdot
.016 w
.72831 .86362 m
.72711 .86456 L
s
.008 w
.72711 .86456 Mdot
.016 w
.72711 .86456 m
.72573 .86568 L
s
1 .335 0 r
.008 w
.72573 .86568 Mdot
.016 w
.72573 .86568 m
.72414 .86701 L
s
.008 w
.72414 .86701 Mdot
.016 w
.72414 .86701 m
.72231 .86856 L
s
1 .334 0 r
.008 w
.72231 .86856 Mdot
.016 w
.72231 .86856 m
.72057 .87012 L
s
.008 w
.72057 .87012 Mdot
.016 w
.72057 .87012 m
.71854 .87177 L
s
1 .333 0 r
.008 w
.71854 .87177 Mdot
.016 w
.71854 .87177 m
.71632 .87362 L
s
.008 w
.71632 .87362 Mdot
.016 w
.71632 .87362 m
.71417 .87563 L
s
.008 w
.71417 .87563 Mdot
.016 w
.71417 .87563 m
.71165 .8777 L
s
1 .332 0 r
.008 w
.71165 .8777 Mdot
.016 w
.71165 .8777 m
.70943 .87953 L
s
.008 w
.70943 .87953 Mdot
.016 w
.70943 .87953 m
.70716 .88136 L
s
1 .331 0 r
.008 w
.70716 .88136 Mdot
.016 w
.70716 .88136 m
.7049 .88311 L
s
.008 w
.7049 .88311 Mdot
.016 w
.7049 .88311 m
.70285 .8846 L
s
1 .33 0 r
.008 w
.70285 .8846 Mdot
.016 w
.70285 .8846 m
.70094 .88597 L
s
.008 w
.70094 .88597 Mdot
.016 w
.70094 .88597 m
.69931 .88716 L
s
.008 w
.69931 .88716 Mdot
.016 w
.69931 .88716 m
.69786 .88818 L
s
1 .329 0 r
.008 w
.69786 .88818 Mdot
.016 w
.69786 .88818 m
.69654 .88909 L
s
.008 w
.69654 .88909 Mdot
.016 w
.69654 .88909 m
.69531 .88991 L
s
1 .328 0 r
.008 w
.69531 .88991 Mdot
.016 w
.69531 .88991 m
.69423 .89068 L
s
.008 w
.69423 .89068 Mdot
.016 w
.69423 .89068 m
.69313 .89136 L
s
1 .327 0 r
.008 w
.69313 .89136 Mdot
.016 w
.69313 .89136 m
.69203 .89203 L
s
.008 w
.69203 .89203 Mdot
.016 w
.69203 .89203 m
.69092 .89263 L
s
.008 w
.69092 .89263 Mdot
.016 w
.69092 .89263 m
.68989 .89326 L
s
1 .326 0 r
.008 w
.68989 .89326 Mdot
.016 w
.68989 .89326 m
.68888 .89385 L
s
.008 w
.68888 .89385 Mdot
.016 w
.68888 .89385 m
.68795 .89439 L
s
1 .325 0 r
.008 w
.68795 .89439 Mdot
.016 w
.68795 .89439 m
.68713 .89486 L
s
.008 w
.68713 .89486 Mdot
.016 w
.68713 .89486 m
.68645 .89522 L
s
1 .324 0 r
.008 w
.68645 .89522 Mdot
.016 w
.68645 .89522 m
.68591 .89543 L
s
.008 w
.68591 .89543 Mdot
.016 w
.68591 .89543 m
.68548 .89555 L
s
1 .323 0 r
.008 w
.68548 .89555 Mdot
.016 w
.68548 .89555 m
.68513 .89561 L
s
.008 w
.68513 .89561 Mdot
.016 w
.68513 .89561 m
.6849 .89557 L
s
.008 w
.6849 .89557 Mdot
.016 w
.6849 .89557 m
.68476 .89545 L
s
1 .322 0 r
.008 w
.68476 .89545 Mdot
.016 w
.68476 .89545 m
.68468 .89529 L
s
.008 w
.68468 .89529 Mdot
.016 w
.68468 .89529 m
.68465 .89507 L
s
1 .321 0 r
.008 w
.68465 .89507 Mdot
.016 w
.68465 .89507 m
.68465 .89486 L
s
.008 w
.68465 .89486 Mdot
.016 w
.68465 .89486 m
.68467 .8947 L
s
1 .32 0 r
.008 w
.68467 .8947 Mdot
.016 w
.68467 .8947 m
.68468 .89463 L
s
.008 w
.68468 .89463 Mdot
.016 w
.68468 .89463 m
.68463 .89468 L
s
.008 w
.68463 .89468 Mdot
.016 w
.68463 .89468 m
.68447 .89486 L
s
1 .319 0 r
.008 w
.68447 .89486 Mdot
.016 w
.68447 .89486 m
.6842 .89519 L
s
.008 w
.6842 .89519 Mdot
.016 w
.6842 .89519 m
.68381 .89558 L
s
1 .318 0 r
.008 w
.68381 .89558 Mdot
.016 w
.68381 .89558 m
.68332 .89605 L
s
.008 w
.68332 .89605 Mdot
.016 w
.68332 .89605 m
.68273 .89657 L
s
1 .317 0 r
.008 w
.68273 .89657 Mdot
.016 w
.68273 .89657 m
.68198 .89714 L
s
.008 w
.68198 .89714 Mdot
.016 w
.68198 .89714 m
.68135 .89763 L
s
1 .316 0 r
.008 w
.68135 .89763 Mdot
.016 w
.68135 .89763 m
.68065 .89814 L
s
.008 w
.68065 .89814 Mdot
.016 w
.68065 .89814 m
.68003 .89859 L
s
.008 w
.68003 .89859 Mdot
.016 w
.68003 .89859 m
.67954 .89896 L
s
1 .315 0 r
.008 w
.67954 .89896 Mdot
.016 w
.67954 .89896 m
.67913 .89925 L
s
.008 w
.67913 .89925 Mdot
.016 w
.67913 .89925 m
.67881 .89946 L
s
1 .314 0 r
.008 w
.67881 .89946 Mdot
.016 w
.67881 .89946 m
.67854 .89959 L
s
.008 w
.67854 .89959 Mdot
.016 w
.67854 .89959 m
.67833 .89965 L
s
1 .313 0 r
.008 w
.67833 .89965 Mdot
.016 w
.67833 .89965 m
.6781 .89966 L
s
.008 w
.6781 .89966 Mdot
.016 w
.6781 .89966 m
.67787 .89963 L
s
.008 w
.67787 .89963 Mdot
.016 w
.67787 .89963 m
.67763 .89957 L
s
1 .312 0 r
.008 w
.67763 .89957 Mdot
.016 w
.67763 .89957 m
.67741 .89953 L
s
.008 w
.67741 .89953 Mdot
.016 w
.67741 .89953 m
.67716 .89953 L
s
1 .311 0 r
.008 w
.67716 .89953 Mdot
.016 w
.67716 .89953 m
.67688 .89955 L
s
.008 w
.67688 .89955 Mdot
.016 w
.67688 .89955 m
.67656 .89958 L
s
1 .31 0 r
.008 w
.67656 .89958 Mdot
.016 w
.67656 .89958 m
.67623 .89961 L
s
.008 w
.67623 .89961 Mdot
.016 w
.67623 .89961 m
.67588 .89964 L
s
.008 w
.67588 .89964 Mdot
.016 w
.67588 .89964 m
.67555 .89968 L
s
1 .309 0 r
.008 w
.67555 .89968 Mdot
.016 w
.67555 .89968 m
.67527 .8997 L
s
.008 w
.67527 .8997 Mdot
.016 w
.67527 .8997 m
.6751 .89972 L
s
1 .308 0 r
.008 w
.6751 .89972 Mdot
.016 w
.6751 .89972 m
.67507 .89972 L
s
.008 w
.67507 .89972 Mdot
.016 w
.67507 .89972 m
.67514 .89972 L
s
1 .307 0 r
.008 w
.67514 .89972 Mdot
.016 w
.67514 .89972 m
.67528 .89971 L
s
.008 w
.67528 .89971 Mdot
.016 w
.67528 .89971 m
.67548 .8997 L
s
1 .306 0 r
.008 w
.67548 .8997 Mdot
.016 w
.67548 .8997 m
.67573 .89968 L
s
.008 w
.67573 .89968 Mdot
.016 w
.67573 .89968 m
.676 .89966 L
s
.008 w
.676 .89966 Mdot
.016 w
.676 .89966 m
.67629 .89964 L
s
1 .305 0 r
.008 w
.67629 .89964 Mdot
.016 w
.67629 .89964 m
.67657 .89961 L
s
.008 w
.67657 .89961 Mdot
.016 w
.67657 .89961 m
.67687 .89959 L
s
1 .304 0 r
.008 w
.67687 .89959 Mdot
.016 w
.67687 .89959 m
.67715 .89956 L
s
.008 w
.67715 .89956 Mdot
.016 w
.67715 .89956 m
.67744 .89954 L
s
1 .303 0 r
.008 w
.67744 .89954 Mdot
.016 w
.67744 .89954 m
.67765 .89952 L
s
.008 w
.67765 .89952 Mdot
.016 w
.67765 .89952 m
.67778 .8995 L
s
.008 w
.67778 .8995 Mdot
.016 w
.67778 .8995 m
.67781 .8995 L
s
1 .302 0 r
.008 w
.67781 .8995 Mdot
.016 w
.67781 .8995 m
.67776 .8995 L
s
.008 w
.67776 .8995 Mdot
.016 w
.67776 .8995 m
.67766 .8995 L
s
1 .301 0 r
.008 w
.67766 .8995 Mdot
.016 w
.67766 .8995 m
.67754 .89951 L
s
.008 w
.67754 .89951 Mdot
.016 w
.67754 .89951 m
.67744 .89951 L
s
1 .3 0 r
.008 w
.67744 .89951 Mdot
.016 w
.67744 .89951 m
.67738 .8995 L
s
.008 w
.67738 .8995 Mdot
.016 w
.67738 .8995 m
.67736 .89949 L
s
.008 w
.67736 .89949 Mdot
.016 w
.67736 .89949 m
.67736 .89949 L
s
1 .299 0 r
.008 w
.67736 .89949 Mdot
.016 w
.67736 .89949 m
.67734 .89949 L
s
.008 w
.67734 .89949 Mdot
.016 w
.67734 .89949 m
.67731 .89949 L
s
1 .298 0 r
.008 w
.67731 .89949 Mdot
.016 w
.67731 .89949 m
.67732 .89949 L
s
.008 w
.67732 .89949 Mdot
.016 w
.67732 .89949 m
.67739 .89949 L
s
1 .297 0 r
.008 w
.67739 .89949 Mdot
.016 w
.67739 .89949 m
.67755 .89947 L
s
.008 w
.67755 .89947 Mdot
.016 w
.67755 .89947 m
.67775 .89945 L
s
1 .296 0 r
.008 w
.67775 .89945 Mdot
.016 w
.67775 .89945 m
.67796 .89942 L
s
.008 w
.67796 .89942 Mdot
.016 w
.67796 .89942 m
.67817 .8994 L
s
.008 w
.67817 .8994 Mdot
.016 w
.67817 .8994 m
.6783 .89938 L
s
1 .295 0 r
.008 w
.6783 .89938 Mdot
.016 w
.6783 .89938 m
.67834 .89938 L
s
.008 w
.67834 .89938 Mdot
.016 w
.67834 .89938 m
.67825 .89938 L
s
1 .294 0 r
.008 w
.67825 .89938 Mdot
.016 w
.67825 .89938 m
.67804 .8994 L
s
.008 w
.67804 .8994 Mdot
.016 w
.67804 .8994 m
.67774 .89944 L
s
1 .293 0 r
.008 w
.67774 .89944 Mdot
.016 w
.67774 .89944 m
.67734 .89948 L
s
.008 w
.67734 .89948 Mdot
.016 w
.67734 .89948 m
.67695 .89953 L
s
.008 w
.67695 .89953 Mdot
.016 w
.67695 .89953 m
.67647 .89958 L
s
1 .292 0 r
.008 w
.67647 .89958 Mdot
.016 w
.67647 .89958 m
.67598 .89964 L
s
.008 w
.67598 .89964 Mdot
.016 w
.67598 .89964 m
.67552 .89969 L
s
1 .291 0 r
.008 w
.67552 .89969 Mdot
.016 w
.67552 .89969 m
.67512 .89974 L
s
.008 w
.67512 .89974 Mdot
.016 w
.67512 .89974 m
.67481 .89977 L
s
1 .29 0 r
.008 w
.67481 .89977 Mdot
.016 w
.67481 .89977 m
.67458 .8998 L
s
.008 w
.67458 .8998 Mdot
.016 w
.67458 .8998 m
.67445 .89982 L
s
.008 w
.67445 .89982 Mdot
.016 w
.67445 .89982 m
.67441 .89982 L
s
1 .289 0 r
.008 w
.67441 .89982 Mdot
.016 w
.67441 .89982 m
.67442 .89982 L
s
.008 w
.67442 .89982 Mdot
.016 w
.67442 .89982 m
.67448 .89981 L
s
1 .288 0 r
.008 w
.67448 .89981 Mdot
.016 w
.67448 .89981 m
.67456 .8998 L
s
.008 w
.67456 .8998 Mdot
.016 w
.67456 .8998 m
.67463 .8998 L
s
1 .287 0 r
.008 w
.67463 .8998 Mdot
.016 w
.67463 .8998 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .286 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .285 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .284 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .283 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .282 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .281 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .28 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .279 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .278 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .277 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .276 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .275 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .274 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .273 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .272 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
1 .271 0 r
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67466 .89979 L
s
.008 w
.67466 .89979 Mdot
.016 w
.67466 .89979 m
.67467 .89979 L
s
1 .27 0 r
.008 w
.67467 .89979 Mdot
.016 w
.67467 .89979 m
.67469 .89979 L
s
.008 w
.67469 .89979 Mdot
.016 w
.67469 .89979 m
.67474 .89978 L
s
1 .269 0 r
.008 w
.67474 .89978 Mdot
.016 w
.67474 .89978 m
.67481 .89977 L
s
.008 w
.67481 .89977 Mdot
.016 w
.67481 .89977 m
.67488 .89977 L
s
.008 w
.67488 .89977 Mdot
.016 w
.67488 .89977 m
.67491 .89976 L
s
1 .268 0 r
.008 w
.67491 .89976 Mdot
.016 w
.67491 .89976 m
.67489 .89977 L
s
.008 w
.67489 .89977 Mdot
.016 w
.67489 .89977 m
.67478 .89978 L
s
1 .267 0 r
.008 w
.67478 .89978 Mdot
.016 w
.67478 .89978 m
.67458 .8998 L
s
.008 w
.67458 .8998 Mdot
.016 w
.67458 .8998 m
.67429 .89983 L
s
1 .266 0 r
.008 w
.67429 .89983 Mdot
.016 w
.67429 .89983 m
.67393 .89987 L
s
.008 w
.67393 .89987 Mdot
.016 w
.67393 .89987 m
.67353 .89992 L
s
.008 w
.67353 .89992 Mdot
.016 w
.67353 .89992 m
.67312 .89996 L
s
1 .265 0 r
.008 w
.67312 .89996 Mdot
.016 w
.67312 .89996 m
.67272 .90001 L
s
.008 w
.67272 .90001 Mdot
.016 w
.67272 .90001 m
.67235 .90005 L
s
1 .264 0 r
.008 w
.67235 .90005 Mdot
.016 w
.67235 .90005 m
.672 .90009 L
s
.008 w
.672 .90009 Mdot
.016 w
.672 .90009 m
.6717 .90013 L
s
1 .263 0 r
.008 w
.6717 .90013 Mdot
.016 w
.6717 .90013 m
.67148 .90017 L
s
.008 w
.67148 .90017 Mdot
.016 w
.67148 .90017 m
.67138 .90022 L
s
.008 w
.67138 .90022 Mdot
.016 w
.67138 .90022 m
.6714 .90028 L
s
1 .262 0 r
.008 w
.6714 .90028 Mdot
.016 w
.6714 .90028 m
.67153 .9003 L
s
.008 w
.67153 .9003 Mdot
.016 w
.67153 .9003 m
.67173 .90025 L
s
1 .261 0 r
.008 w
.67173 .90025 Mdot
.016 w
.67173 .90025 m
.67199 .90015 L
s
.008 w
.67199 .90015 Mdot
.016 w
.67199 .90015 m
.67226 .89999 L
s
1 .26 0 r
.008 w
.67226 .89999 Mdot
.016 w
.67226 .89999 m
.6725 .89981 L
s
.008 w
.6725 .89981 Mdot
.016 w
.6725 .89981 m
.67268 .89961 L
s
1 .259 0 r
.008 w
.67268 .89961 Mdot
.016 w
.67268 .89961 m
.67278 .89942 L
s
.008 w
.67278 .89942 Mdot
.016 w
.67278 .89942 m
.6728 .89926 L
s
.008 w
.6728 .89926 Mdot
.016 w
.6728 .89926 m
.67276 .89915 L
s
1 .258 0 r
.008 w
.67276 .89915 Mdot
.016 w
.67276 .89915 m
.6727 .89911 L
s
.008 w
.6727 .89911 Mdot
.016 w
.6727 .89911 m
.67264 .89913 L
s
1 .257 0 r
.008 w
.67264 .89913 Mdot
.016 w
.67264 .89913 m
.67258 .8992 L
s
.008 w
.67258 .8992 Mdot
.016 w
.67258 .8992 m
.67251 .89928 L
s
1 .256 0 r
.008 w
.67251 .89928 Mdot
.016 w
.67251 .89928 m
.67244 .89934 L
s
.008 w
.67244 .89934 Mdot
.016 w
.67244 .89934 m
.67236 .8994 L
s
.008 w
.67236 .8994 Mdot
.016 w
.67236 .8994 m
.67226 .89942 L
s
1 .255 0 r
.008 w
.67226 .89942 Mdot
.016 w
.67226 .89942 m
.67214 .89938 L
s
.008 w
.67214 .89938 Mdot
.016 w
.67214 .89938 m
.672 .89926 L
s
1 .254 0 r
.008 w
.672 .89926 Mdot
.016 w
.672 .89926 m
.67186 .89905 L
s
.008 w
.67186 .89905 Mdot
.016 w
.67186 .89905 m
.67174 .8988 L
s
1 .253 0 r
.008 w
.67174 .8988 Mdot
.016 w
.67174 .8988 m
.67164 .89853 L
s
.008 w
.67164 .89853 Mdot
.016 w
.67164 .89853 m
.67158 .89827 L
s
.008 w
.67158 .89827 Mdot
.016 w
.67158 .89827 m
.67153 .89803 L
s
1 .252 0 r
.008 w
.67153 .89803 Mdot
.016 w
.67153 .89803 m
.67146 .8978 L
s
.008 w
.67146 .8978 Mdot
.016 w
.67146 .8978 m
.67137 .89764 L
s
1 .251 0 r
.008 w
.67137 .89764 Mdot
.016 w
.67137 .89764 m
.67129 .89758 L
s
.008 w
.67129 .89758 Mdot
.016 w
.67129 .89758 m
.67124 .89764 L
s
1 .25 0 r
.008 w
.67124 .89764 Mdot
.016 w
.67124 .89764 m
.67122 .89779 L
s
.008 w
.67122 .89779 Mdot
.016 w
.67122 .89779 m
.67124 .89802 L
s
1 .249 0 r
.008 w
.67124 .89802 Mdot
.016 w
.67124 .89802 m
.67129 .89835 L
s
.008 w
.67129 .89835 Mdot
.016 w
.67129 .89835 m
.67133 .89876 L
s
.008 w
.67133 .89876 Mdot
.016 w
.67133 .89876 m
.67136 .89921 L
s
1 .248 0 r
.008 w
.67136 .89921 Mdot
.016 w
.67136 .89921 m
.67134 .89967 L
s
.008 w
.67134 .89967 Mdot
.016 w
.67134 .89967 m
.67128 .90007 L
s
1 .247 0 r
.008 w
.67128 .90007 Mdot
.016 w
.67128 .90007 m
.67117 .90037 L
s
.008 w
.67117 .90037 Mdot
.016 w
.67117 .90037 m
.67104 .90055 L
s
1 .246 0 r
.008 w
.67104 .90055 Mdot
.016 w
.67104 .90055 m
.67091 .90062 L
s
.008 w
.67091 .90062 Mdot
.016 w
.67091 .90062 m
.67088 .90061 L
s
.008 w
.67088 .90061 Mdot
.016 w
.67088 .90061 m
.67097 .90055 L
s
1 .245 0 r
.008 w
.67097 .90055 Mdot
.016 w
.67097 .90055 m
.67119 .90045 L
s
.008 w
.67119 .90045 Mdot
.016 w
.67119 .90045 m
.67144 .90037 L
s
1 .244 0 r
.008 w
.67144 .90037 Mdot
.016 w
.67144 .90037 m
.67179 .90029 L
s
.008 w
.67179 .90029 Mdot
.016 w
.67179 .90029 m
.67217 .90022 L
s
1 .243 0 r
.008 w
.67217 .90022 Mdot
.016 w
.67217 .90022 m
.67253 .90016 L
s
.008 w
.67253 .90016 Mdot
.016 w
.67253 .90016 m
.67284 .90009 L
s
1 .242 0 r
.008 w
.67284 .90009 Mdot
.016 w
.67284 .90009 m
.67306 .90003 L
s
.008 w
.67306 .90003 Mdot
.016 w
.67306 .90003 m
.67319 .89999 L
s
.008 w
.67319 .89999 Mdot
.016 w
.67319 .89999 m
.67326 .89996 L
s
1 .241 0 r
.008 w
.67326 .89996 Mdot
.016 w
.67326 .89996 m
.67332 .89993 L
s
.008 w
.67332 .89993 Mdot
.016 w
.67332 .89993 m
.67338 .89991 L
s
1 .24 0 r
.008 w
.67338 .89991 Mdot
.016 w
.67338 .89991 m
.67344 .8999 L
s
.008 w
.67344 .8999 Mdot
.016 w
.67344 .8999 m
.67341 .89992 L
s
1 .239 0 r
.008 w
.67341 .89992 Mdot
.016 w
.67341 .89992 m
.67332 .89995 L
s
.008 w
.67332 .89995 Mdot
.016 w
.67332 .89995 m
.67321 .89997 L
s
.008 w
.67321 .89997 Mdot
.016 w
.67321 .89997 m
.67318 .89998 L
s
1 .238 0 r
.008 w
.67318 .89998 Mdot
.016 w
.67318 .89998 m
.67319 .89998 L
s
.008 w
.67319 .89998 Mdot
.016 w
.67319 .89998 m
.6733 .89996 L
s
1 .237 0 r
.008 w
.6733 .89996 Mdot
.016 w
.6733 .89996 m
.67347 .89994 L
s
.008 w
.67347 .89994 Mdot
.016 w
.67347 .89994 m
.67371 .89991 L
s
1 .236 0 r
.008 w
.67371 .89991 Mdot
.016 w
.67371 .89991 m
.67397 .89988 L
s
.008 w
.67397 .89988 Mdot
.016 w
.67397 .89988 m
.67425 .89984 L
s
.008 w
.67425 .89984 Mdot
.016 w
.67425 .89984 m
.67454 .89981 L
s
1 .235 0 r
.008 w
.67454 .89981 Mdot
.016 w
.67454 .89981 m
.6748 .89977 L
s
.008 w
.6748 .89977 Mdot
.016 w
.6748 .89977 m
.675 .89974 L
s
1 .234 0 r
.008 w
.675 .89974 Mdot
.016 w
.675 .89974 m
.67509 .89973 L
s
.008 w
.67509 .89973 Mdot
.016 w
.67509 .89973 m
.67505 .89974 L
s
1 .233 0 r
.008 w
.67505 .89974 Mdot
.016 w
.67505 .89974 m
.67488 .89977 L
s
.008 w
.67488 .89977 Mdot
.016 w
.67488 .89977 m
.67456 .89982 L
s
1 .232 0 r
.008 w
.67456 .89982 Mdot
.016 w
.67456 .89982 m
.67412 .89988 L
s
.008 w
.67412 .89988 Mdot
.016 w
.67412 .89988 m
.67361 .89994 L
s
.008 w
.67361 .89994 Mdot
.016 w
.67361 .89994 m
.67307 .90001 L
s
1 .231 0 r
.008 w
.67307 .90001 Mdot
.016 w
.67307 .90001 m
.67254 .90007 L
s
.008 w
.67254 .90007 Mdot
.016 w
.67254 .90007 m
.67203 .90013 L
s
1 .23 0 r
.008 w
.67203 .90013 Mdot
.016 w
.67203 .90013 m
.67157 .90019 L
s
.008 w
.67157 .90019 Mdot
.016 w
.67157 .90019 m
.67121 .90024 L
s
1 .229 0 r
.008 w
.67121 .90024 Mdot
.016 w
.67121 .90024 m
.67092 .90028 L
s
.008 w
.67092 .90028 Mdot
.016 w
.67092 .90028 m
.6707 .90033 L
s
.008 w
.6707 .90033 Mdot
.016 w
.6707 .90033 m
.67061 .90035 L
s
1 .228 0 r
.008 w
.67061 .90035 Mdot
.016 w
.67061 .90035 m
.6707 .90034 L
s
.008 w
.6707 .90034 Mdot
.016 w
.6707 .90034 m
.67096 .90028 L
s
1 .227 0 r
.008 w
.67096 .90028 Mdot
.016 w
.67096 .90028 m
.67134 .90018 L
s
.008 w
.67134 .90018 Mdot
.016 w
.67134 .90018 m
.67179 .90006 L
s
1 .226 0 r
.008 w
.67179 .90006 Mdot
.016 w
.67179 .90006 m
.67227 .89992 L
s
.008 w
.67227 .89992 Mdot
.016 w
.67227 .89992 m
.67276 .89979 L
s
.008 w
.67276 .89979 Mdot
.016 w
.67276 .89979 m
.67319 .89967 L
s
1 .225 0 r
.008 w
.67319 .89967 Mdot
.016 w
.67319 .89967 m
.67353 .89958 L
s
.008 w
.67353 .89958 Mdot
.016 w
.67353 .89958 m
.67374 .89952 L
s
1 .224 0 r
.008 w
.67374 .89952 Mdot
.016 w
.67374 .89952 m
.67387 .89948 L
s
.008 w
.67387 .89948 Mdot
.016 w
.67387 .89948 m
.67398 .89946 L
s
1 .223 0 r
.008 w
.67398 .89946 Mdot
.016 w
.67398 .89946 m
.67408 .89944 L
s
.008 w
.67408 .89944 Mdot
.016 w
.67408 .89944 m
.67421 .89942 L
s
1 .222 0 r
.008 w
.67421 .89942 Mdot
.016 w
.67421 .89942 m
.67432 .89941 L
s
.008 w
.67432 .89941 Mdot
.016 w
.67432 .89941 m
.6744 .89942 L
s
.008 w
.6744 .89942 Mdot
.016 w
.6744 .89942 m
.67445 .89947 L
s
1 .221 0 r
.008 w
.67445 .89947 Mdot
.016 w
.67445 .89947 m
.67446 .89955 L
s
.008 w
.67446 .89955 Mdot
.016 w
.67446 .89955 m
.67445 .89967 L
s
1 .22 0 r
.008 w
.67445 .89967 Mdot
.016 w
.67445 .89967 m
.6744 .8998 L
s
.008 w
.6744 .8998 Mdot
.016 w
.6744 .8998 m
.67431 .89994 L
s
1 .219 0 r
.008 w
.67431 .89994 Mdot
.016 w
.67431 .89994 m
.67416 .90007 L
s
.008 w
.67416 .90007 Mdot
.016 w
.67416 .90007 m
.67398 .90018 L
s
.008 w
.67398 .90018 Mdot
.016 w
.67398 .90018 m
.67381 .90026 L
s
1 .218 0 r
.008 w
.67381 .90026 Mdot
.016 w
.67381 .90026 m
.67366 .90031 L
s
.008 w
.67366 .90031 Mdot
.016 w
.67366 .90031 m
.67329 .90041 L
s
1 .217 0 r
.008 w
.67329 .90041 Mdot
.016 w
.67329 .90041 m
.67302 .90048 L
s
.008 w
.67302 .90048 Mdot
.016 w
.67302 .90048 m
.67268 .90056 L
s
1 .216 0 r
.008 w
.67268 .90056 Mdot
.016 w
.67268 .90056 m
.67219 .90066 L
s
.008 w
.67219 .90066 Mdot
.016 w
.67219 .90066 m
.67152 .90077 L
s
1 .215 0 r
.008 w
.67152 .90077 Mdot
.016 w
.67152 .90077 m
.67064 .90089 L
s
.008 w
.67064 .90089 Mdot
.016 w
.67064 .90089 m
.66947 .90103 L
s
.008 w
.66947 .90103 Mdot
.016 w
.66947 .90103 m
.66813 .90123 L
s
1 .214 0 r
.008 w
.66813 .90123 Mdot
.016 w
.66813 .90123 m
.66644 .90146 L
s
.008 w
.66644 .90146 Mdot
.016 w
.66644 .90146 m
.66447 .90175 L
s
1 .213 0 r
.008 w
.66447 .90175 Mdot
.016 w
.66447 .90175 m
.66236 .90209 L
s
.008 w
.66236 .90209 Mdot
.016 w
.66236 .90209 m
.65998 .90248 L
s
1 .212 0 r
.008 w
.65998 .90248 Mdot
.016 w
.65998 .90248 m
.65736 .90292 L
s
.008 w
.65736 .90292 Mdot
.016 w
.65736 .90292 m
.65459 .90342 L
s
.008 w
.65459 .90342 Mdot
.016 w
.65459 .90342 m
.6517 .90399 L
s
1 .211 0 r
.008 w
.6517 .90399 Mdot
.016 w
.6517 .90399 m
.64921 .90452 L
s
.008 w
.64921 .90452 Mdot
.016 w
.64921 .90452 m
.64686 .90512 L
s
1 .21 0 r
.008 w
.64686 .90512 Mdot
.016 w
.64686 .90512 m
.64493 .90574 L
s
.008 w
.64493 .90574 Mdot
.016 w
.64493 .90574 m
.6433 .90631 L
s
1 .209 0 r
.008 w
.6433 .90631 Mdot
.016 w
.6433 .90631 m
.64217 .90682 L
s
.008 w
.64217 .90682 Mdot
.016 w
.64217 .90682 m
.64139 .90724 L
s
.008 w
.64139 .90724 Mdot
.016 w
.64139 .90724 m
.64096 .90754 L
s
1 .208 0 r
.008 w
.64096 .90754 Mdot
.016 w
.64096 .90754 m
.64087 .90774 L
s
.008 w
.64087 .90774 Mdot
.016 w
.64087 .90774 m
.64096 .90781 L
s
1 .207 0 r
.008 w
.64096 .90781 Mdot
.016 w
.64096 .90781 m
.64123 .90783 L
s
.008 w
.64123 .90783 Mdot
.016 w
.64123 .90783 m
.64164 .90776 L
s
1 .206 0 r
.008 w
.64164 .90776 Mdot
.016 w
.64164 .90776 m
.64214 .90757 L
s
.008 w
.64214 .90757 Mdot
.016 w
.64214 .90757 m
.64267 .90733 L
s
1 .205 0 r
.008 w
.64267 .90733 Mdot
.016 w
.64267 .90733 m
.64315 .90705 L
s
.008 w
.64315 .90705 Mdot
.016 w
.64315 .90705 m
.64352 .90674 L
s
.008 w
.64352 .90674 Mdot
.016 w
.64352 .90674 m
.64372 .90639 L
s
1 .204 0 r
.008 w
.64372 .90639 Mdot
.016 w
.64372 .90639 m
.6438 .90606 L
s
.008 w
.6438 .90606 Mdot
.016 w
.6438 .90606 m
.64377 .90575 L
s
1 .203 0 r
.008 w
.64377 .90575 Mdot
.016 w
.64377 .90575 m
.64368 .90547 L
s
.008 w
.64368 .90547 Mdot
.016 w
.64368 .90547 m
.64352 .90525 L
s
1 .202 0 r
.008 w
.64352 .90525 Mdot
.016 w
.64352 .90525 m
.64328 .90508 L
s
.008 w
.64328 .90508 Mdot
.016 w
.64328 .90508 m
.64298 .90491 L
s
.008 w
.64298 .90491 Mdot
.016 w
.64298 .90491 m
.64264 .90469 L
s
1 .201 0 r
.008 w
.64264 .90469 Mdot
.016 w
.64264 .90469 m
.64229 .90443 L
s
.008 w
.64229 .90443 Mdot
.016 w
.64229 .90443 m
.64196 .90411 L
s
1 .2 0 r
.008 w
.64196 .90411 Mdot
.016 w
.64196 .90411 m
.64166 .90372 L
s
.008 w
.64166 .90372 Mdot
.016 w
.64166 .90372 m
.64139 .90323 L
s
1 .199 0 r
.008 w
.64139 .90323 Mdot
.016 w
.64139 .90323 m
.64116 .90264 L
s
.008 w
.64116 .90264 Mdot
.016 w
.64116 .90264 m
.641 .90205 L
s
.008 w
.641 .90205 Mdot
.016 w
.641 .90205 m
.64091 .90148 L
s
1 .198 0 r
.008 w
.64091 .90148 Mdot
.016 w
.64091 .90148 m
.64086 .90095 L
s
.008 w
.64086 .90095 Mdot
.016 w
.64086 .90095 m
.64083 .90047 L
s
1 .197 0 r
.008 w
.64083 .90047 Mdot
.016 w
.64083 .90047 m
.64082 .90007 L
s
.008 w
.64082 .90007 Mdot
.016 w
.64082 .90007 m
.64081 .89981 L
s
1 .196 0 r
.008 w
.64081 .89981 Mdot
.016 w
.64081 .89981 m
.64082 .8997 L
s
.008 w
.64082 .8997 Mdot
.016 w
.64082 .8997 m
.64084 .89975 L
s
1 .195 0 r
.008 w
.64084 .89975 Mdot
.016 w
.64084 .89975 m
.64088 .89993 L
s
.008 w
.64088 .89993 Mdot
.016 w
.64088 .89993 m
.64095 .9002 L
s
.008 w
.64095 .9002 Mdot
.016 w
.64095 .9002 m
.64103 .90049 L
s
1 .194 0 r
.008 w
.64103 .90049 Mdot
.016 w
.64103 .90049 m
.64111 .90075 L
s
.008 w
.64111 .90075 Mdot
.016 w
.64111 .90075 m
.64118 .9009 L
s
1 .193 0 r
.008 w
.64118 .9009 Mdot
.016 w
.64118 .9009 m
.64125 .90103 L
s
.008 w
.64125 .90103 Mdot
.016 w
.64125 .90103 m
.64129 .90107 L
s
1 .192 0 r
.008 w
.64129 .90107 Mdot
.016 w
.64129 .90107 m
.64134 .90099 L
s
.008 w
.64134 .90099 Mdot
.016 w
.64134 .90099 m
.64143 .90086 L
s
.008 w
.64143 .90086 Mdot
.016 w
.64143 .90086 m
.64157 .90067 L
s
1 .191 0 r
.008 w
.64157 .90067 Mdot
.016 w
.64157 .90067 m
.64177 .90045 L
s
.008 w
.64177 .90045 Mdot
.016 w
.64177 .90045 m
.64202 .90022 L
s
1 .19 0 r
.008 w
.64202 .90022 Mdot
.016 w
.64202 .90022 m
.64228 .90002 L
s
.008 w
.64228 .90002 Mdot
.016 w
.64228 .90002 m
.64249 .89988 L
s
1 .189 0 r
.008 w
.64249 .89988 Mdot
.016 w
.64249 .89988 m
.6426 .89981 L
s
.008 w
.6426 .89981 Mdot
.016 w
.6426 .89981 m
.64257 .89983 L
s
.008 w
.64257 .89983 Mdot
.016 w
.64257 .89983 m
.6424 .89998 L
s
1 .188 0 r
.008 w
.6424 .89998 Mdot
.016 w
.6424 .89998 m
.64206 .90028 L
s
.008 w
.64206 .90028 Mdot
.016 w
.64206 .90028 m
.64151 .90069 L
s
1 .187 0 r
.008 w
.64151 .90069 Mdot
.016 w
.64151 .90069 m
.64074 .90123 L
s
.008 w
.64074 .90123 Mdot
.016 w
.64074 .90123 m
.63974 .90188 L
s
1 .186 0 r
.008 w
.63974 .90188 Mdot
.016 w
.63974 .90188 m
.63853 .9026 L
s
.008 w
.63853 .9026 Mdot
.016 w
.63853 .9026 m
.63715 .90341 L
s
1 .185 0 r
.008 w
.63715 .90341 Mdot
.016 w
.63715 .90341 m
.63534 .90411 L
s
.008 w
.63534 .90411 Mdot
.016 w
.63534 .90411 m
.63347 .90487 L
s
.008 w
.63347 .90487 Mdot
.016 w
.63347 .90487 m
.63133 .90567 L
s
1 .184 0 r
.008 w
.63133 .90567 Mdot
.016 w
.63133 .90567 m
.62875 .90647 L
s
.008 w
.62875 .90647 Mdot
.016 w
.62875 .90647 m
.62584 .90731 L
s
1 .183 0 r
.008 w
.62584 .90731 Mdot
.016 w
.62584 .90731 m
.62255 .90811 L
s
.008 w
.62255 .90811 Mdot
.016 w
.62255 .90811 m
.61926 .90893 L
s
1 .182 0 r
.008 w
.61926 .90893 Mdot
.016 w
.61926 .90893 m
.61604 .90978 L
s
.008 w
.61604 .90978 Mdot
.016 w
.61604 .90978 m
.61251 .91061 L
s
.008 w
.61251 .91061 Mdot
.016 w
.61251 .91061 m
.60867 .91149 L
s
1 .181 0 r
.008 w
.60867 .91149 Mdot
.016 w
.60867 .91149 m
.60525 .91239 L
s
.008 w
.60525 .91239 Mdot
.016 w
.60525 .91239 m
.60122 .91317 L
s
1 .18 0 r
.008 w
.60122 .91317 Mdot
.016 w
.60122 .91317 m
.59736 .91391 L
s
.008 w
.59736 .91391 Mdot
.016 w
.59736 .91391 m
.59307 .91461 L
s
1 .179 0 r
.008 w
.59307 .91461 Mdot
.016 w
.59307 .91461 m
.58893 .91531 L
s
.008 w
.58893 .91531 Mdot
.016 w
.58893 .91531 m
.58508 .91591 L
s
1 .178 0 r
.008 w
.58508 .91591 Mdot
.016 w
.58508 .91591 m
.581 .9165 L
s
.008 w
.581 .9165 Mdot
.016 w
.581 .9165 m
.57687 .91707 L
s
.008 w
.57687 .91707 Mdot
.016 w
.57687 .91707 m
.57354 .91758 L
s
1 .177 0 r
.008 w
.57354 .91758 Mdot
.016 w
.57354 .91758 m
.56985 .91804 L
s
.008 w
.56985 .91804 Mdot
.016 w
.56985 .91804 m
.56649 .91847 L
s
1 .176 0 r
.008 w
.56649 .91847 Mdot
.016 w
.56649 .91847 m
.56294 .91887 L
s
.008 w
.56294 .91887 Mdot
.016 w
.56294 .91887 m
.55963 .91927 L
s
1 .175 0 r
.008 w
.55963 .91927 Mdot
.016 w
.55963 .91927 m
.55612 .91966 L
s
.008 w
.55612 .91966 Mdot
.016 w
.55612 .91966 m
.55259 .92006 L
s
.008 w
.55259 .92006 Mdot
.016 w
.55259 .92006 m
.54933 .92045 L
s
1 .174 0 r
.008 w
.54933 .92045 Mdot
.016 w
.54933 .92045 m
.54591 .92087 L
s
.008 w
.54591 .92087 Mdot
.016 w
.54591 .92087 m
.54237 .92134 L
s
1 .173 0 r
.008 w
.54237 .92134 Mdot
.016 w
.54237 .92134 m
.53924 .92184 L
s
.008 w
.53924 .92184 Mdot
.016 w
.53924 .92184 m
.53628 .92235 L
s
1 .172 0 r
.008 w
.53628 .92235 Mdot
.016 w
.53628 .92235 m
.53285 .92285 L
s
.008 w
.53285 .92285 Mdot
.016 w
.53285 .92285 m
.52997 .9233 L
s
.008 w
.52997 .9233 Mdot
.016 w
.52997 .9233 m
.52701 .92369 L
s
1 .171 0 r
.008 w
.52701 .92369 Mdot
.016 w
.52701 .92369 m
.52395 .92401 L
s
.008 w
.52395 .92401 Mdot
.016 w
.52395 .92401 m
.52092 .92426 L
s
1 .17 0 r
.008 w
.52092 .92426 Mdot
.016 w
.52092 .92426 m
.51827 .92438 L
s
.008 w
.51827 .92438 Mdot
.016 w
.51827 .92438 m
.51563 .92435 L
s
1 .169 0 r
.008 w
.51563 .92435 Mdot
.016 w
.51563 .92435 m
.51316 .92415 L
s
.008 w
.51316 .92415 Mdot
.016 w
.51316 .92415 m
.51078 .92383 L
s
1 .168 0 r
.008 w
.51078 .92383 Mdot
.016 w
.51078 .92383 m
.50865 .92341 L
s
.008 w
.50865 .92341 Mdot
.016 w
.50865 .92341 m
.5066 .92289 L
s
.008 w
.5066 .92289 Mdot
.016 w
.5066 .92289 m
.50467 .92233 L
s
1 .167 0 r
.008 w
.50467 .92233 Mdot
.016 w
.50467 .92233 m
.5031 .92178 L
s
.008 w
.5031 .92178 Mdot
.016 w
.5031 .92178 m
.50172 .92133 L
s
1 .166 0 r
.008 w
.50172 .92133 Mdot
.016 w
.50172 .92133 m
.50052 .92091 L
s
.008 w
.50052 .92091 Mdot
.016 w
.50052 .92091 m
.49956 .92059 L
s
1 .165 0 r
.008 w
.49956 .92059 Mdot
.016 w
.49956 .92059 m
.49879 .92038 L
s
.008 w
.49879 .92038 Mdot
.016 w
.49879 .92038 m
.49816 .92025 L
s
.008 w
.49816 .92025 Mdot
.016 w
.49816 .92025 m
.49758 .92016 L
s
1 .164 0 r
.008 w
.49758 .92016 Mdot
.016 w
.49758 .92016 m
.49696 .9201 L
s
.008 w
.49696 .9201 Mdot
.016 w
.49696 .9201 m
.49623 .9201 L
s
1 .163 0 r
.008 w
.49623 .9201 Mdot
.016 w
.49623 .9201 m
.49532 .92014 L
s
.008 w
.49532 .92014 Mdot
.016 w
.49532 .92014 m
.4941 .92019 L
s
1 .162 0 r
.008 w
.4941 .92019 Mdot
.016 w
.4941 .92019 m
.49255 .92027 L
s
.008 w
.49255 .92027 Mdot
.016 w
.49255 .92027 m
.49077 .9204 L
s
.008 w
.49077 .9204 Mdot
.016 w
.49077 .9204 m
.48859 .92053 L
s
1 .161 0 r
.008 w
.48859 .92053 Mdot
.016 w
.48859 .92053 m
.48602 .92063 L
s
.008 w
.48602 .92063 Mdot
.016 w
.48602 .92063 m
.48301 .92071 L
s
1 .16 0 r
.008 w
.48301 .92071 Mdot
.016 w
.48301 .92071 m
.47979 .92082 L
s
.008 w
.47979 .92082 Mdot
.016 w
.47979 .92082 m
.47637 .92096 L
s
1 .159 0 r
.008 w
.47637 .92096 Mdot
.016 w
.47637 .92096 m
.47249 .92116 L
s
.008 w
.47249 .92116 Mdot
.016 w
.47249 .92116 m
.46851 .92139 L
s
1 .158 0 r
.008 w
.46851 .92139 Mdot
.016 w
.46851 .92139 m
.46475 .92162 L
s
.008 w
.46475 .92162 Mdot
.016 w
.46475 .92162 m
.46075 .92183 L
s
.008 w
.46075 .92183 Mdot
.016 w
.46075 .92183 m
.45673 .92199 L
s
1 .157 0 r
.008 w
.45673 .92199 Mdot
.016 w
.45673 .92199 m
.45278 .92205 L
s
.008 w
.45278 .92205 Mdot
.016 w
.45278 .92205 m
.44902 .92201 L
s
1 .156 0 r
.008 w
.44902 .92201 Mdot
.016 w
.44902 .92201 m
.4452 .92187 L
s
.008 w
.4452 .92187 Mdot
.016 w
.4452 .92187 m
.44188 .92169 L
s
1 .155 0 r
.008 w
.44188 .92169 Mdot
.016 w
.44188 .92169 m
.43878 .92152 L
s
.008 w
.43878 .92152 Mdot
.016 w
.43878 .92152 m
.43599 .92138 L
s
.008 w
.43599 .92138 Mdot
.016 w
.43599 .92138 m
.43365 .92127 L
s
1 .154 0 r
.008 w
.43365 .92127 Mdot
.016 w
.43365 .92127 m
.43162 .92116 L
s
.008 w
.43162 .92116 Mdot
.016 w
.43162 .92116 m
.42993 .92107 L
s
1 .153 0 r
.008 w
.42993 .92107 Mdot
.016 w
.42993 .92107 m
.42867 .92101 L
s
.008 w
.42867 .92101 Mdot
.016 w
.42867 .92101 m
.42771 .92096 L
s
1 .152 0 r
.008 w
.42771 .92096 Mdot
.016 w
.42771 .92096 m
.42705 .92091 L
s
.008 w
.42705 .92091 Mdot
.016 w
.42705 .92091 m
.42669 .92087 L
s
.008 w
.42669 .92087 Mdot
.016 w
.42669 .92087 m
.42657 .92084 L
s
1 .151 0 r
.008 w
.42657 .92084 Mdot
.016 w
.42657 .92084 m
.42662 .92083 L
s
.008 w
.42662 .92083 Mdot
.016 w
.42662 .92083 m
.42676 .92079 L
s
1 .15 0 r
.008 w
.42676 .92079 Mdot
.016 w
.42676 .92079 m
.42693 .92072 L
s
.008 w
.42693 .92072 Mdot
.016 w
.42693 .92072 m
.42708 .92058 L
s
1 .149 0 r
.008 w
.42708 .92058 Mdot
.016 w
.42708 .92058 m
.4272 .92035 L
s
.008 w
.4272 .92035 Mdot
.016 w
.4272 .92035 m
.42727 .92013 L
s
1 .148 0 r
.008 w
.42727 .92013 Mdot
.016 w
.42727 .92013 m
.42729 .91989 L
s
.008 w
.42729 .91989 Mdot
.016 w
.42729 .91989 m
.42725 .91965 L
s
.008 w
.42725 .91965 Mdot
.016 w
.42725 .91965 m
.42716 .9194 L
s
1 .147 0 r
.008 w
.42716 .9194 Mdot
.016 w
.42716 .9194 m
.42706 .91914 L
s
.008 w
.42706 .91914 Mdot
.016 w
.42706 .91914 m
.42696 .91889 L
s
1 .146 0 r
.008 w
.42696 .91889 Mdot
.016 w
.42696 .91889 m
.42687 .91869 L
s
.008 w
.42687 .91869 Mdot
.016 w
.42687 .91869 m
.42675 .91848 L
s
1 .145 0 r
.008 w
.42675 .91848 Mdot
.016 w
.42675 .91848 m
.42661 .9182 L
s
.008 w
.42661 .9182 Mdot
.016 w
.42661 .9182 m
.42647 .9179 L
s
.008 w
.42647 .9179 Mdot
.016 w
.42647 .9179 m
.42632 .91755 L
s
1 .144 0 r
.008 w
.42632 .91755 Mdot
.016 w
.42632 .91755 m
.42617 .9172 L
s
.008 w
.42617 .9172 Mdot
.016 w
.42617 .9172 m
.42602 .91683 L
s
1 .143 0 r
.008 w
.42602 .91683 Mdot
.016 w
.42602 .91683 m
.42588 .91648 L
s
.008 w
.42588 .91648 Mdot
.016 w
.42588 .91648 m
.42577 .91615 L
s
1 .142 0 r
.008 w
.42577 .91615 Mdot
.016 w
.42577 .91615 m
.42565 .91584 L
s
.008 w
.42565 .91584 Mdot
.016 w
.42565 .91584 m
.42552 .91556 L
s
1 .141 0 r
.008 w
.42552 .91556 Mdot
.016 w
.42552 .91556 m
.42538 .91535 L
s
.008 w
.42538 .91535 Mdot
.016 w
.42538 .91535 m
.42525 .91523 L
s
.008 w
.42525 .91523 Mdot
.016 w
.42525 .91523 m
.42513 .9152 L
s
1 .14 0 r
.008 w
.42513 .9152 Mdot
.016 w
.42513 .9152 m
.42507 .9153 L
s
.008 w
.42507 .9153 Mdot
.016 w
.42507 .9153 m
.42508 .91556 L
s
1 .139 0 r
.008 w
.42508 .91556 Mdot
.016 w
.42508 .91556 m
.42516 .91594 L
s
.008 w
.42516 .91594 Mdot
.016 w
.42516 .91594 m
.4253 .91641 L
s
1 .138 0 r
.008 w
.4253 .91641 Mdot
.016 w
.4253 .91641 m
.42545 .9169 L
s
.008 w
.42545 .9169 Mdot
.016 w
.42545 .9169 m
.42562 .91738 L
s
.008 w
.42562 .91738 Mdot
.016 w
.42562 .91738 m
.42578 .91781 L
s
1 .137 0 r
.008 w
.42578 .91781 Mdot
.016 w
.42578 .91781 m
.42594 .91817 L
s
.008 w
.42594 .91817 Mdot
.016 w
.42594 .91817 m
.42609 .91844 L
s
1 .136 0 r
.008 w
.42609 .91844 Mdot
.016 w
.42609 .91844 m
.42623 .91862 L
s
.008 w
.42623 .91862 Mdot
.016 w
.42623 .91862 m
.42638 .91869 L
s
1 .135 0 r
.008 w
.42638 .91869 Mdot
.016 w
.42638 .91869 m
.42655 .91864 L
s
.008 w
.42655 .91864 Mdot
.016 w
.42655 .91864 m
.42672 .91843 L
s
.008 w
.42672 .91843 Mdot
.016 w
.42672 .91843 m
.42689 .91807 L
s
1 .134 0 r
.008 w
.42689 .91807 Mdot
.016 w
.42689 .91807 m
.42706 .91766 L
s
.008 w
.42706 .91766 Mdot
.016 w
.42706 .91766 m
.42722 .91721 L
s
1 .133 0 r
.008 w
.42722 .91721 Mdot
.016 w
.42722 .91721 m
.42735 .91675 L
s
.008 w
.42735 .91675 Mdot
.016 w
.42735 .91675 m
.42743 .91634 L
s
1 .132 0 r
.008 w
.42743 .91634 Mdot
.016 w
.42743 .91634 m
.42748 .91602 L
s
.008 w
.42748 .91602 Mdot
.016 w
.42748 .91602 m
.42751 .91583 L
s
1 .131 0 r
.008 w
.42751 .91583 Mdot
.016 w
.42751 .91583 m
.42752 .91579 L
s
.008 w
.42752 .91579 Mdot
.016 w
.42752 .91579 m
.42751 .91583 L
s
.008 w
.42751 .91583 Mdot
.016 w
.42751 .91583 m
.42748 .91592 L
s
1 .13 0 r
.008 w
.42748 .91592 Mdot
.016 w
.42748 .91592 m
.42741 .91604 L
s
.008 w
.42741 .91604 Mdot
.016 w
.42741 .91604 m
.42729 .91618 L
s
1 .129 0 r
.008 w
.42729 .91618 Mdot
.016 w
.42729 .91618 m
.42711 .91628 L
s
.008 w
.42711 .91628 Mdot
.016 w
.42711 .91628 m
.42687 .91638 L
s
1 .128 0 r
.008 w
.42687 .91638 Mdot
.016 w
.42687 .91638 m
.4266 .91644 L
s
.008 w
.4266 .91644 Mdot
.016 w
.4266 .91644 m
.42631 .91642 L
s
.008 w
.42631 .91642 Mdot
.016 w
.42631 .91642 m
.42603 .91635 L
s
1 .127 0 r
.008 w
.42603 .91635 Mdot
.016 w
.42603 .91635 m
.42579 .91623 L
s
.008 w
.42579 .91623 Mdot
.016 w
.42579 .91623 m
.4256 .91608 L
s
1 .126 0 r
.008 w
.4256 .91608 Mdot
.016 w
.4256 .91608 m
.42544 .91591 L
s
.008 w
.42544 .91591 Mdot
.016 w
.42544 .91591 m
.42533 .91574 L
s
1 .125 0 r
.008 w
.42533 .91574 Mdot
.016 w
.42533 .91574 m
.42527 .9156 L
s
.008 w
.42527 .9156 Mdot
.016 w
.42527 .9156 m
.42525 .91549 L
s
.008 w
.42525 .91549 Mdot
.016 w
.42525 .91549 m
.42526 .91544 L
s
1 .124 0 r
.008 w
.42526 .91544 Mdot
.016 w
.42526 .91544 m
.42528 .91545 L
s
.008 w
.42528 .91545 Mdot
.016 w
.42528 .91545 m
.42531 .9155 L
s
1 .123 0 r
.008 w
.42531 .9155 Mdot
.016 w
.42531 .9155 m
.42535 .91555 L
s
.008 w
.42535 .91555 Mdot
.016 w
.42535 .91555 m
.42538 .91559 L
s
1 .122 0 r
.008 w
.42538 .91559 Mdot
.016 w
.42538 .91559 m
.42541 .91562 L
s
.008 w
.42541 .91562 Mdot
.016 w
.42541 .91562 m
.42544 .91566 L
s
1 .121 0 r
.008 w
.42544 .91566 Mdot
.016 w
.42544 .91566 m
.42548 .9157 L
s
.008 w
.42548 .9157 Mdot
.016 w
.42548 .9157 m
.42551 .91572 L
s
.008 w
.42551 .91572 Mdot
.016 w
.42551 .91572 m
.42553 .9157 L
s
1 .12 0 r
.008 w
.42553 .9157 Mdot
.016 w
.42553 .9157 m
.42554 .91564 L
s
.008 w
.42554 .91564 Mdot
.016 w
.42554 .91564 m
.42555 .91557 L
s
1 .119 0 r
.008 w
.42555 .91557 Mdot
.016 w
.42555 .91557 m
.42555 .91552 L
s
.008 w
.42555 .91552 Mdot
.016 w
.42555 .91552 m
.42556 .91553 L
s
1 .118 0 r
.008 w
.42556 .91553 Mdot
.016 w
.42556 .91553 m
.42558 .91565 L
s
.008 w
.42558 .91565 Mdot
.016 w
.42558 .91565 m
.42562 .91589 L
s
.008 w
.42562 .91589 Mdot
.016 w
.42562 .91589 m
.42566 .91624 L
s
1 .117 0 r
.008 w
.42566 .91624 Mdot
.016 w
.42566 .91624 m
.42571 .91668 L
s
.008 w
.42571 .91668 Mdot
.016 w
.42571 .91668 m
.42576 .9172 L
s
1 .116 0 r
.008 w
.42576 .9172 Mdot
.016 w
.42576 .9172 m
.42583 .91775 L
s
.008 w
.42583 .91775 Mdot
.016 w
.42583 .91775 m
.42591 .9183 L
s
1 .115 0 r
.008 w
.42591 .9183 Mdot
.016 w
.42591 .9183 m
.426 .91882 L
s
.008 w
.426 .91882 Mdot
.016 w
.426 .91882 m
.42612 .91924 L
s
1 .114 0 r
.008 w
.42612 .91924 Mdot
.016 w
.42612 .91924 m
.42626 .91969 L
s
.008 w
.42626 .91969 Mdot
.016 w
.42626 .91969 m
.42641 .92009 L
s
.008 w
.42641 .92009 Mdot
.016 w
.42641 .92009 m
.42656 .9204 L
s
1 .113 0 r
.008 w
.42656 .9204 Mdot
.016 w
.42656 .9204 m
.42672 .92062 L
s
.008 w
.42672 .92062 Mdot
.016 w
.42672 .92062 m
.42686 .92068 L
s
1 .112 0 r
.008 w
.42686 .92068 Mdot
.016 w
.42686 .92068 m
.42697 .9206 L
s
.008 w
.42697 .9206 Mdot
.016 w
.42697 .9206 m
.42706 .92043 L
s
1 .111 0 r
.008 w
.42706 .92043 Mdot
.016 w
.42706 .92043 m
.42713 .92021 L
s
.008 w
.42713 .92021 Mdot
.016 w
.42713 .92021 m
.42719 .91994 L
s
.008 w
.42719 .91994 Mdot
.016 w
.42719 .91994 m
.42721 .91968 L
s
1 .11 0 r
.008 w
.42721 .91968 Mdot
.016 w
.42721 .91968 m
.42723 .91944 L
s
.008 w
.42723 .91944 Mdot
.016 w
.42723 .91944 m
.42725 .91924 L
s
1 .109 0 r
.008 w
.42725 .91924 Mdot
.016 w
.42725 .91924 m
.42728 .91906 L
s
.008 w
.42728 .91906 Mdot
.016 w
.42728 .91906 m
.4273 .91886 L
s
1 .108 0 r
.008 w
.4273 .91886 Mdot
.016 w
.4273 .91886 m
.42734 .91867 L
s
.008 w
.42734 .91867 Mdot
.016 w
.42734 .91867 m
.42736 .91846 L
s
.008 w
.42736 .91846 Mdot
.016 w
.42736 .91846 m
.42736 .91822 L
s
1 .107 0 r
.008 w
.42736 .91822 Mdot
.016 w
.42736 .91822 m
.42731 .91793 L
s
.008 w
.42731 .91793 Mdot
.016 w
.42731 .91793 m
.42724 .91763 L
s
1 .106 0 r
.008 w
.42724 .91763 Mdot
.016 w
.42724 .91763 m
.42714 .91734 L
s
.008 w
.42714 .91734 Mdot
.016 w
.42714 .91734 m
.42702 .91703 L
s
1 .105 0 r
.008 w
.42702 .91703 Mdot
.016 w
.42702 .91703 m
.42689 .91672 L
s
.008 w
.42689 .91672 Mdot
.016 w
.42689 .91672 m
.42675 .91643 L
s
1 .104 0 r
.008 w
.42675 .91643 Mdot
.016 w
.42675 .91643 m
.42661 .91616 L
s
.008 w
.42661 .91616 Mdot
.016 w
.42661 .91616 m
.42647 .91596 L
s
.008 w
.42647 .91596 Mdot
.016 w
.42647 .91596 m
.42632 .9158 L
s
1 .103 0 r
.008 w
.42632 .9158 Mdot
.016 w
.42632 .9158 m
.42624 .91571 L
s
.008 w
.42624 .91571 Mdot
.016 w
.42624 .91571 m
.42627 .91567 L
s
1 .102 0 r
.008 w
.42627 .91567 Mdot
.016 w
.42627 .91567 m
.42634 .91567 L
s
.008 w
.42634 .91567 Mdot
.016 w
.42634 .91567 m
.42641 .91568 L
s
1 .101 0 r
.008 w
.42641 .91568 Mdot
.016 w
.42641 .91568 m
.42645 .91568 L
s
.008 w
.42645 .91568 Mdot
.016 w
.42645 .91568 m
.42645 .91566 L
s
.008 w
.42645 .91566 Mdot
.016 w
.42645 .91566 m
.42637 .91563 L
s
1 .1 0 r
.008 w
.42637 .91563 Mdot
.016 w
.42637 .91563 m
.42609 .9156 L
s
.008 w
.42609 .9156 Mdot
.016 w
.42609 .9156 m
.4255 .91561 L
s
1 .099 0 r
.008 w
.4255 .91561 Mdot
.016 w
.4255 .91561 m
.42454 .91566 L
s
.008 w
.42454 .91566 Mdot
.016 w
.42454 .91566 m
.42311 .91569 L
s
1 .098 0 r
.008 w
.42311 .91569 Mdot
.016 w
.42311 .91569 m
.42117 .91567 L
s
.008 w
.42117 .91567 Mdot
.016 w
.42117 .91567 m
.41872 .91556 L
s
.008 w
.41872 .91556 Mdot
.016 w
.41872 .91556 m
.41626 .91535 L
s
1 .097 0 r
.008 w
.41626 .91535 Mdot
.016 w
.41626 .91535 m
.41339 .91504 L
s
.008 w
.41339 .91504 Mdot
.016 w
.41339 .91504 m
.40982 .9146 L
s
1 .096 0 r
.008 w
.40982 .9146 Mdot
.016 w
.40982 .9146 m
.40636 .91405 L
s
.008 w
.40636 .91405 Mdot
.016 w
.40636 .91405 m
.40186 .91335 L
s
1 .095 0 r
.008 w
.40186 .91335 Mdot
.016 w
.40186 .91335 m
.39824 .91252 L
s
.008 w
.39824 .91252 Mdot
.016 w
.39824 .91252 m
.39366 .91164 L
s
1 .094 0 r
.008 w
.39366 .91164 Mdot
.016 w
.39366 .91164 m
.38961 .91058 L
s
.008 w
.38961 .91058 Mdot
.016 w
.38961 .91058 m
.3854 .90946 L
s
.008 w
.3854 .90946 Mdot
.016 w
.3854 .90946 m
.3807 .90822 L
s
1 .093 0 r
.008 w
.3807 .90822 Mdot
.016 w
.3807 .90822 m
.37702 .90687 L
s
.008 w
.37702 .90687 Mdot
.016 w
.37702 .90687 m
.37275 .90547 L
s
1 .092 0 r
.008 w
.37275 .90547 Mdot
.016 w
.37275 .90547 m
.36889 .90402 L
s
.008 w
.36889 .90402 Mdot
.016 w
.36889 .90402 m
.36494 .90257 L
s
1 .091 0 r
.008 w
.36494 .90257 Mdot
.016 w
.36494 .90257 m
.36108 .9011 L
s
.008 w
.36108 .9011 Mdot
.016 w
.36108 .9011 m
.35687 .8997 L
s
.008 w
.35687 .8997 Mdot
.016 w
.35687 .8997 m
.3533 .89834 L
s
1 .09 0 r
.008 w
.3533 .89834 Mdot
.016 w
.3533 .89834 m
.34922 .89704 L
s
.008 w
.34922 .89704 Mdot
.016 w
.34922 .89704 m
.34546 .89577 L
s
1 .089 0 r
.008 w
.34546 .89577 Mdot
.016 w
.34546 .89577 m
.34156 .89452 L
s
.008 w
.34156 .89452 Mdot
.016 w
.34156 .89452 m
.33767 .8933 L
s
1 .088 0 r
.008 w
.33767 .8933 Mdot
.016 w
.33767 .8933 m
.33398 .89207 L
s
.008 w
.33398 .89207 Mdot
.016 w
.33398 .89207 m
.32993 .89085 L
s
.008 w
.32993 .89085 Mdot
.016 w
.32993 .89085 m
.32652 .88964 L
s
1 .087 0 r
.008 w
.32652 .88964 Mdot
.016 w
.32652 .88964 m
.32284 .88841 L
s
.008 w
.32284 .88841 Mdot
.016 w
.32284 .88841 m
.3193 .88719 L
s
1 .086 0 r
.008 w
.3193 .88719 Mdot
.016 w
.3193 .88719 m
.31589 .88598 L
s
.008 w
.31589 .88598 Mdot
.016 w
.31589 .88598 m
.31248 .88481 L
s
1 .085 0 r
.008 w
.31248 .88481 Mdot
.016 w
.31248 .88481 m
.30933 .88375 L
s
.008 w
.30933 .88375 Mdot
.016 w
.30933 .88375 m
.30612 .8827 L
s
1 .084 0 r
.008 w
.30612 .8827 Mdot
.016 w
.30612 .8827 m
.30327 .8817 L
s
.008 w
.30327 .8817 Mdot
.016 w
.30327 .8817 m
.30082 .8808 L
s
.008 w
.30082 .8808 Mdot
.016 w
.30082 .8808 m
.29859 .87997 L
s
1 .083 0 r
.008 w
.29859 .87997 Mdot
.016 w
.29859 .87997 m
.29663 .87923 L
s
.008 w
.29663 .87923 Mdot
.016 w
.29663 .87923 m
.29514 .87866 L
s
1 .082 0 r
.008 w
.29514 .87866 Mdot
.016 w
.29514 .87866 m
.29388 .87826 L
s
.008 w
.29388 .87826 Mdot
.016 w
.29388 .87826 m
.29294 .87806 L
s
1 .081 0 r
.008 w
.29294 .87806 Mdot
.016 w
.29294 .87806 m
.29226 .87799 L
s
.008 w
.29226 .87799 Mdot
.016 w
.29226 .87799 m
.29175 .87801 L
s
.008 w
.29175 .87801 Mdot
.016 w
.29175 .87801 m
.29133 .87805 L
s
1 .08 0 r
.008 w
.29133 .87805 Mdot
.016 w
.29133 .87805 m
.29091 .87805 L
s
.008 w
.29091 .87805 Mdot
.016 w
.29091 .87805 m
.29039 .8779 L
s
1 .079 0 r
.008 w
.29039 .8779 Mdot
.016 w
.29039 .8779 m
.28968 .87757 L
s
.008 w
.28968 .87757 Mdot
.016 w
.28968 .87757 m
.28863 .87703 L
s
1 .078 0 r
.008 w
.28863 .87703 Mdot
.016 w
.28863 .87703 m
.28744 .87634 L
s
.008 w
.28744 .87634 Mdot
.016 w
.28744 .87634 m
.28583 .87546 L
s
1 .077 0 r
.008 w
.28583 .87546 Mdot
.016 w
.28583 .87546 m
.2838 .87442 L
s
.008 w
.2838 .87442 Mdot
.016 w
.2838 .87442 m
.28152 .87335 L
s
.008 w
.28152 .87335 Mdot
.016 w
.28152 .87335 m
.27893 .87202 L
s
1 .076 0 r
.008 w
.27893 .87202 Mdot
.016 w
.27893 .87202 m
.27613 .87067 L
s
.008 w
.27613 .87067 Mdot
.016 w
.27613 .87067 m
.27302 .86918 L
s
1 .075 0 r
.008 w
.27302 .86918 Mdot
.016 w
.27302 .86918 m
.27004 .86762 L
s
.008 w
.27004 .86762 Mdot
.016 w
.27004 .86762 m
.2671 .86598 L
s
1 .074 0 r
.008 w
.2671 .86598 Mdot
.016 w
.2671 .86598 m
.26427 .8645 L
s
.008 w
.26427 .8645 Mdot
.016 w
.26427 .8645 m
.26145 .86303 L
s
.008 w
.26145 .86303 Mdot
.016 w
.26145 .86303 m
.25882 .86159 L
s
1 .073 0 r
.008 w
.25882 .86159 Mdot
.016 w
.25882 .86159 m
.25628 .86025 L
s
.008 w
.25628 .86025 Mdot
.016 w
.25628 .86025 m
.25393 .85891 L
s
1 .072 0 r
.008 w
.25393 .85891 Mdot
.016 w
.25393 .85891 m
.25159 .85749 L
s
.008 w
.25159 .85749 Mdot
.016 w
.25159 .85749 m
.24934 .85597 L
s
1 .071 0 r
.008 w
.24934 .85597 Mdot
.016 w
.24934 .85597 m
.24717 .85431 L
s
.008 w
.24717 .85431 Mdot
.016 w
.24717 .85431 m
.24494 .85249 L
s
.008 w
.24494 .85249 Mdot
.016 w
.24494 .85249 m
.24264 .85049 L
s
1 .07 0 r
.008 w
.24264 .85049 Mdot
.016 w
.24264 .85049 m
.24046 .84842 L
s
.008 w
.24046 .84842 Mdot
.016 w
.24046 .84842 m
.23819 .84614 L
s
1 .069 0 r
.008 w
.23819 .84614 Mdot
.016 w
.23819 .84614 m
.2359 .8438 L
s
.008 w
.2359 .8438 Mdot
.016 w
.2359 .8438 m
.23365 .84128 L
s
1 .068 0 r
.008 w
.23365 .84128 Mdot
.016 w
.23365 .84128 m
.23147 .83857 L
s
.008 w
.23147 .83857 Mdot
.016 w
.23147 .83857 m
.22933 .83586 L
s
1 .067 0 r
.008 w
.22933 .83586 Mdot
.016 w
.22933 .83586 m
.22727 .8329 L
s
.008 w
.22727 .8329 Mdot
.016 w
.22727 .8329 m
.22549 .83014 L
s
.008 w
.22549 .83014 Mdot
.016 w
.22549 .83014 m
.22387 .82717 L
s
1 .066 0 r
.008 w
.22387 .82717 Mdot
.016 w
.22387 .82717 m
.22245 .82453 L
s
.008 w
.22245 .82453 Mdot
.016 w
.22245 .82453 m
.22125 .82197 L
s
1 .065 0 r
.008 w
.22125 .82197 Mdot
.016 w
.22125 .82197 m
.22022 .81962 L
s
.008 w
.22022 .81962 Mdot
.016 w
.22022 .81962 m
.21932 .81749 L
s
1 .064 0 r
.008 w
.21932 .81749 Mdot
.016 w
.21932 .81749 m
.21846 .81559 L
s
.008 w
.21846 .81559 Mdot
.016 w
.21846 .81559 m
.21754 .81375 L
s
.008 w
.21754 .81375 Mdot
.016 w
.21754 .81375 m
.21648 .81228 L
s
1 .063 0 r
.008 w
.21648 .81228 Mdot
.016 w
.21648 .81228 m
.21524 .81094 L
s
.008 w
.21524 .81094 Mdot
.016 w
.21524 .81094 m
.21376 .80972 L
s
1 .062 0 r
.008 w
.21376 .80972 Mdot
.016 w
.21376 .80972 m
.21197 .80863 L
s
.008 w
.21197 .80863 Mdot
.016 w
.21197 .80863 m
.20982 .80765 L
s
1 .061 0 r
.008 w
.20982 .80765 Mdot
.016 w
.20982 .80765 m
.20771 .80671 L
s
.008 w
.20771 .80671 Mdot
.016 w
.20771 .80671 m
.20516 .80581 L
s
.008 w
.20516 .80581 Mdot
.016 w
.20516 .80581 m
.2022 .80475 L
s
1 .06 0 r
.008 w
.2022 .80475 Mdot
.016 w
.2022 .80475 m
.19934 .80351 L
s
.008 w
.19934 .80351 Mdot
.016 w
.19934 .80351 m
.19607 .80204 L
s
1 .059 0 r
.008 w
.19607 .80204 Mdot
.016 w
.19607 .80204 m
.19243 .8003 L
s
.008 w
.19243 .8003 Mdot
.016 w
.19243 .8003 m
.18904 .79833 L
s
1 .058 0 r
.008 w
.18904 .79833 Mdot
.016 w
.18904 .79833 m
.18529 .79595 L
s
.008 w
.18529 .79595 Mdot
.016 w
.18529 .79595 m
.18168 .79341 L
s
1 .057 0 r
.008 w
.18168 .79341 Mdot
.016 w
.18168 .79341 m
.17798 .79071 L
s
.008 w
.17798 .79071 Mdot
.016 w
.17798 .79071 m
.17454 .78808 L
s
.008 w
.17454 .78808 Mdot
.016 w
.17454 .78808 m
.17096 .78512 L
s
1 .056 0 r
.008 w
.17096 .78512 Mdot
.016 w
.17096 .78512 m
.16774 .78226 L
s
.008 w
.16774 .78226 Mdot
.016 w
.16774 .78226 m
.16441 .77918 L
s
1 .055 0 r
.008 w
.16441 .77918 Mdot
.016 w
.16441 .77918 m
.16132 .77633 L
s
.008 w
.16132 .77633 Mdot
.016 w
.16132 .77633 m
.1583 .77337 L
s
1 .054 0 r
.008 w
.1583 .77337 Mdot
.016 w
.1583 .77337 m
.15546 .77052 L
s
.008 w
.15546 .77052 Mdot
.016 w
.15546 .77052 m
.15279 .76768 L
s
.008 w
.15279 .76768 Mdot
.016 w
.15279 .76768 m
.15032 .76512 L
s
1 .053 0 r
.008 w
.15032 .76512 Mdot
.016 w
.15032 .76512 m
.14807 .76252 L
s
.008 w
.14807 .76252 Mdot
.016 w
.14807 .76252 m
.14603 .75994 L
s
1 .052 0 r
.008 w
.14603 .75994 Mdot
.016 w
.14603 .75994 m
.14424 .75749 L
s
.008 w
.14424 .75749 Mdot
.016 w
.14424 .75749 m
.14262 .75491 L
s
1 .051 0 r
.008 w
.14262 .75491 Mdot
.016 w
.14262 .75491 m
.14119 .75255 L
s
.008 w
.14119 .75255 Mdot
.016 w
.14119 .75255 m
.13988 .75008 L
s
.008 w
.13988 .75008 Mdot
.016 w
.13988 .75008 m
.13863 .74764 L
s
1 .05 0 r
.008 w
.13863 .74764 Mdot
.016 w
.13863 .74764 m
.13736 .74518 L
s
.008 w
.13736 .74518 Mdot
.016 w
.13736 .74518 m
.13607 .74272 L
s
1 .049 0 r
.008 w
.13607 .74272 Mdot
.016 w
.13607 .74272 m
.13479 .7401 L
s
.008 w
.13479 .7401 Mdot
.016 w
.13479 .7401 m
.13347 .73769 L
s
1 .048 0 r
.008 w
.13347 .73769 Mdot
.016 w
.13347 .73769 m
.13219 .73512 L
s
.008 w
.13219 .73512 Mdot
.016 w
.13219 .73512 m
.13089 .73249 L
s
1 .047 0 r
.008 w
.13089 .73249 Mdot
.016 w
.13089 .73249 m
.1297 .73002 L
s
.008 w
.1297 .73002 Mdot
.016 w
.1297 .73002 m
.12855 .72748 L
s
.008 w
.12855 .72748 Mdot
.016 w
.12855 .72748 m
.12748 .72515 L
s
1 .046 0 r
.008 w
.12748 .72515 Mdot
.016 w
.12748 .72515 m
.12646 .72299 L
s
.008 w
.12646 .72299 Mdot
.016 w
.12646 .72299 m
.12559 .7208 L
s
1 .045 0 r
.008 w
.12559 .7208 Mdot
.016 w
.12559 .7208 m
.12527 .71881 L
s
.008 w
.12527 .71881 Mdot
.016 w
.12527 .71881 m
.1245 .71682 L
s
1 .044 0 r
.008 w
.1245 .71682 Mdot
.016 w
.1245 .71682 m
.12383 .7151 L
s
.008 w
.12383 .7151 Mdot
.016 w
.12383 .7151 m
.12334 .71348 L
s
.008 w
.12334 .71348 Mdot
.016 w
.12334 .71348 m
.12306 .71206 L
s
1 .043 0 r
.008 w
.12306 .71206 Mdot
.016 w
.12306 .71206 m
.12295 .71087 L
s
.008 w
.12295 .71087 Mdot
.016 w
.12295 .71087 m
.12295 .70989 L
s
1 .042 0 r
.008 w
.12295 .70989 Mdot
.016 w
.12295 .70989 m
.12301 .70912 L
s
.008 w
.12301 .70912 Mdot
.016 w
.12301 .70912 m
.12307 .7085 L
s
1 .041 0 r
.008 w
.12307 .7085 Mdot
.016 w
.12307 .7085 m
.12306 .70795 L
s
.008 w
.12306 .70795 Mdot
.016 w
.12306 .70795 m
.12294 .70741 L
s
1 .04 0 r
.008 w
.12294 .70741 Mdot
.016 w
.12294 .70741 m
.12265 .70679 L
s
.008 w
.12265 .70679 Mdot
.016 w
.12265 .70679 m
.12212 .70603 L
s
.008 w
.12212 .70603 Mdot
.016 w
.12212 .70603 m
.12132 .70508 L
s
1 .039 0 r
.008 w
.12132 .70508 Mdot
.016 w
.12132 .70508 m
.12029 .70391 L
s
.008 w
.12029 .70391 Mdot
.016 w
.12029 .70391 m
.11905 .70255 L
s
1 .038 0 r
.008 w
.11905 .70255 Mdot
.016 w
.11905 .70255 m
.11784 .70113 L
s
.008 w
.11784 .70113 Mdot
.016 w
.11784 .70113 m
.11626 .69949 L
s
1 .037 0 r
.008 w
.11626 .69949 Mdot
.016 w
.11626 .69949 m
.11442 .69766 L
s
.008 w
.11442 .69766 Mdot
.016 w
.11442 .69766 m
.11241 .69573 L
s
.008 w
.11241 .69573 Mdot
.016 w
.11241 .69573 m
.11024 .69349 L
s
1 .036 0 r
.008 w
.11024 .69349 Mdot
.016 w
.11024 .69349 m
.10805 .6913 L
s
.008 w
.10805 .6913 Mdot
.016 w
.10805 .6913 m
.10569 .68892 L
s
1 .035 0 r
.008 w
.10569 .68892 Mdot
.016 w
.10569 .68892 m
.10347 .68639 L
s
.008 w
.10347 .68639 Mdot
.016 w
.10347 .68639 m
.10145 .68395 L
s
1 .034 0 r
.008 w
.10145 .68395 Mdot
.016 w
.10145 .68395 m
.09945 .68128 L
s
.008 w
.09945 .68128 Mdot
.016 w
.09945 .68128 m
.09771 .67858 L
s
.008 w
.09771 .67858 Mdot
.016 w
.09771 .67858 m
.09615 .67569 L
s
1 .033 0 r
.008 w
.09615 .67569 Mdot
.016 w
.09615 .67569 m
.09476 .67259 L
s
.008 w
.09476 .67259 Mdot
.016 w
.09476 .67259 m
.09358 .66912 L
s
1 .032 0 r
.008 w
.09358 .66912 Mdot
.016 w
.09358 .66912 m
.09253 .66553 L
s
.008 w
.09253 .66553 Mdot
.016 w
.09253 .66553 m
.09163 .6616 L
s
1 .031 0 r
.008 w
.09163 .6616 Mdot
.016 w
.09163 .6616 m
.09081 .65732 L
s
.008 w
.09081 .65732 Mdot
.016 w
.09081 .65732 m
.09005 .65303 L
s
1 .03 0 r
.008 w
.09005 .65303 Mdot
.016 w
.09005 .65303 m
.08934 .64829 L
s
.008 w
.08934 .64829 Mdot
.016 w
.08934 .64829 m
.08866 .64379 L
s
.008 w
.08866 .64379 Mdot
.016 w
.08866 .64379 m
.08799 .63978 L
s
1 .029 0 r
.008 w
.08799 .63978 Mdot
.016 w
.08799 .63978 m
.08732 .63527 L
s
.008 w
.08732 .63527 Mdot
.016 w
.08732 .63527 m
.08668 .63067 L
s
1 .028 0 r
.008 w
.08668 .63067 Mdot
.016 w
.08668 .63067 m
.08598 .62652 L
s
.008 w
.08598 .62652 Mdot
.016 w
.08598 .62652 m
.08523 .62221 L
s
1 .027 0 r
.008 w
.08523 .62221 Mdot
.016 w
.08523 .62221 m
.08446 .61801 L
s
.008 w
.08446 .61801 Mdot
.016 w
.08446 .61801 m
.08363 .61403 L
s
.008 w
.08363 .61403 Mdot
.016 w
.08363 .61403 m
.08282 .60987 L
s
1 .026 0 r
.008 w
.08282 .60987 Mdot
.016 w
.08282 .60987 m
.08201 .60591 L
s
.008 w
.08201 .60591 Mdot
.016 w
.08201 .60591 m
.08123 .60197 L
s
1 .025 0 r
.008 w
.08123 .60197 Mdot
.016 w
.08123 .60197 m
.08054 .59795 L
s
.008 w
.08054 .59795 Mdot
.016 w
.08054 .59795 m
.07993 .59394 L
s
1 .024 0 r
.008 w
.07993 .59394 Mdot
.016 w
.07993 .59394 m
.07941 .59003 L
s
.008 w
.07941 .59003 Mdot
.016 w
.07941 .59003 m
.07898 .58609 L
s
.008 w
.07898 .58609 Mdot
.016 w
.07898 .58609 m
.07864 .5822 L
s
1 .023 0 r
.008 w
.07864 .5822 Mdot
.016 w
.07864 .5822 m
.07838 .57855 L
s
.008 w
.07838 .57855 Mdot
.016 w
.07838 .57855 m
.07817 .57489 L
s
1 .022 0 r
.008 w
.07817 .57489 Mdot
.016 w
.07817 .57489 m
.07799 .57133 L
s
.008 w
.07799 .57133 Mdot
.016 w
.07799 .57133 m
.0778 .56814 L
s
1 .021 0 r
.008 w
.0778 .56814 Mdot
.016 w
.0778 .56814 m
.07759 .56474 L
s
.008 w
.07759 .56474 Mdot
.016 w
.07759 .56474 m
.07735 .56166 L
s
1 .02 0 r
.008 w
.07735 .56166 Mdot
.016 w
.07735 .56166 m
.07705 .55838 L
s
.008 w
.07705 .55838 Mdot
.016 w
.07705 .55838 m
.07666 .55515 L
s
.008 w
.07666 .55515 Mdot
.016 w
.07666 .55515 m
.07617 .55171 L
s
1 .019 0 r
.008 w
.07617 .55171 Mdot
.016 w
.07617 .55171 m
.07559 .54806 L
s
.008 w
.07559 .54806 Mdot
.016 w
.07559 .54806 m
.07493 .54472 L
s
1 .018 0 r
.008 w
.07493 .54472 Mdot
.016 w
.07493 .54472 m
.07422 .54078 L
s
.008 w
.07422 .54078 Mdot
.016 w
.07422 .54078 m
.07351 .53682 L
s
1 .017 0 r
.008 w
.07351 .53682 Mdot
.016 w
.07351 .53682 m
.07281 .53308 L
s
.008 w
.07281 .53308 Mdot
.016 w
.07281 .53308 m
.07213 .52939 L
s
.008 w
.07213 .52939 Mdot
.016 w
.07213 .52939 m
.07152 .52556 L
s
1 .016 0 r
.008 w
.07152 .52556 Mdot
.016 w
.07152 .52556 m
.07101 .5212 L
s
.008 w
.07101 .5212 Mdot
.016 w
.07101 .5212 m
.07062 .51728 L
s
1 .015 0 r
.008 w
.07062 .51728 Mdot
.016 w
.07062 .51728 m
.07037 .51311 L
s
.008 w
.07037 .51311 Mdot
.016 w
.07037 .51311 m
.07025 .50891 L
s
1 .014 0 r
.008 w
.07025 .50891 Mdot
.016 w
.07025 .50891 m
.07029 .50469 L
s
.008 w
.07029 .50469 Mdot
.016 w
.07029 .50469 m
.07048 .50044 L
s
1 .013 0 r
.008 w
.07048 .50044 Mdot
.016 w
.07048 .50044 m
.07081 .49614 L
s
.008 w
.07081 .49614 Mdot
.016 w
.07081 .49614 m
.07126 .49205 L
s
.008 w
.07126 .49205 Mdot
.016 w
.07126 .49205 m
.07179 .48813 L
s
1 .012 0 r
.008 w
.07179 .48813 Mdot
.016 w
.07179 .48813 m
.07238 .48402 L
s
.008 w
.07238 .48402 Mdot
.016 w
.07238 .48402 m
.073 .48049 L
s
1 .011 0 r
.008 w
.073 .48049 Mdot
.016 w
.073 .48049 m
.07363 .47703 L
s
.008 w
.07363 .47703 Mdot
.016 w
.07363 .47703 m
.07426 .47389 L
s
1 .01 0 r
.008 w
.07426 .47389 Mdot
.016 w
.07426 .47389 m
.07485 .47133 L
s
.008 w
.07485 .47133 Mdot
.016 w
.07485 .47133 m
.07538 .46919 L
s
.008 w
.07538 .46919 Mdot
.016 w
.07538 .46919 m
.07584 .46753 L
s
1 .009 0 r
.008 w
.07584 .46753 Mdot
.016 w
.07584 .46753 m
.07621 .46629 L
s
.008 w
.07621 .46629 Mdot
.016 w
.07621 .46629 m
.07649 .46535 L
s
1 .008 0 r
.008 w
.07649 .46535 Mdot
.016 w
.07649 .46535 m
.07667 .46469 L
s
.008 w
.07667 .46469 Mdot
.016 w
.07667 .46469 m
.07678 .46422 L
s
1 .007 0 r
.008 w
.07678 .46422 Mdot
.016 w
.07678 .46422 m
.07686 .46384 L
s
.008 w
.07686 .46384 Mdot
.016 w
.07686 .46384 m
.07695 .46344 L
s
.008 w
.07695 .46344 Mdot
.016 w
.07695 .46344 m
.07708 .46296 L
s
1 .006 0 r
.008 w
.07708 .46296 Mdot
.016 w
.07708 .46296 m
.07727 .46237 L
s
.008 w
.07727 .46237 Mdot
.016 w
.07727 .46237 m
.07753 .46167 L
s
1 .005 0 r
.008 w
.07753 .46167 Mdot
.016 w
.07753 .46167 m
.07787 .46084 L
s
.008 w
.07787 .46084 Mdot
.016 w
.07787 .46084 m
.07829 .46 L
s
1 .004 0 r
.008 w
.07829 .46 Mdot
.016 w
.07829 .46 m
.07878 .459 L
s
.008 w
.07878 .459 Mdot
.016 w
.07878 .459 m
.07933 .45795 L
s
1 .003 0 r
.008 w
.07933 .45795 Mdot
.016 w
.07933 .45795 m
.07988 .45686 L
s
.008 w
.07988 .45686 Mdot
.016 w
.07988 .45686 m
.08048 .45581 L
s
.008 w
.08048 .45581 Mdot
.016 w
.08048 .45581 m
.08103 .45491 L
s
1 .002 0 r
.008 w
.08103 .45491 Mdot
.016 w
.08103 .45491 m
.08156 .45413 L
s
.008 w
.08156 .45413 Mdot
.016 w
.08156 .45413 m
.08204 .4535 L
s
1 .001 0 r
.008 w
.08204 .4535 Mdot
.016 w
.08204 .4535 m
.08244 .45304 L
s
.008 w
.08244 .45304 Mdot
.016 w
.08244 .45304 m
.08274 .45274 L
s
1 0 0 r
.008 w
.08274 .45274 Mdot
.016 w
.08274 .45274 m
.08294 .4526 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0412856 0.0397566 scale
2.49458 17.9932 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0190592 0.0183534 scale
13.2083 46.8044 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0303662 0.0292416 scale
8.53186 29.5134 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0312728 0.0301147 scale
12.6384 30.3752 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.016716 0.016097 scale
40.232 55.9372 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0158582 0.0152709 scale
55.5712 45.0489 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0149513 0.0143976 scale
58.6445 50.5446 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0197787 0.0190462 scale
43.1434 40.502 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0373782 0.035994 scale
22.8106 21.2636 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0224269 0.0215964 scale
39.0254 34.0043 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0247939 0.0238757 scale
35.4103 30.33 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0175319 0.0168827 scale
48.0917 42.5774 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0299025 0.0287952 scale
27.2559 27.2896 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0325855 0.0313788 scale
24.8248 25.6664 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0773286 0.0744649 scale
8.77166 12.0844 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0211443 0.0203613 scale
30.3179 44.1982 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0574215 0.055295 scale
7.43119 16.6543 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool006ioo`<m
k`AooaHmk`moo`X007aoo`00KGoo9cg_47oo1@00Mgoo001XOol]?NlDOol5001bOol006IooblmkaUo
o`@006ioo`00IGoo;cg_7Woo1000JWoo001SOola?NlROol3001WOol0065ooc8mkbIoo`<006Aoo`00
Ggoo7Sg_2Goo1cg_;goo0`00HGoo001MOolA?Nl5Ool8?Nm4Ool2001OOol005]oo`03000mkcg_00Xm
k`=oo`<mke=oo`<005aoo`00F7oo0P003Sg_17oo0Sg_EWoo0P00FWoo001FOol200000goo?Nlmk`09
?Nl9Ool00cg_Oomoo`1FOol2001HOol005Aoo`800003Oolmkcg_00TmkfIoo`8005Ioo`00DWoo0P00
3Cg_JGoo0`00Dgoo001@Ool20002Ool<?Nm]Ool2001AOol004moo`03?Nmoocg_00dmkg1oo`03001o
ogoo04ioo`00CGoo0P003cg_LWoo00<007ooOol0CGoo001;Ool200000goo?Nlmk`0;?NmfOol2001=
Ool004Uoo`800003Oolmkcg_00`mkgUoo`8004]oo`00B7oo00<007oo?Nl03cg_Ngoo0P00BGoo0016
Ool200000goo?Nlmk`0??NmmOol20017Ool004Eoo`03001oocg_014mkh1oo`03001oogoo04Aoo`00
A7oo00<007oo?Nl04Cg_PWoo00<007ooOol0@goo0013Ool00`00?Nlmk`0??Nn6Ool00`00Oomoo`12
Ool0045oo`80010mkhUoo`80049oo`00?goo0P000Woo43g_Rgoo00<007ooOol0?goo000nOol01000
Oomoogoo2Sg_Tgoo0P00?goo000lOol20002Ool;?NnFOol00`00Oomoo`0lOol003]oo`03001oogoo
00`mkiQoo`03001oogoo03]oo`00>Woo00<007oo?Nl033g_VWoo00<007ooOol0>Woo000jOol00`00
?Nlmk`0;?NnLOol2000jOol003Uoo`03000mkcg_00/mkimoo`03001oogoo03Moo`00=goo0P003Cg_
XGoo00<007ooOol0=Woo000fOol00`00Oolmk`09?NnVOol00`00Oomoo`0eOol003Eoo`03001oogoo
00XmkjMoo`03001oogoo03Aoo`00=7oo00<007ooOol02Sg_ZGoo00<007ooOol0<goo000bOol20002
Ool;?NnZOol2000cOol0035oo`03001oogoo009oo`/mkjaoo`03001oogoo031oo`00<7oo00<007oo
Ool00Woo33g_[Goo00<007ooOol0;goo000_Ool00`00Oomoo`03Ool;?Nn_Ool00`00Oomoo`0^Ool0
02ioo`03001oogoo00=oo`/mkk5oo`03001oogoo02eoo`00;Woo00@007ooOomoo`/mkk=oo`03001o
ogoo02eoo`00;Goo00<007ooOol00goo2Cg_]Goo00<007ooOol0;7oo000/Ool00`00Oomoo`03Ool:
?NnfOol00`00Oomoo`0[Ool002]oo`03001oogoo009oo`03?Nmoocg_00TmkkMoo`03001oogoo02Yo
o`00:Woo00<007ooOol00goo2Cg_^goo00<007ooOol0:Goo000YOol00`00Oomoo`04Ool7?NnnOol0
0`00Oomoo`0XOol002Qoo`03001oogoo00Eoo`Dmkl5oo`03001oogoo02Moo`00:7oo00<007ooOol0
17oo1Sg_`Goo00<007ooOol09goo000WOol00`00Oomoo`04Ool7?No2Ool00`00Oomoo`0VOol002Io
o`03001oogoo00Eoo`Pmkl9oo`03001oogoo02Eoo`009Goo00<007ooOol01Goo2Cg_`goo00<007oo
Ool097oo000TOol00`00Oomoo`06Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`Pm
klIoo`03001oogoo02=oo`008goo00<007ooOol01Goo23g_b7oo00<007ooOol08Woo000ROol00`00
Oomoo`05Ool9?No9Ool00`00Oomoo`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025o
o`008Goo00<007ooOol01Goo2Cg_bgoo00<007ooOol087oo000POol00`00Oomoo`06Ool8?No=Ool0
0`00Oomoo`0OOol001moo`03001oogoo00Ioo`Lmkm1oo`03001oogoo01ioo`007goo00<007ooOol0
1Woo1Sg_dGoo00<007ooOol07Woo000NOol00`00Oomoo`06Ool7?NoBOol00`00Oomoo`0MOol001io
o`03001oogoo00Eoo`Pmkm9oo`03001oogoo01eoo`007Goo00<007ooOol01Woo1cg_e7oo00<007oo
Ool077oo000MOol00`00Oomoo`05Ool8?NoDOol00`00Oomoo`0LOol001aoo`03001oogoo00Eoo`Tm
kmEoo`03001oogoo01]oo`0077oo00<007ooOol01Goo23g_eWoo00<007ooOol06goo000KOol00`00
Oomoo`05Ool9?NoGOol00`00Oomoo`0JOol001Yoo`03001oogoo00Eoo`TmkmQoo`03001oogoo01Yo
o`006Woo00<007ooOol01Goo2Cg_fGoo00<007ooOol06Goo000IOol00`00Oomoo`05Ool9?NoKOol0
0`00Oomoo`0HOol001Uoo`03001oogoo00Eoo`Pmkmaoo`03001oogoo01Qoo`0067oo00<007ooOol0
1Goo23g_gWoo00<007ooOol05goo000HOol00`00Oomoo`04Ool8?NoOOol00`00Oomoo`0GOol001Qo
o`03001oogoo00Aoo`Pmkmmoo`03001oogoo01Moo`005goo00<007ooOol017oo2Cg_h7oo00<007oo
Ool05Woo000GOol00`00Oomoo`04Ool8?NoQOol00`00Oomoo`0FOol001Ioo`03001oogoo00Eoo`Lm
kn=oo`03001oogoo01Eoo`005Woo00<007ooOol00Woo2Cg_i7oo00<007ooOol05Goo000EOol00`00
Oomoo`04Ool8?NoUOol00`00Oomoo`0DOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Ao
o`0057oo00<007ooOol01Woo1cg_iWoo00<007ooOol04goo000DOol00`00Oomoo`06Ool6?NoWOol0
0`00Oomoo`0COol001Aoo`03001oogoo00Ioo`HmknMoo`03001oogoo01=oo`004goo00<007ooOol0
1Woo1cg_j7oo00<007ooOol04Woo000COol00`00Oomoo`06Ool6?NoYOol00`00Oomoo`0BOol001=o
o`03001oogoo00Ioo`DmknYoo`03001oogoo019oo`004Woo00<007ooOol01goo1Cg_jgoo00<007oo
Ool04Goo000BOol00`00Oomoo`07Ool5?No[Ool00`00Oomoo`0AOol0019oo`03001oogoo00Ioo`Hm
kn]oo`03001oogoo015oo`004Woo00<007ooOol01Woo1Sg_k7oo00<007ooOol047oo000AOol00`00
Oomoo`07Ool5?No]Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Hmknaoo`03001oogoo011o
o`0047oo00<007ooOol027oo1Sg_kGoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03001oogoo00moo`0047oo00<007ooOol0
27oo1Cg_kWoo00<007ooOol03goo000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool000mo
o`03001oogoo00Uoo`Dmknmoo`03001oogoo00ioo`003goo00<007ooOol02Goo1Cg_kgoo00<007oo
Ool03Woo000?Ool00`00Oomoo`09Ool4?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`@m
ko1oo`03001oogoo00ioo`003goo00<007ooOol02Goo13g_l7oo00<007ooOol03Woo000>Ool00`00
Oomoo`0:Ool4?NoaOol00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo`@mko5oo`03001oogoo00eo
o`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomoo`3oOol00`00Oomoo`0=Ool0
00ioo`03001oogoo0?moo`5oo`03001oogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol0
37oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001o
ogoo00aoo`003Goo00<007ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<007ooOol02goo
0cg_lgoo00<007ooOol037oo000=Ool00`00Oomoo`09Ool6?NobOol00`00Oomoo`0<Ool000eoo`03
001oogoo00Qoo`8mk`Al0003?Nmoogoo009oo`DmknUoo`03001oogoo00aoo`003Goo00<007ooOol0
27oo0Sg_17`01Goo1Sg_j7oo00<007ooOol037oo000=Ool00`00Oomoo`08Ool00cg_O01l0004O004
Ool7?NoXOol00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`03?Nml07`000=l0003?Nmoogoo009o
o`LmknQoo`03001oogoo00]oo`0037oo00<007ooOol027oo00<mkg`0O00017`03Cg_igoo00<007oo
Ool02goo000<Ool00`00Oomoo`08Ool00cg_O01l0003O00??NoVOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Qoo`03On1l07`000=l010mknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo00=o
h7`0O0000g`04Cg_i7oo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00goPO01l0003O003Ool?
?NoSOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03On1l07`0009l0003?Nmoogoo00Ioo`/m
kn9oo`03001oogoo00]oo`0037oo00<007ooOol027oo1G`000<mkgooOol027oo1Sg_iGoo00<007oo
Ool02goo000<Ool00`00Oomoo`07Ool00goPO01l0003O0000cg_Oomoo`09Ool6?NoTOol00`00Oomo
o`0;Ool000aoo`03001oogoo00Moo`03On1l07`0009l0003?Nmoogoo00Uoo`LmknAoo`03001oogoo
00]oo`0037oo00<007ooOol01goo00=oh7`0O0000W`000<mkgooOol02Goo2Cg_hWoo00<007ooOol0
2goo000<Ool00`00Oomoo`07Ool00goPO01l0002O00<Ool:?NoQOol00`00Oomoo`0;Ool000aoo`03
001oogoo00Moo`03On1l07`0009l00aoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol01Woo
00=oh7`0O0000W`037oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`06Ool00goPO01l0002
O00@Ool7?NoOOol00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`03On1l07`0009l011oo`Pmkmio
o`03001oogoo00aoo`003Goo00<007ooOol01Woo00=oh7`0O0000W`047oo23g_gWoo00<007ooOol0
37oo000=Ool00`00Oomoo`06Ool00goPO01l0002O0000cg_Oomoo`0=Ool8?NoNOol00`00Oomoo`0<
Ool000eoo`03001oogoo00Ioo`03On1l07`000=l00moo`Tmkmeoo`03001oogoo00aoo`003Goo00<0
07ooOol01Woo00=oh7`0O00017`03goo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5
O00@Ool8?NoMOol00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`03On1l07`0009l0003?Nmoogoo
00eoo`Xmkm]oo`03001oogoo00aoo`003Goo00<007ooOol01goo00=oh7`0O0000W`000<mkgooOol0
3goo2Cg_fWoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool00goPO01l0002O0000goPOomoo`0@
Ool8?NoJOol00`00Oomoo`0<Ool000ioo`03001oogoo00Ioo`03On1l07`000=l019oo`Lmkm]oo`03
001oogoo00aoo`003Woo00<007ooOol01goo1W`04Goo1Cg_g7oo00<007ooOol03Goo000>Ool00`00
Oomoo`07Ool5O03cOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`03On1l07`0009l0003?Nmo
ogoo0?1oo`03001oogoo00eoo`003Woo00<007ooOol01goo00=oh7`0O0000W`000=oh7ooOol0l7oo
00<007ooOol03Goo000?Ool00`00Oomoo`06Ool00goPO01l0002O0000cg_Oomoo`3_Ool00`00Oomo
o`0>Ool000moo`03001oogoo00Moo`Al008mko1oo`03001oogoo00ioo`003goo00<007ooOol01goo
17`00Sg_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool4O002?No`Ool00`00Oomoo`0>Ool0
011oo`03001oogoo00Ioo`Al008mko1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo17`00Sg_
kgoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5O0000cg_Oomoo`3]Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Ioo`El0003?Nmoogoo0>eoo`03001oogoo00moo`0047oo00<007ooOol01Woo
00=oh7`0O0000g`0kgoo00<007ooOol03goo000AOol00`00Oomoo`05Ool00goPO01l0002O0000cg_
Oomoo`3]Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Ioo`Al008mkneoo`03001oogoo011oo`00
4Goo00<007ooOol01Woo17`00Sg_kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool5O03^Ool0
0`00Oomoo`0@Ool0019oo`03001oogoo00Eoo`Il0>aoo`03001oogoo015oo`004Woo00<007ooOol0
1Goo1G`000=oh7ooOol0jWoo00<007ooOol04Goo000BOol00`00Oomoo`05Ool00goPO01l0002O03]
Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`Al0003?Nmoogoo0>Uoo`03001oogoo019oo`00
4goo00<007ooOol01Goo1G`0jgoo00<007ooOol04Woo000COol00`00Oomoo`05Ool6O03ZOol00`00
Oomoo`0BOol001Aoo`03001oogoo00Aoo`El0003?Nmoogoo0>Moo`03001oogoo01=oo`0057oo00<0
07ooOol017oo00=oh7`0O0000W`000<mkgooOol0fGoo0WjP37oo00<007ooOol04goo000DOol00`00
Oomoo`04Ool00goPO01l0002O0000goPOomoo`3DOol2OZ000gooOZ1nX003OZ0;Ool00`00Oomoo`0C
Ool001Eoo`03001oogoo00=oo`03On1l07`0009l0003?Nmoogoo0=9oo`EnP0EnX0Yoo`03001oogoo
01Aoo`005Goo00<007ooOol017oo17`000<mkgooOol0dWoo1Gj01GjP2Woo00<007ooOol057oo000F
Ool00`00Oomoo`03Ool5O03DOol5OX05OZ09Ool00`00Oomoo`0EOol001Ioo`03001oogoo00=oo`Il
0==oo`EnP0EnX0Uoo`03001oogoo01Eoo`005goo00<007ooOol00Woo1G`0eGoo17j01GjP27oo00<0
07ooOol05Woo000GOol00`00Oomoo`02Ool00goPO01l0002O0000cg_Oomoo`3BOol2OX04ON03OZ08
Ool00`00Oomoo`0FOol001Qoo`05001oogooOomoh004O0000g`POomoo`3BOol6ON02OZ08Ool00`00
Oomoo`0GOol001Qoo`05001oogooOomoh006O23BOol017gP000000000ggP0WjP27oo00<007ooOol0
5goo000HOol00`00Oomoo`02Ool3O207003<Ool2OL001000OL1m`7gP0P0000=mh7jPOZ0027oo00<0
07ooOol05goo000IOol00`00Oomoo`040004O203Ool20039Ool2OL001000OL1m`7g00ggP00<007jP
OZ001goo00<007ooOol067oo000IOol01@00Ool007ooOl001W`P1Goo00<007ooOol0`goo1Gg000@0
07g0OL1m`0Amh003001oogoo00Ioo`03001oogoo01Qoo`006Woo00<007ooOol00Wo01W`P1Goo00<0
07ooOol0`7oo1Wg000<007g0OL000Wg017gP00<007ooOol01Goo00<007ooOol06Goo000IOol00`00
Ool00002Ool00go0O21l8005O205Ool00`00Oomoo`2nOol8OL001000OL1m`7j017gP00<007ooOol0
17oo00<007ooOol06Woo000IOol00`00Ool00002Ool2Ol07O205Ool00`00Oomoo`2mOol8OL000`00
OL1nP005ON000`00Oomoo`04Ool00`00Oomoo`0JOol001Qoo`06001oogooOol007oo17o01W`P17oo
00<007ooOol0_Goo27g00P0000AnP7gPON1mh08000Ioo`03001oogoo01]oo`0067oo00H007ooOomo
o`00Ool5Ol06O204Ool00`00Oomoo`2kOol40002OL03Ool700000ggPOomoo`04Ool00`00Oomoo`0K
Ool001Moo`03001oogoo00=oo`03001oogo000Ao`0Il80=oo`03001oogoo0;Yoo`03001m`7g0009m
`0800005Ool00000OomnP002ON001000ON1mh0001Goo00<007ooOol077oo000GOol00`00Oomoo`03
Ool00`00Oomo`004Ol000cg_O21l8003O203Ool00`00Oomoo`2jOol00`00OL1m`003OL000goo0000
0002Ool00gj0ON1mh003ON000goo001oo`03Ool00`00Oomoo`0LOol001Moo`03001oogoo00Aoo`03
001o`7nP00=oX003?Nml87`P00=l80=oo`03001oogoo0;Uoo`04001oogg0OL02OJ0017g0Ool00000
0Woo0`000ggP0Woo00@007ooOol001moo`005goo00<007ooOol017oo00<007o0Oj0017nP1G`P0goo
00<007ooOol0^Goo00<007ooOJ0017fP00=oo`0000000`000WgP0`000Woo00@007ooOol001moo`00
5goo00<007ooOol01Goo00<mkgnPOj000gnP1G`P0goo00<007ooOol0^7oo00<007ooOJ001GfP00D0
07oo000007h000Emh0800004Ool007oo000POol001Moo`03001oogoo00Eoo`03001oX7nP00AoX0El
809oo`03001oogoo0;Uoo`03001mX7fP00=mX003OL00000000800003OP1mh7gP00=mh004001oo`00
Ool2000POol001Moo`03001oogoo00Ioo`IoX0Il8003Ool007oo0;]oo`03001mX7fP009mX006Ool0
07oo001n`7h017gP0Woo0P0000=oo`00Ool087oo000GOol00`00Oomoo`07Ool5Oj06O2000`00Oomo
o`2jOol00gfP001mX0090004OP000goo00000002000ROol001Qoo`03001oogoo00Moo`03?NmoX7nP
009oX0El8003001oogoo0;Yoo`03OJ00000000D00005OomnH000OP000003OP000goo001oo`02000R
Ool001Qoo`8000Qoo`03001oX7nP009oX0Al8003001l87oo0;Yoo`03OJ0007fP00=mX09oo`800004
OV000000OP040002Ool2000ROol001Yoo`03001oogoo00Ioo`EoX0=l8003001l87`P0;Yoo`03OJ00
07fP009mX0=oo`05001nH000001n00040002Ool2000SOol001]oo`03001oogoo00Ioo`AoX003O200
000000=l8;Yoo`03001mX7fP009mX0Aoo`03001n87hP0080009n80@002Aoo`006goo0P0027oo0WnP
0P001W`P^7oo00<007fPOJ000gfP17oo00=n8000OR000WhP0P0000=oo`0000009Goo000MOol20006
Ool20002Oj06O2000cg_Oomoo`2dOol00gfP001mX003OJ000goo0000000300000ghP001n8002OR00
17oo000000009Goo000OOol600000goo000mk`02Oj06O203?NnaOol40004OJ000`00Oomoo`03OR07
00000goo001oo`0TOol002Moo`03001oX7nP00Ml80<mkjioo`80009oo`04001mX0000002OJ000`00
Oomn8005OR001000OV1oo`000Woo00<007ooOol08goo000XOol01000OomoX7nP1W`P0Sg_[7oo0P00
0goo00=mX000OJ000WfP0P0000=ooghPOR001WhP0P000goo00<007ooOol08goo000YOol00`00Oj1o
X006O203?NnZOol00`00Oomoo`03Ool00gfP001mX002OJ000goo00000007OR000gk0001oo`03Ool0
0`00Oomoo`0SOol002Yoo`03001oog`P00Ml8003?Nmoogoo0:Qoo`03001oogoo00=oo`03OJ0007fP
009mX003Ool0000000In8003OV00000000Aoo`03001oogoo02=oo`00:Woo00<007ooOol027`P00<m
kgooOol0YWoo00<007oo00001`000WfP00Aoo`00OT0000An8004OV1n`0000004Ool00`00Oomoo`0S
Ool002]oo`03001oognP00Ql8003?Nmoogoo0:Eoo`8000Aoo`9mX003001mX000009oo`03001n@000
00=n8005OT1nH000Ool00003Ool00`00Oomoo`0TOol002aoo`04001oogoo?Nl7O22VOol20004Ool4
OH002000OJ000000O/0007i00002OT001Gk0001oogoo00000goo00<007ooOol097oo000]Ool00`00
Oolmk`09O22TOol00`00Oomoo`03Ool4OH001000O/1n`7k010000Wk000@007oo000000=oo`03001o
ogoo02Eoo`00;Woo00D007ooOolmkgnP00Ml8:=oo`03001oogoo00=oo`EmP004001n`7k00002O/05
0005Ool00`00Oomoo`0UOol002ioo`06001oogooOolmkgnP27`PX7oo00<007oo000017oo1Gf000Un
`000O/1n`000O/0007oo00001Goo0P00:7oo000_Ool01P00Oomoogoo?NmoX0Ul89ioo`03001oo`00
00=oo`ImP09n`0@00003Ool007oo00Aoo`03001oogoo02Qoo`00<7oo00D007ooOomoocg_00]l89]o
o`04001oogoo0003Ool4OF000gf0O/1n`003O/0400000goo00000002000[Ool0035oo`03001oogoo
009oo`9oX0Ul89Yoo`05001oogooOol00006OF000gf0O/1n`003Ool20002Ool00`00Oomoo`0]Ool0
039oo`80009oo`9oX0Yl8003O41oogoo09Ioo`04001oogooOF020005OF02O/03Ool3000bOol003Ao
o`03001oogoo00=oX0Ul8003O41oogoo09Eoo`03001mH7eP00=mH0<0009mH003O/1oogoo0080009o
o`03001oogoo031oo`00=Goo00@007ooOolmk`=oX0Il809l@9Moo`03001mH7eP00ImH0H000=oo`03
001oogoo031oo`00=Woo00@007ooOomoo`AoX003O41l87`P00=l@9Ioo`03OF0007eP00MmH09n`09o
o`05001oogooOol0000cOol003Moo`04001oogooOol4Oj06O42DOol3OF000`00OF1mH003OF02O/03
Ool01@00Oomoogoo0000=7oo000hOol01000Oomoogoo17nP1Wa0MWoo2P004Woo1GeP00@007ePOF1n
`0Eoo`03001oogoo009oo`03001oogoo039oo`00>Goo0P000Woo00<mkgnPOj001Wa0LWoo10002Woo
0P003goo1geP0P0000Anh7ooOomoo`8000Aoo`03001oogoo03=oo`00>goo00@007ooOolmk`9oX0Il
@0Aoo`@006Moo`80011oo`<000]oo`QmH09nh0800003Ool007oo00=oo`8003Ioo`00?7oo00D007oo
OolmkgnP00Ml@003Ool0000000Aoo`<006=oo`03001oogoo01=oo`03001oogoo00Moo`QmH09nh0=o
o`H003Qoo`00?Goo00D007ooOolmkgnP00El@0800004Ool000000005Ool00`00Oomoo`1NOol2000G
Ool00`00Oomoo`05Ool8OF02O^03Ool00`00Oomoo`0lOol003ioo`80008mk`06Oj1l@7a0O40007a0
0P0000<mkgooOol00P0017oo00<007ooOol0G7oo00<007ooOol067oo00<007ooOol00Woo0We01geP
0WkP0Woo0P00?goo0010Ool00`00Oomoo`03O4020002O402?Nl3Ool00`00Oomoo`02Ool00`00Oomo
o`1JOol00`00Oomoo`0JOol200000gooOD1m@002OD05OF04Ool00`00Oomoo`0oOol0045oo`800004
Ooml@0000005O4001Cg_Oomoogoo00000goo00<007ooOol0FGoo00<007ooOol077oo00=m@000OD00
17e00geP00=nh7ooOol00P00@Woo0013Ool01000Ool000001Wa00WmP00=oo`00Ool00goo00<007oo
Ool0Egoo00<007ooOol05goo1Cg_0ge000@007e0OD1m@09mH005O^1oogooOol00014Ool004Aoo`<0
00Ul@003001oogoo009oo`03001oogoo05Moo`03001oogoo01Moo`<mk`Im@004001m@7ePOF04Ool0
0`00Oomoo`13Ool004Eoo`8000Ul@003001l@7oo009oo`03001oogoo05Ioo`03001oogoo01Qoo`8m
k`Qm@003001nh7oo00=oo`03001oogoo04Aoo`00AGoo0P0000=oP7a0O4001Wa000H007a0O41l@7oo
000ROol7000_Ool00`00Oomoo`0GOol2?Nl9OD001000Oomoogoo0P00Agoo0015Ool00`00Ool00002
Oh05O4000`00O41l@003O4000`00Oomoo`02?NlKOol30007Ool2000/Ool00`00Oomoo`0FOol2?Nl9
OD02O^0017oo00000000BGoo0015Ool01`00Ool00000OolmkgmP009l@003001l@7a000Al@004001l
@3g_O402?NlHOol2000<Ool3000YOol00`00Oomoo`0EOol2?Nl9OD000gkPOomoo`02001;Ool004Io
o`03001oogoo00D000Ml@003001l@7a0009l@08mkaEoo`80015oo`8002Ioo`03001oogoo01Aoo`8m
k`03O`1m@7e000Mm@006O^1oo`00001oo`00Bgoo0016Ool00`00Oomoo`05Ool2Of04O4000`00O41l
@008O40AOol00`00Oomoo`0COol00`00Oomoo`0SOol00`00Oomoo`04Ool5000:Ool2?Nl00gl0OD1m
@006OD0017kPOomoo`000goo00<007ooOol0BGoo0017Ool00`00Oomoo`05Ool01@00Of1oH7a00000
37a000<mkga0Ool037oo00<007oo00000`004Goo00<007ooOol08Woo00<007ooOol017oo00<007oo
Ool00goo0P0017oo0P0000=oocg_O`002Ge000Anh7ooOol000Eoo`03001oogoo04Qoo`00B7oo00<0
07ooOol01Goo0`0047a000<mkgooO40027oo0`0000Aoocg_?Nmoo`80011oo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo00Ioo`@00004Oolmk`000009OD02Ool20006Ool00`00Oomoo`18Ool0
04Uoo`P00004Ool000000002Of0AO405Ool200000goo?Nlmk`03?Nl2Ool2000?Ool00`00Oomoo`0P
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000?Nlmkcg_0WdP00=m@000OD0017e00Wl00`0027oo
00<007ooOol0B7oo001EOol200000gooOf1oH00?O4000cg_O41oo`020002Ool5?Nl4Ool00`00Oomo
o`0=Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`02Ool2O<000gooO`1l`0020005O>00
0gdPOD000004OD02000;Ool00`00Oomoo`18Ool005Moo`80009oo`9oH0ml@08000Lmk`Aoo`03001o
ogoo00eoo`03001oogoo01moo`03001oogoo009oo`03001oogoo00ElX09l`003001l`00000Al`09m
8005001m@7e0OD00000=Ool00`00Oomoo`18Ool005Uoo`8000=oo`9oH0]l@006001l@000O40mkgaP
1Cg_17oo00<007ooOol03Goo00<007ooOol07Woo00<007ooOol00WbP00<007bPO:001GbP0Wc000<0
07c0000017c000Em87e0001m@00000moo`03001oogoo04Qoo`00Fgoo0`000goo0gmP1ga00P000ga0
0WaP0gm000=lH7ooOol00Woo00<007ooOol03Goo00<007ooOol077oo0WbP00<007ooO:000WbP00<0
07bPO:001GbP0Wc000<007c0000017c000=m87e000004Goo00<007ooOol0B7oo001NOol30003Ool2
Of04O4000`00O4000004O406O603Ool00gb0001oo`0=Ool00`00Oomoo`0EOol2O:04Ool3O:000`00
O:1lX002O:000`00O:1lX005O:03O<000`00O<1l`003O<000ge0Ool0000AOol00`00Oomoo`18Ool0
065oo`<0009oo`=oH004O40007a00003O40;O6000`00O61lP007Ool2O:04Ool01@00OomoogooO:00
2Woo0WbP0goo0Sg_2WbP00<007bPO:000gbP00<007bPO:000gbP17c000<003g_00000goo0P004Woo
00<007ooOol0B7oo001TOol30002Ool017mP000007aP0Wa037aP00@007aPO81lP0Eoo`MlX003001l
X7bP00=lX0Qooa9lX003001lX7bP00AlX003001lX7c000=l`004Ob000000Ool5000DOol00`00Oomo
o`18Ool006Moo`D00003OomoH7mP00alH003001lH7b000ElP0QlX003001lX7bP01elX003001lX7bP
009lX0=o80H001aoo`03001oogoo04Qoo`00JWoo0`000goo00AoH7m0Od1o@0MlH003001lH7b000El
P0QlX003001lX7bP01elX003Ob0007lP00Ao80<00003Oolmkgoo01aoo`03001oogoo04Uoo`00Jgoo
00<007oo000010000Woo1Gm000AlH000O61lH0IlP0QlX003001lX7bP01IlX0Qo80H0029oo`03001o
ogoo04Uoo`00Jgoo00<007ooOol017oo10000gm000<007m0Od001gb017bP0gm000@007lPOb1o80il
X0Mo80Eoo`H002Ioo`03001oogoo04Uoo`00Jgoo0P002Woo0`0047m000<007lPOb0047lP1Goo1P00
1Woo00<007ooOol08Woo00<007ooOol0BWoo001/Ool30008Ool20004Ool00`00Od1o@009Od000`00
Od1o@002Od05?Nl5Ool:000<Ool00`00Oomoo`0QOol00`00Oomoo`1;Ool006aoo`04001oogoo0005
Ool2000;Ool7Od0?000GOol00`00Oomoo`0OOol00`00Oomoo`1<Ool006eoo`03001oogoo00D001Ao
o`03001oogoo02=oo`03001oogoo01moo`03001oogoo04aoo`00KGoo00<007ooOol067oo00<007oo
Ool09Goo00<007ooOol07Goo00<007ooOol0CGoo001^Ool00`00Oomoo`0GOol00`00Oomoo`0VOol0
0`00Oomoo`0KOol00`00Oomoo`1>Ool006ioo`03001oogoo01Ioo`03001oogoo02Qoo`8001Yoo`03
001oogoo04moo`00Kgoo00<007ooOol057oo00<007ooOol0:goo00<007ooOol05Goo0P00DWoo001`
Ool2000BOol2000_Ool2000DOol00`00Oomoo`1BOol0079oo`8000ioo`8003=oo`80011oo`8005Eo
o`00M7oo0P002Woo0P00=goo0P002Woo1000Egoo001fOol400000goo00000003000kOol:001KOol0
07Yoo`03001oogoo0:=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00T7oo00<007ooOol0SGoo
002=Ool01000Oomoo`00Sgoo002=Ool4002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.828, 1.30024, \
1.35024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.5 0.00280112 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(8)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.5 g
.015 w
.08438 .39535 m
.08448 .39522 L
.08463 .39503 L
.08481 .39476 L
.08501 .39442 L
.08522 .39398 L
.08542 .39344 L
.08562 .39282 L
.08581 .39214 L
.08602 .39138 L
.08626 .39053 L
.08654 .38961 L
.08686 .38868 L
.08716 .38771 L
.08743 .38674 L
.08772 .38582 L
.088 .38496 L
.08829 .3841 L
.08859 .38322 L
.08891 .38231 L
.08923 .38135 L
.08951 .38041 L
.08973 .37941 L
.08987 .37835 L
.08993 .37722 L
.0899 .37612 L
.08981 .3749 L
.08971 .3737 L
.08963 .37248 L
.08956 .37117 L
.08951 .36984 L
.0895 .36862 L
.0895 .36741 L
.08949 .36629 L
.08949 .36529 L
.08952 .36442 L
.08958 .36366 L
.08969 .363 L
.08983 .3624 L
.09 .36179 L
.09019 .36113 L
.09037 .36037 L
.09055 .35951 L
.09073 .3585 L
.09096 .35732 L
.09126 .35621 L
.09164 .35488 L
.0921 .35349 L
.09264 .35185 L
.09322 .35031 L
Mistroke
.09382 .34854 L
.09442 .34661 L
.09499 .3448 L
.09554 .34293 L
.09606 .3411 L
.09658 .33931 L
.09711 .33785 L
.09765 .33638 L
.09819 .33506 L
.09867 .33394 L
.09908 .3329 L
.09941 .33207 L
.09966 .3314 L
.09987 .33089 L
.10005 .33055 L
.10024 .3304 L
.10045 .33039 L
.10063 .3305 L
.10076 .33068 L
.10083 .33086 L
.10083 .33098 L
.10076 .33099 L
.10062 .33085 L
.10043 .33056 L
.10021 .3301 L
.09997 .3295 L
.09971 .32876 L
.09945 .32793 L
.09919 .3271 L
.09893 .32618 L
.09868 .32521 L
.09844 .32421 L
.09823 .32335 L
.09807 .32258 L
.09794 .32197 L
.09785 .32156 L
.09779 .32142 L
.09776 .32155 L
.09778 .32191 L
.09782 .32242 L
.09787 .32301 L
.09794 .3236 L
.09806 .32412 L
.09823 .32454 L
.09845 .32484 L
.09873 .32496 L
.09906 .3249 L
.09944 .32466 L
.09988 .32423 L
.10037 .32364 L
Mistroke
.1009 .32294 L
.10147 .32212 L
.10202 .3212 L
.10254 .32026 L
.10305 .3194 L
.10353 .31868 L
.10397 .31807 L
.10439 .31754 L
.10479 .31708 L
.10519 .31666 L
.1056 .31625 L
.10604 .31581 L
.10652 .3153 L
.10703 .31468 L
.10757 .31393 L
.10816 .31302 L
.1088 .31191 L
.10946 .31073 L
.11008 .30929 L
.1107 .30767 L
.11132 .30609 L
.11189 .30436 L
.11238 .30262 L
.11278 .30089 L
.1131 .29934 L
.11332 .29788 L
.11347 .29659 L
.11356 .29553 L
.11358 .29464 L
.11356 .29388 L
.11352 .29328 L
.11346 .29282 L
.1134 .29252 L
.11333 .29236 L
.11327 .29233 L
.11321 .29241 L
.11316 .29257 L
.11312 .29275 L
.11309 .29292 L
.11309 .29304 L
.11315 .2931 L
.11331 .29307 L
.11361 .29294 L
.11404 .29268 L
.11463 .29229 L
.11536 .29178 L
.11625 .29112 L
.11731 .29033 L
.11842 .28943 L
.11967 .28847 L
Mistroke
.12087 .28743 L
.12212 .28636 L
.12336 .28532 L
.12444 .28444 L
.12548 .28368 L
.12644 .28305 L
.12728 .28255 L
.12797 .28215 L
.12853 .28182 L
.129 .28149 L
.12937 .28114 L
.12968 .28071 L
.12996 .28019 L
.13026 .27956 L
.13061 .27882 L
.131 .27794 L
.13143 .27705 L
.13189 .27607 L
.13238 .27505 L
.13287 .27401 L
.13336 .27304 L
.13384 .27214 L
.13429 .27135 L
.1347 .27075 L
.13507 .27031 L
.13539 .26998 L
.13564 .26973 L
.13582 .2695 L
.13594 .26922 L
.13603 .26883 L
.1361 .26829 L
.13619 .26761 L
.13631 .2668 L
.13647 .26592 L
.13664 .26513 L
.13684 .26407 L
.13706 .26307 L
.13727 .26199 L
.13747 .26083 L
.13764 .25958 L
.13778 .25835 L
.13789 .25707 L
.13801 .25573 L
.13814 .25434 L
.1383 .25308 L
.13846 .25161 L
.13867 .25012 L
.13892 .24856 L
.13923 .24694 L
.13964 .24518 L
Mistroke
.14014 .24367 L
.14076 .24217 L
.1415 .24071 L
.14228 .23935 L
.14313 .23811 L
.14402 .23692 L
.14494 .23575 L
.14581 .23462 L
.14671 .23346 L
.1476 .23233 L
.14857 .23124 L
.14952 .23012 L
.15056 .22897 L
.15171 .2278 L
.15289 .22663 L
.15413 .22539 L
.1554 .22417 L
.15654 .22293 L
.15766 .22171 L
.15872 .22053 L
.15972 .21954 L
.16067 .21854 L
.16146 .21763 L
.16215 .21692 L
.1627 .2163 L
.16311 .21577 L
.16339 .21532 L
.16351 .21493 L
.16352 .21458 L
.16346 .21426 L
.16339 .21391 L
.16332 .21351 L
.16328 .213 L
.16326 .21242 L
.16326 .21185 L
.16324 .21139 L
.16318 .21101 L
.16308 .21078 L
.16294 .21077 L
.16275 .21098 L
.16251 .21144 L
.16224 .21211 L
.16195 .21296 L
.16165 .21384 L
.16137 .21496 L
.1611 .21598 L
.16088 .217 L
.16072 .21793 L
.16066 .21869 L
.16071 .21926 L
Mistroke
.16091 .21961 L
.16125 .21977 L
.16173 .2198 L
.16232 .21974 L
.16302 .21964 L
.1638 .21953 L
.16461 .21946 L
.16534 .21944 L
.16601 .21945 L
.16657 .21947 L
.16697 .21947 L
.16721 .21948 L
.16727 .21947 L
.16717 .21944 L
.16698 .21938 L
.16672 .21929 L
.16633 .21918 L
.16586 .21906 L
.16527 .21897 L
.16457 .21895 L
.1638 .21902 L
.16296 .21921 L
.16206 .21956 L
.1611 .22009 L
.16008 .2208 L
.15901 .22174 L
.15802 .22285 L
.15693 .22418 L
.15568 .22572 L
.15413 .22738 L
.15273 .22902 L
.15127 .23076 L
.14976 .23258 L
.14833 .23433 L
.14687 .23593 L
.14544 .23751 L
.14415 .23906 L
.14295 .24047 L
.14174 .24189 L
.14051 .24335 L
.13927 .24489 L
.1381 .24641 L
.137 .24804 L
.13592 .24983 L
.13488 .25177 L
.13392 .25363 L
.13302 .25572 L
.13217 .25774 L
.13136 .25981 L
.13065 .26173 L
Mistroke
.13006 .2634 L
.12958 .2649 L
.12923 .2662 L
.12897 .26717 L
.12877 .26794 L
.12859 .26855 L
.12841 .26902 L
.12819 .26938 L
.12788 .26971 L
.12747 .27006 L
.12697 .27042 L
.12639 .27082 L
.12573 .27127 L
.12509 .27178 L
.12428 .27246 L
.1235 .27321 L
.12264 .27409 L
.12172 .27509 L
.12078 .27618 L
.11987 .27735 L
.119 .27861 L
.11823 .27984 L
.11745 .28115 L
.1167 .2825 L
.11598 .28389 L
.11528 .28523 L
.11457 .28668 L
.11392 .28825 L
.11341 .28981 L
.11302 .29131 L
.11269 .29276 L
.11239 .2942 L
.11208 .29539 L
.11172 .29664 L
.11124 .29777 L
.11062 .29899 L
.10995 .30028 L
.10908 .30152 L
.10808 .3028 L
.107 .3041 L
.10597 .30542 L
.10488 .30675 L
.10369 .30799 L
.10243 .30926 L
.10117 .31056 L
.10008 .31194 L
.09911 .31324 L
.09828 .3146 L
.09758 .31601 L
.09701 .31745 L
Mistroke
.09655 .31882 L
.09619 .32016 L
.09591 .32153 L
.09569 .32297 L
.09552 .32443 L
.09537 .32594 L
.09524 .32751 L
.09508 .32907 L
.0949 .33049 L
.0947 .33178 L
.09451 .33292 L
.09433 .33392 L
.09413 .3348 L
.09389 .33553 L
.09362 .33618 L
.09333 .33676 L
.09303 .3373 L
.09274 .33784 L
.09247 .33842 L
.09221 .33908 L
.09195 .33988 L
.09169 .34087 L
.09142 .34199 L
.0911 .34328 L
.09072 .34479 L
.09028 .34661 L
.0898 .34849 L
.08933 .35058 L
.08888 .35285 L
.08848 .35486 L
.08811 .35718 L
.08775 .35927 L
.08741 .36153 L
.08708 .36398 L
.08674 .36645 L
.08641 .36865 L
.0861 .37091 L
.08582 .37331 L
.08559 .37576 L
.08541 .37783 L
.08524 .38005 L
.08507 .38216 L
.08492 .38421 L
.08477 .38618 L
.08464 .38791 L
.08451 .38949 L
.08444 .39082 L
.08441 .39195 L
.0844 .39287 L
.08442 .3936 L
Mistroke
.08445 .39418 L
.08447 .39463 L
.08447 .39502 L
.08447 .39544 L
.08446 .39591 L
.08445 .39647 L
.08444 .39715 L
.08443 .39796 L
.08441 .3988 L
.08439 .39975 L
.08438 .40078 L
.08436 .40187 L
.08434 .40297 L
.08432 .40391 L
.08431 .40479 L
.0843 .40556 L
.08429 .4062 L
.08428 .40668 L
.08427 .40697 L
Mfstroke
.0843 .40668 m
.08431 .40651 L
.08431 .40629 L
.08429 .40601 L
.08426 .40564 L
.08422 .40537 L
.08421 .40494 L
.08422 .4045 L
.08427 .40399 L
.08436 .4033 L
.08451 .40262 L
.08473 .40208 L
.08498 .40132 L
.08526 .40059 L
.08553 .39979 L
.08578 .39891 L
.08603 .39786 L
.08628 .39697 L
.08654 .39605 L
.08679 .39498 L
.087 .39377 L
.08714 .39255 L
.08722 .39156 L
.08725 .39047 L
.08726 .38935 L
.08724 .38838 L
.08721 .38742 L
.0872 .38652 L
.08721 .38576 L
.08722 .38514 L
.08723 .38461 L
.08723 .38416 L
.08723 .38381 L
.08724 .38357 L
.08724 .38344 L
.08724 .38337 L
.08724 .38336 L
.08724 .38339 L
.08724 .38345 L
.08724 .38353 L
.08724 .3836 L
.08724 .38362 L
.08724 .38363 L
.08724 .38363 L
.08723 .38364 L
.08723 .38368 L
.08723 .38375 L
.08723 .38382 L
.0872 .38385 L
.08716 .38382 L
Mistroke
.08713 .38373 L
.08712 .38356 L
.08714 .38329 L
.0872 .38293 L
.08731 .3825 L
.08747 .38204 L
.08768 .38156 L
.08794 .38107 L
.08825 .3806 L
.08859 .38012 L
.08888 .37965 L
.08913 .37925 L
.08937 .37895 L
.08961 .37881 L
.08978 .37885 L
.08982 .37906 L
.08972 .3794 L
.08952 .37983 L
.08926 .38034 L
.08897 .38086 L
.08865 .38125 L
.08835 .38152 L
.08806 .38185 L
.0878 .38224 L
.0876 .38265 L
.08744 .38306 L
.08732 .38344 L
.08724 .38383 L
.08718 .38435 L
.08708 .38507 L
.08694 .38601 L
.08675 .38715 L
.08648 .38843 L
.08625 .38971 L
.08595 .39142 L
.08567 .39365 L
.08542 .39534 L
.08515 .3977 L
.08487 .3996 L
.08461 .40164 L
.0844 .40381 L
.08427 .40532 L
.08419 .40693 L
.08414 .40844 L
.08413 .40944 L
.08415 .41026 L
.08417 .41091 L
.08419 .41137 L
.08419 .41164 L
Mfstroke
.11421 .46895 m
.11439 .46905 L
.11462 .46919 L
.1149 .46936 L
.11523 .46956 L
.11562 .4698 L
.11603 .47009 L
.11655 .4705 L
.11707 .47097 L
.11765 .47155 L
.11831 .47227 L
.11899 .47305 L
.11961 .47379 L
.12027 .47464 L
.12087 .47549 L
.12145 .47634 L
.12199 .47716 L
.1225 .47794 L
.12298 .47859 L
.12341 .47917 L
.1238 .47968 L
.12411 .48007 L
.12431 .48033 L
.1244 .48048 L
.12438 .48059 L
.1243 .48075 L
.12419 .481 L
.12409 .48133 L
.12404 .48176 L
.12408 .48229 L
.12425 .48291 L
.12456 .48357 L
.12501 .48426 L
.12557 .48494 L
.12624 .48559 L
.12696 .48617 L
.12764 .48666 L
.12833 .48705 L
.12902 .4873 L
.12975 .48744 L
.13039 .48749 L
.13097 .48749 L
.13148 .4875 L
.13191 .48757 L
.13226 .48774 L
.13254 .48801 L
.1328 .48838 L
.13303 .48876 L
.13327 .48918 L
.13349 .48962 L
Mistroke
.13369 .49002 L
.13385 .49043 L
.13396 .49081 L
.134 .49115 L
.13395 .49143 L
.13382 .4916 L
.13361 .49166 L
.13333 .49165 L
.13301 .49159 L
.13268 .49151 L
.13236 .49147 L
.13209 .49156 L
.13189 .49184 L
.13177 .49233 L
.13173 .493 L
.13178 .49384 L
.13191 .49482 L
.13209 .49591 L
.13232 .49689 L
.13256 .49792 L
.13277 .49894 L
.13298 .49994 L
.13314 .5009 L
.13331 .5016 L
.13347 .50228 L
.13362 .50283 L
.13375 .50328 L
.13388 .50371 L
.13404 .50418 L
.13426 .50479 L
.13454 .50558 L
.13492 .50658 L
.13538 .50763 L
.13592 .50887 L
.13652 .51027 L
.13717 .51183 L
.13782 .51333 L
.13837 .5147 L
.13891 .51605 L
.13937 .51713 L
.13982 .51809 L
.14026 .51889 L
.14069 .51951 L
.14113 .51995 L
.14158 .52025 L
.14205 .52047 L
.14254 .52062 L
.143 .52074 L
.14346 .52085 L
.1439 .52097 L
Mistroke
.14438 .52116 L
.14489 .52138 L
.14538 .52161 L
.14581 .5218 L
.14613 .52193 L
.1463 .52197 L
.14632 .52189 L
.14621 .52168 L
.146 .52137 L
.14571 .52101 L
.14538 .52065 L
.14503 .52031 L
.1447 .52006 L
.14438 .51994 L
.14409 .51998 L
.14384 .52025 L
.14367 .52081 L
.14358 .5217 L
.14358 .52293 L
.14365 .52439 L
.14376 .52607 L
.14392 .52806 L
.1441 .53035 L
.14431 .53244 L
.14453 .5349 L
.14477 .53705 L
.14504 .53929 L
.1453 .54152 L
.14557 .5433 L
.14584 .54492 L
.1461 .54633 L
.14632 .54748 L
.14652 .54833 L
.1467 .54897 L
.14689 .54942 L
.14707 .54971 L
.14724 .5499 L
.14739 .55002 L
.14747 .55007 L
.1475 .55004 L
.14748 .54995 L
.14743 .54983 L
.14737 .5497 L
.14734 .54961 L
.14734 .54959 L
.14739 .54968 L
.14751 .54986 L
.1477 .55014 L
.148 .55052 L
.14841 .551 L
Mistroke
.14893 .55155 L
.14955 .55217 L
.15027 .55283 L
.15108 .55359 L
.15192 .55442 L
.15282 .55527 L
.15376 .55611 L
.15469 .5569 L
.15554 .55763 L
.15636 .55835 L
.15712 .55904 L
.1578 .55971 L
.15838 .56038 L
.15885 .56106 L
.15922 .56179 L
.1595 .56255 L
.15969 .5633 L
.1598 .56396 L
.15984 .56449 L
.1598 .56494 L
.15969 .56527 L
.15949 .56546 L
.15921 .56548 L
.15888 .56534 L
.15851 .56505 L
.15817 .56465 L
.15787 .56418 L
.15762 .56367 L
.15747 .56312 L
.15747 .56258 L
.15767 .56211 L
.15809 .56175 L
.15876 .56149 L
.15962 .56133 L
.16074 .56124 L
.16203 .56121 L
.16355 .56121 L
.16511 .56122 L
.16675 .56122 L
.16815 .56119 L
.1695 .56115 L
.17054 .56111 L
.17134 .5611 L
.17182 .56111 L
.17193 .56115 L
.17169 .5612 L
.17118 .56125 L
.17044 .56128 L
.16952 .56132 L
.1686 .56137 L
Mistroke
.16761 .56143 L
.16655 .56147 L
.16553 .56146 L
.16466 .56135 L
.16396 .56109 L
.16343 .56062 L
.16301 .55994 L
.16267 .55901 L
.16236 .55779 L
.16205 .55624 L
.16168 .55436 L
.16119 .5525 L
.16058 .55028 L
.15984 .54769 L
.15897 .54518 L
.15809 .54247 L
.15707 .53958 L
.15598 .53682 L
.1549 .53423 L
.1538 .53177 L
.15273 .52937 L
.15179 .52756 L
.15098 .52588 L
.1503 .52448 L
.14978 .52347 L
.14942 .52264 L
.14918 .52202 L
.14898 .5216 L
.14877 .52132 L
.1485 .52115 L
.1481 .52106 L
.14751 .521 L
.1467 .52095 L
.14565 .52087 L
.14448 .52073 L
.14307 .52052 L
.14144 .52022 L
.13966 .51987 L
.13802 .51949 L
.13636 .5191 L
.13475 .51874 L
.13329 .51844 L
.13207 .51816 L
.13112 .51793 L
.13039 .51769 L
.12989 .51739 L
.1296 .51696 L
.1295 .51647 L
.12958 .516 L
.12976 .51539 L
Mistroke
.13003 .51468 L
.13035 .51384 L
.13066 .51281 L
.13094 .51168 L
.1311 .51036 L
.1311 .50879 L
.13094 .50702 L
.13068 .50518 L
.13034 .50339 L
.12996 .50148 L
.12956 .49993 L
.12916 .49844 L
.12879 .49729 L
.12848 .49634 L
.12822 .49559 L
.12804 .49517 L
.12793 .49492 L
.12789 .49481 L
.12792 .49482 L
.12803 .495 L
.12819 .49531 L
.12839 .4957 L
.12858 .49612 L
.12876 .49648 L
.12891 .49676 L
.12901 .49691 L
.12907 .49693 L
.12907 .49679 L
.12905 .49647 L
.12902 .49606 L
.129 .4956 L
.12901 .49512 L
.12902 .49463 L
.12904 .49415 L
.12906 .49369 L
.12908 .49323 L
.12914 .49279 L
.12928 .49241 L
.1295 .49212 L
.12972 .49196 L
.12988 .49191 L
.12994 .49194 L
.12986 .49201 L
.1296 .49208 L
.12902 .49209 L
.12805 .492 L
.12672 .49178 L
.12504 .49143 L
.12299 .49099 L
.12101 .49047 L
Mistroke
.11853 .48989 L
.1159 .48931 L
.11321 .48872 L
.11041 .48815 L
.1077 .48761 L
.10474 .48712 L
.10239 .48667 L
.10015 .48627 L
.09785 .4859 L
.09582 .48555 L
.09386 .4852 L
.09199 .48486 L
.09027 .4845 L
.08881 .48416 L
.0878 .48381 L
.08656 .48346 L
.08561 .48309 L
.08467 .48267 L
.08374 .4822 L
.08287 .48169 L
.08207 .48119 L
.08133 .48068 L
.08064 .48015 L
.08002 .47956 L
.07945 .47893 L
.07891 .47827 L
.07826 .47753 L
.07757 .47668 L
.07687 .4757 L
.0762 .47471 L
.07561 .47373 L
.07513 .4728 L
.07478 .47197 L
.07458 .47129 L
.07452 .47071 L
.07459 .47026 L
.07477 .46994 L
.07502 .46972 L
.0753 .46959 L
.07561 .46949 L
.07592 .46939 L
.0762 .46926 L
.07645 .46906 L
.07669 .46879 L
.07693 .46843 L
.07717 .46799 L
.07741 .46751 L
.07765 .46703 L
.07789 .46657 L
.07813 .46611 L
Mistroke
.07836 .46567 L
.07859 .46528 L
.07883 .46497 L
.07907 .46475 L
.07933 .46463 L
.0796 .46459 L
.07984 .46461 L
.08005 .46467 L
.08021 .46474 L
Mfstroke
.08429 .4024 m
.0843 .40228 L
.08432 .40205 L
.08436 .4017 L
.08441 .40118 L
.08449 .40048 L
.08459 .39957 L
.08472 .39841 L
.08489 .39699 L
.0851 .39537 L
.08529 .39337 L
.08547 .39123 L
.08569 .38875 L
.08595 .38607 L
.08623 .38352 L
.08648 .3804 L
.08677 .37778 L
.08707 .37466 L
.08739 .37179 L
.08773 .36873 L
.08811 .36528 L
.08852 .36261 L
.08894 .35976 L
.08937 .35691 L
.08979 .35401 L
.09022 .35103 L
.09066 .34875 L
.09111 .3461 L
.09157 .34367 L
.09202 .34143 L
.09246 .33923 L
.09289 .33736 L
.09331 .3356 L
.0937 .33419 L
.09406 .33298 L
.09438 .33206 L
.09467 .33132 L
.09491 .33079 L
.09511 .33045 L
.09528 .33025 L
.09541 .33017 L
.0955 .33017 L
.09555 .33025 L
.09556 .33036 L
.09555 .33048 L
.09551 .33057 L
.09546 .33063 L
.09543 .33065 L
.09542 .33065 L
.09542 .33065 L
Mistroke
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33065 L
.09542 .33066 L
.09543 .33068 L
.09546 .33074 L
.0955 .33081 L
.09554 .33088 L
.09556 .33091 L
.09554 .33088 L
.09548 .33078 L
.09538 .33058 L
.09522 .3303 L
.09501 .32993 L
.09475 .32946 L
.09444 .32891 L
.09413 .32834 L
.09386 .32785 L
.09361 .32745 L
.0934 .32713 L
.09326 .32688 L
.09319 .32673 L
.09322 .32669 L
.09334 .32675 L
.09354 .32689 L
.09378 .32708 L
.09407 .32728 L
.09436 .32745 L
.09467 .32758 L
.09495 .32761 L
.09518 .32751 L
.09536 .32723 L
.09548 .3268 L
.09555 .32622 L
.09558 .32554 L
.09557 .32481 L
.09554 .32409 L
.0955 .32344 L
.09546 .32286 L
.09545 .32239 L
.09545 .32201 L
.09545 .32171 L
.09545 .32147 L
.09545 .32129 L
.09545 .32119 L
.09545 .32116 L
.09545 .32119 L
Mistroke
.09545 .32125 L
.09545 .32133 L
.09545 .32139 L
.09545 .32142 L
.09545 .32142 L
.09544 .32143 L
.09541 .32145 L
.09537 .3215 L
.09533 .32157 L
.09531 .32164 L
.09532 .32167 L
.09538 .32165 L
.09548 .32155 L
.09563 .32137 L
.09583 .3211 L
.09606 .32076 L
.09631 .32035 L
.09657 .3199 L
.09684 .31943 L
.09709 .31897 L
.09735 .31851 L
.09759 .31806 L
.0978 .31764 L
.09797 .31726 L
.09809 .31697 L
.09815 .31676 L
.09817 .31664 L
.09816 .3166 L
.09812 .31663 L
.09808 .31669 L
.09805 .31677 L
.09803 .31683 L
.09803 .31685 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31686 L
.09803 .31687 L
.09803 .31691 L
.09801 .31697 L
.09798 .31705 L
.09793 .31713 L
.09789 .31719 L
Mistroke
.09785 .3172 L
.09783 .31714 L
.09784 .31699 L
.09792 .3167 L
.09807 .31627 L
.09829 .31569 L
.09858 .31497 L
.09895 .31417 L
.09939 .31322 L
.09989 .31218 L
.10046 .31112 L
.10108 .31 L
.10175 .30886 L
.1024 .30776 L
.10304 .30678 L
.10364 .30589 L
.10419 .30513 L
.10464 .30451 L
.10501 .30404 L
.1053 .30368 L
.10552 .30342 L
.10567 .30323 L
.10578 .30311 L
.10585 .30304 L
.10588 .30301 L
.10588 .30302 L
.10586 .30303 L
.10582 .30306 L
.10578 .30309 L
.10574 .30313 L
.10573 .30316 L
.10573 .30317 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
Mistroke
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10573 .30318 L
.10572 .30318 L
.10571 .30318 L
.10567 .30318 L
.10563 .30318 L
.10559 .30317 L
.10555 .30318 L
.10555 .30319 L
.1056 .30322 L
.10571 .30326 L
.10587 .30329 L
.10608 .30331 L
.10634 .30332 L
.10665 .30331 L
.10698 .30328 L
.1073 .30322 L
.10761 .30313 L
.1079 .30302 L
.10819 .30284 L
.10844 .30258 L
.10868 .3022 L
.10893 .30175 L
.1092 .30121 L
.10954 .30054 L
.11003 .29983 L
.11067 .29895 L
.11139 .29792 L
.11236 .29675 L
.11344 .29551 L
.11477 .29416 L
.11614 .29272 L
.11765 .29129 L
.11913 .28989 L
.12057 .28871 L
.12169 .28763 L
.12292 .28659 L
.12389 .28574 L
.12473 .28492 L
.12541 .28409 L
.12599 .28323 L
Mistroke
.12652 .28232 L
.12703 .28127 L
.12755 .28003 L
.12811 .27861 L
.12868 .27715 L
.12916 .27562 L
.12974 .27373 L
.13035 .27189 L
.13103 .26987 L
.13162 .26773 L
.13218 .2659 L
.1327 .26406 L
.13317 .26228 L
.13362 .26059 L
.13409 .25909 L
.13461 .25766 L
.13522 .25623 L
.13591 .25476 L
.1368 .25323 L
.1378 .25187 L
.13898 .25031 L
.1403 .24869 L
.14177 .2471 L
.14326 .2454 L
.14497 .24368 L
.14637 .24202 L
.14776 .24033 L
.14917 .23876 L
.15041 .23723 L
.1516 .23586 L
.15265 .23455 L
.15369 .2333 L
.15456 .23217 L
.15538 .23107 L
.15614 .22997 L
.15684 .22881 L
.15751 .22769 L
.15809 .22647 L
.15865 .2251 L
.15917 .22364 L
.15963 .22203 L
.16007 .22026 L
.16051 .21862 L
.16097 .21668 L
.16147 .21476 L
.162 .21253 L
.16258 .2103 L
.16323 .20812 L
.16399 .20573 L
.16488 .2033 L
Mistroke
.16579 .20121 L
.16684 .19918 L
.1679 .19713 L
.16907 .19515 L
.17032 .1934 L
.17153 .19159 L
.17285 .18975 L
.17427 .18802 L
.17573 .18628 L
.17727 .18463 L
.17872 .18303 L
.18019 .1816 L
.18167 .18022 L
.18304 .17891 L
.18438 .17776 L
.18567 .17671 L
.1868 .17583 L
.18786 .17508 L
.18869 .17449 L
.18937 .17409 L
.18987 .17388 L
.19018 .17384 L
.19029 .17395 L
.19023 .17414 L
.19006 .17435 L
.18986 .17452 L
.18969 .17457 L
.18961 .17444 L
.18969 .17407 L
.18996 .17346 L
.19043 .17257 L
.1911 .17139 L
.19192 .17005 L
.19287 .16838 L
.19393 .16639 L
.19497 .16444 L
.19612 .16219 L
.19748 .15954 L
.19881 .1573 L
.20025 .15503 L
.20156 .15273 L
.20281 .15059 L
.20395 .14865 L
.20494 .14716 L
.20586 .1458 L
.20672 .14475 L
.20757 .14389 L
.20838 .14318 L
.20915 .14262 L
.20987 .14217 L
Mistroke
.21052 .14182 L
.21111 .14156 L
.2117 .14137 L
.21232 .14125 L
.21302 .14118 L
.21384 .14109 L
.2148 .14097 L
.21591 .14083 L
.21715 .14069 L
.21831 .14058 L
.21958 .14052 L
.22064 .1405 L
.22178 .14052 L
.22287 .14061 L
.22376 .14075 L
.22455 .14094 L
.2252 .14113 L
.22566 .14128 L
.22595 .14135 L
.22611 .14131 L
.22622 .14114 L
.22637 .1408 L
.22667 .14029 L
.22718 .13957 L
.22795 .13861 L
.22902 .13742 L
.23027 .13612 L
.23183 .13444 L
.23354 .13265 L
.23562 .13059 L
.23751 .12834 L
.23967 .12603 L
.24197 .12365 L
.24385 .12139 L
.24582 .11919 L
.24764 .11716 L
.24917 .11545 L
.25055 .11388 L
.25172 .11249 L
.25268 .11139 L
.2535 .1105 L
.2542 .10984 L
.25482 .10942 L
.2554 .10921 L
.25596 .10915 L
.25655 .1092 L
.25716 .10932 L
.25782 .10946 L
.25848 .10959 L
.2591 .10971 L
Mistroke
.25968 .10981 L
.26023 .10989 L
.26073 .10992 L
.26118 .10991 L
.26158 .10987 L
.26192 .10981 L
.26219 .10973 L
.26243 .10966 L
.26263 .10961 L
.26281 .10958 L
.26299 .10959 L
.26318 .10961 L
.26336 .10982 L
.26357 .10977 L
.2638 .10966 L
.26401 .10952 L
.2642 .10937 L
.26435 .10923 L
.26444 .10908 L
.26448 .10892 L
.26445 .10871 L
.2644 .10849 L
.26433 .10822 L
.26428 .10795 L
.26426 .10765 L
.2643 .10729 L
.26442 .10697 L
.26459 .10668 L
.26482 .10645 L
.26509 .10618 L
.2654 .10589 L
.26574 .10559 L
.26614 .10529 L
.26659 .105 L
.26711 .1047 L
.26769 .10441 L
.26835 .10411 L
.26908 .1038 L
.2699 .10347 L
.27079 .1031 L
.27171 .10267 L
.27271 .1022 L
.27375 .10173 L
.27486 .10127 L
.27599 .10085 L
.27713 .10045 L
.27823 .10008 L
.27929 .09975 L
.28021 .09949 L
.28101 .09931 L
Mistroke
.28164 .09922 L
.28213 .09918 L
.2825 .09917 L
.28282 .09911 L
.2831 .09898 L
.2834 .09874 L
.28371 .09836 L
.28406 .09784 L
.28443 .09723 L
.28484 .09656 L
.28527 .09592 L
.28567 .09526 L
.28606 .0946 L
.28641 .09404 L
.28674 .09354 L
.28704 .09313 L
.28733 .09281 L
.28763 .0926 L
.28797 .09244 L
.28838 .0923 L
.28888 .09213 L
.28949 .09188 L
.29027 .09152 L
.29119 .09102 L
.29234 .09039 L
.29363 .08968 L
.29508 .08887 L
.29673 .08802 L
.29829 .08715 L
.2999 .0863 L
.30149 .08553 L
.30304 .08482 L
.30451 .08416 L
.30593 .08355 L
.30734 .08297 L
.30871 .0824 L
.31011 .0818 L
.31151 .08112 L
.31295 .0803 L
.31441 .07932 L
.31575 .07828 L
.31712 .07707 L
.31839 .07564 L
.31963 .07419 L
.32086 .07263 L
.32204 .07113 L
.32322 .06956 L
.32441 .06807 L
.32557 .06666 L
.3268 .06521 L
Mistroke
.32809 .06399 L
.32955 .06281 L
.33115 .06165 L
.33301 .06051 L
.33497 .05944 L
.33703 .05833 L
.33929 .05727 L
.34171 .0562 L
.34402 .05513 L
.34627 .05407 L
.34837 .05309 L
.35013 .05219 L
.35198 .05139 L
.35372 .05075 L
.35535 .0503 L
.357 .05004 L
.35864 .04994 L
.36036 .04999 L
.3621 .05014 L
.36373 .05038 L
.36507 .05067 L
.36639 .05101 L
.36752 .05134 L
.36866 .05165 L
.3698 .05191 L
.37083 .05211 L
.37162 .05225 L
.37213 .05233 L
.3724 .05237 L
.37248 .05239 L
.37239 .05239 L
.37215 .05237 L
.37187 .05236 L
.37164 .05236 L
.37149 .05236 L
.37144 .05236 L
.37152 .05234 L
.37174 .05226 L
.37215 .0521 L
.37273 .05183 L
.37349 .05141 L
.37441 .05086 L
.37547 .05018 L
.37653 .04937 L
.37768 .04848 L
.37893 .04752 L
.38029 .04662 L
.38158 .04565 L
.3829 .04463 L
.38423 .04373 L
Mistroke
.38549 .04287 L
.38673 .04209 L
.38794 .04141 L
.38922 .04085 L
.39063 .04041 L
.39215 .0401 L
.39379 .0399 L
.39563 .03978 L
.39765 .03971 L
.39964 .03966 L
.40168 .03963 L
.40377 .03962 L
.40572 .03963 L
.40759 .03968 L
.40932 .03974 L
.41083 .03983 L
.41223 .03992 L
.41344 .04001 L
.41439 .04007 L
.41502 .04012 L
.41534 .04016 L
.41535 .04018 L
.41509 .04019 L
.41462 .04019 L
.41401 .04018 L
.41332 .04015 L
.41259 .04012 L
.41187 .04009 L
.41115 .04006 L
.41044 .04004 L
.40976 .04002 L
.40915 .04 L
.40868 .03999 L
.40836 .03998 L
.40818 .03998 L
.40812 .03998 L
.40815 .03998 L
.40825 .03998 L
.40836 .03998 L
.40843 .03997 L
.40843 .03992 L
.40838 .03983 L
.40831 .03973 L
.40825 .03965 L
.40825 .03961 L
.40831 .03963 L
.40845 .03975 L
.40868 .04001 L
.40899 .04043 L
.40936 .04101 L
Mistroke
.40979 .04174 L
.41025 .04263 L
.41071 .04357 L
.41119 .04465 L
.41167 .04572 L
.41214 .04681 L
.41257 .04784 L
.41293 .04872 L
.4132 .04932 L
.41335 .04968 L
.41338 .04979 L
.41329 .04965 L
.41312 .04925 L
.41291 .04862 L
.4127 .0479 L
.41252 .04704 L
.41237 .04616 L
.41223 .04526 L
.41207 .04447 L
.41187 .04371 L
.4116 .04304 L
.41123 .0425 L
.41073 .04208 L
.41009 .0418 L
.4093 .04166 L
.40827 .04163 L
.40705 .04165 L
.40557 .04167 L
.40385 .04167 L
.40185 .04162 L
.39968 .04151 L
.39749 .04134 L
.39513 .04114 L
.39288 .04093 L
.39078 .04071 L
.38872 .04049 L
.38671 .04027 L
.38508 .04005 L
.38356 .03981 L
.38216 .03956 L
.38084 .0393 L
.3796 .03905 L
.37838 .03883 L
.37719 .03866 L
.37599 .03857 L
.37468 .03856 L
.37324 .03866 L
.37181 .03889 L
.37028 .03924 L
.36857 .03968 L
Mistroke
.36675 .04021 L
.36496 .04081 L
.36339 .04151 L
.36187 .04229 L
.36043 .0431 L
.35912 .04384 L
.35797 .04456 L
.35701 .04538 L
.3562 .04612 L
.35548 .04686 L
.35481 .04764 L
.35418 .04836 L
.35358 .04914 L
.35297 .04994 L
.35235 .05077 L
.35175 .05162 L
.3512 .05246 L
.35073 .05324 L
.35029 .05396 L
.34987 .05465 L
.34946 .05527 L
.34912 .05575 L
.34886 .05611 L
.34868 .05632 L
.34858 .05645 L
.34855 .05648 L
.34858 .05643 L
.34865 .05631 L
.34872 .05618 L
.34876 .05608 L
.34878 .05602 L
.34879 .05597 L
.34881 .05593 L
.34883 .05588 L
.34887 .05581 L
.3489 .0557 L
.34894 .05557 L
.34899 .0554 L
.34905 .05524 L
.34911 .05508 L
.34918 .05493 L
.34927 .0548 L
.34936 .05471 L
.34941 .05465 L
.34937 .05462 L
.34922 .0546 L
.34895 .05457 L
.34853 .05459 L
.34796 .05467 L
.34725 .05484 L
Mistroke
.34643 .05505 L
.34548 .05535 L
.34445 .05572 L
.34332 .05613 L
.3422 .05654 L
.34098 .05695 L
.33965 .05736 L
.33827 .05777 L
.33688 .05821 L
.33543 .05871 L
.33399 .0593 L
.33252 .05995 L
.33098 .06067 L
.32938 .06146 L
.32786 .0623 L
.32632 .06324 L
.32467 .06422 L
.32301 .0652 L
.32146 .06621 L
.31995 .06722 L
.31854 .06819 L
.31731 .06905 L
.31616 .06981 L
.31511 .07042 L
.31417 .07087 L
.3134 .07116 L
.31274 .07132 L
.31217 .07141 L
.31166 .07151 L
.31119 .07166 L
.31075 .07191 L
.31029 .0723 L
.30991 .07275 L
.30946 .07341 L
.30895 .07426 L
.30839 .07528 L
.30776 .07636 L
.30702 .07763 L
.30622 .07904 L
.30536 .08039 L
.30449 .08171 L
.30363 .08294 L
.30281 .08408 L
.30206 .08508 L
.30139 .08594 L
.30082 .08671 L
.30036 .08741 L
.3 .08804 L
.29976 .08863 L
.29962 .08919 L
Mistroke
.29956 .08972 L
.29955 .0902 L
.29959 .09063 L
.29969 .09096 L
.29983 .09122 L
.29997 .09147 L
.30009 .09175 L
.30018 .09202 L
.30023 .09228 L
.30021 .09258 L
.3001 .09295 L
.29986 .09343 L
.29946 .09402 L
.29887 .09474 L
.29809 .09559 L
.29712 .09656 L
.29606 .09752 L
.29488 .09857 L
.29364 .09965 L
.29246 .10073 L
.29136 .10166 L
.29026 .10249 L
.28914 .10316 L
.28817 .10365 L
.28729 .10397 L
.28651 .10412 L
.28582 .10414 L
.28527 .10407 L
.28485 .10398 L
.28454 .1039 L
.28431 .10381 L
.2841 .10374 L
.28386 .10368 L
.28357 .10364 L
.28323 .10359 L
.28288 .10352 L
.28256 .10344 L
.28231 .10337 L
.28216 .1033 L
.28211 .10325 L
.28214 .10321 L
.28217 .10319 L
.28218 .10318 L
.2822 .10319 L
.28224 .10322 L
.28234 .10325 L
.28253 .10331 L
.28278 .1034 L
.28305 .1035 L
.28329 .10359 L
Mistroke
.28348 .10367 L
.28357 .10372 L
.28352 .10375 L
.28332 .10372 L
.283 .10365 L
.28258 .10353 L
.28208 .10334 L
.28149 .10306 L
.2808 .10273 L
.28015 .10236 L
.27937 .10203 L
.27855 .10172 L
.27771 .10148 L
.27693 .10131 L
.2762 .10122 L
.27557 .10118 L
.27503 .1012 L
.27464 .10131 L
.27433 .10147 L
.27414 .10167 L
.27404 .10193 L
.27399 .10221 L
.27398 .10245 L
.27397 .10263 L
.2739 .10277 L
.27374 .10283 L
.27344 .10286 L
.27298 .1029 L
.27239 .10301 L
.27165 .10328 L
.27077 .10377 L
.26982 .10446 L
.26885 .10533 L
.26782 .10629 L
.26673 .10727 L
.26564 .10811 L
.26461 .10893 L
.26366 .10968 L
.26283 .11038 L
.26212 .11089 L
.26153 .11127 L
.26105 .11149 L
.26066 .11157 L
.26036 .11145 L
.26016 .11117 L
.26005 .11076 L
.26001 .11033 L
.26001 .10995 L
.26 .10968 L
.25996 .10951 L
Mistroke
.25982 .10946 L
.2595 .10956 L
.25897 .1098 L
.25824 .11014 L
.25729 .11056 L
.25609 .11107 L
.25485 .11165 L
.25335 .1123 L
.25173 .11295 L
.25011 .11366 L
.24837 .11437 L
.24663 .11508 L
.24495 .1158 L
.24342 .11651 L
.24187 .11727 L
.24032 .11808 L
.23884 .11893 L
.23745 .11982 L
.23627 .12073 L
.23503 .12172 L
.23384 .1228 L
.23274 .12389 L
.23171 .12509 L
.23069 .12646 L
.22976 .1278 L
.2289 .12921 L
.22815 .13061 L
.22752 .13189 L
.22702 .13296 L
.22666 .13376 L
.2264 .13434 L
.22621 .13467 L
.22606 .13478 L
.22596 .13466 L
.22588 .13438 L
.22583 .13401 L
.22581 .13364 L
.22582 .13329 L
.22587 .13302 L
.22593 .1329 L
.226 .133 L
.22606 .13338 L
.2261 .13403 L
.22615 .13488 L
.22621 .13576 L
.22629 .13689 L
.22635 .13786 L
.22641 .13879 L
.22643 .13959 L
.22644 .14019 L
Mistroke
.22643 .14055 L
.22638 .14068 L
.22626 .14064 L
.22604 .14048 L
.22572 .14025 L
.22528 .14 L
.22469 .13975 L
.22395 .13955 L
.22303 .13941 L
.22194 .1393 L
.22068 .13926 L
.21923 .13931 L
.21761 .13948 L
.21608 .13979 L
.21438 .14024 L
.21244 .14085 L
.21033 .14161 L
.20831 .14251 L
.2064 .14357 L
.20437 .14481 L
.20236 .14613 L
.20037 .1477 L
.19858 .14946 L
.19669 .15134 L
.19513 .15325 L
.19357 .15535 L
.19193 .15745 L
.1904 .15975 L
.18885 .16187 L
.18731 .16409 L
.18579 .16637 L
.18455 .16833 L
.18327 .1704 L
.18215 .17237 L
.18116 .17423 L
.18018 .17612 L
.17933 .17762 L
.1786 .17908 L
.17803 .18052 L
.17762 .18191 L
.17738 .18321 L
.1773 .18432 L
.17733 .18536 L
.17743 .18628 L
.17754 .18704 L
.17764 .18761 L
.17772 .18801 L
.17776 .18827 L
.17776 .18843 L
.17773 .18844 L
Mistroke
.17769 .18836 L
.17763 .1881 L
.17756 .18771 L
.1775 .18721 L
.17748 .18671 L
.17754 .18622 L
.1777 .18576 L
.17796 .18537 L
.17834 .18511 L
.17882 .18502 L
.17939 .18505 L
.18001 .18512 L
.18072 .1852 L
.18148 .18528 L
.18229 .18534 L
.18307 .1854 L
.18386 .18544 L
.18461 .18546 L
.18531 .18548 L
.1859 .1855 L
.18639 .18551 L
.18675 .18552 L
.18702 .18553 L
.18722 .18553 L
.18737 .18553 L
.18748 .18554 L
.18756 .18554 L
.18764 .18554 L
.18768 .18554 L
.1877 .18554 L
.18768 .18554 L
.18764 .18554 L
.1876 .18554 L
.18757 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
Mistroke
.18755 .18554 L
.18755 .18554 L
.18755 .18554 L
.18753 .18554 L
.1875 .18554 L
.18746 .18554 L
.18743 .18554 L
.18741 .18554 L
.18742 .18554 L
.18748 .18554 L
.18757 .18554 L
.18772 .18554 L
.1879 .18555 L
.18812 .18556 L
.18836 .18556 L
.18861 .18557 L
.18886 .18558 L
.18912 .18562 L
.18935 .18568 L
.18954 .18576 L
.18968 .18586 L
.18978 .18595 L
.18983 .18599 L
.18985 .18597 L
.18985 .18586 L
.18987 .18563 L
.18992 .18529 L
.19007 .18482 L
.19035 .18422 L
.19077 .18347 L
.19134 .18259 L
.19203 .18155 L
.19288 .18029 L
.19388 .17882 L
.19502 .17726 L
.19629 .17556 L
.19761 .17382 L
.19898 .17204 L
.20035 .17045 L
.20161 .16891 L
.2028 .16751 L
.20379 .16639 L
.20468 .16533 L
.20543 .16446 L
.20609 .16368 L
.20655 .16318 L
.20691 .16282 L
.20713 .16263 L
.20724 .1626 L
.20727 .16267 L
Mistroke
.20725 .16279 L
.20719 .16291 L
.20711 .16301 L
.20702 .16308 L
.20695 .16312 L
.20692 .16313 L
.20692 .16314 L
.20693 .16316 L
.20693 .16322 L
.20693 .1633 L
.20691 .1634 L
.20688 .1635 L
.20683 .16358 L
.20677 .16361 L
.20672 .16354 L
.2067 .16331 L
.20674 .1629 L
.20685 .16229 L
.20704 .16145 L
.20732 .16037 L
.20767 .15917 L
.20809 .15772 L
.20855 .15605 L
.20901 .15442 L
.2095 .15265 L
.20998 .15075 L
.21039 .14917 L
.21074 .14767 L
.21105 .14628 L
.21129 .14511 L
.21145 .1442 L
.21158 .14351 L
.21172 .14304 L
.21189 .1427 L
.21213 .14245 L
.21248 .14222 L
.21297 .14199 L
.21362 .14172 L
.21436 .14139 L
.21528 .14101 L
.21627 .14054 L
.2174 .13996 L
.21865 .13924 L
.21981 .13839 L
.22104 .1375 L
.22235 .13657 L
.22363 .13565 L
.22494 .13474 L
.22621 .13386 L
.22753 .13307 L
Mistroke
.22878 .13227 L
.23007 .13147 L
.23132 .1307 L
.23259 .12994 L
.23379 .12921 L
.23489 .12851 L
.23596 .12786 L
.23694 .12728 L
.23779 .12681 L
.23853 .12641 L
.23916 .12607 L
.23965 .12575 L
.24002 .12547 L
.2403 .12523 L
.24049 .12506 L
.24062 .12497 L
.24069 .12494 L
.24073 .12498 L
.24074 .12506 L
.24072 .12516 L
.24067 .12527 L
.24057 .12538 L
.24045 .12547 L
.24031 .12553 L
.2402 .12555 L
.24016 .12551 L
.24022 .12537 L
.2404 .1251 L
.24072 .12469 L
.2412 .12413 L
.24185 .12342 L
.24266 .12258 L
.2436 .12169 L
.24451 .1207 L
.24559 .11965 L
.24661 .11861 L
.2477 .11759 L
.24858 .11664 L
.24945 .11584 L
.25028 .11515 L
.25103 .11461 L
.25166 .11422 L
.25225 .11399 L
.25283 .11392 L
.25346 .11397 L
.25416 .11407 L
.25496 .11417 L
.25584 .1142 L
.25675 .11417 L
.2577 .11407 L
Mistroke
.25874 .11389 L
.25992 .11367 L
.26117 .11347 L
.26246 .11332 L
.26376 .11325 L
.26507 .11321 L
.26635 .11319 L
.26759 .1132 L
.2688 .11325 L
.26987 .11331 L
.27089 .11342 L
.27182 .11357 L
.2726 .11373 L
.2732 .11386 L
.27365 .11393 L
.27398 .11392 L
.27419 .1138 L
.27433 .11356 L
.27444 .11313 L
.27453 .11254 L
.27464 .11191 L
.2748 .11122 L
.27503 .11051 L
.27533 .10979 L
.27565 .10908 L
.27603 .1084 L
.27646 .10777 L
.27695 .1072 L
.27745 .10671 L
.27793 .10634 L
.27836 .1061 L
.27872 .10598 L
.27903 .10595 L
.27929 .106 L
.27953 .10606 L
.27978 .10609 L
.28007 .10603 L
.28041 .10584 L
.28081 .10546 L
.28126 .10484 L
.2818 .10396 L
.28244 .10288 L
.28315 .1015 L
.28403 .09999 L
.28499 .09825 L
.28612 .09635 L
.28742 .09438 L
.28888 .09248 L
.29057 .09049 L
.2922 .08873 L
Mistroke
.29406 .0869 L
.29577 .08537 L
.29772 .08389 L
.29967 .0826 L
.30176 .0814 L
.30398 .08027 L
.30609 .07921 L
.30825 .07826 L
.3104 .07729 L
.31248 .07628 L
.31458 .07518 L
.31668 .07405 L
.31875 .07276 L
.32101 .07128 L
.32313 .06976 L
.32538 .06812 L
.32775 .06644 L
.32997 .06462 L
.33231 .0629 L
.33478 .06109 L
.3371 .05923 L
.33952 .05767 L
.34202 .05612 L
.34432 .05461 L
.34663 .05326 L
.34879 .05206 L
.35084 .05097 L
.35252 .05001 L
.35404 .04914 L
.3553 .04838 L
.35635 .04771 L
.35715 .04714 L
.35774 .04667 L
.35814 .04625 L
.35837 .04589 L
.35845 .0456 L
.35841 .04536 L
.35829 .04517 L
.35813 .04504 L
.35797 .04498 L
.35781 .04496 L
.35768 .045 L
.35761 .04507 L
.35761 .04515 L
.35771 .0452 L
.35794 .04523 L
.35833 .04524 L
.35891 .04524 L
.35969 .04525 L
.36066 .04526 L
Mistroke
.36184 .04529 L
.36321 .04536 L
.36453 .04546 L
.36596 .04556 L
.36731 .04563 L
.3687 .04565 L
.36985 .04561 L
.37092 .04547 L
.37191 .04524 L
.37271 .04493 L
.37341 .04455 L
.37404 .04413 L
.37462 .04369 L
.37517 .04325 L
.37568 .04282 L
.37616 .04239 L
.37666 .04199 L
.37722 .04164 L
.37784 .04136 L
.37848 .04114 L
.37912 .04101 L
.37968 .04096 L
.38018 .04097 L
.3806 .04106 L
.38095 .0412 L
.38122 .0414 L
.38142 .04165 L
.38158 .04194 L
.38178 .04227 L
.38202 .04256 L
.3823 .04278 L
.3826 .04292 L
.38294 .043 L
.3833 .04307 L
.38366 .04315 L
.38403 .04324 L
.38441 .04335 L
.3848 .04348 L
.38525 .04358 L
.38579 .04366 L
.38641 .04373 L
.3872 .04383 L
.38798 .04398 L
.38898 .04428 L
.39016 .04471 L
.39139 .04528 L
.39285 .04594 L
.39439 .04664 L
.39621 .04734 L
.39826 .048 L
Mistroke
.40015 .04858 L
.40225 .04906 L
.40436 .04952 L
.40648 .04995 L
.4087 .05037 L
.41075 .05077 L
.41277 .05113 L
.41472 .05144 L
.41647 .05166 L
.4182 .05177 L
.41971 .05178 L
.42102 .05167 L
.42201 .05147 L
.42277 .0512 L
.4233 .05091 L
.42368 .0506 L
.42394 .05028 L
.42415 .04994 L
.42439 .04955 L
.42474 .04912 L
.42526 .04861 L
.42598 .04803 L
.42689 .04737 L
.42794 .0466 L
.4292 .04596 L
.43065 .04526 L
.43227 .0446 L
.43392 .04401 L
.43556 .04344 L
.43721 .04287 L
.43852 .04234 L
.43969 .04182 L
.44058 .04137 L
.4413 .04101 L
.44182 .04077 L
.44214 .04065 L
.44237 .04064 L
.44262 .04069 L
.44298 .04078 L
.44348 .04086 L
.44419 .04093 L
.44513 .04098 L
.44633 .04102 L
.44759 .04106 L
.44929 .04113 L
.45106 .04124 L
.45309 .04138 L
.45538 .04156 L
.45752 .04178 L
.45987 .04203 L
Mistroke
.46208 .04229 L
.46425 .04257 L
.46633 .04285 L
.46818 .04308 L
.46987 .04328 L
.47139 .04344 L
.47267 .04358 L
.4738 .04372 L
.47474 .04387 L
.47546 .04405 L
.47597 .04428 L
.47629 .04456 L
.47646 .04489 L
.47651 .04527 L
.47648 .0457 L
.4764 .04614 L
.4763 .0466 L
.47621 .04707 L
.47613 .04754 L
.47602 .04795 L
.47589 .04827 L
.47574 .04847 L
.4756 .0485 L
.47553 .04838 L
.47556 .04811 L
.47572 .04775 L
.47605 .04731 L
.47658 .04688 L
.47734 .04642 L
.47836 .04601 L
.47955 .04562 L
.48106 .04525 L
.48255 .04493 L
.48442 .04467 L
.48635 .04444 L
.48826 .04424 L
.49045 .04403 L
.4927 .04377 L
.49499 .04349 L
.49727 .04315 L
.49946 .04275 L
.50154 .04232 L
.50359 .04184 L
.50529 .04132 L
.50682 .04082 L
.5083 .04036 L
.5095 .03991 L
.51055 .03948 L
.51133 .03906 L
.51191 .03877 L
Mistroke
.51228 .03854 L
.51246 .03843 L
.51246 .03845 L
.51231 .03859 L
.51205 .03882 L
.51174 .03912 L
.51145 .03945 L
.51122 .03983 L
.51105 .04022 L
.51093 .04064 L
.51085 .04106 L
.5108 .04149 L
.5108 .04194 L
.51085 .04228 L
.51094 .0426 L
.51109 .04285 L
.5113 .04302 L
.51157 .04311 L
.51188 .04316 L
.51222 .04318 L
.5126 .04321 L
.51296 .04326 L
.5133 .04331 L
.51357 .04334 L
.51374 .04332 L
.51382 .04322 L
.51382 .04305 L
.51377 .04279 L
.51369 .04246 L
.51354 .04208 L
.51332 .04168 L
.51302 .04126 L
.51267 .04085 L
.51226 .04042 L
.51181 .03997 L
.51133 .0395 L
.51085 .03904 L
.51035 .03863 L
.50986 .03829 L
.50938 .03803 L
.50895 .03781 L
.50856 .03762 L
.50813 .03743 L
.50769 .03718 L
.50719 .03691 L
.50664 .03658 L
.50599 .03619 L
.50521 .03581 L
.50418 .03545 L
.50285 .03516 L
Mistroke
.5012 .03486 L
.49914 .03458 L
.49694 .03433 L
.49431 .03409 L
.49146 .03386 L
.48856 .03364 L
.48527 .03344 L
.48253 .03328 L
.47911 .03317 L
.47637 .03312 L
.47295 .03309 L
.47022 .03304 L
.46738 .03297 L
.46439 .03288 L
.4618 .0328 L
.45899 .03272 L
.45596 .03261 L
.4534 .03247 L
.45009 .03231 L
.44739 .03216 L
.44436 .03203 L
.44077 .03195 L
.43764 .03194 L
.43413 .03201 L
.43076 .03217 L
.42708 .0324 L
.42413 .03271 L
.42105 .03308 L
.41822 .03349 L
.41552 .03392 L
.4132 .03434 L
.41119 .03472 L
.40942 .03501 L
.40808 .03519 L
.40702 .03525 L
.40624 .03519 L
.4057 .03502 L
.4054 .03479 L
.40528 .03453 L
.40531 .03425 L
.40542 .03404 L
.4056 .03388 L
.40578 .0338 L
.40592 .0338 L
.40603 .03385 L
.40611 .03396 L
.40616 .03414 L
.40619 .03441 L
.40623 .03465 L
.40624 .03493 L
Mistroke
.40625 .03519 L
.40624 .03539 L
.40623 .03552 L
.40625 .03558 L
.40633 .0356 L
.40643 .03558 L
.40653 .03557 L
.40658 .03555 L
.40654 .0355 L
.4064 .03544 L
.40613 .03536 L
.40573 .03531 L
.40521 .0353 L
.4046 .03534 L
.40393 .03544 L
.40323 .0356 L
.40256 .03583 L
.40196 .03613 L
.40134 .03649 L
.4007 .03689 L
.40009 .03732 L
.39961 .03773 L
.3993 .03817 L
.39914 .03854 L
.39908 .03893 L
.3991 .03928 L
.39919 .03955 L
.3993 .03974 L
.39936 .03984 L
.39937 .03988 L
.39934 .03987 L
.39931 .03984 L
.39927 .03979 L
.39925 .03976 L
.39927 .03974 L
.39931 .03973 L
.39941 .03972 L
.39954 .03972 L
.39971 .03973 L
.39992 .03973 L
.40014 .03974 L
.40038 .03975 L
.40061 .03975 L
.40085 .03976 L
.40107 .03979 L
.40128 .03983 L
.40147 .03989 L
.40162 .03994 L
.40173 .03997 L
.4018 .03997 L
Mistroke
.40181 .03991 L
.40179 .03979 L
.40174 .03957 L
.40168 .03925 L
.40162 .03886 L
.40158 .03845 L
.40156 .03807 L
.40155 .03772 L
.40155 .03746 L
.40155 .03733 L
.40156 .03729 L
.40158 .03731 L
.40159 .03737 L
.40161 .0375 L
.40162 .03771 L
.40164 .038 L
.40168 .03834 L
.40171 .03869 L
.40177 .03904 L
.40186 .03936 L
.40199 .03962 L
.40218 .03976 L
.4024 .03983 L
.40268 .03985 L
.40302 .03981 L
.40337 .03976 L
.40377 .03976 L
.40418 .03979 L
.40459 .03984 L
.40499 .03989 L
.40535 .03993 L
.40566 .03995 L
.40592 .03995 L
.40613 .03994 L
.40628 .03993 L
.40636 .03993 L
.40638 .03993 L
.40637 .03993 L
.40634 .03992 L
.40631 .03992 L
.40627 .03992 L
.40624 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
Mistroke
.40622 .03992 L
.40622 .03992 L
.40622 .03992 L
.40621 .03992 L
.40618 .03992 L
.40614 .03992 L
.40611 .03992 L
.40609 .03992 L
.4061 .03992 L
.40615 .03992 L
.40623 .03993 L
.40636 .03995 L
.40652 .03997 L
.40669 .03998 L
.40688 .03998 L
.40708 .03995 L
.4073 .03992 L
.40755 .03989 L
.40784 .03985 L
.40816 .03983 L
.40851 .03982 L
.40885 .03981 L
.40915 .03978 L
.40939 .03974 L
.40958 .0397 L
.40972 .03966 L
.40983 .03963 L
.40993 .03961 L
.41003 .03961 L
.41013 .03963 L
.41023 .03967 L
.41031 .03972 L
.41036 .03977 L
.41039 .03981 L
.41039 .03984 L
.41041 .03988 L
.41048 .03993 L
.41059 .04004 L
.41074 .04016 L
.41087 .04025 L
.41094 .04028 L
.41092 .04022 L
.41077 .04007 L
.41049 .03981 L
.41008 .03945 L
.40959 .03901 L
.40909 .03854 L
.40862 .03807 L
.40822 .03761 L
.40788 .03716 L
Mistroke
.40756 .03672 L
.4073 .0363 L
.40712 .03593 L
.40704 .03564 L
.40708 .03544 L
.4072 .03533 L
.40741 .0353 L
.40766 .03533 L
.40795 .03541 L
.40822 .03549 L
.40843 .03555 L
.40855 .03557 L
.40861 .03558 L
.40862 .03558 L
.40861 .03558 L
.40857 .03558 L
.40854 .03558 L
.40851 .03559 L
.40849 .0356 L
.40849 .03561 L
.40849 .03562 L
.40849 .03562 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03563 L
.40849 .03562 L
.40849 .03562 L
.40849 .03561 L
.40849 .0356 L
.40849 .03559 L
.40849 .03558 L
.40849 .03558 L
.40849 .03557 L
.40849 .03557 L
.40849 .03557 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
Mistroke
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.40849 .03558 L
.4085 .03559 L
.40852 .03559 L
.40853 .03559 L
.40854 .03559 L
.40852 .03558 L
.40849 .03557 L
.40845 .03556 L
.40839 .03554 L
.40834 .03553 L
.40829 .03552 L
.40824 .03552 L
.40821 .03551 L
.40819 .03551 L
.40818 .03551 L
.40819 .03552 L
.40822 .03552 L
.40826 .03553 L
.40831 .03554 L
.40835 .03555 L
.40836 .03556 L
.40836 .03556 L
.40832 .03556 L
.40827 .03556 L
.40821 .03555 L
.40814 .03554 L
.40807 .03553 L
Mistroke
.408 .03552 L
.40796 .03552 L
.40794 .03552 L
.40793 .03552 L
.40791 .03553 L
.40792 .03553 L
.40795 .03554 L
.40802 .03555 L
.40813 .03556 L
.40828 .03557 L
.40846 .03558 L
.40867 .03559 L
.40889 .0356 L
.4091 .0356 L
.40931 .03561 L
.40952 .03561 L
.40973 .03562 L
.40995 .03562 L
.41018 .03563 L
.41039 .03564 L
.41057 .03564 L
.41072 .03565 L
.41082 .03565 L
.41088 .03565 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03565 L
.41077 .03565 L
.41078 .03565 L
.41083 .03565 L
.4109 .03565 L
Mistroke
.41096 .03566 L
.41099 .03566 L
.41097 .03566 L
.41088 .03565 L
.41071 .03565 L
.41044 .03564 L
.41009 .03563 L
.40968 .03562 L
.40924 .0356 L
.40877 .03559 L
.40832 .03557 L
.40788 .03556 L
.40744 .03555 L
.407 .03553 L
.4066 .03552 L
.40627 .03551 L
.40603 .0355 L
.40589 .0355 L
.40586 .0355 L
.40593 .0355 L
.40608 .03551 L
.40628 .03551 L
.4065 .03552 L
.40673 .03553 L
.40696 .03553 L
.4072 .03554 L
.40744 .03555 L
.40767 .03555 L
.4079 .03556 L
.40811 .03557 L
.4083 .03558 L
.40844 .03558 L
.40855 .03559 L
.4086 .03559 L
.40862 .03559 L
.40861 .03558 L
.4086 .03558 L
.40858 .03557 L
.40855 .03556 L
.40853 .03555 L
.40849 .03555 L
.40845 .03554 L
.40839 .03554 L
.40834 .03556 L
.40828 .03557 L
.40824 .03557 L
.40821 .03556 L
.40819 .03554 L
.40818 .03551 L
.40816 .03548 L
Mistroke
.40814 .03544 L
.40812 .03541 L
.40811 .03538 L
.40814 .03536 L
.40821 .03535 L
.40831 .03535 L
.40846 .03535 L
.40865 .03536 L
.40885 .03537 L
.40907 .0354 L
.40929 .03544 L
.40951 .03548 L
.40972 .03554 L
.40995 .03559 L
.41018 .03563 L
.41039 .03566 L
.41057 .03569 L
.41072 .03569 L
.41082 .03568 L
.41088 .03566 L
.41089 .03565 L
.41088 .03565 L
.41085 .03565 L
.41081 .03565 L
.41078 .03565 L
.41077 .03565 L
.41076 .03565 L
.41076 .03565 L
.41076 .03564 L
.41077 .03562 L
.41079 .03557 L
.41081 .03551 L
.41081 .03544 L
.4108 .03541 L
.41077 .03543 L
.41072 .03552 L
.41067 .0357 L
.41061 .03595 L
.41056 .03629 L
.41052 .03668 L
.41049 .03711 L
.41047 .03756 L
.41046 .03801 L
.41046 .03845 L
.41046 .03889 L
.41048 .0393 L
.41051 .03966 L
.41055 .03995 L
.41061 .04015 L
.41067 .04026 L
Mistroke
.41073 .0403 L
.41079 .04026 L
.41087 .04017 L
.41095 .04007 L
.41101 .03996 L
.41102 .03988 L
.41099 .03981 L
.41089 .03979 L
.41071 .03984 L
.41045 .03998 L
.4101 .04023 L
.4097 .04058 L
.40925 .04103 L
.40879 .04158 L
.40833 .04216 L
.40789 .04283 L
.40746 .04355 L
.40704 .04428 L
.40667 .04494 L
.40636 .04554 L
.40615 .04603 L
.40606 .04638 L
.40609 .04654 L
.4062 .04649 L
.40633 .04626 L
.40644 .04588 L
.4065 .04542 L
.40645 .04492 L
.40625 .04441 L
.40597 .04393 L
.4055 .04346 L
.40479 .043 L
.40385 .04257 L
.40274 .04215 L
.40159 .04177 L
.4004 .04144 L
.39897 .04115 L
.39724 .04091 L
.39573 .0407 L
.39406 .04054 L
.39257 .04039 L
.39104 .04021 L
.38964 .04 L
.38852 .03976 L
.38751 .0395 L
.38661 .0392 L
.38587 .03886 L
.38532 .03849 L
.38496 .0381 L
.38477 .03768 L
Mistroke
.38473 .03726 L
.38477 .03685 L
.38486 .03643 L
.38496 .036 L
.38505 .03559 L
.38508 .03523 L
.38504 .03495 L
.38497 .03476 L
.38487 .03466 L
.38475 .03462 L
.38462 .03464 L
.38446 .0347 L
.38427 .03477 L
.38405 .03482 L
.38382 .03485 L
.38359 .03484 L
.38341 .03483 L
.38328 .03482 L
.3832 .03482 L
.38316 .03482 L
.38318 .03482 L
.38325 .03484 L
.38335 .03486 L
.38346 .0349 L
.38356 .03493 L
.38363 .03497 L
.38368 .035 L
.38371 .03504 L
.38375 .03507 L
.3838 .0351 L
.38388 .03512 L
.384 .03513 L
.38416 .03513 L
.38435 .03512 L
.38453 .03509 L
.38469 .03503 L
.38482 .03512 L
.38492 .03507 L
.38499 .03504 L
.38503 .03504 L
.38503 .03507 L
.38498 .03515 L
.38487 .03526 L
.38467 .03543 L
.38438 .03569 L
.384 .03596 L
.38355 .03629 L
.38308 .03666 L
.38261 .03702 L
.3822 .03743 L
Mistroke
.38184 .0378 L
.38155 .03811 L
.38132 .0384 L
.38115 .03866 L
.38104 .03887 L
.38097 .03903 L
.38095 .03915 L
.38098 .03923 L
.38107 .03928 L
.38121 .03929 L
.38134 .03929 L
.38142 .03927 L
.3814 .03923 L
.38126 .03919 L
.381 .03917 L
.3806 .03915 L
.38007 .03913 L
.37945 .03912 L
.37878 .03909 L
.37807 .03907 L
.37739 .03905 L
.37672 .03903 L
.37605 .03901 L
.37541 .03899 L
.37483 .03897 L
.37438 .03896 L
.37406 .03895 L
.37389 .03894 L
.37383 .03894 L
.37386 .03894 L
.37396 .03895 L
.37407 .03895 L
.37415 .03895 L
.37419 .03895 L
.3742 .03893 L
.37421 .0389 L
.37424 .03887 L
.37427 .03886 L
.37431 .03887 L
.37432 .0389 L
.3743 .03897 L
.37422 .03908 L
.37409 .03925 L
.37392 .03945 L
.37374 .03964 L
.37355 .03981 L
.37337 .03997 L
.37323 .04007 L
.37313 .04013 L
.37307 .0402 L
Mistroke
.37304 .0402 L
.37306 .04016 L
.37311 .04007 L
.37319 .03993 L
.37333 .03974 L
.37349 .03954 L
.37369 .03934 L
.37389 .03915 L
.37407 .03899 L
.37421 .0389 L
.3743 .03886 L
.37433 .03884 L
.37431 .03885 L
.37428 .03887 L
.37424 .03891 L
.37421 .03894 L
.3742 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.37419 .03895 L
.3742 .03895 L
.37422 .03895 L
.37427 .03896 L
.37434 .03896 L
.37441 .03896 L
.37444 .03896 L
.37443 .03896 L
.37434 .03896 L
.37418 .03895 L
.37393 .03894 L
.37363 .03889 L
.3733 .0388 L
.37294 .03868 L
.37257 .03857 L
.37219 .0385 L
.3718 .03848 L
.37135 .03856 L
.37082 .03877 L
.37021 .03913 L
.36951 .03966 L
.3687 .04035 L
.36773 .04117 L
.3666 .04211 L
.36542 .04305 L
.36403 .04402 L
.36243 .04503 L
.36085 .04604 L
.35895 .04699 L
.35725 .04779 L
Mistroke
.35554 .04847 L
.35389 .04899 L
.35244 .04935 L
.35126 .04957 L
.35028 .04966 L
.34951 .04966 L
.34897 .04961 L
.34862 .04954 L
.34842 .04947 L
.34836 .04939 L
.34838 .04933 L
.34844 .0493 L
.34855 .0493 L
.34867 .0493 L
.34877 .0493 L
.34881 .0493 L
.34882 .0493 L
.34884 .04927 L
.3489 .0492 L
.34902 .0491 L
.34912 .04901 L
.34919 .04897 L
.34919 .049 L
.34909 .04914 L
.34884 .04939 L
.3484 .04977 L
.34778 .05027 L
.34704 .05085 L
.34622 .0515 L
.34538 .05218 L
.34454 .05282 L
.34387 .05344 L
.34311 .05405 L
.34239 .05464 L
.34177 .05516 L
.34133 .05557 L
.34111 .05581 L
.3411 .05589 L
.34123 .05585 L
.34144 .05574 L
.34167 .05562 L
.34187 .05551 L
.34194 .05548 L
.34181 .05556 L
.34147 .05573 L
.34091 .05598 L
.34011 .05631 L
.33904 .05672 L
.33789 .05721 L
.3364 .05781 L
Mistroke
.33504 .05849 L
.33356 .05929 L
.33186 .0602 L
.33023 .06121 L
.32853 .0623 L
.32675 .06341 L
.32495 .06449 L
.32324 .06548 L
.3215 .06646 L
.31979 .06736 L
.31839 .06819 L
.31694 .06889 L
.31559 .06951 L
.31452 .07004 L
.31358 .07046 L
.31276 .0708 L
.31209 .07105 L
.31157 .07125 L
.31123 .07143 L
.31106 .07159 L
.31104 .07175 L
.31112 .0719 L
.31125 .07208 L
.31139 .07228 L
.3115 .07248 L
.31155 .07266 L
.31156 .0728 L
.31156 .0729 L
.31156 .07296 L
.31156 .07298 L
.31156 .07296 L
.31156 .07293 L
.31156 .07289 L
.31156 .07286 L
.31156 .07285 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31156 .07284 L
.31159 .07282 L
.31165 .07277 L
.31176 .0727 L
.31186 .07264 L
.31192 .07261 L
.31189 .07262 L
Mistroke
.31177 .07271 L
.31153 .07287 L
.31115 .0731 L
.31067 .07339 L
.31011 .07372 L
.30952 .07406 L
.30888 .07444 L
.30818 .07486 L
.30745 .07534 L
.30666 .07587 L
.30582 .07645 L
.30495 .07707 L
.30412 .07768 L
.30339 .07827 L
.3028 .07882 L
.30233 .07932 L
.30196 .07975 L
.30159 .08015 L
.30118 .08053 L
.30068 .0809 L
.30007 .08125 L
.29937 .08154 L
.29863 .08174 L
.29786 .08185 L
.29713 .08187 L
.29647 .08181 L
.29589 .08169 L
.29532 .08157 L
.29472 .08146 L
.29408 .0814 L
.29346 .08138 L
.29292 .08141 L
.29247 .08148 L
.29212 .08159 L
.29185 .08174 L
.29165 .08192 L
.29151 .08213 L
.29138 .08238 L
.29121 .08259 L
.29098 .08284 L
.29074 .08309 L
.29052 .0833 L
.29034 .08348 L
.29022 .08358 L
.29017 .08361 L
.29021 .08358 L
.29032 .08354 L
.29049 .0835 L
.29071 .0835 L
.29095 .08356 L
Mistroke
.29119 .08371 L
.29144 .08394 L
.29169 .08422 L
.29195 .08451 L
.29221 .08476 L
.29249 .08492 L
.29276 .085 L
.293 .08503 L
.29322 .08504 L
.29338 .08505 L
.29343 .08516 L
.29334 .08517 L
.29311 .08522 L
.29269 .0853 L
.29208 .08545 L
.29122 .08572 L
.29008 .08615 L
.28879 .08672 L
.2872 .08753 L
.28527 .08854 L
.28312 .08975 L
.28111 .09101 L
.27888 .09235 L
.2764 .09374 L
.27416 .09507 L
.27183 .09635 L
.26986 .09748 L
.26809 .09852 L
.26662 .09946 L
.26542 .1003 L
.26435 .101 L
.26347 .1016 L
.26274 .10209 L
.26213 .10248 L
.26156 .10281 L
.26098 .1031 L
.26036 .10339 L
.25962 .10373 L
.2587 .10417 L
.25764 .10472 L
.25642 .10541 L
.25496 .10625 L
.25321 .10727 L
.25137 .1084 L
.24944 .10966 L
.24746 .11098 L
.24571 .11227 L
.24401 .1135 L
.2426 .11465 L
.24124 .11569 L
Mistroke
.24013 .11656 L
.23919 .11729 L
.23846 .11786 L
.23797 .11827 L
.23768 .11853 L
.23758 .11865 L
.23761 .11868 L
.23773 .11865 L
.23788 .11857 L
.23803 .11848 L
.23812 .11839 L
.23818 .11831 L
.23827 .11823 L
.23839 .11814 L
.23849 .11804 L
.23854 .11795 L
.23852 .11791 L
.23839 .11792 L
.23815 .11804 L
.23776 .11828 L
.23722 .11868 L
.23655 .11924 L
.23577 .11995 L
.23492 .1208 L
.23406 .12172 L
.23319 .12275 L
.23229 .12379 L
.2314 .12486 L
.23056 .1259 L
.22984 .12688 L
.22927 .12772 L
.22885 .12843 L
.22858 .12899 L
.22842 .12939 L
.22837 .12963 L
.22837 .12974 L
.2284 .12976 L
.22842 .12973 L
.22845 .12967 L
.22849 .1296 L
.22853 .12952 L
.2286 .12944 L
.22867 .12939 L
.22876 .12934 L
.22887 .12928 L
.22899 .12921 L
.22909 .12914 L
.22913 .12907 L
.22906 .12906 L
.22885 .12915 L
Mistroke
.22844 .12937 L
.22779 .12972 L
.22688 .13023 L
.22569 .13088 L
.22436 .13162 L
.22275 .13246 L
.22086 .13338 L
.21891 .13435 L
.21686 .13543 L
.21452 .13671 L
.21235 .13796 L
.21003 .13931 L
.20779 .14071 L
.20588 .14215 L
.20405 .14356 L
.2024 .14489 L
.20106 .14598 L
.19991 .14708 L
.19898 .1481 L
.1983 .14889 L
.19782 .1496 L
.1975 .15022 L
.1973 .1507 L
.19716 .15105 L
.19703 .15137 L
.19684 .15174 L
.19655 .15222 L
.19617 .15286 L
.19568 .1537 L
.19508 .15473 L
.1944 .15592 L
.19372 .15704 L
.19302 .15831 L
.19234 .1596 L
.19175 .1607 L
.19119 .16178 L
.19073 .16269 L
.19039 .16347 L
.19016 .16411 L
.18996 .16466 L
.18976 .1652 L
.18949 .16578 L
.18909 .16649 L
.18847 .16746 L
.18759 .1687 L
.18653 .17005 L
.18524 .17179 L
.18368 .17374 L
.18189 .17608 L
.17999 .17855 L
Mistroke
.17822 .18135 L
.17634 .18394 L
.17433 .18684 L
.17238 .18976 L
.17052 .19262 L
.16866 .19565 L
.16697 .19826 L
.16528 .20104 L
.16374 .20363 L
.16221 .2062 L
.16073 .20863 L
.15939 .2111 L
.15805 .21325 L
.15673 .21542 L
.1555 .21748 L
.15438 .21939 L
.15332 .22121 L
.15232 .22291 L
.15144 .22432 L
.15065 .22565 L
.14997 .22686 L
.14944 .22793 L
.14902 .2288 L
.14873 .22951 L
.14854 .23005 L
.14845 .23039 L
.14841 .23058 L
.1484 .23066 L
.14838 .23065 L
.14835 .23061 L
.14828 .23058 L
.14815 .23059 L
.14793 .23066 L
.14762 .23082 L
.1472 .23112 L
.14666 .23158 L
.14598 .23229 L
.1452 .23318 L
.1443 .2343 L
.14327 .23568 L
.1421 .23736 L
.14084 .23934 L
.1396 .24124 L
.1383 .24355 L
.13697 .24604 L
.13562 .24853 L
.13419 .25132 L
.13266 .25432 L
.13111 .25715 L
.12943 .26037 L
Mistroke
.12775 .26341 L
.12611 .26661 L
.12443 .26959 L
.1227 .27278 L
.12116 .27551 L
.11929 .27848 L
.1176 .28136 L
.1157 .2844 L
.11388 .2875 L
.11193 .29021 L
.10991 .29314 L
.10795 .29621 L
.10646 .29873 L
.10485 .30145 L
.10339 .30379 L
.10193 .30613 L
.10084 .30803 L
.09987 .30979 L
.09902 .31139 L
.09837 .31268 L
.09791 .31372 L
.09764 .31448 L
.09754 .31494 L
.09756 .31517 L
.09765 .3152 L
.09777 .31509 L
.0979 .31493 L
.098 .31475 L
.09805 .3146 L
.09804 .31449 L
.09804 .31442 L
.09804 .3144 L
.09802 .31444 L
.09798 .31453 L
.0979 .31469 L
.09779 .31495 L
.09766 .31535 L
.09753 .31589 L
.09741 .31658 L
.09731 .3174 L
.09723 .31833 L
.0972 .31935 L
.09719 .32035 L
.09721 .32137 L
.09726 .32237 L
.09731 .32333 L
.0974 .32416 L
.09752 .32482 L
.09766 .32524 L
.09782 .32549 L
Mistroke
.09799 .32563 L
.09815 .32567 L
.09827 .32567 L
.09831 .32572 L
.09825 .32591 L
.0981 .32641 L
.09786 .32728 L
.09755 .32856 L
.09719 .33026 L
.09677 .33237 L
.09628 .33455 L
.0957 .33698 L
.09501 .33993 L
.09421 .343 L
.09334 .34641 L
.09239 .34975 L
.09139 .3533 L
.09042 .35679 L
.08946 .35992 L
.08854 .36335 L
.08773 .36647 L
.08695 .36967 L
.08629 .37266 L
.08569 .3758 L
.08518 .37848 L
.08478 .3813 L
.08449 .38393 L
.08431 .38664 L
.08422 .38925 L
.08422 .39138 L
.08425 .3934 L
.08431 .3953 L
.08436 .39701 L
.08439 .39849 L
.08439 .39964 L
.08438 .40059 L
.08437 .40133 L
.08437 .40187 L
.08436 .40224 L
.08436 .40243 L
Mfstroke
.07165 .48585 m
.07162 .48609 L
.07158 .48647 L
.07156 .48693 L
.07155 .48745 L
.07154 .488 L
.07152 .48858 L
.07148 .48922 L
.07143 .48991 L
.07136 .4907 L
.0713 .49154 L
.07126 .49242 L
.07123 .49336 L
.07121 .49435 L
.07118 .4954 L
.07111 .49655 L
.07099 .4978 L
.07082 .49924 L
.07061 .50095 L
.07034 .503 L
.07002 .50526 L
.06967 .50788 L
.0693 .51074 L
.06895 .51333 L
.0686 .51592 L
.06828 .5187 L
.06799 .52133 L
.06776 .52417 L
.06761 .52656 L
.06756 .52898 L
.06766 .53133 L
.06787 .53346 L
.0682 .53547 L
.0686 .53722 L
.06905 .53879 L
.06952 .54017 L
.06998 .54139 L
.07039 .54243 L
.07076 .54328 L
.07109 .54398 L
.07138 .54457 L
.07165 .54505 L
.07189 .54543 L
.07212 .54573 L
.07234 .54595 L
.07258 .54613 L
.07283 .54627 L
.07311 .54637 L
.07339 .54643 L
.07364 .54646 L
Mistroke
.0739 .54653 L
.07413 .54666 L
.07431 .54687 L
.07438 .54716 L
.07433 .54757 L
.07416 .5481 L
.07388 .54878 L
.07354 .54965 L
.07319 .55075 L
.07287 .552 L
.07261 .55354 L
.07243 .5553 L
.07236 .55721 L
.07241 .55936 L
.07257 .56167 L
.07285 .56394 L
.07322 .56639 L
.0737 .5688 L
.07429 .57131 L
.0749 .5736 L
.07551 .5759 L
.07611 .57816 L
.07664 .58006 L
.07708 .5819 L
.07743 .58356 L
.07771 .58496 L
.07791 .58617 L
.07806 .58722 L
.07817 .58792 L
.07825 .58848 L
.07832 .58882 L
.07835 .58898 L
.07834 .58898 L
.0783 .58891 L
.07826 .58884 L
.07824 .58885 L
.07824 .58893 L
.07828 .58908 L
.07833 .58929 L
.07839 .58953 L
.07844 .58981 L
.07848 .5901 L
.0785 .59041 L
.07852 .59073 L
.07851 .59111 L
.07847 .59163 L
.07842 .59233 L
.07833 .5931 L
.07821 .59408 L
.07809 .5952 L
Mistroke
.07796 .59651 L
.07784 .59793 L
.07777 .59963 L
.07776 .60155 L
.07781 .60375 L
.07793 .60628 L
.07814 .60881 L
.07843 .61163 L
.0788 .61462 L
.07925 .61783 L
.07979 .62082 L
.08041 .62387 L
.08108 .62704 L
.08178 .63003 L
.08248 .63318 L
.08315 .63611 L
.08376 .63906 L
.08434 .64167 L
.08491 .64416 L
.08543 .64628 L
.08591 .64815 L
.08636 .64981 L
.08676 .65126 L
.08711 .65257 L
.08742 .65383 L
.08771 .65503 L
.08799 .65618 L
.08828 .6573 L
.08859 .65838 L
.08894 .65933 L
.08931 .66025 L
.08968 .66107 L
.09001 .66184 L
.09029 .66248 L
.09054 .66304 L
.09076 .66354 L
.09097 .66395 L
.09117 .66432 L
.09138 .66475 L
.09159 .66527 L
.09179 .66589 L
.09197 .66678 L
.09214 .66795 L
.0923 .66935 L
.09245 .67086 L
.09261 .67253 L
.09277 .6743 L
.09292 .67602 L
.09304 .67788 L
.09315 .67959 L
Mistroke
.09324 .68133 L
.09332 .68307 L
.09339 .68482 L
.09346 .68663 L
.09354 .68845 L
.09365 .69013 L
.09381 .69194 L
.09407 .69386 L
.09444 .69573 L
.0949 .6977 L
.09547 .69968 L
.09616 .70149 L
.09695 .7032 L
.0979 .70474 L
.09861 .7058 L
.09944 .7068 L
.10029 .7076 L
.10098 .70821 L
.10162 .70868 L
.10222 .70906 L
.10274 .70935 L
.10315 .7096 L
.10343 .70984 L
.10358 .71016 L
.10362 .71058 L
.10358 .71115 L
.1035 .7119 L
.10341 .71285 L
.10332 .71394 L
.10326 .71514 L
.10321 .71643 L
.10314 .71777 L
.10305 .71921 L
.10295 .72077 L
.10285 .7226 L
.10275 .72427 L
.10265 .72614 L
.10258 .72808 L
.10252 .72993 L
.10247 .73164 L
.10245 .73319 L
.10243 .73444 L
.10243 .73553 L
.10245 .73645 L
.10249 .73723 L
.10255 .73787 L
.10261 .73833 L
.10268 .73861 L
.10274 .73873 L
.10279 .73872 L
Mistroke
.10281 .73864 L
.10281 .73852 L
.10279 .7384 L
.10276 .73831 L
.10275 .73826 L
.10275 .73823 L
.10275 .73819 L
.10275 .73812 L
.10276 .73803 L
.10276 .73791 L
.10276 .73778 L
.10276 .73766 L
.10275 .73757 L
.10272 .73754 L
.10268 .73754 L
.10264 .73754 L
.10261 .73753 L
.10261 .73754 L
.10263 .73756 L
.10266 .73763 L
.10272 .73776 L
.10281 .73796 L
.10297 .7383 L
.10324 .73878 L
.10361 .7394 L
.10409 .74017 L
.10471 .74108 L
.10545 .74216 L
.1063 .74329 L
.10723 .74454 L
.10813 .74588 L
.10904 .74726 L
.10992 .74866 L
.11073 .74999 L
.11151 .75129 L
.11225 .75253 L
.11298 .75367 L
.11372 .75474 L
.11451 .75578 L
.1154 .75693 L
.11633 .75806 L
.11737 .75939 L
.11855 .76088 L
.11978 .76242 L
.12121 .76408 L
.1228 .76589 L
.12452 .76777 L
.1263 .76947 L
.12808 .77123 L
.12968 .77267 L
Mistroke
.13121 .77395 L
.13241 .77503 L
.13338 .77583 L
.13402 .77633 L
.13432 .77656 L
.13431 .77657 L
.13413 .77643 L
.13387 .77621 L
.13361 .77596 L
.13336 .77578 L
.13319 .77575 L
.13309 .77592 L
.13308 .77631 L
.13322 .77685 L
.13362 .77754 L
.13443 .77838 L
.13532 .77923 L
.13666 .78017 L
.13819 .78117 L
.13996 .78221 L
.14183 .78327 L
.14384 .78428 L
.1458 .78524 L
.14777 .78611 L
.14977 .78688 L
.15167 .78753 L
.15346 .78806 L
.15507 .7885 L
.15643 .78887 L
.15753 .78917 L
.15846 .78948 L
.15907 .78972 L
.15956 .79003 L
.15993 .79039 L
.16021 .79082 L
.16042 .79137 L
.16064 .79204 L
.16086 .79291 L
.16112 .79387 L
.16142 .79513 L
.16186 .79664 L
.16247 .79832 L
.16328 .80016 L
.16432 .80225 L
.16555 .80458 L
.16689 .80697 L
.16837 .80939 L
.17 .81197 L
.17169 .81451 L
.17352 .81712 L
Mistroke
.17552 .81974 L
.17765 .82228 L
.17993 .82475 L
.18217 .82711 L
.18442 .82929 L
.18647 .83125 L
.18831 .83284 L
.18994 .83424 L
.19128 .83532 L
.19242 .8362 L
.19334 .8369 L
.19412 .83748 L
.19483 .83802 L
.19553 .83861 L
.19627 .83929 L
.19704 .84007 L
.19793 .84101 L
.19892 .84207 L
.20013 .84333 L
.20161 .84482 L
.2033 .84657 L
.20522 .84841 L
.20719 .85034 L
.20925 .85223 L
.21133 .8542 L
.21313 .85571 L
.21488 .85723 L
.21639 .85857 L
.2177 .85968 L
.21874 .86058 L
.21956 .86133 L
.22016 .86188 L
.22055 .86228 L
.22078 .86258 L
.22089 .8628 L
.22093 .863 L
.22097 .86321 L
.22107 .86346 L
.22128 .86378 L
.22161 .86416 L
.22209 .8646 L
.22271 .86508 L
.22343 .86559 L
.22418 .86611 L
.22495 .86654 L
.22572 .86698 L
.22644 .86734 L
.22704 .86761 L
.22753 .86778 L
.22788 .86787 L
Mistroke
.22811 .86791 L
.22823 .86791 L
.22828 .86791 L
.22833 .86796 L
.22848 .86812 L
.2288 .86843 L
.22934 .86891 L
.23013 .86957 L
.23117 .8704 L
.23242 .87144 L
.23397 .87264 L
.23579 .87403 L
.2377 .87554 L
.23976 .87712 L
.24184 .87872 L
.24387 .8802 L
.24574 .8815 L
.24752 .88286 L
.24918 .88419 L
.25059 .88545 L
.25188 .88667 L
.25292 .88775 L
.25389 .88875 L
.25454 .88965 L
.25513 .89044 L
.25566 .89109 L
.25604 .8918 L
.25644 .89253 L
.25686 .89332 L
.25737 .89418 L
.25793 .89499 L
.25865 .89585 L
.25952 .8967 L
.26064 .89751 L
.26166 .89829 L
.26298 .8991 L
.26445 .89995 L
.26613 .90089 L
.26807 .90194 L
.27026 .90308 L
.27261 .90425 L
.27497 .90535 L
.27731 .90641 L
.27963 .9074 L
.28169 .90833 L
.28357 .90914 L
.28502 .90983 L
.2862 .91045 L
.28716 .91097 L
.28791 .91133 L
Mistroke
.28844 .91151 L
.28882 .91152 L
.28907 .91136 L
.28928 .91109 L
.28958 .91076 L
.29005 .91043 L
.29068 .91015 L
.29154 .90991 L
.29252 .90971 L
.29367 .90955 L
.29491 .90936 L
.29619 .90915 L
.29738 .90891 L
.29838 .90864 L
.29914 .90833 L
.29964 .908 L
.29994 .9077 L
.30008 .90749 L
.30008 .90739 L
.29994 .90736 L
.29986 .90744 L
.29989 .90768 L
.30014 .90803 L
.30065 .90855 L
.30153 .90936 L
.3028 .91042 L
.30455 .9117 L
.30663 .91313 L
.30922 .91467 L
.31199 .91634 L
.31519 .9181 L
.31838 .91987 L
.32183 .9216 L
.32519 .92327 L
.32863 .92483 L
.33204 .9262 L
.33545 .92749 L
.33855 .92862 L
.34169 .92965 L
.34475 .93058 L
.34774 .93143 L
.35061 .93223 L
.35341 .93297 L
.35611 .93368 L
.35882 .93439 L
.36149 .93508 L
.36403 .93581 L
.36656 .93657 L
.36905 .93738 L
.37135 .93822 L
Mistroke
.37348 .93906 L
.37536 .93983 L
.37692 .94053 L
.37818 .94111 L
.37918 .94157 L
.37992 .94185 L
.38049 .94198 L
.38093 .94196 L
.38132 .94176 L
.38176 .94138 L
.38234 .94083 L
.3831 .94016 L
.384 .93937 L
.38514 .93847 L
.38639 .93749 L
.38775 .93649 L
.38919 .93553 L
.39067 .93454 L
.39208 .93391 L
.39333 .93323 L
.39431 .93275 L
.39501 .93247 L
.39543 .93243 L
.39559 .9326 L
.39548 .93295 L
.39519 .93344 L
.39485 .93408 L
.39454 .93483 L
.39434 .93556 L
.39432 .93621 L
.39453 .93676 L
.39498 .93727 L
.39564 .93772 L
.39649 .93809 L
.39735 .93845 L
.39822 .93886 L
.399 .93927 L
.39964 .93967 L
.40006 .94008 L
.40026 .94049 L
.40026 .94075 L
.40011 .94091 L
.39982 .94089 L
.39945 .94071 L
.39886 .94035 L
.39838 .93966 L
.39781 .9388 L
.39728 .93792 L
.39682 .9367 L
.39651 .9354 L
Mistroke
.39635 .93391 L
.39631 .93258 L
.39634 .93132 L
.39639 .9303 L
.39643 .92954 L
.39639 .92906 L
.39623 .9288 L
.39594 .9288 L
.39558 .9291 L
.39518 .92963 L
.3948 .93032 L
.39446 .93114 L
.39423 .93211 L
.39411 .93317 L
.39413 .93435 L
.39431 .93559 L
.39467 .93689 L
.39524 .9383 L
.39602 .93978 L
.39699 .94131 L
.39818 .94286 L
.39961 .94439 L
.40123 .94594 L
.40309 .94748 L
.40509 .94898 L
.40734 .95049 L
.40986 .95191 L
.41241 .95317 L
.41515 .95433 L
.41805 .95544 L
.42099 .95652 L
.42394 .95753 L
.42675 .95851 L
.42957 .95943 L
.43222 .96028 L
.43474 .96105 L
.43688 .96172 L
.43881 .96225 L
.44052 .96263 L
.442 .96293 L
.44333 .9632 L
.44454 .96349 L
.44575 .96379 L
.4468 .96406 L
.44799 .96429 L
.44926 .96447 L
.45057 .96452 L
.45199 .96446 L
.45351 .96429 L
.45502 .96409 L
Mistroke
.45655 .96394 L
.45806 .96391 L
.45957 .96399 L
.46103 .96415 L
.46253 .96425 L
.46407 .96433 L
.46568 .96443 L
.46738 .96455 L
.46915 .96468 L
.47098 .96483 L
.47301 .96504 L
.47515 .9653 L
.47741 .96557 L
.47972 .96578 L
.48213 .96588 L
.48457 .96583 L
.48707 .96566 L
.48989 .96543 L
.49223 .96524 L
.49468 .96506 L
.49698 .96491 L
.49903 .96482 L
.50067 .96478 L
.50191 .96478 L
.50268 .96479 L
.50317 .96478 L
.5034 .96476 L
.50344 .96477 L
.50335 .96482 L
.50307 .96488 L
.50269 .96491 L
.5023 .96489 L
.50194 .96478 L
.50162 .96457 L
.50142 .96422 L
.50128 .96377 L
.50129 .96324 L
.50149 .96268 L
.50186 .9621 L
.50233 .96153 L
.50261 .9609 L
.50277 .9602 L
.50282 .95948 L
.50277 .95878 L
.50273 .95811 L
.50268 .95754 L
.50261 .95706 L
.50261 .95674 L
.50261 .95653 L
.50259 .95646 L
Mistroke
.50249 .95652 L
.50229 .95668 L
.50194 .95681 L
.50141 .95684 L
.50068 .95683 L
.49969 .95681 L
.49843 .95679 L
.49695 .95681 L
.49526 .9569 L
.49344 .95708 L
.49134 .95728 L
.48889 .95747 L
.48663 .95761 L
.48413 .95778 L
.48152 .95795 L
.47884 .95807 L
.47611 .95828 L
.4733 .95855 L
.47056 .9589 L
.46778 .95922 L
.46498 .95964 L
.46226 .95991 L
.45944 .96008 L
.45664 .96013 L
.45387 .96016 L
.45114 .96019 L
.44841 .96023 L
.44583 .96029 L
.44322 .96036 L
.44088 .96042 L
.43852 .96035 L
.43608 .96014 L
.43402 .95978 L
.43194 .95929 L
.42991 .95871 L
.42783 .95804 L
.42576 .95732 L
.42371 .9566 L
.42162 .95585 L
.41945 .95509 L
.41719 .9543 L
.41493 .95347 L
.4125 .95257 L
.40984 .95161 L
.4071 .95063 L
.40424 .94967 L
.4013 .9487 L
.39819 .94774 L
.39505 .94678 L
.39194 .94579 L
Mistroke
.38871 .94476 L
.38559 .94368 L
.38241 .94258 L
.37931 .94142 L
.37623 .94026 L
.37304 .93911 L
.36996 .938 L
.36688 .937 L
.36385 .93605 L
.36079 .93514 L
.35785 .93423 L
.35495 .9333 L
.35189 .93231 L
.34877 .93127 L
.34579 .93019 L
.34267 .92907 L
.33945 .92796 L
.33649 .92692 L
.33362 .9259 L
.3307 .92492 L
.32817 .92401 L
.32549 .92315 L
.32341 .92241 L
.32153 .92178 L
.31982 .92131 L
.31837 .92099 L
.31722 .92082 L
.31637 .92076 L
.31571 .92073 L
.31513 .92065 L
.31451 .92043 L
.3138 .92006 L
.31296 .91952 L
.31191 .91878 L
.31058 .9179 L
.3092 .91696 L
.30772 .91596 L
.30625 .91493 L
.30487 .91393 L
.30353 .913 L
.30223 .9122 L
.30114 .91154 L
.30026 .91106 L
.29958 .91077 L
.29912 .91063 L
.29888 .91058 L
.29883 .91057 L
.29892 .91053 L
.29908 .91037 L
.29925 .91004 L
Mistroke
.29938 .90958 L
.29944 .90902 L
.29944 .90838 L
.29941 .90776 L
.2994 .90726 L
.29959 .90688 L
.29976 .90666 L
.29997 .9066 L
.30013 .90672 L
.30025 .90703 L
.30024 .90745 L
.30004 .90794 L
.29958 .90843 L
.29883 .90897 L
.29777 .90944 L
.29638 .90975 L
.29477 .90982 L
.29279 .90961 L
.29063 .90909 L
.28826 .90839 L
.28555 .90748 L
.28271 .90645 L
.2798 .90545 L
.27725 .90445 L
.27461 .90353 L
.27226 .90279 L
.27015 .90212 L
.26837 .90155 L
.26687 .90105 L
.26558 .90057 L
.26458 .90011 L
.26372 .89966 L
.26296 .89922 L
.26244 .89882 L
.26199 .89839 L
.26163 .89795 L
.26137 .89757 L
.2612 .89721 L
.26106 .89684 L
.26091 .89649 L
.2607 .89617 L
.26048 .89592 L
.26014 .8957 L
.2597 .8955 L
.25914 .89527 L
.25842 .89497 L
.25751 .89452 L
.25644 .89391 L
.25521 .89309 L
.25388 .8921 L
Mistroke
.25238 .89091 L
.25069 .88954 L
.24885 .88806 L
.24701 .88652 L
.24516 .88495 L
.24341 .88338 L
.24186 .88188 L
.24052 .8806 L
.23942 .87953 L
.23851 .87868 L
.23773 .87795 L
.23709 .87739 L
.23648 .87686 L
.23581 .87626 L
.23517 .87567 L
.23457 .87512 L
.23384 .87443 L
.23299 .87362 L
.23196 .87264 L
.2307 .87151 L
.22925 .87018 L
.22766 .86876 L
.22587 .86718 L
.22392 .86545 L
.22186 .86357 L
.21973 .86164 L
.21754 .85963 L
.21542 .85765 L
.21329 .85564 L
.21114 .85366 L
.20909 .85187 L
.20708 .85009 L
.20513 .84827 L
.20328 .84657 L
.20151 .84481 L
.19986 .84298 L
.19832 .84122 L
.19685 .83944 L
.19546 .83767 L
.19418 .83603 L
.19298 .83446 L
.19186 .83315 L
.19084 .83187 L
.18986 .83078 L
.18891 .82972 L
.18794 .82867 L
.18695 .8277 L
.18589 .82679 L
.18474 .82594 L
.18351 .82511 L
Mistroke
.18218 .82425 L
.18077 .82334 L
.17939 .82231 L
.17788 .82124 L
.17632 .81987 L
.1747 .81841 L
.17295 .81674 L
.17122 .81498 L
.16942 .81306 L
.16759 .81102 L
.16584 .80899 L
.16415 .80702 L
.16253 .80501 L
.16095 .80295 L
.15934 .80089 L
.15787 .79888 L
.15637 .79684 L
.15488 .79485 L
.15341 .79296 L
.15208 .79124 L
.15085 .78967 L
.14976 .78825 L
.1487 .78697 L
.14762 .78577 L
.14645 .78464 L
.14544 .78356 L
.14418 .78248 L
.1427 .78133 L
.14111 .78003 L
.13927 .77875 L
.13745 .77733 L
.13538 .77575 L
.13329 .77402 L
.13142 .77214 L
.12947 .77015 L
.12732 .76803 L
.1252 .76585 L
.12307 .76362 L
.12106 .76139 L
.11902 .75918 L
.11715 .75715 L
.11537 .75522 L
.11365 .75348 L
.11213 .75187 L
.1107 .75043 L
.10935 .74914 L
.10813 .74798 L
.10714 .74694 L
.1063 .74598 L
.10565 .74515 L
Mistroke
.10519 .7445 L
.10495 .74402 L
.10488 .74368 L
.10495 .74344 L
.10509 .74324 L
.10527 .74308 L
.10545 .74293 L
.10562 .74278 L
.10577 .74262 L
.10587 .74244 L
.10592 .7423 L
.10591 .74221 L
.10585 .74216 L
.10572 .74207 L
.10551 .74191 L
.10525 .74164 L
.10495 .74124 L
.10464 .74068 L
.10433 .7399 L
.10408 .73915 L
.10383 .73826 L
.1036 .73731 L
.10337 .73628 L
.10315 .73509 L
.10291 .73365 L
.10269 .73194 L
.10249 .73001 L
.10228 .72806 L
.10206 .72613 L
.10181 .72429 L
.10153 .72261 L
.10121 .72112 L
.10085 .71987 L
.1005 .71884 L
.10019 .71802 L
.09994 .71738 L
.09975 .71688 L
.09962 .71651 L
.09956 .71632 L
.09957 .71627 L
.09964 .71631 L
.09982 .71633 L
.10008 .71629 L
.10038 .71621 L
.1007 .71609 L
.10099 .71594 L
.10122 .71578 L
.10137 .71568 L
.10141 .71572 L
.10134 .71584 L
Mistroke
.10115 .716 L
.1009 .71611 L
.10059 .71604 L
.10023 .71572 L
.09981 .71521 L
.09931 .7146 L
.09872 .7137 L
.09808 .71253 L
.09742 .71106 L
.09678 .70934 L
.09619 .70738 L
.0956 .7054 L
.09502 .70309 L
.0944 .70033 L
.09374 .6974 L
.09301 .69411 L
.0922 .69057 L
.09138 .68654 L
.09057 .68243 L
.08981 .67796 L
.08911 .67415 L
.08849 .67019 L
.08794 .66687 L
.08745 .6639 L
.08706 .66102 L
.08674 .65837 L
.08653 .65629 L
.0864 .65502 L
.08637 .65434 L
.08639 .65394 L
.08639 .65354 L
.08633 .65307 L
.08619 .65246 L
.08595 .65134 L
.08559 .64948 L
.08519 .64715 L
.08474 .64448 L
.08425 .64164 L
.08377 .63869 L
.08329 .63575 L
.08282 .63287 L
.08244 .63028 L
.08213 .62796 L
.08189 .62603 L
.08177 .62454 L
.08179 .62346 L
.08194 .62282 L
.0822 .62255 L
.08254 .62256 L
.08291 .62275 L
Mistroke
.08328 .62308 L
.08363 .62348 L
.08395 .6239 L
.08421 .62429 L
.08441 .62463 L
.08458 .62489 L
.08473 .62507 L
.08484 .62517 L
.08491 .62523 L
.08493 .62525 L
.08491 .62524 L
.08487 .6252 L
.08483 .62516 L
.08479 .62513 L
.08478 .62511 L
.08478 .62511 L
.0848 .62513 L
.08486 .62515 L
.08494 .6252 L
.08501 .62527 L
.08505 .62539 L
.08503 .62555 L
.08495 .62573 L
.08478 .62589 L
.08451 .62594 L
.08413 .62582 L
.08366 .62544 L
.08311 .62475 L
.08251 .62369 L
.0819 .62228 L
.0813 .62046 L
.08068 .61822 L
.08006 .61581 L
.07948 .61305 L
.07896 .60988 L
.0785 .60678 L
.07811 .60339 L
.07777 .59999 L
.07747 .59651 L
.07719 .59318 L
.0769 .58988 L
.07658 .58663 L
.07619 .58338 L
.07574 .58013 L
.07525 .57681 L
.07473 .57335 L
.07417 .56961 L
.07356 .56606 L
.07291 .56232 L
.07227 .55856 L
Mistroke
.07162 .55481 L
.07097 .5512 L
.07035 .54777 L
.06975 .54434 L
.06919 .54117 L
.0687 .53803 L
.06832 .53505 L
.06803 .53216 L
.06784 .52937 L
.06776 .52651 L
.06779 .52362 L
.06794 .52047 L
.0682 .51736 L
.06856 .514 L
.06903 .51056 L
.06956 .50697 L
.07017 .50354 L
.07076 .50025 L
.07136 .49729 L
.07193 .49464 L
.07245 .49231 L
.07291 .49037 L
.07331 .48878 L
.07365 .48743 L
.07394 .48628 L
.07416 .4853 L
.07431 .48445 L
.0744 .4837 L
.07444 .483 L
.07444 .48228 L
.07445 .48156 L
.0745 .48074 L
.07459 .47983 L
.07473 .47886 L
.07494 .47789 L
.07522 .47701 L
.07553 .47627 L
.07584 .47568 L
.07613 .47522 L
.07641 .47485 L
.07666 .47454 L
.07686 .47423 L
.07701 .47389 L
.0771 .47349 L
.07716 .47304 L
.07723 .47258 L
.07731 .47213 L
.07742 .47171 L
.07753 .4713 L
.07763 .47089 L
Mistroke
.07775 .47047 L
.07792 .47004 L
.07814 .46961 L
.07842 .4692 L
.07875 .46881 L
.07912 .46843 L
.07954 .46806 L
.07998 .4677 L
.08044 .46732 L
.08085 .46692 L
.0812 .46647 L
.08148 .46605 L
.08177 .46565 L
.08204 .4653 L
.08231 .46503 L
.08256 .46483 L
.08278 .46471 L
.08295 .46465 L
Mfstroke
.07677 .49733 m
.07671 .49746 L
.07662 .49772 L
.07647 .49813 L
.07621 .4987 L
.07584 .4995 L
.07534 .50051 L
.0747 .50168 L
.07411 .50295 L
.07337 .50445 L
.07257 .50623 L
.07174 .50832 L
.071 .51032 L
.07017 .51283 L
.06945 .515 L
.06879 .5174 L
.0682 .52012 L
.06772 .52287 L
.06738 .52503 L
.06719 .52754 L
.06715 .53013 L
.06722 .5322 L
.06739 .53421 L
.06762 .53598 L
.06789 .53758 L
.06816 .53878 L
.06841 .53986 L
.06866 .54057 L
.06891 .541 L
.06915 .54118 L
.06937 .54115 L
.06954 .54101 L
.06965 .5408 L
.06969 .5406 L
.06967 .54045 L
.06961 .54041 L
.06952 .54055 L
.06945 .54091 L
.06942 .54151 L
.06946 .54233 L
.0696 .54336 L
.06981 .5446 L
.07009 .5459 L
.07045 .54735 L
.07085 .54889 L
.07127 .55046 L
.07173 .55195 L
.0722 .55336 L
.07267 .55461 L
.07309 .55564 L
Mistroke
.07348 .55646 L
.07382 .55708 L
.07408 .55749 L
.07427 .55772 L
.07437 .55782 L
.07441 .55783 L
.0744 .55778 L
.07436 .55768 L
.07431 .55755 L
.07427 .55737 L
.07424 .5572 L
.07423 .55705 L
.07423 .55697 L
.07423 .55695 L
.07423 .55704 L
.07422 .55725 L
.07419 .55762 L
.07414 .55814 L
.07407 .55882 L
.074 .55967 L
.07394 .56069 L
.0739 .56182 L
.07391 .56307 L
.07395 .56444 L
.07405 .56589 L
.07418 .56733 L
.07435 .56868 L
.07454 .56992 L
.07473 .57101 L
.07493 .57192 L
.07517 .57264 L
.07544 .5732 L
.07574 .57363 L
.07605 .57398 L
.07633 .5743 L
.07656 .57462 L
.07672 .57496 L
.07681 .57533 L
.07685 .57574 L
.07687 .57619 L
.0769 .57672 L
.07697 .57733 L
.07711 .57805 L
.07732 .57887 L
.07756 .57971 L
.07783 .58059 L
.07811 .58146 L
.07837 .5823 L
.07869 .58307 L
.07903 .58375 L
Mistroke
.07941 .58433 L
.07978 .58484 L
.08017 .58527 L
.08052 .58563 L
.08081 .58592 L
.08101 .58616 L
.08112 .58633 L
.08115 .58644 L
.08114 .58647 L
.0811 .58644 L
.08106 .58637 L
.08101 .58628 L
.08096 .58618 L
.08092 .58606 L
.08088 .58594 L
.08085 .58584 L
.08083 .58578 L
.08084 .58578 L
.08089 .58586 L
.08099 .58607 L
.08113 .58644 L
.0813 .58699 L
.08147 .5877 L
.08166 .58856 L
.08185 .5896 L
.08204 .59073 L
.08223 .59195 L
.0824 .59319 L
.08257 .59438 L
.08273 .59546 L
.08288 .59634 L
.08299 .59697 L
.08306 .59735 L
.0831 .5975 L
.08311 .59742 L
.08311 .59713 L
.08312 .59668 L
.08315 .59614 L
.0832 .59556 L
.08325 .59498 L
.0833 .59441 L
.08333 .59388 L
.08334 .59348 L
.08333 .59324 L
.08332 .59314 L
.08331 .59311 L
.08331 .59314 L
.08333 .59318 L
.08336 .59317 L
.0834 .59312 L
Mistroke
.08344 .59305 L
.08346 .593 L
.08345 .59303 L
.08341 .59316 L
.08332 .59342 L
.08319 .59383 L
.08301 .59437 L
.08276 .59501 L
.08244 .59575 L
.08205 .59658 L
.08161 .59746 L
.08116 .59835 L
.08073 .59923 L
.08032 .60006 L
.07996 .60083 L
.07964 .60149 L
.07935 .60203 L
.07912 .60244 L
.07892 .60276 L
.07876 .60299 L
.07865 .60315 L
.07859 .60328 L
.07858 .60342 L
.07861 .60358 L
.07869 .60376 L
.0788 .60395 L
.07893 .60414 L
.07907 .60436 L
.07918 .60455 L
.0793 .60476 L
.07943 .60499 L
.07955 .60516 L
.07971 .60532 L
.0799 .60544 L
.08007 .60551 L
.0802 .60556 L
.08028 .60562 L
.08031 .60569 L
.0803 .60575 L
.08029 .60578 L
.08027 .60578 L
.08026 .60576 L
.08025 .60574 L
.08024 .60572 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
Mistroke
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .6057 L
.08023 .60569 L
.08023 .60565 L
.08023 .60556 L
.08024 .60543 L
.08024 .60531 L
.08024 .60524 L
.08024 .60524 L
.08024 .60537 L
.08023 .60563 L
.08022 .60606 L
.08019 .60666 L
.08017 .60743 L
.08013 .60836 L
.08009 .60943 L
.08005 .61051 L
.08001 .61163 L
.07997 .61277 L
.07993 .61393 L
.07989 .61494 L
.07986 .61579 L
.07982 .61643 L
.07978 .61685 L
.07973 .61708 L
.07968 .61718 L
.07965 .61719 L
.07964 .6172 L
.07965 .6173 L
.07969 .61758 L
.07978 .61808 L
.07992 .61885 L
.08014 .61996 L
.08042 .62146 L
Mistroke
.08079 .62324 L
.0812 .62539 L
.08167 .62796 L
.0822 .63078 L
.08279 .63416 L
.0834 .63768 L
.08402 .64106 L
.08463 .64502 L
.08521 .64932 L
.08574 .65298 L
.08624 .65714 L
.08672 .66159 L
.08718 .66513 L
.08761 .66906 L
.08802 .67262 L
.08842 .67609 L
.08878 .67898 L
.08912 .68163 L
.08941 .68384 L
.08966 .68546 L
.08989 .68679 L
.0901 .68784 L
.09032 .6886 L
.09053 .68914 L
.09074 .68955 L
.09096 .68996 L
.09116 .69043 L
.09136 .69098 L
.09154 .69163 L
.09173 .69243 L
.09194 .69336 L
.0922 .69449 L
.09249 .69573 L
.09281 .697 L
.09312 .69828 L
.09343 .69958 L
.09372 .70079 L
.094 .702 L
.09429 .70329 L
.09458 .70475 L
.0949 .70639 L
.0953 .70832 L
.0957 .71005 L
.09615 .71226 L
.09663 .71473 L
.09709 .71705 L
.09756 .71962 L
.09803 .72234 L
.09851 .72501 L
.099 .72793 L
Mistroke
.09948 .73007 L
.09994 .73227 L
.10034 .73422 L
.10066 .73581 L
.10089 .73704 L
.10104 .73791 L
.10116 .73846 L
.10126 .73871 L
.10135 .73879 L
.10146 .73878 L
.10157 .73868 L
.10167 .73861 L
.10177 .73857 L
.10186 .73858 L
.10193 .73864 L
.102 .73874 L
.10208 .73885 L
.10218 .73897 L
.10231 .73908 L
.10246 .7392 L
.10261 .73937 L
.10275 .73957 L
.10286 .73981 L
.10294 .74007 L
.10296 .7403 L
.10293 .74046 L
.10283 .74051 L
.10269 .74047 L
.10253 .74036 L
.10232 .7402 L
.10209 .74001 L
.10185 .73984 L
.10164 .73977 L
.10146 .73975 L
.10134 .73975 L
.10129 .73976 L
.10132 .7398 L
.10144 .73991 L
.10165 .74012 L
.10197 .74044 L
.10238 .74087 L
.10284 .74137 L
.10332 .74193 L
.10379 .7424 L
.10423 .74289 L
.10464 .74326 L
.10501 .74348 L
.10533 .74362 L
.10565 .74369 L
.10599 .74371 L
Mistroke
.10637 .74367 L
.10679 .74359 L
.10725 .74348 L
.10771 .74339 L
.10821 .7433 L
.10868 .7433 L
.10915 .74333 L
.10956 .74338 L
.1099 .74348 L
.11013 .74364 L
.11022 .74385 L
.11017 .74402 L
.10999 .74413 L
.10967 .74425 L
.10925 .74437 L
.10877 .74448 L
.10825 .74455 L
.10773 .74456 L
.10726 .74454 L
.10686 .7445 L
.10657 .74452 L
.1064 .74459 L
.10635 .74472 L
.10645 .7449 L
.10667 .7452 L
.10697 .74561 L
.10735 .74611 L
.10778 .74667 L
.10826 .74726 L
.10882 .7479 L
.10927 .74843 L
.10978 .74904 L
.11024 .74967 L
.11064 .7503 L
.11096 .75085 L
.11118 .7513 L
.11129 .75163 L
.11133 .75185 L
.11133 .75198 L
.11133 .75205 L
.11148 .75198 L
.11149 .75199 L
.11155 .75203 L
.11162 .75208 L
.11171 .75215 L
.11181 .75221 L
.11192 .75224 L
.11203 .75225 L
.11213 .75224 L
.11223 .7522 L
Mistroke
.11233 .75217 L
.11243 .75216 L
.1125 .75217 L
.11252 .75219 L
.11248 .75219 L
.11236 .75217 L
.11217 .75207 L
.11194 .7519 L
.11171 .75169 L
.11149 .75148 L
.11129 .75129 L
.11115 .75118 L
.11105 .75114 L
.11098 .75117 L
.11092 .75125 L
.11087 .75137 L
.11078 .75151 L
.11067 .75165 L
.11054 .75176 L
.11042 .75186 L
.11035 .75195 L
.11036 .75208 L
.11044 .75225 L
.1106 .75245 L
.1108 .7526 L
.11102 .75269 L
.11126 .75273 L
.11155 .75274 L
.11181 .75273 L
.1121 .7527 L
.11237 .75268 L
.11262 .75265 L
.11279 .75261 L
.11285 .75251 L
.11279 .75235 L
.11264 .75215 L
.11241 .75193 L
.11213 .75169 L
.11181 .75143 L
.1115 .75118 L
.11122 .75098 L
.11101 .75091 L
.11089 .75101 L
.11089 .7513 L
.11104 .75182 L
.11134 .75253 L
.11181 .75347 L
.11243 .75442 L
.11318 .75551 L
.114 .75665 L
Mistroke
.11495 .7578 L
.116 .75894 L
.11714 .7601 L
.11833 .76125 L
.11953 .76233 L
.12069 .76332 L
.12178 .76418 L
.12276 .76491 L
.12359 .76552 L
.12427 .76598 L
.1248 .76632 L
.12515 .76657 L
.12538 .76681 L
.12546 .76706 L
.12542 .76728 L
.12528 .76749 L
.12508 .76765 L
.12481 .76777 L
.12455 .76787 L
.1243 .76798 L
.12406 .76809 L
.12385 .76821 L
.12377 .7684 L
.12379 .76863 L
.12392 .76886 L
.12411 .76905 L
.12439 .76919 L
.12473 .76929 L
.12513 .76935 L
.12558 .76937 L
.12602 .76938 L
.12647 .76936 L
.12686 .76933 L
.12722 .7693 L
.12756 .76932 L
.12789 .76937 L
.12818 .76944 L
.12843 .76949 L
.12859 .76948 L
.12865 .76942 L
.12859 .76935 L
.12845 .76927 L
.12827 .7692 L
.12809 .76913 L
.12794 .76906 L
.12781 .76901 L
.12772 .76901 L
.12767 .7691 L
.12765 .76931 L
.12765 .7696 L
Mistroke
.12766 .76995 L
.12772 .77037 L
.1278 .77086 L
.12789 .77141 L
.128 .77199 L
.12811 .77254 L
.12823 .77308 L
.12834 .77359 L
.12847 .77405 L
.12863 .77446 L
.12885 .77482 L
.12917 .77511 L
.1296 .77533 L
.13017 .77553 L
.13088 .77567 L
.13166 .77575 L
.13253 .77578 L
.13341 .77581 L
.13428 .77587 L
.13509 .77594 L
.13581 .77601 L
.13638 .77607 L
.13671 .77613 L
.13701 .77617 L
.13721 .77621 L
.13728 .77623 L
.13723 .77623 L
.13706 .77619 L
.1368 .77614 L
.13649 .7761 L
.13616 .77605 L
.1358 .77598 L
.13542 .77587 L
.13503 .77573 L
.13463 .77557 L
.13425 .77545 L
.13395 .77541 L
.13376 .77549 L
.13371 .77574 L
.13381 .77615 L
.13405 .77674 L
.13443 .77748 L
.13497 .77836 L
.13557 .77933 L
.13613 .7803 L
.13687 .78131 L
.13775 .78237 L
.13869 .78341 L
.13972 .78447 L
.14082 .78555 L
Mistroke
.14197 .78665 L
.14319 .78777 L
.14447 .78894 L
.14575 .79011 L
.14707 .79134 L
.14856 .79273 L
.14979 .79393 L
.15118 .79531 L
.15249 .79666 L
.15373 .79801 L
.15482 .79928 L
.15568 .80039 L
.15633 .8013 L
.15679 .80201 L
.15705 .80251 L
.15713 .80282 L
.15705 .80297 L
.15685 .80299 L
.15655 .80287 L
.1562 .80265 L
.15585 .8024 L
.15554 .80217 L
.15535 .80204 L
.15535 .80208 L
.15559 .80237 L
.1561 .80288 L
.15691 .8037 L
.15798 .80479 L
.15938 .80618 L
.16112 .80789 L
.16317 .8099 L
.16546 .81195 L
.16797 .81423 L
.17076 .81691 L
.1735 .81942 L
.17641 .82212 L
.17935 .82489 L
.18233 .82766 L
.18523 .83049 L
.18817 .83326 L
.19115 .83613 L
.1942 .83905 L
.19732 .84209 L
.2006 .8455 L
.20366 .84842 L
.20695 .85184 L
.21033 .85531 L
.21368 .85865 L
.21698 .86199 L
.22024 .86528 L
Mistroke
.22326 .86835 L
.22615 .87123 L
.22874 .8738 L
.23109 .87611 L
.23311 .87794 L
.23483 .87942 L
.23622 .88052 L
.23741 .88127 L
.23818 .8817 L
.23881 .88195 L
.23924 .88203 L
.23948 .88201 L
.23964 .88195 L
.2397 .88185 L
.23973 .88177 L
.23976 .88173 L
.23986 .88184 L
.24003 .88206 L
.24032 .88242 L
.24076 .88292 L
.24137 .88358 L
.24214 .88434 L
.24306 .88512 L
.2441 .88589 L
.24535 .88666 L
.24673 .88743 L
.24825 .88822 L
.24985 .889 L
.25144 .88978 L
.253 .89052 L
.2544 .89115 L
.25558 .89159 L
.25653 .89189 L
.25729 .89213 L
.25788 .89231 L
.2583 .89241 L
.25859 .89245 L
.25875 .89244 L
.25876 .89241 L
.25865 .8924 L
.25844 .89238 L
.25816 .89235 L
.25783 .8923 L
.25752 .89229 L
.25724 .89229 L
.25698 .89239 L
.25673 .89254 L
.25647 .89276 L
.25632 .89299 L
.25611 .89316 L
Mistroke
.25593 .89339 L
.25584 .89368 L
.25595 .89412 L
.25625 .89465 L
.25683 .89536 L
.25772 .89622 L
.2589 .8972 L
.26037 .89823 L
.26206 .89926 L
.26402 .90037 L
.26621 .90153 L
.26868 .90279 L
.27126 .90412 L
.27389 .90543 L
.27665 .90673 L
.27935 .90801 L
.28222 .90923 L
.28483 .91044 L
.28751 .91162 L
.29018 .91275 L
.29281 .91387 L
.29543 .91495 L
.29807 .916 L
.30077 .91701 L
.30358 .91798 L
.30657 .91892 L
.3096 .91985 L
.31282 .92077 L
.31626 .9217 L
.31951 .92265 L
.32283 .92362 L
.3262 .92461 L
.32964 .92558 L
.3327 .92657 L
.33573 .92753 L
.33854 .92842 L
.34106 .92922 L
.3433 .92995 L
.34524 .9306 L
.34683 .93116 L
.34824 .93164 L
.34944 .93205 L
.35061 .93243 L
.35179 .93281 L
.35304 .93321 L
.35441 .93369 L
.35591 .93427 L
.35762 .93491 L
.35961 .93565 L
.36176 .9365 L
Mistroke
.36423 .93746 L
.36704 .93848 L
.37006 .93952 L
.37344 .94062 L
.37676 .94172 L
.38041 .94286 L
.38387 .94408 L
.38739 .94528 L
.39106 .94659 L
.39465 .94799 L
.39834 .94931 L
.4021 .95072 L
.40596 .9521 L
.40979 .95358 L
.41368 .95498 L
.41775 .95658 L
.42171 .95798 L
.42588 .9594 L
.42994 .96081 L
.4341 .96215 L
.43809 .96336 L
.44216 .9644 L
.44593 .96523 L
.44962 .96592 L
.45306 .96654 L
.45626 .96707 L
.45936 .96751 L
.46194 .96784 L
.46436 .96805 L
.46651 .96813 L
.46843 .96809 L
.47003 .96796 L
.47148 .96775 L
.47252 .96754 L
.47339 .96736 L
.47407 .96725 L
.47462 .96716 L
.47502 .96706 L
.47533 .96694 L
.47558 .96681 L
.47577 .96668 L
.47587 .96656 L
.4759 .96646 L
.47585 .96639 L
.47575 .96637 L
.47558 .96638 L
.4754 .96642 L
.47521 .96647 L
.47501 .96651 L
.47476 .96654 L
Mistroke
.47447 .96657 L
.47414 .96658 L
.47384 .9666 L
.47349 .96662 L
.47314 .96664 L
.47283 .96665 L
.47258 .96665 L
.47235 .96664 L
.47214 .96664 L
.47201 .96665 L
.47193 .96667 L
.4719 .9667 L
.47195 .96642 L
.47207 .96647 L
.47225 .96653 L
.47249 .96658 L
.47282 .96662 L
.4732 .96665 L
.47357 .96668 L
.47387 .96671 L
.47418 .96674 L
.47445 .96678 L
.47466 .96684 L
.47484 .96691 L
.47505 .96699 L
.47528 .96708 L
.47556 .96718 L
.47589 .96726 L
.47632 .96729 L
.47686 .9673 L
.47753 .96728 L
.47833 .96722 L
.47933 .96712 L
.48051 .96696 L
.48186 .96674 L
.48336 .96647 L
.48492 .96619 L
.48659 .9659 L
.48836 .96562 L
.49029 .96537 L
.4923 .96514 L
.49462 .96494 L
.49666 .96476 L
.49906 .96458 L
.50152 .96437 L
.5042 .96414 L
.50704 .96387 L
.51014 .96356 L
.51325 .96321 L
.51633 .96281 L
Mistroke
.51937 .96239 L
.52254 .96197 L
.52553 .96153 L
.52849 .96108 L
.53145 .96065 L
.53408 .96026 L
.53675 .95988 L
.53936 .95954 L
.54193 .9592 L
.54446 .95881 L
.54697 .95833 L
.54942 .95771 L
.55186 .95699 L
.5542 .95616 L
.55642 .95535 L
.55861 .95452 L
.56061 .95377 L
.56253 .95318 L
.56431 .95266 L
.56578 .95223 L
.56703 .95191 L
.5681 .9517 L
.56904 .95162 L
.56995 .95172 L
.57096 .95196 L
.57224 .95231 L
.57357 .95271 L
.5753 .95306 L
.5773 .95334 L
.57958 .95346 L
.58223 .9534 L
.58508 .95318 L
.5882 .95288 L
.59162 .95243 L
.59497 .95189 L
.5989 .9515 L
.60247 .9509 L
.60608 .95027 L
.60962 .94961 L
.61297 .94889 L
.6162 .94817 L
.61933 .94737 L
.62235 .9465 L
.62532 .94563 L
.62823 .94477 L
.63098 .94396 L
.63357 .94317 L
.63594 .94249 L
.63806 .9418 L
.63995 .94114 L
Mistroke
.64159 .94054 L
.64309 .94005 L
.64445 .93964 L
.64572 .93927 L
.64691 .9389 L
.64802 .93854 L
.64901 .93828 L
.64981 .93814 L
.65052 .93802 L
.65112 .93797 L
.65163 .93793 L
.6521 .93782 L
.65252 .93767 L
.65286 .93753 L
.65303 .93745 L
.65299 .93747 L
.65275 .93757 L
.65234 .93779 L
.65181 .93812 L
.65123 .93849 L
.65069 .9388 L
.65025 .93911 L
.6499 .93943 L
.64962 .93975 L
.64936 .94002 L
.64914 .94029 L
.64892 .94056 L
.64868 .94077 L
.6485 .94089 L
.64844 .94087 L
.64841 .94079 L
.64851 .94047 L
.64871 .93996 L
.64897 .93933 L
.64917 .93878 L
.64933 .93823 L
.64943 .93767 L
.64956 .93707 L
.64968 .93662 L
.64987 .93616 L
.65008 .93578 L
.6503 .93555 L
.65044 .93553 L
.65054 .93562 L
.65058 .93582 L
.65052 .93605 L
.65038 .93642 L
.65024 .93676 L
.65016 .937 L
.65022 .93718 L
Mistroke
.6504 .9373 L
.65069 .93735 L
.65112 .93722 L
.65159 .93708 L
.65199 .93694 L
.6523 .93677 L
.65252 .93653 L
.65263 .93642 L
.65255 .93648 L
.65233 .9367 L
.65194 .93702 L
.65141 .93749 L
.65081 .93805 L
.65026 .93855 L
.64982 .93884 L
.64951 .93899 L
.64925 .93908 L
.64906 .93913 L
.64906 .93907 L
.64919 .93898 L
.64938 .93891 L
.6497 .93878 L
.65006 .93862 L
.65039 .93849 L
.65063 .93845 L
.65075 .93847 L
.65072 .93862 L
.65059 .93885 L
.65043 .93912 L
.65023 .9394 L
.65007 .93963 L
.64996 .93974 L
.64991 .93976 L
.65001 .93958 L
.65024 .93927 L
.65055 .93888 L
.65082 .93856 L
.65112 .93821 L
.65142 .93791 L
.65177 .93762 L
.65203 .93745 L
.65229 .9373 L
.6525 .93723 L
.65268 .93722 L
.65285 .9373 L
.65307 .93742 L
.65336 .9375 L
.65367 .93757 L
.65391 .93769 L
.65402 .93788 L
Mistroke
.65402 .93809 L
.65391 .93834 L
.65373 .93859 L
.65352 .93878 L
.65336 .93886 L
.65324 .93886 L
.65316 .93879 L
.65307 .93867 L
.65301 .93848 L
.65298 .93829 L
.65293 .93815 L
.6529 .93802 L
.65293 .93788 L
.6531 .93771 L
.65341 .93753 L
.65378 .93736 L
.65422 .93718 L
.65462 .93707 L
.6549 .93703 L
.65504 .9371 L
.65505 .93726 L
.65498 .93748 L
.65483 .93774 L
.65466 .93797 L
.65449 .93814 L
.6543 .93812 L
.65412 .93822 L
.65394 .93831 L
.6538 .93834 L
.65376 .93828 L
.65375 .93821 L
.65384 .93804 L
.65399 .93781 L
.65418 .93754 L
.65431 .93734 L
.65444 .93713 L
.65455 .93695 L
.65461 .93684 L
.65454 .93684 L
.65442 .93689 L
.65426 .93695 L
.65404 .93708 L
.65371 .93732 L
.65337 .93762 L
.65309 .93793 L
.65287 .93827 L
.65265 .9387 L
.65247 .93915 L
.65236 .93956 L
.65227 .94 L
Mistroke
.65222 .94046 L
.65223 .94094 L
.65228 .94138 L
.65231 .94177 L
.65232 .94211 L
.65232 .94233 L
.65242 .94241 L
.6526 .94236 L
.65289 .94221 L
.65335 .94184 L
.65393 .9413 L
.65455 .94071 L
.65512 .94016 L
.65568 .93956 L
.65617 .93901 L
.65657 .93857 L
.65691 .93822 L
.6572 .93796 L
.6574 .9378 L
.65753 .93778 L
.65761 .93784 L
.65771 .9379 L
.65777 .93794 L
.65779 .93798 L
.6578 .938 L
.65788 .93792 L
.65807 .93777 L
.65841 .93759 L
.65886 .93739 L
.65945 .93717 L
.66008 .93692 L
.66076 .93667 L
.66141 .9364 L
.66204 .93613 L
.66263 .93585 L
.66318 .93561 L
.66366 .93547 L
.664 .93544 L
.66412 .93553 L
.66403 .93574 L
.66378 .93601 L
.66345 .9363 L
.66308 .93653 L
.66279 .93665 L
.66245 .93671 L
.66202 .93685 L
.6615 .93712 L
.66091 .93751 L
.66025 .93799 L
.65946 .93872 L
Mistroke
.65862 .93933 L
.65785 .93987 L
.65732 .94025 L
.657 .94048 L
.65683 .94055 L
.65675 .94055 L
.65665 .94049 L
.65638 .94055 L
.65623 .94049 L
.65614 .94036 L
.65624 .9401 L
.65666 .93965 L
.6573 .93912 L
.65807 .93856 L
.65882 .93804 L
.65949 .93758 L
.65987 .93732 L
.65988 .93727 L
.65962 .93736 L
.6591 .93745 L
.65845 .93756 L
.65767 .93766 L
.65695 .93772 L
.65635 .93768 L
.65594 .93753 L
.65567 .93731 L
.65542 .93713 L
.65516 .93704 L
.65494 .93707 L
.65481 .9372 L
.65481 .93743 L
.65495 .93769 L
.65521 .93793 L
.6555 .93814 L
.65571 .93833 L
.65577 .93853 L
.65562 .93876 L
.65536 .939 L
.65503 .93926 L
.65471 .93948 L
.65445 .93956 L
.65435 .93952 L
.65433 .93942 L
.65438 .93929 L
.6545 .93915 L
.65461 .93907 L
.65471 .93903 L
.65477 .93898 L
.65481 .93897 L
.65491 .93896 L
Mistroke
.65514 .93893 L
.65547 .93888 L
.65594 .93879 L
.65639 .93874 L
.65673 .93878 L
.65697 .93887 L
.65711 .93905 L
.65718 .93925 L
.65726 .9394 L
.65739 .9394 L
.65756 .93928 L
.65768 .93911 L
.65766 .93891 L
.65741 .93878 L
.65695 .93866 L
.65635 .9385 L
.65577 .93835 L
.65534 .93807 L
.65524 .93746 L
.65519 .93714 L
.65533 .93689 L
.65561 .93672 L
.65603 .93664 L
.65642 .93666 L
.65679 .93675 L
.65708 .93687 L
.65729 .93699 L
.65742 .93713 L
.65742 .93734 L
.65731 .93761 L
.65704 .93796 L
.65661 .93837 L
.656 .93884 L
.65526 .93932 L
.65436 .93979 L
.65357 .9401 L
.65279 .94037 L
.65206 .94059 L
.65149 .94075 L
.65107 .94087 L
.65081 .94096 L
.65075 .94092 L
.65083 .94079 L
.65111 .94054 L
.65156 .94019 L
.65215 .93975 L
.65287 .93919 L
.65363 .93868 L
.65437 .93829 L
.65514 .93793 L
Mistroke
.65591 .93766 L
.65661 .93752 L
.65727 .93743 L
.65787 .93733 L
.6584 .93724 L
.65878 .9372 L
.65899 .93722 L
.65901 .93731 L
.65886 .93748 L
.65859 .93771 L
.65831 .9379 L
.65812 .93799 L
.65815 .93795 L
.65842 .93778 L
.65882 .93757 L
.65937 .93729 L
.66003 .93699 L
.6609 .93663 L
.66168 .93633 L
.66262 .93599 L
.66354 .93567 L
.66439 .9354 L
.6651 .93517 L
.66567 .93497 L
.66609 .93479 L
.66629 .9347 L
.6662 .93475 L
.66587 .93491 L
.66534 .93516 L
.66472 .93545 L
.66399 .93578 L
.66325 .9361 L
.66263 .93638 L
.66224 .93658 L
.66208 .93672 L
.66217 .9368 L
.66252 .9368 L
.66303 .9368 L
.66365 .93678 L
.66455 .93665 L
.66586 .93616 L
.66717 .93589 L
.66864 .93552 L
.67024 .93503 L
.67195 .93442 L
.67371 .93372 L
.67554 .93293 L
.67739 .93208 L
.6792 .93114 L
.68087 .93013 L
Mistroke
.68249 .92903 L
.68402 .92792 L
.68543 .92674 L
.68665 .92563 L
.68765 .92465 L
.68842 .92381 L
.68896 .92313 L
.68924 .92265 L
.68928 .9224 L
.68908 .92237 L
.68867 .92252 L
.68809 .92282 L
.68746 .92323 L
.68677 .92378 L
.68608 .92445 L
.68552 .92503 L
.68505 .92562 L
.68476 .92602 L
.6847 .92617 L
.68486 .92609 L
.68515 .92583 L
.68544 .92547 L
.68574 .92509 L
.68602 .92472 L
.68628 .92439 L
.68651 .9241 L
.6867 .92381 L
.68687 .92357 L
.687 .92341 L
.68712 .92334 L
.68721 .92337 L
.68721 .92354 L
.68712 .92383 L
.687 .92422 L
.68695 .92464 L
.68701 .925 L
.6872 .92525 L
.68749 .9254 L
.6878 .92542 L
.6881 .92543 L
.68836 .9255 L
.68851 .92567 L
.68863 .92588 L
.68876 .92608 L
.68899 .92621 L
.68942 .92619 L
.69007 .92599 L
.69097 .92561 L
.69183 .9252 L
.69285 .9247 L
Mistroke
.69387 .92413 L
.69478 .92353 L
.69576 .92295 L
.69663 .92235 L
.69739 .92175 L
.69799 .92118 L
.69838 .92072 L
.69854 .92037 L
.69842 .92016 L
.69801 .92015 L
.69731 .92033 L
.69645 .92063 L
.69561 .92095 L
.6948 .92125 L
.69429 .92137 L
.69364 .92163 L
.69302 .92186 L
.69245 .92213 L
.6919 .92246 L
.6914 .92291 L
.6909 .92343 L
.69039 .92398 L
.68988 .92451 L
.6894 .92494 L
.68891 .92533 L
.68852 .92558 L
.68812 .92581 L
.68778 .92593 L
.6875 .92598 L
.68731 .92601 L
.68723 .92602 L
.68716 .92602 L
.68712 .926 L
.6871 .92598 L
.68705 .92598 L
.68698 .92597 L
.68682 .92609 L
.68657 .92636 L
.68625 .92673 L
.68589 .92712 L
.68548 .92748 L
.68501 .92778 L
.68446 .92801 L
.68386 .92815 L
.68322 .92821 L
.68258 .92819 L
.68202 .92818 L
.68143 .92822 L
.6809 .92834 L
.68045 .92853 L
Mistroke
.68006 .9288 L
.6797 .92912 L
.67938 .92951 L
.67913 .92994 L
.67894 .93039 L
.67878 .93084 L
.67862 .93129 L
.67843 .93174 L
.6782 .93217 L
.67793 .93255 L
.67762 .93287 L
.67733 .93312 L
.67707 .93329 L
.67686 .93339 L
.67668 .93344 L
.67659 .93343 L
.67654 .93338 L
.67652 .93333 L
.67654 .93327 L
.67658 .93326 L
.67662 .9333 L
.67665 .93337 L
.67667 .93344 L
.67667 .93345 L
.67669 .93339 L
.67669 .93325 L
.67667 .93304 L
.67661 .93281 L
.67651 .93258 L
.67636 .93235 L
.67622 .9321 L
.67615 .9318 L
.67616 .93146 L
.67624 .93111 L
.67636 .93077 L
.67647 .93048 L
.67654 .93028 L
.67654 .93021 L
.67649 .93028 L
.67641 .93051 L
.67631 .93085 L
.67619 .93123 L
.67611 .93156 L
.67607 .9318 L
.67612 .93193 L
.67608 .93202 L
.676 .93209 L
.67586 .93218 L
.67568 .9323 L
.67547 .93244 L
Mistroke
.6753 .93256 L
.6752 .93263 L
.67521 .93262 L
.67527 .93258 L
.67534 .93255 L
.67536 .93262 L
.67536 .93277 L
.67535 .93295 L
.67537 .93311 L
.6754 .93323 L
.67545 .93327 L
.67549 .93325 L
.67549 .93316 L
.67549 .933 L
.67547 .93281 L
.67541 .93265 L
.67529 .93258 L
.67515 .93261 L
.67504 .93272 L
.67498 .93286 L
.67494 .93304 L
.67494 .93321 L
.67496 .93335 L
.67498 .93342 L
.67497 .9334 L
.67489 .93328 L
.67471 .93304 L
.67441 .9328 L
.67402 .93246 L
.6736 .93205 L
.67317 .9316 L
.67267 .93113 L
.67215 .9307 L
.67167 .93033 L
.67132 .93 L
.67108 .9297 L
.67092 .92944 L
.6708 .92927 L
.67068 .92924 L
.67048 .92934 L
.67022 .92951 L
.66989 .92971 L
.66951 .92989 L
.66906 .93004 L
.66858 .93014 L
.66814 .93023 L
.66783 .93031 L
.66757 .93037 L
.66737 .93042 L
.66726 .93047 L
Mistroke
.66721 .93054 L
.66727 .93057 L
.66741 .93058 L
.66757 .93065 L
.66763 .93083 L
.66757 .93112 L
.66733 .93151 L
.66696 .93193 L
.66646 .93238 L
.66589 .93284 L
.66515 .93328 L
.66457 .9336 L
.66399 .93384 L
.66341 .93401 L
.66282 .93409 L
.66231 .93409 L
.66188 .93406 L
.66148 .93395 L
.66125 .93414 L
.66102 .9339 L
.66088 .93358 L
.66072 .93326 L
.66038 .9329 L
.65997 .93262 L
.65955 .93242 L
.65908 .93222 L
.65866 .93208 L
.65832 .93194 L
.65824 .93191 L
.65835 .93192 L
.6587 .93202 L
.65924 .93219 L
.6599 .93239 L
.66057 .93259 L
.66125 .93277 L
.66193 .93288 L
.66271 .93295 L
.66352 .93293 L
.66433 .93289 L
.66508 .93284 L
.66576 .93272 L
.66634 .93247 L
.66684 .93211 L
.66729 .93169 L
.66769 .93125 L
.66807 .93085 L
.66851 .93051 L
.66909 .9303 L
.66985 .93021 L
.67071 .9302 L
Mistroke
.67163 .93021 L
.67273 .93019 L
.67398 .93009 L
.67538 .92989 L
.67688 .92957 L
.67848 .9292 L
.68014 .92873 L
.68186 .92821 L
.68359 .92764 L
.68533 .92703 L
.68709 .92636 L
.68869 .9256 L
.69041 .92475 L
.69213 .92381 L
.69393 .92278 L
.69577 .92165 L
.69764 .92039 L
.69954 .91899 L
.70148 .91743 L
.70346 .91571 L
.70546 .91388 L
.70746 .91195 L
.70946 .90996 L
.71144 .90794 L
.71342 .90593 L
.71557 .90366 L
.71726 .90193 L
.71893 .90007 L
.72039 .89847 L
.72161 .89712 L
.72259 .89609 L
.72335 .89539 L
.7239 .89497 L
.72425 .89477 L
.72443 .89473 L
.72448 .89481 L
.72441 .89494 L
.72423 .89509 L
.72397 .89522 L
.72368 .89522 L
.72336 .89511 L
.72304 .89486 L
.72275 .8945 L
.72247 .89401 L
.72222 .89338 L
.72198 .89267 L
.72173 .89199 L
.72146 .89143 L
.72114 .89099 L
.72078 .89072 L
Mistroke
.72042 .89067 L
.72009 .89087 L
.71981 .89128 L
.71959 .89167 L
.71941 .89243 L
.71923 .89325 L
.71902 .89435 L
.71874 .89538 L
.71836 .89641 L
.71784 .89766 L
.71721 .89877 L
.71643 .89993 L
.7155 .90113 L
.71446 .9022 L
.71326 .90328 L
.71191 .90429 L
.71051 .90522 L
.70897 .90609 L
.70744 .90698 L
.70583 .90787 L
.70429 .90876 L
.70279 .90969 L
.70133 .91073 L
.69987 .9119 L
.69834 .91318 L
.69678 .91453 L
.69513 .91596 L
.69334 .91737 L
.69159 .9189 L
.68969 .92051 L
.68765 .9222 L
.68554 .92388 L
.68344 .92545 L
.68134 .92689 L
.6793 .92817 L
.67746 .92925 L
.67572 .93013 L
.67418 .93077 L
.67286 .93122 L
.67184 .93157 L
.67088 .9319 L
.67005 .93221 L
.66925 .93249 L
.66837 .93283 L
.66739 .93325 L
.6663 .93375 L
.66495 .93425 L
.66326 .93484 L
.6612 .93553 L
.65894 .93632 L
Mistroke
.65598 .93726 L
.65306 .93823 L
.64948 .93927 L
.64585 .9403 L
.6418 .94127 L
.63809 .94224 L
.63415 .94322 L
.63044 .94412 L
.6265 .94496 L
.62301 .94572 L
.61935 .94646 L
.61592 .94709 L
.6128 .94765 L
.60952 .94807 L
.60637 .94836 L
.60325 .94849 L
.60011 .94859 L
.59719 .94869 L
.59405 .94881 L
.59111 .94889 L
.5879 .94902 L
.58464 .94924 L
.58097 .94959 L
.57748 .95001 L
.5737 .95052 L
.56945 .9511 L
.56576 .95172 L
.56162 .95249 L
.55779 .95335 L
.55372 .95426 L
.54998 .9551 L
.54616 .95584 L
.54233 .95646 L
.53887 .95694 L
.53545 .95732 L
.53219 .9576 L
.5292 .95782 L
.52645 .95805 L
.52404 .95835 L
.52211 .95874 L
.52016 .95917 L
.51855 .95962 L
.51704 .96007 L
.51571 .9605 L
.51459 .96086 L
.51368 .96116 L
.51301 .96136 L
.51253 .96141 L
.51222 .96136 L
.51206 .96122 L
Mistroke
.512 .96097 L
.51195 .96064 L
.51185 .9602 L
.5117 .95967 L
.51149 .95912 L
.51123 .95861 L
.51094 .9582 L
.51063 .95796 L
.51033 .9579 L
.51002 .95799 L
.50971 .95819 L
.50939 .95846 L
.50909 .95873 L
.50875 .95897 L
.50843 .95916 L
.50814 .95932 L
.50784 .95947 L
.50752 .95957 L
.50722 .95962 L
.50688 .95963 L
.50645 .95959 L
.50588 .95951 L
.50517 .95937 L
.50437 .95918 L
.5034 .95895 L
.50229 .95869 L
.50111 .95839 L
.4999 .95806 L
.49874 .95772 L
.49762 .95736 L
.49655 .95698 L
.49569 .95665 L
.49489 .95633 L
.49424 .95598 L
.4938 .95565 L
.49359 .95539 L
.49363 .95523 L
.49388 .9552 L
.49428 .95523 L
.4948 .95533 L
.49533 .95547 L
.49578 .95564 L
.49609 .9558 L
.49625 .95585 L
.49628 .95589 L
.49624 .95597 L
.49613 .95608 L
.49597 .95621 L
.49578 .95635 L
.49553 .95651 L
Mistroke
.49528 .95664 L
.4951 .95675 L
.49504 .95683 L
.4951 .95688 L
.4953 .95687 L
.49564 .95682 L
.49609 .95676 L
.4965 .95673 L
.49695 .95668 L
.49735 .95648 L
.49765 .95628 L
.4978 .95597 L
.49783 .95564 L
.49781 .95535 L
.49782 .95514 L
.4978 .95504 L
.49779 .95505 L
.4978 .9552 L
.49781 .95538 L
.49776 .95561 L
.49765 .95583 L
.49755 .95603 L
.4975 .95628 L
.49749 .95654 L
.49751 .95684 L
.49756 .95717 L
.49757 .95749 L
.49751 .95773 L
.49733 .95784 L
.49709 .95785 L
.4969 .95779 L
.4968 .95772 L
.49682 .95764 L
.497 .95755 L
.49732 .95754 L
.49775 .95761 L
.49817 .95768 L
.4985 .95781 L
.49853 .95802 L
.49818 .9583 L
.49744 .95864 L
.4964 .9591 L
.49502 .95965 L
.49344 .9603 L
.49156 .96084 L
.48951 .96139 L
.48741 .96196 L
.48504 .96251 L
.48234 .96291 L
.47988 .96326 L
Mistroke
.47752 .96358 L
.47529 .96389 L
.47335 .96422 L
.47179 .96458 L
.47064 .96498 L
.46972 .96532 L
.46896 .96559 L
.46829 .96577 L
.46766 .96583 L
.467 .96574 L
.46627 .96551 L
.46544 .96516 L
.46464 .9647 L
.46373 .96413 L
.46277 .96349 L
.46171 .96279 L
.46057 .96208 L
.45927 .96139 L
.45783 .96071 L
.45627 .96 L
.45474 .95942 L
.45316 .95884 L
.45168 .95837 L
.45033 .95807 L
.44914 .95793 L
.44806 .95793 L
.44703 .95797 L
.44593 .95796 L
.44477 .95788 L
.44346 .95772 L
.44185 .95749 L
.44027 .95723 L
.43843 .9569 L
.4363 .95653 L
.43394 .95602 L
.4316 .95542 L
.42907 .95473 L
.42626 .9539 L
.42289 .95309 L
.41986 .95218 L
.41636 .95115 L
.41291 .95019 L
.4092 .94919 L
.40526 .94821 L
.40175 .9472 L
.39779 .94622 L
.39402 .94515 L
.38991 .94397 L
.38574 .94269 L
.38198 .94138 L
Mistroke
.37798 .93999 L
.37405 .93854 L
.36999 .93712 L
.3664 .93568 L
.36266 .93423 L
.35895 .93284 L
.35535 .93144 L
.35181 .93006 L
.34811 .92867 L
.34452 .92731 L
.34113 .92598 L
.33751 .92465 L
.33396 .92337 L
.33016 .92216 L
.32675 .92099 L
.32316 .91988 L
.31946 .91882 L
.31611 .91781 L
.31286 .91683 L
.30948 .91586 L
.30623 .91486 L
.30289 .91386 L
.29969 .91282 L
.29639 .9117 L
.29311 .9105 L
.29022 .90921 L
.28712 .90785 L
.28418 .90652 L
.2812 .90514 L
.27837 .90376 L
.27567 .90242 L
.27293 .90109 L
.27039 .89978 L
.26783 .89848 L
.26554 .8972 L
.26334 .89598 L
.26132 .89481 L
.25954 .8937 L
.25799 .89264 L
.25671 .89171 L
.25569 .89081 L
.25489 .89001 L
.25434 .88931 L
.254 .88875 L
.25383 .8883 L
.25374 .8879 L
.25367 .88758 L
.25351 .88726 L
.2532 .88694 L
.25268 .88659 L
Mistroke
.25194 .88618 L
.25088 .88553 L
.24946 .88461 L
.24763 .88338 L
.24546 .88188 L
.243 .88009 L
.24014 .87792 L
.23704 .87557 L
.23376 .87299 L
.23027 .87017 L
.2269 .86741 L
.22342 .86447 L
.22008 .86148 L
.21679 .85882 L
.21358 .85599 L
.21055 .85318 L
.20758 .85041 L
.20474 .84765 L
.20196 .84507 L
.19926 .84244 L
.19661 .83993 L
.19399 .83738 L
.19131 .83471 L
.18869 .8321 L
.18614 .82958 L
.18368 .82699 L
.18136 .82445 L
.17913 .82212 L
.17715 .81985 L
.17523 .81774 L
.17373 .81587 L
.17241 .81411 L
.1713 .8125 L
.17041 .81112 L
.16965 .80986 L
.16899 .80871 L
.1683 .80763 L
.16751 .80659 L
.16656 .80551 L
.16536 .80434 L
.16393 .80302 L
.16216 .80149 L
.16001 .79969 L
.15801 .79778 L
.15564 .79561 L
.1529 .79337 L
.15054 .79107 L
.1479 .7886 L
.1451 .78602 L
.1427 .78364 L
Mistroke
.14006 .7811 L
.13736 .77845 L
.13506 .77581 L
.13267 .77323 L
.13026 .77062 L
.12824 .76828 L
.12613 .76593 L
.12404 .76363 L
.12207 .76139 L
.12011 .75921 L
.11823 .75705 L
.11656 .75521 L
.11496 .7535 L
.1135 .75193 L
.11222 .75054 L
.11123 .74938 L
.11031 .74835 L
.10955 .74742 L
.10885 .74644 L
.10818 .74535 L
.10753 .74415 L
.1069 .74283 L
.10629 .74137 L
.10574 .73994 L
.10529 .73838 L
.10489 .73687 L
.10456 .73547 L
.10426 .73418 L
.10396 .7328 L
.10367 .73155 L
.10338 .73033 L
.1031 .72913 L
.1028 .72791 L
.10246 .72664 L
.10207 .72527 L
.10161 .72367 L
.10108 .72182 L
.10045 .7197 L
.09977 .71765 L
.09902 .71521 L
.0982 .71255 L
.09736 .70966 L
.09655 .70657 L
.09579 .70357 L
.09512 .70064 L
.09458 .69762 L
.09418 .69489 L
.09391 .6924 L
.09373 .68999 L
.0936 .68772 L
Mistroke
.09346 .68559 L
.0933 .68358 L
.0931 .68159 L
.09286 .67972 L
.09259 .67783 L
.09229 .67594 L
.09195 .67399 L
.09158 .67208 L
.09113 .66995 L
.09059 .66768 L
.08999 .66506 L
.0893 .66243 L
.08854 .65941 L
.08772 .65617 L
.08688 .65277 L
.08604 .64933 L
.08526 .64545 L
.08457 .642 L
.08395 .63837 L
.08338 .63465 L
.08288 .63157 L
.08242 .62851 L
.08202 .62575 L
.08169 .62341 L
.08141 .62137 L
.0812 .61985 L
.08104 .6187 L
.08095 .61787 L
.08091 .61734 L
.08096 .61705 L
.08098 .61694 L
.08103 .61696 L
.08107 .61707 L
.08111 .61718 L
.08113 .61726 L
.08116 .61726 L
.08121 .61712 L
.08127 .61679 L
.08132 .61627 L
.08133 .61555 L
.08128 .61457 L
.08115 .61342 L
.08092 .61192 L
.08057 .61011 L
.08023 .60791 L
.0798 .60545 L
.07933 .60251 L
.07886 .5995 L
.07837 .59602 L
.07787 .59239 L
Mistroke
.07735 .58851 L
.07681 .5844 L
.07625 .58024 L
.07565 .57636 L
.07504 .57231 L
.07446 .56842 L
.07392 .56517 L
.07342 .56219 L
.07297 .55967 L
.07258 .5575 L
.07226 .55595 L
.07201 .55478 L
.07184 .55398 L
.07174 .55348 L
.07169 .5532 L
.07169 .55301 L
.07169 .55273 L
.07168 .55229 L
.07162 .55166 L
.07149 .55088 L
.07129 .54972 L
.071 .54819 L
.07064 .54611 L
.07023 .54363 L
.06981 .54098 L
.0694 .53787 L
.06902 .53487 L
.06871 .5311 L
.06848 .52791 L
.06832 .5245 L
.06827 .52082 L
.06832 .5171 L
.06849 .51301 L
.06876 .50935 L
.06916 .50551 L
.06961 .50175 L
.07013 .49817 L
.07072 .49488 L
.07126 .49175 L
.07183 .48913 L
.07235 .48676 L
.07281 .48476 L
.07321 .48326 L
.07355 .4821 L
.07384 .4813 L
.07409 .48082 L
.07431 .48059 L
.07448 .48054 L
Mfstroke
.07141 .49248 m
.07125 .49262 L
.07104 .49301 L
.07078 .49372 L
.07048 .49483 L
.07015 .49639 L
.06979 .49834 L
.0694 .50063 L
.069 .50351 L
.06859 .50695 L
.0682 .50995 L
.06786 .51393 L
.0676 .51768 L
.06745 .52187 L
.0674 .52606 L
.06747 .53023 L
.06763 .53403 L
.06788 .53796 L
.06822 .54175 L
.06861 .54516 L
.06909 .54846 L
.06964 .55167 L
.07026 .55485 L
.07091 .55778 L
.07159 .56097 L
.0723 .56391 L
.07296 .56719 L
.07362 .57038 L
.07426 .57406 L
.07488 .57754 L
.07545 .58089 L
.076 .585 L
.07651 .5887 L
.07697 .5933 L
.0774 .59701 L
.07783 .60155 L
.07826 .60599 L
.0787 .6101 L
.07915 .61448 L
.07966 .61886 L
.08024 .6233 L
.08089 .62776 L
.0816 .63217 L
.08226 .63655 L
.08301 .64105 L
.08373 .64581 L
.08447 .65005 L
.08519 .65492 L
.08587 .65885 L
.08652 .66347 L
Mistroke
.08715 .66742 L
.08769 .6714 L
.08818 .67481 L
.0886 .67793 L
.08895 .68097 L
.08925 .6836 L
.08952 .68599 L
.08977 .6881 L
.09003 .68977 L
.0903 .69125 L
.09059 .6925 L
.0909 .69353 L
.09122 .69441 L
.09153 .69504 L
.09183 .69566 L
.09209 .69616 L
.0923 .6965 L
.09249 .69667 L
.09267 .69667 L
.09284 .69655 L
.09299 .69636 L
.0931 .69616 L
.09317 .69599 L
.09319 .69591 L
.09317 .69598 L
.09312 .69624 L
.09306 .69672 L
.093 .69741 L
.09298 .69831 L
.09302 .69942 L
.09312 .70076 L
.0933 .70236 L
.09359 .70432 L
.09402 .70668 L
.09455 .70937 L
.09519 .71215 L
.09592 .71527 L
.09674 .71853 L
.09757 .72173 L
.09842 .72507 L
.09925 .7279 L
.1 .73068 L
.10072 .73338 L
.10131 .73547 L
.10187 .73738 L
.10225 .73902 L
.10258 .74031 L
.1028 .74118 L
.10292 .74169 L
.10295 .74191 L
Mistroke
.10291 .74191 L
.10286 .74177 L
.1028 .74155 L
.10275 .74139 L
.10272 .74132 L
.10272 .74139 L
.10275 .74162 L
.10277 .74186 L
.10277 .74209 L
.10272 .74226 L
.10263 .74233 L
.10253 .74233 L
.10241 .74227 L
.10229 .74219 L
.10218 .74215 L
.1021 .74215 L
.10204 .74222 L
.102 .74234 L
.10199 .7425 L
.10199 .74271 L
.102 .74295 L
.10205 .74322 L
.10213 .74352 L
.10223 .74386 L
.10234 .74424 L
.10247 .74463 L
.10258 .74504 L
.10266 .74539 L
.10272 .74562 L
.10273 .74572 L
.10271 .74573 L
.10267 .74568 L
.10264 .74561 L
.10263 .74549 L
.10263 .74534 L
.10264 .74517 L
.10264 .74498 L
.10264 .74477 L
.10265 .74455 L
.10265 .74436 L
.10265 .74421 L
.10265 .7441 L
.10266 .74404 L
.10266 .74404 L
.10265 .74406 L
.10265 .74413 L
.10265 .74423 L
.10265 .74442 L
.10264 .74464 L
.10264 .74489 L
Mistroke
.10263 .74515 L
.10263 .74538 L
.10262 .74559 L
.1026 .74574 L
.10256 .74583 L
.10249 .74581 L
.10237 .74564 L
.10224 .74539 L
.10213 .74513 L
.10207 .74493 L
.10208 .74482 L
.10222 .74488 L
.10255 .74516 L
.10309 .74572 L
.10387 .74658 L
.10491 .74778 L
.1061 .7493 L
.10765 .75113 L
.10928 .753 L
.11123 .7553 L
.11329 .75773 L
.11555 .76039 L
.1181 .76312 L
.12056 .76596 L
.12299 .76857 L
.12546 .77127 L
.1279 .77388 L
.13033 .77635 L
.13281 .77889 L
.13527 .78131 L
.13794 .78386 L
.1405 .78639 L
.14329 .78912 L
.14612 .79175 L
.14897 .79464 L
.15184 .79737 L
.15482 .80036 L
.15782 .80329 L
.16092 .80639 L
.16378 .80931 L
.16678 .81246 L
.16984 .81542 L
.17281 .81849 L
.17586 .82149 L
.17901 .82471 L
.18199 .82764 L
.1853 .83088 L
.18853 .83433 L
.19195 .83758 L
.19552 .84112 L
Mistroke
.19943 .84496 L
.20307 .84836 L
.20682 .852 L
.21074 .85586 L
.21449 .85935 L
.21837 .86294 L
.22202 .86695 L
.22571 .8702 L
.22917 .8736 L
.23245 .87699 L
.23554 .88004 L
.23847 .88299 L
.241 .88538 L
.24336 .88756 L
.24531 .88926 L
.24703 .89065 L
.24845 .89173 L
.2496 .89252 L
.25049 .89302 L
.25114 .89325 L
.25156 .89325 L
.25181 .89304 L
.25193 .89269 L
.25193 .89225 L
.25186 .89181 L
.25176 .89144 L
.25167 .89116 L
.25158 .89098 L
.2515 .89087 L
.25145 .89083 L
.25143 .89087 L
.25142 .89094 L
.25142 .891 L
.2514 .89101 L
.25135 .89099 L
.2513 .89097 L
.25124 .89095 L
.2512 .89092 L
.25117 .89089 L
.25118 .89089 L
.25127 .89093 L
.25146 .89103 L
.25175 .89119 L
.25215 .89143 L
.25268 .89176 L
.25333 .89213 L
.25403 .89253 L
.25474 .89294 L
.25547 .89335 L
.25617 .89373 L
Mistroke
.25686 .8941 L
.25747 .89444 L
.25801 .89473 L
.25846 .89497 L
.25881 .89515 L
.25906 .89527 L
.25922 .89535 L
.2593 .89536 L
.25929 .89535 L
.25925 .89532 L
.25919 .8953 L
.25914 .89528 L
.25912 .8953 L
.25913 .89535 L
.25914 .89539 L
.25915 .89543 L
.25914 .89548 L
.25911 .89554 L
.25908 .8956 L
.25904 .89566 L
.25903 .8957 L
.25904 .89568 L
.25908 .89558 L
.25913 .8954 L
.2592 .89514 L
.25927 .8948 L
.25935 .89439 L
.25942 .89393 L
.25949 .89344 L
.25953 .89293 L
.25957 .89244 L
.2596 .89194 L
.25966 .89139 L
.25974 .89099 L
.25984 .89062 L
.25993 .89035 L
.25997 .8902 L
.25995 .89018 L
.25987 .89024 L
.25966 .8904 L
.25953 .89057 L
.25937 .89078 L
.25921 .89105 L
.25906 .89138 L
.25896 .89181 L
.2589 .89232 L
.25895 .89294 L
.25916 .89366 L
.25952 .89444 L
.26017 .89538 L
Mistroke
.26111 .89646 L
.26243 .89766 L
.26419 .89901 L
.26647 .90051 L
.26912 .90215 L
.27223 .9039 L
.27572 .90568 L
.27961 .90753 L
.28376 .90938 L
.2881 .91123 L
.29294 .91307 L
.29777 .91495 L
.30286 .9168 L
.30825 .91866 L
.31339 .92049 L
.31875 .92236 L
.32402 .92419 L
.32933 .92599 L
.33439 .92783 L
.33904 .92965 L
.34355 .93144 L
.34753 .93313 L
.35119 .93472 L
.35482 .93606 L
.3578 .93729 L
.36042 .93829 L
.3629 .93915 L
.36524 .93989 L
.36746 .94054 L
.36957 .9411 L
.37146 .9416 L
.37346 .94209 L
.3756 .94258 L
.37782 .94308 L
.38008 .94362 L
.38238 .94419 L
.38469 .94483 L
.38691 .94552 L
.38884 .94623 L
.39051 .94685 L
.3919 .94743 L
.39301 .94795 L
.3939 .94836 L
.39451 .94866 L
.39491 .94884 L
.3951 .94887 L
.39511 .94879 L
.39504 .94867 L
.39492 .94852 L
.39477 .9483 L
Mistroke
.3947 .94805 L
.39476 .9478 L
.39495 .94757 L
.39521 .94731 L
.39556 .94701 L
.39597 .9467 L
.39638 .94633 L
.39678 .94599 L
.39715 .94562 L
.39751 .94528 L
.39782 .94493 L
.39803 .94461 L
.39814 .94433 L
.39813 .94419 L
.39795 .94397 L
.3976 .94376 L
.39712 .94355 L
.39664 .94344 L
.39614 .94346 L
.39566 .94357 L
.39522 .94378 L
.39487 .94409 L
.39455 .94436 L
.39427 .94464 L
.39403 .94489 L
.39382 .94507 L
.39358 .94517 L
.39331 .94523 L
.39306 .94531 L
.39289 .94542 L
.3928 .94554 L
.39282 .94566 L
.39305 .94584 L
.39353 .94614 L
.39433 .94661 L
.3955 .94725 L
.39708 .94807 L
.39918 .94908 L
.40186 .95025 L
.40469 .95156 L
.40827 .953 L
.41221 .95455 L
.4167 .95607 L
.42162 .9577 L
.42624 .95922 L
.43109 .96069 L
.43619 .96209 L
.44068 .96333 L
.44519 .96444 L
.44911 .96539 L
Mistroke
.45276 .96617 L
.4562 .9668 L
.45876 .96729 L
.46102 .96766 L
.46297 .96793 L
.46459 .96812 L
.46591 .96824 L
.46707 .96827 L
.46797 .96821 L
.46876 .96808 L
.46954 .96791 L
.4703 .96773 L
.47102 .96756 L
.47171 .96741 L
.47238 .96727 L
.47306 .96713 L
.4737 .96698 L
.47431 .96683 L
.47491 .96672 L
.47555 .96667 L
.47623 .96665 L
.47704 .96663 L
.47801 .96657 L
.47923 .96648 L
.48065 .96628 L
.48216 .96594 L
.48399 .96546 L
.48607 .96485 L
.48836 .96416 L
.49075 .96343 L
.49311 .96268 L
.49536 .96191 L
.49745 .96127 L
.49921 .96066 L
.50064 .96011 L
.50167 .95958 L
.50241 .95913 L
.50284 .95874 L
.50307 .95851 L
.50325 .95838 L
.50345 .95836 L
.50371 .95841 L
.50414 .95854 L
.5048 .95875 L
.50582 .95906 L
.50712 .95938 L
.50889 .95978 L
.51084 .96019 L
.51322 .96058 L
.51621 .96107 L
Mistroke
.51915 .96145 L
.52243 .96174 L
.52588 .96189 L
.52941 .96188 L
.53313 .96174 L
.53676 .9615 L
.54057 .96107 L
.54439 .96047 L
.54832 .95974 L
.5524 .95892 L
.55669 .95804 L
.56105 .95716 L
.56552 .95633 L
.57004 .95561 L
.57449 .955 L
.57883 .95446 L
.58311 .95399 L
.58732 .95358 L
.59149 .95319 L
.59543 .95281 L
.59943 .95243 L
.60314 .95204 L
.60679 .95162 L
.61047 .95114 L
.61406 .95057 L
.61761 .94989 L
.6212 .94909 L
.6246 .94813 L
.62791 .94709 L
.63109 .94599 L
.63408 .94486 L
.63696 .94372 L
.63958 .94267 L
.64193 .94172 L
.64393 .94093 L
.64555 .94028 L
.64674 .93982 L
.64761 .93956 L
.64821 .93947 L
.64856 .93954 L
.64884 .9396 L
.64911 .9397 L
.64939 .93978 L
.64974 .93978 L
.65014 .93969 L
.65051 .93959 L
.65101 .93934 L
.65145 .93901 L
.65202 .93847 L
.65265 .9378 L
Mistroke
.65331 .93703 L
.654 .93621 L
.65468 .93538 L
.65538 .93456 L
.65606 .93376 L
.65664 .93303 L
.65709 .93236 L
.65733 .93191 L
.65755 .93153 L
.65774 .93127 L
.658 .93108 L
.65826 .93108 L
.65861 .93119 L
.65899 .93142 L
.65941 .93173 L
.65987 .93206 L
.66034 .93239 L
.66082 .93268 L
.66138 .93295 L
.66206 .93326 L
.6629 .93352 L
.66385 .93372 L
.66486 .93381 L
.66586 .93385 L
.66685 .93382 L
.66778 .93373 L
.66864 .93361 L
.66937 .93351 L
.67 .93345 L
.67046 .93346 L
.67091 .93354 L
.67133 .93365 L
.6717 .93377 L
.67197 .93385 L
.67217 .93391 L
.67231 .93392 L
.67241 .9339 L
.67247 .93389 L
.6725 .93389 L
.67252 .93391 L
.67253 .93393 L
.67247 .93394 L
.67244 .93394 L
.67245 .9339 L
.67241 .93386 L
.6724 .93382 L
.67248 .9338 L
.67269 .93381 L
.67295 .93383 L
.67328 .93385 L
Mistroke
.67366 .93383 L
.67414 .93377 L
.67467 .93363 L
.67527 .93342 L
.67593 .93315 L
.6767 .93282 L
.67757 .93242 L
.67854 .93196 L
.67961 .9314 L
.68079 .93074 L
.68205 .92998 L
.68339 .92909 L
.68494 .92806 L
.68666 .9269 L
.68859 .92563 L
.69072 .92425 L
.69309 .92281 L
.69558 .92123 L
.69824 .91961 L
.70102 .91793 L
.70364 .91623 L
.70632 .91449 L
.70905 .9127 L
.71186 .91088 L
.71459 .90913 L
.71726 .90739 L
.71992 .90566 L
.72256 .90391 L
.7251 .90223 L
.72746 .90062 L
.72932 .8993 L
.73122 .89795 L
.73297 .89677 L
.73451 .89569 L
.73591 .8947 L
.73712 .89383 L
.73813 .89308 L
.73897 .89242 L
.73966 .89185 L
.74023 .89134 L
.74073 .89085 L
.74122 .89035 L
.74177 .88978 L
.74238 .88911 L
.74303 .88835 L
.74371 .88752 L
.7444 .88667 L
.74505 .88583 L
.74563 .88502 L
.74615 .8843 L
Mistroke
.74655 .88367 L
.74683 .88314 L
.74696 .88274 L
.74697 .88244 L
.74687 .88224 L
.7467 .88213 L
.74649 .8821 L
.74633 .88213 L
.74622 .88221 L
.7462 .88232 L
.74634 .88243 L
.74669 .88248 L
.74724 .88245 L
.74796 .88235 L
.74892 .88214 L
.75009 .88182 L
.75147 .88133 L
.75304 .88066 L
.75481 .87982 L
.75672 .87883 L
.75878 .8777 L
.76091 .87646 L
.76314 .87511 L
.76545 .87363 L
.76785 .87203 L
.77021 .87033 L
.77261 .86852 L
.77503 .86668 L
.77745 .86481 L
.77973 .86296 L
.78192 .86118 L
.78391 .85962 L
.78563 .85816 L
.78705 .85692 L
.78815 .85588 L
.78896 .85506 L
.78949 .85445 L
.7898 .85401 L
.78995 .85371 L
.79003 .85351 L
.79001 .85335 L
.78993 .85315 L
.7899 .8528 L
.78996 .85227 L
.79011 .85148 L
.79042 .85043 L
.79088 .84911 L
.7915 .84767 L
.7922 .84607 L
.7929 .84447 L
Mistroke
.7935 .84295 L
.79394 .84166 L
.79419 .84071 L
.79426 .84015 L
.7942 .84001 L
.7941 .84026 L
.79401 .84078 L
.79407 .84143 L
.79436 .84216 L
.79484 .84266 L
.79558 .84318 L
.79657 .84354 L
.79779 .84367 L
.79933 .84354 L
.80117 .84308 L
.80328 .8422 L
.80571 .84089 L
.80829 .83927 L
.81103 .83732 L
.81381 .83514 L
.81662 .83272 L
.81948 .83024 L
.82226 .8278 L
.82515 .82526 L
.82802 .82275 L
.83096 .82026 L
.83384 .81787 L
.83663 .8155 L
.83932 .81328 L
.84185 .81121 L
.84424 .80931 L
.8465 .80754 L
.84849 .80594 L
.85041 .8044 L
.85224 .8028 L
.85416 .80109 L
.85591 .79922 L
.85731 .79743 L
.85884 .79536 L
.86016 .79331 L
.86162 .79097 L
.86277 .78887 L
.86402 .78663 L
.86526 .7843 L
.86644 .78192 L
.86752 .77948 L
.86846 .77708 L
.86926 .77468 L
.86994 .77208 L
.87038 .76986 L
Mistroke
.87077 .76756 L
.87109 .76558 L
.87137 .76367 L
.87155 .76194 L
.87167 .76049 L
.87174 .75926 L
.87175 .75824 L
.87174 .75741 L
.87173 .75675 L
.87173 .75623 L
.87176 .75594 L
.87188 .75581 L
.87213 .75569 L
.87254 .75542 L
.87309 .75484 L
.8738 .7539 L
.87466 .75257 L
.87566 .75083 L
.87681 .74871 L
.87806 .74627 L
.87939 .74349 L
.88075 .74056 L
.88211 .73735 L
.88344 .73403 L
.88474 .7305 L
.88598 .72694 L
.88715 .72328 L
.88822 .71964 L
.88919 .71608 L
.89007 .71276 L
.89083 .70962 L
.89147 .70688 L
.89195 .70446 L
.89231 .70239 L
.89258 .70065 L
.89279 .69921 L
.89297 .69803 L
.89316 .69713 L
.89338 .69639 L
.89361 .69582 L
.89389 .69525 L
.89425 .69463 L
.89471 .69381 L
.89521 .69299 L
.89579 .69183 L
.89653 .69028 L
.89712 .68872 L
.89769 .68697 L
.89821 .685 L
.89864 .68283 L
Mistroke
.89898 .68054 L
.89921 .67824 L
.89931 .67612 L
.8993 .67415 L
.8992 .67246 L
.89902 .67114 L
.89884 .67016 L
.89871 .66945 L
.89865 .66901 L
.89864 .66886 L
.89868 .6689 L
.89875 .6691 L
.89879 .66946 L
.89879 .66998 L
.89871 .67068 L
.89852 .67147 L
.89821 .67232 L
.89779 .67309 L
.89725 .67369 L
.89665 .6741 L
.89594 .67436 L
.89506 .67453 L
.89403 .67467 L
.89287 .6748 L
.89153 .67497 L
.89011 .6751 L
.88868 .67511 L
.88726 .67496 L
.88593 .67469 L
.88482 .67435 L
.88381 .67396 L
.88286 .67362 L
.88199 .67334 L
.88127 .67312 L
.8808 .67291 L
.88045 .67274 L
.88024 .67265 L
.88019 .67265 L
.88027 .67279 L
.88044 .67314 L
.88064 .6738 L
.88084 .67485 L
.881 .67631 L
.88113 .67822 L
.88125 .68056 L
.88132 .68314 L
.88131 .68613 L
.88126 .68925 L
.88121 .69265 L
.88118 .69572 L
Mistroke
.88115 .69878 L
.88114 .70173 L
.88113 .70434 L
.88111 .70657 L
.8811 .70848 L
.88108 .71004 L
.88107 .7112 L
.88105 .71204 L
.88103 .71264 L
.88101 .71301 L
.88099 .71322 L
.88098 .7133 L
.88097 .71332 L
.88099 .71328 L
.88103 .71323 L
.88108 .71321 L
.88112 .71324 L
.88114 .71333 L
.88112 .71348 L
.88107 .71365 L
.88098 .71385 L
.88087 .71406 L
.88072 .71434 L
.88055 .71475 L
.88038 .7153 L
.88021 .71598 L
.88007 .71681 L
.87997 .71782 L
.87991 .71904 L
.87991 .72047 L
.88 .72207 L
.88016 .72383 L
.88037 .72562 L
.88061 .72757 L
.88082 .72968 L
.88098 .73197 L
.88104 .73447 L
.88098 .73709 L
.88077 .73965 L
.88043 .74225 L
.87998 .74478 L
.87947 .74708 L
.87896 .74894 L
.87844 .75057 L
.87794 .75196 L
.8775 .753 L
.87714 .7538 L
.87689 .75444 L
.87676 .75474 L
.87674 .75479 L
Mistroke
.87686 .75462 L
.8771 .75425 L
.87742 .75376 L
.87776 .75324 L
.87806 .7528 L
.87829 .75256 L
.87837 .75257 L
.87828 .75286 L
.87801 .75341 L
.87754 .75421 L
.87688 .75527 L
.87604 .75659 L
.87505 .75815 L
.87401 .75979 L
.87288 .76147 L
.87172 .7631 L
.87054 .76463 L
.86939 .76612 L
.86836 .76738 L
.86747 .76846 L
.86677 .76926 L
.86628 .76976 L
.866 .76997 L
.86594 .76991 L
.86605 .7696 L
.86629 .76915 L
.86661 .76864 L
.86691 .76826 L
.86721 .76795 L
.86747 .76784 L
.86764 .76799 L
.86772 .76836 L
.86776 .76891 L
.86774 .76959 L
.86767 .77042 L
.86757 .77134 L
.86746 .77233 L
.86733 .77342 L
.86718 .77451 L
.86701 .77572 L
.86689 .77688 L
.86683 .77789 L
.8668 .77871 L
.86676 .77941 L
.86669 .78001 L
.86656 .78051 L
.8664 .7809 L
.86622 .78115 L
.86607 .78122 L
.86594 .78112 L
Mistroke
.86589 .78087 L
.86585 .78054 L
.86584 .78015 L
.86586 .77971 L
.86592 .7793 L
.86599 .77896 L
.86609 .77862 L
.86622 .77826 L
.86634 .77788 L
.86644 .77749 L
.86651 .77716 L
.86655 .7769 L
.86655 .77678 L
.86651 .77681 L
.86635 .77705 L
.86609 .77754 L
.86572 .77829 L
.86526 .77923 L
.86472 .7804 L
.86408 .7818 L
.86333 .78331 L
.86243 .78509 L
.8614 .78704 L
.86027 .78913 L
.85908 .79124 L
.85799 .79319 L
.85693 .79498 L
.85597 .79655 L
.85512 .79783 L
.85444 .79876 L
.85391 .79939 L
.8535 .79981 L
.85322 .80006 L
.85306 .80019 L
.85302 .80022 L
.85303 .80019 L
.85303 .80016 L
.85299 .80017 L
.85296 .80018 L
.85297 .80016 L
.85296 .80013 L
.8529 .80014 L
.85276 .80021 L
.85257 .80031 L
.8524 .8004 L
.85223 .80048 L
.85208 .80052 L
.85195 .80049 L
.8518 .80046 L
.8515 .80045 L
Mistroke
.85105 .80051 L
.85047 .80052 L
.84977 .80066 L
.84892 .80083 L
.8479 .80095 L
.84685 .80097 L
.84583 .80091 L
.84492 .80082 L
.844 .80072 L
.84313 .80061 L
.84251 .80049 L
.84208 .8004 L
.84173 .80032 L
.84151 .80028 L
.84149 .80029 L
.84159 .80037 L
.84192 .80038 L
.8424 .80033 L
.84301 .80021 L
.84366 .80008 L
.84437 .79989 L
.84509 .79964 L
.84591 .79923 L
.84668 .7988 L
.8475 .79823 L
.84821 .79765 L
.8489 .79707 L
.84949 .79651 L
.85 .79598 L
.85046 .79548 L
.85084 .79506 L
.85119 .7947 L
.85151 .79438 L
.85182 .79406 L
.85209 .79375 L
.85224 .79358 L
.85228 .79354 L
.85228 .79356 L
.85232 .7936 L
.85238 .79364 L
.85244 .79371 L
.85248 .7938 L
.85249 .79393 L
.8525 .79406 L
.85249 .79418 L
.85245 .79429 L
.85238 .79443 L
.85228 .79459 L
.85219 .79471 L
.85218 .79469 L
Mistroke
.85228 .79456 L
.85249 .79432 L
.85268 .7941 L
.85294 .79381 L
.85318 .79354 L
.85339 .79332 L
.85353 .79317 L
.8536 .79311 L
.8536 .79316 L
.85357 .79324 L
.85354 .79331 L
.85352 .79335 L
.85348 .79338 L
.85343 .79341 L
.85338 .79344 L
.85335 .79344 L
.85334 .79339 L
.85334 .79335 L
.85335 .79327 L
.85336 .79318 L
.85339 .79308 L
.85343 .79299 L
.85347 .79293 L
.85352 .79289 L
.85356 .79288 L
.8536 .79289 L
.85362 .7929 L
.85363 .7929 L
.85362 .79291 L
.8536 .79292 L
.85359 .79293 L
.85358 .79292 L
.85358 .7929 L
.85359 .79286 L
.85361 .7928 L
.85368 .7927 L
.85376 .79261 L
.85381 .79259 L
.85382 .79265 L
.8538 .79278 L
.8537 .79305 L
.85349 .79348 L
.85317 .79406 L
.85274 .79472 L
.85225 .7954 L
.85175 .79604 L
.85128 .79663 L
.85083 .79714 L
.85048 .7975 L
.85018 .79776 L
Mistroke
.84993 .79792 L
.84979 .7979 L
.84976 .79774 L
.84985 .79745 L
.85015 .79691 L
.85062 .79619 L
.85129 .79533 L
.85212 .79443 L
.85312 .79345 L
.85427 .79241 L
.85557 .79126 L
.857 .78994 L
.85859 .78834 L
.8603 .78648 L
.86208 .78435 L
.86386 .78207 L
.8657 .7795 L
.86746 .77679 L
.86907 .77439 L
.87049 .77193 L
.87167 .76978 L
.87269 .7677 L
.87349 .76594 L
.87409 .7645 L
.87452 .76332 L
.87482 .76246 L
.87503 .76191 L
.87517 .76164 L
.87528 .76157 L
.87537 .76164 L
.87547 .76177 L
.8756 .76192 L
.87575 .76205 L
.8759 .76214 L
.87604 .76218 L
.87616 .76219 L
.87624 .76219 L
.87629 .76219 L
.8763 .76221 L
.87629 .76227 L
.87626 .76234 L
.87623 .76241 L
.87621 .76247 L
.8762 .7625 L
.87619 .76247 L
.87618 .76236 L
.87615 .76215 L
.87612 .76183 L
.87608 .76138 L
.87606 .76081 L
Mistroke
.87606 .76011 L
.87608 .75932 L
.87615 .75843 L
.87624 .75747 L
.87637 .75647 L
.87652 .75548 L
.8767 .75455 L
.87688 .75368 L
.87706 .75292 L
.87725 .75229 L
.87744 .75179 L
.87761 .75142 L
.87776 .75116 L
.87788 .751 L
.87796 .75091 L
.87803 .75087 L
.87808 .75088 L
.87814 .75092 L
.87817 .75096 L
.87817 .751 L
.87812 .75104 L
.87801 .75109 L
.87785 .75112 L
.8776 .75115 L
.87729 .75119 L
.87693 .75122 L
.87654 .75126 L
.87614 .7513 L
.87573 .75134 L
.87532 .75138 L
.87494 .75142 L
.87456 .75146 L
.87422 .75148 L
.87397 .7515 L
.87382 .75152 L
.8738 .75155 L
.87388 .75161 L
.87405 .7517 L
.8743 .75179 L
.87461 .75185 L
.87496 .75182 L
.87532 .75167 L
.87572 .75136 L
.87617 .7509 L
.87664 .75027 L
.87712 .74951 L
.87759 .74866 L
.87801 .74774 L
.87839 .74688 L
.87871 .74591 L
Mistroke
.87898 .74503 L
.87923 .7442 L
.87944 .74347 L
.87962 .74291 L
.87978 .74254 L
.87992 .74236 L
.88006 .74233 L
.88021 .74237 L
.88037 .74241 L
.88057 .74234 L
.88082 .74205 L
.88115 .74144 L
.88155 .74048 L
.88204 .73914 L
.8826 .73755 L
.88321 .73569 L
.88389 .73351 L
.88461 .73119 L
.88537 .72868 L
.88614 .72625 L
.88688 .72385 L
.88765 .72157 L
.8883 .71943 L
.88893 .71768 L
.88946 .71612 L
.88989 .71479 L
.89021 .71372 L
.89044 .71283 L
.89058 .71206 L
.89065 .71132 L
.89065 .71055 L
.89062 .7097 L
.89055 .7087 L
.89048 .70752 L
.89041 .70611 L
.89035 .70456 L
.89029 .70287 L
.89024 .70121 L
.89021 .69964 L
.89018 .69832 L
.89015 .69713 L
.89013 .69625 L
.89012 .6956 L
.89012 .69518 L
.89014 .69498 L
.8902 .695 L
.8903 .6952 L
.89039 .69557 L
.89044 .69605 L
.89045 .69659 L
Mistroke
.89039 .69714 L
.89024 .69761 L
.88997 .69795 L
.88958 .69812 L
.88907 .69815 L
.88846 .69813 L
.88779 .6981 L
.88707 .69811 L
.88632 .69821 L
.8855 .6984 L
.88462 .69869 L
.88369 .69904 L
.88274 .69942 L
.88182 .69983 L
.88091 .70025 L
.87998 .70068 L
.87907 .70116 L
.87815 .7017 L
.87727 .7023 L
.87634 .70295 L
.87532 .70363 L
.87419 .70433 L
.87302 .70506 L
.87183 .7058 L
.8706 .70662 L
.86934 .70751 L
.86822 .70848 L
.86712 .7095 L
.8661 .71058 L
.86516 .71166 L
.86437 .71268 L
.86363 .71356 L
.86294 .71431 L
.86231 .7149 L
.86176 .71535 L
.86127 .71566 L
.86083 .71589 L
.86039 .71605 L
.85988 .71617 L
.85927 .71626 L
.85853 .71636 L
.85761 .71646 L
.85666 .71659 L
.85549 .71677 L
.85423 .71701 L
.85307 .71729 L
.85189 .7176 L
.85074 .71792 L
.84968 .71823 L
.84877 .7185 L
Mistroke
.84796 .7187 L
.84728 .7188 L
.84675 .71881 L
.84643 .71875 L
.84633 .71861 L
.84644 .71844 L
.84667 .71833 L
.84697 .71832 L
.84725 .7185 L
.84746 .7189 L
.84758 .71951 L
.84756 .72042 L
.8474 .72162 L
.84714 .72303 L
.84679 .72472 L
.84634 .72664 L
.84585 .72861 L
.84524 .7308 L
.8446 .73287 L
.84391 .73494 L
.84322 .73687 L
.84259 .73858 L
.84207 .74008 L
.8417 .74133 L
.84147 .74228 L
.84136 .74304 L
.84137 .74363 L
.84146 .74407 L
.84159 .7444 L
.84175 .74465 L
.84192 .74486 L
.84212 .74501 L
.84234 .74512 L
.84257 .74522 L
.84279 .74532 L
.84297 .74542 L
.84311 .74552 L
.84321 .74561 L
.84326 .74566 L
.84327 .74568 L
.84326 .74565 L
.84326 .74557 L
.84327 .74542 L
.84331 .74524 L
.84337 .74506 L
.84344 .74492 L
.84347 .74487 L
.84345 .74496 L
.84334 .7452 L
.84315 .74565 L
Mistroke
.84284 .74634 L
.8424 .7473 L
.84184 .74852 L
.84115 .75003 L
.84038 .75174 L
.83951 .75371 L
.83855 .75597 L
.83754 .75847 L
.83652 .76095 L
.83549 .76356 L
.83448 .76615 L
.83354 .76847 L
.83271 .7705 L
.832 .77235 L
.83142 .77396 L
.83099 .77527 L
.83071 .77622 L
.83057 .77695 L
.83057 .77749 L
.83067 .77786 L
.83081 .77809 L
.83093 .77824 L
.83104 .77835 L
.83112 .77843 L
.83114 .77849 L
.83109 .77852 L
.83098 .77855 L
.83081 .77866 L
.83054 .77889 L
.8301 .77925 L
.82956 .77976 L
.8289 .7804 L
.82818 .78119 L
.82738 .78217 L
.82656 .78333 L
.82573 .78469 L
.82488 .78618 L
.82418 .78794 L
.82343 .78999 L
.82266 .79229 L
.82182 .79484 L
.82096 .79751 L
.82006 .80023 L
.8191 .80262 L
.81829 .80515 L
.81754 .80708 L
.81694 .809 L
.81642 .81067 L
.81597 .81207 L
.81561 .81323 L
Mistroke
.8153 .81411 L
.81508 .81472 L
.81497 .81507 L
.81498 .81521 L
.81509 .81517 L
.81524 .81502 L
.81541 .81487 L
.81555 .81476 L
.81564 .81466 L
.81567 .81458 L
.81565 .81454 L
.81559 .81455 L
.81548 .81456 L
.81532 .81458 L
.81517 .81459 L
.81506 .8146 L
.81497 .81461 L
.81489 .81461 L
.81483 .81461 L
.81476 .81462 L
.81469 .81462 L
.81462 .81463 L
.81456 .81463 L
.81454 .81463 L
.81454 .81463 L
.81452 .81461 L
.81448 .81459 L
.81444 .81457 L
.81435 .81456 L
.81425 .81456 L
.81415 .81456 L
.81405 .81455 L
.81397 .81454 L
.8139 .81451 L
.81384 .81451 L
.8138 .81459 L
.81371 .81481 L
.81362 .81521 L
.81347 .81588 L
.8133 .81671 L
.81308 .81777 L
.81285 .81913 L
.81262 .82023 L
.81239 .8218 L
.81214 .8233 L
.81188 .82458 L
.81159 .82623 L
.81126 .82774 L
.81091 .82923 L
.81055 .83062 L
Mistroke
.81021 .83185 L
.80989 .83285 L
.8096 .83361 L
.80937 .83419 L
.80916 .83461 L
.80899 .83491 L
.80887 .83513 L
.80878 .83529 L
.80874 .83541 L
.80875 .83547 L
.80881 .83547 L
.80889 .83542 L
.80898 .83534 L
.80905 .83526 L
.80908 .8352 L
.80906 .83518 L
.80898 .83518 L
.80888 .83519 L
.80874 .83521 L
.80857 .83522 L
.80837 .83524 L
.80814 .83526 L
.80792 .83529 L
.8077 .83531 L
.80749 .83533 L
.80735 .83534 L
.80724 .83535 L
.80721 .83536 L
.80724 .83535 L
.80736 .83534 L
.80752 .83533 L
.80773 .8353 L
.80796 .83528 L
.80818 .83526 L
.80838 .83524 L
.80855 .83523 L
.80871 .83521 L
.80886 .83519 L
.80898 .83518 L
.80907 .83517 L
.80913 .83516 L
.80917 .83515 L
.80919 .83512 L
.80918 .83506 L
.80915 .83498 L
.80909 .83492 L
.80898 .83489 L
.80878 .83493 L
.80846 .83504 L
.80798 .83523 L
Mistroke
.80728 .83554 L
.80647 .83598 L
.80541 .83658 L
.80412 .83733 L
.80272 .83821 L
.80112 .83923 L
.79932 .84031 L
.79746 .84151 L
.79551 .84269 L
.79362 .84393 L
.79172 .84512 L
.78992 .84619 L
.78836 .84714 L
.78693 .84795 L
.7857 .84862 L
.78471 .84915 L
.784 .84954 L
.78345 .84979 L
.78309 .84988 L
.7829 .84984 L
.78282 .8497 L
.78279 .84956 L
.78274 .84949 L
.78267 .84952 L
.78252 .84968 L
.7823 .84996 L
.78199 .85033 L
.78163 .85081 L
.78115 .8514 L
.7806 .85207 L
.77998 .8528 L
.77932 .85361 L
.77867 .85447 L
.77799 .85539 L
.77723 .85638 L
.77643 .85742 L
.77557 .8585 L
.77459 .8596 L
.77362 .86079 L
.77249 .86208 L
.77119 .8635 L
.7697 .86507 L
.76818 .86668 L
.76647 .86839 L
.76459 .87015 L
.76277 .87183 L
.76105 .87336 L
.75941 .87474 L
.75786 .87597 L
.75649 .87702 L
Mistroke
.75514 .87797 L
.75393 .87883 L
.75276 .8796 L
.75167 .88029 L
.75064 .88093 L
.74961 .88151 L
.74863 .88214 L
.74758 .88283 L
.74646 .88357 L
.74527 .8844 L
.74408 .88525 L
.7428 .88618 L
.74143 .88717 L
.74004 .88816 L
.73868 .88914 L
.73734 .89005 L
.73614 .89083 L
.73504 .89149 L
.73402 .89206 L
.73304 .89261 L
.73211 .89318 L
.73119 .89378 L
.73031 .89441 L
.72936 .8951 L
.72831 .89591 L
.72711 .89689 L
.72573 .89806 L
.72414 .89944 L
.72231 .90105 L
.72057 .90267 L
.71854 .90438 L
.71632 .9063 L
.71417 .90839 L
.71165 .91053 L
.70943 .91243 L
.70716 .91434 L
.7049 .91615 L
.70285 .91771 L
.70094 .91913 L
.69931 .92037 L
.69786 .92142 L
.69654 .92237 L
.69531 .92322 L
.69423 .92402 L
.69313 .92473 L
.69203 .92542 L
.69092 .92604 L
.68989 .92669 L
.68888 .92731 L
.68795 .92787 L
Mistroke
.68713 .92836 L
.68645 .92873 L
.68591 .92895 L
.68548 .92908 L
.68513 .92914 L
.6849 .92909 L
.68476 .92897 L
.68468 .92881 L
.68465 .92857 L
.68465 .92836 L
.68467 .9282 L
.68468 .92812 L
.68463 .92817 L
.68447 .92836 L
.6842 .9287 L
.68381 .92911 L
.68332 .9296 L
.68273 .93013 L
.68198 .93073 L
.68135 .93124 L
.68065 .93177 L
.68003 .93223 L
.67954 .93261 L
.67913 .93292 L
.67881 .93313 L
.67854 .93327 L
.67833 .93334 L
.6781 .93334 L
.67787 .93331 L
.67763 .93325 L
.67741 .93321 L
.67716 .93321 L
.67688 .93323 L
.67656 .93326 L
.67623 .93329 L
.67588 .93332 L
.67555 .93336 L
.67527 .93339 L
.6751 .9334 L
.67507 .93341 L
.67514 .93341 L
.67528 .9334 L
.67548 .93338 L
.67573 .93336 L
.676 .93334 L
.67629 .93332 L
.67657 .93329 L
.67687 .93327 L
.67715 .93324 L
.67744 .93321 L
Mistroke
.67765 .93319 L
.67778 .93318 L
.67781 .93317 L
.67776 .93317 L
.67766 .93318 L
.67754 .93318 L
.67744 .93318 L
.67738 .93318 L
.67736 .93317 L
.67736 .93317 L
.67734 .93316 L
.67731 .93317 L
.67732 .93317 L
.67739 .93316 L
.67755 .93315 L
.67775 .93313 L
.67796 .9331 L
.67817 .93307 L
.6783 .93305 L
.67834 .93305 L
.67825 .93305 L
.67804 .93308 L
.67774 .93311 L
.67734 .93315 L
.67695 .93321 L
.67647 .93326 L
.67598 .93332 L
.67552 .93337 L
.67512 .93342 L
.67481 .93346 L
.67458 .93349 L
.67445 .9335 L
.67441 .93351 L
.67442 .93351 L
.67448 .9335 L
.67456 .93349 L
.67463 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
Mistroke
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67466 .93348 L
.67467 .93348 L
.67469 .93348 L
.67474 .93347 L
.67481 .93346 L
.67488 .93345 L
.67491 .93345 L
.67489 .93345 L
.67478 .93347 L
.67458 .93349 L
.67429 .93352 L
.67393 .93356 L
.67353 .93361 L
.67312 .93366 L
.67272 .9337 L
.67235 .93375 L
.672 .93379 L
.6717 .93383 L
.67148 .93387 L
.67138 .93393 L
.6714 .93398 L
.67153 .934 L
.67173 .93396 L
.67199 .93385 L
.67226 .93369 L
.6725 .9335 L
Mistroke
.67268 .93329 L
.67278 .93309 L
.6728 .93293 L
.67276 .93282 L
.6727 .93277 L
.67264 .93279 L
.67258 .93286 L
.67251 .93295 L
.67244 .93301 L
.67236 .93307 L
.67226 .9331 L
.67214 .93305 L
.672 .93292 L
.67186 .93271 L
.67174 .93245 L
.67164 .93217 L
.67158 .9319 L
.67153 .93165 L
.67146 .93141 L
.67137 .93124 L
.67129 .93119 L
.67124 .93124 L
.67122 .9314 L
.67124 .93164 L
.67129 .93198 L
.67133 .9324 L
.67136 .93287 L
.67134 .93335 L
.67128 .93376 L
.67117 .93408 L
.67104 .93426 L
.67091 .93433 L
.67088 .93433 L
.67097 .93426 L
.67119 .93416 L
.67144 .93408 L
.67179 .934 L
.67217 .93393 L
.67253 .93386 L
.67284 .93379 L
.67306 .93373 L
.67319 .93369 L
.67326 .93365 L
.67332 .93362 L
.67338 .9336 L
.67344 .9336 L
.67341 .93361 L
.67332 .93364 L
.67321 .93367 L
.67318 .93367 L
Mistroke
.67319 .93367 L
.6733 .93366 L
.67347 .93364 L
.67371 .93361 L
.67397 .93357 L
.67425 .93353 L
.67454 .93349 L
.6748 .93346 L
.675 .93343 L
.67509 .93342 L
.67505 .93343 L
.67488 .93346 L
.67456 .93351 L
.67412 .93357 L
.67361 .93363 L
.67307 .9337 L
.67254 .93377 L
.67203 .93384 L
.67157 .93389 L
.67121 .93394 L
.67092 .93399 L
.6707 .93404 L
.67061 .93406 L
.6707 .93405 L
.67096 .93398 L
.67134 .93388 L
.67179 .93376 L
.67227 .93361 L
.67276 .93347 L
.67319 .93335 L
.67353 .93326 L
.67374 .93319 L
.67387 .93315 L
.67398 .93313 L
.67408 .93312 L
.67421 .93309 L
.67432 .93308 L
.6744 .93309 L
.67445 .93314 L
.67446 .93323 L
.67445 .93335 L
.6744 .93349 L
.67431 .93363 L
.67416 .93377 L
.67398 .93389 L
.67381 .93397 L
.67366 .93402 L
.67329 .93413 L
.67302 .9342 L
.67268 .93428 L
Mistroke
.67219 .93438 L
.67152 .93449 L
.67064 .93462 L
.66947 .93477 L
.66813 .93497 L
.66644 .93522 L
.66447 .93552 L
.66236 .93587 L
.65998 .93627 L
.65736 .93673 L
.65459 .93724 L
.6517 .93784 L
.64921 .93839 L
.64686 .93901 L
.64493 .93965 L
.6433 .94025 L
.64217 .94078 L
.64139 .94121 L
.64096 .94153 L
.64087 .94173 L
.64096 .94181 L
.64123 .94182 L
.64164 .94175 L
.64214 .94156 L
.64267 .94131 L
.64315 .94102 L
.64352 .94069 L
.64372 .94034 L
.6438 .93999 L
.64377 .93967 L
.64368 .93938 L
.64352 .93915 L
.64328 .93897 L
.64298 .9388 L
.64264 .93857 L
.64229 .9383 L
.64196 .93796 L
.64166 .93756 L
.64139 .93705 L
.64116 .93644 L
.641 .93582 L
.64091 .93523 L
.64086 .93468 L
.64083 .93419 L
.64082 .93376 L
.64081 .9335 L
.64082 .93339 L
.64084 .93344 L
.64088 .93362 L
.64095 .93391 L
Mistroke
.64103 .93421 L
.64111 .93447 L
.64118 .93464 L
.64125 .93476 L
.64129 .93481 L
.64134 .93473 L
.64143 .93459 L
.64157 .93439 L
.64177 .93417 L
.64202 .93392 L
.64228 .93372 L
.64249 .93357 L
.6426 .9335 L
.64257 .93352 L
.6424 .93368 L
.64206 .93399 L
.64151 .93441 L
.64074 .93497 L
.63974 .93565 L
.63853 .93639 L
.63715 .93723 L
.63534 .93796 L
.63347 .93876 L
.63133 .93958 L
.62875 .94041 L
.62584 .94128 L
.62255 .94211 L
.61926 .94297 L
.61604 .94385 L
.61251 .94471 L
.60867 .94563 L
.60525 .94657 L
.60122 .94737 L
.59736 .94814 L
.59307 .94887 L
.58893 .94959 L
.58508 .95022 L
.581 .95083 L
.57687 .95142 L
.57354 .95195 L
.56985 .95243 L
.56649 .95288 L
.56294 .95329 L
.55963 .9537 L
.55612 .95411 L
.55259 .95453 L
.54933 .95493 L
.54591 .95537 L
.54237 .95585 L
.53924 .95638 L
Mistroke
.53628 .95691 L
.53285 .95742 L
.52997 .95789 L
.52701 .9583 L
.52395 .95863 L
.52092 .95889 L
.51827 .95901 L
.51563 .95898 L
.51316 .95877 L
.51078 .95844 L
.50865 .958 L
.5066 .95747 L
.50467 .95688 L
.5031 .95632 L
.50172 .95584 L
.50052 .95541 L
.49956 .95508 L
.49879 .95486 L
.49816 .95472 L
.49758 .95463 L
.49696 .95457 L
.49623 .95457 L
.49532 .95461 L
.4941 .95466 L
.49255 .95475 L
.49077 .95488 L
.48859 .95501 L
.48602 .95512 L
.48301 .9552 L
.47979 .95531 L
.47637 .95546 L
.47249 .95567 L
.46851 .95591 L
.46475 .95615 L
.46075 .95636 L
.45673 .95653 L
.45278 .9566 L
.44902 .95655 L
.4452 .9564 L
.44188 .95622 L
.43878 .95605 L
.43599 .9559 L
.43365 .95578 L
.43162 .95567 L
.42993 .95558 L
.42867 .95551 L
.42771 .95546 L
.42705 .95541 L
.42669 .95537 L
.42657 .95534 L
Mistroke
.42662 .95533 L
.42676 .95528 L
.42693 .95522 L
.42708 .95507 L
.4272 .95482 L
.42727 .9546 L
.42729 .95435 L
.42725 .95411 L
.42716 .95384 L
.42706 .95357 L
.42696 .95331 L
.42687 .95311 L
.42675 .95288 L
.42661 .9526 L
.42647 .95228 L
.42632 .95192 L
.42617 .95156 L
.42602 .95117 L
.42588 .95081 L
.42577 .95047 L
.42565 .95015 L
.42552 .94986 L
.42538 .94964 L
.42525 .94951 L
.42513 .94948 L
.42507 .94958 L
.42508 .94985 L
.42516 .95025 L
.4253 .95074 L
.42545 .95125 L
.42562 .95174 L
.42578 .95219 L
.42594 .95256 L
.42609 .95285 L
.42623 .95303 L
.42638 .9531 L
.42655 .95305 L
.42672 .95283 L
.42689 .95246 L
.42706 .95203 L
.42722 .95156 L
.42735 .95109 L
.42743 .95066 L
.42748 .95033 L
.42751 .95014 L
.42752 .95009 L
.42751 .95014 L
.42748 .95023 L
.42741 .95035 L
.42729 .9505 L
Mistroke
.42711 .9506 L
.42687 .9507 L
.4266 .95077 L
.42631 .95075 L
.42603 .95067 L
.42579 .95055 L
.4256 .95039 L
.42544 .95022 L
.42533 .95004 L
.42527 .94989 L
.42525 .94978 L
.42526 .94973 L
.42528 .94974 L
.42531 .94979 L
.42535 .94984 L
.42538 .94989 L
.42541 .94992 L
.42544 .94996 L
.42548 .95 L
.42551 .95002 L
.42553 .95 L
.42554 .94994 L
.42555 .94987 L
.42555 .94981 L
.42556 .94982 L
.42558 .94995 L
.42562 .95019 L
.42566 .95056 L
.42571 .95102 L
.42576 .95155 L
.42583 .95213 L
.42591 .9527 L
.426 .95324 L
.42612 .95368 L
.42626 .95414 L
.42641 .95456 L
.42656 .95488 L
.42672 .95511 L
.42686 .95517 L
.42697 .95509 L
.42706 .95492 L
.42713 .95468 L
.42719 .9544 L
.42721 .95414 L
.42723 .95389 L
.42725 .95368 L
.42728 .95348 L
.4273 .95328 L
.42734 .95308 L
.42736 .95287 L
Mistroke
.42736 .95262 L
.42731 .95232 L
.42724 .95201 L
.42714 .9517 L
.42702 .95138 L
.42689 .95106 L
.42675 .95076 L
.42661 .95048 L
.42647 .95027 L
.42632 .9501 L
.42624 .95001 L
.42627 .94997 L
.42634 .94997 L
.42641 .94998 L
.42645 .94998 L
.42645 .94996 L
.42637 .94992 L
.42609 .9499 L
.4255 .94991 L
.42454 .94995 L
.42311 .94999 L
.42117 .94996 L
.41872 .94985 L
.41626 .94964 L
.41339 .94931 L
.40982 .94886 L
.40636 .94828 L
.40186 .94756 L
.39824 .9467 L
.39366 .94579 L
.38961 .94468 L
.3854 .94352 L
.3807 .94223 L
.37702 .94083 L
.37275 .93938 L
.36889 .93787 L
.36494 .93636 L
.36108 .93484 L
.35687 .93338 L
.3533 .93197 L
.34922 .93062 L
.34546 .9293 L
.34156 .928 L
.33767 .92674 L
.33398 .92546 L
.32993 .92419 L
.32652 .92294 L
.32284 .92166 L
.3193 .9204 L
.31589 .91914 L
Mistroke
.31248 .91793 L
.30933 .91682 L
.30612 .91573 L
.30327 .91469 L
.30082 .91375 L
.29859 .91289 L
.29663 .91213 L
.29514 .91153 L
.29388 .91112 L
.29294 .91091 L
.29226 .91084 L
.29175 .91086 L
.29133 .91091 L
.29091 .9109 L
.29039 .91075 L
.28968 .9104 L
.28863 .90984 L
.28744 .90912 L
.28583 .90821 L
.2838 .90713 L
.28152 .90602 L
.27893 .90464 L
.27613 .90323 L
.27302 .90169 L
.27004 .90007 L
.2671 .89837 L
.26427 .89683 L
.26145 .8953 L
.25882 .89381 L
.25628 .89242 L
.25393 .89103 L
.25159 .88955 L
.24934 .88797 L
.24717 .88625 L
.24494 .88436 L
.24264 .88229 L
.24046 .88014 L
.23819 .87777 L
.2359 .87534 L
.23365 .87272 L
.23147 .86991 L
.22933 .86709 L
.22727 .86402 L
.22549 .86115 L
.22387 .85807 L
.22245 .85532 L
.22125 .85266 L
.22022 .85023 L
.21932 .84802 L
.21846 .84604 L
Mistroke
.21754 .84413 L
.21648 .8426 L
.21524 .84121 L
.21376 .83995 L
.21197 .83881 L
.20982 .83779 L
.20771 .83682 L
.20516 .83588 L
.2022 .83478 L
.19934 .8335 L
.19607 .83197 L
.19243 .83016 L
.18904 .82812 L
.18529 .82565 L
.18168 .82301 L
.17798 .8202 L
.17454 .81747 L
.17096 .81439 L
.16774 .81143 L
.16441 .80823 L
.16132 .80527 L
.1583 .8022 L
.15546 .79924 L
.15279 .79629 L
.15032 .79363 L
.14807 .79093 L
.14603 .78825 L
.14424 .78571 L
.14262 .78303 L
.14119 .78057 L
.13988 .77801 L
.13863 .77548 L
.13736 .77293 L
.13607 .77037 L
.13479 .76764 L
.13347 .76515 L
.13219 .76248 L
.13089 .75974 L
.1297 .75717 L
.12855 .75454 L
.12748 .75212 L
.12646 .74988 L
.12559 .74761 L
.12527 .74554 L
.1245 .74347 L
.12383 .74168 L
.12334 .74001 L
.12306 .73853 L
.12295 .73729 L
.12295 .73628 L
Mistroke
.12301 .73547 L
.12307 .73483 L
.12306 .73426 L
.12294 .7337 L
.12265 .73305 L
.12212 .73226 L
.12132 .73128 L
.12029 .73007 L
.11905 .72865 L
.11784 .72718 L
.11626 .72547 L
.11442 .72358 L
.11241 .72157 L
.11024 .71925 L
.10805 .71697 L
.10569 .7145 L
.10347 .71187 L
.10145 .70934 L
.09945 .70656 L
.09771 .70376 L
.09615 .70076 L
.09476 .69754 L
.09358 .69394 L
.09253 .69021 L
.09163 .68613 L
.09081 .68169 L
.09005 .67723 L
.08934 .67231 L
.08866 .66763 L
.08799 .66347 L
.08732 .65878 L
.08668 .65401 L
.08598 .6497 L
.08523 .64523 L
.08446 .64086 L
.08363 .63673 L
.08282 .63241 L
.08201 .6283 L
.08123 .6242 L
.08054 .62003 L
.07993 .61586 L
.07941 .61181 L
.07898 .60772 L
.07864 .60367 L
.07838 .59988 L
.07817 .59608 L
.07799 .59239 L
.0778 .58908 L
.07759 .58555 L
.07735 .58234 L
Mistroke
.07705 .57894 L
.07666 .57558 L
.07617 .57202 L
.07559 .56822 L
.07493 .56475 L
.07422 .56066 L
.07351 .55655 L
.07281 .55266 L
.07213 .54884 L
.07152 .54486 L
.07101 .54033 L
.07062 .53625 L
.07037 .53193 L
.07025 .52756 L
.07029 .52318 L
.07048 .51877 L
.07081 .5143 L
.07126 .51006 L
.07179 .50599 L
.07238 .50172 L
.073 .49805 L
.07363 .49446 L
.07426 .4912 L
.07485 .48854 L
.07538 .48632 L
.07584 .4846 L
.07621 .48331 L
.07649 .48233 L
.07667 .48164 L
.07678 .48116 L
.07686 .48076 L
.07695 .48035 L
.07708 .47985 L
.07727 .47923 L
.07753 .47851 L
.07787 .47765 L
.07829 .47678 L
.07878 .47574 L
.07933 .47465 L
.07988 .47351 L
.08048 .47242 L
.08103 .47149 L
.08156 .47068 L
.08204 .47003 L
.08244 .46955 L
.08274 .46924 L
.08294 .46909 L
Mfstroke
1 .994 0 r
.008 w
.09098 .4625 Mdot
.016 w
.09098 .4625 m
.09112 .46246 L
s
1 .987 0 r
.008 w
.09112 .46246 Mdot
.016 w
.09112 .46246 m
.09139 .46238 L
s
1 .981 0 r
.008 w
.09139 .46238 Mdot
.016 w
.09139 .46238 m
.09184 .46223 L
s
1 .974 0 r
.008 w
.09184 .46223 Mdot
.016 w
.09184 .46223 m
.09247 .462 L
s
1 .968 0 r
.008 w
.09247 .462 Mdot
.016 w
.09247 .462 m
.09332 .46168 L
s
1 .962 0 r
.008 w
.09332 .46168 Mdot
.016 w
.09332 .46168 m
.09441 .46129 L
s
1 .955 0 r
.008 w
.09441 .46129 Mdot
.016 w
.09441 .46129 m
.09567 .46088 L
s
1 .949 0 r
.008 w
.09567 .46088 Mdot
.016 w
.09567 .46088 m
.09715 .46046 L
s
1 .942 0 r
.008 w
.09715 .46046 Mdot
.016 w
.09715 .46046 m
.09871 .46003 L
s
1 .936 0 r
.008 w
.09871 .46003 Mdot
.016 w
.09871 .46003 m
.10046 .45955 L
s
1 .929 0 r
.008 w
.10046 .45955 Mdot
.016 w
.10046 .45955 m
.1022 .45903 L
s
1 .923 0 r
.008 w
.1022 .45903 Mdot
.016 w
.1022 .45903 m
.10427 .45847 L
s
1 .917 0 r
.008 w
.10427 .45847 Mdot
.016 w
.10427 .45847 m
.10605 .4579 L
s
1 .91 0 r
.008 w
.10605 .4579 Mdot
.016 w
.10605 .4579 m
.10788 .45733 L
s
1 .904 0 r
.008 w
.10788 .45733 Mdot
.016 w
.10788 .45733 m
.10985 .45679 L
s
1 .897 0 r
.008 w
.10985 .45679 Mdot
.016 w
.10985 .45679 m
.11173 .45629 L
s
1 .891 0 r
.008 w
.11173 .45629 Mdot
.016 w
.11173 .45629 m
.11365 .45583 L
s
1 .885 0 r
.008 w
.11365 .45583 Mdot
.016 w
.11365 .45583 m
.11548 .45541 L
s
1 .878 0 r
.008 w
.11548 .45541 Mdot
.016 w
.11548 .45541 m
.11696 .45503 L
s
1 .872 0 r
.008 w
.11696 .45503 Mdot
.016 w
.11696 .45503 m
.11847 .45466 L
s
1 .865 0 r
.008 w
.11847 .45466 Mdot
.016 w
.11847 .45466 m
.11984 .4543 L
s
1 .859 0 r
.008 w
.11984 .4543 Mdot
.016 w
.11984 .4543 m
.12115 .45394 L
s
1 .853 0 r
.008 w
.12115 .45394 Mdot
.016 w
.12115 .45394 m
.12236 .45358 L
s
1 .846 0 r
.008 w
.12236 .45358 Mdot
.016 w
.12236 .45358 m
.1236 .45332 L
s
1 .84 0 r
.008 w
.1236 .45332 Mdot
.016 w
.1236 .45332 m
.12481 .4531 L
s
1 .833 0 r
.008 w
.12481 .4531 Mdot
.016 w
.12481 .4531 m
.12606 .45293 L
s
1 .827 0 r
.008 w
.12606 .45293 Mdot
.016 w
.12606 .45293 m
.12729 .4528 L
s
1 .821 0 r
.008 w
.12729 .4528 Mdot
.016 w
.12729 .4528 m
.12853 .45268 L
s
1 .814 0 r
.008 w
.12853 .45268 Mdot
.016 w
.12853 .45268 m
.12976 .45256 L
s
1 .808 0 r
.008 w
.12976 .45256 Mdot
.016 w
.12976 .45256 m
.13091 .45241 L
s
1 .801 0 r
.008 w
.13091 .45241 Mdot
.016 w
.13091 .45241 m
.13207 .45221 L
s
1 .795 0 r
.008 w
.13207 .45221 Mdot
.016 w
.13207 .45221 m
.13322 .45197 L
s
1 .788 0 r
.008 w
.13322 .45197 Mdot
.016 w
.13322 .45197 m
.13434 .45168 L
s
1 .782 0 r
.008 w
.13434 .45168 Mdot
.016 w
.13434 .45168 m
.13541 .45136 L
s
1 .776 0 r
.008 w
.13541 .45136 Mdot
.016 w
.13541 .45136 m
.13633 .45102 L
s
1 .769 0 r
.008 w
.13633 .45102 Mdot
.016 w
.13633 .45102 m
.13715 .4507 L
s
1 .763 0 r
.008 w
.13715 .4507 Mdot
.016 w
.13715 .4507 m
.1378 .45044 L
s
1 .756 0 r
.008 w
.1378 .45044 Mdot
.016 w
.1378 .45044 m
.13824 .45027 L
s
1 .75 0 r
.008 w
.13824 .45027 Mdot
.016 w
.13824 .45027 m
.13843 .45022 L
s
1 .744 0 r
.008 w
.13843 .45022 Mdot
.016 w
.13843 .45022 m
.13835 .45032 L
s
1 .737 0 r
.008 w
.13835 .45032 Mdot
.016 w
.13835 .45032 m
.13803 .45057 L
s
1 .731 0 r
.008 w
.13803 .45057 Mdot
.016 w
.13803 .45057 m
.13751 .45098 L
s
1 .724 0 r
.008 w
.13751 .45098 Mdot
.016 w
.13751 .45098 m
.13689 .45154 L
s
1 .718 0 r
.008 w
.13689 .45154 Mdot
.016 w
.13689 .45154 m
.13625 .45222 L
s
1 .712 0 r
.008 w
.13625 .45222 Mdot
.016 w
.13625 .45222 m
.13566 .45298 L
s
1 .705 0 r
.008 w
.13566 .45298 Mdot
.016 w
.13566 .45298 m
.13517 .45381 L
s
1 .699 0 r
.008 w
.13517 .45381 Mdot
.016 w
.13517 .45381 m
.13479 .45468 L
s
1 .692 0 r
.008 w
.13479 .45468 Mdot
.016 w
.13479 .45468 m
.13454 .45563 L
s
1 .686 0 r
.008 w
.13454 .45563 Mdot
.016 w
.13454 .45563 m
.13442 .45667 L
s
1 .679 0 r
.008 w
.13442 .45667 Mdot
.016 w
.13442 .45667 m
.13446 .45781 L
s
1 .673 0 r
.008 w
.13446 .45781 Mdot
.016 w
.13446 .45781 m
.13467 .45902 L
s
1 .667 0 r
.008 w
.13467 .45902 Mdot
.016 w
.13467 .45902 m
.13504 .46025 L
s
1 .66 0 r
.008 w
.13504 .46025 Mdot
.016 w
.13504 .46025 m
.13566 .46153 L
s
1 .654 0 r
.008 w
.13566 .46153 Mdot
.016 w
.13566 .46153 m
.13641 .46287 L
s
1 .647 0 r
.008 w
.13641 .46287 Mdot
.016 w
.13641 .46287 m
.13731 .46425 L
s
1 .641 0 r
.008 w
.13731 .46425 Mdot
.016 w
.13731 .46425 m
.13833 .46559 L
s
1 .635 0 r
.008 w
.13833 .46559 Mdot
.016 w
.13833 .46559 m
.13936 .46697 L
s
1 .628 0 r
.008 w
.13936 .46697 Mdot
.016 w
.13936 .46697 m
.14033 .46832 L
s
1 .622 0 r
.008 w
.14033 .46832 Mdot
.016 w
.14033 .46832 m
.14118 .46966 L
s
1 .615 0 r
.008 w
.14118 .46966 Mdot
.016 w
.14118 .46966 m
.1419 .47091 L
s
1 .609 0 r
.008 w
.1419 .47091 Mdot
.016 w
.1419 .47091 m
.14252 .47199 L
s
1 .603 0 r
.008 w
.14252 .47199 Mdot
.016 w
.14252 .47199 m
.14306 .47297 L
s
1 .596 0 r
.008 w
.14306 .47297 Mdot
.016 w
.14306 .47297 m
.14352 .47386 L
s
1 .59 0 r
.008 w
.14352 .47386 Mdot
.016 w
.14352 .47386 m
.14394 .47464 L
s
1 .583 0 r
.008 w
.14394 .47464 Mdot
.016 w
.14394 .47464 m
.14436 .47534 L
s
1 .577 0 r
.008 w
.14436 .47534 Mdot
.016 w
.14436 .47534 m
.1448 .47597 L
s
1 .571 0 r
.008 w
.1448 .47597 Mdot
.016 w
.1448 .47597 m
.14528 .47652 L
s
1 .564 0 r
.008 w
.14528 .47652 Mdot
.016 w
.14528 .47652 m
.14584 .47701 L
s
1 .558 0 r
.008 w
.14584 .47701 Mdot
.016 w
.14584 .47701 m
.14654 .47746 L
s
1 .551 0 r
.008 w
.14654 .47746 Mdot
.016 w
.14654 .47746 m
.14741 .47789 L
s
1 .545 0 r
.008 w
.14741 .47789 Mdot
.016 w
.14741 .47789 m
.14843 .47827 L
s
1 .538 0 r
.008 w
.14843 .47827 Mdot
.016 w
.14843 .47827 m
.14965 .47864 L
s
1 .532 0 r
.008 w
.14965 .47864 Mdot
.016 w
.14965 .47864 m
.15105 .47901 L
s
1 .526 0 r
.008 w
.15105 .47901 Mdot
.016 w
.15105 .47901 m
.15266 .47936 L
s
1 .519 0 r
.008 w
.15266 .47936 Mdot
.016 w
.15266 .47936 m
.1543 .47967 L
s
1 .513 0 r
.008 w
.1543 .47967 Mdot
.016 w
.1543 .47967 m
.15607 .47991 L
s
1 .506 0 r
.008 w
.15607 .47991 Mdot
.016 w
.15607 .47991 m
.15791 .48008 L
s
1 .5 0 r
.008 w
.15791 .48008 Mdot
.016 w
.15791 .48008 m
.15974 .48016 L
s
1 .494 0 r
.008 w
.15974 .48016 Mdot
.016 w
.15974 .48016 m
.16148 .48017 L
s
1 .487 0 r
.008 w
.16148 .48017 Mdot
.016 w
.16148 .48017 m
.163 .48012 L
s
1 .481 0 r
.008 w
.163 .48012 Mdot
.016 w
.163 .48012 m
.16434 .48003 L
s
1 .474 0 r
.008 w
.16434 .48003 Mdot
.016 w
.16434 .48003 m
.16538 .47994 L
s
1 .468 0 r
.008 w
.16538 .47994 Mdot
.016 w
.16538 .47994 m
.16613 .4799 L
s
1 .462 0 r
.008 w
.16613 .4799 Mdot
.016 w
.16613 .4799 m
.16659 .47992 L
s
1 .455 0 r
.008 w
.16659 .47992 Mdot
.016 w
.16659 .47992 m
.16678 .47998 L
s
1 .449 0 r
.008 w
.16678 .47998 Mdot
.016 w
.16678 .47998 m
.16675 .48005 L
s
1 .442 0 r
.008 w
.16675 .48005 Mdot
.016 w
.16675 .48005 m
.16652 .48009 L
s
1 .436 0 r
.008 w
.16652 .48009 Mdot
.016 w
.16652 .48009 m
.16617 .48009 L
s
1 .429 0 r
.008 w
.16617 .48009 Mdot
.016 w
.16617 .48009 m
.16574 .48001 L
s
1 .423 0 r
.008 w
.16574 .48001 Mdot
.016 w
.16574 .48001 m
.16529 .47987 L
s
1 .417 0 r
.008 w
.16529 .47987 Mdot
.016 w
.16529 .47987 m
.16479 .47964 L
s
1 .41 0 r
.008 w
.16479 .47964 Mdot
.016 w
.16479 .47964 m
.16429 .47932 L
s
1 .404 0 r
.008 w
.16429 .47932 Mdot
.016 w
.16429 .47932 m
.16383 .4789 L
s
1 .397 0 r
.008 w
.16383 .4789 Mdot
.016 w
.16383 .4789 m
.16344 .47839 L
s
1 .391 0 r
.008 w
.16344 .47839 Mdot
.016 w
.16344 .47839 m
.16319 .47781 L
s
1 .385 0 r
.008 w
.16319 .47781 Mdot
.016 w
.16319 .47781 m
.16311 .47718 L
s
1 .378 0 r
.008 w
.16311 .47718 Mdot
.016 w
.16311 .47718 m
.16323 .47652 L
s
1 .372 0 r
.008 w
.16323 .47652 Mdot
.016 w
.16323 .47652 m
.16349 .47584 L
s
1 .365 0 r
.008 w
.16349 .47584 Mdot
.016 w
.16349 .47584 m
.16382 .47517 L
s
1 .359 0 r
.008 w
.16382 .47517 Mdot
.016 w
.16382 .47517 m
.16418 .47457 L
s
1 .353 0 r
.008 w
.16418 .47457 Mdot
.016 w
.16418 .47457 m
.1645 .4741 L
s
1 .346 0 r
.008 w
.1645 .4741 Mdot
.016 w
.1645 .4741 m
.16477 .4738 L
s
1 .34 0 r
.008 w
.16477 .4738 Mdot
.016 w
.16477 .4738 m
.16496 .47369 L
s
1 .333 0 r
.008 w
.16496 .47369 Mdot
.016 w
.16496 .47369 m
.16507 .47373 L
s
1 .327 0 r
.008 w
.16507 .47373 Mdot
.016 w
.16507 .47373 m
.16506 .47386 L
s
1 .321 0 r
.008 w
.16506 .47386 Mdot
.016 w
.16506 .47386 m
.16492 .47405 L
s
1 .314 0 r
.008 w
.16492 .47405 Mdot
.016 w
.16492 .47405 m
.16458 .47424 L
s
1 .308 0 r
.008 w
.16458 .47424 Mdot
.016 w
.16458 .47424 m
.16395 .47437 L
s
1 .301 0 r
.008 w
.16395 .47437 Mdot
.016 w
.16395 .47437 m
.16318 .47438 L
s
1 .295 0 r
.008 w
.16318 .47438 Mdot
.016 w
.16318 .47438 m
.16219 .47424 L
s
1 .288 0 r
.008 w
.16219 .47424 Mdot
.016 w
.16219 .47424 m
.1609 .47395 L
s
1 .282 0 r
.008 w
.1609 .47395 Mdot
.016 w
.1609 .47395 m
.15918 .4735 L
s
1 .276 0 r
.008 w
.15918 .4735 Mdot
.016 w
.15918 .4735 m
.15705 .47285 L
s
1 .269 0 r
.008 w
.15705 .47285 Mdot
.016 w
.15705 .47285 m
.15526 .47211 L
s
1 .263 0 r
.008 w
.15526 .47211 Mdot
.016 w
.15526 .47211 m
.15267 .4711 L
s
1 .256 0 r
.008 w
.15267 .4711 Mdot
.016 w
.15267 .4711 m
.15036 .47007 L
s
1 .25 0 r
.008 w
.15036 .47007 Mdot
.016 w
.15036 .47007 m
.14715 .46892 L
s
1 .244 0 r
.008 w
.14715 .46892 Mdot
.016 w
.14715 .46892 m
.14451 .46769 L
s
1 .237 0 r
.008 w
.14451 .46769 Mdot
.016 w
.14451 .46769 m
.14106 .46648 L
s
1 .231 0 r
.008 w
.14106 .46648 Mdot
.016 w
.14106 .46648 m
.13855 .46543 L
s
1 .224 0 r
.008 w
.13855 .46543 Mdot
.016 w
.13855 .46543 m
.13476 .46449 L
s
1 .218 0 r
.008 w
.13476 .46449 Mdot
.016 w
.13476 .46449 m
.13185 .46369 L
s
1 .212 0 r
.008 w
.13185 .46369 Mdot
.016 w
.13185 .46369 m
.12811 .46305 L
s
1 .205 0 r
.008 w
.12811 .46305 Mdot
.016 w
.12811 .46305 m
.12552 .46254 L
s
1 .199 0 r
.008 w
.12552 .46254 Mdot
.016 w
.12552 .46254 m
.12177 .46213 L
s
1 .192 0 r
.008 w
.12177 .46213 Mdot
.016 w
.12177 .46213 m
.11897 .46182 L
s
1 .186 0 r
.008 w
.11897 .46182 Mdot
.016 w
.11897 .46182 m
.11542 .46162 L
s
1 .179 0 r
.008 w
.11542 .46162 Mdot
.016 w
.11542 .46162 m
.11289 .46152 L
s
1 .173 0 r
.008 w
.11289 .46152 Mdot
.016 w
.11289 .46152 m
.10957 .46155 L
s
1 .167 0 r
.008 w
.10957 .46155 Mdot
.016 w
.10957 .46155 m
.10635 .46174 L
s
1 .16 0 r
.008 w
.10635 .46174 Mdot
.016 w
.10635 .46174 m
.10373 .46211 L
s
1 .154 0 r
.008 w
.10373 .46211 Mdot
.016 w
.10373 .46211 m
.10007 .46264 L
s
1 .147 0 r
.008 w
.10007 .46264 Mdot
.016 w
.10007 .46264 m
.0975 .46333 L
s
1 .141 0 r
.008 w
.0975 .46333 Mdot
.016 w
.0975 .46333 m
.09443 .46419 L
s
1 .135 0 r
.008 w
.09443 .46419 Mdot
.016 w
.09443 .46419 m
.09109 .46521 L
s
1 .128 0 r
.008 w
.09109 .46521 Mdot
.016 w
.09109 .46521 m
.08847 .46616 L
s
1 .122 0 r
.008 w
.08847 .46616 Mdot
.016 w
.08847 .46616 m
.0859 .46723 L
s
1 .115 0 r
.008 w
.0859 .46723 Mdot
.016 w
.0859 .46723 m
.08392 .46824 L
s
1 .109 0 r
.008 w
.08392 .46824 Mdot
.016 w
.08392 .46824 m
.08154 .46935 L
s
1 .103 0 r
.008 w
.08154 .46935 Mdot
.016 w
.08154 .46935 m
.0794 .47066 L
s
1 .096 0 r
.008 w
.0794 .47066 Mdot
.016 w
.0794 .47066 m
.07788 .47178 L
s
1 .09 0 r
.008 w
.07788 .47178 Mdot
.016 w
.07788 .47178 m
.07663 .47288 L
s
1 .083 0 r
.008 w
.07663 .47288 Mdot
.016 w
.07663 .47288 m
.07558 .47395 L
s
1 .077 0 r
.008 w
.07558 .47395 Mdot
.016 w
.07558 .47395 m
.07477 .47498 L
s
1 .071 0 r
.008 w
.07477 .47498 Mdot
.016 w
.07477 .47498 m
.07418 .47595 L
s
1 .064 0 r
.008 w
.07418 .47595 Mdot
.016 w
.07418 .47595 m
.07377 .47683 L
s
1 .058 0 r
.008 w
.07377 .47683 Mdot
.016 w
.07377 .47683 m
.07348 .47761 L
s
1 .051 0 r
.008 w
.07348 .47761 Mdot
.016 w
.07348 .47761 m
.07328 .47827 L
s
1 .045 0 r
.008 w
.07328 .47827 Mdot
.016 w
.07328 .47827 m
.0731 .47885 L
s
1 .038 0 r
.008 w
.0731 .47885 Mdot
.016 w
.0731 .47885 m
.07297 .4794 L
s
1 .032 0 r
.008 w
.07297 .4794 Mdot
.016 w
.07297 .4794 m
.07292 .48001 L
s
1 .026 0 r
.008 w
.07292 .48001 Mdot
.016 w
.07292 .48001 m
.0729 .48046 L
s
1 .019 0 r
.008 w
.0729 .48046 Mdot
.016 w
.0729 .48046 m
.07285 .48091 L
s
1 .013 0 r
.008 w
.07285 .48091 Mdot
.016 w
.07285 .48091 m
.07283 .48124 L
s
1 .006 0 r
.008 w
.07283 .48124 Mdot
.016 w
.07283 .48124 m
.07287 .48144 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolE0026Ool007Eoo`8m
k`03Oolmkcg_00`mkaAoo`T007eoo`00JWoo0Sg_0Woo0cg_00=oocg_?Nl07cg_47oo1P00Mgoo001Y
Ool[?NlEOol5001bOol006MoobhmkaUoo`@006ioo`00IGoo<3g_7Goo1000JWoo001SOolb?NlQOol3
001WOol0069ooc8mkbEoo`<006Aoo`00H7oo7cg_27oo1cg_;Woo0`00HGoo001NOolB?Nl00goo?Nlm
k`0:?Nm2Ool2001OOol005aooa4mk`Ioo`03?Nmoogoo00HmkdEoo`8005eoo`00FWoo00<003g_?Nl0
2cg_Fgoo0P00Fgoo001HOol00`00?Nlmk`09?NmQOol2001IOol005Eoo`<000XmkfEoo`<005Ioo`00
Dgoo0P000Woo2cg_J7oo0P00E7oo001AOol200000goo?Nlmk`09?Nm]Ool2001BOol0051oo`03001o
ogoo00`mkfmoo`03001oogoo04moo`00Cgoo00<007oo?Nl03Cg_L7oo00<007ooOol0CWoo001=Ool2
00000goo?Nlmk`0<?NmbOol2001>Ool004]oo`800003Oolmkcg_00/mkgMoo`8004aoo`00BGoo0P00
00=oocg_?Nl033g_NWoo0P00BWoo0018Ool00`00Oolmk`0??NmlOol00`00Oomoo`17Ool004Ioo`80
0003Oolmkcg_00lmkgeoo`8004Moo`00AGoo00<007oo?Nl04Cg_P7oo00<007ooOol0A7oo0014Ool0
0`00Oolmk`0??Nn4Ool00`00Oomoo`13Ool004=oo`03000mkcg_00lmkhIoo`03001oogoo049oo`00
@Goo0P0043g_RGoo0P00@Woo0010Ool00`00Oomoo`0@?Nn;Ool00`00Oomoo`0oOol003moo`03001o
ogoo00Xmki=oo`8003moo`00?Woo00<007oo?Nl02Sg_UWoo00<007ooOol0?7oo000lOol2000<?NnH
Ool00`00Oomoo`0kOol003]oo`03001oocg_00/mkiYoo`03001oogoo03Yoo`00>Woo00<003g_?Nl0
2cg_W7oo0P00>Woo000iOol00`00?Nlmk`0:?NnPOol00`00Oomoo`0gOol003Moo`800003Oolmkcg_
00Xmkj5oo`03001oogoo03Ioo`00=Woo00<007ooOol02Cg_YWoo00<007ooOol0=Goo000eOol00`00
Oomoo`0:?NnWOol00`00Oomoo`0dOol003Aoo`04001oogooOol9?NnYOol00`00Oomoo`0cOol0039o
o`8000=oo`XmkjYoo`03001oogoo039oo`00<Goo00<007ooOol00Woo2cg_Zgoo00<007ooOol0<Goo
000`Ool00`00Oomoo`02Ool<?Nn/Ool00`00Oomoo`0`Ool0031oo`03001oogoo009oo`/mkjioo`03
001oogoo02moo`00;goo00<007ooOol00Woo2Sg_/Goo00<007ooOol0;Woo000^Ool00`00Oomoo`03
Ool:?NnbOol00`00Oomoo`0]Ool002eoo`03001oogoo00Aoo`Xmkk=oo`03001oogoo02aoo`00;7oo
00<007ooOol017oo2Sg_]Goo00<007ooOol0:goo000/Ool00`00Oomoo`03Ool9?NngOol00`00Oomo
o`0[Ool002]oo`03001oogoo00Aoo`LmkkYoo`03001oogoo02Yoo`00:Woo00<007ooOol017oo1Cg_
_Woo00<007ooOol0:Goo000YOol00`00Oomoo`04Ool6?NnoOol00`00Oomoo`0XOol002Qoo`03001o
ogoo00Aoo`Hmkl5oo`03001oogoo02Moo`00:7oo00<007ooOol017oo1Sg_`Goo00<007ooOol09goo
000WOol00`00Oomoo`04Ool7?No2Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Eoo`Pmkl9oo`03
001oogoo02Eoo`009Goo00<007ooOol01Goo2Cg_`goo00<007ooOol097oo000TOol00`00Oomoo`06
Ool8?No5Ool00`00Oomoo`0SOol002Aoo`03001oogoo00Eoo`PmklIoo`03001oogoo02=oo`008goo
00<007ooOol01Goo23g_b7oo00<007ooOol08Woo000ROol00`00Oomoo`05Ool9?No9Ool00`00Oomo
o`0QOol0029oo`03001oogoo00Eoo`TmklUoo`03001oogoo025oo`008Goo00<007ooOol01Goo2Cg_
bgoo00<007ooOol087oo000POol00`00Oomoo`06Ool8?No=Ool00`00Oomoo`0OOol0021oo`03001o
ogoo00Eoo`Lmklmoo`03001oogoo01moo`007goo00<007ooOol01Woo1Sg_dGoo00<007ooOol07Woo
000OOol00`00Oomoo`05Ool7?NoBOol00`00Oomoo`0MOol001ioo`03001oogoo00Ioo`Lmkm9oo`03
001oogoo01eoo`007Goo00<007ooOol01Woo23g_dgoo00<007ooOol077oo000MOol00`00Oomoo`05
Ool9?NoCOol00`00Oomoo`0LOol001aoo`03001oogoo00Ioo`PmkmEoo`03001oogoo01]oo`0077oo
00<007ooOol01Goo2Cg_eGoo00<007ooOol06goo000KOol00`00Oomoo`06Ool9?NoFOol00`00Oomo
o`0JOol001]oo`03001oogoo00Eoo`TmkmMoo`03001oogoo01Yoo`006Woo00<007ooOol01Goo2Sg_
f7oo00<007ooOol06Goo000JOol00`00Oomoo`05Ool9?NoIOol00`00Oomoo`0IOol001Uoo`03001o
ogoo00Eoo`Tmkm]oo`03001oogoo01Qoo`006Goo00<007ooOol01Goo23g_g7oo00<007ooOol067oo
000HOol00`00Oomoo`05Ool8?NoNOol00`00Oomoo`0GOol001Qoo`03001oogoo00Aoo`Pmkmmoo`03
001oogoo01Moo`0067oo00<007ooOol017oo23g_ggoo00<007ooOol05goo000GOol00`00Oomoo`04
Ool9?NoPOol00`00Oomoo`0FOol001Moo`03001oogoo00Aoo`Pmkn5oo`03001oogoo01Ioo`005Woo
00<007ooOol01Goo23g_hWoo00<007ooOol05Goo000FOol00`00Oomoo`04Ool7?NoTOol00`00Oomo
o`0EOol001Eoo`03001oogoo00Eoo`LmknEoo`03001oogoo01Aoo`005Goo00<007ooOol01Goo1cg_
iGoo00<007ooOol057oo000EOol00`00Oomoo`05Ool7?NoUOol00`00Oomoo`0DOol001Aoo`03001o
ogoo00Ioo`HmknMoo`03001oogoo01=oo`0057oo00<007ooOol01Woo1Sg_igoo00<007ooOol04goo
000DOol00`00Oomoo`05Ool7?NoWOol00`00Oomoo`0COol001=oo`03001oogoo00Ioo`HmknUoo`03
001oogoo019oo`004goo00<007ooOol01Woo1Sg_jGoo00<007ooOol04Woo000COol00`00Oomoo`06
Ool6?NoYOol00`00Oomoo`0BOol0019oo`03001oogoo00Moo`Dmkn]oo`03001oogoo015oo`004Woo
00<007ooOol01goo1Cg_jgoo00<007ooOol04Goo000BOol00`00Oomoo`06Ool5?No/Ool00`00Oomo
o`0AOol0015oo`03001oogoo00Moo`Dmkneoo`03001oogoo011oo`004Goo00<007ooOol01goo1Cg_
kGoo00<007ooOol047oo000AOol00`00Oomoo`07Ool6?No/Ool00`00Oomoo`0@Ool0015oo`03001o
ogoo00Moo`Hmkneoo`03001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo
000@Ool00`00Oomoo`08Ool5?No^Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Dmknioo`03
001oogoo00moo`0047oo00<007ooOol027oo1Cg_kWoo00<007ooOol03goo000?Ool00`00Oomoo`09
Ool5?No_Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Dmknmoo`03001oogoo00ioo`003goo
00<007ooOol02Goo13g_l7oo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4?No`Ool00`00Oomo
o`0>Ool000moo`03001oogoo00Uoo`@mko1oo`03001oogoo00ioo`003Woo00<007ooOol02Woo13g_
lGoo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool4?NoaOol00`00Oomoo`0=Ool000ioo`03001o
ogoo0?moo`03001oogoo00eoo`003Woo00<007ooOol0ogoo00<007ooOol03Goo000>Ool00`00Oomo
o`3oOol1Ool00`00Oomoo`0<Ool000eoo`03001oogoo0?moo`9oo`03001oogoo00aoo`003Goo00<0
07ooOol0ogoo0Woo00<007ooOol037oo000=Ool00`00Oomoo`3oOol2Ool00`00Oomoo`0<Ool000eo
o`03001oogoo01Eoo`9oP09oo`An`003O^1oogoo0>5oo`03001oogoo00aoo`003Goo00<007ooOol0
57oo0WmP00=o@7lPOb0017k000=nh7ooOol0hGoo00<007ooOol037oo000=Ool00`00Oomoo`0@Ool0
17nPO81lP7n00WmP00=o@7lPO<0017jP00=nh7ooOol0hGoo00<007ooOol037oo000=Ool00`00Oomo
o`0=Ool2O6000gnPO81lP002O804O:02O<03OX000gkPOomoo`3QOol00`00Oomoo`0<Ool000eoo`03
001oogoo00Uoo`<mk`AlH0ElP0=lX0El`09lh>9oo`03001oogoo00aoo`003Goo00<007ooOol027oo
0Sg_0Wa01GaP0gb017bP1Gc00gcPhGoo00<007ooOol037oo000=Ool00`00Oomoo`08Ool00cg_O41l
@002O403O603O805O:05O<04O>02O@000ge0Oomoo`3KOol00`00Oomoo`0<Ool000eoo`03001oogoo
00Qoo`Al809l@003O61lP7b0009lP0@mk`Il`0Elh003O@1m87dP0=aoo`03001oogoo00aoo`0037oo
00<007ooOol02Goo17`000=l@7aPO6001Goo1Sg_1gcP0Wd00WdP00=m`7ooOol0fWoo00<007ooOol0
2goo000<Ool00`00Oomoo`09Ool4O002O602?Nl5Ool5?Nl017ooOT1n87d00WcP0gd00WdP00=m`7oo
Ool0fWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_O01l0002O00??Nl017i0OR1n07h0
17d00WdP00=m`7ooOol0fWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_O01l0002O00@
?Nl00ghPOP1n0002ON04OH000gg0Oomoo`3JOol00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03
?Nml07`0009l010mknIoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_00=oocg_?Nl033g_
iWoo00<007ooOol02goo000<Ool00`00Oomoo`08Ool6?Nl6Ool9?NoVOol00`00Oomoo`0;Ool000ao
o`03001oogoo00Qoo`Hmk`Yoo`HmknEoo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo
1Sg_iGoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7?Nl;Ool6?NoTOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Moo`Dmk`aoo`LmknAoo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_
37oo2Cg_hWoo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5?Nl<Ool:?NoQOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Moo`Dmk`aoo`Xmkn5oo`03001oogoo00]oo`003Goo00<007ooOol01Woo
1Cg_37oo2cg_h7oo00<007ooOol02goo000=Ool00`00Oomoo`06Ool5?Nl@Ool7?NoOOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkmioo`03001oogoo00aoo`003Goo00<007ooOol0
1Woo1Cg_47oo23g_gWoo00<007ooOol037oo000=Ool00`00Oomoo`06Ool6?Nl?Ool8?NoNOol00`00
Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmkmeoo`03001oogoo00aoo`003Goo00<007oo
Ool01goo1Cg_47oo23g_gGoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?Nl@Ool8?NoMOol0
0`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Hmk`moo`Tmkmaoo`03001oogoo00aoo`003Goo00<0
07ooOol01goo1Sg_3goo2Sg_fgoo00<007ooOol037oo000=Ool00`00Oomoo`07Ool5?NlAOol9?NoK
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka9oo`Pmkm]oo`03001oogoo00aoo`003Woo
00<007ooOol01Woo1Sg_4Woo1cg_fWoo00<007ooOol03Goo000>Ool00`00Oomoo`07Ool5?NlBOol5
?NoLOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmko=oo`03001oogoo00eoo`003Woo00<0
07ooOol01goo1Sg_lWoo00<007ooOol03Goo000?Ool00`00Oomoo`06Ool6?NobOol00`00Oomoo`0=
Ool000moo`03001oogoo00Moo`Hmko1oo`03001oogoo00ioo`003goo00<007ooOol01goo1Sg_l7oo
00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?No`Ool00`00Oomoo`0>Ool000moo`03001oogoo
00Moo`Hmko1oo`03001oogoo00ioo`0047oo00<007ooOol01Woo1Sg_l7oo00<007ooOol03Woo000@
Ool00`00Oomoo`06Ool5?No`Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Dmko1oo`03001o
ogoo00moo`0047oo00<007ooOol01Woo1Sg_kgoo00<007ooOol03goo000@Ool00`00Oomoo`06Ool6
?No_Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Hmknmoo`03001oogoo00moo`004Goo00<0
07ooOol01Woo1Sg_kGoo00<007ooOol047oo000AOol00`00Oomoo`06Ool7?No/Ool00`00Oomoo`0@
Ool0019oo`03001oogoo00Eoo`Pmkn]oo`03001oogoo011oo`004Woo00<007ooOol01Goo1Cg_kGoo
00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?No]Ool00`00Oomoo`0AOol001=oo`03001oogoo
00Eoo`@mkneoo`03001oogoo015oo`004goo00<007ooOol01Goo1Cg_jgoo00<007ooOol04Woo000C
Ool00`00Oomoo`05Ool5?No[Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`DmkmYoo`03?Nmo
ogoo00ioo`03001oogoo019oo`0057oo00<007ooOol017oo1Sg_fGoo0Sg_3Woo00<007ooOol04goo
000DOol00`00Oomoo`04Ool6?NoIOol3?Nl=Ool00`00Oomoo`0COol001Eoo`03001oogoo00=oo`Hm
kmUoo`@mk`aoo`03001oogoo01=oo`005Goo00<007ooOol00goo1Sg_dWoo33g_2Woo00<007ooOol0
57oo000EOol00`00Oomoo`03Ool6?NoCOol;?Nl:Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Ao
o`DmkmAoo`Xmk`Yoo`03001oogoo01Aoo`005Woo00<007ooOol00goo1Cg_eGoo2Cg_2Goo00<007oo
Ool05Goo000FOol00`00Oomoo`03Ool5?NoEOol9?Nl9Ool00`00Oomoo`0EOol001Moo`03001oogoo
009oo`DmkmEoo`Pmk`Uoo`03001oogoo01Ioo`005goo00<007ooOol00Woo1Sg_e7oo23g_2Goo00<0
07ooOol05Woo000HOol01000Oomoogoo1Sg_e7oo23g_27oo00<007ooOol05goo000HOol01000Oomo
ogoo1Sg_dgoo2Cg_27oo00<007ooOol05goo000IOol01000Oomoogoo1Sg_d7oo2cg_27oo00<007oo
Ool05goo000IOol01000Oomoogoo1cg_cWoo2cg_27oo00<007ooOol067oo000JOol00`00Oomoo`07
?No=Ool<?Nl8Ool00`00Oomoo`0HOol001Yoo`04001oogooOol7?No9Ool>?Nl8Ool00`00Oomoo`0I
Ool001]oo`03001oogoo00PmklIooa0mk`Moo`03001oogoo01Yoo`006goo00<007ooOol02Cg_aGoo
43g_1goo00<007ooOol06Woo000LOol00`00Oolmk`09?No4Ool@?Nl6Ool00`00Oomoo`0KOol001ao
o`03001oogoo00Xmkl=oo`Hmk`=oo`Hmk`Moo`03001oogoo01]oo`007Goo00<007oo?Nl02Cg_`Woo
1Cg_1Goo1Sg_1Woo00<007ooOol077oo000MOol00`00Oolmk`0:?No1Ool5?Nl5Ool6?Nl6Ool00`00
Oomoo`0LOol001ioo`03000mkcg_00Tmkl5oo`Dmk`Eoo`Dmk`Ioo`03001oogoo01eoo`007Woo00<0
03g_?Nl02Cg_`Goo1Cg_1Goo1Cg_1Woo00<007ooOol07Goo000OOol;?No1Ool5?Nl4Ool6?Nl5Ool0
0`00Oomoo`0NOol001moo`03000mkcg_00Tmkkmoo`Hmk`Aoo`Hmk`Eoo`03001oogoo01ioo`0087oo
2cg__goo1Cg_17oo1Sg_1Goo00<007ooOol07goo000POol00`00?Nlmk`09?NnmOol5?Nl5Ool6?Nl5
Ool00`00Oomoo`0OOol0025oo`/mkkeoo`Dmk`Eoo`Hmk`Aoo`03001oogoo021oo`008Woo00<003g_
?Nl023g__7oo1Cg_17oo1cg_0goo00<007ooOol08Goo000SOol:?NnkOol6?Nl4Ool6?Nl3Ool00`00
Oomoo`0ROol002Aoo`XmkkYoo`Dmk`Eoo`Hmk`9oo`03001oogoo02=oo`0097oo00<003g_?Nl01cg_
^Woo13g_1Goo1cg_0Woo00<007ooOol08goo000UOol:?NnhOol5?Nl5Ool6?Nl2Ool00`00Oomoo`0T
Ool002Ioo`03000mkcg_00LmkkIoo`Hmk`Aoo`Hmk`9oo`03001oogoo02Eoo`009Woo00<007oo?Nl0
2cg_/Woo1Cg_17oo1cg_0Woo00<007ooOol09Goo000WOol00`00Oolmk`0:?NnbOol5?Nl3Ool8?Nl0
0goo001oo`0WOol002Qoo`03001oocg_00Tmkk5oo`Hmk`9oo`Pmk`03Ool007oo02Qoo`00:Goo00<0
07oo?Nl02Cg_/7oo1Cg_0Woo23g_00=oo`00Ool0:Goo000ZOol00`00Oolmk`08?Nn`Ool4?Nl2Ool9
?Nl00`00Oomoo`0YOol002Yoo`03001oogoo00Tmkjioo`Dmk`9oo`Tmk`03001oogoo02Uoo`00:goo
00@007ooOomoo`Pmkjeoo`Dmk`9oo`Pmk`03001oogoo02Yoo`00;7oo00<007ooOol023g_[7oo1Cg_
00=oocg_?Nl01cg_00<007ooOol0:goo000]Ool00`00Oolmk`08?Nn[Ool5?Nl00goo?Nlmk`06?Nl0
0`00Oomoo`0/Ool002ioo`03001oogoo00TmkjUoo`dmk`03001oogoo02eoo`00;Woo00@007ooOomo
o`TmkjQoo`Xmk`=oo`03001oogoo02eoo`00;goo00@007ooOomoo`XmkjEoo`Xmk`=oo`03001oogoo
02ioo`00<7oo00@007ooOomoo`XmkjAoo`Tmk`=oo`03001oogoo02moo`00<Goo00@007ooOomoo``m
kj1oo`Pmk`Aoo`03001oogoo031oo`00<Woo0P000Woo3Cg_W7oo2Cg_0goo0P00<goo000dOol00`00
Oomoo`0<?NnJOol:?Nl3Ool00`00Oomoo`0cOol003Eoo`03001oocg_00`mkiQoo`Xmk`=oo`03001o
ogoo03Aoo`00=Goo00@007ooOomoo``mkiEoo``mk`=oo`03001oogoo03Aoo`00=Woo00@007ooOomo
o`/mkiAoo`Xmk`Eoo`03001oogoo03Eoo`00=goo00<007ooOol00Woo2Cg_U7oo23g_1Woo00<007oo
Ool0=Woo000hOol00`00Oomoo`02Ool9?NnBOol9?Nl5Ool00`00Oomoo`0gOol003Uoo`8000=oo`Pm
ki5oo`Xmk`=oo`8003Yoo`00>goo00<007ooOol02Cg_Sgoo2Sg_0goo00<007ooOol0>Woo000lOol0
0`00Oomoo`09?Nn=Ool:?Nl3Ool00`00Oomoo`0kOol003eoo`03001oogoo00XmkhUoo`Tmk`Eoo`03
001oogoo03aoo`00?Woo0P000Woo2Cg_Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`09?Nn4Ool;
?Nl3Ool00`00Oomoo`0oOol0045oo`800003Oolmkcg_00Tmkh1oo`Tmk`Aoo`80049oo`00@goo00<0
07oo?Nl02Sg_NGoo3Sg_17oo00<007ooOol0@Woo0014Ool00`00?Nlmk`09?NmiOol=?Nl4Ool00`00
Oomoo`13Ool004Eoo`03000mkcg_00TmkgQoo`/mk`Eoo`03001oogoo04Aoo`00AWoo00<003g_?Nl0
2cg_M7oo33g_0goo0P00Agoo0018Ool>?Nl2Ool2?Nm/Ool=?Nl2Ool20019Ool004Yooa4mkfYoo``m
k`9oo`8004]oo`00C7oo43g_Igoo2cg_0goo0P00CGoo001>OolA?NmSOol;?Nl3Ool00`00Oomoo`1=
Ool004moo`03000mkcg_00lmkf1oo``mk`9oo`03001oogoo04ioo`00D7oo0P0000=oocg_?Nl03cg_
FGoo00<mkgooOol02Sg_0goo0P00DGoo001BOol20002OolA?NmBOol00cg_Oomoo`0>?Nl00goo0000
001COol005Aoo`80009ooa4mk`Moo`Dmkd1ooa<mk`03Ool0000005Eoo`00EWoo0P0017oo4Cg_0Woo
1Sg_?Woo53g_0P00Egoo001HOol30004OolF?NllOolE?Nl00`00Oomoo`1GOol005]oo`<000=ooa@m
kcUooaDmk`03001oogoo05Yoo`00GWoo0P0017oo4Sg_=7oo63g_GWoo001POol20004OolG?NlTOolN
?NmQOol0069oo`<000AooaDmk`moo`<mk`aoob0mk`03001oogoo065oo`00IGoo0`001Goo9Sg_0Woo
8Sg_00<003g_?Nl0IWoo001XOol40003Oom4?Nl01P00?Nl00000OolmkfMoo`00K7oo10000goo>cg_
00=oo`0000000P00KGoo001`Ool30003Ool`?Nl5Ool4001aOol007=oo`D00003Oolmkcg_02Dmk`Mo
o`@007Eoo`00N7oo10007Cg_1goo1`00NGoo001oOol??Nl4Ool>0020Ool008eoo`D008ioo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00SWoo0P00T7oo002=Ool01000Oomoo`00Sgoo
002=Ool01000Oomoo`00Sgoo002>Ool2002@Ool008eoo`04001oogoo002?Ool008ioo`80091oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -178.502, 1.30024, \
1.30024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.516342 0.00270499 [
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(9)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.459849 scale
1.05 1.12285 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .41528 m
.08448 .41516 L
.08463 .41497 L
.08481 .41471 L
.08501 .41438 L
.08522 .41396 L
.08542 .41344 L
.08562 .41284 L
.08581 .41218 L
.08602 .41145 L
.08626 .41063 L
.08654 .40974 L
.08686 .40884 L
.08716 .4079 L
.08743 .40697 L
.08772 .40608 L
.088 .40525 L
.08829 .40442 L
.08859 .40357 L
.08891 .40269 L
.08923 .40177 L
.08951 .40086 L
.08973 .39989 L
.08987 .39886 L
.08993 .39777 L
.0899 .39671 L
.08981 .39554 L
.08971 .39438 L
.08963 .39319 L
.08956 .39194 L
.08951 .39065 L
.0895 .38947 L
.0895 .38831 L
.08949 .38722 L
.08949 .38626 L
.08952 .38541 L
.08958 .38468 L
.08969 .38404 L
.08983 .38347 L
.09 .38288 L
.09019 .38223 L
.09037 .38151 L
.09055 .38068 L
.09073 .3797 L
.09096 .37856 L
.09126 .37748 L
.09164 .3762 L
.0921 .37486 L
.09264 .37328 L
.09322 .37179 L
Mistroke
.09382 .37008 L
.09442 .36821 L
.09499 .36647 L
.09554 .36466 L
.09606 .3629 L
.09658 .36116 L
.09711 .35976 L
.09765 .35834 L
.09819 .35706 L
.09867 .35598 L
.09908 .35498 L
.09941 .35418 L
.09966 .35353 L
.09987 .35304 L
.10005 .35271 L
.10024 .35256 L
.10045 .35255 L
.10063 .35266 L
.10076 .35283 L
.10083 .35301 L
.10083 .35313 L
.10076 .35313 L
.10062 .353 L
.10043 .35271 L
.10021 .35227 L
.09997 .35169 L
.09971 .35098 L
.09945 .35017 L
.09919 .34938 L
.09893 .34849 L
.09868 .34755 L
.09844 .34658 L
.09823 .34575 L
.09807 .34501 L
.09794 .34442 L
.09785 .34403 L
.09779 .34389 L
.09776 .34401 L
.09778 .34436 L
.09782 .34486 L
.09787 .34542 L
.09794 .34599 L
.09806 .3465 L
.09823 .34691 L
.09845 .34719 L
.09873 .3473 L
.09906 .34725 L
.09944 .34702 L
.09988 .34661 L
.10037 .34604 L
Mistroke
.1009 .34535 L
.10147 .34456 L
.10202 .34368 L
.10254 .34277 L
.10305 .34194 L
.10353 .34124 L
.10397 .34065 L
.10439 .34015 L
.10479 .3397 L
.10519 .33929 L
.1056 .3389 L
.10604 .33847 L
.10652 .33798 L
.10703 .33738 L
.10757 .33666 L
.10816 .33578 L
.1088 .3347 L
.10946 .33357 L
.11008 .33218 L
.1107 .33061 L
.11132 .32909 L
.11189 .32741 L
.11238 .32573 L
.11278 .32406 L
.1131 .32257 L
.11332 .32116 L
.11347 .31991 L
.11356 .31889 L
.11358 .31803 L
.11356 .3173 L
.11352 .31672 L
.11346 .31627 L
.1134 .31598 L
.11333 .31583 L
.11327 .3158 L
.11321 .31588 L
.11316 .31603 L
.11312 .3162 L
.11309 .31636 L
.11309 .31649 L
.11315 .31654 L
.11331 .31652 L
.11361 .31639 L
.11404 .31614 L
.11463 .31576 L
.11536 .31526 L
.11625 .31463 L
.11731 .31386 L
.11842 .313 L
.11967 .31207 L
Mistroke
.12087 .31107 L
.12212 .31003 L
.12336 .30903 L
.12444 .30818 L
.12548 .30744 L
.12644 .30684 L
.12728 .30635 L
.12797 .30597 L
.12853 .30565 L
.129 .30533 L
.12937 .30499 L
.12968 .30458 L
.12996 .30407 L
.13026 .30347 L
.13061 .30275 L
.131 .30191 L
.13143 .30104 L
.13189 .3001 L
.13238 .29911 L
.13287 .2981 L
.13336 .29717 L
.13384 .2963 L
.13429 .29554 L
.1347 .29496 L
.13507 .29453 L
.13539 .29422 L
.13564 .29397 L
.13582 .29375 L
.13594 .29348 L
.13603 .2931 L
.1361 .29259 L
.13619 .29192 L
.13631 .29114 L
.13647 .29029 L
.13664 .28953 L
.13684 .2885 L
.13706 .28754 L
.13727 .2865 L
.13747 .28538 L
.13764 .28418 L
.13778 .28299 L
.13789 .28175 L
.13801 .28046 L
.13814 .27911 L
.1383 .27789 L
.13846 .27648 L
.13867 .27504 L
.13892 .27353 L
.13923 .27196 L
.13964 .27026 L
Mistroke
.14014 .26881 L
.14076 .26736 L
.1415 .26595 L
.14228 .26464 L
.14313 .26344 L
.14402 .26229 L
.14494 .26116 L
.14581 .26007 L
.14671 .25895 L
.1476 .25786 L
.14857 .2568 L
.14952 .25573 L
.15056 .25461 L
.15171 .25348 L
.15289 .25236 L
.15413 .25116 L
.1554 .24998 L
.15654 .24878 L
.15766 .2476 L
.15872 .24646 L
.15972 .24551 L
.16067 .24454 L
.16146 .24366 L
.16215 .24297 L
.1627 .24238 L
.16311 .24187 L
.16339 .24143 L
.16351 .24105 L
.16352 .24072 L
.16346 .24041 L
.16339 .24007 L
.16332 .23968 L
.16328 .23919 L
.16326 .23863 L
.16326 .23808 L
.16324 .23764 L
.16318 .23727 L
.16308 .23704 L
.16294 .23704 L
.16275 .23724 L
.16251 .23768 L
.16224 .23833 L
.16195 .23915 L
.16165 .24 L
.16137 .24108 L
.1611 .24207 L
.16088 .24305 L
.16072 .24395 L
.16066 .24469 L
.16071 .24524 L
Mistroke
.16091 .24557 L
.16125 .24572 L
.16173 .24575 L
.16232 .2457 L
.16302 .2456 L
.1638 .2455 L
.16461 .24543 L
.16534 .24541 L
.16601 .24542 L
.16657 .24543 L
.16697 .24544 L
.16721 .24545 L
.16727 .24544 L
.16717 .24541 L
.16698 .24535 L
.16672 .24526 L
.16633 .24516 L
.16586 .24504 L
.16527 .24496 L
.16457 .24493 L
.1638 .245 L
.16296 .24519 L
.16206 .24553 L
.1611 .24603 L
.16008 .24673 L
.15901 .24764 L
.15802 .2487 L
.15693 .24999 L
.15568 .25147 L
.15413 .25308 L
.15273 .25466 L
.15127 .25634 L
.14976 .2581 L
.14833 .25979 L
.14687 .26133 L
.14544 .26286 L
.14415 .26436 L
.14295 .26572 L
.14174 .26709 L
.14051 .2685 L
.13927 .26998 L
.1381 .27146 L
.137 .27302 L
.13592 .27475 L
.13488 .27663 L
.13392 .27843 L
.13302 .28044 L
.13217 .2824 L
.13136 .2844 L
.13065 .28625 L
Mistroke
.13006 .28786 L
.12958 .28931 L
.12923 .29056 L
.12897 .2915 L
.12877 .29225 L
.12859 .29284 L
.12841 .29329 L
.12819 .29364 L
.12788 .29396 L
.12747 .29429 L
.12697 .29464 L
.12639 .29503 L
.12573 .29546 L
.12509 .29596 L
.12428 .29661 L
.1235 .29733 L
.12264 .29819 L
.12172 .29915 L
.12078 .3002 L
.11987 .30133 L
.119 .30255 L
.11823 .30374 L
.11745 .305 L
.1167 .30631 L
.11598 .30764 L
.11528 .30894 L
.11457 .31035 L
.11392 .31185 L
.11341 .31337 L
.11302 .31481 L
.11269 .31621 L
.11239 .31761 L
.11208 .31875 L
.11172 .31996 L
.11124 .32105 L
.11062 .32223 L
.10995 .32348 L
.10908 .32468 L
.10808 .32591 L
.107 .32716 L
.10597 .32844 L
.10488 .32973 L
.10369 .33092 L
.10243 .33214 L
.10117 .33341 L
.10008 .33473 L
.09911 .33599 L
.09828 .3373 L
.09758 .33867 L
.09701 .34006 L
Mistroke
.09655 .34138 L
.09619 .34267 L
.09591 .344 L
.09569 .34538 L
.09552 .3468 L
.09537 .34826 L
.09524 .34977 L
.09508 .35128 L
.0949 .35265 L
.0947 .3539 L
.09451 .355 L
.09433 .35596 L
.09413 .35681 L
.09389 .35752 L
.09362 .35814 L
.09333 .35871 L
.09303 .35923 L
.09274 .35975 L
.09247 .3603 L
.09221 .36094 L
.09195 .36172 L
.09169 .36267 L
.09142 .36376 L
.0911 .365 L
.09072 .36646 L
.09028 .36822 L
.0898 .37003 L
.08933 .37205 L
.08888 .37424 L
.08848 .37618 L
.08811 .37843 L
.08775 .38044 L
.08741 .38262 L
.08708 .38499 L
.08674 .38737 L
.08641 .38949 L
.0861 .39168 L
.08582 .394 L
.08559 .39637 L
.08541 .39837 L
.08524 .4005 L
.08507 .40255 L
.08492 .40453 L
.08477 .40643 L
.08464 .4081 L
.08451 .40962 L
.08444 .41091 L
.08441 .412 L
.0844 .41289 L
.08442 .4136 L
Mistroke
.08445 .41415 L
.08447 .41458 L
.08447 .41497 L
.08447 .41537 L
.08446 .41583 L
.08445 .41637 L
.08444 .41702 L
.08443 .4178 L
.08441 .41862 L
.08439 .41953 L
.08438 .42053 L
.08436 .42158 L
.08434 .42264 L
.08432 .42355 L
.08431 .4244 L
.0843 .42515 L
.08429 .42577 L
.08428 .42622 L
.08427 .42651 L
Mfstroke
.0843 .42623 m
.08431 .42606 L
.08431 .42584 L
.08429 .42558 L
.08426 .42522 L
.08422 .42496 L
.08421 .42455 L
.08422 .42412 L
.08427 .42363 L
.08436 .42296 L
.08451 .42231 L
.08473 .42178 L
.08498 .42105 L
.08526 .42034 L
.08553 .41957 L
.08578 .41872 L
.08603 .4177 L
.08628 .41684 L
.08654 .41595 L
.08679 .41492 L
.087 .41375 L
.08714 .41258 L
.08722 .41162 L
.08725 .41058 L
.08726 .40949 L
.08724 .40855 L
.08721 .40763 L
.0872 .40676 L
.08721 .40602 L
.08722 .40542 L
.08723 .40491 L
.08723 .40448 L
.08723 .40414 L
.08724 .40391 L
.08724 .40378 L
.08724 .40372 L
.08724 .4037 L
.08724 .40373 L
.08724 .40379 L
.08724 .40387 L
.08724 .40393 L
.08724 .40396 L
.08724 .40396 L
.08724 .40396 L
.08723 .40398 L
.08723 .40402 L
.08723 .40409 L
.08723 .40415 L
.0872 .40417 L
.08716 .40415 L
Mistroke
.08713 .40406 L
.08712 .4039 L
.08714 .40363 L
.0872 .40329 L
.08731 .40288 L
.08747 .40243 L
.08768 .40196 L
.08794 .4015 L
.08825 .40104 L
.08859 .40057 L
.08888 .40013 L
.08913 .39973 L
.08937 .39944 L
.08961 .39931 L
.08978 .39935 L
.08982 .39955 L
.08972 .39988 L
.08952 .4003 L
.08926 .40079 L
.08897 .40129 L
.08865 .40166 L
.08835 .40193 L
.08806 .40225 L
.0878 .40262 L
.0876 .40302 L
.08744 .40341 L
.08732 .40378 L
.08724 .40416 L
.08718 .40466 L
.08708 .40536 L
.08694 .40626 L
.08675 .40737 L
.08648 .4086 L
.08625 .40984 L
.08595 .41149 L
.08567 .41365 L
.08542 .41527 L
.08515 .41756 L
.08487 .41938 L
.08461 .42136 L
.0844 .42345 L
.08427 .42491 L
.08419 .42646 L
.08414 .42792 L
.08413 .42889 L
.08415 .42968 L
.08417 .43031 L
.08419 .43076 L
.08419 .43102 L
Mfstroke
.11421 .48636 m
.11439 .48646 L
.11462 .48659 L
.1149 .48675 L
.11523 .48695 L
.11562 .48718 L
.11603 .48746 L
.11655 .48785 L
.11707 .48831 L
.11765 .48887 L
.11831 .48956 L
.11899 .49032 L
.11961 .49103 L
.12027 .49186 L
.12087 .49267 L
.12145 .49349 L
.12199 .49429 L
.1225 .49504 L
.12298 .49567 L
.12341 .49623 L
.1238 .49672 L
.12411 .4971 L
.12431 .49735 L
.1244 .49749 L
.12438 .49759 L
.1243 .49775 L
.12419 .49799 L
.12409 .49832 L
.12404 .49873 L
.12408 .49924 L
.12425 .49984 L
.12456 .50047 L
.12501 .50114 L
.12557 .5018 L
.12624 .50243 L
.12696 .50298 L
.12764 .50346 L
.12833 .50383 L
.12902 .50408 L
.12975 .50421 L
.13039 .50426 L
.13097 .50426 L
.13148 .50427 L
.13191 .50434 L
.13226 .5045 L
.13254 .50476 L
.1328 .50512 L
.13303 .50548 L
.13327 .5059 L
.13349 .50631 L
Mistroke
.13369 .5067 L
.13385 .5071 L
.13396 .50747 L
.134 .5078 L
.13395 .50807 L
.13382 .50823 L
.13361 .50829 L
.13333 .50828 L
.13301 .50822 L
.13268 .50814 L
.13236 .5081 L
.13209 .50819 L
.13189 .50846 L
.13177 .50893 L
.13173 .50958 L
.13178 .51039 L
.13191 .51134 L
.13209 .51239 L
.13232 .51334 L
.13256 .51433 L
.13277 .51531 L
.13298 .51628 L
.13314 .51721 L
.13331 .51789 L
.13347 .51854 L
.13362 .51907 L
.13375 .51951 L
.13388 .51992 L
.13404 .52038 L
.13426 .52097 L
.13454 .52173 L
.13492 .5227 L
.13538 .52371 L
.13592 .52491 L
.13652 .52626 L
.13717 .52776 L
.13782 .52921 L
.13837 .53054 L
.13891 .53184 L
.13937 .53288 L
.13982 .53381 L
.14026 .53458 L
.14069 .53518 L
.14113 .53561 L
.14158 .5359 L
.14205 .53611 L
.14254 .53626 L
.143 .53637 L
.14346 .53647 L
.1439 .5366 L
Mistroke
.14438 .53677 L
.14489 .53699 L
.14538 .53721 L
.14581 .53739 L
.14613 .53752 L
.1463 .53756 L
.14632 .53748 L
.14621 .53728 L
.146 .53698 L
.14571 .53663 L
.14538 .53628 L
.14503 .53596 L
.1447 .53571 L
.14438 .5356 L
.14409 .53564 L
.14384 .5359 L
.14367 .53644 L
.14358 .53729 L
.14358 .53849 L
.14365 .5399 L
.14376 .54152 L
.14392 .54344 L
.1441 .54565 L
.14431 .54767 L
.14453 .55004 L
.14477 .55212 L
.14504 .55428 L
.1453 .55643 L
.14557 .55816 L
.14584 .55972 L
.1461 .56108 L
.14632 .56219 L
.14652 .56301 L
.1467 .56363 L
.14689 .56406 L
.14707 .56435 L
.14724 .56453 L
.14739 .56464 L
.14747 .56469 L
.1475 .56466 L
.14748 .56458 L
.14743 .56446 L
.14737 .56434 L
.14734 .56425 L
.14734 .56423 L
.14739 .56431 L
.14751 .56449 L
.1477 .56476 L
.148 .56513 L
.14841 .56559 L
Mistroke
.14893 .56612 L
.14955 .56672 L
.15027 .56736 L
.15108 .56809 L
.15192 .56889 L
.15282 .56972 L
.15376 .57052 L
.15469 .57129 L
.15554 .572 L
.15636 .57269 L
.15712 .57335 L
.1578 .57401 L
.15838 .57465 L
.15885 .5753 L
.15922 .57601 L
.1595 .57675 L
.15969 .57747 L
.1598 .57811 L
.15984 .57862 L
.1598 .57905 L
.15969 .57937 L
.15949 .57956 L
.15921 .57958 L
.15888 .57944 L
.15851 .57916 L
.15817 .57878 L
.15787 .57832 L
.15762 .57782 L
.15747 .57729 L
.15747 .57677 L
.15767 .57632 L
.15809 .57597 L
.15876 .57572 L
.15962 .57556 L
.16074 .57548 L
.16203 .57545 L
.16355 .57545 L
.16511 .57546 L
.16675 .57546 L
.16815 .57543 L
.1695 .57539 L
.17054 .57535 L
.17134 .57534 L
.17182 .57535 L
.17193 .57539 L
.17169 .57544 L
.17118 .57549 L
.17044 .57552 L
.16952 .57556 L
.1686 .5756 L
Mistroke
.16761 .57566 L
.16655 .5757 L
.16553 .57569 L
.16466 .57558 L
.16396 .57533 L
.16343 .57488 L
.16301 .57422 L
.16267 .57333 L
.16236 .57215 L
.16205 .57065 L
.16168 .56884 L
.16119 .56704 L
.16058 .5649 L
.15984 .56239 L
.15897 .55997 L
.15809 .55735 L
.15707 .55456 L
.15598 .5519 L
.1549 .54939 L
.1538 .54702 L
.15273 .5447 L
.15179 .54295 L
.15098 .54133 L
.1503 .53998 L
.14978 .539 L
.14942 .53821 L
.14918 .53761 L
.14898 .5372 L
.14877 .53693 L
.1485 .53677 L
.1481 .53667 L
.14751 .53662 L
.1467 .53657 L
.14565 .5365 L
.14448 .53636 L
.14307 .53615 L
.14144 .53587 L
.13966 .53553 L
.13802 .53516 L
.13636 .53478 L
.13475 .53444 L
.13329 .53415 L
.13207 .53388 L
.13112 .53366 L
.13039 .53342 L
.12989 .53313 L
.1296 .53272 L
.1295 .53225 L
.12958 .53179 L
.12976 .5312 L
Mistroke
.13003 .53052 L
.13035 .5297 L
.13066 .52871 L
.13094 .52763 L
.1311 .52635 L
.1311 .52483 L
.13094 .52312 L
.13068 .52134 L
.13034 .51961 L
.12996 .51777 L
.12956 .51627 L
.12916 .51483 L
.12879 .51372 L
.12848 .51281 L
.12822 .51209 L
.12804 .51168 L
.12793 .51143 L
.12789 .51133 L
.12792 .51134 L
.12803 .51151 L
.12819 .51181 L
.12839 .51219 L
.12858 .51259 L
.12876 .51294 L
.12891 .51321 L
.12901 .51336 L
.12907 .51338 L
.12907 .51324 L
.12905 .51294 L
.12902 .51254 L
.129 .5121 L
.12901 .51163 L
.12902 .51115 L
.12904 .51069 L
.12906 .51025 L
.12908 .50981 L
.12914 .50938 L
.12928 .50901 L
.1295 .50873 L
.12972 .50858 L
.12988 .50853 L
.12994 .50856 L
.12986 .50863 L
.1296 .50869 L
.12902 .5087 L
.12805 .50862 L
.12672 .5084 L
.12504 .50807 L
.12299 .50764 L
.12101 .50714 L
Mistroke
.11853 .50658 L
.1159 .50602 L
.11321 .50545 L
.11041 .5049 L
.1077 .50438 L
.10474 .5039 L
.10239 .50347 L
.10015 .50308 L
.09785 .50272 L
.09582 .50238 L
.09386 .50205 L
.09199 .50172 L
.09027 .50138 L
.08881 .50104 L
.0878 .50071 L
.08656 .50037 L
.08561 .50001 L
.08467 .49961 L
.08374 .49915 L
.08287 .49866 L
.08207 .49818 L
.08133 .49769 L
.08064 .49717 L
.08002 .49661 L
.07945 .49599 L
.07891 .49535 L
.07826 .49465 L
.07757 .49382 L
.07687 .49287 L
.0762 .49192 L
.07561 .49097 L
.07513 .49007 L
.07478 .48927 L
.07458 .48861 L
.07452 .48806 L
.07459 .48763 L
.07477 .48731 L
.07502 .4871 L
.0753 .48697 L
.07561 .48688 L
.07592 .48679 L
.0762 .48666 L
.07645 .48647 L
.07669 .4862 L
.07693 .48586 L
.07717 .48543 L
.07741 .48497 L
.07765 .4845 L
.07789 .48406 L
.07813 .48361 L
Mistroke
.07836 .48319 L
.07859 .48281 L
.07883 .48251 L
.07907 .4823 L
.07933 .48218 L
.0796 .48214 L
.07984 .48216 L
.08005 .48222 L
.08021 .4823 L
Mfstroke
.08429 .42209 m
.0843 .42197 L
.08432 .42176 L
.08436 .42141 L
.08441 .42092 L
.08449 .42024 L
.08459 .41936 L
.08472 .41824 L
.08489 .41687 L
.0851 .41531 L
.08529 .41337 L
.08547 .4113 L
.08569 .40891 L
.08595 .40633 L
.08623 .40386 L
.08648 .40085 L
.08677 .39832 L
.08707 .3953 L
.08739 .39253 L
.08773 .38958 L
.08811 .38625 L
.08852 .38366 L
.08894 .38091 L
.08937 .37816 L
.08979 .37536 L
.09022 .37248 L
.09066 .37028 L
.09111 .36773 L
.09157 .36538 L
.09202 .36321 L
.09246 .36109 L
.09289 .35928 L
.09331 .35758 L
.0937 .35622 L
.09406 .35505 L
.09438 .35416 L
.09467 .35345 L
.09491 .35294 L
.09511 .35261 L
.09528 .35242 L
.09541 .35234 L
.0955 .35234 L
.09555 .35242 L
.09556 .35252 L
.09555 .35263 L
.09551 .35273 L
.09546 .35279 L
.09543 .3528 L
.09542 .35281 L
.09542 .35281 L
Mistroke
.09542 .35281 L
.09542 .35281 L
.09542 .35281 L
.09542 .35281 L
.09542 .35281 L
.09542 .35281 L
.09542 .35281 L
.09543 .35284 L
.09546 .35289 L
.0955 .35296 L
.09554 .35302 L
.09556 .35305 L
.09554 .35302 L
.09548 .35292 L
.09538 .35274 L
.09522 .35247 L
.09501 .35211 L
.09475 .35165 L
.09444 .35113 L
.09413 .35058 L
.09386 .3501 L
.09361 .34971 L
.0934 .3494 L
.09326 .34916 L
.09319 .34901 L
.09322 .34898 L
.09334 .34904 L
.09354 .34917 L
.09378 .34935 L
.09407 .34955 L
.09436 .34972 L
.09467 .34984 L
.09495 .34986 L
.09518 .34977 L
.09536 .3495 L
.09548 .34909 L
.09555 .34853 L
.09558 .34787 L
.09557 .34717 L
.09554 .34647 L
.0955 .34584 L
.09546 .34528 L
.09545 .34482 L
.09545 .34446 L
.09545 .34417 L
.09545 .34393 L
.09545 .34377 L
.09545 .34367 L
.09545 .34364 L
.09545 .34366 L
Mistroke
.09545 .34373 L
.09545 .34381 L
.09545 .34386 L
.09545 .34389 L
.09545 .34389 L
.09544 .3439 L
.09541 .34392 L
.09537 .34397 L
.09533 .34404 L
.09531 .3441 L
.09532 .34413 L
.09538 .34411 L
.09548 .34402 L
.09563 .34384 L
.09583 .34358 L
.09606 .34325 L
.09631 .34286 L
.09657 .34242 L
.09684 .34197 L
.09709 .34152 L
.09735 .34108 L
.09759 .34065 L
.0978 .34024 L
.09797 .33988 L
.09809 .33959 L
.09815 .33939 L
.09817 .33927 L
.09816 .33924 L
.09812 .33926 L
.09808 .33933 L
.09805 .3394 L
.09803 .33945 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33948 L
.09803 .33949 L
.09803 .3395 L
.09803 .33953 L
.09801 .33959 L
.09798 .33967 L
.09793 .33975 L
.09789 .33981 L
Mistroke
.09785 .33982 L
.09783 .33976 L
.09784 .33961 L
.09792 .33933 L
.09807 .33891 L
.09829 .33836 L
.09858 .33766 L
.09895 .33689 L
.09939 .33597 L
.09989 .33497 L
.10046 .33394 L
.10108 .33286 L
.10175 .33176 L
.1024 .3307 L
.10304 .32975 L
.10364 .32889 L
.10419 .32816 L
.10464 .32756 L
.10501 .3271 L
.1053 .32676 L
.10552 .32651 L
.10567 .32633 L
.10578 .32621 L
.10585 .32614 L
.10588 .32612 L
.10588 .32612 L
.10586 .32613 L
.10582 .32616 L
.10578 .32619 L
.10574 .32623 L
.10573 .32626 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
Mistroke
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10573 .32627 L
.10572 .32627 L
.10571 .32627 L
.10567 .32627 L
.10563 .32627 L
.10559 .32627 L
.10555 .32627 L
.10555 .32628 L
.1056 .32632 L
.10571 .32635 L
.10587 .32638 L
.10608 .3264 L
.10634 .32641 L
.10665 .3264 L
.10698 .32637 L
.1073 .32631 L
.10761 .32623 L
.1079 .32612 L
.10819 .32595 L
.10844 .3257 L
.10868 .32533 L
.10893 .32489 L
.1092 .32437 L
.10954 .32373 L
.11003 .32304 L
.11067 .32219 L
.11139 .3212 L
.11236 .32006 L
.11344 .31886 L
.11477 .31756 L
.11614 .31618 L
.11765 .31479 L
.11913 .31344 L
.12057 .3123 L
.12169 .31126 L
.12292 .31026 L
.12389 .30943 L
.12473 .30864 L
.12541 .30784 L
.12599 .30701 L
Mistroke
.12652 .30613 L
.12703 .30512 L
.12755 .30392 L
.12811 .30255 L
.12868 .30114 L
.12916 .29966 L
.12974 .29784 L
.13035 .29606 L
.13103 .29411 L
.13162 .29204 L
.13218 .29027 L
.1327 .2885 L
.13317 .28678 L
.13362 .28515 L
.13409 .2837 L
.13461 .28232 L
.13522 .28094 L
.13591 .27952 L
.1368 .27804 L
.1378 .27673 L
.13898 .27522 L
.1403 .27365 L
.14177 .27212 L
.14326 .27048 L
.14497 .26882 L
.14637 .26721 L
.14776 .26558 L
.14917 .26407 L
.15041 .26259 L
.1516 .26126 L
.15265 .26 L
.15369 .25879 L
.15456 .2577 L
.15538 .25664 L
.15614 .25558 L
.15684 .25446 L
.15751 .25338 L
.15809 .2522 L
.15865 .25087 L
.15917 .24947 L
.15963 .24791 L
.16007 .2462 L
.16051 .24462 L
.16097 .24275 L
.16147 .24089 L
.162 .23874 L
.16258 .23658 L
.16323 .23448 L
.16399 .23217 L
.16488 .22982 L
Mistroke
.16579 .22781 L
.16684 .22584 L
.1679 .22387 L
.16907 .22196 L
.17032 .22026 L
.17153 .21852 L
.17285 .21674 L
.17427 .21507 L
.17573 .21339 L
.17727 .2118 L
.17872 .21025 L
.18019 .20887 L
.18167 .20753 L
.18304 .20627 L
.18438 .20516 L
.18567 .20415 L
.1868 .2033 L
.18786 .20257 L
.18869 .202 L
.18937 .20161 L
.18987 .20141 L
.19018 .20138 L
.19029 .20148 L
.19023 .20166 L
.19006 .20187 L
.18986 .20203 L
.18969 .20208 L
.18961 .20195 L
.18969 .2016 L
.18996 .20101 L
.19043 .20015 L
.1911 .19901 L
.19192 .19771 L
.19287 .1961 L
.19393 .19418 L
.19497 .19229 L
.19612 .19013 L
.19748 .18756 L
.19881 .1854 L
.20025 .18321 L
.20156 .18099 L
.20281 .17892 L
.20395 .17705 L
.20494 .17561 L
.20586 .1743 L
.20672 .17329 L
.20757 .17245 L
.20838 .17177 L
.20915 .17122 L
.20987 .17079 L
Mistroke
.21052 .17045 L
.21111 .1702 L
.2117 .17002 L
.21232 .1699 L
.21302 .16983 L
.21384 .16975 L
.2148 .16963 L
.21591 .16949 L
.21715 .16936 L
.21831 .16926 L
.21958 .1692 L
.22064 .16918 L
.22178 .1692 L
.22287 .16928 L
.22376 .16942 L
.22455 .1696 L
.2252 .16979 L
.22566 .16993 L
.22595 .17 L
.22611 .16996 L
.22622 .1698 L
.22637 .16947 L
.22667 .16897 L
.22718 .16828 L
.22795 .16736 L
.22902 .1662 L
.23027 .16495 L
.23183 .16332 L
.23354 .1616 L
.23562 .15961 L
.23751 .15744 L
.23967 .15521 L
.24197 .15291 L
.24385 .15073 L
.24582 .1486 L
.24764 .14664 L
.24917 .14499 L
.25055 .14348 L
.25172 .14213 L
.25268 .14107 L
.2535 .14021 L
.2542 .13957 L
.25482 .13917 L
.2554 .13896 L
.25596 .13891 L
.25655 .13896 L
.25716 .13907 L
.25782 .1392 L
.25848 .13933 L
.2591 .13944 L
Mistroke
.25968 .13955 L
.26023 .13962 L
.26073 .13965 L
.26118 .13964 L
.26158 .1396 L
.26192 .13954 L
.26219 .13947 L
.26243 .1394 L
.26263 .13934 L
.26281 .13932 L
.26299 .13933 L
.26318 .13935 L
.26336 .13955 L
.26357 .1395 L
.2638 .1394 L
.26401 .13926 L
.2642 .13912 L
.26435 .13898 L
.26444 .13884 L
.26448 .13868 L
.26445 .13848 L
.2644 .13827 L
.26433 .13801 L
.26428 .13775 L
.26426 .13745 L
.2643 .13711 L
.26442 .1368 L
.26459 .13652 L
.26482 .13629 L
.26509 .13603 L
.2654 .13576 L
.26574 .13547 L
.26614 .13518 L
.26659 .13489 L
.26711 .13461 L
.26769 .13433 L
.26835 .13403 L
.26908 .13374 L
.2699 .13342 L
.27079 .13307 L
.27171 .13265 L
.27271 .1322 L
.27375 .13174 L
.27486 .13129 L
.27599 .13089 L
.27713 .13051 L
.27823 .13015 L
.27929 .12983 L
.28021 .12957 L
.28101 .1294 L
Mistroke
.28164 .12931 L
.28213 .12928 L
.2825 .12926 L
.28282 .12921 L
.2831 .12908 L
.2834 .12885 L
.28371 .12848 L
.28406 .12798 L
.28443 .12739 L
.28484 .12675 L
.28527 .12613 L
.28567 .12549 L
.28606 .12485 L
.28641 .12431 L
.28674 .12383 L
.28704 .12343 L
.28733 .12313 L
.28763 .12292 L
.28797 .12277 L
.28838 .12264 L
.28888 .12247 L
.28949 .12223 L
.29027 .12188 L
.29119 .12139 L
.29234 .12078 L
.29363 .1201 L
.29508 .11932 L
.29673 .1185 L
.29829 .11766 L
.2999 .11684 L
.30149 .1161 L
.30304 .11541 L
.30451 .11478 L
.30593 .11419 L
.30734 .11363 L
.30871 .11307 L
.31011 .11249 L
.31151 .11183 L
.31295 .11104 L
.31441 .1101 L
.31575 .1091 L
.31712 .10792 L
.31839 .10655 L
.31963 .10514 L
.32086 .10364 L
.32204 .10219 L
.32322 .10067 L
.32441 .09923 L
.32557 .09787 L
.3268 .09647 L
Mistroke
.32809 .09529 L
.32955 .09415 L
.33115 .09304 L
.33301 .09193 L
.33497 .0909 L
.33703 .08983 L
.33929 .0888 L
.34171 .08777 L
.34402 .08674 L
.34627 .08571 L
.34837 .08477 L
.35013 .0839 L
.35198 .08313 L
.35372 .08251 L
.35535 .08208 L
.357 .08182 L
.35864 .08173 L
.36036 .08177 L
.3621 .08192 L
.36373 .08215 L
.36507 .08244 L
.36639 .08276 L
.36752 .08308 L
.36866 .08338 L
.3698 .08363 L
.37083 .08383 L
.37162 .08396 L
.37213 .08404 L
.3724 .08408 L
.37248 .08409 L
.37239 .08409 L
.37215 .08408 L
.37187 .08406 L
.37164 .08406 L
.37149 .08407 L
.37144 .08406 L
.37152 .08404 L
.37174 .08397 L
.37215 .08382 L
.37273 .08355 L
.37349 .08315 L
.37441 .08261 L
.37547 .08195 L
.37653 .08118 L
.37768 .08032 L
.37893 .07939 L
.38029 .07852 L
.38158 .07758 L
.3829 .0766 L
.38423 .07573 L
Mistroke
.38549 .0749 L
.38673 .07415 L
.38794 .07349 L
.38922 .07295 L
.39063 .07252 L
.39215 .07222 L
.39379 .07203 L
.39563 .07191 L
.39765 .07185 L
.39964 .0718 L
.40168 .07177 L
.40377 .07176 L
.40572 .07177 L
.40759 .07182 L
.40932 .07187 L
.41083 .07196 L
.41223 .07205 L
.41344 .07213 L
.41439 .0722 L
.41502 .07224 L
.41534 .07228 L
.41535 .0723 L
.41509 .07231 L
.41462 .07231 L
.41401 .0723 L
.41332 .07227 L
.41259 .07224 L
.41187 .07221 L
.41115 .07219 L
.41044 .07217 L
.40976 .07215 L
.40915 .07213 L
.40868 .07212 L
.40836 .07211 L
.40818 .07211 L
.40812 .0721 L
.40815 .07211 L
.40825 .07211 L
.40836 .07211 L
.40843 .07209 L
.40843 .07205 L
.40838 .07196 L
.40831 .07186 L
.40825 .07179 L
.40825 .07175 L
.40831 .07177 L
.40845 .07189 L
.40868 .07214 L
.40899 .07254 L
.40936 .0731 L
Mistroke
.40979 .07381 L
.41025 .07467 L
.41071 .07558 L
.41119 .07661 L
.41167 .07765 L
.41214 .07871 L
.41257 .0797 L
.41293 .08055 L
.4132 .08113 L
.41335 .08148 L
.41338 .08158 L
.41329 .08144 L
.41312 .08106 L
.41291 .08045 L
.4127 .07975 L
.41252 .07893 L
.41237 .07808 L
.41223 .07721 L
.41207 .07644 L
.41187 .07571 L
.4116 .07507 L
.41123 .07454 L
.41073 .07414 L
.41009 .07387 L
.4093 .07374 L
.40827 .0737 L
.40705 .07372 L
.40557 .07374 L
.40385 .07374 L
.40185 .07369 L
.39968 .07358 L
.39749 .07342 L
.39513 .07323 L
.39288 .07302 L
.39078 .07281 L
.38872 .0726 L
.38671 .07239 L
.38508 .07217 L
.38356 .07194 L
.38216 .0717 L
.38084 .07145 L
.3796 .07121 L
.37838 .07099 L
.37719 .07084 L
.37599 .07075 L
.37468 .07074 L
.37324 .07084 L
.37181 .07106 L
.37028 .07139 L
.36857 .07182 L
Mistroke
.36675 .07233 L
.36496 .07291 L
.36339 .07358 L
.36187 .07434 L
.36043 .07512 L
.35912 .07584 L
.35797 .07653 L
.35701 .07732 L
.3562 .07803 L
.35548 .07876 L
.35481 .07951 L
.35418 .0802 L
.35358 .08095 L
.35297 .08172 L
.35235 .08252 L
.35175 .08334 L
.3512 .08416 L
.35073 .08491 L
.35029 .08561 L
.34987 .08628 L
.34946 .08687 L
.34912 .08734 L
.34886 .08769 L
.34868 .08789 L
.34858 .08801 L
.34855 .08804 L
.34858 .08799 L
.34865 .08788 L
.34872 .08775 L
.34876 .08766 L
.34878 .0876 L
.34879 .08755 L
.34881 .08751 L
.34883 .08746 L
.34887 .08739 L
.3489 .08729 L
.34894 .08716 L
.34899 .087 L
.34905 .08685 L
.34911 .08669 L
.34918 .08654 L
.34927 .08642 L
.34936 .08633 L
.34941 .08628 L
.34937 .08625 L
.34922 .08622 L
.34895 .0862 L
.34853 .08622 L
.34796 .0863 L
.34725 .08646 L
Mistroke
.34643 .08666 L
.34548 .08696 L
.34445 .08731 L
.34332 .0877 L
.3422 .0881 L
.34098 .08849 L
.33965 .08889 L
.33827 .08929 L
.33688 .08971 L
.33543 .0902 L
.33399 .09076 L
.33252 .09139 L
.33098 .09209 L
.32938 .09285 L
.32786 .09367 L
.32632 .09457 L
.32467 .09552 L
.32301 .09646 L
.32146 .09744 L
.31995 .09841 L
.31854 .09935 L
.31731 .10018 L
.31616 .10091 L
.31511 .1015 L
.31417 .10194 L
.3134 .10222 L
.31274 .10237 L
.31217 .10246 L
.31166 .10255 L
.31119 .1027 L
.31075 .10294 L
.31029 .10332 L
.30991 .10375 L
.30946 .1044 L
.30895 .10521 L
.30839 .1062 L
.30776 .10724 L
.30702 .10847 L
.30622 .10982 L
.30536 .11113 L
.30449 .1124 L
.30363 .1136 L
.30281 .11469 L
.30206 .11566 L
.30139 .11649 L
.30082 .11724 L
.30036 .11791 L
.3 .11852 L
.29976 .11909 L
.29962 .11963 L
Mistroke
.29956 .12014 L
.29955 .12061 L
.29959 .12102 L
.29969 .12134 L
.29983 .12159 L
.29997 .12183 L
.30009 .1221 L
.30018 .12236 L
.30023 .12262 L
.30021 .1229 L
.3001 .12326 L
.29986 .12372 L
.29946 .1243 L
.29887 .12499 L
.29809 .12581 L
.29712 .12674 L
.29606 .12768 L
.29488 .12869 L
.29364 .12973 L
.29246 .13078 L
.29136 .13168 L
.29026 .13247 L
.28914 .13312 L
.28817 .1336 L
.28729 .1339 L
.28651 .13405 L
.28582 .13407 L
.28527 .134 L
.28485 .13392 L
.28454 .13383 L
.28431 .13375 L
.2841 .13368 L
.28386 .13363 L
.28357 .13358 L
.28323 .13353 L
.28288 .13347 L
.28256 .13339 L
.28231 .13332 L
.28216 .13326 L
.28211 .13321 L
.28214 .13317 L
.28217 .13315 L
.28218 .13314 L
.2822 .13315 L
.28224 .13318 L
.28234 .1332 L
.28253 .13327 L
.28278 .13335 L
.28305 .13345 L
.28329 .13354 L
Mistroke
.28348 .13361 L
.28357 .13366 L
.28352 .13369 L
.28332 .13366 L
.283 .13359 L
.28258 .13348 L
.28208 .13329 L
.28149 .13303 L
.2808 .13271 L
.28015 .13235 L
.27937 .13203 L
.27855 .13173 L
.27771 .1315 L
.27693 .13133 L
.2762 .13124 L
.27557 .13121 L
.27503 .13123 L
.27464 .13134 L
.27433 .13149 L
.27414 .13168 L
.27404 .13193 L
.27399 .1322 L
.27398 .13244 L
.27397 .13261 L
.2739 .13274 L
.27374 .1328 L
.27344 .13283 L
.27298 .13287 L
.27239 .13297 L
.27165 .13324 L
.27077 .13371 L
.26982 .13438 L
.26885 .13521 L
.26782 .13614 L
.26673 .13709 L
.26564 .1379 L
.26461 .13869 L
.26366 .13942 L
.26283 .14009 L
.26212 .14058 L
.26153 .14095 L
.26105 .14117 L
.26066 .14124 L
.26036 .14113 L
.26016 .14085 L
.26005 .14046 L
.26001 .14004 L
.26001 .13968 L
.26 .13941 L
.25996 .13925 L
Mistroke
.25982 .13921 L
.2595 .1393 L
.25897 .13953 L
.25824 .13986 L
.25729 .14027 L
.25609 .14076 L
.25485 .14132 L
.25335 .14195 L
.25173 .14258 L
.25011 .14326 L
.24837 .14394 L
.24663 .14463 L
.24495 .14532 L
.24342 .14601 L
.24187 .14675 L
.24032 .14753 L
.23884 .14835 L
.23745 .14921 L
.23627 .15009 L
.23503 .15105 L
.23384 .15208 L
.23274 .15314 L
.23171 .1543 L
.23069 .15562 L
.22976 .15692 L
.2289 .15828 L
.22815 .15963 L
.22752 .16086 L
.22702 .1619 L
.22666 .16267 L
.2264 .16323 L
.22621 .16355 L
.22606 .16365 L
.22596 .16354 L
.22588 .16327 L
.22583 .16291 L
.22581 .16255 L
.22582 .16221 L
.22587 .16196 L
.22593 .16184 L
.226 .16193 L
.22606 .16231 L
.2261 .16293 L
.22615 .16376 L
.22621 .16461 L
.22629 .16569 L
.22635 .16663 L
.22641 .16752 L
.22643 .1683 L
.22644 .16888 L
Mistroke
.22643 .16922 L
.22638 .16935 L
.22626 .16931 L
.22604 .16916 L
.22572 .16894 L
.22528 .16869 L
.22469 .16845 L
.22395 .16826 L
.22303 .16812 L
.22194 .16802 L
.22068 .16798 L
.21923 .16803 L
.21761 .16819 L
.21608 .16849 L
.21438 .16893 L
.21244 .16951 L
.21033 .17025 L
.20831 .17112 L
.2064 .17214 L
.20437 .17334 L
.20236 .17462 L
.20037 .17613 L
.19858 .17783 L
.19669 .17965 L
.19513 .18149 L
.19357 .18352 L
.19193 .18555 L
.1904 .18777 L
.18885 .18981 L
.18731 .19196 L
.18579 .19416 L
.18455 .19605 L
.18327 .19805 L
.18215 .19996 L
.18116 .20175 L
.18018 .20358 L
.17933 .20503 L
.1786 .20643 L
.17803 .20782 L
.17762 .20917 L
.17738 .21043 L
.1773 .21149 L
.17733 .2125 L
.17743 .21339 L
.17754 .21412 L
.17764 .21467 L
.17772 .21506 L
.17776 .21531 L
.17776 .21546 L
.17773 .21548 L
Mistroke
.17769 .2154 L
.17763 .21515 L
.17756 .21476 L
.1775 .21429 L
.17748 .2138 L
.17754 .21333 L
.1777 .21289 L
.17796 .21251 L
.17834 .21226 L
.17882 .21217 L
.17939 .2122 L
.18001 .21227 L
.18072 .21235 L
.18148 .21242 L
.18229 .21248 L
.18307 .21254 L
.18386 .21257 L
.18461 .2126 L
.18531 .21261 L
.1859 .21263 L
.18639 .21264 L
.18675 .21265 L
.18702 .21266 L
.18722 .21266 L
.18737 .21267 L
.18748 .21267 L
.18756 .21267 L
.18764 .21267 L
.18768 .21268 L
.1877 .21268 L
.18768 .21268 L
.18764 .21268 L
.1876 .21267 L
.18757 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
Mistroke
.18755 .21267 L
.18755 .21267 L
.18755 .21267 L
.18753 .21267 L
.1875 .21267 L
.18746 .21267 L
.18743 .21267 L
.18741 .21267 L
.18742 .21267 L
.18748 .21267 L
.18757 .21267 L
.18772 .21268 L
.1879 .21268 L
.18812 .21269 L
.18836 .21269 L
.18861 .2127 L
.18886 .21271 L
.18912 .21275 L
.18935 .21281 L
.18954 .21289 L
.18968 .21298 L
.18978 .21306 L
.18983 .21311 L
.18985 .21309 L
.18985 .21298 L
.18987 .21276 L
.18992 .21243 L
.19007 .21198 L
.19035 .2114 L
.19077 .21067 L
.19134 .20982 L
.19203 .20882 L
.19288 .2076 L
.19388 .20618 L
.19502 .20468 L
.19629 .20303 L
.19761 .20136 L
.19898 .19964 L
.20035 .1981 L
.20161 .19661 L
.2028 .19526 L
.20379 .19418 L
.20468 .19315 L
.20543 .19231 L
.20609 .19156 L
.20655 .19108 L
.20691 .19073 L
.20713 .19055 L
.20724 .19052 L
.20727 .19059 L
Mistroke
.20725 .1907 L
.20719 .19082 L
.20711 .19091 L
.20702 .19098 L
.20695 .19102 L
.20692 .19103 L
.20692 .19104 L
.20693 .19106 L
.20693 .19112 L
.20693 .1912 L
.20691 .19129 L
.20688 .19139 L
.20683 .19147 L
.20677 .1915 L
.20672 .19143 L
.2067 .1912 L
.20674 .19081 L
.20685 .19022 L
.20704 .18941 L
.20732 .18837 L
.20767 .18721 L
.20809 .18581 L
.20855 .18419 L
.20901 .18262 L
.2095 .18091 L
.20998 .17908 L
.21039 .17755 L
.21074 .1761 L
.21105 .17476 L
.21129 .17363 L
.21145 .17275 L
.21158 .17209 L
.21172 .17163 L
.21189 .17131 L
.21213 .17106 L
.21248 .17084 L
.21297 .17062 L
.21362 .17035 L
.21436 .17004 L
.21528 .16967 L
.21627 .16922 L
.2174 .16866 L
.21865 .16796 L
.21981 .16714 L
.22104 .16628 L
.22235 .16539 L
.22363 .16449 L
.22494 .16361 L
.22621 .16277 L
.22753 .162 L
Mistroke
.22878 .16123 L
.23007 .16046 L
.23132 .15972 L
.23259 .15899 L
.23379 .15828 L
.23489 .1576 L
.23596 .15697 L
.23694 .15641 L
.23779 .15596 L
.23853 .15557 L
.23916 .15524 L
.23965 .15494 L
.24002 .15466 L
.2403 .15443 L
.24049 .15427 L
.24062 .15418 L
.24069 .15416 L
.24073 .15419 L
.24074 .15427 L
.24072 .15436 L
.24067 .15447 L
.24057 .15458 L
.24045 .15466 L
.24031 .15472 L
.2402 .15474 L
.24016 .1547 L
.24022 .15457 L
.2404 .15431 L
.24072 .15391 L
.2412 .15337 L
.24185 .15269 L
.24266 .15187 L
.2436 .15101 L
.24451 .15006 L
.24559 .14904 L
.24661 .14804 L
.2477 .14706 L
.24858 .14614 L
.24945 .14536 L
.25028 .1447 L
.25103 .14418 L
.25166 .1438 L
.25225 .14358 L
.25283 .14351 L
.25346 .14356 L
.25416 .14366 L
.25496 .14375 L
.25584 .14379 L
.25675 .14376 L
.2577 .14366 L
Mistroke
.25874 .14349 L
.25992 .14327 L
.26117 .14307 L
.26246 .14293 L
.26376 .14286 L
.26507 .14282 L
.26635 .14281 L
.26759 .14282 L
.2688 .14286 L
.26987 .14292 L
.27089 .14303 L
.27182 .14317 L
.2726 .14332 L
.2732 .14345 L
.27365 .14352 L
.27398 .14351 L
.27419 .1434 L
.27433 .14316 L
.27444 .14274 L
.27453 .14217 L
.27464 .14157 L
.2748 .1409 L
.27503 .14022 L
.27533 .13952 L
.27565 .13884 L
.27603 .13818 L
.27646 .13757 L
.27695 .13702 L
.27745 .13655 L
.27793 .13619 L
.27836 .13596 L
.27872 .13584 L
.27903 .13582 L
.27929 .13586 L
.27953 .13592 L
.27978 .13595 L
.28007 .13589 L
.28041 .13571 L
.28081 .13534 L
.28126 .13475 L
.2818 .1339 L
.28244 .13285 L
.28315 .13152 L
.28403 .13006 L
.28499 .12838 L
.28612 .12654 L
.28742 .12464 L
.28888 .1228 L
.29057 .12088 L
.2922 .11918 L
Mistroke
.29406 .11742 L
.29577 .11594 L
.29772 .11451 L
.29967 .11327 L
.30176 .11211 L
.30398 .11102 L
.30609 .10999 L
.30825 .10908 L
.3104 .10814 L
.31248 .10716 L
.31458 .1061 L
.31668 .10501 L
.31875 .10376 L
.32101 .10234 L
.32313 .10086 L
.32538 .09928 L
.32775 .09766 L
.32997 .09591 L
.33231 .09424 L
.33478 .09249 L
.3371 .0907 L
.33952 .08919 L
.34202 .08769 L
.34432 .08624 L
.34663 .08494 L
.34879 .08378 L
.35084 .08272 L
.35252 .08179 L
.35404 .08096 L
.3553 .08022 L
.35635 .07958 L
.35715 .07902 L
.35774 .07857 L
.35814 .07816 L
.35837 .07781 L
.35845 .07753 L
.35841 .0773 L
.35829 .07712 L
.35813 .077 L
.35797 .07693 L
.35781 .07692 L
.35768 .07696 L
.35761 .07702 L
.35761 .0771 L
.35771 .07715 L
.35794 .07718 L
.35833 .07719 L
.35891 .07719 L
.35969 .07719 L
.36066 .0772 L
Mistroke
.36184 .07724 L
.36321 .07731 L
.36453 .0774 L
.36596 .0775 L
.36731 .07756 L
.3687 .07759 L
.36985 .07754 L
.37092 .07741 L
.37191 .07719 L
.37271 .07688 L
.37341 .07652 L
.37404 .07612 L
.37462 .07569 L
.37517 .07527 L
.37568 .07485 L
.37616 .07444 L
.37666 .07405 L
.37722 .07371 L
.37784 .07344 L
.37848 .07323 L
.37912 .0731 L
.37968 .07305 L
.38018 .07307 L
.3806 .07315 L
.38095 .07329 L
.38122 .07348 L
.38142 .07372 L
.38158 .07401 L
.38178 .07432 L
.38202 .0746 L
.3823 .07481 L
.3826 .07495 L
.38294 .07503 L
.3833 .07509 L
.38366 .07517 L
.38403 .07526 L
.38441 .07537 L
.3848 .07549 L
.38525 .07558 L
.38579 .07566 L
.38641 .07573 L
.3872 .07583 L
.38798 .07598 L
.38898 .07626 L
.39016 .07668 L
.39139 .07723 L
.39285 .07786 L
.39439 .07854 L
.39621 .07922 L
.39826 .07985 L
Mistroke
.40015 .08041 L
.40225 .08088 L
.40436 .08132 L
.40648 .08173 L
.4087 .08214 L
.41075 .08253 L
.41277 .08288 L
.41472 .08317 L
.41647 .08339 L
.4182 .0835 L
.41971 .0835 L
.42102 .0834 L
.42201 .0832 L
.42277 .08295 L
.4233 .08266 L
.42368 .08237 L
.42394 .08206 L
.42415 .08173 L
.42439 .08135 L
.42474 .08094 L
.42526 .08045 L
.42598 .07988 L
.42689 .07925 L
.42794 .07851 L
.4292 .07789 L
.43065 .07721 L
.43227 .07657 L
.43392 .076 L
.43556 .07545 L
.43721 .0749 L
.43852 .07438 L
.43969 .07389 L
.44058 .07345 L
.4413 .07311 L
.44182 .07287 L
.44214 .07275 L
.44237 .07274 L
.44262 .0728 L
.44298 .07288 L
.44348 .07296 L
.44419 .07303 L
.44513 .07307 L
.44633 .07311 L
.44759 .07316 L
.44929 .07322 L
.45106 .07332 L
.45309 .07346 L
.45538 .07364 L
.45752 .07385 L
.45987 .07409 L
Mistroke
.46208 .07434 L
.46425 .07461 L
.46633 .07488 L
.46818 .07511 L
.46987 .0753 L
.47139 .07545 L
.47267 .07559 L
.4738 .07572 L
.47474 .07586 L
.47546 .07604 L
.47597 .07626 L
.47629 .07653 L
.47646 .07685 L
.47651 .07722 L
.47648 .07763 L
.4764 .07806 L
.4763 .0785 L
.47621 .07896 L
.47613 .0794 L
.47602 .0798 L
.47589 .08012 L
.47574 .08031 L
.4756 .08034 L
.47553 .08022 L
.47556 .07996 L
.47572 .07961 L
.47605 .07919 L
.47658 .07877 L
.47734 .07833 L
.47836 .07794 L
.47955 .07756 L
.48106 .0772 L
.48255 .07689 L
.48442 .07663 L
.48635 .07642 L
.48826 .07622 L
.49045 .07602 L
.4927 .07577 L
.49499 .0755 L
.49727 .07517 L
.49946 .07478 L
.50154 .07437 L
.50359 .0739 L
.50529 .07341 L
.50682 .07292 L
.5083 .07247 L
.5095 .07204 L
.51055 .07162 L
.51133 .07122 L
.51191 .07094 L
Mistroke
.51228 .07072 L
.51246 .07062 L
.51246 .07063 L
.51231 .07076 L
.51205 .07099 L
.51174 .07127 L
.51145 .0716 L
.51122 .07196 L
.51105 .07234 L
.51093 .07275 L
.51085 .07315 L
.5108 .07357 L
.5108 .074 L
.51085 .07433 L
.51094 .07464 L
.51109 .07488 L
.5113 .07504 L
.51157 .07513 L
.51188 .07518 L
.51222 .0752 L
.5126 .07523 L
.51296 .07527 L
.5133 .07532 L
.51357 .07535 L
.51374 .07533 L
.51382 .07524 L
.51382 .07507 L
.51377 .07482 L
.51369 .0745 L
.51354 .07414 L
.51332 .07375 L
.51302 .07334 L
.51267 .07295 L
.51226 .07254 L
.51181 .0721 L
.51133 .07164 L
.51085 .0712 L
.51035 .07081 L
.50986 .07048 L
.50938 .07022 L
.50895 .07001 L
.50856 .06983 L
.50813 .06964 L
.50769 .06941 L
.50719 .06914 L
.50664 .06882 L
.50599 .06845 L
.50521 .06809 L
.50418 .06774 L
.50285 .06745 L
Mistroke
.5012 .06716 L
.49914 .0669 L
.49694 .06665 L
.49431 .06642 L
.49146 .0662 L
.48856 .06599 L
.48527 .06579 L
.48253 .06564 L
.47911 .06554 L
.47637 .06548 L
.47295 .06545 L
.47022 .0654 L
.46738 .06534 L
.46439 .06526 L
.4618 .06518 L
.45899 .06509 L
.45596 .06499 L
.4534 .06486 L
.45009 .0647 L
.44739 .06455 L
.44436 .06443 L
.44077 .06435 L
.43764 .06434 L
.43413 .06441 L
.43076 .06456 L
.42708 .06479 L
.42413 .06509 L
.42105 .06544 L
.41822 .06584 L
.41552 .06625 L
.4132 .06666 L
.41119 .06703 L
.40942 .06731 L
.40808 .06748 L
.40702 .06755 L
.40624 .06748 L
.4057 .06732 L
.4054 .06709 L
.40528 .06684 L
.40531 .06658 L
.40542 .06637 L
.4056 .06622 L
.40578 .06615 L
.40592 .06614 L
.40603 .06618 L
.40611 .0663 L
.40616 .06647 L
.40619 .06673 L
.40623 .06696 L
.40624 .06723 L
Mistroke
.40625 .06748 L
.40624 .06768 L
.40623 .0678 L
.40625 .06786 L
.40633 .06787 L
.40643 .06786 L
.40653 .06785 L
.40658 .06783 L
.40654 .06779 L
.4064 .06772 L
.40613 .06765 L
.40573 .0676 L
.40521 .06759 L
.4046 .06763 L
.40393 .06772 L
.40323 .06788 L
.40256 .0681 L
.40196 .06839 L
.40134 .06874 L
.4007 .06913 L
.40009 .06954 L
.39961 .06993 L
.3993 .07036 L
.39914 .07072 L
.39908 .0711 L
.3991 .07143 L
.39919 .07169 L
.3993 .07187 L
.39936 .07198 L
.39937 .07201 L
.39934 .072 L
.39931 .07197 L
.39927 .07193 L
.39925 .0719 L
.39927 .07188 L
.39931 .07187 L
.39941 .07186 L
.39954 .07186 L
.39971 .07186 L
.39992 .07187 L
.40014 .07188 L
.40038 .07188 L
.40061 .07189 L
.40085 .0719 L
.40107 .07192 L
.40128 .07197 L
.40147 .07202 L
.40162 .07207 L
.40173 .0721 L
.4018 .07209 L
Mistroke
.40181 .07204 L
.40179 .07192 L
.40174 .07171 L
.40168 .0714 L
.40162 .07103 L
.40158 .07063 L
.40156 .07026 L
.40155 .06993 L
.40155 .06968 L
.40155 .06955 L
.40156 .06952 L
.40158 .06953 L
.40159 .06958 L
.40161 .06971 L
.40162 .06992 L
.40164 .0702 L
.40168 .07052 L
.40171 .07087 L
.40177 .0712 L
.40186 .07151 L
.40199 .07176 L
.40218 .0719 L
.4024 .07197 L
.40268 .07198 L
.40302 .07194 L
.40337 .0719 L
.40377 .07189 L
.40418 .07192 L
.40459 .07197 L
.40499 .07202 L
.40535 .07206 L
.40566 .07208 L
.40592 .07208 L
.40613 .07207 L
.40628 .07206 L
.40636 .07206 L
.40638 .07206 L
.40637 .07206 L
.40634 .07205 L
.40631 .07205 L
.40627 .07205 L
.40624 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
Mistroke
.40622 .07205 L
.40622 .07205 L
.40622 .07205 L
.40621 .07205 L
.40618 .07205 L
.40614 .07205 L
.40611 .07205 L
.40609 .07205 L
.4061 .07205 L
.40615 .07205 L
.40623 .07206 L
.40636 .07208 L
.40652 .0721 L
.40669 .07211 L
.40688 .0721 L
.40708 .07208 L
.4073 .07205 L
.40755 .07202 L
.40784 .07199 L
.40816 .07196 L
.40851 .07196 L
.40885 .07194 L
.40915 .07192 L
.40939 .07188 L
.40958 .07184 L
.40972 .0718 L
.40983 .07177 L
.40993 .07175 L
.41003 .07175 L
.41013 .07177 L
.41023 .07181 L
.41031 .07186 L
.41036 .07191 L
.41039 .07194 L
.41039 .07198 L
.41041 .07201 L
.41048 .07206 L
.41059 .07216 L
.41074 .07228 L
.41087 .07237 L
.41094 .0724 L
.41092 .07234 L
.41077 .07219 L
.41049 .07194 L
.41008 .0716 L
.40959 .07117 L
.40909 .07072 L
.40862 .07027 L
.40822 .06982 L
.40788 .06938 L
Mistroke
.40756 .06896 L
.4073 .06855 L
.40712 .0682 L
.40704 .06792 L
.40708 .06773 L
.4072 .06762 L
.40741 .06759 L
.40766 .06762 L
.40795 .06769 L
.40822 .06777 L
.40843 .06783 L
.40855 .06785 L
.40861 .06786 L
.40862 .06785 L
.40861 .06785 L
.40857 .06786 L
.40854 .06786 L
.40851 .06787 L
.40849 .06788 L
.40849 .06789 L
.40849 .06789 L
.40849 .0679 L
.40849 .0679 L
.40849 .06791 L
.40849 .06791 L
.40849 .06791 L
.40849 .06791 L
.40849 .0679 L
.40849 .0679 L
.40849 .06789 L
.40849 .06788 L
.40849 .06787 L
.40849 .06786 L
.40849 .06786 L
.40849 .06785 L
.40849 .06785 L
.40849 .06785 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
Mistroke
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.40849 .06786 L
.4085 .06787 L
.40852 .06787 L
.40853 .06787 L
.40854 .06786 L
.40852 .06786 L
.40849 .06785 L
.40845 .06784 L
.40839 .06782 L
.40834 .06781 L
.40829 .06781 L
.40824 .0678 L
.40821 .0678 L
.40819 .06779 L
.40818 .06779 L
.40819 .0678 L
.40822 .0678 L
.40826 .06781 L
.40831 .06782 L
.40835 .06783 L
.40836 .06784 L
.40836 .06784 L
.40832 .06784 L
.40827 .06784 L
.40821 .06783 L
.40814 .06782 L
.40807 .06781 L
Mistroke
.408 .0678 L
.40796 .06781 L
.40794 .0678 L
.40793 .0678 L
.40791 .06781 L
.40792 .06781 L
.40795 .06782 L
.40802 .06783 L
.40813 .06784 L
.40828 .06785 L
.40846 .06786 L
.40867 .06787 L
.40889 .06788 L
.4091 .06788 L
.40931 .06789 L
.40952 .06789 L
.40973 .0679 L
.40995 .0679 L
.41018 .06791 L
.41039 .06791 L
.41057 .06792 L
.41072 .06792 L
.41082 .06793 L
.41088 .06793 L
.41089 .06793 L
.41088 .06793 L
.41085 .06793 L
.41081 .06793 L
.41078 .06793 L
.41077 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06793 L
.41077 .06793 L
.41078 .06793 L
.41083 .06793 L
.4109 .06793 L
Mistroke
.41096 .06793 L
.41099 .06793 L
.41097 .06793 L
.41088 .06793 L
.41071 .06792 L
.41044 .06792 L
.41009 .06791 L
.40968 .06789 L
.40924 .06788 L
.40877 .06787 L
.40832 .06785 L
.40788 .06784 L
.40744 .06783 L
.407 .06781 L
.4066 .0678 L
.40627 .06779 L
.40603 .06778 L
.40589 .06778 L
.40586 .06778 L
.40593 .06778 L
.40608 .06779 L
.40628 .06779 L
.4065 .0678 L
.40673 .06781 L
.40696 .06781 L
.4072 .06782 L
.40744 .06783 L
.40767 .06784 L
.4079 .06784 L
.40811 .06785 L
.4083 .06786 L
.40844 .06786 L
.40855 .06787 L
.4086 .06787 L
.40862 .06787 L
.40861 .06786 L
.4086 .06785 L
.40858 .06785 L
.40855 .06784 L
.40853 .06783 L
.40849 .06783 L
.40845 .06782 L
.40839 .06782 L
.40834 .06784 L
.40828 .06785 L
.40824 .06785 L
.40821 .06784 L
.40819 .06782 L
.40818 .0678 L
.40816 .06776 L
Mistroke
.40814 .06773 L
.40812 .06769 L
.40811 .06767 L
.40814 .06765 L
.40821 .06764 L
.40831 .06764 L
.40846 .06764 L
.40865 .06764 L
.40885 .06766 L
.40907 .06768 L
.40929 .06772 L
.40951 .06777 L
.40972 .06782 L
.40995 .06787 L
.41018 .06791 L
.41039 .06794 L
.41057 .06796 L
.41072 .06796 L
.41082 .06795 L
.41088 .06794 L
.41089 .06793 L
.41088 .06793 L
.41085 .06793 L
.41081 .06793 L
.41078 .06793 L
.41077 .06793 L
.41076 .06793 L
.41076 .06793 L
.41076 .06792 L
.41077 .0679 L
.41079 .06785 L
.41081 .06779 L
.41081 .06773 L
.4108 .0677 L
.41077 .06772 L
.41072 .06781 L
.41067 .06797 L
.41061 .06822 L
.41056 .06854 L
.41052 .06892 L
.41049 .06934 L
.41047 .06977 L
.41046 .07021 L
.41046 .07063 L
.41046 .07105 L
.41048 .07145 L
.41051 .0718 L
.41055 .07208 L
.41061 .07227 L
.41067 .07238 L
Mistroke
.41073 .07241 L
.41079 .07238 L
.41087 .07229 L
.41095 .07219 L
.41101 .07209 L
.41102 .07201 L
.41099 .07195 L
.41089 .07193 L
.41071 .07198 L
.41045 .07211 L
.4101 .07235 L
.4097 .07268 L
.40925 .07312 L
.40879 .07365 L
.40833 .07422 L
.40789 .07486 L
.40746 .07556 L
.40704 .07626 L
.40667 .0769 L
.40636 .07748 L
.40615 .07795 L
.40606 .07829 L
.40609 .07844 L
.4062 .07839 L
.40633 .07817 L
.40644 .0778 L
.4065 .07736 L
.40645 .07688 L
.40625 .07639 L
.40597 .07592 L
.4055 .07546 L
.40479 .07503 L
.40385 .07461 L
.40274 .0742 L
.40159 .07384 L
.4004 .07352 L
.39897 .07324 L
.39724 .073 L
.39573 .07281 L
.39406 .07265 L
.39257 .0725 L
.39104 .07233 L
.38964 .07213 L
.38852 .0719 L
.38751 .07164 L
.38661 .07135 L
.38587 .07102 L
.38532 .07067 L
.38496 .07029 L
.38477 .06989 L
Mistroke
.38473 .06948 L
.38477 .06909 L
.38486 .06868 L
.38496 .06827 L
.38505 .06787 L
.38508 .06752 L
.38504 .06725 L
.38497 .06707 L
.38487 .06697 L
.38475 .06694 L
.38462 .06695 L
.38446 .06701 L
.38427 .06707 L
.38405 .06713 L
.38382 .06715 L
.38359 .06715 L
.38341 .06714 L
.38328 .06713 L
.3832 .06713 L
.38316 .06712 L
.38318 .06713 L
.38325 .06715 L
.38335 .06717 L
.38346 .0672 L
.38356 .06723 L
.38363 .06727 L
.38368 .0673 L
.38371 .06733 L
.38375 .06737 L
.3838 .06739 L
.38388 .06742 L
.384 .06743 L
.38416 .06742 L
.38435 .06742 L
.38453 .06739 L
.38469 .06733 L
.38482 .06741 L
.38492 .06737 L
.38499 .06734 L
.38503 .06734 L
.38503 .06737 L
.38498 .06744 L
.38487 .06755 L
.38467 .06772 L
.38438 .06796 L
.384 .06822 L
.38355 .06855 L
.38308 .0689 L
.38261 .06925 L
.3822 .06965 L
Mistroke
.38184 .07001 L
.38155 .0703 L
.38132 .07059 L
.38115 .07083 L
.38104 .07104 L
.38097 .07119 L
.38095 .07131 L
.38098 .07139 L
.38107 .07143 L
.38121 .07145 L
.38134 .07145 L
.38142 .07143 L
.3814 .07139 L
.38126 .07135 L
.381 .07132 L
.3806 .07131 L
.38007 .07129 L
.37945 .07127 L
.37878 .07125 L
.37807 .07123 L
.37739 .07121 L
.37672 .07119 L
.37605 .07117 L
.37541 .07115 L
.37483 .07113 L
.37438 .07112 L
.37406 .07111 L
.37389 .07111 L
.37383 .07111 L
.37386 .07111 L
.37396 .07111 L
.37407 .07111 L
.37415 .07112 L
.37419 .07111 L
.3742 .0711 L
.37421 .07107 L
.37424 .07104 L
.37427 .07103 L
.37431 .07104 L
.37432 .07107 L
.3743 .07113 L
.37422 .07124 L
.37409 .0714 L
.37392 .07159 L
.37374 .07178 L
.37355 .07195 L
.37337 .0721 L
.37323 .07219 L
.37313 .07226 L
.37307 .07232 L
Mistroke
.37304 .07232 L
.37306 .07228 L
.37311 .07219 L
.37319 .07206 L
.37333 .07188 L
.37349 .07169 L
.37369 .07149 L
.37389 .07131 L
.37407 .07115 L
.37421 .07106 L
.3743 .07102 L
.37433 .07101 L
.37431 .07102 L
.37428 .07104 L
.37424 .07107 L
.37421 .0711 L
.3742 .07111 L
.37419 .07112 L
.37419 .07112 L
.37419 .07112 L
.37419 .07112 L
.3742 .07112 L
.37422 .07112 L
.37427 .07112 L
.37434 .07112 L
.37441 .07112 L
.37444 .07113 L
.37443 .07112 L
.37434 .07112 L
.37418 .07112 L
.37393 .0711 L
.37363 .07106 L
.3733 .07097 L
.37294 .07085 L
.37257 .07075 L
.37219 .07068 L
.3718 .07066 L
.37135 .07074 L
.37082 .07094 L
.37021 .07129 L
.36951 .0718 L
.3687 .07247 L
.36773 .07326 L
.3666 .07416 L
.36542 .07507 L
.36403 .07601 L
.36243 .07699 L
.36085 .07796 L
.35895 .07888 L
.35725 .07965 L
Mistroke
.35554 .0803 L
.35389 .0808 L
.35244 .08116 L
.35126 .08137 L
.35028 .08146 L
.34951 .08145 L
.34897 .08141 L
.34862 .08134 L
.34842 .08127 L
.34836 .08119 L
.34838 .08113 L
.34844 .08111 L
.34855 .0811 L
.34867 .08111 L
.34877 .08111 L
.34881 .08111 L
.34882 .08111 L
.34884 .08108 L
.3489 .08101 L
.34902 .08092 L
.34912 .08083 L
.34919 .08079 L
.34919 .08082 L
.34909 .08095 L
.34884 .0812 L
.3484 .08157 L
.34778 .08204 L
.34704 .08261 L
.34622 .08323 L
.34538 .08389 L
.34454 .08451 L
.34387 .08511 L
.34311 .0857 L
.34239 .08627 L
.34177 .08677 L
.34133 .08716 L
.34111 .08739 L
.3411 .08747 L
.34123 .08744 L
.34144 .08733 L
.34167 .08721 L
.34187 .08711 L
.34194 .08708 L
.34181 .08715 L
.34147 .08732 L
.34091 .08756 L
.34011 .08788 L
.33904 .08827 L
.33789 .08875 L
.3364 .08933 L
Mistroke
.33504 .08998 L
.33356 .09076 L
.33186 .09163 L
.33023 .09261 L
.32853 .09366 L
.32675 .09474 L
.32495 .09578 L
.32324 .09674 L
.3215 .09768 L
.31979 .09855 L
.31839 .09935 L
.31694 .10003 L
.31559 .10062 L
.31452 .10113 L
.31358 .10154 L
.31276 .10187 L
.31209 .10212 L
.31157 .10231 L
.31123 .10248 L
.31106 .10264 L
.31104 .10279 L
.31112 .10294 L
.31125 .10311 L
.31139 .1033 L
.3115 .10349 L
.31155 .10367 L
.31156 .1038 L
.31156 .1039 L
.31156 .10396 L
.31156 .10397 L
.31156 .10396 L
.31156 .10392 L
.31156 .10389 L
.31156 .10386 L
.31156 .10385 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31156 .10384 L
.31159 .10382 L
.31165 .10377 L
.31176 .10371 L
.31186 .10365 L
.31192 .10361 L
.31189 .10363 L
Mistroke
.31177 .10371 L
.31153 .10387 L
.31115 .10409 L
.31067 .10438 L
.31011 .10469 L
.30952 .10502 L
.30888 .10539 L
.30818 .1058 L
.30745 .10625 L
.30666 .10677 L
.30582 .10733 L
.30495 .10792 L
.30412 .10852 L
.30339 .10909 L
.3028 .10961 L
.30233 .11009 L
.30196 .11051 L
.30159 .1109 L
.30118 .11127 L
.30068 .11163 L
.30007 .11196 L
.29937 .11224 L
.29863 .11244 L
.29786 .11254 L
.29713 .11256 L
.29647 .1125 L
.29589 .11239 L
.29532 .11227 L
.29472 .11217 L
.29408 .11211 L
.29346 .11209 L
.29292 .11211 L
.29247 .11218 L
.29212 .11229 L
.29185 .11244 L
.29165 .11261 L
.29151 .11281 L
.29138 .11305 L
.29121 .11325 L
.29098 .1135 L
.29074 .11374 L
.29052 .11395 L
.29034 .11411 L
.29022 .11422 L
.29017 .11424 L
.29021 .11421 L
.29032 .11417 L
.29049 .11413 L
.29071 .11413 L
.29095 .11419 L
Mistroke
.29119 .11433 L
.29144 .11456 L
.29169 .11483 L
.29195 .11511 L
.29221 .11535 L
.29249 .1155 L
.29276 .11559 L
.293 .11561 L
.29322 .11562 L
.29338 .11563 L
.29343 .11573 L
.29334 .11575 L
.29311 .1158 L
.29269 .11587 L
.29208 .11602 L
.29122 .11628 L
.29008 .1167 L
.28879 .11725 L
.2872 .11802 L
.28527 .119 L
.28312 .12017 L
.28111 .12138 L
.27888 .12268 L
.2764 .12402 L
.27416 .1253 L
.27183 .12654 L
.26986 .12764 L
.26809 .12864 L
.26662 .12955 L
.26542 .13036 L
.26435 .13104 L
.26347 .13161 L
.26274 .13208 L
.26213 .13246 L
.26156 .13278 L
.26098 .13306 L
.26036 .13334 L
.25962 .13367 L
.2587 .13409 L
.25764 .13462 L
.25642 .13529 L
.25496 .13611 L
.25321 .13709 L
.25137 .13818 L
.24944 .1394 L
.24746 .14067 L
.24571 .14192 L
.24401 .1431 L
.2426 .14422 L
.24124 .14522 L
Mistroke
.24013 .14606 L
.23919 .14677 L
.23846 .14732 L
.23797 .14772 L
.23768 .14796 L
.23758 .14808 L
.23761 .14811 L
.23773 .14807 L
.23788 .148 L
.23803 .14791 L
.23812 .14783 L
.23818 .14775 L
.23827 .14768 L
.23839 .14759 L
.23849 .14749 L
.23854 .14741 L
.23852 .14736 L
.23839 .14738 L
.23815 .14749 L
.23776 .14773 L
.23722 .14811 L
.23655 .14865 L
.23577 .14933 L
.23492 .15015 L
.23406 .15104 L
.23319 .15204 L
.23229 .15304 L
.2314 .15407 L
.23056 .15508 L
.22984 .15603 L
.22927 .15684 L
.22885 .15752 L
.22858 .15806 L
.22842 .15845 L
.22837 .15868 L
.22837 .15879 L
.2284 .15881 L
.22842 .15878 L
.22845 .15872 L
.22849 .15865 L
.22853 .15858 L
.2286 .1585 L
.22867 .15845 L
.22876 .1584 L
.22887 .15835 L
.22899 .15828 L
.22909 .15821 L
.22913 .15814 L
.22906 .15813 L
.22885 .15822 L
Mistroke
.22844 .15843 L
.22779 .15877 L
.22688 .15926 L
.22569 .15989 L
.22436 .1606 L
.22275 .16141 L
.22086 .1623 L
.21891 .16324 L
.21686 .16428 L
.21452 .16552 L
.21235 .16673 L
.21003 .16803 L
.20779 .16938 L
.20588 .17077 L
.20405 .17213 L
.2024 .17342 L
.20106 .17447 L
.19991 .17553 L
.19898 .17651 L
.1983 .17728 L
.19782 .17797 L
.1975 .17857 L
.1973 .17903 L
.19716 .17937 L
.19703 .17967 L
.19684 .18004 L
.19655 .1805 L
.19617 .18111 L
.19568 .18192 L
.19508 .18292 L
.1944 .18407 L
.19372 .18515 L
.19302 .18638 L
.19234 .18763 L
.19175 .18868 L
.19119 .18973 L
.19073 .19061 L
.19039 .19136 L
.19016 .19197 L
.18996 .19251 L
.18976 .19303 L
.18949 .19359 L
.18909 .19428 L
.18847 .19521 L
.18759 .19641 L
.18653 .19771 L
.18524 .1994 L
.18368 .20128 L
.18189 .20354 L
.17999 .20592 L
Mistroke
.17822 .20863 L
.17634 .21113 L
.17433 .21393 L
.17238 .21675 L
.17052 .21951 L
.16866 .22244 L
.16697 .22495 L
.16528 .22764 L
.16374 .23014 L
.16221 .23262 L
.16073 .23497 L
.15939 .23736 L
.15805 .23943 L
.15673 .24152 L
.1555 .24352 L
.15438 .24536 L
.15332 .24712 L
.15232 .24876 L
.15144 .25012 L
.15065 .25141 L
.14997 .25258 L
.14944 .2536 L
.14902 .25445 L
.14873 .25514 L
.14854 .25565 L
.14845 .25598 L
.14841 .25617 L
.1484 .25624 L
.14838 .25624 L
.14835 .2562 L
.14828 .25617 L
.14815 .25618 L
.14793 .25625 L
.14762 .2564 L
.1472 .25669 L
.14666 .25714 L
.14598 .25781 L
.1452 .25868 L
.1443 .25976 L
.14327 .2611 L
.1421 .26271 L
.14084 .26462 L
.1396 .26646 L
.1383 .2687 L
.13697 .2711 L
.13562 .2735 L
.13419 .27619 L
.13266 .2791 L
.13111 .28182 L
.12943 .28494 L
Mistroke
.12775 .28787 L
.12611 .29096 L
.12443 .29384 L
.1227 .29692 L
.12116 .29956 L
.11929 .30243 L
.1176 .30521 L
.1157 .30814 L
.11388 .31113 L
.11193 .31375 L
.10991 .31658 L
.10795 .31955 L
.10646 .32198 L
.10485 .3246 L
.10339 .32686 L
.10193 .32912 L
.10084 .33096 L
.09987 .33266 L
.09902 .3342 L
.09837 .33545 L
.09791 .33645 L
.09764 .33719 L
.09754 .33764 L
.09756 .33785 L
.09765 .33788 L
.09777 .33778 L
.0979 .33762 L
.098 .33745 L
.09805 .3373 L
.09804 .3372 L
.09804 .33713 L
.09804 .33712 L
.09802 .33715 L
.09798 .33724 L
.0979 .33739 L
.09779 .33765 L
.09766 .33803 L
.09753 .33855 L
.09741 .33921 L
.09731 .34 L
.09723 .34091 L
.0972 .34189 L
.09719 .34286 L
.09721 .34384 L
.09726 .34481 L
.09731 .34573 L
.0974 .34653 L
.09752 .34717 L
.09766 .34758 L
.09782 .34782 L
Mistroke
.09799 .34795 L
.09815 .34799 L
.09827 .348 L
.09831 .34804 L
.09825 .34823 L
.0981 .34871 L
.09786 .34955 L
.09755 .35079 L
.09719 .35242 L
.09677 .35447 L
.09628 .35657 L
.0957 .35892 L
.09501 .36176 L
.09421 .36473 L
.09334 .36802 L
.09239 .37125 L
.09139 .37468 L
.09042 .37804 L
.08946 .38107 L
.08854 .38438 L
.08773 .3874 L
.08695 .39048 L
.08629 .39337 L
.08569 .39641 L
.08518 .39899 L
.08478 .40171 L
.08449 .40425 L
.08431 .40687 L
.08422 .40939 L
.08422 .41145 L
.08425 .4134 L
.08431 .41524 L
.08436 .41689 L
.08439 .41832 L
.08439 .41942 L
.08438 .42035 L
.08437 .42106 L
.08437 .42158 L
.08436 .42194 L
.08436 .42212 L
Mfstroke
.07165 .50267 m
.07162 .50291 L
.07158 .50327 L
.07156 .50372 L
.07155 .50422 L
.07154 .50475 L
.07152 .50531 L
.07148 .50593 L
.07143 .5066 L
.07136 .50736 L
.0713 .50818 L
.07126 .50903 L
.07123 .50993 L
.07121 .51089 L
.07118 .5119 L
.07111 .51301 L
.07099 .51422 L
.07082 .51561 L
.07061 .51726 L
.07034 .51924 L
.07002 .52142 L
.06967 .52395 L
.0693 .52671 L
.06895 .52922 L
.0686 .53172 L
.06828 .5344 L
.06799 .53694 L
.06776 .53968 L
.06761 .54199 L
.06756 .54433 L
.06766 .54659 L
.06787 .54865 L
.0682 .55059 L
.0686 .55229 L
.06905 .5538 L
.06952 .55513 L
.06998 .55631 L
.07039 .55732 L
.07076 .55813 L
.07109 .55881 L
.07138 .55938 L
.07165 .55985 L
.07189 .56021 L
.07212 .5605 L
.07234 .56072 L
.07258 .56089 L
.07283 .56102 L
.07311 .56112 L
.07339 .56117 L
.07364 .56121 L
Mistroke
.0739 .56128 L
.07413 .5614 L
.07431 .5616 L
.07438 .56189 L
.07433 .56228 L
.07416 .56279 L
.07388 .56345 L
.07354 .56429 L
.07319 .56535 L
.07287 .56656 L
.07261 .56804 L
.07243 .56974 L
.07236 .57158 L
.07241 .57367 L
.07257 .57589 L
.07285 .57809 L
.07322 .58045 L
.0737 .58278 L
.07429 .5852 L
.0749 .58741 L
.07551 .58964 L
.07611 .59182 L
.07664 .59366 L
.07708 .59543 L
.07743 .59704 L
.07771 .59839 L
.07791 .59955 L
.07806 .60057 L
.07817 .60125 L
.07825 .60178 L
.07832 .60212 L
.07835 .60226 L
.07834 .60227 L
.0783 .6022 L
.07826 .60213 L
.07824 .60214 L
.07824 .60222 L
.07828 .60236 L
.07833 .60256 L
.07839 .6028 L
.07844 .60307 L
.07848 .60335 L
.0785 .60365 L
.07852 .60396 L
.07851 .60433 L
.07847 .60483 L
.07842 .6055 L
.07833 .60625 L
.07821 .60719 L
.07809 .60828 L
Mistroke
.07796 .60954 L
.07784 .61091 L
.07777 .61255 L
.07776 .61441 L
.07781 .61653 L
.07793 .61898 L
.07814 .62142 L
.07843 .62414 L
.0788 .62703 L
.07925 .63013 L
.07979 .63302 L
.08041 .63596 L
.08108 .63902 L
.08178 .64191 L
.08248 .64495 L
.08315 .64778 L
.08376 .65063 L
.08434 .65315 L
.08491 .65556 L
.08543 .6576 L
.08591 .65941 L
.08636 .66101 L
.08676 .66241 L
.08711 .66368 L
.08742 .66489 L
.08771 .66605 L
.08799 .66717 L
.08828 .66825 L
.08859 .66928 L
.08894 .6702 L
.08931 .67109 L
.08968 .67188 L
.09001 .67263 L
.09029 .67324 L
.09054 .67379 L
.09076 .67427 L
.09097 .67466 L
.09117 .67502 L
.09138 .67544 L
.09159 .67594 L
.09179 .67654 L
.09197 .6774 L
.09214 .67853 L
.0923 .67988 L
.09245 .68133 L
.09261 .68295 L
.09277 .68466 L
.09292 .68632 L
.09304 .68812 L
.09315 .68977 L
Mistroke
.09324 .69144 L
.09332 .69312 L
.09339 .69482 L
.09346 .69656 L
.09354 .69833 L
.09365 .69995 L
.09381 .7017 L
.09407 .70355 L
.09444 .70535 L
.0949 .70726 L
.09547 .70917 L
.09616 .71092 L
.09695 .71257 L
.0979 .71405 L
.09861 .71507 L
.09944 .71604 L
.10029 .71681 L
.10098 .7174 L
.10162 .71786 L
.10222 .71823 L
.10274 .71851 L
.10315 .71874 L
.10343 .71898 L
.10358 .71929 L
.10362 .7197 L
.10358 .72024 L
.1035 .72097 L
.10341 .72189 L
.10332 .72294 L
.10326 .7241 L
.10321 .72535 L
.10314 .72663 L
.10305 .72802 L
.10295 .72953 L
.10285 .73131 L
.10275 .73291 L
.10265 .73472 L
.10258 .7366 L
.10252 .73838 L
.10247 .74003 L
.10245 .74153 L
.10243 .74274 L
.10243 .74379 L
.10245 .74468 L
.10249 .74543 L
.10255 .74605 L
.10261 .7465 L
.10268 .74676 L
.10274 .74688 L
.10279 .74687 L
Mistroke
.10281 .74679 L
.10281 .74668 L
.10279 .74656 L
.10276 .74647 L
.10275 .74642 L
.10275 .7464 L
.10275 .74635 L
.10275 .74629 L
.10276 .7462 L
.10276 .74609 L
.10276 .74596 L
.10276 .74584 L
.10275 .74576 L
.10272 .74573 L
.10268 .74573 L
.10264 .74573 L
.10261 .74572 L
.10261 .74573 L
.10263 .74575 L
.10266 .74582 L
.10272 .74594 L
.10281 .74614 L
.10297 .74647 L
.10324 .74693 L
.10361 .74753 L
.10409 .74827 L
.10471 .74915 L
.10545 .75019 L
.1063 .75128 L
.10723 .75249 L
.10813 .75378 L
.10904 .75511 L
.10992 .75647 L
.11073 .75775 L
.11151 .75901 L
.11225 .76021 L
.11298 .7613 L
.11372 .76234 L
.11451 .76334 L
.1154 .76445 L
.11633 .76554 L
.11737 .76683 L
.11855 .76827 L
.11978 .76975 L
.12121 .77136 L
.1228 .77311 L
.12452 .77492 L
.1263 .77656 L
.12808 .77826 L
.12968 .77966 L
Mistroke
.13121 .78089 L
.13241 .78193 L
.13338 .7827 L
.13402 .78318 L
.13432 .78341 L
.13431 .78342 L
.13413 .78329 L
.13387 .78307 L
.13361 .78284 L
.13336 .78266 L
.13319 .78263 L
.13309 .78279 L
.13308 .78317 L
.13322 .78369 L
.13362 .78436 L
.13443 .78517 L
.13532 .78599 L
.13666 .7869 L
.13819 .78787 L
.13996 .78887 L
.14183 .78989 L
.14384 .79086 L
.1458 .79179 L
.14777 .79264 L
.14977 .79338 L
.15167 .794 L
.15346 .79452 L
.15507 .79494 L
.15643 .7953 L
.15753 .79559 L
.15846 .79589 L
.15907 .79612 L
.15956 .79642 L
.15993 .79676 L
.16021 .79719 L
.16042 .79771 L
.16064 .79836 L
.16086 .7992 L
.16112 .80013 L
.16142 .80134 L
.16186 .8028 L
.16247 .80442 L
.16328 .8062 L
.16432 .80822 L
.16555 .81047 L
.16689 .81277 L
.16837 .81511 L
.17 .81761 L
.17169 .82006 L
.17352 .82258 L
Mistroke
.17552 .82511 L
.17765 .82756 L
.17993 .82995 L
.18217 .83223 L
.18442 .83433 L
.18647 .83623 L
.18831 .83776 L
.18994 .83911 L
.19128 .84015 L
.19242 .841 L
.19334 .84168 L
.19412 .84224 L
.19483 .84276 L
.19553 .84333 L
.19627 .84399 L
.19704 .84475 L
.19793 .84565 L
.19892 .84667 L
.20013 .84789 L
.20161 .84933 L
.2033 .85101 L
.20522 .8528 L
.20719 .85466 L
.20925 .85649 L
.21133 .85839 L
.21313 .85985 L
.21488 .86131 L
.21639 .86261 L
.2177 .86368 L
.21874 .86455 L
.21956 .86527 L
.22016 .86581 L
.22055 .86619 L
.22078 .86648 L
.22089 .86669 L
.22093 .86689 L
.22097 .86709 L
.22107 .86733 L
.22128 .86764 L
.22161 .868 L
.22209 .86843 L
.22271 .8689 L
.22343 .86939 L
.22418 .86989 L
.22495 .8703 L
.22572 .87073 L
.22644 .87108 L
.22704 .87133 L
.22753 .8715 L
.22788 .87159 L
Mistroke
.22811 .87162 L
.22823 .87162 L
.22828 .87162 L
.22833 .87168 L
.22848 .87183 L
.2288 .87213 L
.22934 .8726 L
.23013 .87323 L
.23117 .87403 L
.23242 .87503 L
.23397 .87619 L
.23579 .87754 L
.2377 .879 L
.23976 .88052 L
.24184 .88207 L
.24387 .88349 L
.24574 .88475 L
.24752 .88606 L
.24918 .88734 L
.25059 .88857 L
.25188 .88975 L
.25292 .89079 L
.25389 .89175 L
.25454 .89262 L
.25513 .89338 L
.25566 .89401 L
.25604 .8947 L
.25644 .8954 L
.25686 .89617 L
.25737 .897 L
.25793 .89778 L
.25865 .89861 L
.25952 .89943 L
.26064 .90021 L
.26166 .90097 L
.26298 .90174 L
.26445 .90256 L
.26613 .90348 L
.26807 .90449 L
.27026 .90559 L
.27261 .90672 L
.27497 .90778 L
.27731 .90881 L
.27963 .90976 L
.28169 .91066 L
.28357 .91144 L
.28502 .91211 L
.2862 .91271 L
.28716 .91321 L
.28791 .91356 L
Mistroke
.28844 .91373 L
.28882 .91374 L
.28907 .91359 L
.28928 .91332 L
.28958 .913 L
.29005 .91269 L
.29068 .91242 L
.29154 .91218 L
.29252 .91199 L
.29367 .91183 L
.29491 .91165 L
.29619 .91145 L
.29738 .91122 L
.29838 .91096 L
.29914 .91066 L
.29964 .91034 L
.29994 .91005 L
.30008 .90985 L
.30008 .90975 L
.29994 .90972 L
.29986 .9098 L
.29989 .91003 L
.30014 .91037 L
.30065 .91087 L
.30153 .91165 L
.3028 .91268 L
.30455 .91392 L
.30663 .9153 L
.30922 .91678 L
.31199 .91839 L
.31519 .92009 L
.31838 .9218 L
.32183 .92347 L
.32519 .92509 L
.32863 .9266 L
.33204 .92792 L
.33545 .92916 L
.33855 .93026 L
.34169 .93124 L
.34475 .93214 L
.34774 .93297 L
.35061 .93374 L
.35341 .93445 L
.35611 .93514 L
.35882 .93582 L
.36149 .93649 L
.36403 .93719 L
.36656 .93793 L
.36905 .93871 L
.37135 .93953 L
Mistroke
.37348 .94033 L
.37536 .94108 L
.37692 .94175 L
.37818 .94232 L
.37918 .94275 L
.37992 .94303 L
.38049 .94315 L
.38093 .94313 L
.38132 .94294 L
.38176 .94257 L
.38234 .94205 L
.3831 .9414 L
.384 .94063 L
.38514 .93976 L
.38639 .93882 L
.38775 .93786 L
.38919 .93692 L
.39067 .93597 L
.39208 .93536 L
.39333 .93471 L
.39431 .93425 L
.39501 .93397 L
.39543 .93393 L
.39559 .9341 L
.39548 .93443 L
.39519 .9349 L
.39485 .93553 L
.39454 .93625 L
.39434 .93696 L
.39432 .93758 L
.39453 .93811 L
.39498 .9386 L
.39564 .93904 L
.39649 .9394 L
.39735 .93975 L
.39822 .94014 L
.399 .94054 L
.39964 .94093 L
.40006 .94132 L
.40026 .94171 L
.40026 .94196 L
.40011 .94212 L
.39982 .9421 L
.39945 .94193 L
.39886 .94158 L
.39838 .94091 L
.39781 .94008 L
.39728 .93923 L
.39682 .93806 L
.39651 .9368 L
Mistroke
.39635 .93536 L
.39631 .93407 L
.39634 .93286 L
.39639 .93187 L
.39643 .93114 L
.39639 .93067 L
.39623 .93043 L
.39594 .93043 L
.39558 .93071 L
.39518 .93123 L
.3948 .93189 L
.39446 .93268 L
.39423 .93363 L
.39411 .93464 L
.39413 .93578 L
.39431 .93698 L
.39467 .93824 L
.39524 .9396 L
.39602 .94103 L
.39699 .94251 L
.39818 .944 L
.39961 .94548 L
.40123 .94698 L
.40309 .94847 L
.40509 .94992 L
.40734 .95137 L
.40986 .95274 L
.41241 .95396 L
.41515 .95508 L
.41805 .95615 L
.42099 .95719 L
.42394 .95817 L
.42675 .95911 L
.42957 .96001 L
.43222 .96083 L
.43474 .96157 L
.43688 .96222 L
.43881 .96273 L
.44052 .9631 L
.442 .96338 L
.44333 .96365 L
.44454 .96393 L
.44575 .96422 L
.4468 .96447 L
.44799 .9647 L
.44926 .96487 L
.45057 .96492 L
.45199 .96486 L
.45351 .9647 L
.45502 .96451 L
Mistroke
.45655 .96436 L
.45806 .96433 L
.45957 .96441 L
.46103 .96457 L
.46253 .96466 L
.46407 .96474 L
.46568 .96483 L
.46738 .96495 L
.46915 .96508 L
.47098 .96522 L
.47301 .96542 L
.47515 .96568 L
.47741 .96594 L
.47972 .96614 L
.48213 .96623 L
.48457 .96618 L
.48707 .96602 L
.48989 .9658 L
.49223 .96562 L
.49468 .96544 L
.49698 .9653 L
.49903 .96521 L
.50067 .96517 L
.50191 .96517 L
.50268 .96518 L
.50317 .96518 L
.5034 .96515 L
.50344 .96516 L
.50335 .96521 L
.50307 .96527 L
.50269 .9653 L
.5023 .96528 L
.50194 .96517 L
.50162 .96497 L
.50142 .96463 L
.50128 .96419 L
.50129 .96369 L
.50149 .96314 L
.50186 .96259 L
.50233 .96203 L
.50261 .96143 L
.50277 .96075 L
.50282 .96005 L
.50277 .95938 L
.50273 .95873 L
.50268 .95818 L
.50261 .95772 L
.50261 .95741 L
.50261 .95721 L
.50259 .95714 L
Mistroke
.50249 .9572 L
.50229 .95735 L
.50194 .95747 L
.50141 .9575 L
.50068 .95749 L
.49969 .95748 L
.49843 .95746 L
.49695 .95747 L
.49526 .95756 L
.49344 .95774 L
.49134 .95793 L
.48889 .95811 L
.48663 .95825 L
.48413 .95841 L
.48152 .95857 L
.47884 .95869 L
.47611 .95889 L
.4733 .95916 L
.47056 .9595 L
.46778 .95981 L
.46498 .96021 L
.46226 .96047 L
.45944 .96064 L
.45664 .96068 L
.45387 .96071 L
.45114 .96074 L
.44841 .96078 L
.44583 .96084 L
.44322 .96091 L
.44088 .96096 L
.43852 .96089 L
.43608 .96069 L
.43402 .96035 L
.43194 .95987 L
.42991 .95931 L
.42783 .95866 L
.42576 .95797 L
.42371 .95727 L
.42162 .95655 L
.41945 .95581 L
.41719 .95505 L
.41493 .95425 L
.4125 .95338 L
.40984 .95245 L
.4071 .95151 L
.40424 .95058 L
.4013 .94965 L
.39819 .94871 L
.39505 .94779 L
.39194 .94684 L
Mistroke
.38871 .94584 L
.38559 .9448 L
.38241 .94373 L
.37931 .94261 L
.37623 .94149 L
.37304 .94038 L
.36996 .93931 L
.36688 .93835 L
.36385 .93743 L
.36079 .93655 L
.35785 .93567 L
.35495 .93477 L
.35189 .93382 L
.34877 .93281 L
.34579 .93177 L
.34267 .93069 L
.33945 .92962 L
.33649 .92861 L
.33362 .92763 L
.3307 .92668 L
.32817 .9258 L
.32549 .92497 L
.32341 .92425 L
.32153 .92365 L
.31982 .92319 L
.31837 .92288 L
.31722 .92272 L
.31637 .92266 L
.31571 .92263 L
.31513 .92255 L
.31451 .92235 L
.3138 .92199 L
.31296 .92146 L
.31191 .92075 L
.31058 .9199 L
.3092 .919 L
.30772 .91802 L
.30625 .91703 L
.30487 .91607 L
.30353 .91516 L
.30223 .91439 L
.30114 .91376 L
.30026 .9133 L
.29958 .91302 L
.29912 .91288 L
.29888 .91283 L
.29883 .91283 L
.29892 .91279 L
.29908 .91263 L
.29925 .91231 L
Mistroke
.29938 .91187 L
.29944 .91132 L
.29944 .91071 L
.29941 .91011 L
.2994 .90962 L
.29959 .90926 L
.29976 .90905 L
.29997 .90899 L
.30013 .90911 L
.30025 .9094 L
.30024 .90981 L
.30004 .91028 L
.29958 .91075 L
.29883 .91127 L
.29777 .91173 L
.29638 .91203 L
.29477 .9121 L
.29279 .91189 L
.29063 .9114 L
.28826 .91072 L
.28555 .90984 L
.28271 .90884 L
.2798 .90788 L
.27725 .90691 L
.27461 .90602 L
.27226 .90531 L
.27015 .90466 L
.26837 .90411 L
.26687 .90363 L
.26558 .90317 L
.26458 .90272 L
.26372 .90229 L
.26296 .90186 L
.26244 .90147 L
.26199 .90106 L
.26163 .90064 L
.26137 .90027 L
.2612 .89992 L
.26106 .89957 L
.26091 .89922 L
.2607 .89892 L
.26048 .89867 L
.26014 .89846 L
.2597 .89827 L
.25914 .89805 L
.25842 .89776 L
.25751 .89733 L
.25644 .89673 L
.25521 .89594 L
.25388 .89499 L
Mistroke
.25238 .89383 L
.25069 .89251 L
.24885 .89109 L
.24701 .8896 L
.24516 .88808 L
.24341 .88657 L
.24186 .88512 L
.24052 .88388 L
.23942 .88285 L
.23851 .88202 L
.23773 .88132 L
.23709 .88078 L
.23648 .88027 L
.23581 .87969 L
.23517 .87912 L
.23457 .87859 L
.23384 .87792 L
.23299 .87714 L
.23196 .8762 L
.2307 .87511 L
.22925 .87382 L
.22766 .87245 L
.22587 .87092 L
.22392 .86925 L
.22186 .86743 L
.21973 .86558 L
.21754 .86363 L
.21542 .86172 L
.21329 .85978 L
.21114 .85786 L
.20909 .85614 L
.20708 .85442 L
.20513 .85266 L
.20328 .85102 L
.20151 .84932 L
.19986 .84755 L
.19832 .84585 L
.19685 .84413 L
.19546 .84242 L
.19418 .84084 L
.19298 .83932 L
.19186 .83806 L
.19084 .83682 L
.18986 .83577 L
.18891 .83474 L
.18794 .83373 L
.18695 .8328 L
.18589 .83192 L
.18474 .8311 L
.18351 .83029 L
Mistroke
.18218 .82947 L
.18077 .82858 L
.17939 .82759 L
.17788 .82656 L
.17632 .82523 L
.1747 .82383 L
.17295 .82221 L
.17122 .82051 L
.16942 .81865 L
.16759 .81668 L
.16584 .81472 L
.16415 .81283 L
.16253 .81088 L
.16095 .80889 L
.15934 .80691 L
.15787 .80497 L
.15637 .80299 L
.15488 .80107 L
.15341 .79925 L
.15208 .79759 L
.15085 .79607 L
.14976 .7947 L
.1487 .79346 L
.14762 .7923 L
.14645 .79122 L
.14544 .79017 L
.14418 .78913 L
.1427 .78802 L
.14111 .78676 L
.13927 .78553 L
.13745 .78415 L
.13538 .78263 L
.13329 .78096 L
.13142 .77914 L
.12947 .77722 L
.12732 .77517 L
.1252 .77307 L
.12307 .77092 L
.12106 .76876 L
.11902 .76663 L
.11715 .76467 L
.11537 .76281 L
.11365 .76112 L
.11213 .75957 L
.1107 .75818 L
.10935 .75693 L
.10813 .75581 L
.10714 .7548 L
.1063 .75388 L
.10565 .75308 L
Mistroke
.10519 .75245 L
.10495 .75199 L
.10488 .75166 L
.10495 .75143 L
.10509 .75124 L
.10527 .75108 L
.10545 .75094 L
.10562 .75079 L
.10577 .75064 L
.10587 .75046 L
.10592 .75032 L
.10591 .75024 L
.10585 .75019 L
.10572 .7501 L
.10551 .74995 L
.10525 .74969 L
.10495 .7493 L
.10464 .74876 L
.10433 .74801 L
.10408 .74729 L
.10383 .74642 L
.1036 .7455 L
.10337 .74451 L
.10315 .74336 L
.10291 .74197 L
.10269 .74032 L
.10249 .73846 L
.10228 .73657 L
.10206 .73471 L
.10181 .73293 L
.10153 .73131 L
.10121 .72988 L
.10085 .72866 L
.1005 .72767 L
.10019 .72688 L
.09994 .72626 L
.09975 .72578 L
.09962 .72542 L
.09956 .72524 L
.09957 .72519 L
.09964 .72523 L
.09982 .72525 L
.10008 .72521 L
.10038 .72513 L
.1007 .72502 L
.10099 .72488 L
.10122 .72472 L
.10137 .72462 L
.10141 .72466 L
.10134 .72477 L
Mistroke
.10115 .72493 L
.1009 .72503 L
.10059 .72497 L
.10023 .72466 L
.09981 .72416 L
.09931 .72357 L
.09872 .7227 L
.09808 .72158 L
.09742 .72016 L
.09678 .7185 L
.09619 .71661 L
.0956 .7147 L
.09502 .71246 L
.0944 .70979 L
.09374 .70697 L
.09301 .70379 L
.0922 .70037 L
.09138 .69648 L
.09057 .69251 L
.08981 .68819 L
.08911 .68452 L
.08849 .68069 L
.08794 .67749 L
.08745 .67462 L
.08706 .67184 L
.08674 .66927 L
.08653 .66727 L
.0864 .66604 L
.08637 .66539 L
.08639 .66499 L
.08639 .66461 L
.08633 .66416 L
.08619 .66357 L
.08595 .66249 L
.08559 .66069 L
.08519 .65844 L
.08474 .65586 L
.08425 .65312 L
.08377 .65028 L
.08329 .64743 L
.08282 .64465 L
.08244 .64215 L
.08213 .63991 L
.08189 .63804 L
.08177 .63661 L
.08179 .63557 L
.08194 .63494 L
.0822 .63469 L
.08254 .63469 L
.08291 .63488 L
Mistroke
.08328 .6352 L
.08363 .63558 L
.08395 .63599 L
.08421 .63637 L
.08441 .6367 L
.08458 .63695 L
.08473 .63712 L
.08484 .63722 L
.08491 .63728 L
.08493 .6373 L
.08491 .63728 L
.08487 .63725 L
.08483 .63721 L
.08479 .63718 L
.08478 .63716 L
.08478 .63716 L
.0848 .63718 L
.08486 .6372 L
.08494 .63724 L
.08501 .63731 L
.08505 .63742 L
.08503 .63758 L
.08495 .63776 L
.08478 .63791 L
.08451 .63796 L
.08413 .63784 L
.08366 .63748 L
.08311 .63681 L
.08251 .63579 L
.0819 .63443 L
.0813 .63267 L
.08068 .6305 L
.08006 .62818 L
.07948 .62551 L
.07896 .62245 L
.0785 .61945 L
.07811 .61618 L
.07777 .6129 L
.07747 .60954 L
.07719 .60633 L
.0769 .60314 L
.07658 .6 L
.07619 .59686 L
.07574 .59372 L
.07525 .59052 L
.07473 .58718 L
.07417 .58357 L
.07356 .58014 L
.07291 .57652 L
.07227 .57289 L
Mistroke
.07162 .56927 L
.07097 .56579 L
.07035 .56247 L
.06975 .55916 L
.06919 .5561 L
.0687 .55307 L
.06832 .55019 L
.06803 .5474 L
.06784 .5447 L
.06776 .54194 L
.06779 .53915 L
.06794 .53611 L
.0682 .5331 L
.06856 .52986 L
.06903 .52654 L
.06956 .52307 L
.07017 .51976 L
.07076 .51658 L
.07136 .51373 L
.07193 .51117 L
.07245 .50891 L
.07291 .50705 L
.07331 .50551 L
.07365 .5042 L
.07394 .50309 L
.07416 .50214 L
.07431 .50132 L
.0744 .5006 L
.07444 .49992 L
.07444 .49923 L
.07445 .49854 L
.0745 .49774 L
.07459 .49686 L
.07473 .49593 L
.07494 .49499 L
.07522 .49414 L
.07553 .49343 L
.07584 .49286 L
.07613 .49241 L
.07641 .49205 L
.07666 .49175 L
.07686 .49146 L
.07701 .49113 L
.0771 .49074 L
.07716 .49031 L
.07723 .48986 L
.07731 .48943 L
.07742 .48902 L
.07753 .48863 L
.07763 .48823 L
Mistroke
.07775 .48782 L
.07792 .48741 L
.07814 .487 L
.07842 .4866 L
.07875 .48622 L
.07912 .48586 L
.07954 .4855 L
.07998 .48515 L
.08044 .48479 L
.08085 .4844 L
.0812 .48396 L
.08148 .48356 L
.08177 .48317 L
.08204 .48283 L
.08231 .48257 L
.08256 .48238 L
.08278 .48226 L
.08295 .48221 L
Mfstroke
.07677 .51376 m
.07671 .51389 L
.07662 .51414 L
.07647 .51453 L
.07621 .51509 L
.07584 .51586 L
.07534 .51683 L
.0747 .51797 L
.07411 .51919 L
.07337 .52064 L
.07257 .52236 L
.07174 .52437 L
.071 .5263 L
.07017 .52873 L
.06945 .53083 L
.06879 .53315 L
.0682 .53577 L
.06772 .53843 L
.06738 .54051 L
.06719 .54294 L
.06715 .54544 L
.06722 .54744 L
.06739 .54938 L
.06762 .55109 L
.06789 .55263 L
.06816 .55379 L
.06841 .55483 L
.06866 .55552 L
.06891 .55594 L
.06915 .55611 L
.06937 .55608 L
.06954 .55594 L
.06965 .55575 L
.06969 .55555 L
.06967 .5554 L
.06961 .55537 L
.06952 .5555 L
.06945 .55584 L
.06942 .55642 L
.06946 .55722 L
.0696 .55822 L
.06981 .55941 L
.07009 .56067 L
.07045 .56207 L
.07085 .56356 L
.07127 .56507 L
.07173 .56651 L
.0722 .56787 L
.07267 .56908 L
.07309 .57007 L
Mistroke
.07348 .57087 L
.07382 .57146 L
.07408 .57186 L
.07427 .57208 L
.07437 .57218 L
.07441 .57219 L
.0744 .57214 L
.07436 .57205 L
.07431 .57191 L
.07427 .57175 L
.07424 .57158 L
.07423 .57144 L
.07423 .57136 L
.07423 .57134 L
.07423 .57142 L
.07422 .57163 L
.07419 .57198 L
.07414 .57248 L
.07407 .57314 L
.074 .57397 L
.07394 .57495 L
.0739 .57604 L
.07391 .57725 L
.07395 .57857 L
.07405 .57997 L
.07418 .58136 L
.07435 .58267 L
.07454 .58387 L
.07473 .58492 L
.07493 .58579 L
.07517 .58649 L
.07544 .58703 L
.07574 .58744 L
.07605 .58778 L
.07633 .58809 L
.07656 .5884 L
.07672 .58873 L
.07681 .58908 L
.07685 .58948 L
.07687 .58992 L
.0769 .59042 L
.07697 .59102 L
.07711 .59172 L
.07732 .5925 L
.07756 .59332 L
.07783 .59417 L
.07811 .59501 L
.07837 .59581 L
.07869 .59656 L
.07903 .59722 L
Mistroke
.07941 .59778 L
.07978 .59827 L
.08017 .59868 L
.08052 .59903 L
.08081 .59931 L
.08101 .59954 L
.08112 .59971 L
.08115 .59981 L
.08114 .59985 L
.0811 .59981 L
.08106 .59974 L
.08101 .59966 L
.08096 .59956 L
.08092 .59945 L
.08088 .59933 L
.08085 .59923 L
.08083 .59918 L
.08084 .59918 L
.08089 .59926 L
.08099 .59946 L
.08113 .59982 L
.0813 .60034 L
.08147 .60103 L
.08166 .60187 L
.08185 .60287 L
.08204 .60396 L
.08223 .60513 L
.0824 .60633 L
.08257 .60749 L
.08273 .60852 L
.08288 .60938 L
.08299 .60998 L
.08306 .61035 L
.0831 .6105 L
.08311 .61042 L
.08311 .61014 L
.08312 .6097 L
.08315 .60918 L
.0832 .60863 L
.08325 .60806 L
.0833 .60751 L
.08333 .607 L
.08334 .60661 L
.08333 .60638 L
.08332 .60628 L
.08331 .60626 L
.08331 .60629 L
.08333 .60632 L
.08336 .60632 L
.0834 .60627 L
Mistroke
.08344 .6062 L
.08346 .60615 L
.08345 .60618 L
.08341 .6063 L
.08332 .60655 L
.08319 .60695 L
.08301 .60748 L
.08276 .60809 L
.08244 .6088 L
.08205 .60961 L
.08161 .61046 L
.08116 .61132 L
.08073 .61217 L
.08032 .61297 L
.07996 .61371 L
.07964 .61435 L
.07935 .61487 L
.07912 .61527 L
.07892 .61558 L
.07876 .6158 L
.07865 .61595 L
.07859 .61608 L
.07858 .61621 L
.07861 .61637 L
.07869 .61654 L
.0788 .61672 L
.07893 .61691 L
.07907 .61712 L
.07918 .6173 L
.0793 .61751 L
.07943 .61773 L
.07955 .61789 L
.07971 .61805 L
.0799 .61816 L
.08007 .61823 L
.0802 .61828 L
.08028 .61834 L
.08031 .6184 L
.0803 .61846 L
.08029 .61849 L
.08027 .61849 L
.08026 .61847 L
.08025 .61845 L
.08024 .61843 L
.08023 .61842 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
Mistroke
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61841 L
.08023 .61837 L
.08023 .61828 L
.08024 .61816 L
.08024 .61804 L
.08024 .61797 L
.08024 .61797 L
.08024 .61809 L
.08023 .61835 L
.08022 .61876 L
.08019 .61934 L
.08017 .62008 L
.08013 .62098 L
.08009 .62202 L
.08005 .62306 L
.08001 .62414 L
.07997 .62524 L
.07993 .62636 L
.07989 .62733 L
.07986 .62816 L
.07982 .62878 L
.07978 .62918 L
.07973 .6294 L
.07968 .6295 L
.07965 .62951 L
.07964 .62952 L
.07965 .62962 L
.07969 .62988 L
.07978 .63037 L
.07992 .63112 L
.08014 .63218 L
.08042 .63364 L
Mistroke
.08079 .63535 L
.0812 .63743 L
.08167 .63991 L
.0822 .64264 L
.08279 .64589 L
.0834 .6493 L
.08402 .65256 L
.08463 .65638 L
.08521 .66054 L
.08574 .66407 L
.08624 .66809 L
.08672 .67238 L
.08718 .6758 L
.08761 .6796 L
.08802 .68304 L
.08842 .68638 L
.08878 .68918 L
.08912 .69174 L
.08941 .69388 L
.08966 .69543 L
.08989 .69673 L
.0901 .69773 L
.09032 .69847 L
.09053 .69899 L
.09074 .69939 L
.09096 .69978 L
.09116 .70024 L
.09136 .70077 L
.09154 .7014 L
.09173 .70217 L
.09194 .70307 L
.0922 .70416 L
.09249 .70536 L
.09281 .70658 L
.09312 .70782 L
.09343 .70907 L
.09372 .71025 L
.094 .71141 L
.09429 .71266 L
.09458 .71406 L
.0949 .71565 L
.0953 .71751 L
.0957 .71919 L
.09615 .72132 L
.09663 .72371 L
.09709 .72595 L
.09756 .72843 L
.09803 .73105 L
.09851 .73363 L
.099 .73645 L
Mistroke
.09948 .73851 L
.09994 .74064 L
.10034 .74252 L
.10066 .74406 L
.10089 .74525 L
.10104 .74608 L
.10116 .74662 L
.10126 .74686 L
.10135 .74694 L
.10146 .74693 L
.10157 .74683 L
.10167 .74676 L
.10177 .74672 L
.10186 .74673 L
.10193 .74679 L
.102 .74689 L
.10208 .747 L
.10218 .74712 L
.10231 .74722 L
.10246 .74733 L
.10261 .74749 L
.10275 .74769 L
.10286 .74793 L
.10294 .74817 L
.10296 .7484 L
.10293 .74855 L
.10283 .7486 L
.10269 .74855 L
.10253 .74845 L
.10232 .7483 L
.10209 .74812 L
.10185 .74795 L
.10164 .74789 L
.10146 .74787 L
.10134 .74786 L
.10129 .74787 L
.10132 .74791 L
.10144 .74802 L
.10165 .74822 L
.10197 .74853 L
.10238 .74895 L
.10284 .74943 L
.10332 .74997 L
.10379 .75043 L
.10423 .7509 L
.10464 .75125 L
.10501 .75147 L
.10533 .7516 L
.10565 .75167 L
.10599 .75168 L
Mistroke
.10637 .75165 L
.10679 .75157 L
.10725 .75147 L
.10771 .75138 L
.10821 .75129 L
.10868 .75129 L
.10915 .75132 L
.10956 .75137 L
.1099 .75147 L
.11013 .75162 L
.11022 .75182 L
.11017 .75198 L
.10999 .7521 L
.10967 .75221 L
.10925 .75233 L
.10877 .75243 L
.10825 .7525 L
.10773 .75251 L
.10726 .75249 L
.10686 .75245 L
.10657 .75247 L
.1064 .75254 L
.10635 .75267 L
.10645 .75284 L
.10667 .75313 L
.10697 .75353 L
.10735 .75401 L
.10778 .75455 L
.10826 .75511 L
.10882 .75573 L
.10927 .75624 L
.10978 .75684 L
.11024 .75745 L
.11064 .75805 L
.11096 .75858 L
.11118 .75902 L
.11129 .75934 L
.11133 .75955 L
.11133 .75968 L
.11133 .75974 L
.11148 .75968 L
.11149 .75969 L
.11155 .75972 L
.11162 .75977 L
.11171 .75984 L
.11181 .75989 L
.11192 .75993 L
.11203 .75993 L
.11213 .75993 L
.11223 .75989 L
Mistroke
.11233 .75985 L
.11243 .75984 L
.1125 .75986 L
.11252 .75987 L
.11248 .75988 L
.11236 .75985 L
.11217 .75976 L
.11194 .7596 L
.11171 .75939 L
.11149 .75919 L
.11129 .75901 L
.11115 .7589 L
.11105 .75886 L
.11098 .75889 L
.11092 .75897 L
.11087 .75909 L
.11078 .75922 L
.11067 .75935 L
.11054 .75947 L
.11042 .75956 L
.11035 .75964 L
.11036 .75977 L
.11044 .75994 L
.1106 .76012 L
.1108 .76027 L
.11102 .76036 L
.11126 .76039 L
.11155 .76041 L
.11181 .76039 L
.1121 .76037 L
.11237 .76035 L
.11262 .76032 L
.11279 .76028 L
.11285 .76019 L
.11279 .76003 L
.11264 .75984 L
.11241 .75963 L
.11213 .75939 L
.11181 .75914 L
.1115 .7589 L
.11122 .75871 L
.11101 .75865 L
.11089 .75874 L
.11089 .75902 L
.11104 .75952 L
.11134 .7602 L
.11181 .76112 L
.11243 .76203 L
.11318 .76308 L
.114 .76419 L
Mistroke
.11495 .76529 L
.116 .7664 L
.11714 .76752 L
.11833 .76862 L
.11953 .76967 L
.12069 .77062 L
.12178 .77146 L
.12276 .77216 L
.12359 .77275 L
.12427 .7732 L
.1248 .77353 L
.12515 .77377 L
.12538 .77399 L
.12546 .77424 L
.12542 .77445 L
.12528 .77465 L
.12508 .77481 L
.12481 .77492 L
.12455 .77502 L
.1243 .77512 L
.12406 .77523 L
.12385 .77535 L
.12377 .77553 L
.12379 .77575 L
.12392 .77597 L
.12411 .77616 L
.12439 .7763 L
.12473 .77639 L
.12513 .77645 L
.12558 .77647 L
.12602 .77647 L
.12647 .77646 L
.12686 .77643 L
.12722 .7764 L
.12756 .77642 L
.12789 .77647 L
.12818 .77654 L
.12843 .77658 L
.12859 .77658 L
.12865 .77652 L
.12859 .77645 L
.12845 .77637 L
.12827 .7763 L
.12809 .77623 L
.12794 .77617 L
.12781 .77612 L
.12772 .77612 L
.12767 .77621 L
.12765 .77641 L
.12765 .77669 L
Mistroke
.12766 .77703 L
.12772 .77744 L
.1278 .77791 L
.12789 .77844 L
.128 .779 L
.12811 .77952 L
.12823 .78005 L
.12834 .78054 L
.12847 .78098 L
.12863 .78138 L
.12885 .78173 L
.12917 .78201 L
.1296 .78223 L
.13017 .78242 L
.13088 .78255 L
.13166 .78263 L
.13253 .78266 L
.13341 .78269 L
.13428 .78274 L
.13509 .78281 L
.13581 .78288 L
.13638 .78294 L
.13671 .78299 L
.13701 .78303 L
.13721 .78307 L
.13728 .78309 L
.13723 .78309 L
.13706 .78305 L
.1368 .78301 L
.13649 .78297 L
.13616 .78292 L
.1358 .78285 L
.13542 .78274 L
.13503 .78261 L
.13463 .78246 L
.13425 .78234 L
.13395 .7823 L
.13376 .78238 L
.13371 .78262 L
.13381 .78302 L
.13405 .78358 L
.13443 .7843 L
.13497 .78515 L
.13557 .78609 L
.13613 .78703 L
.13687 .78799 L
.13775 .78902 L
.13869 .79003 L
.13972 .79105 L
.14082 .79209 L
Mistroke
.14197 .79315 L
.14319 .79424 L
.14447 .79536 L
.14575 .7965 L
.14707 .79768 L
.14856 .79903 L
.14979 .80018 L
.15118 .80152 L
.15249 .80282 L
.15373 .80412 L
.15482 .80535 L
.15568 .80642 L
.15633 .8073 L
.15679 .80798 L
.15705 .80847 L
.15713 .80877 L
.15705 .80892 L
.15685 .80893 L
.15655 .80881 L
.1562 .80861 L
.15585 .80836 L
.15554 .80814 L
.15535 .80801 L
.15535 .80806 L
.15559 .80834 L
.1561 .80883 L
.15691 .80961 L
.15798 .81067 L
.15938 .81202 L
.16112 .81366 L
.16317 .8156 L
.16546 .81759 L
.16797 .81978 L
.17076 .82238 L
.1735 .8248 L
.17641 .82741 L
.17935 .83008 L
.18233 .83276 L
.18523 .83549 L
.18817 .83817 L
.19115 .84094 L
.1942 .84376 L
.19732 .84669 L
.2006 .84998 L
.20366 .85281 L
.20695 .85611 L
.21033 .85946 L
.21368 .86268 L
.21698 .86591 L
.22024 .86908 L
Mistroke
.22326 .87205 L
.22615 .87484 L
.22874 .87731 L
.23109 .87954 L
.23311 .88131 L
.23483 .88274 L
.23622 .8838 L
.23741 .88453 L
.23818 .88495 L
.23881 .88518 L
.23924 .88527 L
.23948 .88524 L
.23964 .88519 L
.2397 .88509 L
.23973 .88501 L
.23976 .88498 L
.23986 .88508 L
.24003 .88529 L
.24032 .88564 L
.24076 .88612 L
.24137 .88676 L
.24214 .88749 L
.24306 .88824 L
.2441 .88899 L
.24535 .88974 L
.24673 .89047 L
.24825 .89124 L
.24985 .89199 L
.25144 .89274 L
.253 .89346 L
.2544 .89407 L
.25558 .8945 L
.25653 .89479 L
.25729 .89501 L
.25788 .89519 L
.2583 .89529 L
.25859 .89532 L
.25875 .89532 L
.25876 .89529 L
.25865 .89527 L
.25844 .89525 L
.25816 .89523 L
.25783 .89518 L
.25752 .89517 L
.25724 .89517 L
.25698 .89527 L
.25673 .89541 L
.25647 .89562 L
.25632 .89584 L
.25611 .89601 L
Mistroke
.25593 .89623 L
.25584 .89651 L
.25595 .89694 L
.25625 .89745 L
.25683 .89813 L
.25772 .89896 L
.2589 .89991 L
.26037 .90091 L
.26206 .9019 L
.26402 .90297 L
.26621 .9041 L
.26868 .90531 L
.27126 .90659 L
.27389 .90785 L
.27665 .90911 L
.27935 .91035 L
.28222 .91153 L
.28483 .9127 L
.28751 .91384 L
.29018 .91493 L
.29281 .91601 L
.29543 .91706 L
.29807 .91806 L
.30077 .91904 L
.30358 .91998 L
.30657 .92089 L
.3096 .92178 L
.31282 .92267 L
.31626 .92357 L
.31951 .92448 L
.32283 .92542 L
.3262 .92638 L
.32964 .92732 L
.3327 .92827 L
.33573 .9292 L
.33854 .93006 L
.34106 .93083 L
.3433 .93153 L
.34524 .93216 L
.34683 .93271 L
.34824 .93317 L
.34944 .93356 L
.35061 .93393 L
.35179 .9343 L
.35304 .93469 L
.35441 .93515 L
.35591 .9357 L
.35762 .93632 L
.35961 .93704 L
.36176 .93786 L
Mistroke
.36423 .93879 L
.36704 .93978 L
.37006 .94078 L
.37344 .94184 L
.37676 .9429 L
.38041 .94401 L
.38387 .94519 L
.38739 .94634 L
.39106 .9476 L
.39465 .94896 L
.39834 .95024 L
.4021 .9516 L
.40596 .95293 L
.40979 .95435 L
.41368 .95571 L
.41775 .95725 L
.42171 .95861 L
.42588 .95998 L
.42994 .96134 L
.4341 .96263 L
.43809 .9638 L
.44216 .96481 L
.44593 .96561 L
.44962 .96627 L
.45306 .96687 L
.45626 .96738 L
.45936 .96781 L
.46194 .96813 L
.46436 .96833 L
.46651 .96841 L
.46843 .96837 L
.47003 .96824 L
.47148 .96804 L
.47252 .96783 L
.47339 .96766 L
.47407 .96755 L
.47462 .96747 L
.47502 .96737 L
.47533 .96726 L
.47558 .96713 L
.47577 .96701 L
.47587 .96689 L
.4759 .96679 L
.47585 .96672 L
.47575 .9667 L
.47558 .96672 L
.4754 .96676 L
.47521 .9668 L
.47501 .96684 L
.47476 .96688 L
Mistroke
.47447 .9669 L
.47414 .96691 L
.47384 .96693 L
.47349 .96695 L
.47314 .96696 L
.47283 .96697 L
.47258 .96697 L
.47235 .96697 L
.47214 .96697 L
.47201 .96698 L
.47193 .967 L
.4719 .96703 L
.47195 .96675 L
.47207 .9668 L
.47225 .96686 L
.47249 .96691 L
.47282 .96695 L
.4732 .96698 L
.47357 .96701 L
.47387 .96703 L
.47418 .96707 L
.47445 .9671 L
.47466 .96716 L
.47484 .96723 L
.47505 .9673 L
.47528 .96739 L
.47556 .96749 L
.47589 .96756 L
.47632 .9676 L
.47686 .9676 L
.47753 .96758 L
.47833 .96753 L
.47933 .96743 L
.48051 .96728 L
.48186 .96707 L
.48336 .96681 L
.48492 .96653 L
.48659 .96625 L
.48836 .96598 L
.49029 .96574 L
.4923 .96552 L
.49462 .96532 L
.49666 .96515 L
.49906 .96498 L
.50152 .96478 L
.5042 .96456 L
.50704 .96429 L
.51014 .96399 L
.51325 .96365 L
.51633 .96327 L
Mistroke
.51937 .96287 L
.52254 .96246 L
.52553 .96203 L
.52849 .9616 L
.53145 .96119 L
.53408 .9608 L
.53675 .96044 L
.53936 .96011 L
.54193 .95978 L
.54446 .9594 L
.54697 .95894 L
.54942 .95835 L
.55186 .95765 L
.5542 .95685 L
.55642 .95606 L
.55861 .95526 L
.56061 .95454 L
.56253 .95397 L
.56431 .95347 L
.56578 .95306 L
.56703 .95275 L
.5681 .95254 L
.56904 .95247 L
.56995 .95256 L
.57096 .9528 L
.57224 .95313 L
.57357 .95351 L
.5753 .95386 L
.5773 .95412 L
.57958 .95424 L
.58223 .95418 L
.58508 .95397 L
.5882 .95368 L
.59162 .95324 L
.59497 .95273 L
.5989 .95234 L
.60247 .95176 L
.60608 .95116 L
.60962 .95052 L
.61297 .94982 L
.6162 .94913 L
.61933 .94836 L
.62235 .94752 L
.62532 .94668 L
.62823 .94585 L
.63098 .94506 L
.63357 .9443 L
.63594 .94364 L
.63806 .94298 L
.63995 .94234 L
Mistroke
.64159 .94176 L
.64309 .94129 L
.64445 .94089 L
.64572 .94054 L
.64691 .94018 L
.64802 .93984 L
.64901 .93959 L
.64981 .93945 L
.65052 .93933 L
.65112 .93928 L
.65163 .93924 L
.6521 .93914 L
.65252 .93899 L
.65286 .93885 L
.65303 .93878 L
.65299 .9388 L
.65275 .93889 L
.65234 .93911 L
.65181 .93943 L
.65123 .93979 L
.65069 .94008 L
.65025 .94038 L
.6499 .94069 L
.64962 .941 L
.64936 .94126 L
.64914 .94152 L
.64892 .94178 L
.64868 .94199 L
.6485 .94211 L
.64844 .94209 L
.64841 .94201 L
.64851 .94169 L
.64871 .9412 L
.64897 .9406 L
.64917 .94006 L
.64933 .93954 L
.64943 .939 L
.64956 .93842 L
.64968 .93798 L
.64987 .93753 L
.65008 .93717 L
.6503 .93695 L
.65044 .93692 L
.65054 .93701 L
.65058 .9372 L
.65052 .93743 L
.65038 .93779 L
.65024 .93811 L
.65016 .93834 L
.65022 .93852 L
Mistroke
.6504 .93864 L
.65069 .93868 L
.65112 .93856 L
.65159 .93842 L
.65199 .93829 L
.6523 .93812 L
.65252 .93789 L
.65263 .93779 L
.65255 .93784 L
.65233 .93806 L
.65194 .93836 L
.65141 .93882 L
.65081 .93936 L
.65026 .93984 L
.64982 .94012 L
.64951 .94027 L
.64925 .94035 L
.64906 .9404 L
.64906 .94034 L
.64919 .94026 L
.64938 .94019 L
.6497 .94007 L
.65006 .93991 L
.65039 .93978 L
.65063 .93975 L
.65075 .93977 L
.65072 .93991 L
.65059 .94013 L
.65043 .94039 L
.65023 .94066 L
.65007 .94089 L
.64996 .94099 L
.64991 .94101 L
.65001 .94083 L
.65024 .94053 L
.65055 .94016 L
.65082 .93985 L
.65112 .93951 L
.65142 .93922 L
.65177 .93895 L
.65203 .93878 L
.65229 .93864 L
.6525 .93856 L
.65268 .93855 L
.65285 .93863 L
.65307 .93875 L
.65336 .93882 L
.65367 .9389 L
.65391 .93901 L
.65402 .93919 L
Mistroke
.65402 .93939 L
.65391 .93964 L
.65373 .93988 L
.65352 .94006 L
.65336 .94014 L
.65324 .94014 L
.65316 .94007 L
.65307 .93996 L
.65301 .93978 L
.65298 .93959 L
.65293 .93945 L
.6529 .93933 L
.65293 .9392 L
.6531 .93904 L
.65341 .93886 L
.65378 .93869 L
.65422 .93852 L
.65462 .93841 L
.6549 .93837 L
.65504 .93845 L
.65505 .9386 L
.65498 .93881 L
.65483 .93906 L
.65466 .93928 L
.65449 .93945 L
.6543 .93943 L
.65412 .93953 L
.65394 .93961 L
.6538 .93964 L
.65376 .93958 L
.65375 .93951 L
.65384 .93935 L
.65399 .93913 L
.65418 .93886 L
.65431 .93867 L
.65444 .93847 L
.65455 .9383 L
.65461 .93819 L
.65454 .93819 L
.65442 .93824 L
.65426 .93829 L
.65404 .93842 L
.65371 .93865 L
.65337 .93894 L
.65309 .93925 L
.65287 .93957 L
.65265 .93999 L
.65247 .94042 L
.65236 .94082 L
.65227 .94124 L
Mistroke
.65222 .94168 L
.65223 .94215 L
.65228 .94257 L
.65231 .94295 L
.65232 .94328 L
.65232 .94349 L
.65242 .94357 L
.6526 .94352 L
.65289 .94337 L
.65335 .94302 L
.65393 .9425 L
.65455 .94193 L
.65512 .9414 L
.65568 .94081 L
.65617 .94029 L
.65657 .93986 L
.65691 .93953 L
.6572 .93927 L
.6574 .93912 L
.65753 .9391 L
.65761 .93915 L
.65771 .93921 L
.65777 .93925 L
.65779 .93929 L
.6578 .93931 L
.65788 .93924 L
.65807 .93909 L
.65841 .93892 L
.65886 .93872 L
.65945 .93851 L
.66008 .93827 L
.66076 .93802 L
.66141 .93777 L
.66204 .9375 L
.66263 .93723 L
.66318 .937 L
.66366 .93686 L
.664 .93684 L
.66412 .93693 L
.66403 .93712 L
.66378 .93739 L
.66345 .93767 L
.66308 .93789 L
.66279 .938 L
.66245 .93807 L
.66202 .9382 L
.6615 .93846 L
.66091 .93884 L
.66025 .9393 L
.65946 .94001 L
Mistroke
.65862 .9406 L
.65785 .94111 L
.65732 .94148 L
.657 .94171 L
.65683 .94178 L
.65675 .94177 L
.65665 .94172 L
.65638 .94177 L
.65623 .94171 L
.65614 .94159 L
.65624 .94134 L
.65666 .94091 L
.6573 .94039 L
.65807 .93986 L
.65882 .93935 L
.65949 .93891 L
.65987 .93865 L
.65988 .93861 L
.65962 .93869 L
.6591 .93878 L
.65845 .93888 L
.65767 .93898 L
.65695 .93904 L
.65635 .939 L
.65594 .93885 L
.65567 .93864 L
.65542 .93847 L
.65516 .93839 L
.65494 .93841 L
.65481 .93854 L
.65481 .93876 L
.65495 .93901 L
.65521 .93924 L
.6555 .93945 L
.65571 .93963 L
.65577 .93982 L
.65562 .94004 L
.65536 .94028 L
.65503 .94053 L
.65471 .94074 L
.65445 .94082 L
.65435 .94078 L
.65433 .94068 L
.65438 .94056 L
.6545 .94042 L
.65461 .94034 L
.65471 .9403 L
.65477 .94026 L
.65481 .94024 L
.65491 .94023 L
Mistroke
.65514 .9402 L
.65547 .94016 L
.65594 .94007 L
.65639 .94003 L
.65673 .94006 L
.65697 .94015 L
.65711 .94032 L
.65718 .94052 L
.65726 .94066 L
.65739 .94066 L
.65756 .94055 L
.65768 .94038 L
.65766 .94019 L
.65741 .94006 L
.65695 .93995 L
.65635 .93979 L
.65577 .93965 L
.65534 .93938 L
.65524 .93879 L
.65519 .93848 L
.65533 .93824 L
.65561 .93808 L
.65603 .938 L
.65642 .93802 L
.65679 .93811 L
.65708 .93821 L
.65729 .93833 L
.65742 .93847 L
.65742 .93867 L
.65731 .93894 L
.65704 .93927 L
.65661 .93967 L
.656 .94012 L
.65526 .94059 L
.65436 .94104 L
.65357 .94134 L
.65279 .9416 L
.65206 .94181 L
.65149 .94196 L
.65107 .94209 L
.65081 .94217 L
.65075 .94213 L
.65083 .942 L
.65111 .94176 L
.65156 .94143 L
.65215 .941 L
.65287 .94046 L
.65363 .93997 L
.65437 .93959 L
.65514 .93924 L
Mistroke
.65591 .93899 L
.65661 .93885 L
.65727 .93876 L
.65787 .93866 L
.6584 .93858 L
.65878 .93854 L
.65899 .93856 L
.65901 .93864 L
.65886 .93881 L
.65859 .93903 L
.65831 .93921 L
.65812 .9393 L
.65815 .93926 L
.65842 .9391 L
.65882 .9389 L
.65937 .93863 L
.66003 .93833 L
.6609 .93799 L
.66168 .9377 L
.66262 .93737 L
.66354 .93706 L
.66439 .9368 L
.6651 .93658 L
.66567 .93638 L
.66609 .93621 L
.66629 .93612 L
.6662 .93617 L
.66587 .93633 L
.66534 .93656 L
.66472 .93685 L
.66399 .93717 L
.66325 .93748 L
.66263 .93775 L
.66224 .93794 L
.66208 .93808 L
.66217 .93815 L
.66252 .93815 L
.66303 .93815 L
.66365 .93813 L
.66455 .938 L
.66586 .93753 L
.66717 .93728 L
.66864 .93692 L
.67024 .93644 L
.67195 .93586 L
.67371 .93518 L
.67554 .93442 L
.67739 .93359 L
.6792 .93269 L
.68087 .93171 L
Mistroke
.68249 .93065 L
.68402 .92958 L
.68543 .92844 L
.68665 .92736 L
.68765 .92642 L
.68842 .92561 L
.68896 .92495 L
.68924 .92448 L
.68928 .92424 L
.68908 .92421 L
.68867 .92436 L
.68809 .92465 L
.68746 .92505 L
.68677 .92557 L
.68608 .92623 L
.68552 .92679 L
.68505 .92736 L
.68476 .92774 L
.6847 .92788 L
.68486 .92781 L
.68515 .92755 L
.68544 .92721 L
.68574 .92685 L
.68602 .92649 L
.68628 .92617 L
.68651 .92589 L
.6867 .92561 L
.68687 .92537 L
.687 .92522 L
.68712 .92515 L
.68721 .92519 L
.68721 .92535 L
.68712 .92562 L
.687 .92601 L
.68695 .92641 L
.68701 .92675 L
.6872 .92699 L
.68749 .92714 L
.6878 .92717 L
.6881 .92717 L
.68836 .92724 L
.68851 .9274 L
.68863 .92761 L
.68876 .9278 L
.68899 .92793 L
.68942 .92791 L
.69007 .92771 L
.69097 .92735 L
.69183 .92695 L
.69285 .92646 L
Mistroke
.69387 .92592 L
.69478 .92534 L
.69576 .92477 L
.69663 .9242 L
.69739 .92361 L
.69799 .92307 L
.69838 .92262 L
.69854 .92228 L
.69842 .92209 L
.69801 .92207 L
.69731 .92225 L
.69645 .92254 L
.69561 .92285 L
.6948 .92314 L
.69429 .92326 L
.69364 .9235 L
.69302 .92372 L
.69245 .92398 L
.6919 .92431 L
.6914 .92473 L
.6909 .92524 L
.69039 .92578 L
.68988 .92628 L
.6894 .9267 L
.68891 .92708 L
.68852 .92732 L
.68812 .92754 L
.68778 .92765 L
.6875 .92771 L
.68731 .92773 L
.68723 .92774 L
.68716 .92774 L
.68712 .92772 L
.6871 .9277 L
.68705 .9277 L
.68698 .9277 L
.68682 .92781 L
.68657 .92807 L
.68625 .92843 L
.68589 .9288 L
.68548 .92915 L
.68501 .92944 L
.68446 .92966 L
.68386 .9298 L
.68322 .92985 L
.68258 .92984 L
.68202 .92983 L
.68143 .92987 L
.6809 .92998 L
.68045 .93017 L
Mistroke
.68006 .93042 L
.6797 .93074 L
.67938 .93111 L
.67913 .93153 L
.67894 .93196 L
.67878 .9324 L
.67862 .93283 L
.67843 .93327 L
.6782 .93368 L
.67793 .93405 L
.67762 .93436 L
.67733 .93459 L
.67707 .93476 L
.67686 .93486 L
.67668 .9349 L
.67659 .93489 L
.67654 .93485 L
.67652 .9348 L
.67654 .93475 L
.67658 .93474 L
.67662 .93477 L
.67665 .93484 L
.67667 .9349 L
.67667 .93492 L
.67669 .93486 L
.67669 .93472 L
.67667 .93452 L
.67661 .9343 L
.67651 .93408 L
.67636 .93386 L
.67622 .93361 L
.67615 .93333 L
.67616 .933 L
.67624 .93266 L
.67636 .93233 L
.67647 .93205 L
.67654 .93185 L
.67654 .93179 L
.67649 .93186 L
.67641 .93208 L
.67631 .93241 L
.67619 .93277 L
.67611 .93309 L
.67607 .93332 L
.67612 .93345 L
.67608 .93354 L
.676 .9336 L
.67586 .93369 L
.67568 .93381 L
.67547 .93395 L
Mistroke
.6753 .93406 L
.6752 .93412 L
.67521 .93411 L
.67527 .93407 L
.67534 .93405 L
.67536 .93412 L
.67536 .93426 L
.67535 .93444 L
.67537 .93459 L
.6754 .9347 L
.67545 .93475 L
.67549 .93473 L
.67549 .93464 L
.67549 .93448 L
.67547 .9343 L
.67541 .93414 L
.67529 .93407 L
.67515 .93411 L
.67504 .93422 L
.67498 .93435 L
.67494 .93452 L
.67494 .93469 L
.67496 .93482 L
.67498 .93489 L
.67497 .93487 L
.67489 .93475 L
.67471 .93453 L
.67441 .93428 L
.67402 .93396 L
.6736 .93357 L
.67317 .93313 L
.67267 .93267 L
.67215 .93226 L
.67167 .9319 L
.67132 .93158 L
.67108 .93129 L
.67092 .93105 L
.6708 .93088 L
.67068 .93085 L
.67048 .93094 L
.67022 .93111 L
.66989 .9313 L
.66951 .93148 L
.66906 .93162 L
.66858 .93172 L
.66814 .93181 L
.66783 .93189 L
.66757 .93195 L
.66737 .93199 L
.66726 .93203 L
Mistroke
.66721 .9321 L
.66727 .93214 L
.66741 .93215 L
.66757 .93221 L
.66763 .93238 L
.66757 .93267 L
.66733 .93305 L
.66696 .93345 L
.66646 .93388 L
.66589 .93433 L
.66515 .93476 L
.66457 .93507 L
.66399 .93529 L
.66341 .93546 L
.66282 .93553 L
.66231 .93553 L
.66188 .93551 L
.66148 .93539 L
.66125 .93558 L
.66102 .93535 L
.66088 .93505 L
.66072 .93473 L
.66038 .93439 L
.65997 .93412 L
.65955 .93392 L
.65908 .93373 L
.65866 .9336 L
.65832 .93346 L
.65824 .93343 L
.65835 .93344 L
.6587 .93353 L
.65924 .9337 L
.6599 .9339 L
.66057 .93409 L
.66125 .93426 L
.66193 .93437 L
.66271 .93443 L
.66352 .93442 L
.66433 .93438 L
.66508 .93432 L
.66576 .93421 L
.66634 .93398 L
.66684 .93363 L
.66729 .93322 L
.66769 .93279 L
.66807 .9324 L
.66851 .93208 L
.66909 .93188 L
.66985 .93179 L
.67071 .93177 L
Mistroke
.67163 .93179 L
.67273 .93177 L
.67398 .93167 L
.67538 .93147 L
.67688 .93117 L
.67848 .93081 L
.68014 .93036 L
.68186 .92986 L
.68359 .92931 L
.68533 .92871 L
.68709 .92807 L
.68869 .92734 L
.69041 .92652 L
.69213 .92561 L
.69393 .92461 L
.69577 .92352 L
.69764 .9223 L
.69954 .92095 L
.70148 .91945 L
.70346 .91778 L
.70546 .91602 L
.70746 .91416 L
.70946 .91223 L
.71144 .91028 L
.71342 .90834 L
.71557 .90615 L
.71726 .90448 L
.71893 .90269 L
.72039 .90114 L
.72161 .89984 L
.72259 .89884 L
.72335 .89816 L
.7239 .89776 L
.72425 .89757 L
.72443 .89753 L
.72448 .8976 L
.72441 .89773 L
.72423 .89788 L
.72397 .89799 L
.72368 .898 L
.72336 .89789 L
.72304 .89765 L
.72275 .8973 L
.72247 .89683 L
.72222 .89622 L
.72198 .89553 L
.72173 .89488 L
.72146 .89434 L
.72114 .89391 L
.72078 .89366 L
Mistroke
.72042 .89361 L
.72009 .89379 L
.71981 .89419 L
.71959 .89457 L
.71941 .8953 L
.71923 .8961 L
.71902 .89716 L
.71874 .89815 L
.71836 .89915 L
.71784 .90035 L
.71721 .90142 L
.71643 .90254 L
.7155 .90371 L
.71446 .90474 L
.71326 .90579 L
.71191 .90676 L
.71051 .90765 L
.70897 .9085 L
.70744 .90935 L
.70583 .91022 L
.70429 .91107 L
.70279 .91198 L
.70133 .91298 L
.69987 .9141 L
.69834 .91534 L
.69678 .91665 L
.69513 .91802 L
.69334 .91939 L
.69159 .92087 L
.68969 .92242 L
.68765 .92405 L
.68554 .92568 L
.68344 .92719 L
.68134 .92859 L
.6793 .92982 L
.67746 .93086 L
.67572 .93171 L
.67418 .93233 L
.67286 .93277 L
.67184 .9331 L
.67088 .93342 L
.67005 .93372 L
.66925 .93399 L
.66837 .93432 L
.66739 .93472 L
.6663 .9352 L
.66495 .93569 L
.66326 .93626 L
.6612 .93693 L
.65894 .93769 L
Mistroke
.65598 .9386 L
.65306 .93953 L
.64948 .94054 L
.64585 .94153 L
.6418 .94247 L
.63809 .94341 L
.63415 .94435 L
.63044 .94522 L
.6265 .94603 L
.62301 .94676 L
.61935 .94748 L
.61592 .94809 L
.6128 .94863 L
.60952 .94904 L
.60637 .94932 L
.60325 .94944 L
.60011 .94954 L
.59719 .94964 L
.59405 .94975 L
.59111 .94983 L
.5879 .94995 L
.58464 .95017 L
.58097 .9505 L
.57748 .95091 L
.5737 .9514 L
.56945 .95196 L
.56576 .95256 L
.56162 .9533 L
.55779 .95413 L
.55372 .95501 L
.54998 .95582 L
.54616 .95654 L
.54233 .95714 L
.53887 .9576 L
.53545 .95797 L
.53219 .95823 L
.5292 .95845 L
.52645 .95867 L
.52404 .95896 L
.52211 .95934 L
.52016 .95975 L
.51855 .96019 L
.51704 .96063 L
.51571 .96103 L
.51459 .96138 L
.51368 .96168 L
.51301 .96187 L
.51253 .96192 L
.51222 .96187 L
.51206 .96173 L
Mistroke
.512 .9615 L
.51195 .96118 L
.51185 .96074 L
.5117 .96024 L
.51149 .95971 L
.51123 .95921 L
.51094 .95882 L
.51063 .95859 L
.51033 .95852 L
.51002 .95861 L
.50971 .95881 L
.50939 .95906 L
.50909 .95933 L
.50875 .95956 L
.50843 .95975 L
.50814 .9599 L
.50784 .96004 L
.50752 .96014 L
.50722 .96019 L
.50688 .96019 L
.50645 .96016 L
.50588 .96008 L
.50517 .95995 L
.50437 .95977 L
.5034 .95955 L
.50229 .95929 L
.50111 .959 L
.4999 .95869 L
.49874 .95835 L
.49762 .95801 L
.49655 .95764 L
.49569 .95732 L
.49489 .95701 L
.49424 .95668 L
.4938 .95636 L
.49359 .9561 L
.49363 .95595 L
.49388 .95592 L
.49428 .95595 L
.4948 .95605 L
.49533 .95619 L
.49578 .95635 L
.49609 .9565 L
.49625 .95655 L
.49628 .95659 L
.49624 .95667 L
.49613 .95677 L
.49597 .95689 L
.49578 .95704 L
.49553 .95718 L
Mistroke
.49528 .95731 L
.4951 .95742 L
.49504 .95749 L
.4951 .95754 L
.4953 .95753 L
.49564 .95749 L
.49609 .95743 L
.4965 .9574 L
.49695 .95735 L
.49735 .95716 L
.49765 .95697 L
.4978 .95666 L
.49783 .95634 L
.49781 .95606 L
.49782 .95586 L
.4978 .95576 L
.49779 .95578 L
.4978 .95592 L
.49781 .9561 L
.49776 .95631 L
.49765 .95653 L
.49755 .95672 L
.4975 .95696 L
.49749 .95722 L
.49751 .9575 L
.49756 .95782 L
.49757 .95813 L
.49751 .95837 L
.49733 .95847 L
.49709 .95848 L
.4969 .95842 L
.4968 .95836 L
.49682 .95827 L
.497 .95819 L
.49732 .95818 L
.49775 .95825 L
.49817 .95832 L
.4985 .95844 L
.49853 .95865 L
.49818 .95892 L
.49744 .95924 L
.4964 .95968 L
.49502 .96022 L
.49344 .96084 L
.49156 .96137 L
.48951 .9619 L
.48741 .96245 L
.48504 .96298 L
.48234 .96336 L
.47988 .9637 L
Mistroke
.47752 .96401 L
.47529 .96431 L
.47335 .96463 L
.47179 .96497 L
.47064 .96536 L
.46972 .96569 L
.46896 .96596 L
.46829 .96613 L
.46766 .96618 L
.467 .9661 L
.46627 .96588 L
.46544 .96554 L
.46464 .96509 L
.46373 .96454 L
.46277 .96392 L
.46171 .96325 L
.46057 .96257 L
.45927 .9619 L
.45783 .96124 L
.45627 .96056 L
.45474 .95999 L
.45316 .95944 L
.45168 .95898 L
.45033 .95869 L
.44914 .95856 L
.44806 .95856 L
.44703 .95859 L
.44593 .95859 L
.44477 .95851 L
.44346 .95836 L
.44185 .95814 L
.44027 .95788 L
.43843 .95756 L
.4363 .9572 L
.43394 .95671 L
.4316 .95613 L
.42907 .95546 L
.42626 .95467 L
.42289 .95388 L
.41986 .95301 L
.41636 .95201 L
.41291 .95109 L
.4092 .95012 L
.40526 .94917 L
.40175 .9482 L
.39779 .94725 L
.39402 .94621 L
.38991 .94508 L
.38574 .94384 L
.38198 .94258 L
Mistroke
.37798 .94123 L
.37405 .93983 L
.36999 .93846 L
.3664 .93707 L
.36266 .93567 L
.35895 .93432 L
.35535 .93297 L
.35181 .93164 L
.34811 .9303 L
.34452 .92899 L
.34113 .9277 L
.33751 .92642 L
.33396 .92519 L
.33016 .92401 L
.32675 .92289 L
.32316 .92181 L
.31946 .92078 L
.31611 .91981 L
.31286 .91887 L
.30948 .91793 L
.30623 .91697 L
.30289 .916 L
.29969 .91499 L
.29639 .91391 L
.29311 .91275 L
.29022 .91151 L
.28712 .91019 L
.28418 .90891 L
.2812 .90758 L
.27837 .90625 L
.27567 .90496 L
.27293 .90366 L
.27039 .9024 L
.26783 .90114 L
.26554 .89991 L
.26334 .89873 L
.26132 .8976 L
.25954 .89653 L
.25799 .89551 L
.25671 .89461 L
.25569 .89374 L
.25489 .89297 L
.25434 .89229 L
.254 .89176 L
.25383 .89132 L
.25374 .89093 L
.25367 .89062 L
.25351 .89031 L
.2532 .89001 L
.25268 .88966 L
Mistroke
.25194 .88927 L
.25088 .88864 L
.24946 .88775 L
.24763 .88656 L
.24546 .88512 L
.243 .88338 L
.24014 .88129 L
.23704 .87902 L
.23376 .87653 L
.23027 .87381 L
.2269 .87114 L
.22342 .8683 L
.22008 .86542 L
.21679 .86285 L
.21358 .86012 L
.21055 .8574 L
.20758 .85473 L
.20474 .85206 L
.20196 .84957 L
.19926 .84703 L
.19661 .84461 L
.19399 .84214 L
.19131 .83957 L
.18869 .83705 L
.18614 .83462 L
.18368 .83211 L
.18136 .82966 L
.17913 .8274 L
.17715 .82522 L
.17523 .82317 L
.17373 .82137 L
.17241 .81968 L
.1713 .81812 L
.17041 .81678 L
.16965 .81557 L
.16899 .81445 L
.1683 .81341 L
.16751 .81241 L
.16656 .81136 L
.16536 .81023 L
.16393 .80896 L
.16216 .80748 L
.16001 .80574 L
.15801 .8039 L
.15564 .80181 L
.1529 .79964 L
.15054 .79742 L
.1479 .79504 L
.1451 .79254 L
.1427 .79025 L
Mistroke
.14006 .7878 L
.13736 .78523 L
.13506 .78269 L
.13267 .78019 L
.13026 .77767 L
.12824 .77542 L
.12613 .77314 L
.12404 .77092 L
.12207 .76876 L
.12011 .76666 L
.11823 .76457 L
.11656 .7628 L
.11496 .76114 L
.1135 .75962 L
.11222 .75828 L
.11123 .75716 L
.11031 .75617 L
.10955 .75527 L
.10885 .75432 L
.10818 .75328 L
.10753 .75212 L
.1069 .75084 L
.10629 .74943 L
.10574 .74804 L
.10529 .74654 L
.10489 .74508 L
.10456 .74373 L
.10426 .74248 L
.10396 .74115 L
.10367 .73995 L
.10338 .73877 L
.1031 .7376 L
.1028 .73643 L
.10246 .7352 L
.10207 .73388 L
.10161 .73234 L
.10108 .73055 L
.10045 .7285 L
.09977 .72653 L
.09902 .72416 L
.0982 .7216 L
.09736 .71881 L
.09655 .71582 L
.09579 .71293 L
.09512 .71009 L
.09458 .70718 L
.09418 .70455 L
.09391 .70214 L
.09373 .69981 L
.0936 .69762 L
Mistroke
.09346 .69557 L
.0933 .69362 L
.0931 .6917 L
.09286 .68989 L
.09259 .68807 L
.09229 .68624 L
.09195 .68437 L
.09158 .68252 L
.09113 .68046 L
.09059 .67826 L
.08999 .67574 L
.0893 .6732 L
.08854 .67028 L
.08772 .66715 L
.08688 .66387 L
.08604 .66055 L
.08526 .6568 L
.08457 .65346 L
.08395 .64997 L
.08338 .64637 L
.08288 .6434 L
.08242 .64044 L
.08202 .63778 L
.08169 .63552 L
.08141 .63355 L
.0812 .63208 L
.08104 .63096 L
.08095 .63017 L
.08091 .62965 L
.08096 .62938 L
.08098 .62927 L
.08103 .62929 L
.08107 .62939 L
.08111 .6295 L
.08113 .62958 L
.08116 .62958 L
.08121 .62944 L
.08127 .62912 L
.08132 .62862 L
.08133 .62793 L
.08128 .62698 L
.08115 .62587 L
.08092 .62442 L
.08057 .62268 L
.08023 .62055 L
.0798 .61817 L
.07933 .61534 L
.07886 .61243 L
.07837 .60907 L
.07787 .60556 L
Mistroke
.07735 .60182 L
.07681 .59785 L
.07625 .59382 L
.07565 .59008 L
.07504 .58617 L
.07446 .58241 L
.07392 .57927 L
.07342 .5764 L
.07297 .57396 L
.07258 .57186 L
.07226 .57037 L
.07201 .56924 L
.07184 .56847 L
.07174 .56799 L
.07169 .56772 L
.07169 .56754 L
.07169 .56727 L
.07168 .56684 L
.07162 .56623 L
.07149 .56548 L
.07129 .56435 L
.071 .56288 L
.07064 .56087 L
.07023 .55848 L
.06981 .55591 L
.0694 .55292 L
.06902 .55001 L
.06871 .54637 L
.06848 .5433 L
.06832 .54 L
.06827 .53645 L
.06832 .53285 L
.06849 .5289 L
.06876 .52537 L
.06916 .52166 L
.06961 .51803 L
.07013 .51457 L
.07072 .51139 L
.07126 .50837 L
.07183 .50584 L
.07235 .50355 L
.07281 .50163 L
.07321 .50017 L
.07355 .49906 L
.07384 .49828 L
.07409 .49782 L
.07431 .4976 L
.07448 .49755 L
Mfstroke
.07141 .50908 m
.07125 .50922 L
.07104 .50959 L
.07078 .51028 L
.07048 .51135 L
.07015 .51286 L
.06979 .51474 L
.0694 .51695 L
.069 .51973 L
.06859 .52305 L
.0682 .52595 L
.06786 .5298 L
.0676 .53341 L
.06745 .53746 L
.0674 .5415 L
.06747 .54553 L
.06763 .5492 L
.06788 .553 L
.06822 .55666 L
.06861 .55995 L
.06909 .56314 L
.06964 .56624 L
.07026 .56931 L
.07091 .57214 L
.07159 .57522 L
.0723 .57806 L
.07296 .58122 L
.07362 .58431 L
.07426 .58786 L
.07488 .59122 L
.07545 .59445 L
.076 .59842 L
.07651 .602 L
.07697 .60644 L
.0774 .61002 L
.07783 .6144 L
.07826 .6187 L
.0787 .62267 L
.07915 .62689 L
.07966 .63113 L
.08024 .63541 L
.08089 .63972 L
.0816 .64397 L
.08226 .6482 L
.08301 .65255 L
.08373 .65715 L
.08447 .66125 L
.08519 .66594 L
.08587 .66974 L
.08652 .6742 L
Mistroke
.08715 .67801 L
.08769 .68186 L
.08818 .68515 L
.0886 .68817 L
.08895 .6911 L
.08925 .69364 L
.08952 .69595 L
.08977 .69798 L
.09003 .6996 L
.0903 .70103 L
.09059 .70224 L
.0909 .70323 L
.09122 .70408 L
.09153 .70469 L
.09183 .70528 L
.09209 .70577 L
.0923 .7061 L
.09249 .70626 L
.09267 .70627 L
.09284 .70614 L
.09299 .70596 L
.0931 .70577 L
.09317 .70561 L
.09319 .70553 L
.09317 .7056 L
.09312 .70585 L
.09306 .70631 L
.093 .70698 L
.09298 .70784 L
.09302 .70892 L
.09312 .71021 L
.0933 .71175 L
.09359 .71365 L
.09402 .71593 L
.09455 .71853 L
.09519 .72121 L
.09592 .72423 L
.09674 .72738 L
.09757 .73046 L
.09842 .73368 L
.09925 .73642 L
.1 .7391 L
.10072 .74171 L
.10131 .74373 L
.10187 .74557 L
.10225 .74716 L
.10258 .7484 L
.1028 .74925 L
.10292 .74974 L
.10295 .74995 L
Mistroke
.10291 .74995 L
.10286 .74982 L
.1028 .7496 L
.10275 .74945 L
.10272 .74938 L
.10272 .74945 L
.10275 .74967 L
.10277 .7499 L
.10277 .75013 L
.10272 .75029 L
.10263 .75036 L
.10253 .75035 L
.10241 .75029 L
.10229 .75022 L
.10218 .75018 L
.1021 .75018 L
.10204 .75025 L
.102 .75037 L
.10199 .75052 L
.10199 .75072 L
.102 .75095 L
.10205 .75122 L
.10213 .7515 L
.10223 .75183 L
.10234 .7522 L
.10247 .75258 L
.10258 .75297 L
.10266 .75331 L
.10272 .75353 L
.10273 .75363 L
.10271 .75364 L
.10267 .75359 L
.10264 .75352 L
.10263 .75341 L
.10263 .75326 L
.10264 .7531 L
.10264 .75291 L
.10264 .75271 L
.10265 .7525 L
.10265 .75232 L
.10265 .75217 L
.10265 .75207 L
.10266 .75201 L
.10266 .752 L
.10265 .75202 L
.10265 .75209 L
.10265 .75219 L
.10265 .75237 L
.10264 .75259 L
.10264 .75283 L
Mistroke
.10263 .75307 L
.10263 .7533 L
.10262 .7535 L
.1026 .75365 L
.10256 .75374 L
.10249 .75371 L
.10237 .75355 L
.10224 .75331 L
.10213 .75306 L
.10207 .75286 L
.10208 .75276 L
.10222 .75282 L
.10255 .75309 L
.10309 .75363 L
.10387 .75446 L
.10491 .75562 L
.1061 .75709 L
.10765 .75886 L
.10928 .76066 L
.11123 .76288 L
.11329 .76523 L
.11555 .7678 L
.1181 .77043 L
.12056 .77318 L
.12299 .7757 L
.12546 .7783 L
.1279 .78083 L
.13033 .78321 L
.13281 .78566 L
.13527 .78799 L
.13794 .79046 L
.1405 .79291 L
.14329 .79554 L
.14612 .79808 L
.14897 .80087 L
.15184 .80351 L
.15482 .80639 L
.15782 .80923 L
.16092 .81222 L
.16378 .81503 L
.16678 .81808 L
.16984 .82094 L
.17281 .82391 L
.17586 .8268 L
.17901 .82991 L
.18199 .83273 L
.1853 .83587 L
.18853 .8392 L
.19195 .84234 L
.19552 .84576 L
Mistroke
.19943 .84947 L
.20307 .85275 L
.20682 .85626 L
.21074 .85999 L
.21449 .86336 L
.21837 .86683 L
.22202 .8707 L
.22571 .87384 L
.22917 .87713 L
.23245 .8804 L
.23554 .88334 L
.23847 .88619 L
.241 .88849 L
.24336 .8906 L
.24531 .89224 L
.24703 .89359 L
.24845 .89463 L
.2496 .89539 L
.25049 .89587 L
.25114 .89609 L
.25156 .89609 L
.25181 .8959 L
.25193 .89556 L
.25193 .89513 L
.25186 .89471 L
.25176 .89434 L
.25167 .89408 L
.25158 .8939 L
.2515 .8938 L
.25145 .89376 L
.25143 .8938 L
.25142 .89387 L
.25142 .89392 L
.2514 .89393 L
.25135 .89391 L
.2513 .8939 L
.25124 .89387 L
.2512 .89384 L
.25117 .89382 L
.25118 .89382 L
.25127 .89386 L
.25146 .89395 L
.25175 .89411 L
.25215 .89434 L
.25268 .89465 L
.25333 .89501 L
.25403 .89541 L
.25474 .8958 L
.25547 .89619 L
.25617 .89656 L
Mistroke
.25686 .89692 L
.25747 .89725 L
.25801 .89753 L
.25846 .89776 L
.25881 .89793 L
.25906 .89805 L
.25922 .89812 L
.2593 .89814 L
.25929 .89813 L
.25925 .8981 L
.25919 .89807 L
.25914 .89806 L
.25912 .89808 L
.25913 .89812 L
.25914 .89816 L
.25915 .8982 L
.25914 .89825 L
.25911 .8983 L
.25908 .89837 L
.25904 .89843 L
.25903 .89846 L
.25904 .89844 L
.25908 .89834 L
.25913 .89817 L
.2592 .89792 L
.25927 .89759 L
.25935 .8972 L
.25942 .89675 L
.25949 .89628 L
.25953 .89578 L
.25957 .89531 L
.2596 .89483 L
.25966 .8943 L
.25974 .89391 L
.25984 .89355 L
.25993 .8933 L
.25997 .89315 L
.25995 .89313 L
.25987 .89319 L
.25966 .89335 L
.25953 .89351 L
.25937 .89371 L
.25921 .89397 L
.25906 .89429 L
.25896 .89471 L
.2589 .8952 L
.25895 .8958 L
.25916 .89649 L
.25952 .89725 L
.26017 .89816 L
Mistroke
.26111 .89919 L
.26243 .90036 L
.26419 .90165 L
.26647 .90311 L
.26912 .90469 L
.27223 .90638 L
.27572 .9081 L
.27961 .90989 L
.28376 .91167 L
.2881 .91346 L
.29294 .91524 L
.29777 .91705 L
.30286 .91883 L
.30825 .92064 L
.31339 .9224 L
.31875 .9242 L
.32402 .92597 L
.32933 .92772 L
.33439 .92949 L
.33904 .93125 L
.34355 .93298 L
.34753 .93461 L
.35119 .93614 L
.35482 .93744 L
.3578 .93862 L
.36042 .93959 L
.3629 .94042 L
.36524 .94114 L
.36746 .94176 L
.36957 .9423 L
.37146 .94279 L
.37346 .94326 L
.3756 .94373 L
.37782 .94422 L
.38008 .94474 L
.38238 .94529 L
.38469 .94591 L
.38691 .94657 L
.38884 .94726 L
.39051 .94785 L
.3919 .94842 L
.39301 .94892 L
.3939 .94932 L
.39451 .9496 L
.39491 .94977 L
.3951 .94981 L
.39511 .94973 L
.39504 .94962 L
.39492 .94947 L
.39477 .94926 L
Mistroke
.3947 .94901 L
.39476 .94878 L
.39495 .94855 L
.39521 .9483 L
.39556 .94801 L
.39597 .94771 L
.39638 .94736 L
.39678 .94703 L
.39715 .94667 L
.39751 .94634 L
.39782 .946 L
.39803 .94569 L
.39814 .94542 L
.39813 .94529 L
.39795 .94508 L
.3976 .94487 L
.39712 .94467 L
.39664 .94456 L
.39614 .94458 L
.39566 .94469 L
.39522 .9449 L
.39487 .94519 L
.39455 .94545 L
.39427 .94573 L
.39403 .94597 L
.39382 .94614 L
.39358 .94624 L
.39331 .94629 L
.39306 .94637 L
.39289 .94648 L
.3928 .94659 L
.39282 .94671 L
.39305 .94688 L
.39353 .94717 L
.39433 .94762 L
.3955 .94824 L
.39708 .94904 L
.39918 .95001 L
.40186 .95114 L
.40469 .9524 L
.40827 .9538 L
.41221 .95529 L
.4167 .95676 L
.42162 .95833 L
.42624 .9598 L
.43109 .96123 L
.43619 .96257 L
.44068 .96378 L
.44519 .96484 L
.44911 .96576 L
Mistroke
.45276 .96651 L
.4562 .96712 L
.45876 .96759 L
.46102 .96795 L
.46297 .96821 L
.46459 .9684 L
.46591 .96852 L
.46707 .96855 L
.46797 .96849 L
.46876 .96835 L
.46954 .96819 L
.4703 .96802 L
.47102 .96786 L
.47171 .96771 L
.47238 .96758 L
.47306 .96744 L
.4737 .96729 L
.47431 .96716 L
.47491 .96705 L
.47555 .967 L
.47623 .96698 L
.47704 .96696 L
.47801 .9669 L
.47923 .96681 L
.48065 .96662 L
.48216 .9663 L
.48399 .96583 L
.48607 .96524 L
.48836 .96457 L
.49075 .96386 L
.49311 .96314 L
.49536 .9624 L
.49745 .96178 L
.49921 .96119 L
.50064 .96066 L
.50167 .96015 L
.50241 .95971 L
.50284 .95934 L
.50307 .95912 L
.50325 .959 L
.50345 .95897 L
.50371 .95902 L
.50414 .95914 L
.5048 .95935 L
.50582 .95964 L
.50712 .95996 L
.50889 .96034 L
.51084 .96074 L
.51322 .96112 L
.51621 .96159 L
Mistroke
.51915 .96196 L
.52243 .96224 L
.52588 .96238 L
.52941 .96237 L
.53313 .96224 L
.53676 .962 L
.54057 .96159 L
.54439 .96101 L
.54832 .9603 L
.5524 .95951 L
.55669 .95867 L
.56105 .95781 L
.56552 .95701 L
.57004 .95632 L
.57449 .95572 L
.57883 .9552 L
.58311 .95475 L
.58732 .95436 L
.59149 .95398 L
.59543 .95361 L
.59943 .95325 L
.60314 .95287 L
.60679 .95247 L
.61047 .952 L
.61406 .95145 L
.61761 .9508 L
.6212 .95002 L
.6246 .9491 L
.62791 .94809 L
.63109 .94702 L
.63408 .94594 L
.63696 .94483 L
.63958 .94382 L
.64193 .9429 L
.64393 .94214 L
.64555 .94151 L
.64674 .94107 L
.64761 .94081 L
.64821 .94073 L
.64856 .9408 L
.64884 .94085 L
.64911 .94095 L
.64939 .94103 L
.64974 .94103 L
.65014 .94094 L
.65051 .94084 L
.65101 .9406 L
.65145 .94028 L
.65202 .93976 L
.65265 .93911 L
Mistroke
.65331 .93837 L
.654 .93758 L
.65468 .93678 L
.65538 .93599 L
.65606 .93521 L
.65664 .93451 L
.65709 .93386 L
.65733 .93343 L
.65755 .93306 L
.65774 .93281 L
.658 .93263 L
.65826 .93263 L
.65861 .93273 L
.65899 .93295 L
.65941 .93325 L
.65987 .93358 L
.66034 .93389 L
.66082 .93417 L
.66138 .93444 L
.66206 .93473 L
.6629 .93499 L
.66385 .93517 L
.66486 .93527 L
.66586 .9353 L
.66685 .93527 L
.66778 .93519 L
.66864 .93508 L
.66937 .93497 L
.67 .93492 L
.67046 .93493 L
.67091 .935 L
.67133 .93511 L
.6717 .93523 L
.67197 .93531 L
.67217 .93536 L
.67231 .93537 L
.67241 .93535 L
.67247 .93534 L
.6725 .93534 L
.67252 .93536 L
.67253 .93538 L
.67247 .93539 L
.67244 .93539 L
.67245 .93536 L
.67241 .93531 L
.6724 .93527 L
.67248 .93525 L
.67269 .93526 L
.67295 .93528 L
.67328 .9353 L
Mistroke
.67366 .93529 L
.67414 .93522 L
.67467 .93509 L
.67527 .93489 L
.67593 .93463 L
.6767 .93431 L
.67757 .93393 L
.67854 .93347 L
.67961 .93294 L
.68079 .9323 L
.68205 .93156 L
.68339 .9307 L
.68494 .92971 L
.68666 .9286 L
.68859 .92737 L
.69072 .92603 L
.69309 .92464 L
.69558 .92311 L
.69824 .92155 L
.70102 .91993 L
.70364 .91829 L
.70632 .91661 L
.70905 .91488 L
.71186 .91312 L
.71459 .91144 L
.71726 .90975 L
.71992 .90808 L
.72256 .90639 L
.7251 .90477 L
.72746 .90321 L
.72932 .90194 L
.73122 .90064 L
.73297 .89949 L
.73451 .89845 L
.73591 .8975 L
.73712 .89666 L
.73813 .89593 L
.73897 .8953 L
.73966 .89475 L
.74023 .89425 L
.74073 .89378 L
.74122 .8933 L
.74177 .89274 L
.74238 .8921 L
.74303 .89137 L
.74371 .89057 L
.7444 .88974 L
.74505 .88893 L
.74563 .88815 L
.74615 .88745 L
Mistroke
.74655 .88684 L
.74683 .88634 L
.74696 .88595 L
.74697 .88566 L
.74687 .88547 L
.7467 .88536 L
.74649 .88533 L
.74633 .88535 L
.74622 .88543 L
.7462 .88555 L
.74634 .88565 L
.74669 .8857 L
.74724 .88567 L
.74796 .88557 L
.74892 .88537 L
.75009 .88506 L
.75147 .88459 L
.75304 .88394 L
.75481 .88313 L
.75672 .88217 L
.75878 .88108 L
.76091 .87988 L
.76314 .87858 L
.76545 .87715 L
.76785 .87561 L
.77021 .87396 L
.77261 .87222 L
.77503 .87044 L
.77745 .86863 L
.77973 .86684 L
.78192 .86513 L
.78391 .86362 L
.78563 .86222 L
.78705 .86102 L
.78815 .86001 L
.78896 .85922 L
.78949 .85862 L
.7898 .8582 L
.78995 .85792 L
.79003 .85772 L
.79001 .85757 L
.78993 .85737 L
.7899 .85704 L
.78996 .85652 L
.79011 .85576 L
.79042 .85474 L
.79088 .85347 L
.7915 .85208 L
.7922 .85053 L
.7929 .84899 L
Mistroke
.7935 .84752 L
.79394 .84627 L
.79419 .84536 L
.79426 .84482 L
.7942 .84469 L
.7941 .84493 L
.79401 .84543 L
.79407 .84605 L
.79436 .84676 L
.79484 .84724 L
.79558 .84774 L
.79657 .8481 L
.79779 .84822 L
.79933 .84809 L
.80117 .84765 L
.80328 .8468 L
.80571 .84553 L
.80829 .84397 L
.81103 .84208 L
.81381 .83998 L
.81662 .83764 L
.81948 .83525 L
.82226 .83289 L
.82515 .83044 L
.82802 .82801 L
.83096 .82561 L
.83384 .8233 L
.83663 .82101 L
.83932 .81887 L
.84185 .81687 L
.84424 .81504 L
.8465 .81333 L
.84849 .81178 L
.85041 .81029 L
.85224 .80875 L
.85416 .8071 L
.85591 .80529 L
.85731 .80356 L
.85884 .80156 L
.86016 .79959 L
.86162 .79733 L
.86277 .7953 L
.86402 .79313 L
.86526 .79089 L
.86644 .78859 L
.86752 .78624 L
.86846 .78391 L
.86926 .78159 L
.86994 .77908 L
.87038 .77694 L
Mistroke
.87077 .77472 L
.87109 .7728 L
.87137 .77096 L
.87155 .7693 L
.87167 .76789 L
.87174 .76671 L
.87175 .76571 L
.87174 .76492 L
.87173 .76428 L
.87173 .76378 L
.87176 .7635 L
.87188 .76337 L
.87213 .76326 L
.87254 .763 L
.87309 .76243 L
.8738 .76153 L
.87466 .76024 L
.87566 .75857 L
.87681 .75652 L
.87806 .75416 L
.87939 .75148 L
.88075 .74864 L
.88211 .74555 L
.88344 .74234 L
.88474 .73893 L
.88598 .73549 L
.88715 .73196 L
.88822 .72844 L
.88919 .725 L
.89007 .7218 L
.89083 .71877 L
.89147 .71612 L
.89195 .71378 L
.89231 .71179 L
.89258 .7101 L
.89279 .70872 L
.89297 .70758 L
.89316 .70671 L
.89338 .70599 L
.89361 .70544 L
.89389 .70489 L
.89425 .70429 L
.89471 .7035 L
.89521 .70271 L
.89579 .70159 L
.89653 .70009 L
.89712 .69858 L
.89769 .6969 L
.89821 .69499 L
.89864 .6929 L
Mistroke
.89898 .69068 L
.89921 .68847 L
.89931 .68642 L
.8993 .68452 L
.8992 .68289 L
.89902 .68161 L
.89884 .68066 L
.89871 .67998 L
.89865 .67956 L
.89864 .6794 L
.89868 .67945 L
.89875 .67964 L
.89879 .67999 L
.89879 .68049 L
.89871 .68116 L
.89852 .68193 L
.89821 .68275 L
.89779 .68349 L
.89725 .68407 L
.89665 .68447 L
.89594 .68472 L
.89506 .68489 L
.89403 .68502 L
.89287 .68514 L
.89153 .68531 L
.89011 .68544 L
.88868 .68544 L
.88726 .68529 L
.88593 .68504 L
.88482 .6847 L
.88381 .68433 L
.88286 .68401 L
.88199 .68374 L
.88127 .68352 L
.8808 .68332 L
.88045 .68316 L
.88024 .68306 L
.88019 .68306 L
.88027 .6832 L
.88044 .68354 L
.88064 .68418 L
.88084 .68519 L
.881 .6866 L
.88113 .68844 L
.88125 .69071 L
.88132 .6932 L
.88131 .69608 L
.88126 .6991 L
.88121 .70238 L
.88118 .70535 L
Mistroke
.88115 .7083 L
.88114 .71114 L
.88113 .71367 L
.88111 .71582 L
.8811 .71767 L
.88108 .71917 L
.88107 .72029 L
.88105 .7211 L
.88103 .72168 L
.88101 .72204 L
.88099 .72224 L
.88098 .72232 L
.88097 .72234 L
.88099 .72231 L
.88103 .72225 L
.88108 .72223 L
.88112 .72227 L
.88114 .72235 L
.88112 .72249 L
.88107 .72266 L
.88098 .72285 L
.88087 .72306 L
.88072 .72333 L
.88055 .72372 L
.88038 .72425 L
.88021 .72491 L
.88007 .72571 L
.87997 .72669 L
.87991 .72787 L
.87991 .72924 L
.88 .73079 L
.88016 .73249 L
.88037 .73422 L
.88061 .7361 L
.88082 .73814 L
.88098 .74035 L
.88104 .74276 L
.88098 .7453 L
.88077 .74777 L
.88043 .75028 L
.87998 .75272 L
.87947 .75494 L
.87896 .75674 L
.87844 .75831 L
.87794 .75966 L
.8775 .76066 L
.87714 .76143 L
.87689 .76205 L
.87676 .76233 L
.87674 .76239 L
Mistroke
.87686 .76222 L
.8771 .76187 L
.87742 .76139 L
.87776 .76089 L
.87806 .76047 L
.87829 .76023 L
.87837 .76024 L
.87828 .76052 L
.87801 .76105 L
.87754 .76183 L
.87688 .76285 L
.87604 .76412 L
.87505 .76563 L
.87401 .76721 L
.87288 .76884 L
.87172 .77041 L
.87054 .77189 L
.86939 .77333 L
.86836 .77454 L
.86747 .77559 L
.86677 .77636 L
.86628 .77684 L
.866 .77705 L
.86594 .77698 L
.86605 .77669 L
.86629 .77626 L
.86661 .77576 L
.86691 .77539 L
.86721 .7751 L
.86747 .77499 L
.86764 .77514 L
.86772 .7755 L
.86776 .77602 L
.86774 .77668 L
.86767 .77748 L
.86757 .77837 L
.86746 .77932 L
.86733 .78038 L
.86718 .78143 L
.86701 .7826 L
.86689 .78372 L
.86683 .78469 L
.8668 .78549 L
.86676 .78617 L
.86669 .78674 L
.86656 .78722 L
.8664 .7876 L
.86622 .78784 L
.86607 .78791 L
.86594 .78781 L
Mistroke
.86589 .78757 L
.86585 .78725 L
.86584 .78688 L
.86586 .78645 L
.86592 .78605 L
.86599 .78573 L
.86609 .7854 L
.86622 .78506 L
.86634 .78468 L
.86644 .78431 L
.86651 .78399 L
.86655 .78374 L
.86655 .78362 L
.86651 .78365 L
.86635 .78388 L
.86609 .78436 L
.86572 .78508 L
.86526 .78599 L
.86472 .78712 L
.86408 .78847 L
.86333 .78993 L
.86243 .79165 L
.8614 .79353 L
.86027 .79555 L
.85908 .79759 L
.85799 .79947 L
.85693 .8012 L
.85597 .80272 L
.85512 .80395 L
.85444 .80485 L
.85391 .80546 L
.8535 .80586 L
.85322 .8061 L
.85306 .80623 L
.85302 .80626 L
.85303 .80623 L
.85303 .80621 L
.85299 .80621 L
.85296 .80622 L
.85297 .8062 L
.85296 .80617 L
.8529 .80618 L
.85276 .80625 L
.85257 .80635 L
.8524 .80643 L
.85223 .80651 L
.85208 .80655 L
.85195 .80652 L
.8518 .80649 L
.8515 .80648 L
Mistroke
.85105 .80654 L
.85047 .80655 L
.84977 .80668 L
.84892 .80685 L
.8479 .80696 L
.84685 .80698 L
.84583 .80692 L
.84492 .80684 L
.844 .80674 L
.84313 .80663 L
.84251 .80652 L
.84208 .80643 L
.84173 .80635 L
.84151 .80632 L
.84149 .80632 L
.84159 .8064 L
.84192 .80641 L
.8424 .80637 L
.84301 .80625 L
.84366 .80612 L
.84437 .80594 L
.84509 .8057 L
.84591 .8053 L
.84668 .80489 L
.8475 .80433 L
.84821 .80378 L
.8489 .80321 L
.84949 .80267 L
.85 .80216 L
.85046 .80168 L
.85084 .80127 L
.85119 .80093 L
.85151 .80062 L
.85182 .80031 L
.85209 .80001 L
.85224 .79984 L
.85228 .79981 L
.85228 .79983 L
.85232 .79987 L
.85238 .79991 L
.85244 .79997 L
.85248 .80006 L
.85249 .80018 L
.8525 .80031 L
.85249 .80043 L
.85245 .80054 L
.85238 .80067 L
.85228 .80082 L
.85219 .80094 L
.85218 .80092 L
Mistroke
.85228 .80079 L
.85249 .80056 L
.85268 .80035 L
.85294 .80007 L
.85318 .79981 L
.85339 .7996 L
.85353 .79945 L
.8536 .7994 L
.8536 .79944 L
.85357 .79952 L
.85354 .79958 L
.85352 .79962 L
.85348 .79965 L
.85343 .79969 L
.85338 .79971 L
.85335 .79971 L
.85334 .79967 L
.85334 .79962 L
.85335 .79954 L
.85336 .79946 L
.85339 .79936 L
.85343 .79928 L
.85347 .79922 L
.85352 .79918 L
.85356 .79917 L
.8536 .79918 L
.85362 .79919 L
.85363 .79919 L
.85362 .7992 L
.8536 .79921 L
.85359 .79921 L
.85358 .79921 L
.85358 .79919 L
.85359 .79915 L
.85361 .79909 L
.85368 .799 L
.85376 .79891 L
.85381 .79889 L
.85382 .79894 L
.8538 .79907 L
.8537 .79933 L
.85349 .79975 L
.85317 .80031 L
.85274 .80094 L
.85225 .8016 L
.85175 .80222 L
.85128 .80279 L
.85083 .80328 L
.85048 .80363 L
.85018 .80388 L
Mistroke
.84993 .80404 L
.84979 .80402 L
.84976 .80386 L
.84985 .80358 L
.85015 .80306 L
.85062 .80237 L
.85129 .80154 L
.85212 .80067 L
.85312 .79972 L
.85427 .79871 L
.85557 .79761 L
.857 .79633 L
.85859 .79479 L
.8603 .79299 L
.86208 .79093 L
.86386 .78873 L
.8657 .78625 L
.86746 .78364 L
.86907 .78132 L
.87049 .77894 L
.87167 .77686 L
.87269 .77486 L
.87349 .77315 L
.87409 .77176 L
.87452 .77063 L
.87482 .76979 L
.87503 .76926 L
.87517 .769 L
.87528 .76894 L
.87537 .769 L
.87547 .76913 L
.8756 .76927 L
.87575 .7694 L
.8759 .76948 L
.87604 .76953 L
.87616 .76954 L
.87624 .76953 L
.87629 .76953 L
.8763 .76955 L
.87629 .76961 L
.87626 .76968 L
.87623 .76975 L
.87621 .76981 L
.8762 .76983 L
.87619 .76981 L
.87618 .7697 L
.87615 .76949 L
.87612 .76918 L
.87608 .76875 L
.87606 .7682 L
Mistroke
.87606 .76752 L
.87608 .76676 L
.87615 .7659 L
.87624 .76497 L
.87637 .76401 L
.87652 .76306 L
.8767 .76215 L
.87688 .76132 L
.87706 .76058 L
.87725 .75997 L
.87744 .75949 L
.87761 .75913 L
.87776 .75888 L
.87788 .75873 L
.87796 .75864 L
.87803 .7586 L
.87808 .75861 L
.87814 .75865 L
.87817 .75869 L
.87817 .75873 L
.87812 .75877 L
.87801 .75881 L
.87785 .75885 L
.8776 .75888 L
.87729 .75891 L
.87693 .75894 L
.87654 .75898 L
.87614 .75902 L
.87573 .75906 L
.87532 .7591 L
.87494 .75914 L
.87456 .75917 L
.87422 .75919 L
.87397 .75921 L
.87382 .75923 L
.8738 .75925 L
.87388 .75931 L
.87405 .7594 L
.8743 .75949 L
.87461 .75955 L
.87496 .75952 L
.87532 .75937 L
.87572 .75908 L
.87617 .75863 L
.87664 .75803 L
.87712 .75729 L
.87759 .75647 L
.87801 .75558 L
.87839 .75474 L
.87871 .75381 L
Mistroke
.87898 .75296 L
.87923 .75216 L
.87944 .75146 L
.87962 .75091 L
.87978 .75055 L
.87992 .75038 L
.88006 .75036 L
.88021 .7504 L
.88037 .75043 L
.88057 .75036 L
.88082 .75008 L
.88115 .7495 L
.88155 .74856 L
.88204 .74728 L
.8826 .74574 L
.88321 .74395 L
.88389 .74184 L
.88461 .7396 L
.88537 .73718 L
.88614 .73483 L
.88688 .73251 L
.88765 .7303 L
.8883 .72824 L
.88893 .72655 L
.88946 .72505 L
.88989 .72376 L
.89021 .72272 L
.89044 .72186 L
.89058 .72112 L
.89065 .72041 L
.89065 .71967 L
.89062 .71885 L
.89055 .71788 L
.89048 .71674 L
.89041 .71537 L
.89035 .71388 L
.89029 .71225 L
.89024 .71065 L
.89021 .70913 L
.89018 .70785 L
.89015 .7067 L
.89013 .70586 L
.89012 .70523 L
.89012 .70483 L
.89014 .70463 L
.8902 .70465 L
.8903 .70485 L
.89039 .7052 L
.89044 .70567 L
.89045 .70619 L
Mistroke
.89039 .70671 L
.89024 .70717 L
.88997 .7075 L
.88958 .70766 L
.88907 .70769 L
.88846 .70767 L
.88779 .70764 L
.88707 .70765 L
.88632 .70775 L
.8855 .70794 L
.88462 .70821 L
.88369 .70855 L
.88274 .70892 L
.88182 .70932 L
.88091 .70972 L
.87998 .71014 L
.87907 .7106 L
.87815 .71112 L
.87727 .7117 L
.87634 .71232 L
.87532 .71298 L
.87419 .71366 L
.87302 .71436 L
.87183 .71508 L
.8706 .71587 L
.86934 .71673 L
.86822 .71766 L
.86712 .71865 L
.8661 .7197 L
.86516 .72074 L
.86437 .72172 L
.86363 .72258 L
.86294 .7233 L
.86231 .72387 L
.86176 .7243 L
.86127 .7246 L
.86083 .72482 L
.86039 .72498 L
.85988 .72509 L
.85927 .72518 L
.85853 .72528 L
.85761 .72537 L
.85666 .7255 L
.85549 .72568 L
.85423 .72591 L
.85307 .72618 L
.85189 .72647 L
.85074 .72678 L
.84968 .72708 L
.84877 .72735 L
Mistroke
.84796 .72753 L
.84728 .72763 L
.84675 .72765 L
.84643 .72758 L
.84633 .72745 L
.84644 .72729 L
.84667 .72717 L
.84697 .72717 L
.84725 .72735 L
.84746 .72773 L
.84758 .72832 L
.84756 .7292 L
.8474 .73036 L
.84714 .73172 L
.84679 .73335 L
.84634 .73521 L
.84585 .7371 L
.84524 .73922 L
.8446 .74122 L
.84391 .74322 L
.84322 .74509 L
.84259 .74674 L
.84207 .74818 L
.8417 .74939 L
.84147 .75031 L
.84136 .75104 L
.84137 .75161 L
.84146 .75203 L
.84159 .75235 L
.84175 .7526 L
.84192 .7528 L
.84212 .75294 L
.84234 .75305 L
.84257 .75314 L
.84279 .75324 L
.84297 .75334 L
.84311 .75344 L
.84321 .75353 L
.84326 .75358 L
.84327 .75359 L
.84326 .75356 L
.84326 .75348 L
.84327 .75334 L
.84331 .75317 L
.84337 .75299 L
.84344 .75286 L
.84347 .75281 L
.84345 .75289 L
.84334 .75313 L
.84315 .75356 L
Mistroke
.84284 .75423 L
.8424 .75516 L
.84184 .75633 L
.84115 .75779 L
.84038 .75944 L
.83951 .76135 L
.83855 .76353 L
.83754 .76594 L
.83652 .76834 L
.83549 .77085 L
.83448 .77336 L
.83354 .7756 L
.83271 .77756 L
.832 .77935 L
.83142 .7809 L
.83099 .78217 L
.83071 .78308 L
.83057 .78379 L
.83057 .78431 L
.83067 .78467 L
.83081 .78489 L
.83093 .78504 L
.83104 .78514 L
.83112 .78522 L
.83114 .78528 L
.83109 .7853 L
.83098 .78534 L
.83081 .78544 L
.83054 .78566 L
.8301 .78601 L
.82956 .7865 L
.8289 .78712 L
.82818 .78788 L
.82738 .78883 L
.82656 .78995 L
.82573 .79127 L
.82488 .7927 L
.82418 .7944 L
.82343 .79638 L
.82266 .7986 L
.82182 .80106 L
.82096 .80364 L
.82006 .80627 L
.8191 .80858 L
.81829 .81102 L
.81754 .81288 L
.81694 .81474 L
.81642 .81635 L
.81597 .8177 L
.81561 .81882 L
Mistroke
.8153 .81968 L
.81508 .82026 L
.81497 .8206 L
.81498 .82073 L
.81509 .8207 L
.81524 .82056 L
.81541 .82041 L
.81555 .8203 L
.81564 .8202 L
.81567 .82013 L
.81565 .82009 L
.81559 .82009 L
.81548 .82011 L
.81532 .82013 L
.81517 .82014 L
.81506 .82015 L
.81497 .82015 L
.81489 .82015 L
.81483 .82016 L
.81476 .82016 L
.81469 .82017 L
.81462 .82018 L
.81456 .82018 L
.81454 .82017 L
.81454 .82017 L
.81452 .82016 L
.81448 .82013 L
.81444 .82012 L
.81435 .82011 L
.81425 .82011 L
.81415 .8201 L
.81405 .8201 L
.81397 .82008 L
.8139 .82006 L
.81384 .82006 L
.8138 .82014 L
.81371 .82035 L
.81362 .82074 L
.81347 .82138 L
.8133 .82218 L
.81308 .82321 L
.81285 .82452 L
.81262 .82558 L
.81239 .82709 L
.81214 .82854 L
.81188 .82978 L
.81159 .83138 L
.81126 .83283 L
.81091 .83427 L
.81055 .83562 L
Mistroke
.81021 .8368 L
.80989 .83777 L
.8096 .8385 L
.80937 .83906 L
.80916 .83947 L
.80899 .83976 L
.80887 .83997 L
.80878 .84013 L
.80874 .84024 L
.80875 .8403 L
.80881 .8403 L
.80889 .84025 L
.80898 .84018 L
.80905 .8401 L
.80908 .84004 L
.80906 .84002 L
.80898 .84002 L
.80888 .84003 L
.80874 .84004 L
.80857 .84006 L
.80837 .84008 L
.80814 .8401 L
.80792 .84012 L
.8077 .84014 L
.80749 .84016 L
.80735 .84018 L
.80724 .84019 L
.80721 .84019 L
.80724 .84019 L
.80736 .84018 L
.80752 .84016 L
.80773 .84014 L
.80796 .84012 L
.80818 .8401 L
.80838 .84008 L
.80855 .84007 L
.80871 .84005 L
.80886 .84003 L
.80898 .84002 L
.80907 .84001 L
.80913 .84 L
.80917 .83999 L
.80919 .83996 L
.80918 .8399 L
.80915 .83983 L
.80909 .83976 L
.80898 .83974 L
.80878 .83978 L
.80846 .83988 L
.80798 .84007 L
Mistroke
.80728 .84037 L
.80647 .8408 L
.80541 .84137 L
.80412 .84209 L
.80272 .84295 L
.80112 .84393 L
.79932 .84497 L
.79746 .84613 L
.79551 .84728 L
.79362 .84846 L
.79172 .84961 L
.78992 .85066 L
.78836 .85157 L
.78693 .85235 L
.7857 .853 L
.78471 .85351 L
.784 .85389 L
.78345 .85413 L
.78309 .85421 L
.7829 .85417 L
.78282 .85404 L
.78279 .85391 L
.78274 .85384 L
.78267 .85387 L
.78252 .85402 L
.7823 .85429 L
.78199 .85465 L
.78163 .85511 L
.78115 .85568 L
.7806 .85633 L
.77998 .85703 L
.77932 .85782 L
.77867 .85865 L
.77799 .85953 L
.77723 .86049 L
.77643 .8615 L
.77557 .86254 L
.77459 .8636 L
.77362 .86475 L
.77249 .866 L
.77119 .86737 L
.7697 .86888 L
.76818 .87043 L
.76647 .87209 L
.76459 .87379 L
.76277 .87541 L
.76105 .87689 L
.75941 .87822 L
.75786 .87941 L
.75649 .88042 L
Mistroke
.75514 .88134 L
.75393 .88217 L
.75276 .88292 L
.75167 .88358 L
.75064 .8842 L
.74961 .88476 L
.74863 .88537 L
.74758 .88603 L
.74646 .88675 L
.74527 .88755 L
.74408 .88837 L
.7428 .88927 L
.74143 .89022 L
.74004 .89118 L
.73868 .89212 L
.73734 .89301 L
.73614 .89376 L
.73504 .89439 L
.73402 .89494 L
.73304 .89548 L
.73211 .89603 L
.73119 .89661 L
.73031 .89721 L
.72936 .89788 L
.72831 .89867 L
.72711 .89961 L
.72573 .90074 L
.72414 .90207 L
.72231 .90363 L
.72057 .90519 L
.71854 .90684 L
.71632 .9087 L
.71417 .91072 L
.71165 .91279 L
.70943 .91462 L
.70716 .91647 L
.7049 .91821 L
.70285 .91971 L
.70094 .92109 L
.69931 .92228 L
.69786 .9233 L
.69654 .92421 L
.69531 .92504 L
.69423 .92581 L
.69313 .92649 L
.69203 .92716 L
.69092 .92776 L
.68989 .92839 L
.68888 .92899 L
.68795 .92953 L
Mistroke
.68713 .93 L
.68645 .93036 L
.68591 .93057 L
.68548 .9307 L
.68513 .93075 L
.6849 .93071 L
.68476 .93059 L
.68468 .93043 L
.68465 .93021 L
.68465 .93 L
.68467 .92984 L
.68468 .92977 L
.68463 .92982 L
.68447 .93 L
.6842 .93033 L
.68381 .93072 L
.68332 .9312 L
.68273 .93171 L
.68198 .93229 L
.68135 .93278 L
.68065 .93329 L
.68003 .93374 L
.67954 .93411 L
.67913 .9344 L
.67881 .93461 L
.67854 .93474 L
.67833 .93481 L
.6781 .93481 L
.67787 .93478 L
.67763 .93472 L
.67741 .93468 L
.67716 .93468 L
.67688 .9347 L
.67656 .93473 L
.67623 .93476 L
.67588 .9348 L
.67555 .93483 L
.67527 .93486 L
.6751 .93487 L
.67507 .93488 L
.67514 .93487 L
.67528 .93486 L
.67548 .93485 L
.67573 .93483 L
.676 .93481 L
.67629 .93479 L
.67657 .93477 L
.67687 .93474 L
.67715 .93472 L
.67744 .93469 L
Mistroke
.67765 .93467 L
.67778 .93466 L
.67781 .93465 L
.67776 .93465 L
.67766 .93465 L
.67754 .93466 L
.67744 .93466 L
.67738 .93466 L
.67736 .93465 L
.67736 .93464 L
.67734 .93464 L
.67731 .93464 L
.67732 .93464 L
.67739 .93464 L
.67755 .93463 L
.67775 .9346 L
.67796 .93458 L
.67817 .93455 L
.6783 .93454 L
.67834 .93453 L
.67825 .93454 L
.67804 .93456 L
.67774 .93459 L
.67734 .93463 L
.67695 .93468 L
.67647 .93474 L
.67598 .93479 L
.67552 .93484 L
.67512 .93489 L
.67481 .93493 L
.67458 .93495 L
.67445 .93497 L
.67441 .93498 L
.67442 .93497 L
.67448 .93497 L
.67456 .93496 L
.67463 .93495 L
.67466 .93495 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
Mistroke
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67466 .93494 L
.67467 .93494 L
.67469 .93494 L
.67474 .93494 L
.67481 .93493 L
.67488 .93492 L
.67491 .93492 L
.67489 .93492 L
.67478 .93493 L
.67458 .93495 L
.67429 .93499 L
.67393 .93503 L
.67353 .93507 L
.67312 .93512 L
.67272 .93516 L
.67235 .9352 L
.672 .93524 L
.6717 .93528 L
.67148 .93532 L
.67138 .93538 L
.6714 .93543 L
.67153 .93545 L
.67173 .93541 L
.67199 .9353 L
.67226 .93515 L
.6725 .93496 L
Mistroke
.67268 .93476 L
.67278 .93457 L
.6728 .93441 L
.67276 .9343 L
.6727 .93426 L
.67264 .93428 L
.67258 .93435 L
.67251 .93444 L
.67244 .9345 L
.67236 .93455 L
.67226 .93458 L
.67214 .93453 L
.672 .93441 L
.67186 .9342 L
.67174 .93395 L
.67164 .93368 L
.67158 .93342 L
.67153 .93318 L
.67146 .93295 L
.67137 .93278 L
.67129 .93273 L
.67124 .93279 L
.67122 .93294 L
.67124 .93317 L
.67129 .9335 L
.67133 .93391 L
.67136 .93436 L
.67134 .93482 L
.67128 .93522 L
.67117 .93552 L
.67104 .9357 L
.67091 .93577 L
.67088 .93576 L
.67097 .9357 L
.67119 .9356 L
.67144 .93552 L
.67179 .93544 L
.67217 .93538 L
.67253 .93531 L
.67284 .93524 L
.67306 .93519 L
.67319 .93514 L
.67326 .93511 L
.67332 .93508 L
.67338 .93507 L
.67344 .93506 L
.67341 .93507 L
.67332 .9351 L
.67321 .93512 L
.67318 .93513 L
Mistroke
.67319 .93513 L
.6733 .93512 L
.67347 .9351 L
.67371 .93507 L
.67397 .93503 L
.67425 .935 L
.67454 .93496 L
.6748 .93492 L
.675 .9349 L
.67509 .93489 L
.67505 .93489 L
.67488 .93492 L
.67456 .93497 L
.67412 .93503 L
.67361 .93509 L
.67307 .93516 L
.67254 .93523 L
.67203 .93529 L
.67157 .93534 L
.67121 .93539 L
.67092 .93544 L
.6707 .93549 L
.67061 .93551 L
.6707 .93549 L
.67096 .93543 L
.67134 .93533 L
.67179 .93521 L
.67227 .93507 L
.67276 .93494 L
.67319 .93482 L
.67353 .93473 L
.67374 .93467 L
.67387 .93463 L
.67398 .93461 L
.67408 .9346 L
.67421 .93457 L
.67432 .93456 L
.6744 .93457 L
.67445 .93462 L
.67446 .93471 L
.67445 .93482 L
.6744 .93495 L
.67431 .93509 L
.67416 .93523 L
.67398 .93534 L
.67381 .93541 L
.67366 .93547 L
.67329 .93557 L
.67302 .93564 L
.67268 .93572 L
Mistroke
.67219 .93581 L
.67152 .93592 L
.67064 .93605 L
.66947 .93619 L
.66813 .93638 L
.66644 .93662 L
.66447 .93691 L
.66236 .93725 L
.65998 .93764 L
.65736 .93808 L
.65459 .93858 L
.6517 .93915 L
.64921 .93968 L
.64686 .94028 L
.64493 .94091 L
.6433 .94148 L
.64217 .94199 L
.64139 .94241 L
.64096 .94271 L
.64087 .94292 L
.64096 .94299 L
.64123 .943 L
.64164 .94294 L
.64214 .94274 L
.64267 .9425 L
.64315 .94222 L
.64352 .94191 L
.64372 .94157 L
.6438 .94123 L
.64377 .94092 L
.64368 .94064 L
.64352 .94042 L
.64328 .94025 L
.64298 .94008 L
.64264 .93986 L
.64229 .9396 L
.64196 .93927 L
.64166 .93889 L
.64139 .93839 L
.64116 .93781 L
.641 .93721 L
.64091 .93664 L
.64086 .93611 L
.64083 .93563 L
.64082 .93522 L
.64081 .93497 L
.64082 .93486 L
.64084 .9349 L
.64088 .93508 L
.64095 .93536 L
Mistroke
.64103 .93565 L
.64111 .9359 L
.64118 .93606 L
.64125 .93618 L
.64129 .93623 L
.64134 .93615 L
.64143 .93602 L
.64157 .93582 L
.64177 .93561 L
.64202 .93537 L
.64228 .93517 L
.64249 .93503 L
.6426 .93497 L
.64257 .93499 L
.6424 .93514 L
.64206 .93544 L
.64151 .93584 L
.64074 .93639 L
.63974 .93704 L
.63853 .93776 L
.63715 .93857 L
.63534 .93927 L
.63347 .94004 L
.63133 .94084 L
.62875 .94164 L
.62584 .94248 L
.62255 .94328 L
.61926 .94411 L
.61604 .94496 L
.61251 .94579 L
.60867 .94668 L
.60525 .94758 L
.60122 .94836 L
.59736 .9491 L
.59307 .9498 L
.58893 .95051 L
.58508 .95111 L
.581 .9517 L
.57687 .95227 L
.57354 .95278 L
.56985 .95325 L
.56649 .95368 L
.56294 .95408 L
.55963 .95448 L
.55612 .95487 L
.55259 .95527 L
.54933 .95566 L
.54591 .95608 L
.54237 .95655 L
.53924 .95706 L
Mistroke
.53628 .95757 L
.53285 .95806 L
.52997 .95852 L
.52701 .95891 L
.52395 .95924 L
.52092 .95948 L
.51827 .9596 L
.51563 .95957 L
.51316 .95937 L
.51078 .95905 L
.50865 .95863 L
.5066 .95811 L
.50467 .95755 L
.5031 .957 L
.50172 .95654 L
.50052 .95612 L
.49956 .95581 L
.49879 .9556 L
.49816 .95546 L
.49758 .95537 L
.49696 .95531 L
.49623 .95531 L
.49532 .95535 L
.4941 .9554 L
.49255 .95548 L
.49077 .95561 L
.48859 .95574 L
.48602 .95584 L
.48301 .95592 L
.47979 .95603 L
.47637 .95617 L
.47249 .95637 L
.46851 .95661 L
.46475 .95684 L
.46075 .95705 L
.45673 .9572 L
.45278 .95727 L
.44902 .95722 L
.4452 .95708 L
.44188 .9569 L
.43878 .95674 L
.43599 .9566 L
.43365 .95648 L
.43162 .95638 L
.42993 .95629 L
.42867 .95622 L
.42771 .95617 L
.42705 .95613 L
.42669 .95608 L
.42657 .95606 L
Mistroke
.42662 .95605 L
.42676 .956 L
.42693 .95594 L
.42708 .95579 L
.4272 .95556 L
.42727 .95534 L
.42729 .9551 L
.42725 .95486 L
.42716 .95461 L
.42706 .95435 L
.42696 .9541 L
.42687 .9539 L
.42675 .95368 L
.42661 .95341 L
.42647 .9531 L
.42632 .95275 L
.42617 .9524 L
.42602 .95203 L
.42588 .95168 L
.42577 .95135 L
.42565 .95104 L
.42552 .95076 L
.42538 .95055 L
.42525 .95042 L
.42513 .9504 L
.42507 .9505 L
.42508 .95075 L
.42516 .95114 L
.4253 .95161 L
.42545 .9521 L
.42562 .95258 L
.42578 .95302 L
.42594 .95338 L
.42609 .95365 L
.42623 .95383 L
.42638 .9539 L
.42655 .95385 L
.42672 .95364 L
.42689 .95328 L
.42706 .95286 L
.42722 .95241 L
.42735 .95195 L
.42743 .95154 L
.42748 .95121 L
.42751 .95103 L
.42752 .95099 L
.42751 .95103 L
.42748 .95112 L
.42741 .95124 L
.42729 .95138 L
Mistroke
.42711 .95148 L
.42687 .95158 L
.4266 .95164 L
.42631 .95162 L
.42603 .95155 L
.42579 .95143 L
.4256 .95128 L
.42544 .95111 L
.42533 .95094 L
.42527 .9508 L
.42525 .95069 L
.42526 .95064 L
.42528 .95065 L
.42531 .9507 L
.42535 .95075 L
.42538 .95079 L
.42541 .95082 L
.42544 .95086 L
.42548 .9509 L
.42551 .95092 L
.42553 .9509 L
.42554 .95084 L
.42555 .95077 L
.42555 .95072 L
.42556 .95073 L
.42558 .95085 L
.42562 .95109 L
.42566 .95144 L
.42571 .95188 L
.42576 .9524 L
.42583 .95296 L
.42591 .9535 L
.426 .95403 L
.42612 .95445 L
.42626 .9549 L
.42641 .9553 L
.42656 .95561 L
.42672 .95583 L
.42686 .95589 L
.42697 .95582 L
.42706 .95565 L
.42713 .95542 L
.42719 .95515 L
.42721 .95489 L
.42723 .95465 L
.42725 .95445 L
.42728 .95426 L
.4273 .95407 L
.42734 .95388 L
.42736 .95367 L
Mistroke
.42736 .95342 L
.42731 .95314 L
.42724 .95284 L
.42714 .95254 L
.42702 .95223 L
.42689 .95192 L
.42675 .95163 L
.42661 .95136 L
.42647 .95116 L
.42632 .951 L
.42624 .9509 L
.42627 .95087 L
.42634 .95087 L
.42641 .95088 L
.42645 .95087 L
.42645 .95086 L
.42637 .95082 L
.42609 .9508 L
.4255 .95081 L
.42454 .95085 L
.42311 .95089 L
.42117 .95086 L
.41872 .95075 L
.41626 .95055 L
.41339 .95023 L
.40982 .9498 L
.40636 .94924 L
.40186 .94854 L
.39824 .94771 L
.39366 .94683 L
.38961 .94576 L
.3854 .94464 L
.3807 .9434 L
.37702 .94205 L
.37275 .94064 L
.36889 .93919 L
.36494 .93773 L
.36108 .93626 L
.35687 .93485 L
.3533 .93349 L
.34922 .93218 L
.34546 .93091 L
.34156 .92966 L
.33767 .92843 L
.33398 .9272 L
.32993 .92598 L
.32652 .92476 L
.32284 .92353 L
.3193 .92231 L
.31589 .9211 L
Mistroke
.31248 .91993 L
.30933 .91886 L
.30612 .91781 L
.30327 .9168 L
.30082 .9159 L
.29859 .91506 L
.29663 .91433 L
.29514 .91375 L
.29388 .91335 L
.29294 .91315 L
.29226 .91308 L
.29175 .9131 L
.29133 .91315 L
.29091 .91314 L
.29039 .91299 L
.28968 .91266 L
.28863 .91212 L
.28744 .91142 L
.28583 .91054 L
.2838 .9095 L
.28152 .90843 L
.27893 .90709 L
.27613 .90574 L
.27302 .90425 L
.27004 .90268 L
.2671 .90104 L
.26427 .89955 L
.26145 .89808 L
.25882 .89664 L
.25628 .89529 L
.25393 .89395 L
.25159 .89252 L
.24934 .891 L
.24717 .88934 L
.24494 .88751 L
.24264 .88551 L
.24046 .88343 L
.23819 .88115 L
.2359 .8788 L
.23365 .87627 L
.23147 .87356 L
.22933 .87083 L
.22727 .86787 L
.22549 .8651 L
.22387 .86212 L
.22245 .85947 L
.22125 .8569 L
.22022 .85455 L
.21932 .85242 L
.21846 .85051 L
Mistroke
.21754 .84866 L
.21648 .84719 L
.21524 .84584 L
.21376 .84462 L
.21197 .84353 L
.20982 .84254 L
.20771 .84161 L
.20516 .8407 L
.2022 .83963 L
.19934 .8384 L
.19607 .83692 L
.19243 .83517 L
.18904 .8332 L
.18529 .83081 L
.18168 .82826 L
.17798 .82555 L
.17454 .82292 L
.17096 .81995 L
.16774 .81708 L
.16441 .814 L
.16132 .81114 L
.1583 .80817 L
.15546 .80531 L
.15279 .80246 L
.15032 .7999 L
.14807 .79729 L
.14603 .7947 L
.14424 .79224 L
.14262 .78966 L
.14119 .78729 L
.13988 .78481 L
.13863 .78237 L
.13736 .7799 L
.13607 .77743 L
.13479 .7748 L
.13347 .77239 L
.13219 .76981 L
.13089 .76717 L
.1297 .76469 L
.12855 .76215 L
.12748 .75981 L
.12646 .75764 L
.12559 .75545 L
.12527 .75346 L
.1245 .75146 L
.12383 .74973 L
.12334 .74811 L
.12306 .74668 L
.12295 .74549 L
.12295 .74451 L
Mistroke
.12301 .74373 L
.12307 .74311 L
.12306 .74257 L
.12294 .74202 L
.12265 .7414 L
.12212 .74063 L
.12132 .73968 L
.12029 .73851 L
.11905 .73714 L
.11784 .73572 L
.11626 .73408 L
.11442 .73225 L
.11241 .7303 L
.11024 .72806 L
.10805 .72587 L
.10569 .72348 L
.10347 .72094 L
.10145 .7185 L
.09945 .71581 L
.09771 .71311 L
.09615 .71021 L
.09476 .7071 L
.09358 .70362 L
.09253 .70002 L
.09163 .69609 L
.09081 .69179 L
.09005 .68749 L
.08934 .68274 L
.08866 .67822 L
.08799 .6742 L
.08732 .66967 L
.08668 .66506 L
.08598 .6609 L
.08523 .65658 L
.08446 .65237 L
.08363 .64838 L
.08282 .64421 L
.08201 .64023 L
.08123 .63628 L
.08054 .63225 L
.07993 .62823 L
.07941 .62431 L
.07898 .62036 L
.07864 .61646 L
.07838 .6128 L
.07817 .60913 L
.07799 .60556 L
.0778 .60236 L
.07759 .59895 L
.07735 .59586 L
Mistroke
.07705 .59257 L
.07666 .58933 L
.07617 .58589 L
.07559 .58222 L
.07493 .57887 L
.07422 .57492 L
.07351 .57095 L
.07281 .5672 L
.07213 .5635 L
.07152 .55966 L
.07101 .55528 L
.07062 .55135 L
.07037 .54717 L
.07025 .54296 L
.07029 .53873 L
.07048 .53447 L
.07081 .53015 L
.07126 .52606 L
.07179 .52212 L
.07238 .518 L
.073 .51446 L
.07363 .51099 L
.07426 .50785 L
.07485 .50528 L
.07538 .50313 L
.07584 .50147 L
.07621 .50022 L
.07649 .49928 L
.07667 .49861 L
.07678 .49815 L
.07686 .49777 L
.07695 .49736 L
.07708 .49688 L
.07727 .49629 L
.07753 .49559 L
.07787 .49476 L
.07829 .49391 L
.07878 .49291 L
.07933 .49186 L
.07988 .49077 L
.08048 .48971 L
.08103 .48881 L
.08156 .48803 L
.08204 .4874 L
.08244 .48693 L
.08274 .48664 L
.08294 .4865 L
Mfstroke
.09098 .48013 m
.09112 .48009 L
.09139 .48002 L
.09184 .47987 L
.09247 .47965 L
.09332 .47934 L
.09441 .47896 L
.09567 .47857 L
.09715 .47816 L
.09871 .47774 L
.10046 .47728 L
.1022 .47678 L
.10427 .47624 L
.10605 .47569 L
.10788 .47514 L
.10985 .47462 L
.11173 .47413 L
.11365 .47369 L
.11548 .47328 L
.11696 .47291 L
.11847 .47256 L
.11984 .47221 L
.12115 .47186 L
.12236 .47151 L
.1236 .47126 L
.12481 .47105 L
.12606 .47088 L
.12729 .47076 L
.12853 .47065 L
.12976 .47053 L
.13091 .47038 L
.13207 .47019 L
.13322 .46996 L
.13434 .46968 L
.13541 .46937 L
.13633 .46904 L
.13715 .46874 L
.1378 .46848 L
.13824 .46832 L
.13843 .46827 L
.13835 .46836 L
.13803 .46861 L
.13751 .46901 L
.13689 .46955 L
.13625 .4702 L
.13566 .47093 L
.13517 .47174 L
.13479 .47258 L
.13454 .47349 L
.13442 .4745 L
Mistroke
.13446 .4756 L
.13467 .47677 L
.13504 .47796 L
.13566 .47919 L
.13641 .48048 L
.13731 .48182 L
.13833 .48312 L
.13936 .48444 L
.14033 .48575 L
.14118 .48704 L
.1419 .48825 L
.14252 .48929 L
.14306 .49024 L
.14352 .4911 L
.14394 .49185 L
.14436 .49253 L
.1448 .49313 L
.14528 .49366 L
.14584 .49414 L
.14654 .49458 L
.14741 .49499 L
.14843 .49536 L
.14965 .49572 L
.15105 .49607 L
.15266 .49641 L
.1543 .49671 L
.15607 .49695 L
.15791 .49711 L
.15974 .49719 L
.16148 .49719 L
.163 .49714 L
.16434 .49705 L
.16538 .49697 L
.16613 .49693 L
.16659 .49695 L
.16678 .49701 L
.16675 .49708 L
.16652 .49712 L
.16617 .49711 L
.16574 .49704 L
.16529 .4969 L
.16479 .49668 L
.16429 .49637 L
.16383 .49596 L
.16344 .49548 L
.16319 .49491 L
.16311 .4943 L
.16323 .49367 L
.16349 .49301 L
.16382 .49237 L
Mistroke
.16418 .49178 L
.1645 .49133 L
.16477 .49104 L
.16496 .49093 L
.16507 .49097 L
.16506 .4911 L
.16492 .49128 L
.16458 .49147 L
.16395 .49159 L
.16318 .4916 L
.16219 .49147 L
.1609 .49119 L
.15918 .49075 L
.15705 .49013 L
.15526 .48941 L
.15267 .48843 L
.15036 .48744 L
.14715 .48633 L
.14451 .48514 L
.14106 .48397 L
.13855 .48296 L
.13476 .48205 L
.13185 .48128 L
.12811 .48066 L
.12552 .48016 L
.12177 .47977 L
.11897 .47948 L
.11542 .47928 L
.11289 .47918 L
.10957 .47921 L
.10635 .4794 L
.10373 .47976 L
.10007 .48027 L
.0975 .48093 L
.09443 .48176 L
.09109 .48274 L
.08847 .48366 L
.0859 .4847 L
.08392 .48568 L
.08154 .48674 L
.0794 .48801 L
.07788 .48909 L
.07663 .49016 L
.07558 .49119 L
.07477 .49218 L
.07418 .49311 L
.07377 .49397 L
.07348 .49472 L
.07328 .49536 L
.0731 .49592 L
Mistroke
.07297 .49645 L
.07292 .49704 L
.0729 .49747 L
.07285 .49791 L
.07283 .49823 L
.07287 .49842 L
Mfstroke
1 1 0 r
.008 w
.08407 .42185 Mdot
.016 w
.08407 .42185 m
.0842 .42159 L
s
1 .999 0 r
.008 w
.0842 .42159 Mdot
.016 w
.0842 .42159 m
.08434 .42118 L
s
.008 w
.08434 .42118 Mdot
.016 w
.08434 .42118 m
.0845 .42054 L
s
1 .998 0 r
.008 w
.0845 .42054 Mdot
.016 w
.0845 .42054 m
.08468 .41964 L
s
.008 w
.08468 .41964 Mdot
.016 w
.08468 .41964 m
.08488 .41841 L
s
.008 w
.08488 .41841 Mdot
.016 w
.08488 .41841 m
.08512 .4168 L
s
1 .997 0 r
.008 w
.08512 .4168 Mdot
.016 w
.08512 .4168 m
.08539 .41509 L
s
.008 w
.08539 .41509 Mdot
.016 w
.08539 .41509 m
.08568 .41278 L
s
.008 w
.08568 .41278 Mdot
.016 w
.08568 .41278 m
.08601 .4103 L
s
1 .996 0 r
.008 w
.08601 .4103 Mdot
.016 w
.08601 .4103 m
.08637 .4076 L
s
.008 w
.08637 .4076 Mdot
.016 w
.08637 .4076 m
.08678 .40449 L
s
1 .995 0 r
.008 w
.08678 .40449 Mdot
.016 w
.08678 .40449 m
.08722 .40098 L
s
.008 w
.08722 .40098 Mdot
.016 w
.08722 .40098 m
.08769 .39724 L
s
.008 w
.08769 .39724 Mdot
.016 w
.08769 .39724 m
.08815 .39311 L
s
1 .994 0 r
.008 w
.08815 .39311 Mdot
.016 w
.08815 .39311 m
.08863 .38958 L
s
.008 w
.08863 .38958 Mdot
.016 w
.08863 .38958 m
.08911 .38499 L
s
1 .993 0 r
.008 w
.08911 .38499 Mdot
.016 w
.08911 .38499 m
.08963 .38129 L
s
.008 w
.08963 .38129 Mdot
.016 w
.08963 .38129 m
.0902 .37698 L
s
.008 w
.0902 .37698 Mdot
.016 w
.0902 .37698 m
.09085 .37246 L
s
1 .992 0 r
.008 w
.09085 .37246 Mdot
.016 w
.09085 .37246 m
.09157 .36809 L
s
.008 w
.09157 .36809 Mdot
.016 w
.09157 .36809 m
.09229 .36365 L
s
1 .991 0 r
.008 w
.09229 .36365 Mdot
.016 w
.09229 .36365 m
.09304 .35984 L
s
.008 w
.09304 .35984 Mdot
.016 w
.09304 .35984 m
.09381 .35568 L
s
.008 w
.09381 .35568 Mdot
.016 w
.09381 .35568 m
.09457 .35231 L
s
1 .99 0 r
.008 w
.09457 .35231 Mdot
.016 w
.09457 .35231 m
.09523 .34902 L
s
.008 w
.09523 .34902 Mdot
.016 w
.09523 .34902 m
.09598 .34592 L
s
.008 w
.09598 .34592 Mdot
.016 w
.09598 .34592 m
.09662 .34307 L
s
1 .989 0 r
.008 w
.09662 .34307 Mdot
.016 w
.09662 .34307 m
.09724 .34096 L
s
.008 w
.09724 .34096 Mdot
.016 w
.09724 .34096 m
.09785 .33897 L
s
1 .988 0 r
.008 w
.09785 .33897 Mdot
.016 w
.09785 .33897 m
.09843 .33736 L
s
.008 w
.09843 .33736 Mdot
.016 w
.09843 .33736 m
.09894 .33599 L
s
.008 w
.09894 .33599 Mdot
.016 w
.09894 .33599 m
.09937 .33491 L
s
1 .987 0 r
.008 w
.09937 .33491 Mdot
.016 w
.09937 .33491 m
.09972 .33429 L
s
.008 w
.09972 .33429 Mdot
.016 w
.09972 .33429 m
.09999 .33378 L
s
1 .986 0 r
.008 w
.09999 .33378 Mdot
.016 w
.09999 .33378 m
.1002 .33345 L
s
.008 w
.1002 .33345 Mdot
.016 w
.1002 .33345 m
.10036 .33325 L
s
.008 w
.10036 .33325 Mdot
.016 w
.10036 .33325 m
.10049 .33317 L
s
1 .985 0 r
.008 w
.10049 .33317 Mdot
.016 w
.10049 .33317 m
.10059 .33311 L
s
.008 w
.10059 .33311 Mdot
.016 w
.10059 .33311 m
.10067 .33305 L
s
1 .984 0 r
.008 w
.10067 .33305 Mdot
.016 w
.10067 .33305 m
.1007 .33295 L
s
.008 w
.1007 .33295 Mdot
.016 w
.1007 .33295 m
.10067 .33283 L
s
.008 w
.10067 .33283 Mdot
.016 w
.10067 .33283 m
.10062 .33269 L
s
1 .983 0 r
.008 w
.10062 .33269 Mdot
.016 w
.10062 .33269 m
.10056 .3325 L
s
.008 w
.10056 .3325 Mdot
.016 w
.10056 .3325 m
.10053 .33226 L
s
.008 w
.10053 .33226 Mdot
.016 w
.10053 .33226 m
.10055 .33195 L
s
1 .982 0 r
.008 w
.10055 .33195 Mdot
.016 w
.10055 .33195 m
.10063 .33159 L
s
.008 w
.10063 .33159 Mdot
.016 w
.10063 .33159 m
.10078 .33119 L
s
1 .981 0 r
.008 w
.10078 .33119 Mdot
.016 w
.10078 .33119 m
.10096 .33079 L
s
.008 w
.10096 .33079 Mdot
.016 w
.10096 .33079 m
.10118 .33039 L
s
.008 w
.10118 .33039 Mdot
.016 w
.10118 .33039 m
.1014 .33005 L
s
1 .98 0 r
.008 w
.1014 .33005 Mdot
.016 w
.1014 .33005 m
.10158 .32977 L
s
.008 w
.10158 .32977 Mdot
.016 w
.10158 .32977 m
.10172 .3296 L
s
1 .979 0 r
.008 w
.10172 .3296 Mdot
.016 w
.10172 .3296 m
.10187 .32944 L
s
.008 w
.10187 .32944 Mdot
.016 w
.10187 .32944 m
.10204 .32931 L
s
.008 w
.10204 .32931 Mdot
.016 w
.10204 .32931 m
.10227 .32919 L
s
1 .978 0 r
.008 w
.10227 .32919 Mdot
.016 w
.10227 .32919 m
.10255 .32902 L
s
.008 w
.10255 .32902 Mdot
.016 w
.10255 .32902 m
.1029 .32873 L
s
1 .977 0 r
.008 w
.1029 .32873 Mdot
.016 w
.1029 .32873 m
.10333 .32826 L
s
.008 w
.10333 .32826 Mdot
.016 w
.10333 .32826 m
.10386 .32754 L
s
.008 w
.10386 .32754 Mdot
.016 w
.10386 .32754 m
.10454 .32648 L
s
1 .976 0 r
.008 w
.10454 .32648 Mdot
.016 w
.10454 .32648 m
.10539 .32504 L
s
.008 w
.10539 .32504 Mdot
.016 w
.10539 .32504 m
.10643 .32335 L
s
.008 w
.10643 .32335 Mdot
.016 w
.10643 .32335 m
.10752 .32129 L
s
1 .975 0 r
.008 w
.10752 .32129 Mdot
.016 w
.10752 .32129 m
.10892 .31917 L
s
.008 w
.10892 .31917 Mdot
.016 w
.10892 .31917 m
.11039 .31668 L
s
1 .974 0 r
.008 w
.11039 .31668 Mdot
.016 w
.11039 .31668 m
.11209 .31374 L
s
.008 w
.11209 .31374 Mdot
.016 w
.11209 .31374 m
.11384 .31076 L
s
.008 w
.11384 .31076 Mdot
.016 w
.11384 .31076 m
.11574 .30788 L
s
1 .973 0 r
.008 w
.11574 .30788 Mdot
.016 w
.11574 .30788 m
.11752 .30471 L
s
.008 w
.11752 .30471 Mdot
.016 w
.11752 .30471 m
.11941 .30148 L
s
1 .972 0 r
.008 w
.11941 .30148 Mdot
.016 w
.11941 .30148 m
.12129 .29823 L
s
.008 w
.12129 .29823 Mdot
.016 w
.12129 .29823 m
.12307 .29518 L
s
.008 w
.12307 .29518 Mdot
.016 w
.12307 .29518 m
.1249 .29209 L
s
1 .971 0 r
.008 w
.1249 .29209 Mdot
.016 w
.1249 .29209 m
.12671 .28912 L
s
.008 w
.12671 .28912 Mdot
.016 w
.12671 .28912 m
.12853 .28609 L
s
1 .97 0 r
.008 w
.12853 .28609 Mdot
.016 w
.12853 .28609 m
.13049 .28307 L
s
.008 w
.13049 .28307 Mdot
.016 w
.13049 .28307 m
.1324 .27997 L
s
.008 w
.1324 .27997 Mdot
.016 w
.1324 .27997 m
.13444 .27673 L
s
1 .969 0 r
.008 w
.13444 .27673 Mdot
.016 w
.13444 .27673 m
.13649 .27363 L
s
.008 w
.13649 .27363 Mdot
.016 w
.13649 .27363 m
.1386 .2701 L
s
.008 w
.1386 .2701 Mdot
.016 w
.1386 .2701 m
.14076 .26685 L
s
1 .968 0 r
.008 w
.14076 .26685 Mdot
.016 w
.14076 .26685 m
.14299 .26338 L
s
.008 w
.14299 .26338 Mdot
.016 w
.14299 .26338 m
.14531 .2598 L
s
1 .967 0 r
.008 w
.14531 .2598 Mdot
.016 w
.14531 .2598 m
.1475 .25647 L
s
.008 w
.1475 .25647 Mdot
.016 w
.1475 .25647 m
.14976 .25301 L
s
.008 w
.14976 .25301 Mdot
.016 w
.14976 .25301 m
.15224 .24934 L
s
1 .966 0 r
.008 w
.15224 .24934 Mdot
.016 w
.15224 .24934 m
.15436 .2461 L
s
.008 w
.15436 .2461 Mdot
.016 w
.15436 .2461 m
.15671 .24256 L
s
1 .965 0 r
.008 w
.15671 .24256 Mdot
.016 w
.15671 .24256 m
.15906 .23896 L
s
.008 w
.15906 .23896 Mdot
.016 w
.15906 .23896 m
.16165 .23546 L
s
.008 w
.16165 .23546 Mdot
.016 w
.16165 .23546 m
.1639 .23179 L
s
1 .964 0 r
.008 w
.1639 .23179 Mdot
.016 w
.1639 .23179 m
.16633 .22828 L
s
.008 w
.16633 .22828 Mdot
.016 w
.16633 .22828 m
.16879 .2248 L
s
1 .963 0 r
.008 w
.16879 .2248 Mdot
.016 w
.16879 .2248 m
.17113 .22128 L
s
.008 w
.17113 .22128 Mdot
.016 w
.17113 .22128 m
.17346 .21794 L
s
.008 w
.17346 .21794 Mdot
.016 w
.17346 .21794 m
.17579 .21456 L
s
1 .962 0 r
.008 w
.17579 .21456 Mdot
.016 w
.17579 .21456 m
.17798 .21117 L
s
.008 w
.17798 .21117 Mdot
.016 w
.17798 .21117 m
.17999 .20801 L
s
.008 w
.17999 .20801 Mdot
.016 w
.17999 .20801 m
.18202 .20474 L
s
1 .961 0 r
.008 w
.18202 .20474 Mdot
.016 w
.18202 .20474 m
.18397 .20134 L
s
.008 w
.18397 .20134 Mdot
.016 w
.18397 .20134 m
.18584 .19847 L
s
1 .96 0 r
.008 w
.18584 .19847 Mdot
.016 w
.18584 .19847 m
.18755 .19555 L
s
.008 w
.18755 .19555 Mdot
.016 w
.18755 .19555 m
.18925 .19272 L
s
.008 w
.18925 .19272 Mdot
.016 w
.18925 .19272 m
.19079 .19048 L
s
1 .959 0 r
.008 w
.19079 .19048 Mdot
.016 w
.19079 .19048 m
.19232 .18823 L
s
.008 w
.19232 .18823 Mdot
.016 w
.19232 .18823 m
.19363 .18634 L
s
1 .958 0 r
.008 w
.19363 .18634 Mdot
.016 w
.19363 .18634 m
.19484 .1846 L
s
.008 w
.19484 .1846 Mdot
.016 w
.19484 .1846 m
.19604 .18311 L
s
.008 w
.19604 .18311 Mdot
.016 w
.19604 .18311 m
.197 .1819 L
s
1 .957 0 r
.008 w
.197 .1819 Mdot
.016 w
.197 .1819 m
.19786 .1809 L
s
.008 w
.19786 .1809 Mdot
.016 w
.19786 .1809 m
.19859 .18016 L
s
.008 w
.19859 .18016 Mdot
.016 w
.19859 .18016 m
.19917 .17966 L
s
1 .956 0 r
.008 w
.19917 .17966 Mdot
.016 w
.19917 .17966 m
.19957 .17941 L
s
.008 w
.19957 .17941 Mdot
.016 w
.19957 .17941 m
.19978 .17937 L
s
1 .955 0 r
.008 w
.19978 .17937 Mdot
.016 w
.19978 .17937 m
.19982 .17948 L
s
.008 w
.19982 .17948 Mdot
.016 w
.19982 .17948 m
.19975 .17964 L
s
.008 w
.19975 .17964 Mdot
.016 w
.19975 .17964 m
.19964 .17975 L
s
1 .954 0 r
.008 w
.19964 .17975 Mdot
.016 w
.19964 .17975 m
.19956 .17973 L
s
.008 w
.19956 .17973 Mdot
.016 w
.19956 .17973 m
.1996 .17954 L
s
1 .953 0 r
.008 w
.1996 .17954 Mdot
.016 w
.1996 .17954 m
.19979 .17913 L
s
.008 w
.19979 .17913 Mdot
.016 w
.19979 .17913 m
.20016 .17849 L
s
.008 w
.20016 .17849 Mdot
.016 w
.20016 .17849 m
.20073 .17763 L
s
1 .952 0 r
.008 w
.20073 .17763 Mdot
.016 w
.20073 .17763 m
.20149 .17661 L
s
.008 w
.20149 .17661 Mdot
.016 w
.20149 .17661 m
.20247 .1754 L
s
1 .951 0 r
.008 w
.20247 .1754 Mdot
.016 w
.20247 .1754 m
.20371 .17401 L
s
.008 w
.20371 .17401 Mdot
.016 w
.20371 .17401 m
.20515 .1725 L
s
.008 w
.20515 .1725 Mdot
.016 w
.20515 .1725 m
.20678 .17085 L
s
1 .95 0 r
.008 w
.20678 .17085 Mdot
.016 w
.20678 .17085 m
.20874 .16906 L
s
.008 w
.20874 .16906 Mdot
.016 w
.20874 .16906 m
.21096 .16712 L
s
.008 w
.21096 .16712 Mdot
.016 w
.21096 .16712 m
.21312 .16519 L
s
1 .949 0 r
.008 w
.21312 .16519 Mdot
.016 w
.21312 .16519 m
.2157 .16315 L
s
.008 w
.2157 .16315 Mdot
.016 w
.2157 .16315 m
.21838 .16115 L
s
1 .948 0 r
.008 w
.21838 .16115 Mdot
.016 w
.21838 .16115 m
.22103 .15918 L
s
.008 w
.22103 .15918 Mdot
.016 w
.22103 .15918 m
.22393 .15728 L
s
.008 w
.22393 .15728 Mdot
.016 w
.22393 .15728 m
.22664 .15546 L
s
1 .947 0 r
.008 w
.22664 .15546 Mdot
.016 w
.22664 .15546 m
.22936 .1539 L
s
.008 w
.22936 .1539 Mdot
.016 w
.22936 .1539 m
.23195 .1524 L
s
1 .946 0 r
.008 w
.23195 .1524 Mdot
.016 w
.23195 .1524 m
.2343 .15117 L
s
.008 w
.2343 .15117 Mdot
.016 w
.2343 .15117 m
.23642 .15005 L
s
.008 w
.23642 .15005 Mdot
.016 w
.23642 .15005 m
.23828 .14915 L
s
1 .945 0 r
.008 w
.23828 .14915 Mdot
.016 w
.23828 .14915 m
.23985 .14843 L
s
.008 w
.23985 .14843 Mdot
.016 w
.23985 .14843 m
.24105 .14789 L
s
1 .944 0 r
.008 w
.24105 .14789 Mdot
.016 w
.24105 .14789 m
.242 .14756 L
s
.008 w
.242 .14756 Mdot
.016 w
.242 .14756 m
.24272 .14739 L
s
.008 w
.24272 .14739 Mdot
.016 w
.24272 .14739 m
.24322 .14736 L
s
1 .943 0 r
.008 w
.24322 .14736 Mdot
.016 w
.24322 .14736 m
.24355 .14741 L
s
.008 w
.24355 .14741 Mdot
.016 w
.24355 .14741 m
.24375 .14754 L
s
.008 w
.24375 .14754 Mdot
.016 w
.24375 .14754 m
.24387 .1477 L
s
1 .942 0 r
.008 w
.24387 .1477 Mdot
.016 w
.24387 .1477 m
.24394 .14787 L
s
.008 w
.24394 .14787 Mdot
.016 w
.24394 .14787 m
.24396 .14803 L
s
1 .941 0 r
.008 w
.24396 .14803 Mdot
.016 w
.24396 .14803 m
.24396 .14817 L
s
.008 w
.24396 .14817 Mdot
.016 w
.24396 .14817 m
.24396 .14828 L
s
.008 w
.24396 .14828 Mdot
.016 w
.24396 .14828 m
.24402 .14834 L
s
1 .94 0 r
.008 w
.24402 .14834 Mdot
.016 w
.24402 .14834 m
.24411 .14834 L
s
.008 w
.24411 .14834 Mdot
.016 w
.24411 .14834 m
.24425 .14824 L
s
1 .939 0 r
.008 w
.24425 .14824 Mdot
.016 w
.24425 .14824 m
.24447 .14799 L
s
.008 w
.24447 .14799 Mdot
.016 w
.24447 .14799 m
.24481 .14759 L
s
.008 w
.24481 .14759 Mdot
.016 w
.24481 .14759 m
.24533 .14701 L
s
1 .938 0 r
.008 w
.24533 .14701 Mdot
.016 w
.24533 .14701 m
.24608 .14626 L
s
.008 w
.24608 .14626 Mdot
.016 w
.24608 .14626 m
.2471 .14533 L
s
1 .937 0 r
.008 w
.2471 .14533 Mdot
.016 w
.2471 .14533 m
.24843 .14434 L
s
.008 w
.24843 .14434 Mdot
.016 w
.24843 .14434 m
.24997 .14316 L
s
.008 w
.24997 .14316 Mdot
.016 w
.24997 .14316 m
.25179 .14176 L
s
1 .936 0 r
.008 w
.25179 .14176 Mdot
.016 w
.25179 .14176 m
.25405 .14034 L
s
.008 w
.25405 .14034 Mdot
.016 w
.25405 .14034 m
.25651 .13871 L
s
.008 w
.25651 .13871 Mdot
.016 w
.25651 .13871 m
.25932 .13691 L
s
1 .935 0 r
.008 w
.25932 .13691 Mdot
.016 w
.25932 .13691 m
.2627 .13503 L
s
.008 w
.2627 .13503 Mdot
.016 w
.2627 .13503 m
.26561 .13315 L
s
1 .934 0 r
.008 w
.26561 .13315 Mdot
.016 w
.26561 .13315 m
.26893 .13111 L
s
.008 w
.26893 .13111 Mdot
.016 w
.26893 .13111 m
.27257 .12919 L
s
.008 w
.27257 .12919 Mdot
.016 w
.27257 .12919 m
.27569 .12713 L
s
1 .933 0 r
.008 w
.27569 .12713 Mdot
.016 w
.27569 .12713 m
.27906 .1252 L
s
.008 w
.27906 .1252 Mdot
.016 w
.27906 .1252 m
.28232 .12316 L
s
1 .932 0 r
.008 w
.28232 .12316 Mdot
.016 w
.28232 .12316 m
.28565 .12098 L
s
.008 w
.28565 .12098 Mdot
.016 w
.28565 .12098 m
.28874 .11895 L
s
.008 w
.28874 .11895 Mdot
.016 w
.28874 .11895 m
.29197 .11669 L
s
1 .931 0 r
.008 w
.29197 .11669 Mdot
.016 w
.29197 .11669 m
.2954 .11459 L
s
.008 w
.2954 .11459 Mdot
.016 w
.2954 .11459 m
.29875 .11235 L
s
1 .93 0 r
.008 w
.29875 .11235 Mdot
.016 w
.29875 .11235 m
.30248 .10998 L
s
.008 w
.30248 .10998 Mdot
.016 w
.30248 .10998 m
.30607 .10778 L
s
.008 w
.30607 .10778 Mdot
.016 w
.30607 .10778 m
.30991 .10543 L
s
1 .929 0 r
.008 w
.30991 .10543 Mdot
.016 w
.30991 .10543 m
.31399 .1031 L
s
.008 w
.31399 .1031 Mdot
.016 w
.31399 .1031 m
.318 .10068 L
s
.008 w
.318 .10068 Mdot
.016 w
.318 .10068 m
.32208 .09823 L
s
1 .928 0 r
.008 w
.32208 .09823 Mdot
.016 w
.32208 .09823 m
.32671 .09562 L
s
.008 w
.32671 .09562 Mdot
.016 w
.32671 .09562 m
.33062 .0931 L
s
1 .927 0 r
.008 w
.33062 .0931 Mdot
.016 w
.33062 .0931 m
.33505 .09045 L
s
.008 w
.33505 .09045 Mdot
.016 w
.33505 .09045 m
.33922 .08787 L
s
.008 w
.33922 .08787 Mdot
.016 w
.33922 .08787 m
.34365 .08526 L
s
1 .926 0 r
.008 w
.34365 .08526 Mdot
.016 w
.34365 .08526 m
.34758 .08292 L
s
.008 w
.34758 .08292 Mdot
.016 w
.34758 .08292 m
.35139 .08068 L
s
1 .925 0 r
.008 w
.35139 .08068 Mdot
.016 w
.35139 .08068 m
.35495 .07853 L
s
.008 w
.35495 .07853 Mdot
.016 w
.35495 .07853 m
.35829 .07669 L
s
.008 w
.35829 .07669 Mdot
.016 w
.35829 .07669 m
.36117 .0752 L
s
1 .924 0 r
.008 w
.36117 .0752 Mdot
.016 w
.36117 .0752 m
.36375 .07387 L
s
.008 w
.36375 .07387 Mdot
.016 w
.36375 .07387 m
.36607 .07273 L
s
1 .923 0 r
.008 w
.36607 .07273 Mdot
.016 w
.36607 .07273 m
.36783 .07186 L
s
.008 w
.36783 .07186 Mdot
.016 w
.36783 .07186 m
.36939 .07121 L
s
.008 w
.36939 .07121 Mdot
.016 w
.36939 .07121 m
.37057 .0708 L
s
1 .922 0 r
.008 w
.37057 .0708 Mdot
.016 w
.37057 .0708 m
.37147 .07058 L
s
.008 w
.37147 .07058 Mdot
.016 w
.37147 .07058 m
.37209 .0705 L
s
.008 w
.37209 .0705 Mdot
.016 w
.37209 .0705 m
.37245 .07052 L
s
1 .921 0 r
.008 w
.37245 .07052 Mdot
.016 w
.37245 .07052 m
.37259 .07062 L
s
.008 w
.37259 .07062 Mdot
.016 w
.37259 .07062 m
.3726 .07077 L
s
1 .92 0 r
.008 w
.3726 .07077 Mdot
.016 w
.3726 .07077 m
.37251 .0709 L
s
.008 w
.37251 .0709 Mdot
.016 w
.37251 .0709 m
.37236 .07098 L
s
.008 w
.37236 .07098 Mdot
.016 w
.37236 .07098 m
.37219 .07101 L
s
1 .919 0 r
.008 w
.37219 .07101 Mdot
.016 w
.37219 .07101 m
.37204 .07104 L
s
.008 w
.37204 .07104 Mdot
.016 w
.37204 .07104 m
.37195 .07105 L
s
1 .918 0 r
.008 w
.37195 .07105 Mdot
.016 w
.37195 .07105 m
.37191 .07105 L
s
.008 w
.37191 .07105 Mdot
.016 w
.37191 .07105 m
.3719 .07105 L
s
.008 w
.3719 .07105 Mdot
.016 w
.3719 .07105 m
.37189 .07105 L
s
1 .917 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .916 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .915 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .914 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .913 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .912 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
1 .911 0 r
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37189 .07105 L
s
.008 w
.37189 .07105 Mdot
.016 w
.37189 .07105 m
.37188 .07105 L
s
.008 w
.37188 .07105 Mdot
.016 w
.37188 .07105 m
.37185 .07105 L
s
1 .91 0 r
.008 w
.37185 .07105 Mdot
.016 w
.37185 .07105 m
.3718 .07105 L
s
.008 w
.3718 .07105 Mdot
.016 w
.3718 .07105 m
.37173 .07104 L
s
.008 w
.37173 .07104 Mdot
.016 w
.37173 .07104 m
.37166 .07104 L
s
1 .909 0 r
.008 w
.37166 .07104 Mdot
.016 w
.37166 .07104 m
.37159 .07104 L
s
.008 w
.37159 .07104 Mdot
.016 w
.37159 .07104 m
.37153 .07104 L
s
1 .908 0 r
.008 w
.37153 .07104 Mdot
.016 w
.37153 .07104 m
.37153 .07104 L
s
.008 w
.37153 .07104 Mdot
.016 w
.37153 .07104 m
.37161 .07104 L
s
.008 w
.37161 .07104 Mdot
.016 w
.37161 .07104 m
.37178 .07107 L
s
1 .907 0 r
.008 w
.37178 .07107 Mdot
.016 w
.37178 .07107 m
.37207 .07113 L
s
.008 w
.37207 .07113 Mdot
.016 w
.37207 .07113 m
.37251 .07121 L
s
1 .906 0 r
.008 w
.37251 .07121 Mdot
.016 w
.37251 .07121 m
.37313 .07129 L
s
.008 w
.37313 .07129 Mdot
.016 w
.37313 .07129 m
.37392 .07135 L
s
.008 w
.37392 .07135 Mdot
.016 w
.37392 .07135 m
.37491 .07135 L
s
1 .905 0 r
.008 w
.37491 .07135 Mdot
.016 w
.37491 .07135 m
.3761 .0713 L
s
.008 w
.3761 .0713 Mdot
.016 w
.3761 .0713 m
.3775 .07117 L
s
1 .904 0 r
.008 w
.3775 .07117 Mdot
.016 w
.3775 .07117 m
.37906 .07097 L
s
.008 w
.37906 .07097 Mdot
.016 w
.37906 .07097 m
.38089 .07069 L
s
.008 w
.38089 .07069 Mdot
.016 w
.38089 .07069 m
.38273 .07037 L
s
1 .903 0 r
.008 w
.38273 .07037 Mdot
.016 w
.38273 .07037 m
.38483 .07001 L
s
.008 w
.38483 .07001 Mdot
.016 w
.38483 .07001 m
.38699 .06964 L
s
.008 w
.38699 .06964 Mdot
.016 w
.38699 .06964 m
.38932 .06927 L
s
1 .902 0 r
.008 w
.38932 .06927 Mdot
.016 w
.38932 .06927 m
.39142 .0689 L
s
.008 w
.39142 .0689 Mdot
.016 w
.39142 .0689 m
.39365 .06854 L
s
1 .901 0 r
.008 w
.39365 .06854 Mdot
.016 w
.39365 .06854 m
.39576 .0682 L
s
.008 w
.39576 .0682 Mdot
.016 w
.39576 .0682 m
.39777 .06792 L
s
.008 w
.39777 .06792 Mdot
.016 w
.39777 .06792 m
.39958 .06769 L
s
1 .9 0 r
.008 w
.39958 .06769 Mdot
.016 w
.39958 .06769 m
.40122 .06755 L
s
.008 w
.40122 .06755 Mdot
.016 w
.40122 .06755 m
.40265 .06748 L
s
1 .899 0 r
.008 w
.40265 .06748 Mdot
.016 w
.40265 .06748 m
.40388 .06748 L
s
.008 w
.40388 .06748 Mdot
.016 w
.40388 .06748 m
.40483 .06753 L
s
.008 w
.40483 .06753 Mdot
.016 w
.40483 .06753 m
.40557 .06762 L
s
1 .898 0 r
.008 w
.40557 .06762 Mdot
.016 w
.40557 .06762 m
.40612 .06771 L
s
.008 w
.40612 .06771 Mdot
.016 w
.40612 .06771 m
.40648 .06777 L
s
1 .897 0 r
.008 w
.40648 .06777 Mdot
.016 w
.40648 .06777 m
.40666 .0678 L
s
.008 w
.40666 .0678 Mdot
.016 w
.40666 .0678 m
.40672 .06781 L
s
.008 w
.40672 .06781 Mdot
.016 w
.40672 .06781 m
.40668 .06781 L
s
1 .896 0 r
.008 w
.40668 .06781 Mdot
.016 w
.40668 .06781 m
.40659 .0678 L
s
.008 w
.40659 .0678 Mdot
.016 w
.40659 .0678 m
.40648 .0678 L
s
.008 w
.40648 .0678 Mdot
.016 w
.40648 .0678 m
.40637 .0678 L
s
1 .895 0 r
.008 w
.40637 .0678 Mdot
.016 w
.40637 .0678 m
.40628 .06779 L
s
.008 w
.40628 .06779 Mdot
.016 w
.40628 .06779 m
.40622 .06779 L
s
1 .894 0 r
.008 w
.40622 .06779 Mdot
.016 w
.40622 .06779 m
.40617 .06779 L
s
.008 w
.40617 .06779 Mdot
.016 w
.40617 .06779 m
.40613 .06779 L
s
.008 w
.40613 .06779 Mdot
.016 w
.40613 .06779 m
.4061 .06779 L
s
1 .893 0 r
.008 w
.4061 .06779 Mdot
.016 w
.4061 .06779 m
.40608 .06779 L
s
.008 w
.40608 .06779 Mdot
.016 w
.40608 .06779 m
.40609 .06779 L
s
1 .892 0 r
.008 w
.40609 .06779 Mdot
.016 w
.40609 .06779 m
.40614 .06779 L
s
.008 w
.40614 .06779 Mdot
.016 w
.40614 .06779 m
.40624 .06779 L
s
.008 w
.40624 .06779 Mdot
.016 w
.40624 .06779 m
.40637 .06779 L
s
1 .891 0 r
.008 w
.40637 .06779 Mdot
.016 w
.40637 .06779 m
.40654 .06779 L
s
.008 w
.40654 .06779 Mdot
.016 w
.40654 .06779 m
.40674 .0678 L
s
1 .89 0 r
.008 w
.40674 .0678 Mdot
.016 w
.40674 .0678 m
.40697 .06781 L
s
.008 w
.40697 .06781 Mdot
.016 w
.40697 .06781 m
.4072 .06782 L
s
.008 w
.4072 .06782 Mdot
.016 w
.4072 .06782 m
.40744 .06784 L
s
1 .889 0 r
.008 w
.40744 .06784 Mdot
.016 w
.40744 .06784 m
.40768 .06785 L
s
.008 w
.40768 .06785 Mdot
.016 w
.40768 .06785 m
.4079 .06785 L
s
.008 w
.4079 .06785 Mdot
.016 w
.4079 .06785 m
.40811 .06781 L
s
1 .888 0 r
.008 w
.40811 .06781 Mdot
.016 w
.40811 .06781 m
.4083 .06775 L
s
.008 w
.4083 .06775 Mdot
.016 w
.4083 .06775 m
.40844 .06769 L
s
1 .887 0 r
.008 w
.40844 .06769 Mdot
.016 w
.40844 .06769 m
.40855 .06766 L
s
.008 w
.40855 .06766 Mdot
.016 w
.40855 .06766 m
.40861 .0677 L
s
.008 w
.40861 .0677 Mdot
.016 w
.40861 .0677 m
.40862 .06782 L
s
1 .886 0 r
.008 w
.40862 .06782 Mdot
.016 w
.40862 .06782 m
.40861 .06804 L
s
.008 w
.40861 .06804 Mdot
.016 w
.40861 .06804 m
.40858 .06836 L
s
1 .885 0 r
.008 w
.40858 .06836 Mdot
.016 w
.40858 .06836 m
.40854 .06873 L
s
.008 w
.40854 .06873 Mdot
.016 w
.40854 .06873 m
.40851 .06913 L
s
.008 w
.40851 .06913 Mdot
.016 w
.40851 .06913 m
.40848 .0695 L
s
1 .884 0 r
.008 w
.40848 .0695 Mdot
.016 w
.40848 .0695 m
.40845 .06982 L
s
.008 w
.40845 .06982 Mdot
.016 w
.40845 .06982 m
.40841 .07006 L
s
1 .883 0 r
.008 w
.40841 .07006 Mdot
.016 w
.40841 .07006 m
.40836 .07022 L
s
.008 w
.40836 .07022 Mdot
.016 w
.40836 .07022 m
.40829 .07028 L
s
.008 w
.40829 .07028 Mdot
.016 w
.40829 .07028 m
.40821 .07025 L
s
1 .882 0 r
.008 w
.40821 .07025 Mdot
.016 w
.40821 .07025 m
.40813 .07012 L
s
.008 w
.40813 .07012 Mdot
.016 w
.40813 .07012 m
.4081 .06989 L
s
.008 w
.4081 .06989 Mdot
.016 w
.4081 .06989 m
.40811 .0696 L
s
1 .881 0 r
.008 w
.40811 .0696 Mdot
.016 w
.40811 .0696 m
.40821 .06928 L
s
.008 w
.40821 .06928 Mdot
.016 w
.40821 .06928 m
.40842 .06897 L
s
1 .88 0 r
.008 w
.40842 .06897 Mdot
.016 w
.40842 .06897 m
.40879 .06871 L
s
.008 w
.40879 .06871 Mdot
.016 w
.40879 .06871 m
.40934 .06858 L
s
.008 w
.40934 .06858 Mdot
.016 w
.40934 .06858 m
.41011 .06865 L
s
1 .879 0 r
.008 w
.41011 .06865 Mdot
.016 w
.41011 .06865 m
.41111 .0689 L
s
.008 w
.41111 .0689 Mdot
.016 w
.41111 .0689 m
.41241 .06929 L
s
1 .878 0 r
.008 w
.41241 .06929 Mdot
.016 w
.41241 .06929 m
.41393 .06975 L
s
.008 w
.41393 .06975 Mdot
.016 w
.41393 .06975 m
.4158 .07023 L
s
.008 w
.4158 .07023 Mdot
.016 w
.4158 .07023 m
.41784 .0707 L
s
1 .877 0 r
.008 w
.41784 .0707 Mdot
.016 w
.41784 .0707 m
.4202 .0711 L
s
.008 w
.4202 .0711 Mdot
.016 w
.4202 .0711 m
.42281 .07138 L
s
.008 w
.42281 .07138 Mdot
.016 w
.42281 .07138 m
.42581 .07154 L
s
1 .876 0 r
.008 w
.42581 .07154 Mdot
.016 w
.42581 .07154 m
.42851 .07157 L
s
.008 w
.42851 .07157 Mdot
.016 w
.42851 .07157 m
.43164 .07149 L
s
1 .875 0 r
.008 w
.43164 .07149 Mdot
.016 w
.43164 .07149 m
.435 .0713 L
s
.008 w
.435 .0713 Mdot
.016 w
.435 .0713 m
.43803 .07105 L
s
.008 w
.43803 .07105 Mdot
.016 w
.43803 .07105 m
.44126 .07077 L
s
1 .874 0 r
.008 w
.44126 .07077 Mdot
.016 w
.44126 .07077 m
.44449 .07047 L
s
.008 w
.44449 .07047 Mdot
.016 w
.44449 .07047 m
.44801 .07022 L
s
1 .873 0 r
.008 w
.44801 .07022 Mdot
.016 w
.44801 .07022 m
.4509 .07 L
s
.008 w
.4509 .07 Mdot
.016 w
.4509 .07 m
.45414 .06983 L
s
.008 w
.45414 .06983 Mdot
.016 w
.45414 .06983 m
.45758 .06971 L
s
1 .872 0 r
.008 w
.45758 .06971 Mdot
.016 w
.45758 .06971 m
.46068 .06962 L
s
.008 w
.46068 .06962 Mdot
.016 w
.46068 .06962 m
.46394 .06948 L
s
1 .871 0 r
.008 w
.46394 .06948 Mdot
.016 w
.46394 .06948 m
.46717 .06927 L
s
.008 w
.46717 .06927 Mdot
.016 w
.46717 .06927 m
.47057 .06897 L
s
.008 w
.47057 .06897 Mdot
.016 w
.47057 .06897 m
.47423 .06863 L
s
1 .87 0 r
.008 w
.47423 .06863 Mdot
.016 w
.47423 .06863 m
.47754 .06825 L
s
.008 w
.47754 .06825 Mdot
.016 w
.47754 .06825 m
.48106 .06787 L
s
.008 w
.48106 .06787 Mdot
.016 w
.48106 .06787 m
.48474 .06757 L
s
1 .869 0 r
.008 w
.48474 .06757 Mdot
.016 w
.48474 .06757 m
.48809 .06733 L
s
.008 w
.48809 .06733 Mdot
.016 w
.48809 .06733 m
.49179 .06719 L
s
1 .868 0 r
.008 w
.49179 .06719 Mdot
.016 w
.49179 .06719 m
.49522 .06715 L
s
.008 w
.49522 .06715 Mdot
.016 w
.49522 .06715 m
.49887 .06726 L
s
.008 w
.49887 .06726 Mdot
.016 w
.49887 .06726 m
.50249 .06753 L
s
1 .867 0 r
.008 w
.50249 .06753 Mdot
.016 w
.50249 .06753 m
.50586 .06798 L
s
.008 w
.50586 .06798 Mdot
.016 w
.50586 .06798 m
.50943 .06858 L
s
1 .866 0 r
.008 w
.50943 .06858 Mdot
.016 w
.50943 .06858 m
.51277 .06928 L
s
.008 w
.51277 .06928 Mdot
.016 w
.51277 .06928 m
.51608 .07012 L
s
.008 w
.51608 .07012 Mdot
.016 w
.51608 .07012 m
.51945 .07104 L
s
1 .865 0 r
.008 w
.51945 .07104 Mdot
.016 w
.51945 .07104 m
.52288 .07198 L
s
.008 w
.52288 .07198 Mdot
.016 w
.52288 .07198 m
.52618 .07288 L
s
1 .864 0 r
.008 w
.52618 .07288 Mdot
.016 w
.52618 .07288 m
.52948 .07368 L
s
.008 w
.52948 .07368 Mdot
.016 w
.52948 .07368 m
.53279 .07439 L
s
.008 w
.53279 .07439 Mdot
.016 w
.53279 .07439 m
.53611 .07506 L
s
1 .863 0 r
.008 w
.53611 .07506 Mdot
.016 w
.53611 .07506 m
.53938 .07571 L
s
.008 w
.53938 .07571 Mdot
.016 w
.53938 .07571 m
.54263 .07638 L
s
.008 w
.54263 .07638 Mdot
.016 w
.54263 .07638 m
.54579 .0771 L
s
1 .862 0 r
.008 w
.54579 .0771 Mdot
.016 w
.54579 .0771 m
.54897 .07787 L
s
.008 w
.54897 .07787 Mdot
.016 w
.54897 .07787 m
.55192 .07872 L
s
1 .861 0 r
.008 w
.55192 .07872 Mdot
.016 w
.55192 .07872 m
.55474 .07963 L
s
.008 w
.55474 .07963 Mdot
.016 w
.55474 .07963 m
.5574 .08057 L
s
.008 w
.5574 .08057 Mdot
.016 w
.5574 .08057 m
.55975 .08152 L
s
1 .86 0 r
.008 w
.55975 .08152 Mdot
.016 w
.55975 .08152 m
.56187 .08233 L
s
.008 w
.56187 .08233 Mdot
.016 w
.56187 .08233 m
.5637 .08321 L
s
1 .859 0 r
.008 w
.5637 .08321 Mdot
.016 w
.5637 .08321 m
.56524 .08412 L
s
.008 w
.56524 .08412 Mdot
.016 w
.56524 .08412 m
.5664 .0849 L
s
.008 w
.5664 .0849 Mdot
.016 w
.5664 .0849 m
.56725 .08561 L
s
1 .858 0 r
.008 w
.56725 .08561 Mdot
.016 w
.56725 .08561 m
.56783 .08623 L
s
.008 w
.56783 .08623 Mdot
.016 w
.56783 .08623 m
.56816 .08673 L
s
1 .857 0 r
.008 w
.56816 .08673 Mdot
.016 w
.56816 .08673 m
.56829 .08709 L
s
.008 w
.56829 .08709 Mdot
.016 w
.56829 .08709 m
.56832 .08732 L
s
.008 w
.56832 .08732 Mdot
.016 w
.56832 .08732 m
.56836 .08742 L
s
1 .856 0 r
.008 w
.56836 .08742 Mdot
.016 w
.56836 .08742 m
.56851 .08742 L
s
.008 w
.56851 .08742 Mdot
.016 w
.56851 .08742 m
.56884 .08738 L
s
.008 w
.56884 .08738 Mdot
.016 w
.56884 .08738 m
.56941 .08735 L
s
1 .855 0 r
.008 w
.56941 .08735 Mdot
.016 w
.56941 .08735 m
.57029 .08736 L
s
.008 w
.57029 .08736 Mdot
.016 w
.57029 .08736 m
.57153 .08739 L
s
1 .854 0 r
.008 w
.57153 .08739 Mdot
.016 w
.57153 .08739 m
.57308 .08743 L
s
.008 w
.57308 .08743 Mdot
.016 w
.57308 .08743 m
.57513 .08746 L
s
.008 w
.57513 .08746 Mdot
.016 w
.57513 .08746 m
.57758 .08744 L
s
1 .853 0 r
.008 w
.57758 .08744 Mdot
.016 w
.57758 .08744 m
.58033 .08735 L
s
.008 w
.58033 .08735 Mdot
.016 w
.58033 .08735 m
.58339 .08719 L
s
1 .852 0 r
.008 w
.58339 .08719 Mdot
.016 w
.58339 .08719 m
.5867 .08695 L
s
.008 w
.5867 .08695 Mdot
.016 w
.5867 .08695 m
.58988 .08661 L
s
.008 w
.58988 .08661 Mdot
.016 w
.58988 .08661 m
.59311 .08622 L
s
1 .851 0 r
.008 w
.59311 .08622 Mdot
.016 w
.59311 .08622 m
.59606 .08579 L
s
.008 w
.59606 .08579 Mdot
.016 w
.59606 .08579 m
.59896 .0854 L
s
1 .85 0 r
.008 w
.59896 .0854 Mdot
.016 w
.59896 .0854 m
.60141 .08503 L
s
.008 w
.60141 .08503 Mdot
.016 w
.60141 .08503 m
.60382 .08472 L
s
.008 w
.60382 .08472 Mdot
.016 w
.60382 .08472 m
.60608 .08452 L
s
1 .849 0 r
.008 w
.60608 .08452 Mdot
.016 w
.60608 .08452 m
.608 .08446 L
s
.008 w
.608 .08446 Mdot
.016 w
.608 .08446 m
.60989 .08458 L
s
.008 w
.60989 .08458 Mdot
.016 w
.60989 .08458 m
.61179 .08492 L
s
1 .848 0 r
.008 w
.61179 .08492 Mdot
.016 w
.61179 .08492 m
.61374 .08547 L
s
.008 w
.61374 .08547 Mdot
.016 w
.61374 .08547 m
.61579 .08625 L
s
1 .847 0 r
.008 w
.61579 .08625 Mdot
.016 w
.61579 .08625 m
.61783 .08718 L
s
.008 w
.61783 .08718 Mdot
.016 w
.61783 .08718 m
.62 .08829 L
s
.008 w
.62 .08829 Mdot
.016 w
.62 .08829 m
.62215 .08957 L
s
1 .846 0 r
.008 w
.62215 .08957 Mdot
.016 w
.62215 .08957 m
.62451 .09092 L
s
.008 w
.62451 .09092 Mdot
.016 w
.62451 .09092 m
.62708 .09236 L
s
1 .845 0 r
.008 w
.62708 .09236 Mdot
.016 w
.62708 .09236 m
.63 .09377 L
s
.008 w
.63 .09377 Mdot
.016 w
.63 .09377 m
.63257 .09512 L
s
.008 w
.63257 .09512 Mdot
.016 w
.63257 .09512 m
.63533 .09641 L
s
1 .844 0 r
.008 w
.63533 .09641 Mdot
.016 w
.63533 .09641 m
.63805 .09756 L
s
.008 w
.63805 .09756 Mdot
.016 w
.63805 .09756 m
.6409 .09853 L
s
1 .843 0 r
.008 w
.6409 .09853 Mdot
.016 w
.6409 .09853 m
.64344 .09939 L
s
.008 w
.64344 .09939 Mdot
.016 w
.64344 .09939 m
.64607 .10013 L
s
.008 w
.64607 .10013 Mdot
.016 w
.64607 .10013 m
.64869 .10074 L
s
1 .842 0 r
.008 w
.64869 .10074 Mdot
.016 w
.64869 .10074 m
.65132 .10129 L
s
.008 w
.65132 .10129 Mdot
.016 w
.65132 .10129 m
.6542 .1018 L
s
.008 w
.6542 .1018 Mdot
.016 w
.6542 .1018 m
.65707 .10231 L
s
1 .841 0 r
.008 w
.65707 .10231 Mdot
.016 w
.65707 .10231 m
.66011 .10283 L
s
.008 w
.66011 .10283 Mdot
.016 w
.66011 .10283 m
.66342 .10341 L
s
1 .84 0 r
.008 w
.66342 .10341 Mdot
.016 w
.66342 .10341 m
.66668 .10408 L
s
.008 w
.66668 .10408 Mdot
.016 w
.66668 .10408 m
.67012 .10481 L
s
.008 w
.67012 .10481 Mdot
.016 w
.67012 .10481 m
.67371 .10558 L
s
1 .839 0 r
.008 w
.67371 .10558 Mdot
.016 w
.67371 .10558 m
.6771 .10648 L
s
.008 w
.6771 .10648 Mdot
.016 w
.6771 .10648 m
.68062 .10753 L
s
1 .838 0 r
.008 w
.68062 .10753 Mdot
.016 w
.68062 .10753 m
.68395 .10876 L
s
.008 w
.68395 .10876 Mdot
.016 w
.68395 .10876 m
.68741 .11 L
s
.008 w
.68741 .11 Mdot
.016 w
.68741 .11 m
.69048 .11136 L
s
1 .837 0 r
.008 w
.69048 .11136 Mdot
.016 w
.69048 .11136 m
.69368 .11281 L
s
.008 w
.69368 .11281 Mdot
.016 w
.69368 .11281 m
.69688 .11427 L
s
.008 w
.69688 .11427 Mdot
.016 w
.69688 .11427 m
.69977 .1157 L
s
1 .836 0 r
.008 w
.69977 .1157 Mdot
.016 w
.69977 .1157 m
.70295 .11714 L
s
.008 w
.70295 .11714 Mdot
.016 w
.70295 .11714 m
.70566 .11839 L
s
1 .835 0 r
.008 w
.70566 .11839 Mdot
.016 w
.70566 .11839 m
.70825 .11966 L
s
.008 w
.70825 .11966 Mdot
.016 w
.70825 .11966 m
.71068 .12077 L
s
.008 w
.71068 .12077 Mdot
.016 w
.71068 .12077 m
.71285 .1218 L
s
1 .834 0 r
.008 w
.71285 .1218 Mdot
.016 w
.71285 .1218 m
.71491 .1227 L
s
.008 w
.71491 .1227 Mdot
.016 w
.71491 .1227 m
.7164 .12342 L
s
1 .833 0 r
.008 w
.7164 .12342 Mdot
.016 w
.7164 .12342 m
.71767 .12394 L
s
.008 w
.71767 .12394 Mdot
.016 w
.71767 .12394 m
.7187 .12425 L
s
.008 w
.7187 .12425 Mdot
.016 w
.7187 .12425 m
.71942 .12434 L
s
1 .832 0 r
.008 w
.71942 .12434 Mdot
.016 w
.71942 .12434 m
.71984 .12426 L
s
.008 w
.71984 .12426 Mdot
.016 w
.71984 .12426 m
.71998 .12402 L
s
1 .831 0 r
.008 w
.71998 .12402 Mdot
.016 w
.71998 .12402 m
.71989 .12367 L
s
.008 w
.71989 .12367 Mdot
.016 w
.71989 .12367 m
.71965 .12333 L
s
.008 w
.71965 .12333 Mdot
.016 w
.71965 .12333 m
.71935 .12305 L
s
1 .83 0 r
.008 w
.71935 .12305 Mdot
.016 w
.71935 .12305 m
.71907 .12285 L
s
.008 w
.71907 .12285 Mdot
.016 w
.71907 .12285 m
.7188 .12276 L
s
.008 w
.7188 .12276 Mdot
.016 w
.7188 .12276 m
.71862 .12277 L
s
1 .829 0 r
.008 w
.71862 .12277 Mdot
.016 w
.71862 .12277 m
.71859 .12292 L
s
.008 w
.71859 .12292 Mdot
.016 w
.71859 .12292 m
.71871 .12318 L
s
1 .828 0 r
.008 w
.71871 .12318 Mdot
.016 w
.71871 .12318 m
.71889 .12353 L
s
.008 w
.71889 .12353 Mdot
.016 w
.71889 .12353 m
.7191 .12393 L
s
.008 w
.7191 .12393 Mdot
.016 w
.7191 .12393 m
.71934 .12436 L
s
1 .827 0 r
.008 w
.71934 .12436 Mdot
.016 w
.71934 .12436 m
.71959 .12477 L
s
.008 w
.71959 .12477 Mdot
.016 w
.71959 .12477 m
.71982 .12514 L
s
1 .826 0 r
.008 w
.71982 .12514 Mdot
.016 w
.71982 .12514 m
.72001 .12542 L
s
.008 w
.72001 .12542 Mdot
.016 w
.72001 .12542 m
.72009 .12558 L
s
.008 w
.72009 .12558 Mdot
.016 w
.72009 .12558 m
.72006 .12563 L
s
1 .825 0 r
.008 w
.72006 .12563 Mdot
.016 w
.72006 .12563 m
.71997 .12557 L
s
.008 w
.71997 .12557 Mdot
.016 w
.71997 .12557 m
.71983 .12543 L
s
1 .824 0 r
.008 w
.71983 .12543 Mdot
.016 w
.71983 .12543 m
.71969 .12524 L
s
.008 w
.71969 .12524 Mdot
.016 w
.71969 .12524 m
.71961 .125 L
s
.008 w
.71961 .125 Mdot
.016 w
.71961 .125 m
.71967 .1248 L
s
1 .823 0 r
.008 w
.71967 .1248 Mdot
.016 w
.71967 .1248 m
.71992 .12469 L
s
.008 w
.71992 .12469 Mdot
.016 w
.71992 .12469 m
.72042 .12473 L
s
.008 w
.72042 .12473 Mdot
.016 w
.72042 .12473 m
.7212 .12494 L
s
1 .822 0 r
.008 w
.7212 .12494 Mdot
.016 w
.7212 .12494 m
.72227 .12534 L
s
.008 w
.72227 .12534 Mdot
.016 w
.72227 .12534 m
.72366 .12593 L
s
1 .821 0 r
.008 w
.72366 .12593 Mdot
.016 w
.72366 .12593 m
.72525 .1267 L
s
.008 w
.72525 .1267 Mdot
.016 w
.72525 .1267 m
.72702 .12755 L
s
.008 w
.72702 .12755 Mdot
.016 w
.72702 .12755 m
.72906 .12852 L
s
1 .82 0 r
.008 w
.72906 .12852 Mdot
.016 w
.72906 .12852 m
.73131 .12957 L
s
.008 w
.73131 .12957 Mdot
.016 w
.73131 .12957 m
.73377 .13066 L
s
1 .819 0 r
.008 w
.73377 .13066 Mdot
.016 w
.73377 .13066 m
.73614 .13166 L
s
.008 w
.73614 .13166 Mdot
.016 w
.73614 .13166 m
.7384 .13259 L
s
.008 w
.7384 .13259 Mdot
.016 w
.7384 .13259 m
.74059 .13343 L
s
1 .818 0 r
.008 w
.74059 .13343 Mdot
.016 w
.74059 .13343 m
.74258 .13414 L
s
.008 w
.74258 .13414 Mdot
.016 w
.74258 .13414 m
.74426 .1347 L
s
1 .817 0 r
.008 w
.74426 .1347 Mdot
.016 w
.74426 .1347 m
.7457 .13511 L
s
.008 w
.7457 .13511 Mdot
.016 w
.7457 .13511 m
.74687 .13538 L
s
.008 w
.74687 .13538 Mdot
.016 w
.74687 .13538 m
.74775 .13554 L
s
1 .816 0 r
.008 w
.74775 .13554 Mdot
.016 w
.74775 .13554 m
.74843 .13562 L
s
.008 w
.74843 .13562 Mdot
.016 w
.74843 .13562 m
.74895 .13565 L
s
.008 w
.74895 .13565 Mdot
.016 w
.74895 .13565 m
.74936 .13564 L
s
1 .815 0 r
.008 w
.74936 .13564 Mdot
.016 w
.74936 .13564 m
.74965 .13561 L
s
.008 w
.74965 .13561 Mdot
.016 w
.74965 .13561 m
.74986 .13557 L
s
1 .814 0 r
.008 w
.74986 .13557 Mdot
.016 w
.74986 .13557 m
.75002 .13554 L
s
.008 w
.75002 .13554 Mdot
.016 w
.75002 .13554 m
.75013 .13551 L
s
.008 w
.75013 .13551 Mdot
.016 w
.75013 .13551 m
.75023 .13548 L
s
1 .813 0 r
.008 w
.75023 .13548 Mdot
.016 w
.75023 .13548 m
.75033 .13546 L
s
.008 w
.75033 .13546 Mdot
.016 w
.75033 .13546 m
.75045 .13542 L
s
1 .812 0 r
.008 w
.75045 .13542 Mdot
.016 w
.75045 .13542 m
.75057 .13539 L
s
.008 w
.75057 .13539 Mdot
.016 w
.75057 .13539 m
.75068 .13537 L
s
.008 w
.75068 .13537 Mdot
.016 w
.75068 .13537 m
.75076 .13537 L
s
1 .811 0 r
.008 w
.75076 .13537 Mdot
.016 w
.75076 .13537 m
.75081 .13539 L
s
.008 w
.75081 .13539 Mdot
.016 w
.75081 .13539 m
.75081 .13542 L
s
1 .81 0 r
.008 w
.75081 .13542 Mdot
.016 w
.75081 .13542 m
.75077 .13547 L
s
.008 w
.75077 .13547 Mdot
.016 w
.75077 .13547 m
.75067 .13554 L
s
.008 w
.75067 .13554 Mdot
.016 w
.75067 .13554 m
.75054 .13564 L
s
1 .809 0 r
.008 w
.75054 .13564 Mdot
.016 w
.75054 .13564 m
.75039 .13576 L
s
.008 w
.75039 .13576 Mdot
.016 w
.75039 .13576 m
.75026 .13593 L
s
.008 w
.75026 .13593 Mdot
.016 w
.75026 .13593 m
.75018 .13617 L
s
1 .808 0 r
.008 w
.75018 .13617 Mdot
.016 w
.75018 .13617 m
.75019 .1365 L
s
.008 w
.75019 .1365 Mdot
.016 w
.75019 .1365 m
.75032 .1369 L
s
1 .807 0 r
.008 w
.75032 .1369 Mdot
.016 w
.75032 .1369 m
.75061 .13736 L
s
.008 w
.75061 .13736 Mdot
.016 w
.75061 .13736 m
.75109 .1379 L
s
.008 w
.75109 .1379 Mdot
.016 w
.75109 .1379 m
.7518 .13848 L
s
1 .806 0 r
.008 w
.7518 .13848 Mdot
.016 w
.7518 .13848 m
.75274 .13916 L
s
.008 w
.75274 .13916 Mdot
.016 w
.75274 .13916 m
.75389 .13995 L
s
1 .805 0 r
.008 w
.75389 .13995 Mdot
.016 w
.75389 .13995 m
.75538 .14087 L
s
.008 w
.75538 .14087 Mdot
.016 w
.75538 .14087 m
.75705 .14192 L
s
.008 w
.75705 .14192 Mdot
.016 w
.75705 .14192 m
.75895 .1431 L
s
1 .804 0 r
.008 w
.75895 .1431 Mdot
.016 w
.75895 .1431 m
.76111 .14443 L
s
.008 w
.76111 .14443 Mdot
.016 w
.76111 .14443 m
.76346 .14586 L
s
1 .803 0 r
.008 w
.76346 .14586 Mdot
.016 w
.76346 .14586 m
.76585 .1474 L
s
.008 w
.76585 .1474 Mdot
.016 w
.76585 .1474 m
.76824 .14901 L
s
.008 w
.76824 .14901 Mdot
.016 w
.76824 .14901 m
.77057 .15046 L
s
1 .802 0 r
.008 w
.77057 .15046 Mdot
.016 w
.77057 .15046 m
.77271 .1519 L
s
.008 w
.77271 .1519 Mdot
.016 w
.77271 .1519 m
.77456 .15313 L
s
.008 w
.77456 .15313 Mdot
.016 w
.77456 .15313 m
.77625 .15426 L
s
1 .801 0 r
.008 w
.77625 .15426 Mdot
.016 w
.77625 .15426 m
.77777 .15535 L
s
.008 w
.77777 .15535 Mdot
.016 w
.77777 .15535 m
.77895 .15627 L
s
1 .8 0 r
.008 w
.77895 .15627 Mdot
.016 w
.77895 .15627 m
.77995 .1571 L
s
.008 w
.77995 .1571 Mdot
.016 w
.77995 .1571 m
.78078 .15786 L
s
.008 w
.78078 .15786 Mdot
.016 w
.78078 .15786 m
.78146 .15866 L
s
1 .799 0 r
.008 w
.78146 .15866 Mdot
.016 w
.78146 .15866 m
.78204 .15954 L
s
.008 w
.78204 .15954 Mdot
.016 w
.78204 .15954 m
.78253 .16046 L
s
1 .798 0 r
.008 w
.78253 .16046 Mdot
.016 w
.78253 .16046 m
.78295 .16144 L
s
.008 w
.78295 .16144 Mdot
.016 w
.78295 .16144 m
.78334 .16243 L
s
.008 w
.78334 .16243 Mdot
.016 w
.78334 .16243 m
.78372 .16355 L
s
1 .797 0 r
.008 w
.78372 .16355 Mdot
.016 w
.78372 .16355 m
.78404 .16455 L
s
.008 w
.78404 .16455 Mdot
.016 w
.78404 .16455 m
.78429 .16565 L
s
.008 w
.78429 .16565 Mdot
.016 w
.78429 .16565 m
.78451 .16665 L
s
1 .796 0 r
.008 w
.78451 .16665 Mdot
.016 w
.78451 .16665 m
.78474 .16765 L
s
.008 w
.78474 .16765 Mdot
.016 w
.78474 .16765 m
.785 .16874 L
s
1 .795 0 r
.008 w
.785 .16874 Mdot
.016 w
.785 .16874 m
.78531 .16961 L
s
.008 w
.78531 .16961 Mdot
.016 w
.78531 .16961 m
.78573 .17047 L
s
.008 w
.78573 .17047 Mdot
.016 w
.78573 .17047 m
.78629 .17131 L
s
1 .794 0 r
.008 w
.78629 .17131 Mdot
.016 w
.78629 .17131 m
.7871 .17218 L
s
.008 w
.7871 .17218 Mdot
.016 w
.7871 .17218 m
.7882 .17305 L
s
1 .793 0 r
.008 w
.7882 .17305 Mdot
.016 w
.7882 .17305 m
.7896 .17398 L
s
.008 w
.7896 .17398 Mdot
.016 w
.7896 .17398 m
.79116 .17496 L
s
.008 w
.79116 .17496 Mdot
.016 w
.79116 .17496 m
.79296 .1763 L
s
1 .792 0 r
.008 w
.79296 .1763 Mdot
.016 w
.79296 .1763 m
.79495 .17783 L
s
.008 w
.79495 .17783 Mdot
.016 w
.79495 .17783 m
.79702 .17957 L
s
1 .791 0 r
.008 w
.79702 .17957 Mdot
.016 w
.79702 .17957 m
.79939 .18149 L
s
.008 w
.79939 .18149 Mdot
.016 w
.79939 .18149 m
.80206 .1836 L
s
.008 w
.80206 .1836 Mdot
.016 w
.80206 .1836 m
.80438 .18579 L
s
1 .79 0 r
.008 w
.80438 .18579 Mdot
.016 w
.80438 .18579 m
.80677 .18811 L
s
.008 w
.80677 .18811 Mdot
.016 w
.80677 .18811 m
.80905 .19043 L
s
.008 w
.80905 .19043 Mdot
.016 w
.80905 .19043 m
.8111 .19283 L
s
1 .789 0 r
.008 w
.8111 .19283 Mdot
.016 w
.8111 .19283 m
.81293 .19505 L
s
.008 w
.81293 .19505 Mdot
.016 w
.81293 .19505 m
.81464 .19736 L
s
1 .788 0 r
.008 w
.81464 .19736 Mdot
.016 w
.81464 .19736 m
.81613 .19954 L
s
.008 w
.81613 .19954 Mdot
.016 w
.81613 .19954 m
.8175 .20175 L
s
.008 w
.8175 .20175 Mdot
.016 w
.8175 .20175 m
.81883 .204 L
s
1 .787 0 r
.008 w
.81883 .204 Mdot
.016 w
.81883 .204 m
.8201 .20615 L
s
.008 w
.8201 .20615 Mdot
.016 w
.8201 .20615 m
.82136 .20809 L
s
1 .786 0 r
.008 w
.82136 .20809 Mdot
.016 w
.82136 .20809 m
.82263 .21 L
s
.008 w
.82263 .21 Mdot
.016 w
.82263 .21 m
.82387 .21183 L
s
.008 w
.82387 .21183 Mdot
.016 w
.82387 .21183 m
.82514 .2136 L
s
1 .785 0 r
.008 w
.82514 .2136 Mdot
.016 w
.82514 .2136 m
.82644 .21523 L
s
.008 w
.82644 .21523 Mdot
.016 w
.82644 .21523 m
.82771 .21683 L
s
1 .784 0 r
.008 w
.82771 .21683 Mdot
.016 w
.82771 .21683 m
.82905 .21838 L
s
.008 w
.82905 .21838 Mdot
.016 w
.82905 .21838 m
.83039 .21991 L
s
.008 w
.83039 .21991 Mdot
.016 w
.83039 .21991 m
.8317 .22139 L
s
1 .783 0 r
.008 w
.8317 .22139 Mdot
.016 w
.8317 .22139 m
.83308 .22296 L
s
.008 w
.83308 .22296 Mdot
.016 w
.83308 .22296 m
.83449 .22469 L
s
.008 w
.83449 .22469 Mdot
.016 w
.83449 .22469 m
.83592 .22645 L
s
1 .782 0 r
.008 w
.83592 .22645 Mdot
.016 w
.83592 .22645 m
.8375 .22851 L
s
.008 w
.8375 .22851 Mdot
.016 w
.8375 .22851 m
.83922 .23061 L
s
1 .781 0 r
.008 w
.83922 .23061 Mdot
.016 w
.83922 .23061 m
.84081 .23301 L
s
.008 w
.84081 .23301 Mdot
.016 w
.84081 .23301 m
.84256 .23531 L
s
.008 w
.84256 .23531 Mdot
.016 w
.84256 .23531 m
.8443 .23788 L
s
1 .78 0 r
.008 w
.8443 .23788 Mdot
.016 w
.8443 .23788 m
.84609 .2404 L
s
.008 w
.84609 .2404 Mdot
.016 w
.84609 .2404 m
.84792 .24294 L
s
1 .779 0 r
.008 w
.84792 .24294 Mdot
.016 w
.84792 .24294 m
.84954 .24534 L
s
.008 w
.84954 .24534 Mdot
.016 w
.84954 .24534 m
.85111 .24758 L
s
.008 w
.85111 .24758 Mdot
.016 w
.85111 .24758 m
.85248 .24961 L
s
1 .778 0 r
.008 w
.85248 .24961 Mdot
.016 w
.85248 .24961 m
.85364 .25112 L
s
.008 w
.85364 .25112 Mdot
.016 w
.85364 .25112 m
.85451 .25236 L
s
1 .777 0 r
.008 w
.85451 .25236 Mdot
.016 w
.85451 .25236 m
.85516 .25329 L
s
.008 w
.85516 .25329 Mdot
.016 w
.85516 .25329 m
.85557 .25392 L
s
.008 w
.85557 .25392 Mdot
.016 w
.85557 .25392 m
.8557 .25421 L
s
1 .776 0 r
.008 w
.8557 .25421 Mdot
.016 w
.8557 .25421 m
.8556 .25418 L
s
.008 w
.8556 .25418 Mdot
.016 w
.8556 .25418 m
.85533 .25389 L
s
.008 w
.85533 .25389 Mdot
.016 w
.85533 .25389 m
.85492 .25343 L
s
1 .775 0 r
.008 w
.85492 .25343 Mdot
.016 w
.85492 .25343 m
.85442 .25286 L
s
.008 w
.85442 .25286 Mdot
.016 w
.85442 .25286 m
.8539 .25227 L
s
1 .774 0 r
.008 w
.8539 .25227 Mdot
.016 w
.8539 .25227 m
.85338 .25168 L
s
.008 w
.85338 .25168 Mdot
.016 w
.85338 .25168 m
.85289 .25115 L
s
.008 w
.85289 .25115 Mdot
.016 w
.85289 .25115 m
.85249 .25074 L
s
1 .773 0 r
.008 w
.85249 .25074 Mdot
.016 w
.85249 .25074 m
.85219 .25046 L
s
.008 w
.85219 .25046 Mdot
.016 w
.85219 .25046 m
.852 .25028 L
s
1 .772 0 r
.008 w
.852 .25028 Mdot
.016 w
.852 .25028 m
.85189 .25016 L
s
.008 w
.85189 .25016 Mdot
.016 w
.85189 .25016 m
.85184 .2501 L
s
.008 w
.85184 .2501 Mdot
.016 w
.85184 .2501 m
.85181 .25006 L
s
1 .771 0 r
.008 w
.85181 .25006 Mdot
.016 w
.85181 .25006 m
.8518 .25003 L
s
.008 w
.8518 .25003 Mdot
.016 w
.8518 .25003 m
.8518 .25 L
s
1 .77 0 r
.008 w
.8518 .25 Mdot
.016 w
.8518 .25 m
.85178 .24997 L
s
.008 w
.85178 .24997 Mdot
.016 w
.85178 .24997 m
.85173 .24994 L
s
.008 w
.85173 .24994 Mdot
.016 w
.85173 .24994 m
.85167 .24993 L
s
1 .769 0 r
.008 w
.85167 .24993 Mdot
.016 w
.85167 .24993 m
.85168 .25001 L
s
.008 w
.85168 .25001 Mdot
.016 w
.85168 .25001 m
.8518 .2502 L
s
.008 w
.8518 .2502 Mdot
.016 w
.8518 .2502 m
.85206 .25054 L
s
1 .768 0 r
.008 w
.85206 .25054 Mdot
.016 w
.85206 .25054 m
.85247 .25103 L
s
.008 w
.85247 .25103 Mdot
.016 w
.85247 .25103 m
.85305 .25171 L
s
1 .767 0 r
.008 w
.85305 .25171 Mdot
.016 w
.85305 .25171 m
.8538 .25256 L
s
.008 w
.8538 .25256 Mdot
.016 w
.8538 .25256 m
.85467 .25356 L
s
.008 w
.85467 .25356 Mdot
.016 w
.85467 .25356 m
.85571 .2548 L
s
1 .766 0 r
.008 w
.85571 .2548 Mdot
.016 w
.85571 .2548 m
.85693 .25622 L
s
.008 w
.85693 .25622 Mdot
.016 w
.85693 .25622 m
.85824 .25789 L
s
1 .765 0 r
.008 w
.85824 .25789 Mdot
.016 w
.85824 .25789 m
.85977 .25975 L
s
.008 w
.85977 .25975 Mdot
.016 w
.85977 .25975 m
.86154 .26194 L
s
.008 w
.86154 .26194 Mdot
.016 w
.86154 .26194 m
.86315 .26418 L
s
1 .764 0 r
.008 w
.86315 .26418 Mdot
.016 w
.86315 .26418 m
.86487 .26676 L
s
.008 w
.86487 .26676 Mdot
.016 w
.86487 .26676 m
.86681 .26938 L
s
1 .763 0 r
.008 w
.86681 .26938 Mdot
.016 w
.86681 .26938 m
.86891 .27222 L
s
.008 w
.86891 .27222 Mdot
.016 w
.86891 .27222 m
.87071 .2751 L
s
.008 w
.87071 .2751 Mdot
.016 w
.87071 .2751 m
.87266 .27817 L
s
1 .762 0 r
.008 w
.87266 .27817 Mdot
.016 w
.87266 .27817 m
.8746 .28137 L
s
.008 w
.8746 .28137 Mdot
.016 w
.8746 .28137 m
.87647 .2843 L
s
.008 w
.87647 .2843 Mdot
.016 w
.87647 .2843 m
.8783 .28737 L
s
1 .761 0 r
.008 w
.8783 .28737 Mdot
.016 w
.8783 .28737 m
.88015 .29058 L
s
.008 w
.88015 .29058 Mdot
.016 w
.88015 .29058 m
.88189 .29342 L
s
1 .76 0 r
.008 w
.88189 .29342 Mdot
.016 w
.88189 .29342 m
.8835 .29615 L
s
.008 w
.8835 .29615 Mdot
.016 w
.8835 .29615 m
.88513 .29904 L
s
.008 w
.88513 .29904 Mdot
.016 w
.88513 .29904 m
.88668 .30175 L
s
1 .759 0 r
.008 w
.88668 .30175 Mdot
.016 w
.88668 .30175 m
.88814 .30423 L
s
.008 w
.88814 .30423 Mdot
.016 w
.88814 .30423 m
.88958 .30673 L
s
1 .758 0 r
.008 w
.88958 .30673 Mdot
.016 w
.88958 .30673 m
.89089 .30922 L
s
.008 w
.89089 .30922 Mdot
.016 w
.89089 .30922 m
.89216 .31146 L
s
.008 w
.89216 .31146 Mdot
.016 w
.89216 .31146 m
.89342 .31375 L
s
1 .757 0 r
.008 w
.89342 .31375 Mdot
.016 w
.89342 .31375 m
.89455 .31573 L
s
.008 w
.89455 .31573 Mdot
.016 w
.89455 .31573 m
.89563 .31772 L
s
.008 w
.89563 .31772 Mdot
.016 w
.89563 .31772 m
.89663 .31938 L
s
1 .756 0 r
.008 w
.89663 .31938 Mdot
.016 w
.89663 .31938 m
.89753 .32092 L
s
.008 w
.89753 .32092 Mdot
.016 w
.89753 .32092 m
.89835 .32231 L
s
1 .755 0 r
.008 w
.89835 .32231 Mdot
.016 w
.89835 .32231 m
.89901 .3234 L
s
.008 w
.89901 .3234 Mdot
.016 w
.89901 .3234 m
.89954 .32427 L
s
.008 w
.89954 .32427 Mdot
.016 w
.89954 .32427 m
.89994 .32491 L
s
1 .754 0 r
.008 w
.89994 .32491 Mdot
.016 w
.89994 .32491 m
.90019 .32532 L
s
.008 w
.90019 .32532 Mdot
.016 w
.90019 .32532 m
.90031 .32554 L
s
1 .753 0 r
.008 w
.90031 .32554 Mdot
.016 w
.90031 .32554 m
.90034 .32558 L
s
.008 w
.90034 .32558 Mdot
.016 w
.90034 .32558 m
.9003 .32552 L
s
.008 w
.9003 .32552 Mdot
.016 w
.9003 .32552 m
.90023 .3254 L
s
1 .752 0 r
.008 w
.90023 .3254 Mdot
.016 w
.90023 .3254 m
.90015 .32527 L
s
.008 w
.90015 .32527 Mdot
.016 w
.90015 .32527 m
.90008 .32517 L
s
1 .751 0 r
.008 w
.90008 .32517 Mdot
.016 w
.90008 .32517 m
.90003 .32509 L
s
.008 w
.90003 .32509 Mdot
.016 w
.90003 .32509 m
.9 .32504 L
s
.008 w
.9 .32504 Mdot
.016 w
.9 .32504 m
.89999 .32501 L
s
1 .75 0 r
.008 w
.89999 .32501 Mdot
.016 w
.89999 .32501 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
1 .749 0 r
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
1 .748 0 r
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
1 .747 0 r
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
1 .746 0 r
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89998 .325 L
s
.008 w
.89998 .325 Mdot
.016 w
.89998 .325 m
.89997 .32499 L
s
.008 w
.89997 .32499 Mdot
.016 w
.89997 .32499 m
.89995 .32496 L
s
1 .745 0 r
.008 w
.89995 .32496 Mdot
.016 w
.89995 .32496 m
.89992 .32493 L
s
.008 w
.89992 .32493 Mdot
.016 w
.89992 .32493 m
.89989 .3249 L
s
1 .744 0 r
.008 w
.89989 .3249 Mdot
.016 w
.89989 .3249 m
.89987 .32489 L
s
.008 w
.89987 .32489 Mdot
.016 w
.89987 .32489 m
.89988 .3249 L
s
.008 w
.89988 .3249 Mdot
.016 w
.89988 .3249 m
.89992 .32494 L
s
1 .743 0 r
.008 w
.89992 .32494 Mdot
.016 w
.89992 .32494 m
.9 .32502 L
s
.008 w
.9 .32502 Mdot
.016 w
.9 .32502 m
.90012 .32514 L
s
.008 w
.90012 .32514 Mdot
.016 w
.90012 .32514 m
.90026 .32529 L
s
1 .742 0 r
.008 w
.90026 .32529 Mdot
.016 w
.90026 .32529 m
.90043 .32547 L
s
.008 w
.90043 .32547 Mdot
.016 w
.90043 .32547 m
.90062 .32567 L
s
1 .741 0 r
.008 w
.90062 .32567 Mdot
.016 w
.90062 .32567 m
.90082 .32588 L
s
.008 w
.90082 .32588 Mdot
.016 w
.90082 .32588 m
.90102 .32609 L
s
.008 w
.90102 .32609 Mdot
.016 w
.90102 .32609 m
.90123 .3263 L
s
1 .74 0 r
.008 w
.90123 .3263 Mdot
.016 w
.90123 .3263 m
.90142 .3265 L
s
.008 w
.90142 .3265 Mdot
.016 w
.90142 .3265 m
.9016 .32669 L
s
1 .739 0 r
.008 w
.9016 .32669 Mdot
.016 w
.9016 .32669 m
.90175 .32685 L
s
.008 w
.90175 .32685 Mdot
.016 w
.90175 .32685 m
.90188 .32698 L
s
.008 w
.90188 .32698 Mdot
.016 w
.90188 .32698 m
.90196 .32707 L
s
1 .738 0 r
.008 w
.90196 .32707 Mdot
.016 w
.90196 .32707 m
.90201 .32712 L
s
.008 w
.90201 .32712 Mdot
.016 w
.90201 .32712 m
.90203 .32714 L
s
1 .737 0 r
.008 w
.90203 .32714 Mdot
.016 w
.90203 .32714 m
.90202 .32713 L
s
.008 w
.90202 .32713 Mdot
.016 w
.90202 .32713 m
.90199 .32709 L
s
.008 w
.90199 .32709 Mdot
.016 w
.90199 .32709 m
.90195 .32706 L
s
1 .736 0 r
.008 w
.90195 .32706 Mdot
.016 w
.90195 .32706 m
.90193 .32703 L
s
.008 w
.90193 .32703 Mdot
.016 w
.90193 .32703 m
.90192 .32702 L
s
.008 w
.90192 .32702 Mdot
.016 w
.90192 .32702 m
.90191 .32702 L
s
1 .735 0 r
.008 w
.90191 .32702 Mdot
.016 w
.90191 .32702 m
.90191 .32702 L
s
.008 w
.90191 .32702 Mdot
.016 w
.90191 .32702 m
.90191 .32702 L
s
1 .734 0 r
.008 w
.90191 .32702 Mdot
.016 w
.90191 .32702 m
.90191 .32702 L
s
.008 w
.90191 .32702 Mdot
.016 w
.90191 .32702 m
.90192 .32702 L
s
.008 w
.90192 .32702 Mdot
.016 w
.90192 .32702 m
.90193 .32701 L
s
1 .733 0 r
.008 w
.90193 .32701 Mdot
.016 w
.90193 .32701 m
.90195 .32699 L
s
.008 w
.90195 .32699 Mdot
.016 w
.90195 .32699 m
.90198 .32698 L
s
1 .732 0 r
.008 w
.90198 .32698 Mdot
.016 w
.90198 .32698 m
.902 .32698 L
s
.008 w
.902 .32698 Mdot
.016 w
.902 .32698 m
.90202 .327 L
s
.008 w
.90202 .327 Mdot
.016 w
.90202 .327 m
.90201 .32703 L
s
1 .731 0 r
.008 w
.90201 .32703 Mdot
.016 w
.90201 .32703 m
.90197 .32707 L
s
.008 w
.90197 .32707 Mdot
.016 w
.90197 .32707 m
.9019 .32712 L
s
1 .73 0 r
.008 w
.9019 .32712 Mdot
.016 w
.9019 .32712 m
.9018 .32719 L
s
.008 w
.9018 .32719 Mdot
.016 w
.9018 .32719 m
.90166 .32725 L
s
.008 w
.90166 .32725 Mdot
.016 w
.90166 .32725 m
.9015 .32731 L
s
1 .729 0 r
.008 w
.9015 .32731 Mdot
.016 w
.9015 .32731 m
.90132 .32735 L
s
.008 w
.90132 .32735 Mdot
.016 w
.90132 .32735 m
.90113 .32735 L
s
.008 w
.90113 .32735 Mdot
.016 w
.90113 .32735 m
.90093 .3273 L
s
1 .728 0 r
.008 w
.90093 .3273 Mdot
.016 w
.90093 .3273 m
.90073 .32722 L
s
.008 w
.90073 .32722 Mdot
.016 w
.90073 .32722 m
.90054 .3271 L
s
1 .727 0 r
.008 w
.90054 .3271 Mdot
.016 w
.90054 .3271 m
.90036 .32693 L
s
.008 w
.90036 .32693 Mdot
.016 w
.90036 .32693 m
.90021 .32673 L
s
.008 w
.90021 .32673 Mdot
.016 w
.90021 .32673 m
.90008 .32649 L
s
1 .726 0 r
.008 w
.90008 .32649 Mdot
.016 w
.90008 .32649 m
.89998 .32624 L
s
.008 w
.89998 .32624 Mdot
.016 w
.89998 .32624 m
.89993 .32599 L
s
1 .725 0 r
.008 w
.89993 .32599 Mdot
.016 w
.89993 .32599 m
.8999 .32573 L
s
.008 w
.8999 .32573 Mdot
.016 w
.8999 .32573 m
.8999 .32549 L
s
.008 w
.8999 .32549 Mdot
.016 w
.8999 .32549 m
.89992 .32524 L
s
1 .724 0 r
.008 w
.89992 .32524 Mdot
.016 w
.89992 .32524 m
.89994 .32499 L
s
.008 w
.89994 .32499 Mdot
.016 w
.89994 .32499 m
.89994 .32476 L
s
1 .723 0 r
.008 w
.89994 .32476 Mdot
.016 w
.89994 .32476 m
.89991 .32455 L
s
.008 w
.89991 .32455 Mdot
.016 w
.89991 .32455 m
.89984 .32439 L
s
.008 w
.89984 .32439 Mdot
.016 w
.89984 .32439 m
.89975 .32434 L
s
1 .722 0 r
.008 w
.89975 .32434 Mdot
.016 w
.89975 .32434 m
.89969 .32441 L
s
.008 w
.89969 .32441 Mdot
.016 w
.89969 .32441 m
.89967 .32463 L
s
.008 w
.89967 .32463 Mdot
.016 w
.89967 .32463 m
.89971 .32502 L
s
1 .721 0 r
.008 w
.89971 .32502 Mdot
.016 w
.89971 .32502 m
.89986 .3256 L
s
.008 w
.89986 .3256 Mdot
.016 w
.89986 .3256 m
.90011 .32636 L
s
1 .72 0 r
.008 w
.90011 .32636 Mdot
.016 w
.90011 .32636 m
.9005 .32731 L
s
.008 w
.9005 .32731 Mdot
.016 w
.9005 .32731 m
.901 .32845 L
s
.008 w
.901 .32845 Mdot
.016 w
.901 .32845 m
.90161 .32965 L
s
1 .719 0 r
.008 w
.90161 .32965 Mdot
.016 w
.90161 .32965 m
.9023 .33107 L
s
.008 w
.9023 .33107 Mdot
.016 w
.9023 .33107 m
.90301 .33274 L
s
1 .718 0 r
.008 w
.90301 .33274 Mdot
.016 w
.90301 .33274 m
.90382 .33455 L
s
.008 w
.90382 .33455 Mdot
.016 w
.90382 .33455 m
.90459 .33644 L
s
.008 w
.90459 .33644 Mdot
.016 w
.90459 .33644 m
.90536 .33854 L
s
1 .717 0 r
.008 w
.90536 .33854 Mdot
.016 w
.90536 .33854 m
.9061 .34061 L
s
.008 w
.9061 .34061 Mdot
.016 w
.9061 .34061 m
.90678 .34305 L
s
.008 w
.90678 .34305 Mdot
.016 w
.90678 .34305 m
.90735 .34493 L
s
1 .716 0 r
.008 w
.90735 .34493 Mdot
.016 w
.90735 .34493 m
.90782 .34721 L
s
.008 w
.90782 .34721 Mdot
.016 w
.90782 .34721 m
.9082 .34955 L
s
1 .715 0 r
.008 w
.9082 .34955 Mdot
.016 w
.9082 .34955 m
.90851 .35162 L
s
.008 w
.90851 .35162 Mdot
.016 w
.90851 .35162 m
.90876 .35371 L
s
.008 w
.90876 .35371 Mdot
.016 w
.90876 .35371 m
.90898 .35595 L
s
1 .714 0 r
.008 w
.90898 .35595 Mdot
.016 w
.90898 .35595 m
.90918 .35814 L
s
.008 w
.90918 .35814 Mdot
.016 w
.90918 .35814 m
.90941 .36023 L
s
1 .713 0 r
.008 w
.90941 .36023 Mdot
.016 w
.90941 .36023 m
.90962 .36218 L
s
.008 w
.90962 .36218 Mdot
.016 w
.90962 .36218 m
.90981 .36398 L
s
.008 w
.90981 .36398 Mdot
.016 w
.90981 .36398 m
.90993 .36547 L
s
1 .712 0 r
.008 w
.90993 .36547 Mdot
.016 w
.90993 .36547 m
.91 .36666 L
s
.008 w
.91 .36666 Mdot
.016 w
.91 .36666 m
.91005 .36768 L
s
1 .711 0 r
.008 w
.91005 .36768 Mdot
.016 w
.91005 .36768 m
.91008 .36852 L
s
.008 w
.91008 .36852 Mdot
.016 w
.91008 .36852 m
.91008 .36918 L
s
.008 w
.91008 .36918 Mdot
.016 w
.91008 .36918 m
.91007 .36967 L
s
1 .71 0 r
.008 w
.91007 .36967 Mdot
.016 w
.91007 .36967 m
.91006 .37001 L
s
.008 w
.91006 .37001 Mdot
.016 w
.91006 .37001 m
.91004 .37022 L
s
.008 w
.91004 .37022 Mdot
.016 w
.91004 .37022 m
.91002 .37038 L
s
1 .709 0 r
.008 w
.91002 .37038 Mdot
.016 w
.91002 .37038 m
.91001 .37046 L
s
.008 w
.91001 .37046 Mdot
.016 w
.91001 .37046 m
.91004 .3705 L
s
1 .708 0 r
.008 w
.91004 .3705 Mdot
.016 w
.91004 .3705 m
.91011 .37052 L
s
.008 w
.91011 .37052 Mdot
.016 w
.91011 .37052 m
.91021 .37058 L
s
.008 w
.91021 .37058 Mdot
.016 w
.91021 .37058 m
.91036 .37072 L
s
1 .707 0 r
.008 w
.91036 .37072 Mdot
.016 w
.91036 .37072 m
.91053 .3709 L
s
.008 w
.91053 .3709 Mdot
.016 w
.91053 .3709 m
.91068 .37105 L
s
1 .706 0 r
.008 w
.91068 .37105 Mdot
.016 w
.91068 .37105 m
.91079 .37115 L
s
.008 w
.91079 .37115 Mdot
.016 w
.91079 .37115 m
.91083 .37116 L
s
.008 w
.91083 .37116 Mdot
.016 w
.91083 .37116 m
.91079 .37108 L
s
1 .705 0 r
.008 w
.91079 .37108 Mdot
.016 w
.91079 .37108 m
.91068 .37088 L
s
.008 w
.91068 .37088 Mdot
.016 w
.91068 .37088 m
.9105 .37054 L
s
1 .704 0 r
.008 w
.9105 .37054 Mdot
.016 w
.9105 .37054 m
.91028 .37005 L
s
.008 w
.91028 .37005 Mdot
.016 w
.91028 .37005 m
.91007 .36942 L
s
.008 w
.91007 .36942 Mdot
.016 w
.91007 .36942 m
.90987 .36871 L
s
1 .703 0 r
.008 w
.90987 .36871 Mdot
.016 w
.90987 .36871 m
.90968 .36797 L
s
.008 w
.90968 .36797 Mdot
.016 w
.90968 .36797 m
.90949 .36726 L
s
.008 w
.90949 .36726 Mdot
.016 w
.90949 .36726 m
.9093 .36666 L
s
1 .702 0 r
.008 w
.9093 .36666 Mdot
.016 w
.9093 .36666 m
.90911 .36621 L
s
.008 w
.90911 .36621 Mdot
.016 w
.90911 .36621 m
.9089 .36596 L
s
1 .701 0 r
.008 w
.9089 .36596 Mdot
.016 w
.9089 .36596 m
.90868 .36594 L
s
.008 w
.90868 .36594 Mdot
.016 w
.90868 .36594 m
.90843 .36617 L
s
.008 w
.90843 .36617 Mdot
.016 w
.90843 .36617 m
.90815 .36666 L
s
1 .7 0 r
.008 w
.90815 .36666 Mdot
.016 w
.90815 .36666 m
.90784 .36741 L
s
.008 w
.90784 .36741 Mdot
.016 w
.90784 .36741 m
.90751 .36837 L
s
1 .699 0 r
.008 w
.90751 .36837 Mdot
.016 w
.90751 .36837 m
.90718 .36937 L
s
.008 w
.90718 .36937 Mdot
.016 w
.90718 .36937 m
.90684 .37043 L
s
.008 w
.90684 .37043 Mdot
.016 w
.90684 .37043 m
.9065 .37151 L
s
1 .698 0 r
.008 w
.9065 .37151 Mdot
.016 w
.9065 .37151 m
.90621 .37253 L
s
.008 w
.90621 .37253 Mdot
.016 w
.90621 .37253 m
.90599 .37331 L
s
1 .697 0 r
.008 w
.90599 .37331 Mdot
.016 w
.90599 .37331 m
.90586 .37387 L
s
.008 w
.90586 .37387 Mdot
.016 w
.90586 .37387 m
.90585 .37416 L
s
.008 w
.90585 .37416 Mdot
.016 w
.90585 .37416 m
.90597 .3742 L
s
1 .696 0 r
.008 w
.90597 .3742 Mdot
.016 w
.90597 .3742 m
.90621 .37404 L
s
.008 w
.90621 .37404 Mdot
.016 w
.90621 .37404 m
.90654 .37369 L
s
.008 w
.90654 .37369 Mdot
.016 w
.90654 .37369 m
.90691 .37319 L
s
1 .695 0 r
.008 w
.90691 .37319 Mdot
.016 w
.90691 .37319 m
.9073 .37255 L
s
.008 w
.9073 .37255 Mdot
.016 w
.9073 .37255 m
.90767 .37183 L
s
1 .694 0 r
.008 w
.90767 .37183 Mdot
.016 w
.90767 .37183 m
.90798 .37106 L
s
.008 w
.90798 .37106 Mdot
.016 w
.90798 .37106 m
.90821 .37033 L
s
.008 w
.90821 .37033 Mdot
.016 w
.90821 .37033 m
.90836 .36963 L
s
1 .693 0 r
.008 w
.90836 .36963 Mdot
.016 w
.90836 .36963 m
.90845 .36898 L
s
.008 w
.90845 .36898 Mdot
.016 w
.90845 .36898 m
.90848 .36839 L
s
1 .692 0 r
.008 w
.90848 .36839 Mdot
.016 w
.90848 .36839 m
.90845 .36783 L
s
.008 w
.90845 .36783 Mdot
.016 w
.90845 .36783 m
.90837 .36728 L
s
.008 w
.90837 .36728 Mdot
.016 w
.90837 .36728 m
.90826 .36677 L
s
1 .691 0 r
.008 w
.90826 .36677 Mdot
.016 w
.90826 .36677 m
.90816 .36625 L
s
.008 w
.90816 .36625 Mdot
.016 w
.90816 .36625 m
.90807 .3657 L
s
1 .69 0 r
.008 w
.90807 .3657 Mdot
.016 w
.90807 .3657 m
.90802 .36511 L
s
.008 w
.90802 .36511 Mdot
.016 w
.90802 .36511 m
.90804 .36447 L
s
.008 w
.90804 .36447 Mdot
.016 w
.90804 .36447 m
.90812 .36381 L
s
1 .689 0 r
.008 w
.90812 .36381 Mdot
.016 w
.90812 .36381 m
.90828 .36309 L
s
.008 w
.90828 .36309 Mdot
.016 w
.90828 .36309 m
.90852 .36233 L
s
.008 w
.90852 .36233 Mdot
.016 w
.90852 .36233 m
.90881 .36148 L
s
1 .688 0 r
.008 w
.90881 .36148 Mdot
.016 w
.90881 .36148 m
.90911 .36056 L
s
.008 w
.90911 .36056 Mdot
.016 w
.90911 .36056 m
.90942 .35956 L
s
1 .687 0 r
.008 w
.90942 .35956 Mdot
.016 w
.90942 .35956 m
.90971 .35853 L
s
.008 w
.90971 .35853 Mdot
.016 w
.90971 .35853 m
.90996 .35741 L
s
.008 w
.90996 .35741 Mdot
.016 w
.90996 .35741 m
.91015 .35629 L
s
1 .686 0 r
.008 w
.91015 .35629 Mdot
.016 w
.91015 .35629 m
.91029 .35515 L
s
.008 w
.91029 .35515 Mdot
.016 w
.91029 .35515 m
.91036 .35401 L
s
1 .685 0 r
.008 w
.91036 .35401 Mdot
.016 w
.91036 .35401 m
.91036 .35291 L
s
.008 w
.91036 .35291 Mdot
.016 w
.91036 .35291 m
.91031 .3518 L
s
.008 w
.91031 .3518 Mdot
.016 w
.91031 .3518 m
.91019 .35076 L
s
1 .684 0 r
.008 w
.91019 .35076 Mdot
.016 w
.91019 .35076 m
.91002 .34971 L
s
.008 w
.91002 .34971 Mdot
.016 w
.91002 .34971 m
.90981 .34867 L
s
1 .683 0 r
.008 w
.90981 .34867 Mdot
.016 w
.90981 .34867 m
.90956 .34771 L
s
.008 w
.90956 .34771 Mdot
.016 w
.90956 .34771 m
.90931 .34683 L
s
.008 w
.90931 .34683 Mdot
.016 w
.90931 .34683 m
.90906 .34608 L
s
1 .682 0 r
.008 w
.90906 .34608 Mdot
.016 w
.90906 .34608 m
.90884 .34537 L
s
.008 w
.90884 .34537 Mdot
.016 w
.90884 .34537 m
.90865 .34467 L
s
.008 w
.90865 .34467 Mdot
.016 w
.90865 .34467 m
.90848 .34398 L
s
1 .681 0 r
.008 w
.90848 .34398 Mdot
.016 w
.90848 .34398 m
.90833 .34326 L
s
.008 w
.90833 .34326 Mdot
.016 w
.90833 .34326 m
.9082 .34253 L
s
1 .68 0 r
.008 w
.9082 .34253 Mdot
.016 w
.9082 .34253 m
.90808 .34176 L
s
.008 w
.90808 .34176 Mdot
.016 w
.90808 .34176 m
.90796 .34096 L
s
.008 w
.90796 .34096 Mdot
.016 w
.90796 .34096 m
.90784 .34017 L
s
1 .679 0 r
.008 w
.90784 .34017 Mdot
.016 w
.90784 .34017 m
.90772 .33942 L
s
.008 w
.90772 .33942 Mdot
.016 w
.90772 .33942 m
.90758 .33871 L
s
1 .678 0 r
.008 w
.90758 .33871 Mdot
.016 w
.90758 .33871 m
.90743 .33809 L
s
.008 w
.90743 .33809 Mdot
.016 w
.90743 .33809 m
.90725 .33749 L
s
.008 w
.90725 .33749 Mdot
.016 w
.90725 .33749 m
.90704 .33693 L
s
1 .677 0 r
.008 w
.90704 .33693 Mdot
.016 w
.90704 .33693 m
.90683 .33641 L
s
.008 w
.90683 .33641 Mdot
.016 w
.90683 .33641 m
.90663 .33596 L
s
.008 w
.90663 .33596 Mdot
.016 w
.90663 .33596 m
.90642 .33557 L
s
1 .676 0 r
.008 w
.90642 .33557 Mdot
.016 w
.90642 .33557 m
.90624 .33524 L
s
.008 w
.90624 .33524 Mdot
.016 w
.90624 .33524 m
.90608 .335 L
s
1 .675 0 r
.008 w
.90608 .335 Mdot
.016 w
.90608 .335 m
.90595 .33485 L
s
.008 w
.90595 .33485 Mdot
.016 w
.90595 .33485 m
.90586 .33479 L
s
.008 w
.90586 .33479 Mdot
.016 w
.90586 .33479 m
.90579 .3348 L
s
1 .674 0 r
.008 w
.90579 .3348 Mdot
.016 w
.90579 .3348 m
.90575 .33485 L
s
.008 w
.90575 .33485 Mdot
.016 w
.90575 .33485 m
.90573 .33491 L
s
1 .673 0 r
.008 w
.90573 .33491 Mdot
.016 w
.90573 .33491 m
.90575 .33496 L
s
.008 w
.90575 .33496 Mdot
.016 w
.90575 .33496 m
.90579 .335 L
s
.008 w
.90579 .335 Mdot
.016 w
.90579 .335 m
.90585 .33503 L
s
1 .672 0 r
.008 w
.90585 .33503 Mdot
.016 w
.90585 .33503 m
.90594 .33504 L
s
.008 w
.90594 .33504 Mdot
.016 w
.90594 .33504 m
.90605 .33505 L
s
1 .671 0 r
.008 w
.90605 .33505 Mdot
.016 w
.90605 .33505 m
.90619 .33505 L
s
.008 w
.90619 .33505 Mdot
.016 w
.90619 .33505 m
.90636 .33505 L
s
.008 w
.90636 .33505 Mdot
.016 w
.90636 .33505 m
.90654 .33505 L
s
1 .67 0 r
.008 w
.90654 .33505 Mdot
.016 w
.90654 .33505 m
.90673 .33505 L
s
.008 w
.90673 .33505 Mdot
.016 w
.90673 .33505 m
.90692 .33505 L
s
.008 w
.90692 .33505 Mdot
.016 w
.90692 .33505 m
.90711 .33505 L
s
1 .669 0 r
.008 w
.90711 .33505 Mdot
.016 w
.90711 .33505 m
.9073 .33505 L
s
.008 w
.9073 .33505 Mdot
.016 w
.9073 .33505 m
.90747 .33505 L
s
1 .668 0 r
.008 w
.90747 .33505 Mdot
.016 w
.90747 .33505 m
.90762 .33505 L
s
.008 w
.90762 .33505 Mdot
.016 w
.90762 .33505 m
.90773 .33506 L
s
.008 w
.90773 .33506 Mdot
.016 w
.90773 .33506 m
.90782 .33506 L
s
1 .667 0 r
.008 w
.90782 .33506 Mdot
.016 w
.90782 .33506 m
.90787 .33506 L
s
.008 w
.90787 .33506 Mdot
.016 w
.90787 .33506 m
.90788 .33506 L
s
1 .666 0 r
.008 w
.90788 .33506 Mdot
.016 w
.90788 .33506 m
.90787 .33506 L
s
.008 w
.90787 .33506 Mdot
.016 w
.90787 .33506 m
.90784 .33506 L
s
.008 w
.90784 .33506 Mdot
.016 w
.90784 .33506 m
.90781 .33506 L
s
1 .665 0 r
.008 w
.90781 .33506 Mdot
.016 w
.90781 .33506 m
.90779 .33506 L
s
.008 w
.90779 .33506 Mdot
.016 w
.90779 .33506 m
.90777 .33506 L
s
1 .664 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .663 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .662 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .661 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .66 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .659 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .658 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .657 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .656 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .655 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
1 .654 0 r
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33506 L
s
.008 w
.90777 .33506 Mdot
.016 w
.90777 .33506 m
.90777 .33505 L
s
1 .653 0 r
.008 w
.90777 .33505 Mdot
.016 w
.90777 .33505 m
.90778 .33504 L
s
.008 w
.90778 .33504 Mdot
.016 w
.90778 .33504 m
.9078 .33502 L
s
1 .652 0 r
.008 w
.9078 .33502 Mdot
.016 w
.9078 .33502 m
.90783 .33497 L
s
.008 w
.90783 .33497 Mdot
.016 w
.90783 .33497 m
.90786 .33494 L
s
.008 w
.90786 .33494 Mdot
.016 w
.90786 .33494 m
.90787 .33493 L
s
1 .651 0 r
.008 w
.90787 .33493 Mdot
.016 w
.90787 .33493 m
.90786 .33495 L
s
.008 w
.90786 .33495 Mdot
.016 w
.90786 .33495 m
.90783 .33501 L
s
1 .65 0 r
.008 w
.90783 .33501 Mdot
.016 w
.90783 .33501 m
.90776 .33511 L
s
.008 w
.90776 .33511 Mdot
.016 w
.90776 .33511 m
.90766 .33526 L
s
.008 w
.90766 .33526 Mdot
.016 w
.90766 .33526 m
.90753 .33544 L
s
1 .649 0 r
.008 w
.90753 .33544 Mdot
.016 w
.90753 .33544 m
.90738 .33564 L
s
.008 w
.90738 .33564 Mdot
.016 w
.90738 .33564 m
.90721 .33585 L
s
.008 w
.90721 .33585 Mdot
.016 w
.90721 .33585 m
.90703 .33606 L
s
1 .648 0 r
.008 w
.90703 .33606 Mdot
.016 w
.90703 .33606 m
.90685 .33628 L
s
.008 w
.90685 .33628 Mdot
.016 w
.90685 .33628 m
.90666 .33648 L
s
1 .647 0 r
.008 w
.90666 .33648 Mdot
.016 w
.90666 .33648 m
.90648 .33666 L
s
.008 w
.90648 .33666 Mdot
.016 w
.90648 .33666 m
.90632 .33685 L
s
.008 w
.90632 .33685 Mdot
.016 w
.90632 .33685 m
.90617 .33701 L
s
1 .646 0 r
.008 w
.90617 .33701 Mdot
.016 w
.90617 .33701 m
.90606 .33712 L
s
.008 w
.90606 .33712 Mdot
.016 w
.90606 .33712 m
.90597 .33719 L
s
1 .645 0 r
.008 w
.90597 .33719 Mdot
.016 w
.90597 .33719 m
.90592 .33721 L
s
.008 w
.90592 .33721 Mdot
.016 w
.90592 .33721 m
.9059 .33719 L
s
.008 w
.9059 .33719 Mdot
.016 w
.9059 .33719 m
.90591 .33715 L
s
1 .644 0 r
.008 w
.90591 .33715 Mdot
.016 w
.90591 .33715 m
.90593 .3371 L
s
.008 w
.90593 .3371 Mdot
.016 w
.90593 .3371 m
.90596 .33705 L
s
1 .643 0 r
.008 w
.90596 .33705 Mdot
.016 w
.90596 .33705 m
.90598 .33702 L
s
.008 w
.90598 .33702 Mdot
.016 w
.90598 .33702 m
.906 .33703 L
s
.008 w
.906 .33703 Mdot
.016 w
.906 .33703 m
.906 .33707 L
s
1 .642 0 r
.008 w
.906 .33707 Mdot
.016 w
.906 .33707 m
.906 .33711 L
s
.008 w
.906 .33711 Mdot
.016 w
.906 .33711 m
.906 .33714 L
s
.008 w
.906 .33714 Mdot
.016 w
.906 .33714 m
.90601 .33716 L
s
1 .641 0 r
.008 w
.90601 .33716 Mdot
.016 w
.90601 .33716 m
.906 .33715 L
s
.008 w
.906 .33715 Mdot
.016 w
.906 .33715 m
.906 .33711 L
s
1 .64 0 r
.008 w
.906 .33711 Mdot
.016 w
.906 .33711 m
.906 .33703 L
s
.008 w
.906 .33703 Mdot
.016 w
.906 .33703 m
.906 .33691 L
s
.008 w
.906 .33691 Mdot
.016 w
.906 .33691 m
.90599 .33677 L
s
1 .639 0 r
.008 w
.90599 .33677 Mdot
.016 w
.90599 .33677 m
.90598 .33661 L
s
.008 w
.90598 .33661 Mdot
.016 w
.90598 .33661 m
.90598 .33647 L
s
1 .638 0 r
.008 w
.90598 .33647 Mdot
.016 w
.90598 .33647 m
.90597 .33633 L
s
.008 w
.90597 .33633 Mdot
.016 w
.90597 .33633 m
.90597 .33618 L
s
.008 w
.90597 .33618 Mdot
.016 w
.90597 .33618 m
.90596 .336 L
s
1 .637 0 r
.008 w
.90596 .336 Mdot
.016 w
.90596 .336 m
.90598 .3358 L
s
.008 w
.90598 .3358 Mdot
.016 w
.90598 .3358 m
.90603 .33557 L
s
.008 w
.90603 .33557 Mdot
.016 w
.90603 .33557 m
.90608 .33532 L
s
1 .636 0 r
.008 w
.90608 .33532 Mdot
.016 w
.90608 .33532 m
.90613 .33502 L
s
.008 w
.90613 .33502 Mdot
.016 w
.90613 .33502 m
.90615 .33468 L
s
1 .635 0 r
.008 w
.90615 .33468 Mdot
.016 w
.90615 .33468 m
.90615 .33429 L
s
.008 w
.90615 .33429 Mdot
.016 w
.90615 .33429 m
.90608 .33383 L
s
.008 w
.90608 .33383 Mdot
.016 w
.90608 .33383 m
.90592 .33328 L
s
1 .634 0 r
.008 w
.90592 .33328 Mdot
.016 w
.90592 .33328 m
.90564 .33262 L
s
.008 w
.90564 .33262 Mdot
.016 w
.90564 .33262 m
.90524 .33186 L
s
1 .633 0 r
.008 w
.90524 .33186 Mdot
.016 w
.90524 .33186 m
.90474 .33104 L
s
.008 w
.90474 .33104 Mdot
.016 w
.90474 .33104 m
.90415 .33016 L
s
.008 w
.90415 .33016 Mdot
.016 w
.90415 .33016 m
.9035 .32926 L
s
1 .632 0 r
.008 w
.9035 .32926 Mdot
.016 w
.9035 .32926 m
.90289 .32843 L
s
.008 w
.90289 .32843 Mdot
.016 w
.90289 .32843 m
.90222 .32767 L
s
1 .631 0 r
.008 w
.90222 .32767 Mdot
.016 w
.90222 .32767 m
.90151 .32697 L
s
.008 w
.90151 .32697 Mdot
.016 w
.90151 .32697 m
.90073 .32637 L
s
.008 w
.90073 .32637 Mdot
.016 w
.90073 .32637 m
.9001 .32587 L
s
1 .63 0 r
.008 w
.9001 .32587 Mdot
.016 w
.9001 .32587 m
.89954 .32548 L
s
.008 w
.89954 .32548 Mdot
.016 w
.89954 .32548 m
.89905 .32518 L
s
.008 w
.89905 .32518 Mdot
.016 w
.89905 .32518 m
.89866 .32501 L
s
1 .629 0 r
.008 w
.89866 .32501 Mdot
.016 w
.89866 .32501 m
.89847 .32494 L
s
.008 w
.89847 .32494 Mdot
.016 w
.89847 .32494 m
.89848 .32498 L
s
1 .628 0 r
.008 w
.89848 .32498 Mdot
.016 w
.89848 .32498 m
.89861 .3252 L
s
.008 w
.89861 .3252 Mdot
.016 w
.89861 .3252 m
.89884 .32543 L
s
.008 w
.89884 .32543 Mdot
.016 w
.89884 .32543 m
.8991 .32566 L
s
1 .627 0 r
.008 w
.8991 .32566 Mdot
.016 w
.8991 .32566 m
.89931 .32585 L
s
.008 w
.89931 .32585 Mdot
.016 w
.89931 .32585 m
.89943 .32602 L
s
1 .626 0 r
.008 w
.89943 .32602 Mdot
.016 w
.89943 .32602 m
.89943 .3262 L
s
.008 w
.89943 .3262 Mdot
.016 w
.89943 .3262 m
.8993 .32641 L
s
.008 w
.8993 .32641 Mdot
.016 w
.8993 .32641 m
.89903 .32665 L
s
1 .625 0 r
.008 w
.89903 .32665 Mdot
.016 w
.89903 .32665 m
.89858 .32697 L
s
.008 w
.89858 .32697 Mdot
.016 w
.89858 .32697 m
.89795 .32734 L
s
1 .624 0 r
.008 w
.89795 .32734 Mdot
.016 w
.89795 .32734 m
.89717 .32779 L
s
.008 w
.89717 .32779 Mdot
.016 w
.89717 .32779 m
.89638 .32827 L
s
.008 w
.89638 .32827 Mdot
.016 w
.89638 .32827 m
.89554 .32877 L
s
1 .623 0 r
.008 w
.89554 .32877 Mdot
.016 w
.89554 .32877 m
.89464 .32924 L
s
.008 w
.89464 .32924 Mdot
.016 w
.89464 .32924 m
.89372 .32965 L
s
.008 w
.89372 .32965 Mdot
.016 w
.89372 .32965 m
.89291 .32999 L
s
1 .622 0 r
.008 w
.89291 .32999 Mdot
.016 w
.89291 .32999 m
.8925 .33023 L
s
.008 w
.8925 .33023 Mdot
.016 w
.8925 .33023 m
.89224 .33033 L
s
1 .621 0 r
.008 w
.89224 .33033 Mdot
.016 w
.89224 .33033 m
.89221 .33026 L
s
.008 w
.89221 .33026 Mdot
.016 w
.89221 .33026 m
.8924 .33008 L
s
.008 w
.8924 .33008 Mdot
.016 w
.8924 .33008 m
.89273 .32977 L
s
1 .62 0 r
.008 w
.89273 .32977 Mdot
.016 w
.89273 .32977 m
.89313 .32941 L
s
.008 w
.89313 .32941 Mdot
.016 w
.89313 .32941 m
.89367 .32904 L
s
1 .619 0 r
.008 w
.89367 .32904 Mdot
.016 w
.89367 .32904 m
.89439 .32873 L
s
.008 w
.89439 .32873 Mdot
.016 w
.89439 .32873 m
.89503 .32857 L
s
.008 w
.89503 .32857 Mdot
.016 w
.89503 .32857 m
.89571 .32861 L
s
1 .618 0 r
.008 w
.89571 .32861 Mdot
.016 w
.89571 .32861 m
.89643 .32893 L
s
.008 w
.89643 .32893 Mdot
.016 w
.89643 .32893 m
.89706 .32957 L
s
1 .617 0 r
.008 w
.89706 .32957 Mdot
.016 w
.89706 .32957 m
.89763 .33053 L
s
.008 w
.89763 .33053 Mdot
.016 w
.89763 .33053 m
.8982 .33177 L
s
.008 w
.8982 .33177 Mdot
.016 w
.8982 .33177 m
.89881 .33329 L
s
1 .616 0 r
.008 w
.89881 .33329 Mdot
.016 w
.89881 .33329 m
.89948 .3352 L
s
.008 w
.89948 .3352 Mdot
.016 w
.89948 .3352 m
.90021 .33743 L
s
.008 w
.90021 .33743 Mdot
.016 w
.90021 .33743 m
.90097 .33987 L
s
1 .615 0 r
.008 w
.90097 .33987 Mdot
.016 w
.90097 .33987 m
.90189 .3425 L
s
.008 w
.90189 .3425 Mdot
.016 w
.90189 .3425 m
.90294 .34512 L
s
1 .614 0 r
.008 w
.90294 .34512 Mdot
.016 w
.90294 .34512 m
.90395 .34796 L
s
.008 w
.90395 .34796 Mdot
.016 w
.90395 .34796 m
.90517 .35091 L
s
.008 w
.90517 .35091 Mdot
.016 w
.90517 .35091 m
.90647 .35403 L
s
1 .613 0 r
.008 w
.90647 .35403 Mdot
.016 w
.90647 .35403 m
.9077 .35734 L
s
.008 w
.9077 .35734 Mdot
.016 w
.9077 .35734 m
.90902 .36063 L
s
1 .612 0 r
.008 w
.90902 .36063 Mdot
.016 w
.90902 .36063 m
.9103 .36417 L
s
.008 w
.9103 .36417 Mdot
.016 w
.9103 .36417 m
.9115 .36798 L
s
.008 w
.9115 .36798 Mdot
.016 w
.9115 .36798 m
.91257 .37148 L
s
1 .611 0 r
.008 w
.91257 .37148 Mdot
.016 w
.91257 .37148 m
.91354 .37514 L
s
.008 w
.91354 .37514 Mdot
.016 w
.91354 .37514 m
.9144 .37923 L
s
1 .61 0 r
.008 w
.9144 .37923 Mdot
.016 w
.9144 .37923 m
.91517 .38253 L
s
.008 w
.91517 .38253 Mdot
.016 w
.91517 .38253 m
.91589 .38644 L
s
.008 w
.91589 .38644 Mdot
.016 w
.91589 .38644 m
.91653 .38986 L
s
1 .609 0 r
.008 w
.91653 .38986 Mdot
.016 w
.91653 .38986 m
.91714 .39356 L
s
.008 w
.91714 .39356 Mdot
.016 w
.91714 .39356 m
.9177 .39731 L
s
.008 w
.9177 .39731 Mdot
.016 w
.9177 .39731 m
.9182 .40084 L
s
1 .608 0 r
.008 w
.9182 .40084 Mdot
.016 w
.9182 .40084 m
.91864 .40446 L
s
.008 w
.91864 .40446 Mdot
.016 w
.91864 .40446 m
.91901 .40823 L
s
1 .607 0 r
.008 w
.91901 .40823 Mdot
.016 w
.91901 .40823 m
.91933 .41184 L
s
.008 w
.91933 .41184 Mdot
.016 w
.91933 .41184 m
.91962 .41537 L
s
.008 w
.91962 .41537 Mdot
.016 w
.91962 .41537 m
.91988 .4191 L
s
1 .606 0 r
.008 w
.91988 .4191 Mdot
.016 w
.91988 .4191 m
.92012 .42269 L
s
.008 w
.92012 .42269 Mdot
.016 w
.92012 .42269 m
.92033 .42647 L
s
1 .605 0 r
.008 w
.92033 .42647 Mdot
.016 w
.92033 .42647 m
.92052 .42997 L
s
.008 w
.92052 .42997 Mdot
.016 w
.92052 .42997 m
.92071 .4335 L
s
.008 w
.92071 .4335 Mdot
.016 w
.92071 .4335 m
.92088 .43682 L
s
1 .604 0 r
.008 w
.92088 .43682 Mdot
.016 w
.92088 .43682 m
.92105 .44005 L
s
.008 w
.92105 .44005 Mdot
.016 w
.92105 .44005 m
.92122 .4432 L
s
1 .603 0 r
.008 w
.92122 .4432 Mdot
.016 w
.92122 .4432 m
.92141 .44612 L
s
.008 w
.92141 .44612 Mdot
.016 w
.92141 .44612 m
.92163 .44914 L
s
.008 w
.92163 .44914 Mdot
.016 w
.92163 .44914 m
.92187 .45182 L
s
1 .602 0 r
.008 w
.92187 .45182 Mdot
.016 w
.92187 .45182 m
.92214 .45444 L
s
.008 w
.92214 .45444 Mdot
.016 w
.92214 .45444 m
.92243 .45711 L
s
.008 w
.92243 .45711 Mdot
.016 w
.92243 .45711 m
.92271 .45944 L
s
1 .601 0 r
.008 w
.92271 .45944 Mdot
.016 w
.92271 .45944 m
.92298 .46175 L
s
.008 w
.92298 .46175 Mdot
.016 w
.92298 .46175 m
.92324 .4638 L
s
1 .6 0 r
.008 w
.92324 .4638 Mdot
.016 w
.92324 .4638 m
.92348 .46554 L
s
.008 w
.92348 .46554 Mdot
.016 w
.92348 .46554 m
.92368 .46702 L
s
.008 w
.92368 .46702 Mdot
.016 w
.92368 .46702 m
.92384 .46809 L
s
1 .599 0 r
.008 w
.92384 .46809 Mdot
.016 w
.92384 .46809 m
.92395 .46882 L
s
.008 w
.92395 .46882 Mdot
.016 w
.92395 .46882 m
.92401 .46921 L
s
1 .598 0 r
.008 w
.92401 .46921 Mdot
.016 w
.92401 .46921 m
.92402 .46924 L
s
.008 w
.92402 .46924 Mdot
.016 w
.92402 .46924 m
.924 .46897 L
s
.008 w
.924 .46897 Mdot
.016 w
.924 .46897 m
.92395 .46845 L
s
1 .597 0 r
.008 w
.92395 .46845 Mdot
.016 w
.92395 .46845 m
.92389 .46779 L
s
.008 w
.92389 .46779 Mdot
.016 w
.92389 .46779 m
.92384 .46704 L
s
.008 w
.92384 .46704 Mdot
.016 w
.92384 .46704 m
.9238 .46625 L
s
1 .596 0 r
.008 w
.9238 .46625 Mdot
.016 w
.9238 .46625 m
.92377 .46551 L
s
.008 w
.92377 .46551 Mdot
.016 w
.92377 .46551 m
.92375 .46486 L
s
1 .595 0 r
.008 w
.92375 .46486 Mdot
.016 w
.92375 .46486 m
.92373 .46433 L
s
.008 w
.92373 .46433 Mdot
.016 w
.92373 .46433 m
.92372 .46395 L
s
.008 w
.92372 .46395 Mdot
.016 w
.92372 .46395 m
.92373 .46371 L
s
1 .594 0 r
.008 w
.92373 .46371 Mdot
.016 w
.92373 .46371 m
.92377 .46359 L
s
.008 w
.92377 .46359 Mdot
.016 w
.92377 .46359 m
.92382 .46356 L
s
1 .593 0 r
.008 w
.92382 .46356 Mdot
.016 w
.92382 .46356 m
.92387 .4636 L
s
.008 w
.92387 .4636 Mdot
.016 w
.92387 .4636 m
.9239 .46368 L
s
.008 w
.9239 .46368 Mdot
.016 w
.9239 .46368 m
.92389 .46376 L
s
1 .592 0 r
.008 w
.92389 .46376 Mdot
.016 w
.92389 .46376 m
.92381 .46382 L
s
.008 w
.92381 .46382 Mdot
.016 w
.92381 .46382 m
.92365 .46386 L
s
1 .591 0 r
.008 w
.92365 .46386 Mdot
.016 w
.92365 .46386 m
.92341 .46388 L
s
.008 w
.92341 .46388 Mdot
.016 w
.92341 .46388 m
.92309 .46388 L
s
.008 w
.92309 .46388 Mdot
.016 w
.92309 .46388 m
.92273 .46389 L
s
1 .59 0 r
.008 w
.92273 .46389 Mdot
.016 w
.92273 .46389 m
.92235 .4639 L
s
.008 w
.92235 .4639 Mdot
.016 w
.92235 .4639 m
.92199 .46391 L
s
.008 w
.92199 .46391 Mdot
.016 w
.92199 .46391 m
.92166 .46392 L
s
1 .589 0 r
.008 w
.92166 .46392 Mdot
.016 w
.92166 .46392 m
.92138 .46392 L
s
.008 w
.92138 .46392 Mdot
.016 w
.92138 .46392 m
.92114 .46388 L
s
1 .588 0 r
.008 w
.92114 .46388 Mdot
.016 w
.92114 .46388 m
.92096 .4638 L
s
.008 w
.92096 .4638 Mdot
.016 w
.92096 .4638 m
.92085 .4637 L
s
.008 w
.92085 .4637 Mdot
.016 w
.92085 .4637 m
.92083 .46357 L
s
1 .587 0 r
.008 w
.92083 .46357 Mdot
.016 w
.92083 .46357 m
.9209 .46342 L
s
.008 w
.9209 .46342 Mdot
.016 w
.9209 .46342 m
.92105 .46331 L
s
1 .586 0 r
.008 w
.92105 .46331 Mdot
.016 w
.92105 .46331 m
.92123 .46327 L
s
.008 w
.92123 .46327 Mdot
.016 w
.92123 .46327 m
.92139 .46335 L
s
.008 w
.92139 .46335 Mdot
.016 w
.92139 .46335 m
.92151 .46362 L
s
1 .585 0 r
.008 w
.92151 .46362 Mdot
.016 w
.92151 .46362 m
.92155 .46417 L
s
.008 w
.92155 .46417 Mdot
.016 w
.92155 .46417 m
.92145 .46499 L
s
1 .584 0 r
.008 w
.92145 .46499 Mdot
.016 w
.92145 .46499 m
.92122 .46613 L
s
.008 w
.92122 .46613 Mdot
.016 w
.92122 .46613 m
.92087 .46761 L
s
.008 w
.92087 .46761 Mdot
.016 w
.92087 .46761 m
.92045 .46923 L
s
1 .583 0 r
.008 w
.92045 .46923 Mdot
.016 w
.92045 .46923 m
.91996 .47117 L
s
.008 w
.91996 .47117 Mdot
.016 w
.91996 .47117 m
.91941 .47339 L
s
.008 w
.91941 .47339 Mdot
.016 w
.91941 .47339 m
.91884 .47567 L
s
1 .582 0 r
.008 w
.91884 .47567 Mdot
.016 w
.91884 .47567 m
.91832 .47793 L
s
.008 w
.91832 .47793 Mdot
.016 w
.91832 .47793 m
.91784 .48043 L
s
1 .581 0 r
.008 w
.91784 .48043 Mdot
.016 w
.91784 .48043 m
.91743 .48337 L
s
.008 w
.91743 .48337 Mdot
.016 w
.91743 .48337 m
.91712 .48586 L
s
.008 w
.91712 .48586 Mdot
.016 w
.91712 .48586 m
.91694 .4884 L
s
1 .58 0 r
.008 w
.91694 .4884 Mdot
.016 w
.91694 .4884 m
.91691 .49106 L
s
.008 w
.91691 .49106 Mdot
.016 w
.91691 .49106 m
.91702 .49381 L
s
1 .579 0 r
.008 w
.91702 .49381 Mdot
.016 w
.91702 .49381 m
.9173 .49629 L
s
.008 w
.9173 .49629 Mdot
.016 w
.9173 .49629 m
.91769 .49901 L
s
.008 w
.91769 .49901 Mdot
.016 w
.91769 .49901 m
.91815 .50169 L
s
1 .578 0 r
.008 w
.91815 .50169 Mdot
.016 w
.91815 .50169 m
.9187 .5045 L
s
.008 w
.9187 .5045 Mdot
.016 w
.9187 .5045 m
.91929 .50754 L
s
1 .577 0 r
.008 w
.91929 .50754 Mdot
.016 w
.91929 .50754 m
.9199 .51039 L
s
.008 w
.9199 .51039 Mdot
.016 w
.9199 .51039 m
.92054 .51339 L
s
.008 w
.92054 .51339 Mdot
.016 w
.92054 .51339 m
.92119 .51609 L
s
1 .576 0 r
.008 w
.92119 .51609 Mdot
.016 w
.92119 .51609 m
.92183 .51868 L
s
.008 w
.92183 .51868 Mdot
.016 w
.92183 .51868 m
.92249 .52099 L
s
.008 w
.92249 .52099 Mdot
.016 w
.92249 .52099 m
.92311 .52294 L
s
1 .575 0 r
.008 w
.92311 .52294 Mdot
.016 w
.92311 .52294 m
.92373 .52457 L
s
.008 w
.92373 .52457 Mdot
.016 w
.92373 .52457 m
.92432 .526 L
s
1 .574 0 r
.008 w
.92432 .526 Mdot
.016 w
.92432 .526 m
.9249 .52728 L
s
.008 w
.9249 .52728 Mdot
.016 w
.9249 .52728 m
.92546 .52836 L
s
.008 w
.92546 .52836 Mdot
.016 w
.92546 .52836 m
.92601 .52943 L
s
1 .573 0 r
.008 w
.92601 .52943 Mdot
.016 w
.92601 .52943 m
.92658 .53053 L
s
.008 w
.92658 .53053 Mdot
.016 w
.92658 .53053 m
.92716 .53163 L
s
1 .572 0 r
.008 w
.92716 .53163 Mdot
.016 w
.92716 .53163 m
.92775 .53294 L
s
.008 w
.92775 .53294 Mdot
.016 w
.92775 .53294 m
.92836 .5345 L
s
.008 w
.92836 .5345 Mdot
.016 w
.92836 .5345 m
.92899 .53621 L
s
1 .571 0 r
.008 w
.92899 .53621 Mdot
.016 w
.92899 .53621 m
.92962 .53835 L
s
.008 w
.92962 .53835 Mdot
.016 w
.92962 .53835 m
.93024 .54073 L
s
1 .57 0 r
.008 w
.93024 .54073 Mdot
.016 w
.93024 .54073 m
.93081 .54354 L
s
.008 w
.93081 .54354 Mdot
.016 w
.93081 .54354 m
.9313 .5464 L
s
.008 w
.9313 .5464 Mdot
.016 w
.9313 .5464 m
.93168 .54969 L
s
1 .569 0 r
.008 w
.93168 .54969 Mdot
.016 w
.93168 .54969 m
.93196 .55258 L
s
.008 w
.93196 .55258 Mdot
.016 w
.93196 .55258 m
.93211 .55564 L
s
.008 w
.93211 .55564 Mdot
.016 w
.93211 .55564 m
.93215 .5587 L
s
1 .568 0 r
.008 w
.93215 .5587 Mdot
.016 w
.93215 .5587 m
.93209 .56151 L
s
.008 w
.93209 .56151 Mdot
.016 w
.93209 .56151 m
.93193 .56427 L
s
1 .567 0 r
.008 w
.93193 .56427 Mdot
.016 w
.93193 .56427 m
.93171 .56664 L
s
.008 w
.93171 .56664 Mdot
.016 w
.93171 .56664 m
.93146 .56884 L
s
.008 w
.93146 .56884 Mdot
.016 w
.93146 .56884 m
.9312 .57069 L
s
1 .566 0 r
.008 w
.9312 .57069 Mdot
.016 w
.9312 .57069 m
.93093 .57233 L
s
.008 w
.93093 .57233 Mdot
.016 w
.93093 .57233 m
.93069 .57368 L
s
1 .565 0 r
.008 w
.93069 .57368 Mdot
.016 w
.93069 .57368 m
.9305 .57472 L
s
.008 w
.9305 .57472 Mdot
.016 w
.9305 .57472 m
.93037 .57548 L
s
.008 w
.93037 .57548 Mdot
.016 w
.93037 .57548 m
.9303 .57598 L
s
1 .564 0 r
.008 w
.9303 .57598 Mdot
.016 w
.9303 .57598 m
.9303 .57625 L
s
.008 w
.9303 .57625 Mdot
.016 w
.9303 .57625 m
.93036 .57629 L
s
1 .563 0 r
.008 w
.93036 .57629 Mdot
.016 w
.93036 .57629 m
.93049 .57616 L
s
.008 w
.93049 .57616 Mdot
.016 w
.93049 .57616 m
.93068 .57589 L
s
.008 w
.93068 .57589 Mdot
.016 w
.93068 .57589 m
.93091 .57555 L
s
1 .562 0 r
.008 w
.93091 .57555 Mdot
.016 w
.93091 .57555 m
.93114 .5752 L
s
.008 w
.93114 .5752 Mdot
.016 w
.93114 .5752 m
.93134 .5749 L
s
.008 w
.93134 .5749 Mdot
.016 w
.93134 .5749 m
.93147 .57469 L
s
1 .561 0 r
.008 w
.93147 .57469 Mdot
.016 w
.93147 .57469 m
.9315 .57461 L
s
.008 w
.9315 .57461 Mdot
.016 w
.9315 .57461 m
.93141 .5747 L
s
1 .56 0 r
.008 w
.93141 .5747 Mdot
.016 w
.93141 .5747 m
.93121 .575 L
s
.008 w
.93121 .575 Mdot
.016 w
.93121 .575 m
.93093 .57552 L
s
.008 w
.93093 .57552 Mdot
.016 w
.93093 .57552 m
.93058 .57631 L
s
1 .559 0 r
.008 w
.93058 .57631 Mdot
.016 w
.93058 .57631 m
.93015 .57738 L
s
.008 w
.93015 .57738 Mdot
.016 w
.93015 .57738 m
.92965 .57876 L
s
1 .558 0 r
.008 w
.92965 .57876 Mdot
.016 w
.92965 .57876 m
.92909 .58034 L
s
.008 w
.92909 .58034 Mdot
.016 w
.92909 .58034 m
.92845 .58215 L
s
.008 w
.92845 .58215 Mdot
.016 w
.92845 .58215 m
.92773 .58424 L
s
1 .557 0 r
.008 w
.92773 .58424 Mdot
.016 w
.92773 .58424 m
.92693 .58644 L
s
.008 w
.92693 .58644 Mdot
.016 w
.92693 .58644 m
.92607 .58895 L
s
.008 w
.92607 .58895 Mdot
.016 w
.92607 .58895 m
.92524 .59139 L
s
1 .556 0 r
.008 w
.92524 .59139 Mdot
.016 w
.92524 .59139 m
.92438 .59409 L
s
.008 w
.92438 .59409 Mdot
.016 w
.92438 .59409 m
.92362 .59684 L
s
1 .555 0 r
.008 w
.92362 .59684 Mdot
.016 w
.92362 .59684 m
.92287 .59978 L
s
.008 w
.92287 .59978 Mdot
.016 w
.92287 .59978 m
.92223 .60256 L
s
.008 w
.92223 .60256 Mdot
.016 w
.92223 .60256 m
.92161 .60553 L
s
1 .554 0 r
.008 w
.92161 .60553 Mdot
.016 w
.92161 .60553 m
.92101 .60842 L
s
.008 w
.92101 .60842 Mdot
.016 w
.92101 .60842 m
.92042 .61138 L
s
1 .553 0 r
.008 w
.92042 .61138 Mdot
.016 w
.92042 .61138 m
.91983 .61424 L
s
.008 w
.91983 .61424 Mdot
.016 w
.91983 .61424 m
.91923 .61707 L
s
.008 w
.91923 .61707 Mdot
.016 w
.91923 .61707 m
.91861 .61981 L
s
1 .552 0 r
.008 w
.91861 .61981 Mdot
.016 w
.91861 .61981 m
.91803 .62232 L
s
.008 w
.91803 .62232 Mdot
.016 w
.91803 .62232 m
.91746 .62462 L
s
1 .551 0 r
.008 w
.91746 .62462 Mdot
.016 w
.91746 .62462 m
.91694 .62667 L
s
.008 w
.91694 .62667 Mdot
.016 w
.91694 .62667 m
.91648 .62842 L
s
.008 w
.91648 .62842 Mdot
.016 w
.91648 .62842 m
.91608 .62996 L
s
1 .55 0 r
.008 w
.91608 .62996 Mdot
.016 w
.91608 .62996 m
.91573 .63112 L
s
.008 w
.91573 .63112 Mdot
.016 w
.91573 .63112 m
.91544 .63201 L
s
.008 w
.91544 .63201 Mdot
.016 w
.91544 .63201 m
.91524 .63264 L
s
1 .549 0 r
.008 w
.91524 .63264 Mdot
.016 w
.91524 .63264 m
.91514 .633 L
s
.008 w
.91514 .633 Mdot
.016 w
.91514 .633 m
.91516 .63313 L
s
1 .548 0 r
.008 w
.91516 .63313 Mdot
.016 w
.91516 .63313 m
.91527 .63306 L
s
.008 w
.91527 .63306 Mdot
.016 w
.91527 .63306 m
.91547 .63287 L
s
.008 w
.91547 .63287 Mdot
.016 w
.91547 .63287 m
.91571 .63263 L
s
1 .547 0 r
.008 w
.91571 .63263 Mdot
.016 w
.91571 .63263 m
.91597 .63243 L
s
.008 w
.91597 .63243 Mdot
.016 w
.91597 .63243 m
.9162 .63232 L
s
1 .546 0 r
.008 w
.9162 .63232 Mdot
.016 w
.9162 .63232 m
.91638 .63234 L
s
.008 w
.91638 .63234 Mdot
.016 w
.91638 .63234 m
.91644 .63252 L
s
.008 w
.91644 .63252 Mdot
.016 w
.91644 .63252 m
.91636 .63287 L
s
1 .545 0 r
.008 w
.91636 .63287 Mdot
.016 w
.91636 .63287 m
.91612 .63339 L
s
.008 w
.91612 .63339 Mdot
.016 w
.91612 .63339 m
.91567 .6341 L
s
1 .544 0 r
.008 w
.91567 .6341 Mdot
.016 w
.91567 .6341 m
.91503 .63501 L
s
.008 w
.91503 .63501 Mdot
.016 w
.91503 .63501 m
.91422 .6361 L
s
.008 w
.91422 .6361 Mdot
.016 w
.91422 .6361 m
.91328 .63737 L
s
1 .543 0 r
.008 w
.91328 .63737 Mdot
.016 w
.91328 .63737 m
.91215 .63883 L
s
.008 w
.91215 .63883 Mdot
.016 w
.91215 .63883 m
.9108 .64042 L
s
.008 w
.9108 .64042 Mdot
.016 w
.9108 .64042 m
.90954 .64203 L
s
1 .542 0 r
.008 w
.90954 .64203 Mdot
.016 w
.90954 .64203 m
.90812 .64366 L
s
.008 w
.90812 .64366 Mdot
.016 w
.90812 .64366 m
.90667 .64533 L
s
1 .541 0 r
.008 w
.90667 .64533 Mdot
.016 w
.90667 .64533 m
.90556 .64694 L
s
.008 w
.90556 .64694 Mdot
.016 w
.90556 .64694 m
.90426 .64878 L
s
.008 w
.90426 .64878 Mdot
.016 w
.90426 .64878 m
.90325 .65045 L
s
1 .54 0 r
.008 w
.90325 .65045 Mdot
.016 w
.90325 .65045 m
.90234 .65219 L
s
.008 w
.90234 .65219 Mdot
.016 w
.90234 .65219 m
.90152 .65405 L
s
1 .539 0 r
.008 w
.90152 .65405 Mdot
.016 w
.90152 .65405 m
.90084 .65603 L
s
.008 w
.90084 .65603 Mdot
.016 w
.90084 .65603 m
.90036 .65813 L
s
.008 w
.90036 .65813 Mdot
.016 w
.90036 .65813 m
.90005 .66014 L
s
1 .538 0 r
.008 w
.90005 .66014 Mdot
.016 w
.90005 .66014 m
.89986 .66236 L
s
.008 w
.89986 .66236 Mdot
.016 w
.89986 .66236 m
.89972 .66484 L
s
1 .537 0 r
.008 w
.89972 .66484 Mdot
.016 w
.89972 .66484 m
.89958 .66728 L
s
.008 w
.89958 .66728 Mdot
.016 w
.89958 .66728 m
.89944 .67 L
s
.008 w
.89944 .67 Mdot
.016 w
.89944 .67 m
.89926 .67291 L
s
1 .536 0 r
.008 w
.89926 .67291 Mdot
.016 w
.89926 .67291 m
.89895 .67589 L
s
.008 w
.89895 .67589 Mdot
.016 w
.89895 .67589 m
.89854 .67912 L
s
.008 w
.89854 .67912 Mdot
.016 w
.89854 .67912 m
.89805 .68202 L
s
1 .535 0 r
.008 w
.89805 .68202 Mdot
.016 w
.89805 .68202 m
.89759 .68482 L
s
.008 w
.89759 .68482 Mdot
.016 w
.89759 .68482 m
.89714 .68737 L
s
1 .534 0 r
.008 w
.89714 .68737 Mdot
.016 w
.89714 .68737 m
.89672 .68962 L
s
.008 w
.89672 .68962 Mdot
.016 w
.89672 .68962 m
.89635 .69163 L
s
.008 w
.89635 .69163 Mdot
.016 w
.89635 .69163 m
.89603 .69325 L
s
1 .533 0 r
.008 w
.89603 .69325 Mdot
.016 w
.89603 .69325 m
.89578 .69464 L
s
.008 w
.89578 .69464 Mdot
.016 w
.89578 .69464 m
.8956 .69574 L
s
1 .532 0 r
.008 w
.8956 .69574 Mdot
.016 w
.8956 .69574 m
.89548 .69654 L
s
.008 w
.89548 .69654 Mdot
.016 w
.89548 .69654 m
.89542 .69703 L
s
.008 w
.89542 .69703 Mdot
.016 w
.89542 .69703 m
.8954 .69725 L
s
1 .531 0 r
.008 w
.8954 .69725 Mdot
.016 w
.8954 .69725 m
.89542 .69725 L
s
.008 w
.89542 .69725 Mdot
.016 w
.89542 .69725 m
.89548 .6971 L
s
1 .53 0 r
.008 w
.89548 .6971 Mdot
.016 w
.89548 .6971 m
.89558 .69685 L
s
.008 w
.89558 .69685 Mdot
.016 w
.89558 .69685 m
.89569 .69659 L
s
.008 w
.89569 .69659 Mdot
.016 w
.89569 .69659 m
.89577 .69636 L
s
1 .529 0 r
.008 w
.89577 .69636 Mdot
.016 w
.89577 .69636 m
.8958 .69622 L
s
.008 w
.8958 .69622 Mdot
.016 w
.8958 .69622 m
.89575 .6962 L
s
.008 w
.89575 .6962 Mdot
.016 w
.89575 .6962 m
.89563 .69629 L
s
1 .528 0 r
.008 w
.89563 .69629 Mdot
.016 w
.89563 .69629 m
.89542 .69647 L
s
.008 w
.89542 .69647 Mdot
.016 w
.89542 .69647 m
.89515 .69672 L
s
1 .527 0 r
.008 w
.89515 .69672 Mdot
.016 w
.89515 .69672 m
.89483 .69701 L
s
.008 w
.89483 .69701 Mdot
.016 w
.89483 .69701 m
.89451 .69732 L
s
.008 w
.89451 .69732 Mdot
.016 w
.89451 .69732 m
.89421 .69764 L
s
1 .526 0 r
.008 w
.89421 .69764 Mdot
.016 w
.89421 .69764 m
.89395 .69794 L
s
.008 w
.89395 .69794 Mdot
.016 w
.89395 .69794 m
.89371 .69823 L
s
1 .525 0 r
.008 w
.89371 .69823 Mdot
.016 w
.89371 .69823 m
.89349 .69854 L
s
.008 w
.89349 .69854 Mdot
.016 w
.89349 .69854 m
.89329 .69891 L
s
.008 w
.89329 .69891 Mdot
.016 w
.89329 .69891 m
.8931 .69936 L
s
1 .524 0 r
.008 w
.8931 .69936 Mdot
.016 w
.8931 .69936 m
.89295 .69992 L
s
.008 w
.89295 .69992 Mdot
.016 w
.89295 .69992 m
.89285 .70063 L
s
1 .523 0 r
.008 w
.89285 .70063 Mdot
.016 w
.89285 .70063 m
.8928 .70152 L
s
.008 w
.8928 .70152 Mdot
.016 w
.8928 .70152 m
.89275 .7027 L
s
.008 w
.89275 .7027 Mdot
.016 w
.89275 .7027 m
.89267 .70426 L
s
1 .522 0 r
.008 w
.89267 .70426 Mdot
.016 w
.89267 .70426 m
.89251 .70611 L
s
.008 w
.89251 .70611 Mdot
.016 w
.89251 .70611 m
.89222 .7084 L
s
.008 w
.89222 .7084 Mdot
.016 w
.89222 .7084 m
.89177 .7112 L
s
1 .521 0 r
.008 w
.89177 .7112 Mdot
.016 w
.89177 .7112 m
.89112 .71428 L
s
.008 w
.89112 .71428 Mdot
.016 w
.89112 .71428 m
.89027 .71766 L
s
1 .52 0 r
.008 w
.89027 .71766 Mdot
.016 w
.89027 .71766 m
.88923 .72165 L
s
.008 w
.88923 .72165 Mdot
.016 w
.88923 .72165 m
.8881 .72554 L
s
.008 w
.8881 .72554 Mdot
.016 w
.8881 .72554 m
.88687 .72961 L
s
1 .519 0 r
.008 w
.88687 .72961 Mdot
.016 w
.88687 .72961 m
.8856 .73403 L
s
.008 w
.8856 .73403 Mdot
.016 w
.8856 .73403 m
.8843 .73793 L
s
1 .518 0 r
.008 w
.8843 .73793 Mdot
.016 w
.8843 .73793 m
.88295 .7424 L
s
.008 w
.88295 .7424 Mdot
.016 w
.88295 .7424 m
.88157 .74627 L
s
.008 w
.88157 .74627 Mdot
.016 w
.88157 .74627 m
.88015 .75047 L
s
1 .517 0 r
.008 w
.88015 .75047 Mdot
.016 w
.88015 .75047 m
.87874 .75446 L
s
.008 w
.87874 .75446 Mdot
.016 w
.87874 .75446 m
.87731 .75854 L
s
.008 w
.87731 .75854 Mdot
.016 w
.87731 .75854 m
.8759 .76245 L
s
1 .516 0 r
.008 w
.8759 .76245 Mdot
.016 w
.8759 .76245 m
.87453 .76652 L
s
.008 w
.87453 .76652 Mdot
.016 w
.87453 .76652 m
.87325 .76991 L
s
1 .515 0 r
.008 w
.87325 .76991 Mdot
.016 w
.87325 .76991 m
.87202 .77339 L
s
.008 w
.87202 .77339 Mdot
.016 w
.87202 .77339 m
.87086 .77676 L
s
.008 w
.87086 .77676 Mdot
.016 w
.87086 .77676 m
.86974 .77971 L
s
1 .514 0 r
.008 w
.86974 .77971 Mdot
.016 w
.86974 .77971 m
.86868 .78271 L
s
.008 w
.86868 .78271 Mdot
.016 w
.86868 .78271 m
.86768 .78523 L
s
1 .513 0 r
.008 w
.86768 .78523 Mdot
.016 w
.86768 .78523 m
.86672 .78764 L
s
.008 w
.86672 .78764 Mdot
.016 w
.86672 .78764 m
.86579 .78992 L
s
.008 w
.86579 .78992 Mdot
.016 w
.86579 .78992 m
.86496 .79182 L
s
1 .512 0 r
.008 w
.86496 .79182 Mdot
.016 w
.86496 .79182 m
.86416 .79357 L
s
.008 w
.86416 .79357 Mdot
.016 w
.86416 .79357 m
.86344 .79504 L
s
1 .511 0 r
.008 w
.86344 .79504 Mdot
.016 w
.86344 .79504 m
.86285 .79621 L
s
.008 w
.86285 .79621 Mdot
.016 w
.86285 .79621 m
.86241 .79703 L
s
.008 w
.86241 .79703 Mdot
.016 w
.86241 .79703 m
.86204 .79774 L
s
1 .51 0 r
.008 w
.86204 .79774 Mdot
.016 w
.86204 .79774 m
.8617 .79835 L
s
.008 w
.8617 .79835 Mdot
.016 w
.8617 .79835 m
.86134 .79895 L
s
.008 w
.86134 .79895 Mdot
.016 w
.86134 .79895 m
.86105 .79944 L
s
1 .509 0 r
.008 w
.86105 .79944 Mdot
.016 w
.86105 .79944 m
.86074 .79992 L
s
.008 w
.86074 .79992 Mdot
.016 w
.86074 .79992 m
.86046 .80037 L
s
1 .508 0 r
.008 w
.86046 .80037 Mdot
.016 w
.86046 .80037 m
.86026 .80075 L
s
.008 w
.86026 .80075 Mdot
.016 w
.86026 .80075 m
.86012 .80104 L
s
.008 w
.86012 .80104 Mdot
.016 w
.86012 .80104 m
.86002 .80126 L
s
1 .507 0 r
.008 w
.86002 .80126 Mdot
.016 w
.86002 .80126 m
.85993 .80139 L
s
.008 w
.85993 .80139 Mdot
.016 w
.85993 .80139 m
.8598 .80149 L
s
1 .506 0 r
.008 w
.8598 .80149 Mdot
.016 w
.8598 .80149 m
.85962 .80164 L
s
.008 w
.85962 .80164 Mdot
.016 w
.85962 .80164 m
.85931 .80189 L
s
.008 w
.85931 .80189 Mdot
.016 w
.85931 .80189 m
.85889 .80221 L
s
1 .505 0 r
.008 w
.85889 .80221 Mdot
.016 w
.85889 .80221 m
.85841 .8026 L
s
.008 w
.85841 .8026 Mdot
.016 w
.85841 .8026 m
.8579 .803 L
s
1 .504 0 r
.008 w
.8579 .803 Mdot
.016 w
.8579 .803 m
.8574 .80336 L
s
.008 w
.8574 .80336 Mdot
.016 w
.8574 .80336 m
.85697 .80364 L
s
.008 w
.85697 .80364 Mdot
.016 w
.85697 .80364 m
.85662 .80382 L
s
1 .503 0 r
.008 w
.85662 .80382 Mdot
.016 w
.85662 .80382 m
.85636 .80392 L
s
.008 w
.85636 .80392 Mdot
.016 w
.85636 .80392 m
.85619 .80397 L
s
.008 w
.85619 .80397 Mdot
.016 w
.85619 .80397 m
.85603 .80401 L
s
1 .502 0 r
.008 w
.85603 .80401 Mdot
.016 w
.85603 .80401 m
.85593 .80406 L
s
.008 w
.85593 .80406 Mdot
.016 w
.85593 .80406 m
.85588 .80412 L
s
1 .501 0 r
.008 w
.85588 .80412 Mdot
.016 w
.85588 .80412 m
.85587 .80419 L
s
.008 w
.85587 .80419 Mdot
.016 w
.85587 .80419 m
.85598 .80422 L
s
.008 w
.85598 .80422 Mdot
.016 w
.85598 .80422 m
.85618 .80419 L
s
1 .5 0 r
.008 w
.85618 .80419 Mdot
.016 w
.85618 .80419 m
.85645 .8041 L
s
.008 w
.85645 .8041 Mdot
.016 w
.85645 .8041 m
.85673 .80399 L
s
1 .499 0 r
.008 w
.85673 .80399 Mdot
.016 w
.85673 .80399 m
.85699 .80383 L
s
.008 w
.85699 .80383 Mdot
.016 w
.85699 .80383 m
.85719 .80366 L
s
.008 w
.85719 .80366 Mdot
.016 w
.85719 .80366 m
.85733 .80346 L
s
1 .498 0 r
.008 w
.85733 .80346 Mdot
.016 w
.85733 .80346 m
.85741 .80331 L
s
.008 w
.85741 .80331 Mdot
.016 w
.85741 .80331 m
.85746 .80318 L
s
1 .497 0 r
.008 w
.85746 .80318 Mdot
.016 w
.85746 .80318 m
.85747 .80311 L
s
.008 w
.85747 .80311 Mdot
.016 w
.85747 .80311 m
.85744 .80309 L
s
.008 w
.85744 .80309 Mdot
.016 w
.85744 .80309 m
.85737 .80311 L
s
1 .496 0 r
.008 w
.85737 .80311 Mdot
.016 w
.85737 .80311 m
.8573 .80315 L
s
.008 w
.8573 .80315 Mdot
.016 w
.8573 .80315 m
.85719 .80322 L
s
.008 w
.85719 .80322 Mdot
.016 w
.85719 .80322 m
.85703 .80336 L
s
1 .495 0 r
.008 w
.85703 .80336 Mdot
.016 w
.85703 .80336 m
.85682 .80356 L
s
.008 w
.85682 .80356 Mdot
.016 w
.85682 .80356 m
.85657 .8038 L
s
1 .494 0 r
.008 w
.85657 .8038 Mdot
.016 w
.85657 .8038 m
.85628 .80408 L
s
.008 w
.85628 .80408 Mdot
.016 w
.85628 .80408 m
.85596 .80439 L
s
.008 w
.85596 .80439 Mdot
.016 w
.85596 .80439 m
.85562 .80472 L
s
1 .493 0 r
.008 w
.85562 .80472 Mdot
.016 w
.85562 .80472 m
.85528 .80502 L
s
.008 w
.85528 .80502 Mdot
.016 w
.85528 .80502 m
.85499 .80521 L
s
1 .492 0 r
.008 w
.85499 .80521 Mdot
.016 w
.85499 .80521 m
.85483 .80528 L
s
.008 w
.85483 .80528 Mdot
.016 w
.85483 .80528 m
.85472 .8053 L
s
.008 w
.85472 .8053 Mdot
.016 w
.85472 .8053 m
.85458 .80536 L
s
1 .491 0 r
.008 w
.85458 .80536 Mdot
.016 w
.85458 .80536 m
.85437 .80547 L
s
.008 w
.85437 .80547 Mdot
.016 w
.85437 .80547 m
.8541 .80567 L
s
1 .49 0 r
.008 w
.8541 .80567 Mdot
.016 w
.8541 .80567 m
.85373 .80598 L
s
.008 w
.85373 .80598 Mdot
.016 w
.85373 .80598 m
.85324 .80642 L
s
.008 w
.85324 .80642 Mdot
.016 w
.85324 .80642 m
.85262 .80698 L
s
1 .489 0 r
.008 w
.85262 .80698 Mdot
.016 w
.85262 .80698 m
.85187 .80768 L
s
.008 w
.85187 .80768 Mdot
.016 w
.85187 .80768 m
.85099 .80851 L
s
.008 w
.85099 .80851 Mdot
.016 w
.85099 .80851 m
.85003 .80943 L
s
1 .488 0 r
.008 w
.85003 .80943 Mdot
.016 w
.85003 .80943 m
.849 .81044 L
s
.008 w
.849 .81044 Mdot
.016 w
.849 .81044 m
.848 .81144 L
s
1 .487 0 r
.008 w
.848 .81144 Mdot
.016 w
.848 .81144 m
.8469 .81229 L
s
.008 w
.8469 .81229 Mdot
.016 w
.8469 .81229 m
.84567 .81348 L
s
.008 w
.84567 .81348 Mdot
.016 w
.84567 .81348 m
.84438 .81472 L
s
1 .486 0 r
.008 w
.84438 .81472 Mdot
.016 w
.84438 .81472 m
.84309 .81591 L
s
.008 w
.84309 .81591 Mdot
.016 w
.84309 .81591 m
.84189 .81692 L
s
1 .485 0 r
.008 w
.84189 .81692 Mdot
.016 w
.84189 .81692 m
.8408 .81775 L
s
.008 w
.8408 .81775 Mdot
.016 w
.8408 .81775 m
.83987 .81839 L
s
.008 w
.83987 .81839 Mdot
.016 w
.83987 .81839 m
.83905 .8189 L
s
1 .484 0 r
.008 w
.83905 .8189 Mdot
.016 w
.83905 .8189 m
.83832 .81933 L
s
.008 w
.83832 .81933 Mdot
.016 w
.83832 .81933 m
.83764 .81969 L
s
1 .483 0 r
.008 w
.83764 .81969 Mdot
.016 w
.83764 .81969 m
.83703 .82 L
s
.008 w
.83703 .82 Mdot
.016 w
.83703 .82 m
.83641 .82031 L
s
.008 w
.83641 .82031 Mdot
.016 w
.83641 .82031 m
.83587 .82057 L
s
1 .482 0 r
.008 w
.83587 .82057 Mdot
.016 w
.83587 .82057 m
.83546 .82074 L
s
.008 w
.83546 .82074 Mdot
.016 w
.83546 .82074 m
.8352 .82078 L
s
.008 w
.8352 .82078 Mdot
.016 w
.8352 .82078 m
.83509 .8207 L
s
1 .481 0 r
.008 w
.83509 .8207 Mdot
.016 w
.83509 .8207 m
.83511 .8205 L
s
.008 w
.83511 .8205 Mdot
.016 w
.83511 .8205 m
.83521 .82029 L
s
1 .48 0 r
.008 w
.83521 .82029 Mdot
.016 w
.83521 .82029 m
.83533 .82008 L
s
.008 w
.83533 .82008 Mdot
.016 w
.83533 .82008 m
.83545 .81994 L
s
.008 w
.83545 .81994 Mdot
.016 w
.83545 .81994 m
.83558 .8198 L
s
1 .479 0 r
.008 w
.83558 .8198 Mdot
.016 w
.83558 .8198 m
.83569 .81972 L
s
.008 w
.83569 .81972 Mdot
.016 w
.83569 .81972 m
.83579 .81964 L
s
1 .478 0 r
.008 w
.83579 .81964 Mdot
.016 w
.83579 .81964 m
.83584 .81962 L
s
.008 w
.83584 .81962 Mdot
.016 w
.83584 .81962 m
.83585 .81969 L
s
.008 w
.83585 .81969 Mdot
.016 w
.83585 .81969 m
.83583 .81983 L
s
1 .477 0 r
.008 w
.83583 .81983 Mdot
.016 w
.83583 .81983 m
.83577 .82006 L
s
.008 w
.83577 .82006 Mdot
.016 w
.83577 .82006 m
.83565 .82037 L
s
.008 w
.83565 .82037 Mdot
.016 w
.83565 .82037 m
.83544 .82082 L
s
1 .476 0 r
.008 w
.83544 .82082 Mdot
.016 w
.83544 .82082 m
.83513 .82136 L
s
.008 w
.83513 .82136 Mdot
.016 w
.83513 .82136 m
.83474 .82194 L
s
1 .475 0 r
.008 w
.83474 .82194 Mdot
.016 w
.83474 .82194 m
.83435 .82236 L
s
.008 w
.83435 .82236 Mdot
.016 w
.83435 .82236 m
.83395 .8227 L
s
.008 w
.83395 .8227 Mdot
.016 w
.83395 .8227 m
.83353 .82295 L
s
1 .474 0 r
.008 w
.83353 .82295 Mdot
.016 w
.83353 .82295 m
.83303 .8232 L
s
.008 w
.83303 .8232 Mdot
.016 w
.83303 .8232 m
.83259 .8234 L
s
1 .473 0 r
.008 w
.83259 .8234 Mdot
.016 w
.83259 .8234 m
.83209 .82361 L
s
.008 w
.83209 .82361 Mdot
.016 w
.83209 .82361 m
.83161 .82382 L
s
.008 w
.83161 .82382 Mdot
.016 w
.83161 .82382 m
.83112 .82402 L
s
1 .472 0 r
.008 w
.83112 .82402 Mdot
.016 w
.83112 .82402 m
.83063 .82424 L
s
.008 w
.83063 .82424 Mdot
.016 w
.83063 .82424 m
.83014 .82448 L
s
1 .471 0 r
.008 w
.83014 .82448 Mdot
.016 w
.83014 .82448 m
.82967 .82474 L
s
.008 w
.82967 .82474 Mdot
.016 w
.82967 .82474 m
.82917 .82504 L
s
.008 w
.82917 .82504 Mdot
.016 w
.82917 .82504 m
.82856 .82543 L
s
1 .47 0 r
.008 w
.82856 .82543 Mdot
.016 w
.82856 .82543 m
.82794 .82592 L
s
.008 w
.82794 .82592 Mdot
.016 w
.82794 .82592 m
.82731 .82651 L
s
.008 w
.82731 .82651 Mdot
.016 w
.82731 .82651 m
.82651 .82729 L
s
1 .469 0 r
.008 w
.82651 .82729 Mdot
.016 w
.82651 .82729 m
.82566 .8282 L
s
.008 w
.82566 .8282 Mdot
.016 w
.82566 .8282 m
.82476 .82917 L
s
1 .468 0 r
.008 w
.82476 .82917 Mdot
.016 w
.82476 .82917 m
.82394 .83006 L
s
.008 w
.82394 .83006 Mdot
.016 w
.82394 .83006 m
.82305 .83091 L
s
.008 w
.82305 .83091 Mdot
.016 w
.82305 .83091 m
.82217 .83168 L
s
1 .467 0 r
.008 w
.82217 .83168 Mdot
.016 w
.82217 .83168 m
.82136 .83236 L
s
.008 w
.82136 .83236 Mdot
.016 w
.82136 .83236 m
.82055 .83298 L
s
1 .466 0 r
.008 w
.82055 .83298 Mdot
.016 w
.82055 .83298 m
.81995 .83355 L
s
.008 w
.81995 .83355 Mdot
.016 w
.81995 .83355 m
.8194 .83408 L
s
.008 w
.8194 .83408 Mdot
.016 w
.8194 .83408 m
.819 .83452 L
s
1 .465 0 r
.008 w
.819 .83452 Mdot
.016 w
.819 .83452 m
.81878 .83483 L
s
.008 w
.81878 .83483 Mdot
.016 w
.81878 .83483 m
.81872 .83499 L
s
1 .464 0 r
.008 w
.81872 .83499 Mdot
.016 w
.81872 .83499 m
.81879 .83504 L
s
.008 w
.81879 .83504 Mdot
.016 w
.81879 .83504 m
.81897 .83501 L
s
.008 w
.81897 .83501 Mdot
.016 w
.81897 .83501 m
.81916 .83494 L
s
1 .463 0 r
.008 w
.81916 .83494 Mdot
.016 w
.81916 .83494 m
.81934 .83485 L
s
.008 w
.81934 .83485 Mdot
.016 w
.81934 .83485 m
.81948 .83474 L
s
.008 w
.81948 .83474 Mdot
.016 w
.81948 .83474 m
.8196 .8346 L
s
1 .462 0 r
.008 w
.8196 .8346 Mdot
.016 w
.8196 .8346 m
.81966 .83444 L
s
.008 w
.81966 .83444 Mdot
.016 w
.81966 .83444 m
.81963 .83424 L
s
1 .461 0 r
.008 w
.81963 .83424 Mdot
.016 w
.81963 .83424 m
.81952 .83398 L
s
.008 w
.81952 .83398 Mdot
.016 w
.81952 .83398 m
.81933 .83367 L
s
.008 w
.81933 .83367 Mdot
.016 w
.81933 .83367 m
.81907 .83333 L
s
1 .46 0 r
.008 w
.81907 .83333 Mdot
.016 w
.81907 .83333 m
.81874 .83298 L
s
.008 w
.81874 .83298 Mdot
.016 w
.81874 .83298 m
.81836 .83261 L
s
1 .459 0 r
.008 w
.81836 .83261 Mdot
.016 w
.81836 .83261 m
.81801 .83226 L
s
.008 w
.81801 .83226 Mdot
.016 w
.81801 .83226 m
.81773 .8319 L
s
.008 w
.81773 .8319 Mdot
.016 w
.81773 .8319 m
.81755 .83156 L
s
1 .458 0 r
.008 w
.81755 .83156 Mdot
.016 w
.81755 .83156 m
.81752 .83123 L
s
.008 w
.81752 .83123 Mdot
.016 w
.81752 .83123 m
.81764 .83093 L
s
1 .457 0 r
.008 w
.81764 .83093 Mdot
.016 w
.81764 .83093 m
.81787 .83069 L
s
.008 w
.81787 .83069 Mdot
.016 w
.81787 .83069 m
.81818 .83051 L
s
.008 w
.81818 .83051 Mdot
.016 w
.81818 .83051 m
.81856 .83038 L
s
1 .456 0 r
.008 w
.81856 .83038 Mdot
.016 w
.81856 .83038 m
.81902 .83033 L
s
.008 w
.81902 .83033 Mdot
.016 w
.81902 .83033 m
.81952 .83034 L
s
.008 w
.81952 .83034 Mdot
.016 w
.81952 .83034 m
.82005 .83037 L
s
1 .455 0 r
.008 w
.82005 .83037 Mdot
.016 w
.82005 .83037 m
.82059 .83038 L
s
.008 w
.82059 .83038 Mdot
.016 w
.82059 .83038 m
.82115 .83034 L
s
1 .454 0 r
.008 w
.82115 .83034 Mdot
.016 w
.82115 .83034 m
.82172 .8302 L
s
.008 w
.82172 .8302 Mdot
.016 w
.82172 .8302 m
.8223 .82996 L
s
.008 w
.8223 .82996 Mdot
.016 w
.8223 .82996 m
.82291 .8296 L
s
1 .453 0 r
.008 w
.82291 .8296 Mdot
.016 w
.82291 .8296 m
.82352 .82912 L
s
.008 w
.82352 .82912 Mdot
.016 w
.82352 .82912 m
.82416 .8285 L
s
1 .452 0 r
.008 w
.82416 .8285 Mdot
.016 w
.82416 .8285 m
.82492 .8277 L
s
.008 w
.82492 .8277 Mdot
.016 w
.82492 .8277 m
.82588 .82673 L
s
.008 w
.82588 .82673 Mdot
.016 w
.82588 .82673 m
.82705 .8256 L
s
1 .451 0 r
.008 w
.82705 .8256 Mdot
.016 w
.82705 .8256 m
.82852 .82435 L
s
.008 w
.82852 .82435 Mdot
.016 w
.82852 .82435 m
.83023 .82295 L
s
1 .45 0 r
.008 w
.83023 .82295 Mdot
.016 w
.83023 .82295 m
.83218 .82142 L
s
.008 w
.83218 .82142 Mdot
.016 w
.83218 .82142 m
.83442 .81981 L
s
.008 w
.83442 .81981 Mdot
.016 w
.83442 .81981 m
.83674 .81816 L
s
1 .449 0 r
.008 w
.83674 .81816 Mdot
.016 w
.83674 .81816 m
.83926 .81643 L
s
.008 w
.83926 .81643 Mdot
.016 w
.83926 .81643 m
.84192 .8147 L
s
.008 w
.84192 .8147 Mdot
.016 w
.84192 .8147 m
.84449 .81292 L
s
1 .448 0 r
.008 w
.84449 .81292 Mdot
.016 w
.84449 .81292 m
.84703 .81122 L
s
.008 w
.84703 .81122 Mdot
.016 w
.84703 .81122 m
.84965 .80948 L
s
1 .447 0 r
.008 w
.84965 .80948 Mdot
.016 w
.84965 .80948 m
.85191 .80776 L
s
.008 w
.85191 .80776 Mdot
.016 w
.85191 .80776 m
.85418 .80616 L
s
.008 w
.85418 .80616 Mdot
.016 w
.85418 .80616 m
.85622 .80457 L
s
1 .446 0 r
.008 w
.85622 .80457 Mdot
.016 w
.85622 .80457 m
.85806 .80302 L
s
.008 w
.85806 .80302 Mdot
.016 w
.85806 .80302 m
.85969 .80147 L
s
1 .445 0 r
.008 w
.85969 .80147 Mdot
.016 w
.85969 .80147 m
.86114 .79998 L
s
.008 w
.86114 .79998 Mdot
.016 w
.86114 .79998 m
.86228 .79854 L
s
.008 w
.86228 .79854 Mdot
.016 w
.86228 .79854 m
.86327 .79713 L
s
1 .444 0 r
.008 w
.86327 .79713 Mdot
.016 w
.86327 .79713 m
.86411 .79582 L
s
.008 w
.86411 .79582 Mdot
.016 w
.86411 .79582 m
.86478 .79461 L
s
1 .443 0 r
.008 w
.86478 .79461 Mdot
.016 w
.86478 .79461 m
.86533 .79347 L
s
.008 w
.86533 .79347 Mdot
.016 w
.86533 .79347 m
.86575 .7924 L
s
.008 w
.86575 .7924 Mdot
.016 w
.86575 .7924 m
.86605 .79142 L
s
1 .442 0 r
.008 w
.86605 .79142 Mdot
.016 w
.86605 .79142 m
.86624 .79045 L
s
.008 w
.86624 .79045 Mdot
.016 w
.86624 .79045 m
.86634 .78955 L
s
.008 w
.86634 .78955 Mdot
.016 w
.86634 .78955 m
.86635 .7886 L
s
1 .441 0 r
.008 w
.86635 .7886 Mdot
.016 w
.86635 .7886 m
.86627 .78774 L
s
.008 w
.86627 .78774 Mdot
.016 w
.86627 .78774 m
.86613 .78689 L
s
1 .44 0 r
.008 w
.86613 .78689 Mdot
.016 w
.86613 .78689 m
.86597 .78608 L
s
.008 w
.86597 .78608 Mdot
.016 w
.86597 .78608 m
.86579 .78532 L
s
.008 w
.86579 .78532 Mdot
.016 w
.86579 .78532 m
.86562 .78468 L
s
1 .439 0 r
.008 w
.86562 .78468 Mdot
.016 w
.86562 .78468 m
.86546 .78413 L
s
.008 w
.86546 .78413 Mdot
.016 w
.86546 .78413 m
.86533 .78367 L
s
1 .438 0 r
.008 w
.86533 .78367 Mdot
.016 w
.86533 .78367 m
.86523 .7833 L
s
.008 w
.86523 .7833 Mdot
.016 w
.86523 .7833 m
.86519 .78302 L
s
.008 w
.86519 .78302 Mdot
.016 w
.86519 .78302 m
.86519 .78285 L
s
1 .437 0 r
.008 w
.86519 .78285 Mdot
.016 w
.86519 .78285 m
.86524 .78281 L
s
.008 w
.86524 .78281 Mdot
.016 w
.86524 .78281 m
.86535 .78288 L
s
.008 w
.86535 .78288 Mdot
.016 w
.86535 .78288 m
.86554 .78305 L
s
1 .436 0 r
.008 w
.86554 .78305 Mdot
.016 w
.86554 .78305 m
.86579 .7833 L
s
.008 w
.86579 .7833 Mdot
.016 w
.86579 .7833 m
.86612 .78353 L
s
1 .435 0 r
.008 w
.86612 .78353 Mdot
.016 w
.86612 .78353 m
.86657 .78369 L
s
.008 w
.86657 .78369 Mdot
.016 w
.86657 .78369 m
.867 .78371 L
s
.008 w
.867 .78371 Mdot
.016 w
.867 .78371 m
.86753 .78351 L
s
1 .434 0 r
.008 w
.86753 .78351 Mdot
.016 w
.86753 .78351 m
.86814 .78301 L
s
.008 w
.86814 .78301 Mdot
.016 w
.86814 .78301 m
.86883 .78218 L
s
1 .433 0 r
.008 w
.86883 .78218 Mdot
.016 w
.86883 .78218 m
.86963 .78096 L
s
.008 w
.86963 .78096 Mdot
.016 w
.86963 .78096 m
.8705 .77938 L
s
.008 w
.8705 .77938 Mdot
.016 w
.8705 .77938 m
.8715 .77739 L
s
1 .432 0 r
.008 w
.8715 .77739 Mdot
.016 w
.8715 .77739 m
.87255 .77499 L
s
.008 w
.87255 .77499 Mdot
.016 w
.87255 .77499 m
.87371 .77199 L
s
1 .431 0 r
.008 w
.87371 .77199 Mdot
.016 w
.87371 .77199 m
.87487 .76922 L
s
.008 w
.87487 .76922 Mdot
.016 w
.87487 .76922 m
.87611 .76563 L
s
.008 w
.87611 .76563 Mdot
.016 w
.87611 .76563 m
.8773 .7625 L
s
1 .43 0 r
.008 w
.8773 .7625 Mdot
.016 w
.8773 .7625 m
.87855 .75869 L
s
.008 w
.87855 .75869 Mdot
.016 w
.87855 .75869 m
.87983 .75475 L
s
.008 w
.87983 .75475 Mdot
.016 w
.87983 .75475 m
.88105 .75116 L
s
1 .429 0 r
.008 w
.88105 .75116 Mdot
.016 w
.88105 .75116 m
.88231 .74751 L
s
.008 w
.88231 .74751 Mdot
.016 w
.88231 .74751 m
.8835 .74385 L
s
1 .428 0 r
.008 w
.8835 .74385 Mdot
.016 w
.8835 .74385 m
.88465 .74029 L
s
.008 w
.88465 .74029 Mdot
.016 w
.88465 .74029 m
.88573 .73688 L
s
.008 w
.88573 .73688 Mdot
.016 w
.88573 .73688 m
.88673 .73368 L
s
1 .427 0 r
.008 w
.88673 .73368 Mdot
.016 w
.88673 .73368 m
.88757 .73073 L
s
.008 w
.88757 .73073 Mdot
.016 w
.88757 .73073 m
.88832 .72814 L
s
1 .426 0 r
.008 w
.88832 .72814 Mdot
.016 w
.88832 .72814 m
.88899 .72566 L
s
.008 w
.88899 .72566 Mdot
.016 w
.88899 .72566 m
.88953 .72368 L
s
.008 w
.88953 .72368 Mdot
.016 w
.88953 .72368 m
.88998 .72191 L
s
1 .425 0 r
.008 w
.88998 .72191 Mdot
.016 w
.88998 .72191 m
.89032 .7204 L
s
.008 w
.89032 .7204 Mdot
.016 w
.89032 .7204 m
.89057 .71926 L
s
1 .424 0 r
.008 w
.89057 .71926 Mdot
.016 w
.89057 .71926 m
.89074 .71843 L
s
.008 w
.89074 .71843 Mdot
.016 w
.89074 .71843 m
.89085 .71789 L
s
.008 w
.89085 .71789 Mdot
.016 w
.89085 .71789 m
.89089 .71757 L
s
1 .423 0 r
.008 w
.89089 .71757 Mdot
.016 w
.89089 .71757 m
.89087 .71744 L
s
.008 w
.89087 .71744 Mdot
.016 w
.89087 .71744 m
.8908 .71742 L
s
.008 w
.8908 .71742 Mdot
.016 w
.8908 .71742 m
.89066 .71744 L
s
1 .422 0 r
.008 w
.89066 .71744 Mdot
.016 w
.89066 .71744 m
.89046 .71744 L
s
.008 w
.89046 .71744 Mdot
.016 w
.89046 .71744 m
.89018 .71733 L
s
1 .421 0 r
.008 w
.89018 .71733 Mdot
.016 w
.89018 .71733 m
.88982 .71711 L
s
.008 w
.88982 .71711 Mdot
.016 w
.88982 .71711 m
.88938 .71675 L
s
.008 w
.88938 .71675 Mdot
.016 w
.88938 .71675 m
.88887 .7163 L
s
1 .42 0 r
.008 w
.88887 .7163 Mdot
.016 w
.88887 .7163 m
.88828 .71575 L
s
.008 w
.88828 .71575 Mdot
.016 w
.88828 .71575 m
.8877 .71516 L
s
1 .419 0 r
.008 w
.8877 .71516 Mdot
.016 w
.8877 .71516 m
.88709 .71455 L
s
.008 w
.88709 .71455 Mdot
.016 w
.88709 .71455 m
.88648 .71397 L
s
.008 w
.88648 .71397 Mdot
.016 w
.88648 .71397 m
.8859 .71346 L
s
1 .418 0 r
.008 w
.8859 .71346 Mdot
.016 w
.8859 .71346 m
.88542 .71302 L
s
.008 w
.88542 .71302 Mdot
.016 w
.88542 .71302 m
.88506 .71267 L
s
1 .417 0 r
.008 w
.88506 .71267 Mdot
.016 w
.88506 .71267 m
.88484 .71241 L
s
.008 w
.88484 .71241 Mdot
.016 w
.88484 .71241 m
.88478 .71225 L
s
.008 w
.88478 .71225 Mdot
.016 w
.88478 .71225 m
.88488 .71218 L
s
1 .416 0 r
.008 w
.88488 .71218 Mdot
.016 w
.88488 .71218 m
.88511 .71217 L
s
.008 w
.88511 .71217 Mdot
.016 w
.88511 .71217 m
.88546 .7122 L
s
.008 w
.88546 .7122 Mdot
.016 w
.88546 .7122 m
.88587 .71225 L
s
1 .415 0 r
.008 w
.88587 .71225 Mdot
.016 w
.88587 .71225 m
.88632 .71229 L
s
.008 w
.88632 .71229 Mdot
.016 w
.88632 .71229 m
.88678 .71228 L
s
1 .414 0 r
.008 w
.88678 .71228 Mdot
.016 w
.88678 .71228 m
.88722 .71222 L
s
.008 w
.88722 .71222 Mdot
.016 w
.88722 .71222 m
.88762 .71214 L
s
.008 w
.88762 .71214 Mdot
.016 w
.88762 .71214 m
.88796 .71204 L
s
1 .413 0 r
.008 w
.88796 .71204 Mdot
.016 w
.88796 .71204 m
.88822 .71194 L
s
.008 w
.88822 .71194 Mdot
.016 w
.88822 .71194 m
.88838 .71186 L
s
1 .412 0 r
.008 w
.88838 .71186 Mdot
.016 w
.88838 .71186 m
.88844 .71182 L
s
.008 w
.88844 .71182 Mdot
.016 w
.88844 .71182 m
.88842 .71184 L
s
.008 w
.88842 .71184 Mdot
.016 w
.88842 .71184 m
.88833 .71191 L
s
1 .411 0 r
.008 w
.88833 .71191 Mdot
.016 w
.88833 .71191 m
.88818 .71206 L
s
.008 w
.88818 .71206 Mdot
.016 w
.88818 .71206 m
.88799 .71227 L
s
1 .41 0 r
.008 w
.88799 .71227 Mdot
.016 w
.88799 .71227 m
.88779 .71252 L
s
.008 w
.88779 .71252 Mdot
.016 w
.88779 .71252 m
.88757 .71279 L
s
.008 w
.88757 .71279 Mdot
.016 w
.88757 .71279 m
.88734 .71302 L
s
1 .409 0 r
.008 w
.88734 .71302 Mdot
.016 w
.88734 .71302 m
.88709 .71327 L
s
.008 w
.88709 .71327 Mdot
.016 w
.88709 .71327 m
.88682 .71352 L
s
.008 w
.88682 .71352 Mdot
.016 w
.88682 .71352 m
.88652 .71379 L
s
1 .408 0 r
.008 w
.88652 .71379 Mdot
.016 w
.88652 .71379 m
.88619 .7141 L
s
.008 w
.88619 .7141 Mdot
.016 w
.88619 .7141 m
.88585 .71442 L
s
1 .407 0 r
.008 w
.88585 .71442 Mdot
.016 w
.88585 .71442 m
.88549 .71478 L
s
.008 w
.88549 .71478 Mdot
.016 w
.88549 .71478 m
.88515 .71517 L
s
.008 w
.88515 .71517 Mdot
.016 w
.88515 .71517 m
.88481 .71556 L
s
1 .406 0 r
.008 w
.88481 .71556 Mdot
.016 w
.88481 .71556 m
.88448 .71598 L
s
.008 w
.88448 .71598 Mdot
.016 w
.88448 .71598 m
.88415 .7164 L
s
1 .405 0 r
.008 w
.88415 .7164 Mdot
.016 w
.88415 .7164 m
.88383 .71683 L
s
.008 w
.88383 .71683 Mdot
.016 w
.88383 .71683 m
.88352 .71728 L
s
.008 w
.88352 .71728 Mdot
.016 w
.88352 .71728 m
.8832 .7177 L
s
1 .404 0 r
.008 w
.8832 .7177 Mdot
.016 w
.8832 .7177 m
.88292 .71804 L
s
.008 w
.88292 .71804 Mdot
.016 w
.88292 .71804 m
.88267 .71829 L
s
1 .403 0 r
.008 w
.88267 .71829 Mdot
.016 w
.88267 .71829 m
.88249 .71843 L
s
.008 w
.88249 .71843 Mdot
.016 w
.88249 .71843 m
.88238 .71848 L
s
.008 w
.88238 .71848 Mdot
.016 w
.88238 .71848 m
.88236 .71842 L
s
1 .402 0 r
.008 w
.88236 .71842 Mdot
.016 w
.88236 .71842 m
.88242 .71824 L
s
.008 w
.88242 .71824 Mdot
.016 w
.88242 .71824 m
.88257 .71794 L
s
.008 w
.88257 .71794 Mdot
.016 w
.88257 .71794 m
.8828 .71748 L
s
1 .401 0 r
.008 w
.8828 .71748 Mdot
.016 w
.8828 .71748 m
.88307 .71689 L
s
.008 w
.88307 .71689 Mdot
.016 w
.88307 .71689 m
.88343 .71614 L
s
1 .4 0 r
.008 w
.88343 .71614 Mdot
.016 w
.88343 .71614 m
.88388 .71524 L
s
.008 w
.88388 .71524 Mdot
.016 w
.88388 .71524 m
.88438 .71415 L
s
.008 w
.88438 .71415 Mdot
.016 w
.88438 .71415 m
.885 .71282 L
s
1 .399 0 r
.008 w
.885 .71282 Mdot
.016 w
.885 .71282 m
.8857 .71123 L
s
.008 w
.8857 .71123 Mdot
.016 w
.8857 .71123 m
.88649 .70938 L
s
1 .398 0 r
.008 w
.88649 .70938 Mdot
.016 w
.88649 .70938 m
.8874 .70736 L
s
.008 w
.8874 .70736 Mdot
.016 w
.8874 .70736 m
.88837 .70502 L
s
.008 w
.88837 .70502 Mdot
.016 w
.88837 .70502 m
.88944 .70249 L
s
1 .397 0 r
.008 w
.88944 .70249 Mdot
.016 w
.88944 .70249 m
.8905 .69973 L
s
.008 w
.8905 .69973 Mdot
.016 w
.8905 .69973 m
.89158 .69667 L
s
.008 w
.89158 .69667 Mdot
.016 w
.89158 .69667 m
.89268 .69375 L
s
1 .396 0 r
.008 w
.89268 .69375 Mdot
.016 w
.89268 .69375 m
.89372 .69053 L
s
.008 w
.89372 .69053 Mdot
.016 w
.89372 .69053 m
.89479 .68734 L
s
1 .395 0 r
.008 w
.89479 .68734 Mdot
.016 w
.89479 .68734 m
.89578 .68401 L
s
.008 w
.89578 .68401 Mdot
.016 w
.89578 .68401 m
.89684 .68075 L
s
.008 w
.89684 .68075 Mdot
.016 w
.89684 .68075 m
.8978 .67737 L
s
1 .394 0 r
.008 w
.8978 .67737 Mdot
.016 w
.8978 .67737 m
.89892 .67397 L
s
.008 w
.89892 .67397 Mdot
.016 w
.89892 .67397 m
.89997 .67061 L
s
1 .393 0 r
.008 w
.89997 .67061 Mdot
.016 w
.89997 .67061 m
.90113 .66712 L
s
.008 w
.90113 .66712 Mdot
.016 w
.90113 .66712 m
.90243 .66363 L
s
.008 w
.90243 .66363 Mdot
.016 w
.90243 .66363 m
.90366 .66009 L
s
1 .392 0 r
.008 w
.90366 .66009 Mdot
.016 w
.90366 .66009 m
.90496 .65643 L
s
.008 w
.90496 .65643 Mdot
.016 w
.90496 .65643 m
.90646 .65283 L
s
1 .391 0 r
.008 w
.90646 .65283 Mdot
.016 w
.90646 .65283 m
.90765 .64918 L
s
.008 w
.90765 .64918 Mdot
.016 w
.90765 .64918 m
.90917 .64543 L
s
.008 w
.90917 .64543 Mdot
.016 w
.90917 .64543 m
.91063 .64166 L
s
1 .39 0 r
.008 w
.91063 .64166 Mdot
.016 w
.91063 .64166 m
.91198 .63795 L
s
.008 w
.91198 .63795 Mdot
.016 w
.91198 .63795 m
.9135 .63412 L
s
.008 w
.9135 .63412 Mdot
.016 w
.9135 .63412 m
.91497 .63027 L
s
1 .389 0 r
.008 w
.91497 .63027 Mdot
.016 w
.91497 .63027 m
.91631 .62644 L
s
.008 w
.91631 .62644 Mdot
.016 w
.91631 .62644 m
.91757 .6227 L
s
1 .388 0 r
.008 w
.91757 .6227 Mdot
.016 w
.91757 .6227 m
.91874 .61903 L
s
.008 w
.91874 .61903 Mdot
.016 w
.91874 .61903 m
.91974 .61536 L
s
.008 w
.91974 .61536 Mdot
.016 w
.91974 .61536 m
.92073 .6117 L
s
1 .387 0 r
.008 w
.92073 .6117 Mdot
.016 w
.92073 .6117 m
.92165 .60814 L
s
.008 w
.92165 .60814 Mdot
.016 w
.92165 .60814 m
.92252 .60455 L
s
1 .386 0 r
.008 w
.92252 .60455 Mdot
.016 w
.92252 .60455 m
.92346 .60083 L
s
.008 w
.92346 .60083 Mdot
.016 w
.92346 .60083 m
.92438 .59747 L
s
.008 w
.92438 .59747 Mdot
.016 w
.92438 .59747 m
.92537 .59391 L
s
1 .385 0 r
.008 w
.92537 .59391 Mdot
.016 w
.92537 .59391 m
.9263 .59035 L
s
.008 w
.9263 .59035 Mdot
.016 w
.9263 .59035 m
.92723 .58657 L
s
1 .384 0 r
.008 w
.92723 .58657 Mdot
.016 w
.92723 .58657 m
.92804 .58315 L
s
.008 w
.92804 .58315 Mdot
.016 w
.92804 .58315 m
.9288 .57952 L
s
.008 w
.9288 .57952 Mdot
.016 w
.9288 .57952 m
.92944 .57567 L
s
1 .383 0 r
.008 w
.92944 .57567 Mdot
.016 w
.92944 .57567 m
.92995 .57212 L
s
.008 w
.92995 .57212 Mdot
.016 w
.92995 .57212 m
.93037 .56828 L
s
.008 w
.93037 .56828 Mdot
.016 w
.93037 .56828 m
.93069 .56444 L
s
1 .382 0 r
.008 w
.93069 .56444 Mdot
.016 w
.93069 .56444 m
.93092 .56025 L
s
.008 w
.93092 .56025 Mdot
.016 w
.93092 .56025 m
.93103 .55649 L
s
1 .381 0 r
.008 w
.93103 .55649 Mdot
.016 w
.93103 .55649 m
.93104 .55236 L
s
.008 w
.93104 .55236 Mdot
.016 w
.93104 .55236 m
.93094 .5481 L
s
.008 w
.93094 .5481 Mdot
.016 w
.93094 .5481 m
.93076 .54392 L
s
1 .38 0 r
.008 w
.93076 .54392 Mdot
.016 w
.93076 .54392 m
.93053 .53968 L
s
.008 w
.93053 .53968 Mdot
.016 w
.93053 .53968 m
.93028 .53544 L
s
1 .379 0 r
.008 w
.93028 .53544 Mdot
.016 w
.93028 .53544 m
.93003 .53103 L
s
.008 w
.93003 .53103 Mdot
.016 w
.93003 .53103 m
.92979 .52701 L
s
.008 w
.92979 .52701 Mdot
.016 w
.92979 .52701 m
.92957 .52266 L
s
1 .378 0 r
.008 w
.92957 .52266 Mdot
.016 w
.92957 .52266 m
.92937 .51832 L
s
.008 w
.92937 .51832 Mdot
.016 w
.92937 .51832 m
.92916 .5141 L
s
1 .377 0 r
.008 w
.92916 .5141 Mdot
.016 w
.92916 .5141 m
.92891 .51001 L
s
.008 w
.92891 .51001 Mdot
.016 w
.92891 .51001 m
.92862 .50568 L
s
.008 w
.92862 .50568 Mdot
.016 w
.92862 .50568 m
.9283 .50136 L
s
1 .376 0 r
.008 w
.9283 .50136 Mdot
.016 w
.9283 .50136 m
.92795 .49694 L
s
.008 w
.92795 .49694 Mdot
.016 w
.92795 .49694 m
.92759 .4928 L
s
.008 w
.92759 .4928 Mdot
.016 w
.92759 .4928 m
.92724 .48894 L
s
1 .375 0 r
.008 w
.92724 .48894 Mdot
.016 w
.92724 .48894 m
.9269 .48526 L
s
.008 w
.9269 .48526 Mdot
.016 w
.9269 .48526 m
.92658 .48156 L
s
1 .374 0 r
.008 w
.92658 .48156 Mdot
.016 w
.92658 .48156 m
.92627 .47834 L
s
.008 w
.92627 .47834 Mdot
.016 w
.92627 .47834 m
.92598 .47527 L
s
.008 w
.92598 .47527 Mdot
.016 w
.92598 .47527 m
.92566 .472 L
s
1 .373 0 r
.008 w
.92566 .472 Mdot
.016 w
.92566 .472 m
.92535 .46948 L
s
.008 w
.92535 .46948 Mdot
.016 w
.92535 .46948 m
.92503 .46714 L
s
1 .372 0 r
.008 w
.92503 .46714 Mdot
.016 w
.92503 .46714 m
.92471 .46488 L
s
.008 w
.92471 .46488 Mdot
.016 w
.92471 .46488 m
.92438 .4627 L
s
.008 w
.92438 .4627 Mdot
.016 w
.92438 .4627 m
.92405 .46064 L
s
1 .371 0 r
.008 w
.92405 .46064 Mdot
.016 w
.92405 .46064 m
.92371 .45875 L
s
.008 w
.92371 .45875 Mdot
.016 w
.92371 .45875 m
.92335 .45682 L
s
1 .37 0 r
.008 w
.92335 .45682 Mdot
.016 w
.92335 .45682 m
.92297 .45472 L
s
.008 w
.92297 .45472 Mdot
.016 w
.92297 .45472 m
.9226 .45246 L
s
.008 w
.9226 .45246 Mdot
.016 w
.9226 .45246 m
.92223 .45004 L
s
1 .369 0 r
.008 w
.92223 .45004 Mdot
.016 w
.92223 .45004 m
.92188 .44739 L
s
.008 w
.92188 .44739 Mdot
.016 w
.92188 .44739 m
.92155 .44456 L
s
.008 w
.92155 .44456 Mdot
.016 w
.92155 .44456 m
.92125 .44153 L
s
1 .368 0 r
.008 w
.92125 .44153 Mdot
.016 w
.92125 .44153 m
.92099 .4383 L
s
.008 w
.92099 .4383 Mdot
.016 w
.92099 .4383 m
.92078 .43493 L
s
1 .367 0 r
.008 w
.92078 .43493 Mdot
.016 w
.92078 .43493 m
.9206 .43165 L
s
.008 w
.9206 .43165 Mdot
.016 w
.9206 .43165 m
.92041 .4281 L
s
.008 w
.92041 .4281 Mdot
.016 w
.92041 .4281 m
.92019 .42444 L
s
1 .366 0 r
.008 w
.92019 .42444 Mdot
.016 w
.92019 .42444 m
.91992 .42077 L
s
.008 w
.91992 .42077 Mdot
.016 w
.91992 .42077 m
.91957 .41679 L
s
1 .365 0 r
.008 w
.91957 .41679 Mdot
.016 w
.91957 .41679 m
.91916 .41281 L
s
.008 w
.91916 .41281 Mdot
.016 w
.91916 .41281 m
.91868 .40867 L
s
.008 w
.91868 .40867 Mdot
.016 w
.91868 .40867 m
.91811 .40413 L
s
1 .364 0 r
.008 w
.91811 .40413 Mdot
.016 w
.91811 .40413 m
.91749 .40005 L
s
.008 w
.91749 .40005 Mdot
.016 w
.91749 .40005 m
.91681 .39566 L
s
1 .363 0 r
.008 w
.91681 .39566 Mdot
.016 w
.91681 .39566 m
.91611 .3912 L
s
.008 w
.91611 .3912 Mdot
.016 w
.91611 .3912 m
.9154 .38677 L
s
.008 w
.9154 .38677 Mdot
.016 w
.9154 .38677 m
.91469 .38234 L
s
1 .362 0 r
.008 w
.91469 .38234 Mdot
.016 w
.91469 .38234 m
.914 .37808 L
s
.008 w
.914 .37808 Mdot
.016 w
.914 .37808 m
.91334 .37405 L
s
.008 w
.91334 .37405 Mdot
.016 w
.91334 .37405 m
.91271 .37018 L
s
1 .361 0 r
.008 w
.91271 .37018 Mdot
.016 w
.91271 .37018 m
.91211 .36655 L
s
.008 w
.91211 .36655 Mdot
.016 w
.91211 .36655 m
.91155 .3632 L
s
1 .36 0 r
.008 w
.91155 .3632 Mdot
.016 w
.91155 .3632 m
.91102 .36021 L
s
.008 w
.91102 .36021 Mdot
.016 w
.91102 .36021 m
.91054 .35754 L
s
.008 w
.91054 .35754 Mdot
.016 w
.91054 .35754 m
.9101 .35528 L
s
1 .359 0 r
.008 w
.9101 .35528 Mdot
.016 w
.9101 .35528 m
.90971 .35333 L
s
.008 w
.90971 .35333 Mdot
.016 w
.90971 .35333 m
.90937 .35174 L
s
1 .358 0 r
.008 w
.90937 .35174 Mdot
.016 w
.90937 .35174 m
.90909 .35044 L
s
.008 w
.90909 .35044 Mdot
.016 w
.90909 .35044 m
.90884 .34942 L
s
.008 w
.90884 .34942 Mdot
.016 w
.90884 .34942 m
.90864 .34865 L
s
1 .357 0 r
.008 w
.90864 .34865 Mdot
.016 w
.90864 .34865 m
.90848 .34804 L
s
.008 w
.90848 .34804 Mdot
.016 w
.90848 .34804 m
.90836 .34755 L
s
.008 w
.90836 .34755 Mdot
.016 w
.90836 .34755 m
.90829 .34709 L
s
1 .356 0 r
.008 w
.90829 .34709 Mdot
.016 w
.90829 .34709 m
.90825 .34664 L
s
.008 w
.90825 .34664 Mdot
.016 w
.90825 .34664 m
.90822 .34616 L
s
1 .355 0 r
.008 w
.90822 .34616 Mdot
.016 w
.90822 .34616 m
.90821 .34567 L
s
.008 w
.90821 .34567 Mdot
.016 w
.90821 .34567 m
.9082 .34505 L
s
.008 w
.9082 .34505 Mdot
.016 w
.9082 .34505 m
.90819 .34428 L
s
1 .354 0 r
.008 w
.90819 .34428 Mdot
.016 w
.90819 .34428 m
.90816 .34336 L
s
.008 w
.90816 .34336 Mdot
.016 w
.90816 .34336 m
.90808 .3423 L
s
1 .353 0 r
.008 w
.90808 .3423 Mdot
.016 w
.90808 .3423 m
.90793 .34108 L
s
.008 w
.90793 .34108 Mdot
.016 w
.90793 .34108 m
.90768 .33966 L
s
.008 w
.90768 .33966 Mdot
.016 w
.90768 .33966 m
.90733 .33812 L
s
1 .352 0 r
.008 w
.90733 .33812 Mdot
.016 w
.90733 .33812 m
.90688 .33639 L
s
.008 w
.90688 .33639 Mdot
.016 w
.90688 .33639 m
.90632 .33452 L
s
1 .351 0 r
.008 w
.90632 .33452 Mdot
.016 w
.90632 .33452 m
.90565 .33251 L
s
.008 w
.90565 .33251 Mdot
.016 w
.90565 .33251 m
.90487 .33048 L
s
.008 w
.90487 .33048 Mdot
.016 w
.90487 .33048 m
.90399 .3283 L
s
1 .35 0 r
.008 w
.90399 .3283 Mdot
.016 w
.90399 .3283 m
.90297 .326 L
s
.008 w
.90297 .326 Mdot
.016 w
.90297 .326 m
.90182 .32356 L
s
.008 w
.90182 .32356 Mdot
.016 w
.90182 .32356 m
.90043 .32087 L
s
1 .349 0 r
.008 w
.90043 .32087 Mdot
.016 w
.90043 .32087 m
.89902 .31819 L
s
.008 w
.89902 .31819 Mdot
.016 w
.89902 .31819 m
.89741 .31523 L
s
1 .348 0 r
.008 w
.89741 .31523 Mdot
.016 w
.89741 .31523 m
.89565 .31209 L
s
.008 w
.89565 .31209 Mdot
.016 w
.89565 .31209 m
.89375 .30879 L
s
.008 w
.89375 .30879 Mdot
.016 w
.89375 .30879 m
.89163 .30539 L
s
1 .347 0 r
.008 w
.89163 .30539 Mdot
.016 w
.89163 .30539 m
.88962 .30188 L
s
.008 w
.88962 .30188 Mdot
.016 w
.88962 .30188 m
.88745 .29843 L
s
1 .346 0 r
.008 w
.88745 .29843 Mdot
.016 w
.88745 .29843 m
.88504 .29484 L
s
.008 w
.88504 .29484 Mdot
.016 w
.88504 .29484 m
.88294 .29146 L
s
.008 w
.88294 .29146 Mdot
.016 w
.88294 .29146 m
.88062 .28787 L
s
1 .345 0 r
.008 w
.88062 .28787 Mdot
.016 w
.88062 .28787 m
.87813 .28416 L
s
.008 w
.87813 .28416 Mdot
.016 w
.87813 .28416 m
.87581 .28064 L
s
1 .344 0 r
.008 w
.87581 .28064 Mdot
.016 w
.87581 .28064 m
.87339 .27705 L
s
.008 w
.87339 .27705 Mdot
.016 w
.87339 .27705 m
.87101 .2735 L
s
.008 w
.87101 .2735 Mdot
.016 w
.87101 .2735 m
.86849 .27009 L
s
1 .343 0 r
.008 w
.86849 .27009 Mdot
.016 w
.86849 .27009 m
.86629 .26692 L
s
.008 w
.86629 .26692 Mdot
.016 w
.86629 .26692 m
.86402 .26365 L
s
.008 w
.86402 .26365 Mdot
.016 w
.86402 .26365 m
.86184 .26053 L
s
1 .342 0 r
.008 w
.86184 .26053 Mdot
.016 w
.86184 .26053 m
.85951 .2573 L
s
.008 w
.85951 .2573 Mdot
.016 w
.85951 .2573 m
.85736 .25431 L
s
1 .341 0 r
.008 w
.85736 .25431 Mdot
.016 w
.85736 .25431 m
.85514 .25119 L
s
.008 w
.85514 .25119 Mdot
.016 w
.85514 .25119 m
.85295 .24805 L
s
.008 w
.85295 .24805 Mdot
.016 w
.85295 .24805 m
.8508 .24494 L
s
1 .34 0 r
.008 w
.8508 .24494 Mdot
.016 w
.8508 .24494 m
.84871 .24193 L
s
.008 w
.84871 .24193 Mdot
.016 w
.84871 .24193 m
.8467 .23887 L
s
1 .339 0 r
.008 w
.8467 .23887 Mdot
.016 w
.8467 .23887 m
.84462 .23576 L
s
.008 w
.84462 .23576 Mdot
.016 w
.84462 .23576 m
.84267 .23297 L
s
.008 w
.84267 .23297 Mdot
.016 w
.84267 .23297 m
.84061 .22985 L
s
1 .338 0 r
.008 w
.84061 .22985 Mdot
.016 w
.84061 .22985 m
.83847 .22667 L
s
.008 w
.83847 .22667 Mdot
.016 w
.83847 .22667 m
.83642 .22373 L
s
1 .337 0 r
.008 w
.83642 .22373 Mdot
.016 w
.83642 .22373 m
.83422 .22084 L
s
.008 w
.83422 .22084 Mdot
.016 w
.83422 .22084 m
.83188 .21758 L
s
.008 w
.83188 .21758 Mdot
.016 w
.83188 .21758 m
.82975 .21455 L
s
1 .336 0 r
.008 w
.82975 .21455 Mdot
.016 w
.82975 .21455 m
.82742 .21148 L
s
.008 w
.82742 .21148 Mdot
.016 w
.82742 .21148 m
.82513 .20837 L
s
.008 w
.82513 .20837 Mdot
.016 w
.82513 .20837 m
.82279 .20537 L
s
1 .335 0 r
.008 w
.82279 .20537 Mdot
.016 w
.82279 .20537 m
.82039 .20224 L
s
.008 w
.82039 .20224 Mdot
.016 w
.82039 .20224 m
.81814 .19933 L
s
1 .334 0 r
.008 w
.81814 .19933 Mdot
.016 w
.81814 .19933 m
.81586 .19635 L
s
.008 w
.81586 .19635 Mdot
.016 w
.81586 .19635 m
.81365 .19339 L
s
.008 w
.81365 .19339 Mdot
.016 w
.81365 .19339 m
.81149 .19058 L
s
1 .333 0 r
.008 w
.81149 .19058 Mdot
.016 w
.81149 .19058 m
.80948 .18779 L
s
.008 w
.80948 .18779 Mdot
.016 w
.80948 .18779 m
.80751 .18517 L
s
1 .332 0 r
.008 w
.80751 .18517 Mdot
.016 w
.80751 .18517 m
.80555 .18245 L
s
.008 w
.80555 .18245 Mdot
.016 w
.80555 .18245 m
.80366 .18002 L
s
.008 w
.80366 .18002 Mdot
.016 w
.80366 .18002 m
.80169 .17745 L
s
1 .331 0 r
.008 w
.80169 .17745 Mdot
.016 w
.80169 .17745 m
.79972 .17497 L
s
.008 w
.79972 .17497 Mdot
.016 w
.79972 .17497 m
.79777 .17244 L
s
1 .33 0 r
.008 w
.79777 .17244 Mdot
.016 w
.79777 .17244 m
.79578 .16997 L
s
.008 w
.79578 .16997 Mdot
.016 w
.79578 .16997 m
.79385 .16756 L
s
.008 w
.79385 .16756 Mdot
.016 w
.79385 .16756 m
.79195 .16515 L
s
1 .329 0 r
.008 w
.79195 .16515 Mdot
.016 w
.79195 .16515 m
.79017 .16312 L
s
.008 w
.79017 .16312 Mdot
.016 w
.79017 .16312 m
.78852 .16124 L
s
.008 w
.78852 .16124 Mdot
.016 w
.78852 .16124 m
.787 .1595 L
s
1 .328 0 r
.008 w
.787 .1595 Mdot
.016 w
.787 .1595 m
.78567 .15793 L
s
.008 w
.78567 .15793 Mdot
.016 w
.78567 .15793 m
.78459 .1567 L
s
1 .327 0 r
.008 w
.78459 .1567 Mdot
.016 w
.78459 .1567 m
.78373 .15568 L
s
.008 w
.78373 .15568 Mdot
.016 w
.78373 .15568 m
.78313 .15492 L
s
.008 w
.78313 .15492 Mdot
.016 w
.78313 .15492 m
.78279 .15441 L
s
1 .326 0 r
.008 w
.78279 .15441 Mdot
.016 w
.78279 .15441 m
.78268 .15411 L
s
.008 w
.78268 .15411 Mdot
.016 w
.78268 .15411 m
.78275 .15399 L
s
1 .325 0 r
.008 w
.78275 .15399 Mdot
.016 w
.78275 .15399 m
.78295 .15402 L
s
.008 w
.78295 .15402 Mdot
.016 w
.78295 .15402 m
.78324 .15413 L
s
.008 w
.78324 .15413 Mdot
.016 w
.78324 .15413 m
.78358 .15426 L
s
1 .324 0 r
.008 w
.78358 .15426 Mdot
.016 w
.78358 .15426 m
.78391 .15438 L
s
.008 w
.78391 .15438 Mdot
.016 w
.78391 .15438 m
.78421 .15449 L
s
1 .323 0 r
.008 w
.78421 .15449 Mdot
.016 w
.78421 .15449 m
.78447 .15459 L
s
.008 w
.78447 .15459 Mdot
.016 w
.78447 .15459 m
.78467 .15465 L
s
.008 w
.78467 .15465 Mdot
.016 w
.78467 .15465 m
.78483 .1547 L
s
1 .322 0 r
.008 w
.78483 .1547 Mdot
.016 w
.78483 .1547 m
.78496 .15474 L
s
.008 w
.78496 .15474 Mdot
.016 w
.78496 .15474 m
.78505 .15478 L
s
.008 w
.78505 .15478 Mdot
.016 w
.78505 .15478 m
.78511 .15482 L
s
1 .321 0 r
.008 w
.78511 .15482 Mdot
.016 w
.78511 .15482 m
.78512 .15484 L
s
.008 w
.78512 .15484 Mdot
.016 w
.78512 .15484 m
.78511 .15486 L
s
1 .32 0 r
.008 w
.78511 .15486 Mdot
.016 w
.78511 .15486 m
.78508 .15487 L
s
.008 w
.78508 .15487 Mdot
.016 w
.78508 .15487 m
.78505 .15487 L
s
.008 w
.78505 .15487 Mdot
.016 w
.78505 .15487 m
.78502 .15487 L
s
1 .319 0 r
.008 w
.78502 .15487 Mdot
.016 w
.78502 .15487 m
.78501 .15486 L
s
.008 w
.78501 .15486 Mdot
.016 w
.78501 .15486 m
.78501 .15483 L
s
1 .318 0 r
.008 w
.78501 .15483 Mdot
.016 w
.78501 .15483 m
.785 .15477 L
s
.008 w
.785 .15477 Mdot
.016 w
.785 .15477 m
.785 .1547 L
s
.008 w
.785 .1547 Mdot
.016 w
.785 .1547 m
.785 .15464 L
s
1 .317 0 r
.008 w
.785 .15464 Mdot
.016 w
.785 .15464 m
.785 .1546 L
s
.008 w
.785 .1546 Mdot
.016 w
.785 .1546 m
.785 .15459 L
s
.008 w
.785 .15459 Mdot
.016 w
.785 .15459 m
.785 .15461 L
s
1 .316 0 r
.008 w
.785 .15461 Mdot
.016 w
.785 .15461 m
.78502 .15469 L
s
.008 w
.78502 .15469 Mdot
.016 w
.78502 .15469 m
.78503 .15483 L
s
1 .315 0 r
.008 w
.78503 .15483 Mdot
.016 w
.78503 .15483 m
.78503 .15502 L
s
.008 w
.78503 .15502 Mdot
.016 w
.78503 .15502 m
.78503 .15527 L
s
.008 w
.78503 .15527 Mdot
.016 w
.78503 .15527 m
.78501 .15553 L
s
1 .314 0 r
.008 w
.78501 .15553 Mdot
.016 w
.78501 .15553 m
.78499 .15577 L
s
.008 w
.78499 .15577 Mdot
.016 w
.78499 .15577 m
.78497 .15599 L
s
1 .313 0 r
.008 w
.78497 .15599 Mdot
.016 w
.78497 .15599 m
.78494 .15616 L
s
.008 w
.78494 .15616 Mdot
.016 w
.78494 .15616 m
.78492 .15628 L
s
.008 w
.78492 .15628 Mdot
.016 w
.78492 .15628 m
.7849 .15635 L
s
1 .312 0 r
.008 w
.7849 .15635 Mdot
.016 w
.7849 .15635 m
.78488 .15634 L
s
.008 w
.78488 .15634 Mdot
.016 w
.78488 .15634 m
.78487 .15628 L
s
1 .311 0 r
.008 w
.78487 .15628 Mdot
.016 w
.78487 .15628 m
.78486 .15618 L
s
.008 w
.78486 .15618 Mdot
.016 w
.78486 .15618 m
.78486 .15599 L
s
.008 w
.78486 .15599 Mdot
.016 w
.78486 .15599 m
.78486 .1558 L
s
1 .31 0 r
.008 w
.78486 .1558 Mdot
.016 w
.78486 .1558 m
.78489 .15555 L
s
.008 w
.78489 .15555 Mdot
.016 w
.78489 .15555 m
.78495 .15531 L
s
.008 w
.78495 .15531 Mdot
.016 w
.78495 .15531 m
.78503 .15507 L
s
1 .309 0 r
.008 w
.78503 .15507 Mdot
.016 w
.78503 .15507 m
.78512 .15488 L
s
.008 w
.78512 .15488 Mdot
.016 w
.78512 .15488 m
.78518 .15473 L
s
1 .308 0 r
.008 w
.78518 .15473 Mdot
.016 w
.78518 .15473 m
.7852 .15463 L
s
.008 w
.7852 .15463 Mdot
.016 w
.7852 .15463 m
.78517 .15453 L
s
.008 w
.78517 .15453 Mdot
.016 w
.78517 .15453 m
.7851 .15445 L
s
1 .307 0 r
.008 w
.7851 .15445 Mdot
.016 w
.7851 .15445 m
.78498 .1544 L
s
.008 w
.78498 .1544 Mdot
.016 w
.78498 .1544 m
.78479 .15437 L
s
1 .306 0 r
.008 w
.78479 .15437 Mdot
.016 w
.78479 .15437 m
.78451 .15436 L
s
.008 w
.78451 .15436 Mdot
.016 w
.78451 .15436 m
.78411 .15437 L
s
.008 w
.78411 .15437 Mdot
.016 w
.78411 .15437 m
.78358 .15442 L
s
1 .305 0 r
.008 w
.78358 .15442 Mdot
.016 w
.78358 .15442 m
.78292 .15454 L
s
.008 w
.78292 .15454 Mdot
.016 w
.78292 .15454 m
.78212 .15474 L
s
1 .304 0 r
.008 w
.78212 .15474 Mdot
.016 w
.78212 .15474 m
.78121 .15503 L
s
.008 w
.78121 .15503 Mdot
.016 w
.78121 .15503 m
.78022 .1554 L
s
.008 w
.78022 .1554 Mdot
.016 w
.78022 .1554 m
.77917 .15586 L
s
1 .303 0 r
.008 w
.77917 .15586 Mdot
.016 w
.77917 .15586 m
.77812 .15639 L
s
.008 w
.77812 .15639 Mdot
.016 w
.77812 .15639 m
.77717 .15698 L
s
.008 w
.77717 .15698 Mdot
.016 w
.77717 .15698 m
.77623 .15762 L
s
1 .302 0 r
.008 w
.77623 .15762 Mdot
.016 w
.77623 .15762 m
.77543 .15827 L
s
.008 w
.77543 .15827 Mdot
.016 w
.77543 .15827 m
.77476 .1589 L
s
1 .301 0 r
.008 w
.77476 .1589 Mdot
.016 w
.77476 .1589 m
.77422 .15945 L
s
.008 w
.77422 .15945 Mdot
.016 w
.77422 .15945 m
.77381 .15987 L
s
.008 w
.77381 .15987 Mdot
.016 w
.77381 .15987 m
.77354 .16013 L
s
1 .3 0 r
.008 w
.77354 .16013 Mdot
.016 w
.77354 .16013 m
.77341 .1602 L
s
.008 w
.77341 .1602 Mdot
.016 w
.77341 .1602 m
.77338 .16005 L
s
1 .299 0 r
.008 w
.77338 .16005 Mdot
.016 w
.77338 .16005 m
.77343 .15969 L
s
.008 w
.77343 .15969 Mdot
.016 w
.77343 .15969 m
.7735 .15913 L
s
.008 w
.7735 .15913 Mdot
.016 w
.7735 .15913 m
.77353 .15838 L
s
1 .298 0 r
.008 w
.77353 .15838 Mdot
.016 w
.77353 .15838 m
.7734 .15742 L
s
.008 w
.7734 .15742 Mdot
.016 w
.7734 .15742 m
.77305 .15622 L
s
1 .297 0 r
.008 w
.77305 .15622 Mdot
.016 w
.77305 .15622 m
.77246 .15491 L
s
.008 w
.77246 .15491 Mdot
.016 w
.77246 .15491 m
.77161 .15338 L
s
.008 w
.77161 .15338 Mdot
.016 w
.77161 .15338 m
.77054 .1517 L
s
1 .296 0 r
.008 w
.77054 .1517 Mdot
.016 w
.77054 .1517 m
.76922 .14998 L
s
.008 w
.76922 .14998 Mdot
.016 w
.76922 .14998 m
.76764 .14808 L
s
.008 w
.76764 .14808 Mdot
.016 w
.76764 .14808 m
.76591 .14636 L
s
1 .295 0 r
.008 w
.76591 .14636 Mdot
.016 w
.76591 .14636 m
.76406 .14459 L
s
.008 w
.76406 .14459 Mdot
.016 w
.76406 .14459 m
.76205 .14286 L
s
1 .294 0 r
.008 w
.76205 .14286 Mdot
.016 w
.76205 .14286 m
.76001 .14129 L
s
.008 w
.76001 .14129 Mdot
.016 w
.76001 .14129 m
.75752 .13963 L
s
.008 w
.75752 .13963 Mdot
.016 w
.75752 .13963 m
.75539 .13829 L
s
1 .293 0 r
.008 w
.75539 .13829 Mdot
.016 w
.75539 .13829 m
.75322 .13698 L
s
.008 w
.75322 .13698 Mdot
.016 w
.75322 .13698 m
.75084 .1357 L
s
1 .292 0 r
.008 w
.75084 .1357 Mdot
.016 w
.75084 .1357 m
.74828 .13446 L
s
.008 w
.74828 .13446 Mdot
.016 w
.74828 .13446 m
.74552 .13324 L
s
.008 w
.74552 .13324 Mdot
.016 w
.74552 .13324 m
.74241 .13199 L
s
1 .291 0 r
.008 w
.74241 .13199 Mdot
.016 w
.74241 .13199 m
.73956 .13068 L
s
.008 w
.73956 .13068 Mdot
.016 w
.73956 .13068 m
.73628 .12943 L
s
1 .29 0 r
.008 w
.73628 .12943 Mdot
.016 w
.73628 .12943 m
.73284 .12802 L
s
.008 w
.73284 .12802 Mdot
.016 w
.73284 .12802 m
.72919 .12648 L
s
.008 w
.72919 .12648 Mdot
.016 w
.72919 .12648 m
.72534 .12502 L
s
1 .289 0 r
.008 w
.72534 .12502 Mdot
.016 w
.72534 .12502 m
.72125 .12334 L
s
.008 w
.72125 .12334 Mdot
.016 w
.72125 .12334 m
.71657 .12153 L
s
.008 w
.71657 .12153 Mdot
.016 w
.71657 .12153 m
.71253 .11964 L
s
1 .288 0 r
.008 w
.71253 .11964 Mdot
.016 w
.71253 .11964 m
.70763 .11755 L
s
.008 w
.70763 .11755 Mdot
.016 w
.70763 .11755 m
.70333 .11579 L
s
1 .287 0 r
.008 w
.70333 .11579 Mdot
.016 w
.70333 .11579 m
.6996 .11399 L
s
.008 w
.6996 .11399 Mdot
.016 w
.6996 .11399 m
.69515 .11213 L
s
.008 w
.69515 .11213 Mdot
.016 w
.69515 .11213 m
.69123 .11046 L
s
1 .286 0 r
.008 w
.69123 .11046 Mdot
.016 w
.69123 .11046 m
.68712 .10877 L
s
.008 w
.68712 .10877 Mdot
.016 w
.68712 .10877 m
.68341 .10738 L
s
1 .285 0 r
.008 w
.68341 .10738 Mdot
.016 w
.68341 .10738 m
.67955 .10584 L
s
.008 w
.67955 .10584 Mdot
.016 w
.67955 .10584 m
.67612 .10456 L
s
.008 w
.67612 .10456 Mdot
.016 w
.67612 .10456 m
.67254 .1033 L
s
1 .284 0 r
.008 w
.67254 .1033 Mdot
.016 w
.67254 .1033 m
.66967 .10207 L
s
.008 w
.66967 .10207 Mdot
.016 w
.66967 .10207 m
.66683 .10094 L
s
1 .283 0 r
.008 w
.66683 .10094 Mdot
.016 w
.66683 .10094 m
.66404 .09989 L
s
.008 w
.66404 .09989 Mdot
.016 w
.66404 .09989 m
.6619 .09896 L
s
.008 w
.6619 .09896 Mdot
.016 w
.6619 .09896 m
.65999 .09817 L
s
1 .282 0 r
.008 w
.65999 .09817 Mdot
.016 w
.65999 .09817 m
.65838 .09756 L
s
.008 w
.65838 .09756 Mdot
.016 w
.65838 .09756 m
.65716 .09706 L
s
.008 w
.65716 .09706 Mdot
.016 w
.65716 .09706 m
.65623 .09665 L
s
1 .281 0 r
.008 w
.65623 .09665 Mdot
.016 w
.65623 .09665 m
.65558 .09631 L
s
.008 w
.65558 .09631 Mdot
.016 w
.65558 .09631 m
.65518 .09604 L
s
1 .28 0 r
.008 w
.65518 .09604 Mdot
.016 w
.65518 .09604 m
.65501 .09584 L
s
.008 w
.65501 .09584 Mdot
.016 w
.65501 .09584 m
.655 .09571 L
s
.008 w
.655 .09571 Mdot
.016 w
.655 .09571 m
.6551 .09566 L
s
1 .279 0 r
.008 w
.6551 .09566 Mdot
.016 w
.6551 .09566 m
.65525 .09567 L
s
.008 w
.65525 .09567 Mdot
.016 w
.65525 .09567 m
.6554 .09571 L
s
1 .278 0 r
.008 w
.6554 .09571 Mdot
.016 w
.6554 .09571 m
.65552 .09578 L
s
.008 w
.65552 .09578 Mdot
.016 w
.65552 .09578 m
.6556 .09585 L
s
.008 w
.6556 .09585 Mdot
.016 w
.6556 .09585 m
.65566 .0959 L
s
1 .277 0 r
.008 w
.65566 .0959 Mdot
.016 w
.65566 .0959 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .276 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .275 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .274 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .273 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .272 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .271 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .27 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .269 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .268 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .267 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.65569 .09593 L
s
1 .266 0 r
.008 w
.65569 .09593 Mdot
.016 w
.65569 .09593 m
.6557 .09593 L
s
.008 w
.6557 .09593 Mdot
.016 w
.6557 .09593 m
.65574 .09594 L
s
.008 w
.65574 .09594 Mdot
.016 w
.65574 .09594 m
.65583 .09596 L
s
1 .265 0 r
.008 w
.65583 .09596 Mdot
.016 w
.65583 .09596 m
.65595 .09601 L
s
.008 w
.65595 .09601 Mdot
.016 w
.65595 .09601 m
.65607 .09608 L
s
1 .264 0 r
.008 w
.65607 .09608 Mdot
.016 w
.65607 .09608 m
.65613 .09614 L
s
.008 w
.65613 .09614 Mdot
.016 w
.65613 .09614 m
.65611 .09617 L
s
.008 w
.65611 .09617 Mdot
.016 w
.65611 .09617 m
.65598 .09614 L
s
1 .263 0 r
.008 w
.65598 .09614 Mdot
.016 w
.65598 .09614 m
.65572 .09605 L
s
.008 w
.65572 .09605 Mdot
.016 w
.65572 .09605 m
.65532 .09588 L
s
.008 w
.65532 .09588 Mdot
.016 w
.65532 .09588 m
.65476 .09562 L
s
1 .262 0 r
.008 w
.65476 .09562 Mdot
.016 w
.65476 .09562 m
.65406 .09529 L
s
.008 w
.65406 .09529 Mdot
.016 w
.65406 .09529 m
.65321 .0949 L
s
1 .261 0 r
.008 w
.65321 .0949 Mdot
.016 w
.65321 .0949 m
.65223 .09447 L
s
.008 w
.65223 .09447 Mdot
.016 w
.65223 .09447 m
.65124 .09402 L
s
.008 w
.65124 .09402 Mdot
.016 w
.65124 .09402 m
.6501 .09357 L
s
1 .26 0 r
.008 w
.6501 .09357 Mdot
.016 w
.6501 .09357 m
.64899 .09312 L
s
.008 w
.64899 .09312 Mdot
.016 w
.64899 .09312 m
.64785 .09268 L
s
1 .259 0 r
.008 w
.64785 .09268 Mdot
.016 w
.64785 .09268 m
.64673 .09226 L
s
.008 w
.64673 .09226 Mdot
.016 w
.64673 .09226 m
.64572 .09189 L
s
.008 w
.64572 .09189 Mdot
.016 w
.64572 .09189 m
.6449 .0916 L
s
1 .258 0 r
.008 w
.6449 .0916 Mdot
.016 w
.6449 .0916 m
.64429 .09139 L
s
.008 w
.64429 .09139 Mdot
.016 w
.64429 .09139 m
.64386 .09127 L
s
1 .257 0 r
.008 w
.64386 .09127 Mdot
.016 w
.64386 .09127 m
.64359 .09123 L
s
.008 w
.64359 .09123 Mdot
.016 w
.64359 .09123 m
.64339 .09124 L
s
.008 w
.64339 .09124 Mdot
.016 w
.64339 .09124 m
.64322 .09129 L
s
1 .256 0 r
.008 w
.64322 .09129 Mdot
.016 w
.64322 .09129 m
.64301 .09136 L
s
.008 w
.64301 .09136 Mdot
.016 w
.64301 .09136 m
.64271 .09141 L
s
.008 w
.64271 .09141 Mdot
.016 w
.64271 .09141 m
.64231 .09144 L
s
1 .255 0 r
.008 w
.64231 .09144 Mdot
.016 w
.64231 .09144 m
.64184 .09147 L
s
.008 w
.64184 .09147 Mdot
.016 w
.64184 .09147 m
.64132 .09148 L
s
1 .254 0 r
.008 w
.64132 .09148 Mdot
.016 w
.64132 .09148 m
.64081 .09148 L
s
.008 w
.64081 .09148 Mdot
.016 w
.64081 .09148 m
.64034 .09145 L
s
.008 w
.64034 .09145 Mdot
.016 w
.64034 .09145 m
.63988 .09139 L
s
1 .253 0 r
.008 w
.63988 .09139 Mdot
.016 w
.63988 .09139 m
.63944 .09129 L
s
.008 w
.63944 .09129 Mdot
.016 w
.63944 .09129 m
.63899 .09116 L
s
1 .252 0 r
.008 w
.63899 .09116 Mdot
.016 w
.63899 .09116 m
.63855 .09099 L
s
.008 w
.63855 .09099 Mdot
.016 w
.63855 .09099 m
.63813 .09079 L
s
.008 w
.63813 .09079 Mdot
.016 w
.63813 .09079 m
.63775 .09058 L
s
1 .251 0 r
.008 w
.63775 .09058 Mdot
.016 w
.63775 .09058 m
.63741 .09036 L
s
.008 w
.63741 .09036 Mdot
.016 w
.63741 .09036 m
.63712 .09014 L
s
1 .25 0 r
.008 w
.63712 .09014 Mdot
.016 w
.63712 .09014 m
.63688 .08992 L
s
.008 w
.63688 .08992 Mdot
.016 w
.63688 .08992 m
.63669 .08971 L
s
.008 w
.63669 .08971 Mdot
.016 w
.63669 .08971 m
.63651 .08951 L
s
1 .249 0 r
.008 w
.63651 .08951 Mdot
.016 w
.63651 .08951 m
.63634 .08934 L
s
.008 w
.63634 .08934 Mdot
.016 w
.63634 .08934 m
.63608 .0892 L
s
.008 w
.63608 .0892 Mdot
.016 w
.63608 .0892 m
.63575 .0891 L
s
1 .248 0 r
.008 w
.63575 .0891 Mdot
.016 w
.63575 .0891 m
.63538 .08904 L
s
.008 w
.63538 .08904 Mdot
.016 w
.63538 .08904 m
.63503 .08901 L
s
1 .247 0 r
.008 w
.63503 .08901 Mdot
.016 w
.63503 .08901 m
.63473 .08901 L
s
.008 w
.63473 .08901 Mdot
.016 w
.63473 .08901 m
.63449 .08904 L
s
.008 w
.63449 .08904 Mdot
.016 w
.63449 .08904 m
.63433 .08907 L
s
1 .246 0 r
.008 w
.63433 .08907 Mdot
.016 w
.63433 .08907 m
.63426 .08909 L
s
.008 w
.63426 .08909 Mdot
.016 w
.63426 .08909 m
.63427 .0891 L
s
1 .245 0 r
.008 w
.63427 .0891 Mdot
.016 w
.63427 .0891 m
.63434 .08911 L
s
.008 w
.63434 .08911 Mdot
.016 w
.63434 .08911 m
.63446 .08911 L
s
.008 w
.63446 .08911 Mdot
.016 w
.63446 .08911 m
.63459 .08912 L
s
1 .244 0 r
.008 w
.63459 .08912 Mdot
.016 w
.63459 .08912 m
.63474 .08912 L
s
.008 w
.63474 .08912 Mdot
.016 w
.63474 .08912 m
.6349 .08913 L
s
1 .243 0 r
.008 w
.6349 .08913 Mdot
.016 w
.6349 .08913 m
.63509 .08913 L
s
.008 w
.63509 .08913 Mdot
.016 w
.63509 .08913 m
.6353 .08914 L
s
.008 w
.6353 .08914 Mdot
.016 w
.6353 .08914 m
.63552 .08915 L
s
1 .242 0 r
.008 w
.63552 .08915 Mdot
.016 w
.63552 .08915 m
.63574 .08915 L
s
.008 w
.63574 .08915 Mdot
.016 w
.63574 .08915 m
.63596 .08916 L
s
.008 w
.63596 .08916 Mdot
.016 w
.63596 .08916 m
.63617 .08917 L
s
1 .241 0 r
.008 w
.63617 .08917 Mdot
.016 w
.63617 .08917 m
.63637 .08917 L
s
.008 w
.63637 .08917 Mdot
.016 w
.63637 .08917 m
.63653 .08918 L
s
1 .24 0 r
.008 w
.63653 .08918 Mdot
.016 w
.63653 .08918 m
.63667 .08918 L
s
.008 w
.63667 .08918 Mdot
.016 w
.63667 .08918 m
.63676 .08919 L
s
.008 w
.63676 .08919 Mdot
.016 w
.63676 .08919 m
.63682 .08919 L
s
1 .239 0 r
.008 w
.63682 .08919 Mdot
.016 w
.63682 .08919 m
.63683 .08919 L
s
.008 w
.63683 .08919 Mdot
.016 w
.63683 .08919 m
.63682 .08919 L
s
1 .238 0 r
.008 w
.63682 .08919 Mdot
.016 w
.63682 .08919 m
.63679 .08919 L
s
.008 w
.63679 .08919 Mdot
.016 w
.63679 .08919 m
.63675 .08919 L
s
.008 w
.63675 .08919 Mdot
.016 w
.63675 .08919 m
.63672 .08919 L
s
1 .237 0 r
.008 w
.63672 .08919 Mdot
.016 w
.63672 .08919 m
.63671 .08919 L
s
.008 w
.63671 .08919 Mdot
.016 w
.63671 .08919 m
.63671 .08919 L
s
.008 w
.63671 .08919 Mdot
.016 w
.63671 .08919 m
.63671 .08918 L
s
1 .236 0 r
.008 w
.63671 .08918 Mdot
.016 w
.63671 .08918 m
.63674 .08917 L
s
.008 w
.63674 .08917 Mdot
.016 w
.63674 .08917 m
.63679 .08913 L
s
1 .235 0 r
.008 w
.63679 .08913 Mdot
.016 w
.63679 .08913 m
.63685 .08905 L
s
.008 w
.63685 .08905 Mdot
.016 w
.63685 .08905 m
.63691 .08896 L
s
.008 w
.63691 .08896 Mdot
.016 w
.63691 .08896 m
.63694 .0889 L
s
1 .234 0 r
.008 w
.63694 .0889 Mdot
.016 w
.63694 .0889 m
.63692 .08888 L
s
.008 w
.63692 .08888 Mdot
.016 w
.63692 .08888 m
.63684 .08892 L
s
1 .233 0 r
.008 w
.63684 .08892 Mdot
.016 w
.63684 .08892 m
.6367 .08908 L
s
.008 w
.6367 .08908 Mdot
.016 w
.6367 .08908 m
.63649 .08937 L
s
.008 w
.63649 .08937 Mdot
.016 w
.63649 .08937 m
.63621 .08978 L
s
1 .232 0 r
.008 w
.63621 .08978 Mdot
.016 w
.63621 .08978 m
.63584 .09028 L
s
.008 w
.63584 .09028 Mdot
.016 w
.63584 .09028 m
.63539 .09087 L
s
1 .231 0 r
.008 w
.63539 .09087 Mdot
.016 w
.63539 .09087 m
.63485 .09153 L
s
.008 w
.63485 .09153 Mdot
.016 w
.63485 .09153 m
.63428 .09219 L
s
.008 w
.63428 .09219 Mdot
.016 w
.63428 .09219 m
.63368 .09289 L
s
1 .23 0 r
.008 w
.63368 .09289 Mdot
.016 w
.63368 .09289 m
.63311 .09349 L
s
.008 w
.63311 .09349 Mdot
.016 w
.63311 .09349 m
.6326 .09399 L
s
.008 w
.6326 .09399 Mdot
.016 w
.6326 .09399 m
.63219 .09438 L
s
1 .229 0 r
.008 w
.63219 .09438 Mdot
.016 w
.63219 .09438 m
.6319 .09465 L
s
.008 w
.6319 .09465 Mdot
.016 w
.6319 .09465 m
.63175 .09477 L
s
1 .228 0 r
.008 w
.63175 .09477 Mdot
.016 w
.63175 .09477 m
.63174 .09478 L
s
.008 w
.63174 .09478 Mdot
.016 w
.63174 .09478 m
.63183 .09467 L
s
.008 w
.63183 .09467 Mdot
.016 w
.63183 .09467 m
.63198 .09449 L
s
1 .227 0 r
.008 w
.63198 .09449 Mdot
.016 w
.63198 .09449 m
.63213 .09424 L
s
.008 w
.63213 .09424 Mdot
.016 w
.63213 .09424 m
.63234 .09399 L
s
1 .226 0 r
.008 w
.63234 .09399 Mdot
.016 w
.63234 .09399 m
.63259 .0938 L
s
.008 w
.63259 .0938 Mdot
.016 w
.63259 .0938 m
.63292 .0937 L
s
.008 w
.63292 .0937 Mdot
.016 w
.63292 .0937 m
.63336 .09373 L
s
1 .225 0 r
.008 w
.63336 .09373 Mdot
.016 w
.63336 .09373 m
.63398 .094 L
s
.008 w
.63398 .094 Mdot
.016 w
.63398 .094 m
.63482 .09424 L
s
1 .224 0 r
.008 w
.63482 .09424 Mdot
.016 w
.63482 .09424 m
.63588 .0946 L
s
.008 w
.63588 .0946 Mdot
.016 w
.63588 .0946 m
.63717 .09509 L
s
.008 w
.63717 .09509 Mdot
.016 w
.63717 .09509 m
.63863 .0957 L
s
1 .223 0 r
.008 w
.63863 .0957 Mdot
.016 w
.63863 .0957 m
.64037 .09637 L
s
.008 w
.64037 .09637 Mdot
.016 w
.64037 .09637 m
.64224 .09705 L
s
.008 w
.64224 .09705 Mdot
.016 w
.64224 .09705 m
.64419 .0977 L
s
1 .222 0 r
.008 w
.64419 .0977 Mdot
.016 w
.64419 .0977 m
.64648 .09831 L
s
.008 w
.64648 .09831 Mdot
.016 w
.64648 .09831 m
.64877 .09885 L
s
1 .221 0 r
.008 w
.64877 .09885 Mdot
.016 w
.64877 .09885 m
.65142 .09933 L
s
.008 w
.65142 .09933 Mdot
.016 w
.65142 .09933 m
.65379 .09978 L
s
.008 w
.65379 .09978 Mdot
.016 w
.65379 .09978 m
.65625 .10023 L
s
1 .22 0 r
.008 w
.65625 .10023 Mdot
.016 w
.65625 .10023 m
.65864 .10068 L
s
.008 w
.65864 .10068 Mdot
.016 w
.65864 .10068 m
.66092 .10115 L
s
1 .219 0 r
.008 w
.66092 .10115 Mdot
.016 w
.66092 .10115 m
.66303 .10162 L
s
.008 w
.66303 .10162 Mdot
.016 w
.66303 .10162 m
.665 .10211 L
s
.008 w
.665 .10211 Mdot
.016 w
.665 .10211 m
.66682 .10262 L
s
1 .218 0 r
.008 w
.66682 .10262 Mdot
.016 w
.66682 .10262 m
.66854 .10315 L
s
.008 w
.66854 .10315 Mdot
.016 w
.66854 .10315 m
.6701 .10371 L
s
1 .217 0 r
.008 w
.6701 .10371 Mdot
.016 w
.6701 .10371 m
.67152 .10429 L
s
.008 w
.67152 .10429 Mdot
.016 w
.67152 .10429 m
.67283 .10483 L
s
.008 w
.67283 .10483 Mdot
.016 w
.67283 .10483 m
.67399 .10533 L
s
1 .216 0 r
.008 w
.67399 .10533 Mdot
.016 w
.67399 .10533 m
.67496 .10579 L
s
.008 w
.67496 .10579 Mdot
.016 w
.67496 .10579 m
.67574 .10618 L
s
.008 w
.67574 .10618 Mdot
.016 w
.67574 .10618 m
.67632 .1065 L
s
1 .215 0 r
.008 w
.67632 .1065 Mdot
.016 w
.67632 .1065 m
.67672 .10674 L
s
.008 w
.67672 .10674 Mdot
.016 w
.67672 .10674 m
.67697 .10691 L
s
1 .214 0 r
.008 w
.67697 .10691 Mdot
.016 w
.67697 .10691 m
.67709 .107 L
s
.008 w
.67709 .107 Mdot
.016 w
.67709 .107 m
.67712 .10703 L
s
.008 w
.67712 .10703 Mdot
.016 w
.67712 .10703 m
.67707 .107 L
s
1 .213 0 r
.008 w
.67707 .107 Mdot
.016 w
.67707 .107 m
.67698 .10693 L
s
.008 w
.67698 .10693 Mdot
.016 w
.67698 .10693 m
.67688 .10685 L
s
1 .212 0 r
.008 w
.67688 .10685 Mdot
.016 w
.67688 .10685 m
.67678 .10675 L
s
.008 w
.67678 .10675 Mdot
.016 w
.67678 .10675 m
.67668 .10667 L
s
.008 w
.67668 .10667 Mdot
.016 w
.67668 .10667 m
.6766 .1066 L
s
1 .211 0 r
.008 w
.6766 .1066 Mdot
.016 w
.6766 .1066 m
.67654 .10657 L
s
.008 w
.67654 .10657 Mdot
.016 w
.67654 .10657 m
.67653 .10659 L
s
1 .21 0 r
.008 w
.67653 .10659 Mdot
.016 w
.67653 .10659 m
.67657 .10668 L
s
.008 w
.67657 .10668 Mdot
.016 w
.67657 .10668 m
.67668 .10686 L
s
.008 w
.67668 .10686 Mdot
.016 w
.67668 .10686 m
.67685 .10716 L
s
1 .209 0 r
.008 w
.67685 .10716 Mdot
.016 w
.67685 .10716 m
.67707 .10753 L
s
.008 w
.67707 .10753 Mdot
.016 w
.67707 .10753 m
.67733 .10792 L
s
.008 w
.67733 .10792 Mdot
.016 w
.67733 .10792 m
.67762 .10831 L
s
1 .208 0 r
.008 w
.67762 .10831 Mdot
.016 w
.67762 .10831 m
.67791 .10865 L
s
.008 w
.67791 .10865 Mdot
.016 w
.67791 .10865 m
.67822 .10894 L
s
1 .207 0 r
.008 w
.67822 .10894 Mdot
.016 w
.67822 .10894 m
.67854 .10917 L
s
.008 w
.67854 .10917 Mdot
.016 w
.67854 .10917 m
.67888 .10934 L
s
.008 w
.67888 .10934 Mdot
.016 w
.67888 .10934 m
.67918 .10945 L
s
1 .206 0 r
.008 w
.67918 .10945 Mdot
.016 w
.67918 .10945 m
.67943 .10948 L
s
.008 w
.67943 .10948 Mdot
.016 w
.67943 .10948 m
.67959 .10941 L
s
1 .205 0 r
.008 w
.67959 .10941 Mdot
.016 w
.67959 .10941 m
.67965 .10921 L
s
.008 w
.67965 .10921 Mdot
.016 w
.67965 .10921 m
.67959 .10888 L
s
.008 w
.67959 .10888 Mdot
.016 w
.67959 .10888 m
.67942 .10842 L
s
1 .204 0 r
.008 w
.67942 .10842 Mdot
.016 w
.67942 .10842 m
.67911 .10785 L
s
.008 w
.67911 .10785 Mdot
.016 w
.67911 .10785 m
.67865 .10722 L
s
1 .203 0 r
.008 w
.67865 .10722 Mdot
.016 w
.67865 .10722 m
.67799 .10656 L
s
.008 w
.67799 .10656 Mdot
.016 w
.67799 .10656 m
.67711 .10589 L
s
.008 w
.67711 .10589 Mdot
.016 w
.67711 .10589 m
.67598 .10519 L
s
1 .202 0 r
.008 w
.67598 .10519 Mdot
.016 w
.67598 .10519 m
.67457 .10444 L
s
.008 w
.67457 .10444 Mdot
.016 w
.67457 .10444 m
.67294 .10365 L
s
.008 w
.67294 .10365 Mdot
.016 w
.67294 .10365 m
.67098 .10277 L
s
1 .201 0 r
.008 w
.67098 .10277 Mdot
.016 w
.67098 .10277 m
.66864 .10177 L
s
.008 w
.66864 .10177 Mdot
.016 w
.66864 .10177 m
.6663 .1007 L
s
1 .2 0 r
.008 w
.6663 .1007 Mdot
.016 w
.6663 .1007 m
.66339 .09947 L
s
.008 w
.66339 .09947 Mdot
.016 w
.66339 .09947 m
.66041 .09811 L
s
.008 w
.66041 .09811 Mdot
.016 w
.66041 .09811 m
.65722 .0968 L
s
1 .199 0 r
.008 w
.65722 .0968 Mdot
.016 w
.65722 .0968 m
.6533 .09514 L
s
.008 w
.6533 .09514 Mdot
.016 w
.6533 .09514 m
.64998 .09374 L
s
1 .198 0 r
.008 w
.64998 .09374 Mdot
.016 w
.64998 .09374 m
.64613 .09228 L
s
.008 w
.64613 .09228 Mdot
.016 w
.64613 .09228 m
.64215 .09066 L
s
.008 w
.64215 .09066 Mdot
.016 w
.64215 .09066 m
.63772 .08892 L
s
1 .197 0 r
.008 w
.63772 .08892 Mdot
.016 w
.63772 .08892 m
.63365 .08739 L
s
.008 w
.63365 .08739 Mdot
.016 w
.63365 .08739 m
.62937 .08589 L
s
.008 w
.62937 .08589 Mdot
.016 w
.62937 .08589 m
.62459 .08409 L
s
1 .196 0 r
.008 w
.62459 .08409 Mdot
.016 w
.62459 .08409 m
.62057 .08264 L
s
.008 w
.62057 .08264 Mdot
.016 w
.62057 .08264 m
.61573 .08116 L
s
1 .195 0 r
.008 w
.61573 .08116 Mdot
.016 w
.61573 .08116 m
.61158 .0796 L
s
.008 w
.61158 .0796 Mdot
.016 w
.61158 .0796 m
.6065 .07809 L
s
.008 w
.6065 .07809 Mdot
.016 w
.6065 .07809 m
.60254 .07655 L
s
1 .194 0 r
.008 w
.60254 .07655 Mdot
.016 w
.60254 .07655 m
.59804 .07503 L
s
.008 w
.59804 .07503 Mdot
.016 w
.59804 .07503 m
.59401 .07386 L
s
1 .193 0 r
.008 w
.59401 .07386 Mdot
.016 w
.59401 .07386 m
.59 .07268 L
s
.008 w
.59 .07268 Mdot
.016 w
.59 .07268 m
.5864 .0716 L
s
.008 w
.5864 .0716 Mdot
.016 w
.5864 .0716 m
.58317 .07076 L
s
1 .192 0 r
.008 w
.58317 .07076 Mdot
.016 w
.58317 .07076 m
.58025 .07001 L
s
.008 w
.58025 .07001 Mdot
.016 w
.58025 .07001 m
.57763 .06935 L
s
1 .191 0 r
.008 w
.57763 .06935 Mdot
.016 w
.57763 .06935 m
.57526 .06884 L
s
.008 w
.57526 .06884 Mdot
.016 w
.57526 .06884 m
.57365 .06849 L
s
.008 w
.57365 .06849 Mdot
.016 w
.57365 .06849 m
.57224 .06828 L
s
1 .19 0 r
.008 w
.57224 .06828 Mdot
.016 w
.57224 .06828 m
.57115 .06818 L
s
.008 w
.57115 .06818 Mdot
.016 w
.57115 .06818 m
.57035 .06818 L
s
.008 w
.57035 .06818 Mdot
.016 w
.57035 .06818 m
.56984 .06823 L
s
1 .189 0 r
.008 w
.56984 .06823 Mdot
.016 w
.56984 .06823 m
.56957 .06832 L
s
.008 w
.56957 .06832 Mdot
.016 w
.56957 .06832 m
.56948 .0684 L
s
1 .188 0 r
.008 w
.56948 .0684 Mdot
.016 w
.56948 .0684 m
.56954 .06847 L
s
.008 w
.56954 .06847 Mdot
.016 w
.56954 .06847 m
.56971 .06851 L
s
.008 w
.56971 .06851 Mdot
.016 w
.56971 .06851 m
.56996 .06853 L
s
1 .187 0 r
.008 w
.56996 .06853 Mdot
.016 w
.56996 .06853 m
.57027 .06854 L
s
.008 w
.57027 .06854 Mdot
.016 w
.57027 .06854 m
.57058 .06855 L
s
1 .186 0 r
.008 w
.57058 .06855 Mdot
.016 w
.57058 .06855 m
.57084 .06856 L
s
.008 w
.57084 .06856 Mdot
.016 w
.57084 .06856 m
.57107 .06856 L
s
.008 w
.57107 .06856 Mdot
.016 w
.57107 .06856 m
.5713 .06857 L
s
1 .185 0 r
.008 w
.5713 .06857 Mdot
.016 w
.5713 .06857 m
.57152 .06858 L
s
.008 w
.57152 .06858 Mdot
.016 w
.57152 .06858 m
.57175 .06858 L
s
1 .184 0 r
.008 w
.57175 .06858 Mdot
.016 w
.57175 .06858 m
.57197 .06859 L
s
.008 w
.57197 .06859 Mdot
.016 w
.57197 .06859 m
.57217 .0686 L
s
.008 w
.57217 .0686 Mdot
.016 w
.57217 .0686 m
.57234 .0686 L
s
1 .183 0 r
.008 w
.57234 .0686 Mdot
.016 w
.57234 .0686 m
.57248 .06861 L
s
.008 w
.57248 .06861 Mdot
.016 w
.57248 .06861 m
.57257 .06861 L
s
.008 w
.57257 .06861 Mdot
.016 w
.57257 .06861 m
.57263 .06861 L
s
1 .182 0 r
.008 w
.57263 .06861 Mdot
.016 w
.57263 .06861 m
.57265 .06861 L
s
.008 w
.57265 .06861 Mdot
.016 w
.57265 .06861 m
.57263 .06861 L
s
1 .181 0 r
.008 w
.57263 .06861 Mdot
.016 w
.57263 .06861 m
.5726 .06861 L
s
.008 w
.5726 .06861 Mdot
.016 w
.5726 .06861 m
.57256 .06861 L
s
.008 w
.57256 .06861 Mdot
.016 w
.57256 .06861 m
.57253 .06861 L
s
1 .18 0 r
.008 w
.57253 .06861 Mdot
.016 w
.57253 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .179 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .178 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .177 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .176 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .175 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .174 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .173 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .172 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .171 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .17 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .169 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .168 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .167 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .166 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .165 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .164 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .163 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .162 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .161 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57252 .06861 L
s
1 .16 0 r
.008 w
.57252 .06861 Mdot
.016 w
.57252 .06861 m
.57254 .06861 L
s
.008 w
.57254 .06861 Mdot
.016 w
.57254 .06861 m
.5726 .06861 L
s
.008 w
.5726 .06861 Mdot
.016 w
.5726 .06861 m
.57266 .06861 L
s
1 .159 0 r
.008 w
.57266 .06861 Mdot
.016 w
.57266 .06861 m
.57273 .06862 L
s
.008 w
.57273 .06862 Mdot
.016 w
.57273 .06862 m
.57276 .06862 L
s
1 .158 0 r
.008 w
.57276 .06862 Mdot
.016 w
.57276 .06862 m
.57276 .06862 L
s
.008 w
.57276 .06862 Mdot
.016 w
.57276 .06862 m
.5727 .06862 L
s
.008 w
.5727 .06862 Mdot
.016 w
.5727 .06862 m
.57261 .06861 L
s
1 .157 0 r
.008 w
.57261 .06861 Mdot
.016 w
.57261 .06861 m
.57246 .06861 L
s
.008 w
.57246 .06861 Mdot
.016 w
.57246 .06861 m
.57223 .0686 L
s
.008 w
.57223 .0686 Mdot
.016 w
.57223 .0686 m
.57191 .06859 L
s
1 .156 0 r
.008 w
.57191 .06859 Mdot
.016 w
.57191 .06859 m
.57148 .06857 L
s
.008 w
.57148 .06857 Mdot
.016 w
.57148 .06857 m
.57095 .06856 L
s
1 .155 0 r
.008 w
.57095 .06856 Mdot
.016 w
.57095 .06856 m
.57031 .06854 L
s
.008 w
.57031 .06854 Mdot
.016 w
.57031 .06854 m
.56958 .06851 L
s
.008 w
.56958 .06851 Mdot
.016 w
.56958 .06851 m
.56877 .06849 L
s
1 .154 0 r
.008 w
.56877 .06849 Mdot
.016 w
.56877 .06849 m
.56788 .06846 L
s
.008 w
.56788 .06846 Mdot
.016 w
.56788 .06846 m
.56689 .06843 L
s
1 .153 0 r
.008 w
.56689 .06843 Mdot
.016 w
.56689 .06843 m
.56581 .06839 L
s
.008 w
.56581 .06839 Mdot
.016 w
.56581 .06839 m
.56465 .06835 L
s
.008 w
.56465 .06835 Mdot
.016 w
.56465 .06835 m
.56346 .06831 L
s
1 .152 0 r
.008 w
.56346 .06831 Mdot
.016 w
.56346 .06831 m
.56222 .06827 L
s
.008 w
.56222 .06827 Mdot
.016 w
.56222 .06827 m
.56096 .06823 L
s
1 .151 0 r
.008 w
.56096 .06823 Mdot
.016 w
.56096 .06823 m
.55969 .06819 L
s
.008 w
.55969 .06819 Mdot
.016 w
.55969 .06819 m
.55849 .06815 L
s
.008 w
.55849 .06815 Mdot
.016 w
.55849 .06815 m
.55728 .06811 L
s
1 .15 0 r
.008 w
.55728 .06811 Mdot
.016 w
.55728 .06811 m
.55605 .06807 L
s
.008 w
.55605 .06807 Mdot
.016 w
.55605 .06807 m
.55472 .06803 L
s
.008 w
.55472 .06803 Mdot
.016 w
.55472 .06803 m
.55344 .06799 L
s
1 .149 0 r
.008 w
.55344 .06799 Mdot
.016 w
.55344 .06799 m
.55209 .06795 L
s
.008 w
.55209 .06795 Mdot
.016 w
.55209 .06795 m
.55065 .0679 L
s
1 .148 0 r
.008 w
.55065 .0679 Mdot
.016 w
.55065 .0679 m
.54914 .06786 L
s
.008 w
.54914 .06786 Mdot
.016 w
.54914 .06786 m
.54757 .06781 L
s
.008 w
.54757 .06781 Mdot
.016 w
.54757 .06781 m
.54604 .06776 L
s
1 .147 0 r
.008 w
.54604 .06776 Mdot
.016 w
.54604 .06776 m
.54482 .06772 L
s
.008 w
.54482 .06772 Mdot
.016 w
.54482 .06772 m
.54358 .06768 L
s
1 .146 0 r
.008 w
.54358 .06768 Mdot
.016 w
.54358 .06768 m
.54242 .06764 L
s
.008 w
.54242 .06764 Mdot
.016 w
.54242 .06764 m
.54154 .06762 L
s
.008 w
.54154 .06762 Mdot
.016 w
.54154 .06762 m
.5407 .06762 L
s
1 .145 0 r
.008 w
.5407 .06762 Mdot
.016 w
.5407 .06762 m
.53992 .06763 L
s
.008 w
.53992 .06763 Mdot
.016 w
.53992 .06763 m
.53921 .06764 L
s
1 .144 0 r
.008 w
.53921 .06764 Mdot
.016 w
.53921 .06764 m
.53856 .06762 L
s
.008 w
.53856 .06762 Mdot
.016 w
.53856 .06762 m
.53787 .06757 L
s
.008 w
.53787 .06757 Mdot
.016 w
.53787 .06757 m
.53704 .06747 L
s
1 .143 0 r
.008 w
.53704 .06747 Mdot
.016 w
.53704 .06747 m
.53597 .06733 L
s
.008 w
.53597 .06733 Mdot
.016 w
.53597 .06733 m
.53457 .06716 L
s
.008 w
.53457 .06716 Mdot
.016 w
.53457 .06716 m
.53286 .06697 L
s
1 .142 0 r
.008 w
.53286 .06697 Mdot
.016 w
.53286 .06697 m
.53052 .06677 L
s
.008 w
.53052 .06677 Mdot
.016 w
.53052 .06677 m
.52755 .06657 L
s
1 .141 0 r
.008 w
.52755 .06657 Mdot
.016 w
.52755 .06657 m
.52476 .06639 L
s
.008 w
.52476 .06639 Mdot
.016 w
.52476 .06639 m
.52105 .0662 L
s
.008 w
.52105 .0662 Mdot
.016 w
.52105 .0662 m
.51654 .06604 L
s
1 .14 0 r
.008 w
.51654 .06604 Mdot
.016 w
.51654 .06604 m
.51267 .0659 L
s
.008 w
.51267 .0659 Mdot
.016 w
.51267 .0659 m
.50794 .06578 L
s
1 .139 0 r
.008 w
.50794 .06578 Mdot
.016 w
.50794 .06578 m
.5033 .06569 L
s
.008 w
.5033 .06569 Mdot
.016 w
.5033 .06569 m
.4993 .06563 L
s
.008 w
.4993 .06563 Mdot
.016 w
.4993 .06563 m
.49487 .06561 L
s
1 .138 0 r
.008 w
.49487 .06561 Mdot
.016 w
.49487 .06561 m
.49121 .06563 L
s
.008 w
.49121 .06563 Mdot
.016 w
.49121 .06563 m
.48752 .06567 L
s
1 .137 0 r
.008 w
.48752 .06567 Mdot
.016 w
.48752 .06567 m
.4847 .06572 L
s
.008 w
.4847 .06572 Mdot
.016 w
.4847 .06572 m
.48218 .06577 L
s
.008 w
.48218 .06577 Mdot
.016 w
.48218 .06577 m
.4801 .0658 L
s
1 .136 0 r
.008 w
.4801 .0658 Mdot
.016 w
.4801 .0658 m
.47858 .06579 L
s
.008 w
.47858 .06579 Mdot
.016 w
.47858 .06579 m
.47734 .06576 L
s
.008 w
.47734 .06576 Mdot
.016 w
.47734 .06576 m
.47639 .0657 L
s
1 .135 0 r
.008 w
.47639 .0657 Mdot
.016 w
.47639 .0657 m
.47572 .06565 L
s
.008 w
.47572 .06565 Mdot
.016 w
.47572 .06565 m
.4752 .0656 L
s
1 .134 0 r
.008 w
.4752 .0656 Mdot
.016 w
.4752 .0656 m
.47473 .06558 L
s
.008 w
.47473 .06558 Mdot
.016 w
.47473 .06558 m
.47427 .06556 L
s
.008 w
.47427 .06556 Mdot
.016 w
.47427 .06556 m
.4738 .06555 L
s
1 .133 0 r
.008 w
.4738 .06555 Mdot
.016 w
.4738 .06555 m
.4733 .06554 L
s
.008 w
.4733 .06554 Mdot
.016 w
.4733 .06554 m
.47276 .06552 L
s
1 .132 0 r
.008 w
.47276 .06552 Mdot
.016 w
.47276 .06552 m
.47221 .06551 L
s
.008 w
.47221 .06551 Mdot
.016 w
.47221 .06551 m
.47164 .06549 L
s
.008 w
.47164 .06549 Mdot
.016 w
.47164 .06549 m
.47103 .06547 L
s
1 .131 0 r
.008 w
.47103 .06547 Mdot
.016 w
.47103 .06547 m
.47042 .06545 L
s
.008 w
.47042 .06545 Mdot
.016 w
.47042 .06545 m
.46989 .06543 L
s
1 .13 0 r
.008 w
.46989 .06543 Mdot
.016 w
.46989 .06543 m
.46947 .06542 L
s
.008 w
.46947 .06542 Mdot
.016 w
.46947 .06542 m
.46917 .06541 L
s
.008 w
.46917 .06541 Mdot
.016 w
.46917 .06541 m
.46901 .06541 L
s
1 .129 0 r
.008 w
.46901 .06541 Mdot
.016 w
.46901 .06541 m
.46896 .06541 L
s
.008 w
.46896 .06541 Mdot
.016 w
.46896 .06541 m
.469 .06541 L
s
.008 w
.469 .06541 Mdot
.016 w
.469 .06541 m
.4691 .06541 L
s
1 .128 0 r
.008 w
.4691 .06541 Mdot
.016 w
.4691 .06541 m
.46922 .06541 L
s
.008 w
.46922 .06541 Mdot
.016 w
.46922 .06541 m
.46932 .06542 L
s
1 .127 0 r
.008 w
.46932 .06542 Mdot
.016 w
.46932 .06542 m
.46941 .06542 L
s
.008 w
.46941 .06542 Mdot
.016 w
.46941 .06542 m
.46949 .06542 L
s
.008 w
.46949 .06542 Mdot
.016 w
.46949 .06542 m
.46957 .06542 L
s
1 .126 0 r
.008 w
.46957 .06542 Mdot
.016 w
.46957 .06542 m
.46966 .06543 L
s
.008 w
.46966 .06543 Mdot
.016 w
.46966 .06543 m
.46975 .06543 L
s
1 .125 0 r
.008 w
.46975 .06543 Mdot
.016 w
.46975 .06543 m
.46981 .06543 L
s
.008 w
.46981 .06543 Mdot
.016 w
.46981 .06543 m
.46979 .06543 L
s
.008 w
.46979 .06543 Mdot
.016 w
.46979 .06543 m
.46966 .06543 L
s
1 .124 0 r
.008 w
.46966 .06543 Mdot
.016 w
.46966 .06543 m
.46939 .06542 L
s
.008 w
.46939 .06542 Mdot
.016 w
.46939 .06542 m
.4689 .06541 L
s
1 .123 0 r
.008 w
.4689 .06541 Mdot
.016 w
.4689 .06541 m
.46815 .06539 L
s
.008 w
.46815 .06539 Mdot
.016 w
.46815 .06539 m
.46712 .06536 L
s
.008 w
.46712 .06536 Mdot
.016 w
.46712 .06536 m
.46584 .06532 L
s
1 .122 0 r
.008 w
.46584 .06532 Mdot
.016 w
.46584 .06532 m
.46431 .06527 L
s
.008 w
.46431 .06527 Mdot
.016 w
.46431 .06527 m
.46253 .06522 L
s
.008 w
.46253 .06522 Mdot
.016 w
.46253 .06522 m
.46054 .06516 L
s
1 .121 0 r
.008 w
.46054 .06516 Mdot
.016 w
.46054 .06516 m
.45868 .0651 L
s
.008 w
.45868 .0651 Mdot
.016 w
.45868 .0651 m
.45662 .06504 L
s
1 .12 0 r
.008 w
.45662 .06504 Mdot
.016 w
.45662 .06504 m
.45473 .06498 L
s
.008 w
.45473 .06498 Mdot
.016 w
.45473 .06498 m
.45288 .06492 L
s
.008 w
.45288 .06492 Mdot
.016 w
.45288 .06492 m
.45115 .06487 L
s
1 .119 0 r
.008 w
.45115 .06487 Mdot
.016 w
.45115 .06487 m
.44977 .06483 L
s
.008 w
.44977 .06483 Mdot
.016 w
.44977 .06483 m
.44865 .06477 L
s
1 .118 0 r
.008 w
.44865 .06477 Mdot
.016 w
.44865 .06477 m
.44779 .0647 L
s
.008 w
.44779 .0647 Mdot
.016 w
.44779 .0647 m
.4472 .06461 L
s
.008 w
.4472 .06461 Mdot
.016 w
.4472 .06461 m
.44682 .06454 L
s
1 .117 0 r
.008 w
.44682 .06454 Mdot
.016 w
.44682 .06454 m
.4466 .06451 L
s
.008 w
.4466 .06451 Mdot
.016 w
.4466 .06451 m
.44648 .06453 L
s
.008 w
.44648 .06453 Mdot
.016 w
.44648 .06453 m
.4464 .06462 L
s
1 .116 0 r
.008 w
.4464 .06462 Mdot
.016 w
.4464 .06462 m
.44627 .06478 L
s
.008 w
.44627 .06478 Mdot
.016 w
.44627 .06478 m
.44609 .06503 L
s
1 .115 0 r
.008 w
.44609 .06503 Mdot
.016 w
.44609 .06503 m
.44585 .06534 L
s
.008 w
.44585 .06534 Mdot
.016 w
.44585 .06534 m
.44553 .06571 L
s
.008 w
.44553 .06571 Mdot
.016 w
.44553 .06571 m
.4451 .06611 L
s
1 .114 0 r
.008 w
.4451 .06611 Mdot
.016 w
.4451 .06611 m
.44459 .06653 L
s
.008 w
.44459 .06653 Mdot
.016 w
.44459 .06653 m
.44403 .06695 L
s
1 .113 0 r
.008 w
.44403 .06695 Mdot
.016 w
.44403 .06695 m
.44345 .06736 L
s
.008 w
.44345 .06736 Mdot
.016 w
.44345 .06736 m
.44286 .06776 L
s
.008 w
.44286 .06776 Mdot
.016 w
.44286 .06776 m
.4423 .06814 L
s
1 .112 0 r
.008 w
.4423 .06814 Mdot
.016 w
.4423 .06814 m
.44179 .06846 L
s
.008 w
.44179 .06846 Mdot
.016 w
.44179 .06846 m
.44139 .06873 L
s
1 .111 0 r
.008 w
.44139 .06873 Mdot
.016 w
.44139 .06873 m
.44112 .06891 L
s
.008 w
.44112 .06891 Mdot
.016 w
.44112 .06891 m
.44096 .06901 L
s
.008 w
.44096 .06901 Mdot
.016 w
.44096 .06901 m
.44089 .06904 L
s
1 .11 0 r
.008 w
.44089 .06904 Mdot
.016 w
.44089 .06904 m
.44086 .06903 L
s
.008 w
.44086 .06903 Mdot
.016 w
.44086 .06903 m
.44085 .06899 L
s
.008 w
.44085 .06899 Mdot
.016 w
.44085 .06899 m
.4408 .06894 L
s
1 .109 0 r
.008 w
.4408 .06894 Mdot
.016 w
.4408 .06894 m
.44068 .06887 L
s
.008 w
.44068 .06887 Mdot
.016 w
.44068 .06887 m
.44046 .0688 L
s
1 .108 0 r
.008 w
.44046 .0688 Mdot
.016 w
.44046 .0688 m
.44008 .06874 L
s
.008 w
.44008 .06874 Mdot
.016 w
.44008 .06874 m
.43947 .06866 L
s
.008 w
.43947 .06866 Mdot
.016 w
.43947 .06866 m
.43857 .06857 L
s
1 .107 0 r
.008 w
.43857 .06857 Mdot
.016 w
.43857 .06857 m
.43733 .06848 L
s
.008 w
.43733 .06848 Mdot
.016 w
.43733 .06848 m
.43574 .06838 L
s
1 .106 0 r
.008 w
.43574 .06838 Mdot
.016 w
.43574 .06838 m
.43377 .06829 L
s
.008 w
.43377 .06829 Mdot
.016 w
.43377 .06829 m
.43133 .06819 L
s
.008 w
.43133 .06819 Mdot
.016 w
.43133 .06819 m
.42862 .0681 L
s
1 .105 0 r
.008 w
.42862 .0681 Mdot
.016 w
.42862 .0681 m
.4254 .06801 L
s
.008 w
.4254 .06801 Mdot
.016 w
.4254 .06801 m
.42215 .06791 L
s
1 .104 0 r
.008 w
.42215 .06791 Mdot
.016 w
.42215 .06791 m
.41865 .06779 L
s
.008 w
.41865 .06779 Mdot
.016 w
.41865 .06779 m
.41497 .06767 L
s
.008 w
.41497 .06767 Mdot
.016 w
.41497 .06767 m
.41097 .06754 L
s
1 .103 0 r
.008 w
.41097 .06754 Mdot
.016 w
.41097 .06754 m
.4075 .06742 L
s
.008 w
.4075 .06742 Mdot
.016 w
.4075 .06742 m
.40366 .06732 L
s
.008 w
.40366 .06732 Mdot
.016 w
.40366 .06732 m
.40003 .06726 L
s
1 .102 0 r
.008 w
.40003 .06726 Mdot
.016 w
.40003 .06726 m
.3964 .06724 L
s
.008 w
.3964 .06724 Mdot
.016 w
.3964 .06724 m
.39311 .06729 L
s
1 .101 0 r
.008 w
.39311 .06729 Mdot
.016 w
.39311 .06729 m
.38963 .06741 L
s
.008 w
.38963 .06741 Mdot
.016 w
.38963 .06741 m
.38645 .06762 L
s
.008 w
.38645 .06762 Mdot
.016 w
.38645 .06762 m
.3832 .06794 L
s
1 .1 0 r
.008 w
.3832 .06794 Mdot
.016 w
.3832 .06794 m
.38012 .0684 L
s
.008 w
.38012 .0684 Mdot
.016 w
.38012 .0684 m
.37691 .069 L
s
1 .099 0 r
.008 w
.37691 .069 Mdot
.016 w
.37691 .069 m
.37412 .06968 L
s
.008 w
.37412 .06968 Mdot
.016 w
.37412 .06968 m
.37144 .07042 L
s
.008 w
.37144 .07042 Mdot
.016 w
.37144 .07042 m
.36879 .07123 L
s
1 .098 0 r
.008 w
.36879 .07123 Mdot
.016 w
.36879 .07123 m
.36651 .07209 L
s
.008 w
.36651 .07209 Mdot
.016 w
.36651 .07209 m
.36426 .07297 L
s
1 .097 0 r
.008 w
.36426 .07297 Mdot
.016 w
.36426 .07297 m
.36238 .07387 L
s
.008 w
.36238 .07387 Mdot
.016 w
.36238 .07387 m
.36063 .07478 L
s
.008 w
.36063 .07478 Mdot
.016 w
.36063 .07478 m
.35914 .07563 L
s
1 .096 0 r
.008 w
.35914 .07563 Mdot
.016 w
.35914 .07563 m
.35786 .07645 L
s
.008 w
.35786 .07645 Mdot
.016 w
.35786 .07645 m
.35679 .07722 L
s
.008 w
.35679 .07722 Mdot
.016 w
.35679 .07722 m
.35593 .07793 L
s
1 .095 0 r
.008 w
.35593 .07793 Mdot
.016 w
.35593 .07793 m
.35529 .07857 L
s
.008 w
.35529 .07857 Mdot
.016 w
.35529 .07857 m
.35481 .07915 L
s
1 .094 0 r
.008 w
.35481 .07915 Mdot
.016 w
.35481 .07915 m
.35445 .07964 L
s
.008 w
.35445 .07964 Mdot
.016 w
.35445 .07964 m
.35416 .08008 L
s
.008 w
.35416 .08008 Mdot
.016 w
.35416 .08008 m
.35393 .08046 L
s
1 .093 0 r
.008 w
.35393 .08046 Mdot
.016 w
.35393 .08046 m
.35371 .08077 L
s
.008 w
.35371 .08077 Mdot
.016 w
.35371 .08077 m
.3535 .08103 L
s
1 .092 0 r
.008 w
.3535 .08103 Mdot
.016 w
.3535 .08103 m
.35334 .08123 L
s
.008 w
.35334 .08123 Mdot
.016 w
.35334 .08123 m
.35324 .08138 L
s
.008 w
.35324 .08138 Mdot
.016 w
.35324 .08138 m
.35321 .08146 L
s
1 .091 0 r
.008 w
.35321 .08146 Mdot
.016 w
.35321 .08146 m
.35323 .08148 L
s
.008 w
.35323 .08148 Mdot
.016 w
.35323 .08148 m
.35328 .08145 L
s
1 .09 0 r
.008 w
.35328 .08145 Mdot
.016 w
.35328 .08145 m
.35335 .08139 L
s
.008 w
.35335 .08139 Mdot
.016 w
.35335 .08139 m
.3534 .08132 L
s
.008 w
.3534 .08132 Mdot
.016 w
.3534 .08132 m
.35343 .08127 L
s
1 .089 0 r
.008 w
.35343 .08127 Mdot
.016 w
.35343 .08127 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .088 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .087 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .086 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .085 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .084 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
1 .083 0 r
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35345 .08125 L
s
.008 w
.35345 .08125 Mdot
.016 w
.35345 .08125 m
.35348 .08125 L
s
.008 w
.35348 .08125 Mdot
.016 w
.35348 .08125 m
.35354 .08125 L
s
1 .082 0 r
.008 w
.35354 .08125 Mdot
.016 w
.35354 .08125 m
.35362 .08125 L
s
.008 w
.35362 .08125 Mdot
.016 w
.35362 .08125 m
.35374 .08123 L
s
.008 w
.35374 .08123 Mdot
.016 w
.35374 .08123 m
.35389 .08118 L
s
1 .081 0 r
.008 w
.35389 .08118 Mdot
.016 w
.35389 .08118 m
.35403 .08109 L
s
.008 w
.35403 .08109 Mdot
.016 w
.35403 .08109 m
.35412 .08096 L
s
1 .08 0 r
.008 w
.35412 .08096 Mdot
.016 w
.35412 .08096 m
.35412 .08082 L
s
.008 w
.35412 .08082 Mdot
.016 w
.35412 .08082 m
.354 .0807 L
s
.008 w
.354 .0807 Mdot
.016 w
.354 .0807 m
.35369 .08064 L
s
1 .079 0 r
.008 w
.35369 .08064 Mdot
.016 w
.35369 .08064 m
.35315 .08066 L
s
.008 w
.35315 .08066 Mdot
.016 w
.35315 .08066 m
.35232 .08084 L
s
1 .078 0 r
.008 w
.35232 .08084 Mdot
.016 w
.35232 .08084 m
.35115 .08122 L
s
.008 w
.35115 .08122 Mdot
.016 w
.35115 .08122 m
.34964 .08185 L
s
.008 w
.34964 .08185 Mdot
.016 w
.34964 .08185 m
.3477 .08276 L
s
1 .077 0 r
.008 w
.3477 .08276 Mdot
.016 w
.3477 .08276 m
.34527 .08393 L
s
.008 w
.34527 .08393 Mdot
.016 w
.34527 .08393 m
.34269 .08527 L
s
.008 w
.34269 .08527 Mdot
.016 w
.34269 .08527 m
.33959 .08679 L
s
1 .076 0 r
.008 w
.33959 .08679 Mdot
.016 w
.33959 .08679 m
.3363 .08863 L
s
.008 w
.3363 .08863 Mdot
.016 w
.3363 .08863 m
.33265 .09059 L
s
1 .075 0 r
.008 w
.33265 .09059 Mdot
.016 w
.33265 .09059 m
.32896 .09272 L
s
.008 w
.32896 .09272 Mdot
.016 w
.32896 .09272 m
.32485 .09508 L
s
.008 w
.32485 .09508 Mdot
.016 w
.32485 .09508 m
.3211 .09724 L
s
1 .074 0 r
.008 w
.3211 .09724 Mdot
.016 w
.3211 .09724 m
.31713 .09962 L
s
.008 w
.31713 .09962 Mdot
.016 w
.31713 .09962 m
.31302 .10185 L
s
1 .073 0 r
.008 w
.31302 .10185 Mdot
.016 w
.31302 .10185 m
.30937 .10398 L
s
.008 w
.30937 .10398 Mdot
.016 w
.30937 .10398 m
.30547 .1062 L
s
.008 w
.30547 .1062 Mdot
.016 w
.30547 .1062 m
.30211 .10811 L
s
1 .072 0 r
.008 w
.30211 .10811 Mdot
.016 w
.30211 .10811 m
.29864 .11006 L
s
.008 w
.29864 .11006 Mdot
.016 w
.29864 .11006 m
.29567 .11181 L
s
1 .071 0 r
.008 w
.29567 .11181 Mdot
.016 w
.29567 .11181 m
.29277 .11356 L
s
.008 w
.29277 .11356 Mdot
.016 w
.29277 .11356 m
.29025 .11516 L
s
.008 w
.29025 .11516 Mdot
.016 w
.29025 .11516 m
.28803 .11666 L
s
1 .07 0 r
.008 w
.28803 .11666 Mdot
.016 w
.28803 .11666 m
.28616 .11796 L
s
.008 w
.28616 .11796 Mdot
.016 w
.28616 .11796 m
.28458 .11914 L
s
.008 w
.28458 .11914 Mdot
.016 w
.28458 .11914 m
.28336 .12013 L
s
1 .069 0 r
.008 w
.28336 .12013 Mdot
.016 w
.28336 .12013 m
.28245 .12088 L
s
.008 w
.28245 .12088 Mdot
.016 w
.28245 .12088 m
.28177 .12149 L
s
1 .068 0 r
.008 w
.28177 .12149 Mdot
.016 w
.28177 .12149 m
.28127 .12199 L
s
.008 w
.28127 .12199 Mdot
.016 w
.28127 .12199 m
.28087 .12241 L
s
.008 w
.28087 .12241 Mdot
.016 w
.28087 .12241 m
.28049 .12279 L
s
1 .067 0 r
.008 w
.28049 .12279 Mdot
.016 w
.28049 .12279 m
.28007 .12318 L
s
.008 w
.28007 .12318 Mdot
.016 w
.28007 .12318 m
.2796 .1236 L
s
1 .066 0 r
.008 w
.2796 .1236 Mdot
.016 w
.2796 .1236 m
.27909 .12407 L
s
.008 w
.27909 .12407 Mdot
.016 w
.27909 .12407 m
.27851 .12458 L
s
.008 w
.27851 .12458 Mdot
.016 w
.27851 .12458 m
.27787 .12513 L
s
1 .065 0 r
.008 w
.27787 .12513 Mdot
.016 w
.27787 .12513 m
.27725 .12565 L
s
.008 w
.27725 .12565 Mdot
.016 w
.27725 .12565 m
.27662 .12624 L
s
1 .064 0 r
.008 w
.27662 .12624 Mdot
.016 w
.27662 .12624 m
.27609 .1268 L
s
.008 w
.27609 .1268 Mdot
.016 w
.27609 .1268 m
.27563 .12736 L
s
.008 w
.27563 .12736 Mdot
.016 w
.27563 .12736 m
.27524 .12787 L
s
1 .063 0 r
.008 w
.27524 .12787 Mdot
.016 w
.27524 .12787 m
.27492 .12829 L
s
.008 w
.27492 .12829 Mdot
.016 w
.27492 .12829 m
.27468 .1286 L
s
.008 w
.27468 .1286 Mdot
.016 w
.27468 .1286 m
.27446 .12876 L
s
1 .062 0 r
.008 w
.27446 .12876 Mdot
.016 w
.27446 .12876 m
.27415 .12882 L
s
.008 w
.27415 .12882 Mdot
.016 w
.27415 .12882 m
.27367 .12884 L
s
1 .061 0 r
.008 w
.27367 .12884 Mdot
.016 w
.27367 .12884 m
.27293 .12887 L
s
.008 w
.27293 .12887 Mdot
.016 w
.27293 .12887 m
.27185 .129 L
s
.008 w
.27185 .129 Mdot
.016 w
.27185 .129 m
.27033 .12932 L
s
1 .06 0 r
.008 w
.27033 .12932 Mdot
.016 w
.27033 .12932 m
.26834 .12991 L
s
.008 w
.26834 .12991 Mdot
.016 w
.26834 .12991 m
.2663 .13082 L
s
1 .059 0 r
.008 w
.2663 .13082 Mdot
.016 w
.2663 .13082 m
.26346 .13196 L
s
.008 w
.26346 .13196 Mdot
.016 w
.26346 .13196 m
.26065 .13339 L
s
.008 w
.26065 .13339 Mdot
.016 w
.26065 .13339 m
.2572 .13519 L
s
1 .058 0 r
.008 w
.2572 .13519 Mdot
.016 w
.2572 .13519 m
.25351 .13727 L
s
.008 w
.25351 .13727 Mdot
.016 w
.25351 .13727 m
.24949 .13954 L
s
1 .057 0 r
.008 w
.24949 .13954 Mdot
.016 w
.24949 .13954 m
.24575 .14181 L
s
.008 w
.24575 .14181 Mdot
.016 w
.24575 .14181 m
.24106 .14436 L
s
.008 w
.24106 .14436 Mdot
.016 w
.24106 .14436 m
.23718 .14702 L
s
1 .056 0 r
.008 w
.23718 .14702 Mdot
.016 w
.23718 .14702 m
.2324 .14996 L
s
.008 w
.2324 .14996 Mdot
.016 w
.2324 .14996 m
.22875 .15265 L
s
.008 w
.22875 .15265 Mdot
.016 w
.22875 .15265 m
.22455 .15555 L
s
1 .055 0 r
.008 w
.22455 .15555 Mdot
.016 w
.22455 .15555 m
.22062 .15836 L
s
.008 w
.22062 .15836 Mdot
.016 w
.22062 .15836 m
.21651 .16127 L
s
1 .054 0 r
.008 w
.21651 .16127 Mdot
.016 w
.21651 .16127 m
.21297 .16387 L
s
.008 w
.21297 .16387 Mdot
.016 w
.21297 .16387 m
.20922 .1665 L
s
.008 w
.20922 .1665 Mdot
.016 w
.20922 .1665 m
.20633 .16887 L
s
1 .053 0 r
.008 w
.20633 .16887 Mdot
.016 w
.20633 .16887 m
.20353 .17116 L
s
.008 w
.20353 .17116 Mdot
.016 w
.20353 .17116 m
.20112 .17317 L
s
1 .052 0 r
.008 w
.20112 .17317 Mdot
.016 w
.20112 .17317 m
.1991 .17493 L
s
.008 w
.1991 .17493 Mdot
.016 w
.1991 .17493 m
.19746 .1765 L
s
.008 w
.19746 .1765 Mdot
.016 w
.19746 .1765 m
.19625 .17773 L
s
1 .051 0 r
.008 w
.19625 .17773 Mdot
.016 w
.19625 .17773 m
.19535 .17871 L
s
.008 w
.19535 .17871 Mdot
.016 w
.19535 .17871 m
.19474 .17942 L
s
1 .05 0 r
.008 w
.19474 .17942 Mdot
.016 w
.19474 .17942 m
.19436 .17989 L
s
.008 w
.19436 .17989 Mdot
.016 w
.19436 .17989 m
.19418 .18014 L
s
.008 w
.19418 .18014 Mdot
.016 w
.19418 .18014 m
.19413 .18023 L
s
1 .049 0 r
.008 w
.19413 .18023 Mdot
.016 w
.19413 .18023 m
.19418 .18021 L
s
.008 w
.19418 .18021 Mdot
.016 w
.19418 .18021 m
.19428 .18012 L
s
.008 w
.19428 .18012 Mdot
.016 w
.19428 .18012 m
.1944 .17998 L
s
1 .048 0 r
.008 w
.1944 .17998 Mdot
.016 w
.1944 .17998 m
.19454 .17984 L
s
.008 w
.19454 .17984 Mdot
.016 w
.19454 .17984 m
.19465 .17973 L
s
1 .047 0 r
.008 w
.19465 .17973 Mdot
.016 w
.19465 .17973 m
.19473 .17966 L
s
.008 w
.19473 .17966 Mdot
.016 w
.19473 .17966 m
.19476 .17963 L
s
.008 w
.19476 .17963 Mdot
.016 w
.19476 .17963 m
.19477 .17962 L
s
1 .046 0 r
.008 w
.19477 .17962 Mdot
.016 w
.19477 .17962 m
.19477 .17962 L
s
.008 w
.19477 .17962 Mdot
.016 w
.19477 .17962 m
.19477 .17962 L
s
1 .045 0 r
.008 w
.19477 .17962 Mdot
.016 w
.19477 .17962 m
.19477 .17962 L
s
.008 w
.19477 .17962 Mdot
.016 w
.19477 .17962 m
.19477 .17962 L
s
.008 w
.19477 .17962 Mdot
.016 w
.19477 .17962 m
.1948 .17958 L
s
1 .044 0 r
.008 w
.1948 .17958 Mdot
.016 w
.1948 .17958 m
.19485 .17949 L
s
.008 w
.19485 .17949 Mdot
.016 w
.19485 .17949 m
.19493 .17938 L
s
1 .043 0 r
.008 w
.19493 .17938 Mdot
.016 w
.19493 .17938 m
.195 .17927 L
s
.008 w
.195 .17927 Mdot
.016 w
.195 .17927 m
.19504 .17918 L
s
.008 w
.19504 .17918 Mdot
.016 w
.19504 .17918 m
.19501 .17917 L
s
1 .042 0 r
.008 w
.19501 .17917 Mdot
.016 w
.19501 .17917 m
.19491 .17926 L
s
.008 w
.19491 .17926 Mdot
.016 w
.19491 .17926 m
.19471 .17952 L
s
.008 w
.19471 .17952 Mdot
.016 w
.19471 .17952 m
.19443 .17995 L
s
1 .041 0 r
.008 w
.19443 .17995 Mdot
.016 w
.19443 .17995 m
.19406 .18055 L
s
.008 w
.19406 .18055 Mdot
.016 w
.19406 .18055 m
.19363 .18132 L
s
1 .04 0 r
.008 w
.19363 .18132 Mdot
.016 w
.19363 .18132 m
.19315 .18223 L
s
.008 w
.19315 .18223 Mdot
.016 w
.19315 .18223 m
.19265 .18325 L
s
.008 w
.19265 .18325 Mdot
.016 w
.19265 .18325 m
.19215 .18426 L
s
1 .039 0 r
.008 w
.19215 .18426 Mdot
.016 w
.19215 .18426 m
.19166 .18532 L
s
.008 w
.19166 .18532 Mdot
.016 w
.19166 .18532 m
.19118 .1864 L
s
1 .038 0 r
.008 w
.19118 .1864 Mdot
.016 w
.19118 .1864 m
.19073 .18748 L
s
.008 w
.19073 .18748 Mdot
.016 w
.19073 .18748 m
.19034 .18843 L
s
.008 w
.19034 .18843 Mdot
.016 w
.19034 .18843 m
.19002 .18927 L
s
1 .037 0 r
.008 w
.19002 .18927 Mdot
.016 w
.19002 .18927 m
.1898 .18996 L
s
.008 w
.1898 .18996 Mdot
.016 w
.1898 .18996 m
.18969 .19046 L
s
.008 w
.18969 .19046 Mdot
.016 w
.18969 .19046 m
.18969 .19075 L
s
1 .036 0 r
.008 w
.18969 .19075 Mdot
.016 w
.18969 .19075 m
.18979 .19081 L
s
.008 w
.18979 .19081 Mdot
.016 w
.18979 .19081 m
.18997 .19069 L
s
1 .035 0 r
.008 w
.18997 .19069 Mdot
.016 w
.18997 .19069 m
.19016 .19046 L
s
.008 w
.19016 .19046 Mdot
.016 w
.19016 .19046 m
.19033 .19022 L
s
.008 w
.19033 .19022 Mdot
.016 w
.19033 .19022 m
.19044 .19002 L
s
1 .034 0 r
.008 w
.19044 .19002 Mdot
.016 w
.19044 .19002 m
.19046 .18994 L
s
.008 w
.19046 .18994 Mdot
.016 w
.19046 .18994 m
.19037 .19002 L
s
1 .033 0 r
.008 w
.19037 .19002 Mdot
.016 w
.19037 .19002 m
.19013 .19033 L
s
.008 w
.19013 .19033 Mdot
.016 w
.19013 .19033 m
.18972 .1909 L
s
.008 w
.18972 .1909 Mdot
.016 w
.18972 .1909 m
.18908 .1918 L
s
1 .032 0 r
.008 w
.18908 .1918 Mdot
.016 w
.18908 .1918 m
.18817 .19306 L
s
.008 w
.18817 .19306 Mdot
.016 w
.18817 .19306 m
.18696 .19473 L
s
1 .031 0 r
.008 w
.18696 .19473 Mdot
.016 w
.18696 .19473 m
.18559 .19656 L
s
.008 w
.18559 .19656 Mdot
.016 w
.18559 .19656 m
.1839 .19894 L
s
.008 w
.1839 .19894 Mdot
.016 w
.1839 .19894 m
.182 .20151 L
s
1 .03 0 r
.008 w
.182 .20151 Mdot
.016 w
.182 .20151 m
.17981 .2046 L
s
.008 w
.17981 .2046 Mdot
.016 w
.17981 .2046 m
.17758 .20767 L
s
.008 w
.17758 .20767 Mdot
.016 w
.17758 .20767 m
.17527 .21109 L
s
1 .029 0 r
.008 w
.17527 .21109 Mdot
.016 w
.17527 .21109 m
.17277 .21487 L
s
.008 w
.17277 .21487 Mdot
.016 w
.17277 .21487 m
.17036 .21834 L
s
1 .028 0 r
.008 w
.17036 .21834 Mdot
.016 w
.17036 .21834 m
.16782 .22214 L
s
.008 w
.16782 .22214 Mdot
.016 w
.16782 .22214 m
.16535 .22621 L
s
.008 w
.16535 .22621 Mdot
.016 w
.16535 .22621 m
.16295 .22993 L
s
1 .027 0 r
.008 w
.16295 .22993 Mdot
.016 w
.16295 .22993 m
.16052 .23388 L
s
.008 w
.16052 .23388 Mdot
.016 w
.16052 .23388 m
.15802 .23813 L
s
1 .026 0 r
.008 w
.15802 .23813 Mdot
.016 w
.15802 .23813 m
.15562 .2421 L
s
.008 w
.15562 .2421 Mdot
.016 w
.15562 .2421 m
.15325 .24601 L
s
.008 w
.15325 .24601 Mdot
.016 w
.15325 .24601 m
.15074 .25046 L
s
1 .025 0 r
.008 w
.15074 .25046 Mdot
.016 w
.15074 .25046 m
.14837 .25418 L
s
.008 w
.14837 .25418 Mdot
.016 w
.14837 .25418 m
.14581 .2585 L
s
1 .024 0 r
.008 w
.14581 .2585 Mdot
.016 w
.14581 .2585 m
.14335 .26227 L
s
.008 w
.14335 .26227 Mdot
.016 w
.14335 .26227 m
.1408 .26635 L
s
.008 w
.1408 .26635 Mdot
.016 w
.1408 .26635 m
.13817 .27052 L
s
1 .023 0 r
.008 w
.13817 .27052 Mdot
.016 w
.13817 .27052 m
.13566 .27436 L
s
.008 w
.13566 .27436 Mdot
.016 w
.13566 .27436 m
.13314 .2782 L
s
.008 w
.13314 .2782 Mdot
.016 w
.13314 .2782 m
.13068 .28197 L
s
1 .022 0 r
.008 w
.13068 .28197 Mdot
.016 w
.13068 .28197 m
.12822 .28577 L
s
.008 w
.12822 .28577 Mdot
.016 w
.12822 .28577 m
.12592 .28927 L
s
1 .021 0 r
.008 w
.12592 .28927 Mdot
.016 w
.12592 .28927 m
.12363 .29284 L
s
.008 w
.12363 .29284 Mdot
.016 w
.12363 .29284 m
.12132 .29661 L
s
.008 w
.12132 .29661 Mdot
.016 w
.12132 .29661 m
.11904 .30026 L
s
1 .02 0 r
.008 w
.11904 .30026 Mdot
.016 w
.11904 .30026 m
.11688 .30365 L
s
.008 w
.11688 .30365 Mdot
.016 w
.11688 .30365 m
.11461 .30747 L
s
1 .019 0 r
.008 w
.11461 .30747 Mdot
.016 w
.11461 .30747 m
.11236 .31118 L
s
.008 w
.11236 .31118 Mdot
.016 w
.11236 .31118 m
.11015 .31456 L
s
.008 w
.11015 .31456 Mdot
.016 w
.11015 .31456 m
.10791 .3183 L
s
1 .018 0 r
.008 w
.10791 .3183 Mdot
.016 w
.10791 .3183 m
.10592 .32166 L
s
.008 w
.10592 .32166 Mdot
.016 w
.10592 .32166 m
.10397 .32507 L
s
1 .017 0 r
.008 w
.10397 .32507 Mdot
.016 w
.10397 .32507 m
.10217 .32837 L
s
.008 w
.10217 .32837 Mdot
.016 w
.10217 .32837 m
.10057 .33133 L
s
.008 w
.10057 .33133 Mdot
.016 w
.10057 .33133 m
.09909 .33412 L
s
1 .016 0 r
.008 w
.09909 .33412 Mdot
.016 w
.09909 .33412 m
.09791 .33646 L
s
.008 w
.09791 .33646 Mdot
.016 w
.09791 .33646 m
.09692 .33859 L
s
.008 w
.09692 .33859 Mdot
.016 w
.09692 .33859 m
.09611 .34039 L
s
1 .015 0 r
.008 w
.09611 .34039 Mdot
.016 w
.09611 .34039 m
.09552 .34179 L
s
.008 w
.09552 .34179 Mdot
.016 w
.09552 .34179 m
.09513 .34289 L
s
1 .014 0 r
.008 w
.09513 .34289 Mdot
.016 w
.09513 .34289 m
.09495 .34365 L
s
.008 w
.09495 .34365 Mdot
.016 w
.09495 .34365 m
.09493 .3441 L
s
.008 w
.09493 .3441 Mdot
.016 w
.09493 .3441 m
.09503 .34429 L
s
1 .013 0 r
.008 w
.09503 .34429 Mdot
.016 w
.09503 .34429 m
.09518 .34427 L
s
.008 w
.09518 .34427 Mdot
.016 w
.09518 .34427 m
.09535 .3441 L
s
1 .012 0 r
.008 w
.09535 .3441 Mdot
.016 w
.09535 .3441 m
.09549 .34385 L
s
.008 w
.09549 .34385 Mdot
.016 w
.09549 .34385 m
.09557 .3436 L
s
.008 w
.09557 .3436 Mdot
.016 w
.09557 .3436 m
.09557 .3434 L
s
1 .011 0 r
.008 w
.09557 .3434 Mdot
.016 w
.09557 .3434 m
.09548 .34333 L
s
.008 w
.09548 .34333 Mdot
.016 w
.09548 .34333 m
.09532 .34346 L
s
1 .01 0 r
.008 w
.09532 .34346 Mdot
.016 w
.09532 .34346 m
.09508 .34385 L
s
.008 w
.09508 .34385 Mdot
.016 w
.09508 .34385 m
.09478 .34455 L
s
.008 w
.09478 .34455 Mdot
.016 w
.09478 .34455 m
.09438 .34567 L
s
1 .009 0 r
.008 w
.09438 .34567 Mdot
.016 w
.09438 .34567 m
.09389 .34723 L
s
.008 w
.09389 .34723 Mdot
.016 w
.09389 .34723 m
.0933 .34926 L
s
.008 w
.0933 .34926 Mdot
.016 w
.0933 .34926 m
.09261 .35193 L
s
1 .008 0 r
.008 w
.09261 .35193 Mdot
.016 w
.09261 .35193 m
.09183 .35488 L
s
.008 w
.09183 .35488 Mdot
.016 w
.09183 .35488 m
.091 .35857 L
s
1 .007 0 r
.008 w
.091 .35857 Mdot
.016 w
.091 .35857 m
.09014 .36296 L
s
.008 w
.09014 .36296 Mdot
.016 w
.09014 .36296 m
.08926 .3673 L
s
.008 w
.08926 .3673 Mdot
.016 w
.08926 .3673 m
.08842 .37258 L
s
1 .006 0 r
.008 w
.08842 .37258 Mdot
.016 w
.08842 .37258 m
.08762 .37734 L
s
.008 w
.08762 .37734 Mdot
.016 w
.08762 .37734 m
.08689 .38278 L
s
1 .005 0 r
.008 w
.08689 .38278 Mdot
.016 w
.08689 .38278 m
.08625 .3885 L
s
.008 w
.08625 .3885 Mdot
.016 w
.08625 .3885 m
.08569 .3941 L
s
.008 w
.08569 .3941 Mdot
.016 w
.08569 .3941 m
.08521 .39875 L
s
1 .004 0 r
.008 w
.08521 .39875 Mdot
.016 w
.08521 .39875 m
.08483 .4037 L
s
.008 w
.08483 .4037 Mdot
.016 w
.08483 .4037 m
.08453 .40875 L
s
1 .003 0 r
.008 w
.08453 .40875 Mdot
.016 w
.08453 .40875 m
.08433 .41284 L
s
.008 w
.08433 .41284 Mdot
.016 w
.08433 .41284 m
.08422 .41605 L
s
.008 w
.08422 .41605 Mdot
.016 w
.08422 .41605 m
.08416 .41908 L
s
1 .002 0 r
.008 w
.08416 .41908 Mdot
.016 w
.08416 .41908 m
.08415 .42179 L
s
.008 w
.08415 .42179 Mdot
.016 w
.08415 .42179 m
.08417 .4237 L
s
.008 w
.08417 .4237 Mdot
.016 w
.08417 .4237 m
.0842 .42518 L
s
1 .001 0 r
.008 w
.0842 .42518 Mdot
.016 w
.0842 .42518 m
.08423 .42622 L
s
.008 w
.08423 .42622 Mdot
.016 w
.08423 .42622 m
.08425 .42687 L
s
1 0 0 r
.008 w
.08425 .42687 Mdot
.016 w
.08425 .42687 m
.08426 .42719 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0136034 0.0131366 scale
17.93 11.2426 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0299805 0.0289517 scale
12.4284 2.43958 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0316951 0.0306074 scale
12.8358 2.22038 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0162592 0.0157012 scale
44.1995 7.82103 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0125943 0.0121621 scale
59.6157 11.1527 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154249 0.0148955 scale
55.2355 16.8024 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0462746 0.0446865 scale
19.4612 7.29012 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154249 0.0148955 scale
59.0145 24.8833 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0490479 0.0473647 scale
18.4728 7.07151 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0272069 0.0262732 scale
33.9719 17.8684 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145427 0.0140436 scale
63.9772 41.04 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0145427 0.0140436 scale
61.5753 49.6539 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0267166 0.0257998 scale
32.0415 31.1696 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0154249 0.0148955 scale
54.1529 55.1106 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0136034 0.0131366 scale
60.1848 63.5621 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0308497 0.029791 scale
28.6839 23.9119 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0356222 0.0343997 scale
21.9734 4.48143 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0337158 0.0325588 scale
19.4309 2.94728 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0398268 0.03846 scale
16.1612 2.37883 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0170528 0.0164676 scale
39.7025 6.49578 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0462746 0.0446865 scale
12.3124 1.5329 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0185384 0.0179022 scale
25.3188 3.66492 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0241163 0.0232887 scale
18.5285 2.77216 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0281618 0.0271954 scale
12.5447 2.99353 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.022994 0.0222049 scale
8.44611 8.11397 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0125943 0.0121621 scale
15.0766 15.6987 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002POol8001hOol009eoo`<0
00Qoo`03001oogoo07Eoo`00Vgoo0P0037oo00<007ooOol0M7oo002JOol00`00Oomoo`0=Ool2001d
Ool007=oo`H0021oo`03001oogoo011oo`03001oogoo075oo`00JGoo1`0000=oo`0000001Woo00@0
07ooOomoo`H001Eoo`03001oogoo019oo`03001oogoo071oo`00J7oo00<007ooOol01Goo00<007oo
Ool01goo0`001Woo0P004goo00<007ooOol04Woo00<007ooOol0L7oo001WOol00`00Oomoo`05Ool0
0`00Ool00009Ool20007Ool6000=Ool00`00Oomoo`0COol00`00Oomoo`1`Ool006Ioo`<000Ioo`04
001oogoo0007Ool01000Oomoo`001Goo00@007ooOol000=oo`03001oogoo00Yoo`03001oogoo01Ao
o`03001oogoo00=oo`L006Eoo`00Hgoo0`000goo0P000goo00<007ooOol00Woo00<007ooOol017oo
00@007ooOol000AooaX0019oo`03001oogoo00<000Moo`8006=oo`00HWoo00@007ooOol000Eoo`<0
00<mk`9oo`03001oocg_00@mk`05000mkcg_?Nl00003O6000`00O61lH002O6001@00O61lP3g_0000
1Woo00EoH7ooOomoo`0000Eoo`P000]oo`8000aoo`03001oogoo061oo`00HGoo00@007ooOol000Io
o`9lH003001lH7aP00AlH003001lH7aP00=lH005001lH7aPO6000003O6000`00O61lH002O6000`00
O61lP002O8000`00O81lP006O8000`00O81lP00=O80017c0000007c01Woo00<007ooOol017oo2@00
HGoo001QOol01000Oomoo`000goo1GaP00<007aPO60017aP00<007aPO6000gaP00D007aPO61lH000
00=lH003001lH7aP009lH003001lH7b0009lP003001lP7b000IlP003001lP7b000elP0Il`0D000Ao
o`8000Qoo`80061oo`00H7oo00H007ooOomoo`00Ool7O6020005O6000`00O61lH003O6001@00O61l
H7aP00000gaP00<007aPO6000WaP00D007aPO81lP00000YlP003001lP7b000alP0Ml`09oo`@00003
Ool007oo00Yoo`8005moo`00H7oo00H007ooOomoo`00O602O405O6020005O6000`00O61lH004O600
1000O61lH0000gaP00IoH000Of1oH7b00003O8000`00O81lP008O8000`00O81lP00<O808O<001@00
O<0007c0Ool010002Woo0P00GWoo001OOol00`00Oomoo`02O4000`00O41l@002O404O6020004Oh00
0cg_001oP004Oh0017mP001oH0001GmP00H007mPOf0007mP?Nl20006?Nl5Of000`00Of1oH009Of0;
O<000`00O<000002O<001000Ooml`7oo0`0027oo0P00GGoo001OOol00`00O41l@002O4000`00O41l
@002O403O602?Nl00`00?Nlmk`03?Nl00`00?Nlmk`05?Nl20006?Nl5000;?Nl2Of000`00Of1oH00>
Of05O<001P00O<1l`000O<0000El`09oo`<000Eoo`8005eoo`00Ggoo00<007a0O4000ga000D007a0
O41l@7aP00@mk`03000mkcg_008mk`03000mkcg_00Hmk`04001oo`000002Ool20002Ool7?Nl9Ool0
1000Oomoogoo3gmP0gc000<007c000000Wc000<007c0O<001Gc00goo0`000Woo0P00GGoo001MOol2
O4000`00O41l@004O4000`00O41l@005?Nl20003Ool00`00?Nlmk`05?Nl00`00Oomoo`02Ool2000E
Ool00`00Oomoo`03Ool?Of000`00O<000002O<000`00O<1l`006O<000gd0O<1oo`02Ool300000goo
001oo`1KOol005]oo`El@003001l@7a000Al@080009oo`<mk`03001oo`00008000Moo`03001oogoo
01Yoo`03001oogoo00Eoo`eoH0800003Of1l`00000al`080009oo`<005aoo`00FGoo00<007a0O400
17a000D007a0O41l@7nP00<mk`05Ool007ooOolmk`0400001Goo00000000Ool010007Woo00<007oo
Ool01Goo1WmP1Woo00D007ooOf1oH000009lh0Ul`007001l`7c0O<1oo`00Ool00`00FWoo001GOol0
0`00O41l@007O4000`00?Nlmk`06Ool40007Ool00`00Oomoo`0QOol2000@Ool20003Ool00`00O>1l
h002O>06O<000`00O<1l`003O<001@00OB000000Ool00P00F7oo001EOol00`00O41l@009O4000cg_
00000007Ool00`00Oomoo`0]Ool2000=Ool00`00Ool00004Ool00`00O>1lh003O>04O<000`00O<1l
`003O<001@00OB000000OB000Woo0P00EWoo001BOol200000cg_O41l@008O402?Nl3Ool7000bOol2
0009Ool20003Ool01@00Oomoogoo00000Woo0Wm017cP00=l`000O<0017c00P0000=m8000OB000WdP
00=oo`0000000`00DWoo001@Ool200000gooO41l@007O402Oj02?NloOol20002Ool50005Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool2Od000gcP001l`003O<0200000gc0OB000003OB000`00OB1oo`02
Ool2001AOol004moo`03001oocg_00Yl@0<mkd9oo`8000]oo`05001oogooOol00009Ool01P00O<1l
`000O<00009m8005001m87dPOB000002OB001GooOB1oogoo0000D7oo001>Ool00`00Ooml@009O400
17nP?Nlmkcg_D7oo0P000goo00<007ooOol01Woo0`0000=l`000O<000P000gdP00<007dPOB001GdP
0P002Woo1000@Goo001<Ool20002O208O403?NmEOol20002Ool20005Ool200000goo000000020000
0gooOd1m8002OB000`00OB1m8005OB000`00Oomm80030004Ool20004Ool4000mOol004Yoo`8000Ml
80Al@003Oj0mkcg_05Qoo`80009oo`800004Ool00000Ool20007Ool00gm0OB000007OB001@00OB1m
8000OB001@002Woo00<007ooOol0>Woo0018Ool20009O202O4000gnP?Nlmk`02?NmJOol8000;Ool0
0`00OB1m8005OB000`00OB000004OB02000<Ool00`00Oomoo`0iOol004Ioo`@000Ul8003O40mkcg_
00@mkfioo`03001o@7m000=m8004001m87dP0003OB001000OB0000002goo00<007ooOol0>Goo0015
Ool30002O2020007O206?Nm`Ool200000gm000000002OB000`00OB1m8002OB001@00OB0007oo0000
2goo00<007ooOol0>7oo0014Ool00`00Ool00005O2001000O21l87`P23g_Lgoo00<007ooOol00Wm0
00Em8000OB1m8000009m8004001m87dP000;Ool00`00Oomoo`0gOol004=oo`03001oo`0000Il8004
001l87nPOj05?NmkOol01Gm000000000OB000P000gdP00=o8000Ool02Goo00<007ooOol0=goo0011
Ool01@00O21l87`P00001W`P00<007nP?Nl013g_Ogoo00=o800000001WdP00=o8000000027oo00<0
07ooOol0=goo0010Ool00`00O21l8002O2002000O21l87`POl1oX3g_0006?Nn0Ool00`00Ob1m8009
OB07Ool00`00Oomoo`0gOol003moo`Ml8003001l87o0009o`003001oogoo08Eoo`03001ooglP00Ym
8003001oogoo00=oo`03001oogoo03Moo`00>7oo1P0027`P0P0000Ao`3g_000008Moo`05001oogoo
Oomo8008OB000ge0001oo`03Ool00`00Oomoo`0gOol003Moo`03001oogoo009oo`04001l80000004
O203Ol000cg_00000029Ool00`00Oomoo`02Ool7OB02OD000goo001oo`02Ool00`00Oomoo`0gOol0
03Ioo`03001oogoo009oo`03001l87`P009l8003001l87`P009o`0@mkhYoo`03001oogoo009oo`Em
80Em@005Ool007ooOol0000iOol003Eoo`03001oogoo009oo`03001l87`P00Al8003001l87o000@m
khaoo`03001oogoo00Aoo`03Ob1m@7e000Em@004Ool00000000iOol003Eoo`05001oogooOol00006
O2000go0000mk`04?Nn=Ool00`00Oomoo`04Ool2Ob07OD000goo0000000iOol003Eoo`04001oo`00
0006O202Ol000`00?Nlmk`02?Nn?Ool20004Ool4Ob05OD001000Oomoo`00>7oo000eOol200000goo
000000020002O202Ol000cg_001oo`2DOol20003Ool3Ob04OD000`00OD1oo`02Ool00`00Oomoo`0e
Ool003Eoo`03001oo`0000Al80800004Ol0mkcg_002GOol01000Oomoogoo0WlP0We00P000ge00goo
00<007ooOol0=7oo000dOol2000017oo001l07`00g`P00D007o0?Nlmk`0009Qoo`L000Im@0=oo`03
001oogoo03=oo`00<Woo0P000Woo00<007`0O0000W`00W`P00@003g_?Nl00:1oo`03Ob1m@7e000Am
@0=oo`8003=oo`00<Goo00<007ooOol00Woo0P0017`000Eo`000?Nl003g_0:5oo`03Ob1m@7e000=m
@0Eoo`03001oogoo031oo`00<7oo00<007ooOol00Woo00@mkg`00000009l00800004?Nl003g_?NnR
Ool6OD05Ool00`00Oomoo`0_Ool002moo`03001oogoo00=oo`=l00H0008mkj=oo`Mm@0Eoo`03001o
ogoo02ioo`00;Woo00<007ooOol00goo1W`000=o`3g_?Nl00Sg_Y7oo00=o87e0OD001Ge01Goo00<0
07ooOol0;Goo000^Ool00`00Oomoo`02Ool7O003?NnWOol2Ob06OD04Ool00`00Oomoo`0]Ool002eo
o`03001oogoo009oo`Il009o`08mkjUoo`03Ob1m@7e000Am@0Eoo`03001oogoo02aoo`00;7oo00<0
07ooOol00goo1G`000=o`3g_?Nl00Sg_ZGoo00=o87e0OD001Ge01Goo00<007ooOol0:goo000[Ool0
0`00Oomoo`04Ool4O002Ol04?NnZOol00glPOD1m@005OD05Ool00`00Oomoo`0ZOol002Yoo`03001o
ogoo00Aoo`El0003Ol0mkcg_0:moo`Im@0Ioo`03001oogoo02Uoo`00:Woo00<007ooOol00goo1W`0
00=o`7ooOol0[goo00=o87e0OD0017e01Goo00<007ooOol0:Goo000YOol00`00Oomoo`04Ool5O000
0go0Oomoo`2`Ool00glPOD1m@005OD05Ool00`00Oomoo`0XOol002Qoo`03001oogoo00Aoo`Il0003
?Nmoogoo0;5oo`03Ob1o07e0009m@0<000Eoo`03001oogoo02Moo`009goo00<007ooOol017oo1W`0
00=o`7ooOol0/goo0Wl000=m@000OD000We00P0017oo00<007ooOol09Woo000VOol00`00Oomoo`05
Ool6O002?NneOol00gl0001m@004OD000goo001oo`03Ool00`00Oomoo`0UOol002Ioo`03001oogoo
00Aoo`Il00<mkkIoo`03001m@7e000Am@003Ool007oo009oo`03001oogoo02Eoo`009Goo00<007oo
Ool017oo1W`000=o`3g_?Nl0]Woo00<007l0OD001Ge000=oo`00Ool00goo00<007ooOol097oo000T
Ool00`00Oomoo`05Ool6O002?NnhOol00`00OD1m@005OD000`00Oomoo`03Ool00`00Oomoo`0SOol0
02=oo`03001oogoo00Eoo`03?Nml07`0009l009o`08mkkQoo`03001ooge000Am@003001m@7oo00Eo
o`03001oogoo029oo`008Woo00<007ooOol01Goo00<mkg`0O0000g`000=o`3g_?Nl0^Woo0P000ge0
0P0000=m@7ooOol01Goo00<007ooOol08Goo000ROol00`00Oomoo`05Ool6O003?NnlOol30004OD06
Ool00`00Oomoo`0QOol0025oo`03001oogoo00Eoo`03?Nml07`000=l0003Ol0mkcg_0;ioo`Mm@0Io
o`03001oogoo021oo`0087oo00<007ooOol01Woo1W`00Sg_`7oo00=o07e0OD000We000=mH7ooOol0
1Goo00<007ooOol07goo000OOol00`00Oomoo`06Ool6O0000cg_Oomoo`30Ool00gl0OD1m@002OD02
OF07Ool00`00Oomoo`0NOol001moo`03001oogoo00Ioo`Il0<Aoo`Am@0=mH0Ioo`03001oogoo01io
o`007Woo00<007ooOol01Woo1W`000<mkgooOol0`goo00=o07ePOF000WeP2P007Woo000NOol00`00
Oomoo`05Ool6O002?No5Ool01Gl0OF1mH7eP00000WeP17oo0`0000Aoo`00000001]oo`007Goo00<0
07ooOol01Woo1W`00Sg_aWoo0WeP00<007ePOF001@000goo0`0000=oo`00Ool06Goo000MOol00`00
Oomoo`05Ool6O003?No6Ool01Gl0001mH7eP00000WeP1Woo00<007ooOol00`006Goo000LOol00`00
Oomoo`05Ool6O0000goP?Nlmk`37Ool01000O`1mH00017eP1Woo00<007ooOol00Woo00<007ooOol0
5Woo000LOol00`00Oomoo`05Ool6O003?No6Ool01000Oomoo`001WeP1Goo00<007ooOol00goo00<0
07ooOol05Goo000KOol00`00Oomoo`05Ool6O00017oP?Nlmkcg_aWoo00@007oo001o00MmH0Eoo`03
001oogoo009oo`8001Ioo`006goo00<007ooOol01Goo1G`000Aoh3g_?NlmklIoo`03001oo`0000=o
o`03O`1mH7eP00=mH0Eoo`03001oogoo00=oo`8001Eoo`006Woo00<007ooOol01Goo1W`013g_aWoo
0P0017oo00=o07ePOF0017eP1Goo00<007ooOol00Woo0P005Goo000IOol00`00Oomoo`05Ool6O004
?No6Ool20005Ool00gl0OF1mH004OF05Ool00`00Oomoo`02Ool2000EOol001Uoo`03001oogoo00Eo
o`Il008mklQoo`8000Ioo`03O`1mH7eP00AmH0Eoo`03001oogoo009oo`8001Aoo`0067oo00<007oo
Ool01Goo1W`00Sg_b7oo0P001goo00=o07ePOF0017eP1Woo00@007ooOomoo`8001Aoo`0067oo00<0
07ooOol017oo1W`000=oh3g_Ool0b7oo0P001goo0WiP1WeP1Goo00L007ooOomoo`00Ool0000COol0
01Qoo`03001oogoo00Aoo`Il008mklUoo`8000Moo`9nH0ImH0Eoo`07001oogooOol007oo00004goo
000GOol00`00Oomoo`04Ool6O0000goP?Nlmk`39Ool20007Ool3OV05OF000gj0Oomoo`03Ool00`00
Ool00002Ool00`00Oomoo`0AOol001Moo`03001oogoo00Aoo`Il008mkl]oo`03001oogoo00Eoo`=n
H0EmH003OZ1oogoo00=oo`03001oo`00009oo`03001oogoo015oo`005Woo00<007ooOol01Goo1G`0
0Sg_c7oo00<007ooOol01Woo0WiP1GeP00=n`7ooOol017oo0P000Woo00<007ooOol04Goo000FOol0
0`00Oomoo`04Ool6O002?No<Ool20008Ool2OV04OF000gjPOomoo`04Ool20002Ool00`00Oomoo`0A
Ool001Eoo`03001oogoo00Eoo`El0003On0mkcg_0<eoo`03001oogoo00Ioo`9nH0AmH003OZ1oogoo
00Aoo`80009oo`03001oogoo015oo`005Goo00<007ooOol01Goo1G`000=oh3g_Ool0cGoo0P001goo
0WiP1GeP1Goo00D007oo001oo`0001Aoo`0057oo00<007ooOol01Woo17`000=oh3g_?Nl0cgoo0P00
1goo00=nH7eP00000P0000=mH7ooOol00goo00<007ooOol00P0057oo000DOol00`00Oomoo`05Ool6
O0000cg_Oomoo`3>Ool00`00Ool00006Ool00giP001mH002OF020002Ool20003Ool2000DOol001Ao
o`03001oogoo00Eoo`El008mkm5oo`04001oo`000004Ool00`00OF1mH003OF000goo00000005Ool0
0`00Oomoo`0COol001=oo`03001oogoo00Ioo`El008mkm9oo`03001oogoo0080009oo`03001nH7eP
009mH0800003Ool007oo00=oo`03001oo`0001Aoo`004goo00<007ooOol01Woo17`000=oh3g_Ool0
dgoo00@007ooOomoo`L00004OF1nH7oo0002Ool20002Ool00`00Oomoo`0BOol001=oo`03001oogoo
00Ioo`Al009oh=Eoo`8000=oo`03001n`7eP00AmH004OV0007oo0004Ool00`00Oomoo`0BOol0019o
o`03001oogoo00Moo`Al0003On0mkgoo0=Ioo`800003Ool007k000EmH0<000Ioo`03001oogoo015o
o`004Woo00<007ooOol01goo17`000=oh7ooOol0f7oo2@0027oo00<007ooOol04Goo000BOol00`00
Oomoo`06Ool6O03NOol300000gePOomoo`07Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`El
0003?Nmoogoo0=aoo`AmH0Yoo`03001oogoo011oo`004Goo00<007ooOol01goo1G`0ggoo17eP00=n
H7ooOol01goo00<007ooOol047oo000AOol00`00Oomoo`07Ool4O0000goPOomoo`3MOol5OF000giP
Oomoo`06Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Al0003On0mkgoo0=eoo`ImH0Qoo`03
001oogoo011oo`0047oo00<007ooOol027oo17`000=oh3g_Ool0gGoo1GeP2Woo00<007ooOol03goo
000@Ool00`00Oomoo`08Ool4O0000goPOomoo`3NOol4OF0:Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo00Qoo`Al0003On1oogoo0=ioo`AmH0Yoo`03001oogoo00moo`0047oo00<007ooOol027oo17`0
00=oh7ooOol0gWoo17eP2Woo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4O0000cg_Oomoo`3N
Ool4OF0;Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al0>5oo`AmH0]oo`03001oogoo00io
o`003goo00<007ooOol02Goo17`0hGoo17eP2goo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4
O03QOol4OF0;Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al0>5oo`EmH0Yoo`03001oogoo
00ioo`003Woo00<007ooOol02Woo17`0hGoo1WeP2Woo00<007ooOol03Goo000>Ool00`00Oomoo`0:
Ool4?NoQOol5OF0;Ool00`00Oomoo`0=Ool000ioo`03001oogoo0?1oo`9mH0<000Yoo`03001oogoo
00eoo`003Woo00<007ooOol0kgoo0`000WeP00=oo`00000027oo00<007ooOol03Goo000>Ool00`00
Oomoo`3^Ool00`00OommH003OF03Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool000eoo`03001oogoo
0>ioo`03001oogoo00AmH0Aoo`03001oogoo00Eoo`03001oogoo00aoo`003Goo00<007ooOol0kGoo
00@007ooOomoo`AmH0Eoo`03001oogoo00Aoo`03001oogoo00aoo`003Goo00<007ooOol0kGoo00@0
07ooOomoo`EmH0Eoo`03001oogoo00=oo`03001oogoo00aoo`003Goo00<007ooOol06Goo13g_cgoo
00D007ooOomoogi000ImH0Aoo`03001oogoo00=oo`03001oogoo00aoo`003Goo00<007ooOol04goo
2cg_cWoo00D007ooOomoogi000EmH0Eoo`03001oogoo00=oo`03001oogoo00aoo`003Goo00<007oo
Ool047oo3Sg_cWoo00@007ooOomoo`9n@0AmH0Eoo`03001oogoo00=oo`03001oogoo00aoo`003Goo
00<007ooOol02goo4Sg_cgoo00@007ooOomoo`9n@0AmH0Aoo`03001oogoo00Aoo`03001oogoo00ao
o`003Goo00<007ooOol02Goo5Cg_cWoo00@007ooOomoo`9n@0AmH0Aoo`03001oogoo00Aoo`03001o
ogoo00aoo`003Goo00<007ooOol027oo6Cg_c7oo00<007ooOol00Wi017eP17oo00<007ooOol017oo
00<007ooOol037oo000=Ool00`00Oomoo`08OolM?No9Ool01000OT1n@7i017eP0goo00<007ooOol0
1Goo00<007ooOol037oo000=Ool00`00Oomoo`08Ool9?Nl2OolC?No9Ool00`00OT1n@004OF02Ool2
0008Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`Hmk`Eoo`Lmk`03Oolmkcg_00TmklUoo`03
OT00000000=mH0<000Yoo`03001oogoo00]oo`0037oo00<007ooOol02Goo2Sg_0Woo1Sg_00=oocg_
?Nl02Cg_bWoo0Wi00`0000=mH7f0OH002Woo00<007ooOol02goo000<Ool00`00Oomoo`08OolN?No;
Ool2OT05OH0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qooadmklaoo`=n@0AmP0]oo`03001o
ogoo00]oo`0037oo00<007ooOol027oo5Cg_e7oo0gi017f02goo00<007ooOol02goo000<Ool00`00
Oomoo`08Ool6?Nl3Ool<?NoDOol3OT04OH0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Hm
k`Moo`Tmkm=oo`=n@0AmP0]oo`03001oogoo00]oo`0037oo00<007ooOol027oo1Sg_2Woo1Sg_dgoo
0gi017f02goo00<007ooOol02goo000<Ool00`00Oomoo`07Ool7?Nl:Ool6?NoDOol2OT04OH0;Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Hmk`]oo`Lmkm=oo`9n@0AmP0]oo`03001oogoo00]o
o`0037oo00<007ooOol01goo1Sg_2goo1cg_dgoo0Wi017f02goo00<007ooOol02goo000<Ool00`00
Oomoo`07Ool5?Nl<Ool:?No@Ool2OT04OH0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Dm
k`aoo`Xmkm5oo`03OT1mP7f0009mP0]oo`03001oogoo00]oo`0037oo00<007ooOol01goo1Cg_37oo
2cg_d7oo00=n@7f0OH000Wf02goo00<007ooOol02goo000=Ool00`00Oomoo`06Ool5?Nl?Ool8?NoA
Ool4OH000gi0Oomoo`07Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Dmka1oo`Pmkm1oo`Am
P003OT1oogoo00Moo`03001oogoo00aoo`003Goo00<007ooOol01Woo1Cg_47oo23g_d7oo17f000=n
@7ooOol01goo00<007ooOol037oo000=Ool00`00Oomoo`06Ool6?Nl?Ool8?No@Ool4OH000gi0Oomo
o`07Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Hmka1oo`Pmklmoo`AmP003OT1oogoo00Mo
o`03001oogoo00aoo`003Goo00<007ooOol01Woo1Sg_47oo23g_cgoo00EmP000000007i000Uoo`03
001oogoo00aoo`003Goo00<007ooOol01goo1Cg_47oo23g_cgoo00@007f0OH1mP08000Qoo`03001o
ogoo00aoo`003Goo00<007ooOol01goo1Sg_3goo2cg_bgoo00<007f0OH000Wf000=n@000Ool01goo
00<007ooOol037oo000=Ool00`00Oomoo`07Ool6?Nl?Ool;?No;Ool00`00OH1mP002OH000ghPOol0
0007Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Moo`Dmka5oo`XmklYoo`03001oogf000=mP003
OR1oo`0000Moo`03001oogoo00aoo`003Goo00<007ooOol027oo1Cg_4Goo2Cg_bgoo00<007f0OH00
0Wf000=n87oo00001goo00<007ooOol037oo000>Ool00`00Oomoo`07Ool5?NlBOol8?No;Ool00`00
OH1mP003OH000`00Oomoo`05Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`Dmka9oo`Dmklio
o`03OH000000009mP08000Moo`03001oogoo00eoo`003Woo00<007ooOol01goo1Cg_i7oo00An87f0
OH1mP08000Uoo`03001oogoo00eoo`003Woo00<007ooOol01goo1Sg_hgoo1Gf02Woo00<007ooOol0
3Goo000?Ool00`00Oomoo`06Ool6?NoSOol5OH0:Ool00`00Oomoo`0=Ool000moo`03001oogoo00Mo
o`Hmkn9oo`EmP0Uoo`03001oogoo00ioo`003goo00<007ooOol01goo1Sg_hGoo00=n87f0OH000gf0
2Goo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool6?NoQOol6OH09Ool00`00Oomoo`0>Ool000mo
o`03001oogoo00Moo`Hmkn5oo`EmP0Yoo`03001oogoo00ioo`0047oo00<007ooOol01Woo1Sg_hGoo
1Gf02Goo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5?NoQOol6OH09Ool00`00Oomoo`0?Ool0
011oo`03001oogoo00Ioo`Dmkn5oo`EmP003OR1oogoo00Moo`03001oogoo00moo`0047oo00<007oo
Ool01Woo1Sg_h7oo1Gf02Woo00<007ooOol03goo000@Ool00`00Oomoo`06Ool6?NoOOol00ghPOH1m
P002OH000ghPOomoo`08Ool00`00Oomoo`0?Ool0015oo`03001oogoo00Eoo`Lmkmioo`ImP0Uoo`03
001oogoo011oo`004Goo00<007ooOol01Goo1cg_gGoo00=n87f0OH000gf02Woo00<007ooOol047oo
000BOol00`00Oomoo`05Ool5?NoMOol00ghPOH1mP004OH0:Ool00`00Oomoo`0@Ool0019oo`03001o
ogoo00Eoo`Dmkmeoo`03OR1mP7f000=mP0Yoo`03001oogoo015oo`004Woo00<007ooOol01Goo1Cg_
g7oo0WhP1Gf02Woo00<007ooOol04Goo000BOol00`00Oomoo`05Ool5?NoLOol00ghPOH1mP004OH0:
Ool00`00Oomoo`0AOol001=oo`03001oogoo00Eoo`Dmkm]oo`03OR1mP7f000=mP0Yoo`03001oogoo
019oo`004goo00<007ooOol01Goo1Cg_fgoo1Wf02Woo00<007ooOol04Woo000COol00`00Oomoo`05
Ool5?NoKOol5OH0;Ool00`00Oomoo`0BOol001Aoo`03001oogoo00Aoo`HmkmYoo`EmP0Yoo`03001o
ogoo01=oo`0057oo00<007ooOol017oo1Sg_fGoo1Gf02goo00<007ooOol04goo000DOol00`00Oomo
o`04Ool6?NoIOol5OH000ghPOomoo`08Ool00`00Oomoo`0COol001Eoo`03001oogoo00=oo`HmkmIo
o`<mk`EmP0Yoo`03001oogoo01Aoo`005Goo00<007ooOol00goo1Sg_eGoo200000=mP7ooOol027oo
00<007ooOol057oo000FOol00`00Oomoo`03Ool5?NoCOol20003?Nl20002OH030008Ool00`00Oomo
o`0EOol001Ioo`03001oogoo00=oo`Dmkm9oo`03001oogoo00<mk`03001mP7f0009mP08000Qoo`03
001oogoo01Eoo`005goo00<007ooOol00Woo1Cg_dGoo00@007ooOomoo`8mk`03001mP7f0009mP004
OP0mk`000006Ool00`00Oomoo`0FOol001Moo`03001oogoo009oo`Hmkm1oo`04001oogooOol2?Nl0
0`00OH1mP003OH02Ool00`00Oomoo`04Ool00`00Oomoo`0FOol001Qoo`04001oogooOol6?No?Ool0
0`00Oomoo`02Ool2?Nl00`00OH1mP002OH0017h0Ool000001Goo00<007ooOol05goo000HOol01000
Oomoogoo1Sg_cWoo00<007ooOol00Woo0Sg_0Wf000T007f0OH1mP7h0Ool007oo000017oo00<007oo
Ool05goo000HOol01000Oomoogoo1cg_cGoo00@007ooOomoo`<mk`9mP0800004OH1n00000002Ool0
0`00Oomoo`02Ool00`00Oomoo`0GOol001Uoo`04001oogooOol6?No=Ool00`00Oolmk`03?Nl5OH02
00001Gh0Oomoogoo00000goo00<007ooOol067oo000IOol01000Oomoogoo1cg_c7oo00<003g_?Nl0
0cg_1Gf00WfP17oo00D007ooOomoo`0001Yoo`006Woo00<007ooOol023g_bgoo00<mk`00?Nl00cg_
1Gf00WfP17oo00@007ooOol001]oo`006Woo00@007ooOomoo`PmklIoo`Dmk`03000mkcg_008mk`Em
P003OJ1oogoo009oo`05001oogooOol0000KOol001]oo`03001oogoo00TmklEoo`Dmk`03000mkcg_
008mk`AmP0=mX0=oo`04001oogoo000LOol001]oo`03001oogoo00XmklAoo`Hmk`03000mkcg_008m
k`EmX0=oo`05001oogooOol0000LOol001aoo`03001oogoo00Xmkl=oo`Hmk`03000mkgoo008mk`Em
X0=oo`04001oogoo000MOol001aoo`03001oogoo00/mkl9oo`@mk`=oo`800003?Nmn07fP00=mX004
OP1oo`000003Ool00`00Oomoo`0KOol001eoo`03001oocg_00Xmkl5oo`Dmk`Eoo`P000Aoo`03001o
ogoo01aoo`007Woo00<003g_?Nl02Cg_`Goo1Cg_1Woo1GfP1Goo00<007ooOol07Goo000NOol00`00
?Nlmk`09?No1Ool4?Nl6Ool00gh0OJ1mX003OJ05Ool00`00Oomoo`0MOol001moo`03000mkcg_00Pm
kl5oo`Dmk`Aoo`03?NmmX7fP00AmX0Aoo`03001oogoo01ioo`007goo00<003g_?Nl02Cg__goo1Sg_
17oo00<mkgfPOJ000gfP00<mkgooOol00Woo00<007ooOol07Woo000POol;?NnoOol5?Nl4Ool00cg_
OP1mX004OJ04Ool00`00Oomoo`0OOol0021oo``mkkeoo`Hmk`=oo`8mk`ImX0Aoo`03001oogoo01mo
o`008Goo2cg__Goo1Sg_0Woo0Sg_00=n07fPOJ000gfP17oo00<007ooOol087oo000ROol00`00?Nlm
k`08?NnlOol5?Nl4Ool00cg_OJ1mX004OJ03Ool00`00Oomoo`0QOol002=oo`Xmkk]oo`Hmk`Aoo`03
?NmmX7fP00=mX0=oo`03001oogoo029oo`0097oo2Sg_^Woo1Cg_0goo0`001GfP0Woo00<007ooOol0
8goo000TOol00`00?Nlmk`07?NniOol5?Nl01Goo00000000Ool00WfP0P000WfP00@mkgooOol002Eo
o`009Goo00<003g_?Nl023g_]goo1Cg_00<007ooOol00Woo17fP00D007fPOomoo`0002Ioo`009Woo
00<003g_?Nl023g_]Goo1Cg_00<007ooOol00Woo00<mkgfPOJ000gfP00<007oo00009goo000WOol0
0`00?Nlmk`0:?NnbOol4?Nl00`00?Nmoo`02Ool2?Nl5OJ000goo0000000WOol002Qoo`03000mkcg_
00Tmkk5oo`Dmk`03001oogoo00<mk`Im`003Ool0000002Moo`00:7oo00<007oo?Nl02Cg_/Goo13g_
00<007ooOol00cg_1gg000<007oo00009goo000YOol00`00Oolmk`09?Nn`Ool4?Nl01@00Oolmkcg_
ON001gg000@007ooOol002Moo`00:Woo00<007oo?Nl023g_[goo1Cg_10001gg000D007ooOomoo`00
02Moo`00:goo00<007oo?Nl023g_[Woo13g_00<007oo00000Wg00P001Gg017oo00<007ooOol09Goo
000/Ool00`00Oolmk`08?Nn]Ool4?Nl00`00OL000004OL001000OL1mh7gP1Goo00<007ooOol09Goo
000/Ool01000Oomoogoo23g_Zgoo13g_00D007g0OL1m`00000=m`004001m`3g_0004Ool00`00Oomo
o`0VOol002eoo`04001oogooOol8?NnZOol3?Nl30002OL001`00OL1m`7g0001oo`0000Aoo`03001o
ogoo02Moo`00;Woo00@007ooOomoo`PmkjUoo`07?Nl00000OL0007g000000Wg00P0000=mh0000000
0goo0P00:Woo000_Ool01000Oomoogoo2Cg_YWoo0Sg_00@007g0OL1m`08000=m`003ON00000000@0
02aoo`00<7oo00@007ooOomoo`XmkjAoo`03?Nl007g000=m`0<00004ON0mkgoo000aOol0035oo`03
001oogoo00`mkj5oo`8mk`03001m`7g000Am`0@0039oo`00<Woo00@007ooOomoo``mkieoo`Dmk`03
001m`7g000=m`003001oo`0003=oo`00<goo00<007ooOol03Cg_Vgoo1Sg_0P000Wg00P0000=oo`00
Ool0<goo000dOol00`00Oomoo`0=?NnHOol:?Nl20002Ool00`00Oomoo`0cOol003Eoo`04001oogoo
Ool;?NnFOol;?Nl4Ool00`00Oomoo`0dOol003Ioo`04001oogooOol;?NnDOol;?Nl4Ool00`00Oomo
o`0eOol003Moo`04001oogooOol:?NnDOol8?Nl6Ool00`00Oomoo`0fOol003Qoo`04001oogooOol:
?NnBOol9?Nl5Ool00`00Oomoo`0gOol003Uoo`80009oo`Tmki5oo`Xmk`=oo`8003Yoo`00>goo00<0
07ooOol02Cg_Sgoo2Sg_0goo00<007ooOol0>Woo000lOol00`00Oomoo`09?Nn=Ool:?Nl3Ool00`00
Oomoo`0kOol003eoo`03001oogoo00XmkhUoo`/mk`=oo`03001oogoo03aoo`00?Woo0P000Woo2Cg_
Qgoo2Cg_17oo0P00?goo0010Ool00`00Oomoo`0:?Nn3Ool;?Nl3Ool00`00Oomoo`0oOol0045oo`80
00`mkh1oo`Tmk`Aoo`80049oo`00@goo00<003g_?Nl02Sg_NGoo3Sg_17oo00<007ooOol0@Woo0014
Ool00`00?Nlmk`09?NmiOol=?Nl4Ool00`00Oomoo`13Ool004Eoo`800003Oolmkcg_00PmkgIoo``m
k`Aoo`8004Ioo`00Agoo0P002cg_Lgoo2cg_17oo0P00B7oo0019Ool00`00?Nlmk`0;?Nl00goo?Nlm
k`1/Ool<?Nl2Ool2001:Ool004]ooa0mkfUoo`/mk`Aoo`03001oogoo04Yoo`00C7oo4Cg_IWoo33g_
0Woo0P00CGoo001>Ool00`00?Nlmk`0>?NmSOol:?Nl3Ool2001?Ool0051oo`03001oocg_00lmkeio
o``mk`9oo`03001oogoo04moo`00DGoo0P004Sg_FWoo33g_00=oo`000000DWoo001COol20002OolA
?Nl8Ool5?Nm5Ool>?Nl2Ool2001DOol005Eoo`<0009ooa4mk`Aoo`Hmkcmooa@mk`8005Ioo`00F7oo
0P000goo63g_?Goo53g_00<007ooOol0Egoo001JOol20005OolD?NljOolF?NmKOol005aoo`<000Ao
oa<mkcEooaPmkeeoo`00Ggoo0P0017oo63g_9Woo7Cg_00<007ooOol0GGoo001QOol40002OolG?Nl@
Ool2?Nl=OolP?NmSOol006Eoo`<000AoobHmk`Eooalmk`04Ool00000001VOol006Qoo`@0009oodHm
k`<006Uoo`00K7oo0`0017oo?Cg_0`00KGoo001_Ool40002Oolc?Nl3Ool5001`Ool007=oo`D002Pm
k`Moo`@007Eoo`00N7oo10007cg_1Goo1`00NGoo001oOolC?Nl>0020Ool008eoo`<0008mkhioo`00
TGoo00<mkgooOol0S7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00SGoo0`00T7oo002?Ool0
0`00Oomoo`2>Ool008ioo`<008moo`00SGoo00@007ooOol008moo`00SGoo00@007ooOol008moo`00
SWoo0`00Sgoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -190.887, 1.30024, \
1.34645}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.494506 0.00265251 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(10)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.450926 scale
1.05 1.09665 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .39541 m
.08448 .39529 L
.08463 .3951 L
.08481 .39485 L
.08501 .39452 L
.08522 .39411 L
.08542 .3936 L
.08562 .39301 L
.08581 .39237 L
.08602 .39165 L
.08626 .39085 L
.08654 .38998 L
.08686 .38909 L
.08716 .38817 L
.08743 .38726 L
.08772 .38638 L
.088 .38557 L
.08829 .38475 L
.08859 .38392 L
.08891 .38306 L
.08923 .38215 L
.08951 .38126 L
.08973 .38031 L
.08987 .37931 L
.08993 .37824 L
.0899 .3772 L
.08981 .37605 L
.08971 .37491 L
.08963 .37375 L
.08956 .37252 L
.08951 .37125 L
.0895 .3701 L
.0895 .36896 L
.08949 .36789 L
.08949 .36695 L
.08952 .36612 L
.08958 .3654 L
.08969 .36477 L
.08983 .36421 L
.09 .36363 L
.09019 .363 L
.09037 .36229 L
.09055 .36147 L
.09073 .36051 L
.09096 .3594 L
.09126 .35834 L
.09164 .35708 L
.0921 .35577 L
.09264 .35422 L
.09322 .35276 L
Mistroke
.09382 .35109 L
.09442 .34925 L
.09499 .34754 L
.09554 .34577 L
.09606 .34404 L
.09658 .34234 L
.09711 .34096 L
.09765 .33957 L
.09819 .33832 L
.09867 .33726 L
.09908 .33628 L
.09941 .33549 L
.09966 .33485 L
.09987 .33437 L
.10005 .33405 L
.10024 .3339 L
.10045 .3339 L
.10063 .334 L
.10076 .33417 L
.10083 .33434 L
.10083 .33446 L
.10076 .33447 L
.10062 .33433 L
.10043 .33405 L
.10021 .33362 L
.09997 .33305 L
.09971 .33236 L
.09945 .33156 L
.09919 .33078 L
.09893 .32991 L
.09868 .32899 L
.09844 .32804 L
.09823 .32723 L
.09807 .3265 L
.09794 .32592 L
.09785 .32554 L
.09779 .3254 L
.09776 .32552 L
.09778 .32586 L
.09782 .32635 L
.09787 .3269 L
.09794 .32746 L
.09806 .32796 L
.09823 .32836 L
.09845 .32864 L
.09873 .32875 L
.09906 .3287 L
.09944 .32847 L
.09988 .32807 L
.10037 .32751 L
Mistroke
.1009 .32684 L
.10147 .32606 L
.10202 .3252 L
.10254 .3243 L
.10305 .32348 L
.10353 .32281 L
.10397 .32223 L
.10439 .32173 L
.10479 .32129 L
.10519 .32089 L
.1056 .3205 L
.10604 .32009 L
.10652 .3196 L
.10703 .31902 L
.10757 .31831 L
.10816 .31744 L
.1088 .31639 L
.10946 .31528 L
.11008 .31391 L
.1107 .31238 L
.11132 .31089 L
.11189 .30924 L
.11238 .3076 L
.11278 .30596 L
.1131 .30449 L
.11332 .30311 L
.11347 .30188 L
.11356 .30089 L
.11358 .30004 L
.11356 .29932 L
.11352 .29876 L
.11346 .29832 L
.1134 .29803 L
.11333 .29788 L
.11327 .29785 L
.11321 .29793 L
.11316 .29808 L
.11312 .29825 L
.11309 .29841 L
.11309 .29853 L
.11315 .29859 L
.11331 .29856 L
.11361 .29844 L
.11404 .29819 L
.11463 .29781 L
.11536 .29733 L
.11625 .29671 L
.11731 .29596 L
.11842 .29511 L
.11967 .2942 L
Mistroke
.12087 .29322 L
.12212 .2922 L
.12336 .29122 L
.12444 .29038 L
.12548 .28966 L
.12644 .28907 L
.12728 .28859 L
.12797 .28821 L
.12853 .2879 L
.129 .28759 L
.12937 .28726 L
.12968 .28685 L
.12996 .28636 L
.13026 .28576 L
.13061 .28506 L
.131 .28423 L
.13143 .28339 L
.13189 .28246 L
.13238 .28149 L
.13287 .2805 L
.13336 .27958 L
.13384 .27873 L
.13429 .27799 L
.1347 .27742 L
.13507 .277 L
.13539 .27669 L
.13564 .27645 L
.13582 .27623 L
.13594 .27597 L
.13603 .2756 L
.1361 .27509 L
.13619 .27444 L
.13631 .27368 L
.13647 .27284 L
.13664 .2721 L
.13684 .27109 L
.13706 .27015 L
.13727 .26912 L
.13747 .26802 L
.13764 .26685 L
.13778 .26568 L
.13789 .26447 L
.13801 .2632 L
.13814 .26188 L
.1383 .26068 L
.13846 .2593 L
.13867 .25789 L
.13892 .25641 L
.13923 .25487 L
.13964 .2532 L
Mistroke
.14014 .25178 L
.14076 .25036 L
.1415 .24897 L
.14228 .24769 L
.14313 .24651 L
.14402 .24539 L
.14494 .24428 L
.14581 .24321 L
.14671 .24211 L
.1476 .24104 L
.14857 .24 L
.14952 .23895 L
.15056 .23785 L
.15171 .23675 L
.15289 .23564 L
.15413 .23447 L
.1554 .23332 L
.15654 .23214 L
.15766 .23098 L
.15872 .22986 L
.15972 .22893 L
.16067 .22798 L
.16146 .22712 L
.16215 .22644 L
.1627 .22586 L
.16311 .22536 L
.16339 .22493 L
.16351 .22456 L
.16352 .22423 L
.16346 .22392 L
.16339 .2236 L
.16332 .22321 L
.16328 .22273 L
.16326 .22218 L
.16326 .22164 L
.16324 .22121 L
.16318 .22085 L
.16308 .22063 L
.16294 .22062 L
.16275 .22082 L
.16251 .22125 L
.16224 .22189 L
.16195 .2227 L
.16165 .22353 L
.16137 .22459 L
.1611 .22555 L
.16088 .22652 L
.16072 .2274 L
.16066 .22812 L
.16071 .22866 L
Mistroke
.16091 .22899 L
.16125 .22914 L
.16173 .22917 L
.16232 .22912 L
.16302 .22902 L
.1638 .22892 L
.16461 .22885 L
.16534 .22883 L
.16601 .22884 L
.16657 .22886 L
.16697 .22886 L
.16721 .22887 L
.16727 .22886 L
.16717 .22883 L
.16698 .22877 L
.16672 .22869 L
.16633 .22859 L
.16586 .22847 L
.16527 .22839 L
.16457 .22836 L
.1638 .22843 L
.16296 .22862 L
.16206 .22895 L
.1611 .22944 L
.16008 .23012 L
.15901 .23101 L
.15802 .23206 L
.15693 .23332 L
.15568 .23478 L
.15413 .23635 L
.15273 .2379 L
.15127 .23955 L
.14976 .24128 L
.14833 .24293 L
.14687 .24445 L
.14544 .24594 L
.14415 .24741 L
.14295 .24874 L
.14174 .25009 L
.14051 .25147 L
.13927 .25293 L
.1381 .25437 L
.137 .25591 L
.13592 .2576 L
.13488 .25945 L
.13392 .26121 L
.13302 .26318 L
.13217 .2651 L
.13136 .26706 L
.13065 .26888 L
Mistroke
.13006 .27046 L
.12958 .27188 L
.12923 .27311 L
.12897 .27403 L
.12877 .27476 L
.12859 .27534 L
.12841 .27578 L
.12819 .27612 L
.12788 .27644 L
.12747 .27676 L
.12697 .27711 L
.12639 .27748 L
.12573 .27791 L
.12509 .2784 L
.12428 .27904 L
.1235 .27975 L
.12264 .28058 L
.12172 .28153 L
.12078 .28256 L
.11987 .28367 L
.119 .28487 L
.11823 .28603 L
.11745 .28727 L
.1167 .28855 L
.11598 .28986 L
.11528 .29113 L
.11457 .29251 L
.11392 .29399 L
.11341 .29547 L
.11302 .29689 L
.11269 .29826 L
.11239 .29963 L
.11208 .30075 L
.11172 .30193 L
.11124 .30301 L
.11062 .30416 L
.10995 .30538 L
.10908 .30656 L
.10808 .30777 L
.107 .309 L
.10597 .31025 L
.10488 .31151 L
.10369 .31268 L
.10243 .31388 L
.10117 .31512 L
.10008 .31642 L
.09911 .31766 L
.09828 .31894 L
.09758 .32028 L
.09701 .32165 L
Mistroke
.09655 .32294 L
.09619 .32421 L
.09591 .32551 L
.09569 .32686 L
.09552 .32825 L
.09537 .32968 L
.09524 .33117 L
.09508 .33265 L
.0949 .33399 L
.0947 .33521 L
.09451 .33629 L
.09433 .33724 L
.09413 .33807 L
.09389 .33876 L
.09362 .33938 L
.09333 .33993 L
.09303 .34044 L
.09274 .34095 L
.09247 .3415 L
.09221 .34212 L
.09195 .34288 L
.09169 .34382 L
.09142 .34488 L
.0911 .3461 L
.09072 .34753 L
.09028 .34926 L
.0898 .35103 L
.08933 .35301 L
.08888 .35516 L
.08848 .35707 L
.08811 .35927 L
.08775 .36124 L
.08741 .36338 L
.08708 .3657 L
.08674 .36804 L
.08641 .37012 L
.0861 .37226 L
.08582 .37454 L
.08559 .37686 L
.08541 .37882 L
.08524 .38092 L
.08507 .38292 L
.08492 .38486 L
.08477 .38672 L
.08464 .38837 L
.08451 .38986 L
.08444 .39112 L
.08441 .39219 L
.0844 .39306 L
.08442 .39376 L
Mistroke
.08445 .3943 L
.08447 .39472 L
.08447 .3951 L
.08447 .3955 L
.08446 .39594 L
.08445 .39647 L
.08444 .39711 L
.08443 .39788 L
.08441 .39868 L
.08439 .39958 L
.08438 .40055 L
.08436 .40159 L
.08434 .40262 L
.08432 .40352 L
.08431 .40435 L
.0843 .40508 L
.08429 .40569 L
.08428 .40614 L
.08427 .40641 L
Mfstroke
.0843 .40614 m
.08431 .40598 L
.08431 .40577 L
.08429 .4055 L
.08426 .40515 L
.08422 .4049 L
.08421 .40449 L
.08422 .40407 L
.08427 .40359 L
.08436 .40294 L
.08451 .4023 L
.08473 .40178 L
.08498 .40107 L
.08526 .40037 L
.08553 .39961 L
.08578 .39878 L
.08603 .39778 L
.08628 .39694 L
.08654 .39607 L
.08679 .39505 L
.087 .39391 L
.08714 .39276 L
.08722 .39182 L
.08725 .39079 L
.08726 .38973 L
.08724 .38881 L
.08721 .3879 L
.0872 .38705 L
.08721 .38632 L
.08722 .38574 L
.08723 .38524 L
.08723 .38482 L
.08723 .38448 L
.08724 .38426 L
.08724 .38413 L
.08724 .38407 L
.08724 .38405 L
.08724 .38408 L
.08724 .38414 L
.08724 .38422 L
.08724 .38428 L
.08724 .3843 L
.08724 .38431 L
.08724 .38431 L
.08723 .38432 L
.08723 .38436 L
.08723 .38443 L
.08723 .38449 L
.0872 .38451 L
.08716 .38449 L
Mistroke
.08713 .38441 L
.08712 .38424 L
.08714 .38399 L
.0872 .38364 L
.08731 .38324 L
.08747 .38281 L
.08768 .38235 L
.08794 .38189 L
.08825 .38144 L
.08859 .38098 L
.08888 .38055 L
.08913 .38016 L
.08937 .37988 L
.08961 .37974 L
.08978 .37978 L
.08982 .37998 L
.08972 .3803 L
.08952 .38071 L
.08926 .3812 L
.08897 .38169 L
.08865 .38205 L
.08835 .38232 L
.08806 .38263 L
.0878 .38299 L
.0876 .38339 L
.08744 .38377 L
.08732 .38413 L
.08724 .3845 L
.08718 .38499 L
.08708 .38567 L
.08694 .38656 L
.08675 .38765 L
.08648 .38886 L
.08625 .39007 L
.08595 .39169 L
.08567 .3938 L
.08542 .3954 L
.08515 .39764 L
.08487 .39943 L
.08461 .40136 L
.0844 .40342 L
.08427 .40485 L
.08419 .40637 L
.08414 .4078 L
.08413 .40875 L
.08415 .40952 L
.08417 .41014 L
.08419 .41058 L
.08419 .41084 L
Mfstroke
.11421 .46511 m
.11439 .4652 L
.11462 .46533 L
.1149 .46549 L
.11523 .46568 L
.11562 .46591 L
.11603 .46619 L
.11655 .46657 L
.11707 .46702 L
.11765 .46757 L
.11831 .46825 L
.11899 .46899 L
.11961 .46969 L
.12027 .4705 L
.12087 .4713 L
.12145 .4721 L
.12199 .47288 L
.1225 .47361 L
.12298 .47424 L
.12341 .47479 L
.1238 .47526 L
.12411 .47564 L
.12431 .47588 L
.1244 .47602 L
.12438 .47612 L
.1243 .47628 L
.12419 .47651 L
.12409 .47683 L
.12404 .47724 L
.12408 .47773 L
.12425 .47832 L
.12456 .47895 L
.12501 .4796 L
.12557 .48025 L
.12624 .48087 L
.12696 .48141 L
.12764 .48188 L
.12833 .48224 L
.12902 .48248 L
.12975 .48261 L
.13039 .48266 L
.13097 .48266 L
.13148 .48267 L
.13191 .48274 L
.13226 .4829 L
.13254 .48315 L
.1328 .4835 L
.13303 .48386 L
.13327 .48426 L
.13349 .48467 L
Mistroke
.13369 .48506 L
.13385 .48544 L
.13396 .4858 L
.134 .48613 L
.13395 .48639 L
.13382 .48655 L
.13361 .48661 L
.13333 .4866 L
.13301 .48655 L
.13268 .48647 L
.13236 .48643 L
.13209 .48651 L
.13189 .48678 L
.13177 .48724 L
.13173 .48788 L
.13178 .48867 L
.13191 .4896 L
.13209 .49063 L
.13232 .49156 L
.13256 .49254 L
.13277 .4935 L
.13298 .49445 L
.13314 .49536 L
.13331 .49602 L
.13347 .49666 L
.13362 .49719 L
.13375 .49761 L
.13388 .49802 L
.13404 .49847 L
.13426 .49904 L
.13454 .49979 L
.13492 .50074 L
.13538 .50173 L
.13592 .50291 L
.13652 .50423 L
.13717 .50571 L
.13782 .50713 L
.13837 .50843 L
.13891 .5097 L
.13937 .51073 L
.13982 .51163 L
.14026 .51239 L
.14069 .51298 L
.14113 .5134 L
.14158 .51368 L
.14205 .51389 L
.14254 .51403 L
.143 .51414 L
.14346 .51425 L
.1439 .51437 L
Mistroke
.14438 .51454 L
.14489 .51475 L
.14538 .51497 L
.14581 .51515 L
.14613 .51527 L
.1463 .51531 L
.14632 .51524 L
.14621 .51503 L
.146 .51474 L
.14571 .51441 L
.14538 .51406 L
.14503 .51374 L
.1447 .5135 L
.14438 .51339 L
.14409 .51343 L
.14384 .51368 L
.14367 .51421 L
.14358 .51505 L
.14358 .51622 L
.14365 .51761 L
.14376 .51919 L
.14392 .52108 L
.1441 .52325 L
.14431 .52523 L
.14453 .52755 L
.14477 .52959 L
.14504 .53171 L
.1453 .53382 L
.14557 .53551 L
.14584 .53705 L
.1461 .53838 L
.14632 .53946 L
.14652 .54027 L
.1467 .54088 L
.14689 .5413 L
.14707 .54158 L
.14724 .54176 L
.14739 .54187 L
.14747 .54192 L
.1475 .54189 L
.14748 .54181 L
.14743 .54169 L
.14737 .54157 L
.14734 .54148 L
.14734 .54147 L
.14739 .54155 L
.14751 .54172 L
.1477 .54199 L
.148 .54235 L
.14841 .5428 L
Mistroke
.14893 .54332 L
.14955 .54391 L
.15027 .54454 L
.15108 .54526 L
.15192 .54604 L
.15282 .54684 L
.15376 .54764 L
.15469 .54838 L
.15554 .54908 L
.15636 .54976 L
.15712 .55041 L
.1578 .55105 L
.15838 .55168 L
.15885 .55233 L
.15922 .55302 L
.1595 .55374 L
.15969 .55445 L
.1598 .55507 L
.15984 .55558 L
.1598 .556 L
.15969 .55632 L
.15949 .5565 L
.15921 .55652 L
.15888 .55638 L
.15851 .55611 L
.15817 .55573 L
.15787 .55528 L
.15762 .5548 L
.15747 .55428 L
.15747 .55376 L
.15767 .55332 L
.15809 .55298 L
.15876 .55274 L
.15962 .55258 L
.16074 .55249 L
.16203 .55246 L
.16355 .55247 L
.16511 .55248 L
.16675 .55248 L
.16815 .55245 L
.1695 .55241 L
.17054 .55237 L
.17134 .55236 L
.17182 .55237 L
.17193 .55241 L
.17169 .55246 L
.17118 .5525 L
.17044 .55254 L
.16952 .55257 L
.1686 .55262 L
Mistroke
.16761 .55267 L
.16655 .55272 L
.16553 .55271 L
.16466 .5526 L
.16396 .55235 L
.16343 .55191 L
.16301 .55126 L
.16267 .55038 L
.16236 .54923 L
.16205 .54776 L
.16168 .54598 L
.16119 .54422 L
.16058 .54212 L
.15984 .53967 L
.15897 .53729 L
.15809 .53472 L
.15707 .53198 L
.15598 .52938 L
.1549 .52692 L
.1538 .52459 L
.15273 .52231 L
.15179 .5206 L
.15098 .51901 L
.1503 .51769 L
.14978 .51673 L
.14942 .51595 L
.14918 .51536 L
.14898 .51496 L
.14877 .5147 L
.1485 .51454 L
.1481 .51444 L
.14751 .51439 L
.1467 .51435 L
.14565 .51427 L
.14448 .51414 L
.14307 .51393 L
.14144 .51365 L
.13966 .51332 L
.13802 .51296 L
.13636 .51259 L
.13475 .51225 L
.13329 .51197 L
.13207 .5117 L
.13112 .51149 L
.13039 .51126 L
.12989 .51097 L
.1296 .51057 L
.1295 .5101 L
.12958 .50965 L
.12976 .50908 L
Mistroke
.13003 .50841 L
.13035 .50761 L
.13066 .50663 L
.13094 .50557 L
.1311 .50432 L
.1311 .50283 L
.13094 .50115 L
.13068 .49941 L
.13034 .49772 L
.12996 .49591 L
.12956 .49444 L
.12916 .49303 L
.12879 .49194 L
.12848 .49104 L
.12822 .49033 L
.12804 .48993 L
.12793 .48969 L
.12789 .48959 L
.12792 .4896 L
.12803 .48977 L
.12819 .49007 L
.12839 .49044 L
.12858 .49083 L
.12876 .49118 L
.12891 .49143 L
.12901 .49158 L
.12907 .4916 L
.12907 .49146 L
.12905 .49117 L
.12902 .49078 L
.129 .49034 L
.12901 .48988 L
.12902 .48942 L
.12904 .48897 L
.12906 .48853 L
.12908 .4881 L
.12914 .48768 L
.12928 .48732 L
.1295 .48704 L
.12972 .48689 L
.12988 .48685 L
.12994 .48688 L
.12986 .48694 L
.1296 .487 L
.12902 .48702 L
.12805 .48693 L
.12672 .48672 L
.12504 .48639 L
.12299 .48598 L
.12101 .48548 L
Mistroke
.11853 .48493 L
.1159 .48438 L
.11321 .48383 L
.11041 .48329 L
.1077 .48278 L
.10474 .48231 L
.10239 .48189 L
.10015 .4815 L
.09785 .48115 L
.09582 .48082 L
.09386 .48049 L
.09199 .48017 L
.09027 .47983 L
.08881 .4795 L
.0878 .47918 L
.08656 .47884 L
.08561 .47849 L
.08467 .4781 L
.08374 .47765 L
.08287 .47717 L
.08207 .4767 L
.08133 .47622 L
.08064 .47571 L
.08002 .47516 L
.07945 .47455 L
.07891 .47393 L
.07826 .47323 L
.07757 .47242 L
.07687 .47149 L
.0762 .47056 L
.07561 .46963 L
.07513 .46875 L
.07478 .46796 L
.07458 .46732 L
.07452 .46677 L
.07459 .46635 L
.07477 .46604 L
.07502 .46584 L
.0753 .46571 L
.07561 .46561 L
.07592 .46552 L
.0762 .4654 L
.07645 .46521 L
.07669 .46495 L
.07693 .46461 L
.07717 .4642 L
.07741 .46374 L
.07765 .46329 L
.07789 .46285 L
.07813 .46241 L
Mistroke
.07836 .462 L
.07859 .46163 L
.07883 .46133 L
.07907 .46113 L
.07933 .46101 L
.0796 .46097 L
.07984 .46099 L
.08005 .46105 L
.08021 .46112 L
Mfstroke
.08429 .40208 m
.0843 .40197 L
.08432 .40176 L
.08436 .40142 L
.08441 .40093 L
.08449 .40027 L
.08459 .39941 L
.08472 .39831 L
.08489 .39696 L
.0851 .39543 L
.08529 .39353 L
.08547 .3915 L
.08569 .38916 L
.08595 .38663 L
.08623 .38421 L
.08648 .38126 L
.08677 .37877 L
.08707 .37581 L
.08739 .3731 L
.08773 .3702 L
.08811 .36694 L
.08852 .3644 L
.08894 .36171 L
.08937 .359 L
.08979 .35626 L
.09022 .35344 L
.09066 .35128 L
.09111 .34877 L
.09157 .34648 L
.09202 .34435 L
.09246 .34226 L
.09289 .34049 L
.09331 .33883 L
.0937 .33749 L
.09406 .33635 L
.09438 .33548 L
.09467 .33478 L
.09491 .33427 L
.09511 .33395 L
.09528 .33377 L
.09541 .33369 L
.0955 .33369 L
.09555 .33376 L
.09556 .33387 L
.09555 .33398 L
.09551 .33407 L
.09546 .33412 L
.09543 .33414 L
.09542 .33415 L
.09542 .33415 L
Mistroke
.09542 .33415 L
.09542 .33415 L
.09542 .33415 L
.09542 .33415 L
.09542 .33415 L
.09542 .33415 L
.09542 .33415 L
.09543 .33417 L
.09546 .33423 L
.0955 .3343 L
.09554 .33436 L
.09556 .33439 L
.09554 .33436 L
.09548 .33426 L
.09538 .33408 L
.09522 .33381 L
.09501 .33346 L
.09475 .33301 L
.09444 .3325 L
.09413 .33196 L
.09386 .33149 L
.09361 .33111 L
.0934 .3308 L
.09326 .33057 L
.09319 .33043 L
.09322 .33039 L
.09334 .33045 L
.09354 .33058 L
.09378 .33076 L
.09407 .33095 L
.09436 .33111 L
.09467 .33123 L
.09495 .33126 L
.09518 .33117 L
.09536 .33091 L
.09548 .3305 L
.09555 .32995 L
.09558 .3293 L
.09557 .32861 L
.09554 .32793 L
.0955 .32731 L
.09546 .32677 L
.09545 .32632 L
.09545 .32596 L
.09545 .32567 L
.09545 .32544 L
.09545 .32528 L
.09545 .32518 L
.09545 .32515 L
.09545 .32518 L
Mistroke
.09545 .32524 L
.09545 .32532 L
.09545 .32537 L
.09545 .3254 L
.09545 .3254 L
.09544 .32541 L
.09541 .32543 L
.09537 .32548 L
.09533 .32554 L
.09531 .32561 L
.09532 .32564 L
.09538 .32561 L
.09548 .32552 L
.09563 .32535 L
.09583 .3251 L
.09606 .32477 L
.09631 .32439 L
.09657 .32396 L
.09684 .32352 L
.09709 .32308 L
.09735 .32265 L
.09759 .32222 L
.0978 .32182 L
.09797 .32147 L
.09809 .32118 L
.09815 .32099 L
.09817 .32088 L
.09816 .32084 L
.09812 .32086 L
.09808 .32093 L
.09805 .321 L
.09803 .32105 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .32108 L
.09803 .3211 L
.09803 .32113 L
.09801 .32118 L
.09798 .32126 L
.09793 .32134 L
.09789 .3214 L
Mistroke
.09785 .32141 L
.09783 .32135 L
.09784 .32121 L
.09792 .32093 L
.09807 .32052 L
.09829 .31998 L
.09858 .3193 L
.09895 .31853 L
.09939 .31764 L
.09989 .31666 L
.10046 .31565 L
.10108 .31459 L
.10175 .31351 L
.1024 .31247 L
.10304 .31154 L
.10364 .31069 L
.10419 .30997 L
.10464 .30938 L
.10501 .30894 L
.1053 .3086 L
.10552 .30835 L
.10567 .30818 L
.10578 .30806 L
.10585 .30799 L
.10588 .30797 L
.10588 .30798 L
.10586 .30799 L
.10582 .30801 L
.10578 .30805 L
.10574 .30808 L
.10573 .30811 L
.10573 .30812 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
Mistroke
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10573 .30813 L
.10572 .30813 L
.10571 .30813 L
.10567 .30813 L
.10563 .30812 L
.10559 .30812 L
.10555 .30812 L
.10555 .30814 L
.1056 .30817 L
.10571 .3082 L
.10587 .30823 L
.10608 .30825 L
.10634 .30826 L
.10665 .30825 L
.10698 .30822 L
.1073 .30816 L
.10761 .30808 L
.1079 .30797 L
.10819 .30781 L
.10844 .30756 L
.10868 .3072 L
.10893 .30677 L
.1092 .30626 L
.10954 .30563 L
.11003 .30496 L
.11067 .30412 L
.11139 .30315 L
.11236 .30204 L
.11344 .30086 L
.11477 .29958 L
.11614 .29822 L
.11765 .29687 L
.11913 .29555 L
.12057 .29442 L
.12169 .2934 L
.12292 .29242 L
.12389 .29161 L
.12473 .29084 L
.12541 .29005 L
.12599 .28924 L
Mistroke
.12652 .28837 L
.12703 .28738 L
.12755 .28621 L
.12811 .28486 L
.12868 .28348 L
.12916 .28203 L
.12974 .28024 L
.13035 .2785 L
.13103 .27659 L
.13162 .27456 L
.13218 .27282 L
.1327 .27108 L
.13317 .2694 L
.13362 .2678 L
.13409 .26638 L
.13461 .26502 L
.13522 .26367 L
.13591 .26228 L
.1368 .26083 L
.1378 .25954 L
.13898 .25806 L
.1403 .25653 L
.14177 .25503 L
.14326 .25341 L
.14497 .25179 L
.14637 .25021 L
.14776 .24861 L
.14917 .24713 L
.15041 .24568 L
.1516 .24438 L
.15265 .24314 L
.15369 .24195 L
.15456 .24088 L
.15538 .23984 L
.15614 .2388 L
.15684 .23771 L
.15751 .23664 L
.15809 .23549 L
.15865 .23419 L
.15917 .23281 L
.15963 .23129 L
.16007 .22961 L
.16051 .22806 L
.16097 .22622 L
.16147 .2244 L
.162 .22229 L
.16258 .22017 L
.16323 .21811 L
.16399 .21585 L
.16488 .21355 L
Mistroke
.16579 .21157 L
.16684 .20964 L
.1679 .20771 L
.16907 .20583 L
.17032 .20417 L
.17153 .20246 L
.17285 .20072 L
.17427 .19908 L
.17573 .19743 L
.17727 .19587 L
.17872 .19435 L
.18019 .193 L
.18167 .19169 L
.18304 .19045 L
.18438 .18937 L
.18567 .18837 L
.1868 .18754 L
.18786 .18683 L
.18869 .18626 L
.18937 .18588 L
.18987 .18569 L
.19018 .18566 L
.19029 .18576 L
.19023 .18593 L
.19006 .18613 L
.18986 .18629 L
.18969 .18634 L
.18961 .18621 L
.18969 .18587 L
.18996 .18529 L
.19043 .18445 L
.1911 .18333 L
.19192 .18206 L
.19287 .18048 L
.19393 .17859 L
.19497 .17675 L
.19612 .17462 L
.19748 .17211 L
.19881 .16999 L
.20025 .16784 L
.20156 .16566 L
.20281 .16363 L
.20395 .1618 L
.20494 .16039 L
.20586 .1591 L
.20672 .15811 L
.20757 .15729 L
.20838 .15662 L
.20915 .15609 L
.20987 .15566 L
Mistroke
.21052 .15533 L
.21111 .15508 L
.2117 .15491 L
.21232 .15479 L
.21302 .15472 L
.21384 .15464 L
.2148 .15452 L
.21591 .15439 L
.21715 .15426 L
.21831 .15416 L
.21958 .1541 L
.22064 .15408 L
.22178 .1541 L
.22287 .15418 L
.22376 .15432 L
.22455 .15449 L
.2252 .15468 L
.22566 .15482 L
.22595 .15488 L
.22611 .15485 L
.22622 .15468 L
.22637 .15437 L
.22667 .15388 L
.22718 .1532 L
.22795 .15229 L
.22902 .15116 L
.23027 .14993 L
.23183 .14834 L
.23354 .14665 L
.23562 .1447 L
.23751 .14257 L
.23967 .14038 L
.24197 .13813 L
.24385 .13599 L
.24582 .1339 L
.24764 .13198 L
.24917 .13036 L
.25055 .12887 L
.25172 .12756 L
.25268 .12652 L
.2535 .12567 L
.2542 .12505 L
.25482 .12465 L
.2554 .12445 L
.25596 .12439 L
.25655 .12444 L
.25716 .12455 L
.25782 .12468 L
.25848 .12481 L
.2591 .12492 L
Mistroke
.25968 .12502 L
.26023 .12509 L
.26073 .12512 L
.26118 .12511 L
.26158 .12508 L
.26192 .12502 L
.26219 .12494 L
.26243 .12488 L
.26263 .12482 L
.26281 .1248 L
.26299 .12481 L
.26318 .12483 L
.26336 .12503 L
.26357 .12498 L
.2638 .12487 L
.26401 .12474 L
.2642 .1246 L
.26435 .12447 L
.26444 .12433 L
.26448 .12417 L
.26445 .12397 L
.2644 .12377 L
.26433 .12352 L
.26428 .12326 L
.26426 .12297 L
.2643 .12263 L
.26442 .12233 L
.26459 .12206 L
.26482 .12183 L
.26509 .12158 L
.2654 .12131 L
.26574 .12103 L
.26614 .12074 L
.26659 .12046 L
.26711 .12018 L
.26769 .11991 L
.26835 .11962 L
.26908 .11932 L
.2699 .11902 L
.27079 .11867 L
.27171 .11826 L
.27271 .11782 L
.27375 .11736 L
.27486 .11693 L
.27599 .11653 L
.27713 .11616 L
.27823 .11581 L
.27929 .11549 L
.28021 .11524 L
.28101 .11507 L
Mistroke
.28164 .11499 L
.28213 .11496 L
.2825 .11494 L
.28282 .11489 L
.2831 .11476 L
.2834 .11453 L
.28371 .11417 L
.28406 .11368 L
.28443 .1131 L
.28484 .11247 L
.28527 .11187 L
.28567 .11124 L
.28606 .11061 L
.28641 .11008 L
.28674 .10961 L
.28704 .10922 L
.28733 .10892 L
.28763 .10872 L
.28797 .10857 L
.28838 .10844 L
.28888 .10828 L
.28949 .10804 L
.29027 .10769 L
.29119 .10722 L
.29234 .10662 L
.29363 .10595 L
.29508 .10519 L
.29673 .10438 L
.29829 .10356 L
.2999 .10275 L
.30149 .10203 L
.30304 .10135 L
.30451 .10073 L
.30593 .10015 L
.30734 .09961 L
.30871 .09906 L
.31011 .09849 L
.31151 .09785 L
.31295 .09707 L
.31441 .09615 L
.31575 .09517 L
.31712 .09401 L
.31839 .09267 L
.31963 .09129 L
.32086 .08981 L
.32204 .08839 L
.32322 .0869 L
.32441 .08549 L
.32557 .08415 L
.3268 .08278 L
Mistroke
.32809 .08163 L
.32955 .08051 L
.33115 .07942 L
.33301 .07833 L
.33497 .07732 L
.33703 .07627 L
.33929 .07526 L
.34171 .07425 L
.34402 .07324 L
.34627 .07223 L
.34837 .07131 L
.35013 .07045 L
.35198 .0697 L
.35372 .06909 L
.35535 .06867 L
.357 .06842 L
.35864 .06833 L
.36036 .06837 L
.3621 .06852 L
.36373 .06874 L
.36507 .06902 L
.36639 .06934 L
.36752 .06965 L
.36866 .06994 L
.3698 .07019 L
.37083 .07038 L
.37162 .07052 L
.37213 .07059 L
.3724 .07063 L
.37248 .07064 L
.37239 .07064 L
.37215 .07063 L
.37187 .07062 L
.37164 .07061 L
.37149 .07062 L
.37144 .07062 L
.37152 .07059 L
.37174 .07052 L
.37215 .07037 L
.37273 .07011 L
.37349 .06972 L
.37441 .06919 L
.37547 .06855 L
.37653 .06779 L
.37768 .06694 L
.37893 .06603 L
.38029 .06518 L
.38158 .06426 L
.3829 .06329 L
.38423 .06245 L
Mistroke
.38549 .06163 L
.38673 .0609 L
.38794 .06025 L
.38922 .05972 L
.39063 .0593 L
.39215 .05901 L
.39379 .05881 L
.39563 .0587 L
.39765 .05864 L
.39964 .05859 L
.40168 .05857 L
.40377 .05855 L
.40572 .05856 L
.40759 .05861 L
.40932 .05866 L
.41083 .05875 L
.41223 .05884 L
.41344 .05892 L
.41439 .05898 L
.41502 .05903 L
.41534 .05906 L
.41535 .05908 L
.41509 .05909 L
.41462 .05909 L
.41401 .05908 L
.41332 .05905 L
.41259 .05902 L
.41187 .05899 L
.41115 .05897 L
.41044 .05895 L
.40976 .05893 L
.40915 .05892 L
.40868 .0589 L
.40836 .0589 L
.40818 .05889 L
.40812 .05889 L
.40815 .05889 L
.40825 .05889 L
.40836 .05889 L
.40843 .05888 L
.40843 .05883 L
.40838 .05875 L
.40831 .05865 L
.40825 .05858 L
.40825 .05854 L
.40831 .05856 L
.40845 .05868 L
.40868 .05892 L
.40899 .05932 L
.40936 .05987 L
Mistroke
.40979 .06056 L
.41025 .0614 L
.41071 .06229 L
.41119 .06331 L
.41167 .06433 L
.41214 .06536 L
.41257 .06634 L
.41293 .06717 L
.4132 .06774 L
.41335 .06808 L
.41338 .06818 L
.41329 .06805 L
.41312 .06767 L
.41291 .06707 L
.4127 .06639 L
.41252 .06558 L
.41237 .06475 L
.41223 .0639 L
.41207 .06314 L
.41187 .06243 L
.4116 .0618 L
.41123 .06128 L
.41073 .06088 L
.41009 .06062 L
.4093 .06049 L
.40827 .06046 L
.40705 .06047 L
.40557 .06049 L
.40385 .06049 L
.40185 .06045 L
.39968 .06034 L
.39749 .06018 L
.39513 .05999 L
.39288 .05979 L
.39078 .05958 L
.38872 .05937 L
.38671 .05917 L
.38508 .05896 L
.38356 .05873 L
.38216 .05849 L
.38084 .05825 L
.3796 .05801 L
.37838 .0578 L
.37719 .05765 L
.37599 .05756 L
.37468 .05755 L
.37324 .05764 L
.37181 .05786 L
.37028 .05819 L
.36857 .05861 L
Mistroke
.36675 .05911 L
.36496 .05968 L
.36339 .06034 L
.36187 .06108 L
.36043 .06185 L
.35912 .06255 L
.35797 .06323 L
.35701 .064 L
.3562 .0647 L
.35548 .06541 L
.35481 .06615 L
.35418 .06683 L
.35358 .06756 L
.35297 .06832 L
.35235 .06911 L
.35175 .06991 L
.3512 .07071 L
.35073 .07145 L
.35029 .07214 L
.34987 .07278 L
.34946 .07337 L
.34912 .07383 L
.34886 .07417 L
.34868 .07437 L
.34858 .07449 L
.34855 .07452 L
.34858 .07447 L
.34865 .07436 L
.34872 .07423 L
.34876 .07414 L
.34878 .07408 L
.34879 .07403 L
.34881 .074 L
.34883 .07395 L
.34887 .07388 L
.3489 .07378 L
.34894 .07365 L
.34899 .0735 L
.34905 .07335 L
.34911 .07319 L
.34918 .07305 L
.34927 .07293 L
.34936 .07284 L
.34941 .07279 L
.34937 .07276 L
.34922 .07273 L
.34895 .07271 L
.34853 .07273 L
.34796 .07281 L
.34725 .07297 L
Mistroke
.34643 .07316 L
.34548 .07345 L
.34445 .0738 L
.34332 .07419 L
.3422 .07458 L
.34098 .07496 L
.33965 .07535 L
.33827 .07574 L
.33688 .07616 L
.33543 .07663 L
.33399 .07718 L
.33252 .0778 L
.33098 .07848 L
.32938 .07923 L
.32786 .08003 L
.32632 .08091 L
.32467 .08185 L
.32301 .08278 L
.32146 .08373 L
.31995 .08469 L
.31854 .08561 L
.31731 .08642 L
.31616 .08714 L
.31511 .08772 L
.31417 .08815 L
.3134 .08842 L
.31274 .08857 L
.31217 .08866 L
.31166 .08875 L
.31119 .0889 L
.31075 .08913 L
.31029 .0895 L
.30991 .08993 L
.30946 .09055 L
.30895 .09136 L
.30839 .09232 L
.30776 .09334 L
.30702 .09455 L
.30622 .09588 L
.30536 .09716 L
.30449 .0984 L
.30363 .09958 L
.30281 .10065 L
.30206 .1016 L
.30139 .10242 L
.30082 .10315 L
.30036 .10381 L
.3 .10441 L
.29976 .10496 L
.29962 .10549 L
Mistroke
.29956 .10599 L
.29955 .10645 L
.29959 .10686 L
.29969 .10717 L
.29983 .10742 L
.29997 .10765 L
.30009 .10791 L
.30018 .10817 L
.30023 .10842 L
.30021 .1087 L
.3001 .10905 L
.29986 .10951 L
.29946 .11007 L
.29887 .11075 L
.29809 .11155 L
.29712 .11247 L
.29606 .11338 L
.29488 .11438 L
.29364 .11539 L
.29246 .11642 L
.29136 .1173 L
.29026 .11808 L
.28914 .11872 L
.28817 .11919 L
.28729 .11949 L
.28651 .11963 L
.28582 .11965 L
.28527 .11959 L
.28485 .1195 L
.28454 .11942 L
.28431 .11934 L
.2841 .11927 L
.28386 .11922 L
.28357 .11918 L
.28323 .11912 L
.28288 .11906 L
.28256 .11899 L
.28231 .11892 L
.28216 .11886 L
.28211 .11881 L
.28214 .11877 L
.28217 .11875 L
.28218 .11874 L
.2822 .11875 L
.28224 .11878 L
.28234 .1188 L
.28253 .11887 L
.28278 .11895 L
.28305 .11904 L
.28329 .11913 L
Mistroke
.28348 .1192 L
.28357 .11925 L
.28352 .11928 L
.28332 .11925 L
.283 .11919 L
.28258 .11907 L
.28208 .11889 L
.28149 .11863 L
.2808 .11832 L
.28015 .11797 L
.27937 .11765 L
.27855 .11736 L
.27771 .11713 L
.27693 .11697 L
.2762 .11688 L
.27557 .11685 L
.27503 .11687 L
.27464 .11697 L
.27433 .11712 L
.27414 .11731 L
.27404 .11756 L
.27399 .11782 L
.27398 .11805 L
.27397 .11822 L
.2739 .11835 L
.27374 .11841 L
.27344 .11844 L
.27298 .11847 L
.27239 .11858 L
.27165 .11884 L
.27077 .1193 L
.26982 .11996 L
.26885 .12077 L
.26782 .12169 L
.26673 .12262 L
.26564 .1234 L
.26461 .12418 L
.26366 .1249 L
.26283 .12556 L
.26212 .12604 L
.26153 .1264 L
.26105 .12661 L
.26066 .12669 L
.26036 .12657 L
.26016 .1263 L
.26005 .12592 L
.26001 .12551 L
.26001 .12515 L
.26 .12489 L
.25996 .12473 L
Mistroke
.25982 .12469 L
.2595 .12478 L
.25897 .12501 L
.25824 .12533 L
.25729 .12573 L
.25609 .12621 L
.25485 .12676 L
.25335 .12738 L
.25173 .128 L
.25011 .12866 L
.24837 .12933 L
.24663 .13001 L
.24495 .13069 L
.24342 .13136 L
.24187 .13208 L
.24032 .13285 L
.23884 .13365 L
.23745 .1345 L
.23627 .13536 L
.23503 .1363 L
.23384 .13732 L
.23274 .13835 L
.23171 .13949 L
.23069 .14078 L
.22976 .14205 L
.2289 .14339 L
.22815 .14471 L
.22752 .14592 L
.22702 .14694 L
.22666 .1477 L
.2264 .14825 L
.22621 .14856 L
.22606 .14866 L
.22596 .14855 L
.22588 .14828 L
.22583 .14794 L
.22581 .14758 L
.22582 .14725 L
.22587 .147 L
.22593 .14688 L
.226 .14698 L
.22606 .14734 L
.2261 .14796 L
.22615 .14876 L
.22621 .1496 L
.22629 .15066 L
.22635 .15158 L
.22641 .15246 L
.22643 .15322 L
.22644 .15378 L
Mistroke
.22643 .15412 L
.22638 .15425 L
.22626 .15421 L
.22604 .15406 L
.22572 .15385 L
.22528 .1536 L
.22469 .15337 L
.22395 .15318 L
.22303 .15304 L
.22194 .15295 L
.22068 .15291 L
.21923 .15295 L
.21761 .15311 L
.21608 .15341 L
.21438 .15384 L
.21244 .15441 L
.21033 .15513 L
.20831 .15598 L
.2064 .15699 L
.20437 .15816 L
.20236 .15941 L
.20037 .16089 L
.19858 .16256 L
.19669 .16435 L
.19513 .16615 L
.19357 .16814 L
.19193 .17013 L
.1904 .17231 L
.18885 .17431 L
.18731 .17641 L
.18579 .17858 L
.18455 .18043 L
.18327 .18239 L
.18215 .18426 L
.18116 .18602 L
.18018 .18781 L
.17933 .18923 L
.1786 .19061 L
.17803 .19197 L
.17762 .19329 L
.17738 .19453 L
.1773 .19557 L
.17733 .19656 L
.17743 .19743 L
.17754 .19815 L
.17764 .19869 L
.17772 .19907 L
.17776 .19932 L
.17776 .19946 L
.17773 .19948 L
Mistroke
.17769 .1994 L
.17763 .19916 L
.17756 .19878 L
.1775 .19832 L
.17748 .19784 L
.17754 .19737 L
.1777 .19694 L
.17796 .19657 L
.17834 .19633 L
.17882 .19624 L
.17939 .19626 L
.18001 .19633 L
.18072 .19641 L
.18148 .19648 L
.18229 .19654 L
.18307 .1966 L
.18386 .19663 L
.18461 .19666 L
.18531 .19667 L
.1859 .19669 L
.18639 .1967 L
.18675 .19671 L
.18702 .19672 L
.18722 .19672 L
.18737 .19672 L
.18748 .19673 L
.18756 .19673 L
.18764 .19673 L
.18768 .19673 L
.1877 .19673 L
.18768 .19673 L
.18764 .19673 L
.1876 .19673 L
.18757 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
Mistroke
.18755 .19673 L
.18755 .19673 L
.18755 .19673 L
.18753 .19673 L
.1875 .19673 L
.18746 .19673 L
.18743 .19673 L
.18741 .19673 L
.18742 .19673 L
.18748 .19673 L
.18757 .19673 L
.18772 .19673 L
.1879 .19674 L
.18812 .19674 L
.18836 .19675 L
.18861 .19676 L
.18886 .19677 L
.18912 .1968 L
.18935 .19686 L
.18954 .19694 L
.18968 .19703 L
.18978 .19711 L
.18983 .19716 L
.18985 .19714 L
.18985 .19703 L
.18987 .19682 L
.18992 .19649 L
.19007 .19605 L
.19035 .19548 L
.19077 .19477 L
.19134 .19394 L
.19203 .19295 L
.19288 .19176 L
.19388 .19036 L
.19502 .18889 L
.19629 .18728 L
.19761 .18563 L
.19898 .18395 L
.20035 .18244 L
.20161 .18098 L
.2028 .17966 L
.20379 .1786 L
.20468 .17759 L
.20543 .17677 L
.20609 .17603 L
.20655 .17556 L
.20691 .17522 L
.20713 .17504 L
.20724 .17501 L
.20727 .17507 L
Mistroke
.20725 .17519 L
.20719 .1753 L
.20711 .17539 L
.20702 .17546 L
.20695 .1755 L
.20692 .17551 L
.20692 .17552 L
.20693 .17554 L
.20693 .1756 L
.20693 .17567 L
.20691 .17576 L
.20688 .17586 L
.20683 .17593 L
.20677 .17597 L
.20672 .1759 L
.2067 .17568 L
.20674 .17529 L
.20685 .17472 L
.20704 .17392 L
.20732 .17289 L
.20767 .17176 L
.20809 .17039 L
.20855 .1688 L
.20901 .16726 L
.2095 .16558 L
.20998 .16379 L
.21039 .16229 L
.21074 .16087 L
.21105 .15956 L
.21129 .15844 L
.21145 .15758 L
.21158 .15693 L
.21172 .15648 L
.21189 .15617 L
.21213 .15592 L
.21248 .15571 L
.21297 .15549 L
.21362 .15523 L
.21436 .15492 L
.21528 .15456 L
.21627 .15412 L
.2174 .15357 L
.21865 .15289 L
.21981 .15208 L
.22104 .15124 L
.22235 .15036 L
.22363 .14948 L
.22494 .14862 L
.22621 .14779 L
.22753 .14704 L
Mistroke
.22878 .14629 L
.23007 .14553 L
.23132 .1448 L
.23259 .14408 L
.23379 .14339 L
.23489 .14272 L
.23596 .14211 L
.23694 .14156 L
.23779 .14112 L
.23853 .14074 L
.23916 .14041 L
.23965 .14012 L
.24002 .13985 L
.2403 .13962 L
.24049 .13946 L
.24062 .13937 L
.24069 .13935 L
.24073 .13938 L
.24074 .13946 L
.24072 .13955 L
.24067 .13966 L
.24057 .13976 L
.24045 .13985 L
.24031 .13991 L
.2402 .13993 L
.24016 .13989 L
.24022 .13975 L
.2404 .1395 L
.24072 .13911 L
.2412 .13858 L
.24185 .13791 L
.24266 .13711 L
.2436 .13627 L
.24451 .13533 L
.24559 .13434 L
.24661 .13335 L
.2477 .13239 L
.24858 .13149 L
.24945 .13073 L
.25028 .13008 L
.25103 .12956 L
.25166 .1292 L
.25225 .12898 L
.25283 .12891 L
.25346 .12896 L
.25416 .12906 L
.25496 .12914 L
.25584 .12918 L
.25675 .12915 L
.2577 .12905 L
Mistroke
.25874 .12889 L
.25992 .12868 L
.26117 .12848 L
.26246 .12834 L
.26376 .12827 L
.26507 .12823 L
.26635 .12822 L
.26759 .12823 L
.2688 .12827 L
.26987 .12833 L
.27089 .12844 L
.27182 .12858 L
.2726 .12873 L
.2732 .12885 L
.27365 .12892 L
.27398 .12891 L
.27419 .1288 L
.27433 .12857 L
.27444 .12816 L
.27453 .1276 L
.27464 .12701 L
.2748 .12635 L
.27503 .12568 L
.27533 .125 L
.27565 .12433 L
.27603 .12368 L
.27646 .12309 L
.27695 .12255 L
.27745 .12208 L
.27793 .12173 L
.27836 .1215 L
.27872 .12139 L
.27903 .12137 L
.27929 .12141 L
.27953 .12147 L
.27978 .1215 L
.28007 .12144 L
.28041 .12126 L
.28081 .1209 L
.28126 .12032 L
.2818 .11948 L
.28244 .11846 L
.28315 .11715 L
.28403 .11572 L
.28499 .11407 L
.28612 .11227 L
.28742 .11041 L
.28888 .1086 L
.29057 .10672 L
.2922 .10505 L
Mistroke
.29406 .10332 L
.29577 .10188 L
.29772 .10047 L
.29967 .09925 L
.30176 .09812 L
.30398 .09705 L
.30609 .09604 L
.30825 .09514 L
.3104 .09423 L
.31248 .09327 L
.31458 .09223 L
.31668 .09115 L
.31875 .08993 L
.32101 .08854 L
.32313 .08709 L
.32538 .08554 L
.32775 .08395 L
.32997 .08223 L
.33231 .0806 L
.33478 .07888 L
.3371 .07713 L
.33952 .07564 L
.34202 .07418 L
.34432 .07275 L
.34663 .07147 L
.34879 .07034 L
.35084 .0693 L
.35252 .06839 L
.35404 .06757 L
.3553 .06684 L
.35635 .06622 L
.35715 .06567 L
.35774 .06523 L
.35814 .06483 L
.35837 .06449 L
.35845 .06421 L
.35841 .06399 L
.35829 .06381 L
.35813 .06369 L
.35797 .06362 L
.35781 .06361 L
.35768 .06365 L
.35761 .06371 L
.35761 .06379 L
.35771 .06384 L
.35794 .06387 L
.35833 .06387 L
.35891 .06388 L
.35969 .06388 L
.36066 .06389 L
Mistroke
.36184 .06392 L
.36321 .06399 L
.36453 .06408 L
.36596 .06418 L
.36731 .06424 L
.3687 .06426 L
.36985 .06422 L
.37092 .06409 L
.37191 .06387 L
.37271 .06358 L
.37341 .06322 L
.37404 .06283 L
.37462 .06241 L
.37517 .06199 L
.37568 .06158 L
.37616 .06117 L
.37666 .0608 L
.37722 .06047 L
.37784 .0602 L
.37848 .05999 L
.37912 .05987 L
.37968 .05982 L
.38018 .05983 L
.3806 .05991 L
.38095 .06005 L
.38122 .06024 L
.38142 .06047 L
.38158 .06075 L
.38178 .06106 L
.38202 .06133 L
.3823 .06154 L
.3826 .06168 L
.38294 .06175 L
.3833 .06182 L
.38366 .06189 L
.38403 .06198 L
.38441 .06209 L
.3848 .06221 L
.38525 .0623 L
.38579 .06238 L
.38641 .06245 L
.3872 .06254 L
.38798 .06269 L
.38898 .06296 L
.39016 .06337 L
.39139 .06391 L
.39285 .06453 L
.39439 .0652 L
.39621 .06586 L
.39826 .06648 L
Mistroke
.40015 .06704 L
.40225 .0675 L
.40436 .06793 L
.40648 .06833 L
.4087 .06873 L
.41075 .06911 L
.41277 .06946 L
.41472 .06974 L
.41647 .06995 L
.4182 .07006 L
.41971 .07007 L
.42102 .06996 L
.42201 .06977 L
.42277 .06952 L
.4233 .06924 L
.42368 .06895 L
.42394 .06865 L
.42415 .06833 L
.42439 .06796 L
.42474 .06755 L
.42526 .06707 L
.42598 .06651 L
.42689 .06589 L
.42794 .06517 L
.4292 .06456 L
.43065 .0639 L
.43227 .06326 L
.43392 .06271 L
.43556 .06217 L
.43721 .06163 L
.43852 .06113 L
.43969 .06064 L
.44058 .06021 L
.4413 .05987 L
.44182 .05964 L
.44214 .05952 L
.44237 .05952 L
.44262 .05957 L
.44298 .05965 L
.44348 .05973 L
.44419 .05979 L
.44513 .05984 L
.44633 .05988 L
.44759 .05992 L
.44929 .05999 L
.45106 .06008 L
.45309 .06022 L
.45538 .06039 L
.45752 .0606 L
.45987 .06083 L
Mistroke
.46208 .06108 L
.46425 .06135 L
.46633 .06161 L
.46818 .06183 L
.46987 .06202 L
.47139 .06217 L
.47267 .0623 L
.4738 .06243 L
.47474 .06258 L
.47546 .06275 L
.47597 .06296 L
.47629 .06323 L
.47646 .06354 L
.47651 .0639 L
.47648 .06431 L
.4764 .06473 L
.4763 .06516 L
.47621 .06561 L
.47613 .06605 L
.47602 .06644 L
.47589 .06675 L
.47574 .06693 L
.4756 .06696 L
.47553 .06685 L
.47556 .06659 L
.47572 .06625 L
.47605 .06583 L
.47658 .06542 L
.47734 .06499 L
.47836 .06461 L
.47955 .06423 L
.48106 .06389 L
.48255 .06358 L
.48442 .06333 L
.48635 .06312 L
.48826 .06293 L
.49045 .06273 L
.4927 .06249 L
.49499 .06221 L
.49727 .0619 L
.49946 .06151 L
.50154 .06111 L
.50359 .06065 L
.50529 .06017 L
.50682 .05969 L
.5083 .05925 L
.5095 .05882 L
.51055 .05842 L
.51133 .05802 L
.51191 .05774 L
Mistroke
.51228 .05753 L
.51246 .05743 L
.51246 .05745 L
.51231 .05758 L
.51205 .0578 L
.51174 .05808 L
.51145 .0584 L
.51122 .05875 L
.51105 .05912 L
.51093 .05952 L
.51085 .05992 L
.5108 .06033 L
.5108 .06075 L
.51085 .06108 L
.51094 .06138 L
.51109 .06161 L
.5113 .06177 L
.51157 .06186 L
.51188 .0619 L
.51222 .06193 L
.5126 .06196 L
.51296 .062 L
.5133 .06204 L
.51357 .06208 L
.51374 .06205 L
.51382 .06196 L
.51382 .0618 L
.51377 .06155 L
.51369 .06124 L
.51354 .06088 L
.51332 .0605 L
.51302 .0601 L
.51267 .05971 L
.51226 .05931 L
.51181 .05888 L
.51133 .05844 L
.51085 .058 L
.51035 .05762 L
.50986 .0573 L
.50938 .05704 L
.50895 .05684 L
.50856 .05666 L
.50813 .05647 L
.50769 .05624 L
.50719 .05598 L
.50664 .05567 L
.50599 .05531 L
.50521 .05495 L
.50418 .05461 L
.50285 .05433 L
Mistroke
.5012 .05404 L
.49914 .05378 L
.49694 .05354 L
.49431 .05332 L
.49146 .0531 L
.48856 .05289 L
.48527 .0527 L
.48253 .05255 L
.47911 .05245 L
.47637 .0524 L
.47295 .05237 L
.47022 .05232 L
.46738 .05225 L
.46439 .05217 L
.4618 .0521 L
.45899 .05201 L
.45596 .05191 L
.4534 .05178 L
.45009 .05163 L
.44739 .05148 L
.44436 .05136 L
.44077 .05129 L
.43764 .05128 L
.43413 .05135 L
.43076 .05149 L
.42708 .05172 L
.42413 .05201 L
.42105 .05236 L
.41822 .05275 L
.41552 .05315 L
.4132 .05355 L
.41119 .05391 L
.40942 .05419 L
.40808 .05436 L
.40702 .05442 L
.40624 .05436 L
.4057 .0542 L
.4054 .05398 L
.40528 .05373 L
.40531 .05347 L
.40542 .05327 L
.4056 .05312 L
.40578 .05305 L
.40592 .05304 L
.40603 .05308 L
.40611 .05319 L
.40616 .05336 L
.40619 .05361 L
.40623 .05384 L
.40624 .05411 L
Mistroke
.40625 .05435 L
.40624 .05455 L
.40623 .05467 L
.40625 .05473 L
.40633 .05474 L
.40643 .05473 L
.40653 .05472 L
.40658 .0547 L
.40654 .05465 L
.4064 .05459 L
.40613 .05452 L
.40573 .05447 L
.40521 .05446 L
.4046 .0545 L
.40393 .05459 L
.40323 .05475 L
.40256 .05496 L
.40196 .05525 L
.40134 .05559 L
.4007 .05597 L
.40009 .05637 L
.39961 .05676 L
.3993 .05718 L
.39914 .05753 L
.39908 .0579 L
.3991 .05823 L
.39919 .05848 L
.3993 .05866 L
.39936 .05876 L
.39937 .0588 L
.39934 .05879 L
.39931 .05876 L
.39927 .05872 L
.39925 .05869 L
.39927 .05867 L
.39931 .05865 L
.39941 .05865 L
.39954 .05865 L
.39971 .05865 L
.39992 .05866 L
.40014 .05867 L
.40038 .05867 L
.40061 .05868 L
.40085 .05869 L
.40107 .05871 L
.40128 .05876 L
.40147 .05881 L
.40162 .05885 L
.40173 .05888 L
.4018 .05888 L
Mistroke
.40181 .05883 L
.40179 .05871 L
.40174 .0585 L
.40168 .0582 L
.40162 .05783 L
.40158 .05745 L
.40156 .05709 L
.40155 .05675 L
.40155 .05651 L
.40155 .05638 L
.40156 .05635 L
.40158 .05636 L
.40159 .05642 L
.40161 .05654 L
.40162 .05675 L
.40164 .05702 L
.40168 .05734 L
.40171 .05767 L
.40177 .05801 L
.40186 .05831 L
.40199 .05855 L
.40218 .05869 L
.4024 .05876 L
.40268 .05877 L
.40302 .05873 L
.40337 .05869 L
.40377 .05868 L
.40418 .05871 L
.40459 .05876 L
.40499 .05881 L
.40535 .05884 L
.40566 .05886 L
.40592 .05887 L
.40613 .05886 L
.40628 .05885 L
.40636 .05884 L
.40638 .05884 L
.40637 .05884 L
.40634 .05884 L
.40631 .05884 L
.40627 .05884 L
.40624 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
Mistroke
.40622 .05884 L
.40622 .05884 L
.40622 .05884 L
.40621 .05884 L
.40618 .05884 L
.40614 .05883 L
.40611 .05883 L
.40609 .05883 L
.4061 .05883 L
.40615 .05884 L
.40623 .05884 L
.40636 .05886 L
.40652 .05888 L
.40669 .05889 L
.40688 .05889 L
.40708 .05887 L
.4073 .05884 L
.40755 .05881 L
.40784 .05877 L
.40816 .05875 L
.40851 .05874 L
.40885 .05873 L
.40915 .05871 L
.40939 .05867 L
.40958 .05863 L
.40972 .05859 L
.40983 .05856 L
.40993 .05854 L
.41003 .05854 L
.41013 .05856 L
.41023 .0586 L
.41031 .05865 L
.41036 .0587 L
.41039 .05873 L
.41039 .05876 L
.41041 .0588 L
.41048 .05885 L
.41059 .05895 L
.41074 .05906 L
.41087 .05915 L
.41094 .05918 L
.41092 .05912 L
.41077 .05897 L
.41049 .05873 L
.41008 .05839 L
.40959 .05798 L
.40909 .05753 L
.40862 .05709 L
.40822 .05665 L
.40788 .05622 L
Mistroke
.40756 .0558 L
.4073 .05541 L
.40712 .05506 L
.40704 .05478 L
.40708 .05459 L
.4072 .05449 L
.40741 .05446 L
.40766 .05449 L
.40795 .05456 L
.40822 .05464 L
.40843 .0547 L
.40855 .05472 L
.40861 .05472 L
.40862 .05472 L
.40861 .05472 L
.40857 .05472 L
.40854 .05473 L
.40851 .05474 L
.40849 .05474 L
.40849 .05475 L
.40849 .05476 L
.40849 .05477 L
.40849 .05477 L
.40849 .05477 L
.40849 .05477 L
.40849 .05477 L
.40849 .05477 L
.40849 .05477 L
.40849 .05476 L
.40849 .05476 L
.40849 .05475 L
.40849 .05474 L
.40849 .05473 L
.40849 .05472 L
.40849 .05472 L
.40849 .05472 L
.40849 .05472 L
.40849 .05472 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
Mistroke
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.40849 .05473 L
.4085 .05473 L
.40852 .05474 L
.40853 .05474 L
.40854 .05473 L
.40852 .05472 L
.40849 .05472 L
.40845 .0547 L
.40839 .05469 L
.40834 .05468 L
.40829 .05467 L
.40824 .05467 L
.40821 .05466 L
.40819 .05466 L
.40818 .05466 L
.40819 .05467 L
.40822 .05467 L
.40826 .05468 L
.40831 .05469 L
.40835 .0547 L
.40836 .05471 L
.40836 .05471 L
.40832 .05471 L
.40827 .0547 L
.40821 .0547 L
.40814 .05469 L
.40807 .05468 L
Mistroke
.408 .05467 L
.40796 .05467 L
.40794 .05467 L
.40793 .05467 L
.40791 .05467 L
.40792 .05468 L
.40795 .05469 L
.40802 .05469 L
.40813 .05471 L
.40828 .05472 L
.40846 .05473 L
.40867 .05474 L
.40889 .05474 L
.4091 .05475 L
.40931 .05475 L
.40952 .05476 L
.40973 .05476 L
.40995 .05477 L
.41018 .05477 L
.41039 .05478 L
.41057 .05479 L
.41072 .05479 L
.41082 .05479 L
.41088 .0548 L
.41089 .0548 L
.41088 .0548 L
.41085 .05479 L
.41081 .05479 L
.41078 .05479 L
.41077 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41077 .05479 L
.41078 .05479 L
.41083 .05479 L
.4109 .0548 L
Mistroke
.41096 .0548 L
.41099 .0548 L
.41097 .0548 L
.41088 .0548 L
.41071 .05479 L
.41044 .05478 L
.41009 .05477 L
.40968 .05476 L
.40924 .05475 L
.40877 .05473 L
.40832 .05472 L
.40788 .05471 L
.40744 .05469 L
.407 .05468 L
.4066 .05467 L
.40627 .05466 L
.40603 .05465 L
.40589 .05465 L
.40586 .05465 L
.40593 .05465 L
.40608 .05466 L
.40628 .05466 L
.4065 .05467 L
.40673 .05468 L
.40696 .05468 L
.4072 .05469 L
.40744 .0547 L
.40767 .0547 L
.4079 .05471 L
.40811 .05472 L
.4083 .05472 L
.40844 .05473 L
.40855 .05473 L
.4086 .05474 L
.40862 .05473 L
.40861 .05473 L
.4086 .05472 L
.40858 .05471 L
.40855 .05471 L
.40853 .0547 L
.40849 .05469 L
.40845 .05469 L
.40839 .05469 L
.40834 .0547 L
.40828 .05472 L
.40824 .05472 L
.40821 .05471 L
.40819 .05469 L
.40818 .05466 L
.40816 .05463 L
Mistroke
.40814 .0546 L
.40812 .05456 L
.40811 .05454 L
.40814 .05452 L
.40821 .05451 L
.40831 .05451 L
.40846 .05451 L
.40865 .05452 L
.40885 .05453 L
.40907 .05456 L
.40929 .05459 L
.40951 .05464 L
.40972 .05468 L
.40995 .05473 L
.41018 .05477 L
.41039 .05481 L
.41057 .05483 L
.41072 .05483 L
.41082 .05482 L
.41088 .0548 L
.41089 .0548 L
.41088 .0548 L
.41085 .05479 L
.41081 .05479 L
.41078 .05479 L
.41077 .05479 L
.41076 .05479 L
.41076 .05479 L
.41076 .05479 L
.41077 .05477 L
.41079 .05472 L
.41081 .05466 L
.41081 .0546 L
.4108 .05457 L
.41077 .05459 L
.41072 .05467 L
.41067 .05484 L
.41061 .05508 L
.41056 .0554 L
.41052 .05577 L
.41049 .05618 L
.41047 .0566 L
.41046 .05703 L
.41046 .05745 L
.41046 .05786 L
.41048 .05825 L
.41051 .05859 L
.41055 .05886 L
.41061 .05905 L
.41067 .05916 L
Mistroke
.41073 .05919 L
.41079 .05916 L
.41087 .05908 L
.41095 .05897 L
.41101 .05888 L
.41102 .05879 L
.41099 .05874 L
.41089 .05872 L
.41071 .05877 L
.41045 .0589 L
.4101 .05913 L
.4097 .05946 L
.40925 .05989 L
.40879 .0604 L
.40833 .06096 L
.40789 .06159 L
.40746 .06227 L
.40704 .06296 L
.40667 .06359 L
.40636 .06416 L
.40615 .06463 L
.40606 .06495 L
.40609 .0651 L
.4062 .06506 L
.40633 .06484 L
.40644 .06448 L
.4065 .06404 L
.40645 .06357 L
.40625 .06309 L
.40597 .06263 L
.4055 .06218 L
.40479 .06176 L
.40385 .06134 L
.40274 .06095 L
.40159 .06059 L
.4004 .06028 L
.39897 .06 L
.39724 .05977 L
.39573 .05958 L
.39406 .05943 L
.39257 .05928 L
.39104 .05911 L
.38964 .05891 L
.38852 .05869 L
.38751 .05844 L
.38661 .05815 L
.38587 .05783 L
.38532 .05748 L
.38496 .05711 L
.38477 .05672 L
Mistroke
.38473 .05632 L
.38477 .05593 L
.38486 .05554 L
.38496 .05513 L
.38505 .05474 L
.38508 .0544 L
.38504 .05413 L
.38497 .05395 L
.38487 .05386 L
.38475 .05382 L
.38462 .05384 L
.38446 .05389 L
.38427 .05396 L
.38405 .05401 L
.38382 .05403 L
.38359 .05403 L
.38341 .05402 L
.38328 .05401 L
.3832 .05401 L
.38316 .054 L
.38318 .05401 L
.38325 .05403 L
.38335 .05405 L
.38346 .05408 L
.38356 .05411 L
.38363 .05414 L
.38368 .05418 L
.38371 .05421 L
.38375 .05425 L
.3838 .05427 L
.38388 .05429 L
.384 .0543 L
.38416 .0543 L
.38435 .05429 L
.38453 .05426 L
.38469 .05421 L
.38482 .05429 L
.38492 .05425 L
.38499 .05422 L
.38503 .05422 L
.38503 .05425 L
.38498 .05432 L
.38487 .05443 L
.38467 .05459 L
.38438 .05483 L
.384 .05508 L
.38355 .0554 L
.38308 .05574 L
.38261 .05609 L
.3822 .05648 L
Mistroke
.38184 .05683 L
.38155 .05712 L
.38132 .0574 L
.38115 .05764 L
.38104 .05784 L
.38097 .058 L
.38095 .05811 L
.38098 .05818 L
.38107 .05823 L
.38121 .05824 L
.38134 .05824 L
.38142 .05822 L
.3814 .05819 L
.38126 .05815 L
.381 .05812 L
.3806 .05811 L
.38007 .05809 L
.37945 .05807 L
.37878 .05805 L
.37807 .05803 L
.37739 .05801 L
.37672 .05799 L
.37605 .05797 L
.37541 .05795 L
.37483 .05794 L
.37438 .05792 L
.37406 .05792 L
.37389 .05791 L
.37383 .05791 L
.37386 .05791 L
.37396 .05791 L
.37407 .05792 L
.37415 .05792 L
.37419 .05792 L
.3742 .0579 L
.37421 .05787 L
.37424 .05785 L
.37427 .05784 L
.37431 .05784 L
.37432 .05787 L
.3743 .05793 L
.37422 .05804 L
.37409 .0582 L
.37392 .05839 L
.37374 .05857 L
.37355 .05874 L
.37337 .05888 L
.37323 .05898 L
.37313 .05904 L
.37307 .0591 L
Mistroke
.37304 .0591 L
.37306 .05907 L
.37311 .05897 L
.37319 .05884 L
.37333 .05867 L
.37349 .05848 L
.37369 .05829 L
.37389 .05811 L
.37407 .05795 L
.37421 .05787 L
.3743 .05783 L
.37433 .05782 L
.37431 .05782 L
.37428 .05784 L
.37424 .05788 L
.37421 .05791 L
.3742 .05792 L
.37419 .05792 L
.37419 .05792 L
.37419 .05792 L
.37419 .05792 L
.3742 .05792 L
.37422 .05792 L
.37427 .05792 L
.37434 .05793 L
.37441 .05793 L
.37444 .05793 L
.37443 .05793 L
.37434 .05793 L
.37418 .05792 L
.37393 .05791 L
.37363 .05786 L
.3733 .05777 L
.37294 .05766 L
.37257 .05756 L
.37219 .05749 L
.3718 .05747 L
.37135 .05755 L
.37082 .05774 L
.37021 .05809 L
.36951 .05859 L
.3687 .05924 L
.36773 .06002 L
.3666 .06091 L
.36542 .0618 L
.36403 .06272 L
.36243 .06368 L
.36085 .06463 L
.35895 .06553 L
.35725 .06629 L
Mistroke
.35554 .06693 L
.35389 .06742 L
.35244 .06777 L
.35126 .06797 L
.35028 .06806 L
.34951 .06806 L
.34897 .06801 L
.34862 .06795 L
.34842 .06788 L
.34836 .0678 L
.34838 .06774 L
.34844 .06772 L
.34855 .06771 L
.34867 .06772 L
.34877 .06772 L
.34881 .06772 L
.34882 .06772 L
.34884 .06769 L
.3489 .06762 L
.34902 .06753 L
.34912 .06744 L
.34919 .0674 L
.34919 .06744 L
.34909 .06757 L
.34884 .06781 L
.3484 .06817 L
.34778 .06864 L
.34704 .06919 L
.34622 .0698 L
.34538 .07044 L
.34454 .07105 L
.34387 .07164 L
.34311 .07222 L
.34239 .07278 L
.34177 .07327 L
.34133 .07365 L
.34111 .07388 L
.3411 .07396 L
.34123 .07392 L
.34144 .07382 L
.34167 .0737 L
.34187 .0736 L
.34194 .07357 L
.34181 .07364 L
.34147 .07381 L
.34091 .07405 L
.34011 .07436 L
.33904 .07474 L
.33789 .07521 L
.3364 .07578 L
Mistroke
.33504 .07642 L
.33356 .07718 L
.33186 .07804 L
.33023 .079 L
.32853 .08003 L
.32675 .08108 L
.32495 .0821 L
.32324 .08304 L
.3215 .08397 L
.31979 .08483 L
.31839 .0856 L
.31694 .08627 L
.31559 .08686 L
.31452 .08735 L
.31358 .08776 L
.31276 .08808 L
.31209 .08832 L
.31157 .08851 L
.31123 .08867 L
.31106 .08883 L
.31104 .08898 L
.31112 .08912 L
.31125 .08929 L
.31139 .08948 L
.3115 .08967 L
.31155 .08984 L
.31156 .08997 L
.31156 .09007 L
.31156 .09012 L
.31156 .09014 L
.31156 .09012 L
.31156 .09009 L
.31156 .09006 L
.31156 .09003 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31156 .09001 L
.31159 .08999 L
.31165 .08994 L
.31176 .08988 L
.31186 .08982 L
.31192 .08979 L
.31189 .0898 L
Mistroke
.31177 .08988 L
.31153 .09003 L
.31115 .09026 L
.31067 .09053 L
.31011 .09084 L
.30952 .09117 L
.30888 .09153 L
.30818 .09193 L
.30745 .09238 L
.30666 .09288 L
.30582 .09343 L
.30495 .09401 L
.30412 .09459 L
.30339 .09515 L
.3028 .09567 L
.30233 .09614 L
.30196 .09655 L
.30159 .09693 L
.30118 .09729 L
.30068 .09764 L
.30007 .09797 L
.29937 .09825 L
.29863 .09844 L
.29786 .09854 L
.29713 .09856 L
.29647 .09851 L
.29589 .09839 L
.29532 .09828 L
.29472 .09818 L
.29408 .09812 L
.29346 .0981 L
.29292 .09812 L
.29247 .09819 L
.29212 .0983 L
.29185 .09844 L
.29165 .09861 L
.29151 .0988 L
.29138 .09904 L
.29121 .09924 L
.29098 .09948 L
.29074 .09971 L
.29052 .09992 L
.29034 .10008 L
.29022 .10018 L
.29017 .10021 L
.29021 .10018 L
.29032 .10014 L
.29049 .1001 L
.29071 .1001 L
.29095 .10016 L
Mistroke
.29119 .1003 L
.29144 .10052 L
.29169 .10078 L
.29195 .10106 L
.29221 .1013 L
.29249 .10145 L
.29276 .10153 L
.293 .10155 L
.29322 .10156 L
.29338 .10157 L
.29343 .10167 L
.29334 .10168 L
.29311 .10173 L
.29269 .10181 L
.29208 .10195 L
.29122 .10221 L
.29008 .10262 L
.28879 .10316 L
.2872 .10392 L
.28527 .10488 L
.28312 .10602 L
.28111 .10721 L
.27888 .10848 L
.2764 .1098 L
.27416 .11106 L
.27183 .11227 L
.26986 .11335 L
.26809 .11433 L
.26662 .11522 L
.26542 .11601 L
.26435 .11668 L
.26347 .11724 L
.26274 .1177 L
.26213 .11808 L
.26156 .11839 L
.26098 .11866 L
.26036 .11894 L
.25962 .11926 L
.2587 .11967 L
.25764 .1202 L
.25642 .12085 L
.25496 .12165 L
.25321 .12261 L
.25137 .12369 L
.24944 .12488 L
.24746 .12613 L
.24571 .12735 L
.24401 .12851 L
.2426 .1296 L
.24124 .13059 L
Mistroke
.24013 .13141 L
.23919 .1321 L
.23846 .13264 L
.23797 .13303 L
.23768 .13327 L
.23758 .13339 L
.23761 .13342 L
.23773 .13338 L
.23788 .13331 L
.23803 .13322 L
.23812 .13314 L
.23818 .13307 L
.23827 .133 L
.23839 .13291 L
.23849 .13281 L
.23854 .13273 L
.23852 .13269 L
.23839 .1327 L
.23815 .13281 L
.23776 .13304 L
.23722 .13342 L
.23655 .13395 L
.23577 .13462 L
.23492 .13542 L
.23406 .1363 L
.23319 .13727 L
.23229 .13826 L
.2314 .13927 L
.23056 .14026 L
.22984 .14118 L
.22927 .14198 L
.22885 .14265 L
.22858 .14318 L
.22842 .14356 L
.22837 .14379 L
.22837 .14389 L
.2284 .14391 L
.22842 .14388 L
.22845 .14383 L
.22849 .14376 L
.22853 .14368 L
.2286 .14361 L
.22867 .14356 L
.22876 .14351 L
.22887 .14346 L
.22899 .14339 L
.22909 .14332 L
.22913 .14326 L
.22906 .14325 L
.22885 .14333 L
Mistroke
.22844 .14354 L
.22779 .14388 L
.22688 .14435 L
.22569 .14497 L
.22436 .14567 L
.22275 .14646 L
.22086 .14734 L
.21891 .14826 L
.21686 .14928 L
.21452 .15049 L
.21235 .15168 L
.21003 .15295 L
.20779 .15428 L
.20588 .15564 L
.20405 .15698 L
.2024 .15824 L
.20106 .15927 L
.19991 .16031 L
.19898 .16127 L
.1983 .16202 L
.19782 .1627 L
.1975 .16328 L
.1973 .16374 L
.19716 .16407 L
.19703 .16437 L
.19684 .16473 L
.19655 .16518 L
.19617 .16578 L
.19568 .16658 L
.19508 .16756 L
.1944 .16868 L
.19372 .16974 L
.19302 .17095 L
.19234 .17217 L
.19175 .17321 L
.19119 .17423 L
.19073 .1751 L
.19039 .17583 L
.19016 .17643 L
.18996 .17696 L
.18976 .17747 L
.18949 .17802 L
.18909 .1787 L
.18847 .17961 L
.18759 .18079 L
.18653 .18206 L
.18524 .18371 L
.18368 .18556 L
.18189 .18777 L
.17999 .19011 L
Mistroke
.17822 .19276 L
.17634 .19522 L
.17433 .19796 L
.17238 .20073 L
.17052 .20343 L
.16866 .20631 L
.16697 .20877 L
.16528 .21141 L
.16374 .21386 L
.16221 .21629 L
.16073 .21859 L
.15939 .22094 L
.15805 .22297 L
.15673 .22502 L
.1555 .22698 L
.15438 .22878 L
.15332 .23051 L
.15232 .23212 L
.15144 .23345 L
.15065 .23471 L
.14997 .23586 L
.14944 .23687 L
.14902 .23769 L
.14873 .23837 L
.14854 .23887 L
.14845 .2392 L
.14841 .23938 L
.1484 .23945 L
.14838 .23945 L
.14835 .23941 L
.14828 .23938 L
.14815 .23939 L
.14793 .23946 L
.14762 .23961 L
.1472 .23989 L
.14666 .24033 L
.14598 .241 L
.1452 .24184 L
.1443 .24291 L
.14327 .24421 L
.1421 .2458 L
.14084 .24767 L
.1396 .24948 L
.1383 .25167 L
.13697 .25402 L
.13562 .25638 L
.13419 .25902 L
.13266 .26187 L
.13111 .26454 L
.12943 .26759 L
Mistroke
.12775 .27047 L
.12611 .2735 L
.12443 .27632 L
.1227 .27934 L
.12116 .28193 L
.11929 .28474 L
.1176 .28747 L
.1157 .29034 L
.11388 .29328 L
.11193 .29585 L
.10991 .29862 L
.10795 .30153 L
.10646 .30391 L
.10485 .30649 L
.10339 .3087 L
.10193 .31092 L
.10084 .31272 L
.09987 .31439 L
.09902 .3159 L
.09837 .31712 L
.09791 .31811 L
.09764 .31883 L
.09754 .31927 L
.09756 .31948 L
.09765 .31951 L
.09777 .31941 L
.0979 .31925 L
.098 .31908 L
.09805 .31894 L
.09804 .31884 L
.09804 .31878 L
.09804 .31876 L
.09802 .31879 L
.09798 .31888 L
.0979 .31903 L
.09779 .31928 L
.09766 .31965 L
.09753 .32017 L
.09741 .32081 L
.09731 .32159 L
.09723 .32248 L
.0972 .32344 L
.09719 .32439 L
.09721 .32535 L
.09726 .3263 L
.09731 .32721 L
.0974 .32799 L
.09752 .32862 L
.09766 .32902 L
.09782 .32926 L
Mistroke
.09799 .32938 L
.09815 .32943 L
.09827 .32943 L
.09831 .32947 L
.09825 .32966 L
.0981 .33012 L
.09786 .33095 L
.09755 .33216 L
.09719 .33377 L
.09677 .33577 L
.09628 .33783 L
.0957 .34014 L
.09501 .34293 L
.09421 .34584 L
.09334 .34907 L
.09239 .35223 L
.09139 .35559 L
.09042 .35889 L
.08946 .36186 L
.08854 .36511 L
.08773 .36806 L
.08695 .37109 L
.08629 .37392 L
.08569 .3769 L
.08518 .37943 L
.08478 .3821 L
.08449 .38459 L
.08431 .38716 L
.08422 .38963 L
.08422 .39165 L
.08425 .39356 L
.08431 .39536 L
.08436 .39698 L
.08439 .39838 L
.08439 .39947 L
.08438 .40037 L
.08437 .40107 L
.08437 .40159 L
.08436 .40193 L
.08436 .40212 L
Mfstroke
.07165 .4811 m
.07162 .48134 L
.07158 .48169 L
.07156 .48213 L
.07155 .48262 L
.07154 .48314 L
.07152 .48369 L
.07148 .4843 L
.07143 .48495 L
.07136 .4857 L
.0713 .4865 L
.07126 .48733 L
.07123 .48822 L
.07121 .48916 L
.07118 .49015 L
.07111 .49124 L
.07099 .49243 L
.07082 .49379 L
.07061 .4954 L
.07034 .49735 L
.07002 .49949 L
.06967 .50197 L
.0693 .50467 L
.06895 .50713 L
.0686 .50959 L
.06828 .51221 L
.06799 .51471 L
.06776 .51739 L
.06761 .51965 L
.06756 .52195 L
.06766 .52417 L
.06787 .52619 L
.0682 .52809 L
.0686 .52976 L
.06905 .53124 L
.06952 .53255 L
.06998 .5337 L
.07039 .53469 L
.07076 .53549 L
.07109 .53615 L
.07138 .53671 L
.07165 .53717 L
.07189 .53753 L
.07212 .53781 L
.07234 .53802 L
.07258 .53819 L
.07283 .53832 L
.07311 .53841 L
.07339 .53847 L
.07364 .5385 L
Mistroke
.0739 .53857 L
.07413 .53869 L
.07431 .53889 L
.07438 .53917 L
.07433 .53955 L
.07416 .54006 L
.07388 .5407 L
.07354 .54152 L
.07319 .54256 L
.07287 .54375 L
.07261 .5452 L
.07243 .54687 L
.07236 .54868 L
.07241 .55072 L
.07257 .5529 L
.07285 .55506 L
.07322 .55737 L
.0737 .55966 L
.07429 .56203 L
.0749 .5642 L
.07551 .56638 L
.07611 .56852 L
.07664 .57032 L
.07708 .57206 L
.07743 .57364 L
.07771 .57496 L
.07791 .5761 L
.07806 .5771 L
.07817 .57776 L
.07825 .57829 L
.07832 .57862 L
.07835 .57876 L
.07834 .57877 L
.0783 .5787 L
.07826 .57863 L
.07824 .57864 L
.07824 .57872 L
.07828 .57886 L
.07833 .57906 L
.07839 .57929 L
.07844 .57955 L
.07848 .57983 L
.0785 .58012 L
.07852 .58042 L
.07851 .58079 L
.07847 .58127 L
.07842 .58194 L
.07833 .58267 L
.07821 .58359 L
.07809 .58466 L
Mistroke
.07796 .5859 L
.07784 .58724 L
.07777 .58885 L
.07776 .59067 L
.07781 .59275 L
.07793 .59515 L
.07814 .59754 L
.07843 .60022 L
.0788 .60304 L
.07925 .60609 L
.07979 .60892 L
.08041 .6118 L
.08108 .61481 L
.08178 .61764 L
.08248 .62062 L
.08315 .62339 L
.08376 .62619 L
.08434 .62866 L
.08491 .63102 L
.08543 .63302 L
.08591 .6348 L
.08636 .63636 L
.08676 .63774 L
.08711 .63899 L
.08742 .64017 L
.08771 .64131 L
.08799 .6424 L
.08828 .64346 L
.08859 .64448 L
.08894 .64538 L
.08931 .64626 L
.08968 .64703 L
.09001 .64776 L
.09029 .64836 L
.09054 .6489 L
.09076 .64937 L
.09097 .64975 L
.09117 .65011 L
.09138 .65052 L
.09159 .651 L
.09179 .6516 L
.09197 .65244 L
.09214 .65355 L
.0923 .65488 L
.09245 .6563 L
.09261 .65788 L
.09277 .65956 L
.09292 .66119 L
.09304 .66295 L
.09315 .66457 L
Mistroke
.09324 .66621 L
.09332 .66786 L
.09339 .66952 L
.09346 .67123 L
.09354 .67296 L
.09365 .67455 L
.09381 .67627 L
.09407 .67808 L
.09444 .67985 L
.0949 .68172 L
.09547 .6836 L
.09616 .68531 L
.09695 .68692 L
.0979 .68838 L
.09861 .68938 L
.09944 .69033 L
.10029 .69109 L
.10098 .69167 L
.10162 .69212 L
.10222 .69247 L
.10274 .69275 L
.10315 .69298 L
.10343 .69322 L
.10358 .69351 L
.10362 .69392 L
.10358 .69445 L
.1035 .69517 L
.10341 .69606 L
.10332 .6971 L
.10326 .69823 L
.10321 .69946 L
.10314 .70072 L
.10305 .70208 L
.10295 .70356 L
.10285 .7053 L
.10275 .70688 L
.10265 .70865 L
.10258 .71049 L
.10252 .71224 L
.10247 .71386 L
.10245 .71532 L
.10243 .71651 L
.10243 .71754 L
.10245 .71841 L
.10249 .71915 L
.10255 .71975 L
.10261 .7202 L
.10268 .72046 L
.10274 .72057 L
.10279 .72056 L
Mistroke
.10281 .72049 L
.10281 .72038 L
.10279 .72026 L
.10276 .72017 L
.10275 .72012 L
.10275 .7201 L
.10275 .72006 L
.10275 .71999 L
.10276 .7199 L
.10276 .7198 L
.10276 .71967 L
.10276 .71956 L
.10275 .71947 L
.10272 .71944 L
.10268 .71944 L
.10264 .71944 L
.10261 .71944 L
.10261 .71945 L
.10263 .71946 L
.10266 .71953 L
.10272 .71965 L
.10281 .71985 L
.10297 .72017 L
.10324 .72062 L
.10361 .72121 L
.10409 .72193 L
.10471 .72279 L
.10545 .72381 L
.1063 .72489 L
.10723 .72608 L
.10813 .72734 L
.10904 .72864 L
.10992 .72998 L
.11073 .73123 L
.11151 .73247 L
.11225 .73364 L
.11298 .73472 L
.11372 .73573 L
.11451 .73672 L
.1154 .7378 L
.11633 .73887 L
.11737 .74014 L
.11855 .74155 L
.11978 .743 L
.12121 .74458 L
.1228 .74629 L
.12452 .74807 L
.1263 .74968 L
.12808 .75134 L
.12968 .75271 L
Mistroke
.13121 .75392 L
.13241 .75495 L
.13338 .7557 L
.13402 .75617 L
.13432 .75639 L
.13431 .7564 L
.13413 .75627 L
.13387 .75606 L
.13361 .75583 L
.13336 .75566 L
.13319 .75563 L
.13309 .75579 L
.13308 .75615 L
.13322 .75667 L
.13362 .75732 L
.13443 .75812 L
.13532 .75892 L
.13666 .75981 L
.13819 .76076 L
.13996 .76175 L
.14183 .76275 L
.14384 .7637 L
.1458 .76461 L
.14777 .76544 L
.14977 .76617 L
.15167 .76678 L
.15346 .76729 L
.15507 .7677 L
.15643 .76805 L
.15753 .76834 L
.15846 .76863 L
.15907 .76886 L
.15956 .76915 L
.15993 .76949 L
.16021 .7699 L
.16042 .77041 L
.16064 .77105 L
.16086 .77187 L
.16112 .77279 L
.16142 .77398 L
.16186 .77541 L
.16247 .77699 L
.16328 .77874 L
.16432 .78072 L
.16555 .78293 L
.16689 .78519 L
.16837 .78748 L
.17 .78993 L
.17169 .79233 L
.17352 .7948 L
Mistroke
.17552 .79728 L
.17765 .79969 L
.17993 .80203 L
.18217 .80426 L
.18442 .80632 L
.18647 .80818 L
.18831 .80969 L
.18994 .81101 L
.19128 .81204 L
.19242 .81287 L
.19334 .81353 L
.19412 .81408 L
.19483 .81459 L
.19553 .81515 L
.19627 .81579 L
.19704 .81654 L
.19793 .81742 L
.19892 .81843 L
.20013 .81962 L
.20161 .82103 L
.2033 .82268 L
.20522 .82443 L
.20719 .82626 L
.20925 .82805 L
.21133 .82992 L
.21313 .83135 L
.21488 .83279 L
.21639 .83405 L
.2177 .8351 L
.21874 .83596 L
.21956 .83666 L
.22016 .83719 L
.22055 .83757 L
.22078 .83785 L
.22089 .83806 L
.22093 .83825 L
.22097 .83845 L
.22107 .83869 L
.22128 .83899 L
.22161 .83934 L
.22209 .83976 L
.22271 .84022 L
.22343 .8407 L
.22418 .8412 L
.22495 .8416 L
.22572 .84201 L
.22644 .84236 L
.22704 .84261 L
.22753 .84277 L
.22788 .84286 L
Mistroke
.22811 .8429 L
.22823 .84289 L
.22828 .84289 L
.22833 .84295 L
.22848 .8431 L
.2288 .84339 L
.22934 .84385 L
.23013 .84447 L
.23117 .84525 L
.23242 .84624 L
.23397 .84737 L
.23579 .84869 L
.2377 .85013 L
.23976 .85161 L
.24184 .85314 L
.24387 .85453 L
.24574 .85577 L
.24752 .85705 L
.24918 .85831 L
.25059 .85951 L
.25188 .86067 L
.25292 .86169 L
.25389 .86263 L
.25454 .86349 L
.25513 .86423 L
.25566 .86485 L
.25604 .86552 L
.25644 .86621 L
.25686 .86696 L
.25737 .86778 L
.25793 .86854 L
.25865 .86936 L
.25952 .87016 L
.26064 .87093 L
.26166 .87167 L
.26298 .87243 L
.26445 .87323 L
.26613 .87413 L
.26807 .87512 L
.27026 .8762 L
.27261 .87731 L
.27497 .87835 L
.27731 .87936 L
.27963 .88029 L
.28169 .88118 L
.28357 .88194 L
.28502 .8826 L
.2862 .88318 L
.28716 .88368 L
.28791 .88401 L
Mistroke
.28844 .88418 L
.28882 .88419 L
.28907 .88404 L
.28928 .88378 L
.28958 .88347 L
.29005 .88316 L
.29068 .8829 L
.29154 .88267 L
.29252 .88248 L
.29367 .88232 L
.29491 .88215 L
.29619 .88194 L
.29738 .88172 L
.29838 .88147 L
.29914 .88117 L
.29964 .88086 L
.29994 .88057 L
.30008 .88038 L
.30008 .88028 L
.29994 .88025 L
.29986 .88033 L
.29989 .88056 L
.30014 .88089 L
.30065 .88138 L
.30153 .88215 L
.3028 .88315 L
.30455 .88437 L
.30663 .88572 L
.30922 .88718 L
.31199 .88876 L
.31519 .89042 L
.31838 .8921 L
.32183 .89374 L
.32519 .89532 L
.32863 .8968 L
.33204 .89809 L
.33545 .89932 L
.33855 .90039 L
.34169 .90136 L
.34475 .90224 L
.34774 .90305 L
.35061 .9038 L
.35341 .9045 L
.35611 .90518 L
.35882 .90585 L
.36149 .90651 L
.36403 .90719 L
.36656 .90791 L
.36905 .90868 L
.37135 .90948 L
Mistroke
.37348 .91027 L
.37536 .911 L
.37692 .91166 L
.37818 .91222 L
.37918 .91264 L
.37992 .91292 L
.38049 .91304 L
.38093 .91302 L
.38132 .91283 L
.38176 .91247 L
.38234 .91195 L
.3831 .91132 L
.384 .91056 L
.38514 .90971 L
.38639 .90879 L
.38775 .90784 L
.38919 .90693 L
.39067 .90599 L
.39208 .9054 L
.39333 .90476 L
.39431 .9043 L
.39501 .90403 L
.39543 .90399 L
.39559 .90416 L
.39548 .90448 L
.39519 .90495 L
.39485 .90556 L
.39454 .90626 L
.39434 .90696 L
.39432 .90757 L
.39453 .9081 L
.39498 .90857 L
.39564 .909 L
.39649 .90935 L
.39735 .9097 L
.39822 .91008 L
.399 .91047 L
.39964 .91085 L
.40006 .91124 L
.40026 .91162 L
.40026 .91187 L
.40011 .91203 L
.39982 .912 L
.39945 .91184 L
.39886 .91149 L
.39838 .91084 L
.39781 .91002 L
.39728 .90919 L
.39682 .90804 L
.39651 .9068 L
Mistroke
.39635 .9054 L
.39631 .90413 L
.39634 .90295 L
.39639 .90197 L
.39643 .90126 L
.39639 .9008 L
.39623 .90056 L
.39594 .90056 L
.39558 .90084 L
.39518 .90134 L
.3948 .90199 L
.39446 .90277 L
.39423 .90369 L
.39411 .90469 L
.39413 .90581 L
.39431 .90699 L
.39467 .90822 L
.39524 .90955 L
.39602 .91095 L
.39699 .9124 L
.39818 .91387 L
.39961 .91532 L
.40123 .91678 L
.40309 .91825 L
.40509 .91967 L
.40734 .92109 L
.40986 .92244 L
.41241 .92364 L
.41515 .92474 L
.41805 .92579 L
.42099 .9268 L
.42394 .92776 L
.42675 .92869 L
.42957 .92957 L
.43222 .93037 L
.43474 .9311 L
.43688 .93173 L
.43881 .93223 L
.44052 .93259 L
.442 .93287 L
.44333 .93313 L
.44454 .93341 L
.44575 .93369 L
.4468 .93394 L
.44799 .93417 L
.44926 .93434 L
.45057 .93438 L
.45199 .93432 L
.45351 .93417 L
.45502 .93398 L
Mistroke
.45655 .93383 L
.45806 .9338 L
.45957 .93388 L
.46103 .93403 L
.46253 .93412 L
.46407 .9342 L
.46568 .93429 L
.46738 .93441 L
.46915 .93454 L
.47098 .93468 L
.47301 .93487 L
.47515 .93512 L
.47741 .93538 L
.47972 .93558 L
.48213 .93567 L
.48457 .93562 L
.48707 .93546 L
.48989 .93525 L
.49223 .93506 L
.49468 .93489 L
.49698 .93475 L
.49903 .93466 L
.50067 .93462 L
.50191 .93463 L
.50268 .93464 L
.50317 .93463 L
.5034 .93461 L
.50344 .93462 L
.50335 .93467 L
.50307 .93472 L
.50269 .93475 L
.5023 .93473 L
.50194 .93463 L
.50162 .93443 L
.50142 .9341 L
.50128 .93367 L
.50129 .93317 L
.50149 .93264 L
.50186 .93209 L
.50233 .93155 L
.50261 .93096 L
.50277 .93029 L
.50282 .9296 L
.50277 .92895 L
.50273 .92831 L
.50268 .92777 L
.50261 .92732 L
.50261 .92702 L
.50261 .92682 L
.50259 .92675 L
Mistroke
.50249 .92681 L
.50229 .92696 L
.50194 .92708 L
.50141 .92711 L
.50068 .9271 L
.49969 .92708 L
.49843 .92706 L
.49695 .92708 L
.49526 .92717 L
.49344 .92734 L
.49134 .92753 L
.48889 .9277 L
.48663 .92784 L
.48413 .928 L
.48152 .92816 L
.47884 .92827 L
.47611 .92847 L
.4733 .92873 L
.47056 .92906 L
.46778 .92937 L
.46498 .92976 L
.46226 .93001 L
.45944 .93018 L
.45664 .93022 L
.45387 .93026 L
.45114 .93028 L
.44841 .93032 L
.44583 .93038 L
.44322 .93044 L
.44088 .9305 L
.43852 .93043 L
.43608 .93023 L
.43402 .9299 L
.43194 .92943 L
.42991 .92888 L
.42783 .92824 L
.42576 .92757 L
.42371 .92688 L
.42162 .92617 L
.41945 .92545 L
.41719 .92471 L
.41493 .92391 L
.4125 .92306 L
.40984 .92216 L
.4071 .92123 L
.40424 .92032 L
.4013 .9194 L
.39819 .91849 L
.39505 .91759 L
.39194 .91665 L
Mistroke
.38871 .91567 L
.38559 .91465 L
.38241 .9136 L
.37931 .91251 L
.37623 .9114 L
.37304 .91032 L
.36996 .90927 L
.36688 .90832 L
.36385 .90742 L
.36079 .90656 L
.35785 .9057 L
.35495 .90482 L
.35189 .90388 L
.34877 .9029 L
.34579 .90187 L
.34267 .90081 L
.33945 .89976 L
.33649 .89877 L
.33362 .89781 L
.3307 .89689 L
.32817 .89602 L
.32549 .8952 L
.32341 .8945 L
.32153 .89391 L
.31982 .89346 L
.31837 .89316 L
.31722 .893 L
.31637 .89294 L
.31571 .89291 L
.31513 .89283 L
.31451 .89263 L
.3138 .89228 L
.31296 .89176 L
.31191 .89107 L
.31058 .89023 L
.3092 .88935 L
.30772 .88839 L
.30625 .88742 L
.30487 .88648 L
.30353 .88559 L
.30223 .88483 L
.30114 .88421 L
.30026 .88376 L
.29958 .88348 L
.29912 .88335 L
.29888 .8833 L
.29883 .8833 L
.29892 .88326 L
.29908 .8831 L
.29925 .88279 L
Mistroke
.29938 .88236 L
.29944 .88183 L
.29944 .88122 L
.29941 .88063 L
.2994 .88016 L
.29959 .8798 L
.29976 .87959 L
.29997 .87954 L
.30013 .87965 L
.30025 .87994 L
.30024 .88034 L
.30004 .8808 L
.29958 .88126 L
.29883 .88177 L
.29777 .88223 L
.29638 .88251 L
.29477 .88258 L
.29279 .88238 L
.29063 .8819 L
.28826 .88123 L
.28555 .88037 L
.28271 .87939 L
.2798 .87845 L
.27725 .8775 L
.27461 .87662 L
.27226 .87593 L
.27015 .87529 L
.26837 .87475 L
.26687 .87428 L
.26558 .87383 L
.26458 .87339 L
.26372 .87296 L
.26296 .87255 L
.26244 .87216 L
.26199 .87176 L
.26163 .87135 L
.26137 .87098 L
.2612 .87064 L
.26106 .8703 L
.26091 .86996 L
.2607 .86966 L
.26048 .86942 L
.26014 .86921 L
.2597 .86902 L
.25914 .86881 L
.25842 .86852 L
.25751 .8681 L
.25644 .86752 L
.25521 .86674 L
.25388 .8658 L
Mistroke
.25238 .86467 L
.25069 .86337 L
.24885 .86198 L
.24701 .86052 L
.24516 .85903 L
.24341 .85755 L
.24186 .85613 L
.24052 .85491 L
.23942 .8539 L
.23851 .85309 L
.23773 .8524 L
.23709 .85187 L
.23648 .85137 L
.23581 .8508 L
.23517 .85025 L
.23457 .84973 L
.23384 .84907 L
.23299 .84831 L
.23196 .84738 L
.2307 .84631 L
.22925 .84505 L
.22766 .8437 L
.22587 .84221 L
.22392 .84056 L
.22186 .83879 L
.21973 .83696 L
.21754 .83506 L
.21542 .83318 L
.21329 .83128 L
.21114 .8294 L
.20909 .82771 L
.20708 .82602 L
.20513 .8243 L
.20328 .82269 L
.20151 .82102 L
.19986 .81929 L
.19832 .81763 L
.19685 .81593 L
.19546 .81426 L
.19418 .81271 L
.19298 .81122 L
.19186 .80998 L
.19084 .80877 L
.18986 .80773 L
.18891 .80673 L
.18794 .80574 L
.18695 .80482 L
.18589 .80396 L
.18474 .80316 L
.18351 .80236 L
Mistroke
.18218 .80155 L
.18077 .80069 L
.17939 .79972 L
.17788 .7987 L
.17632 .7974 L
.1747 .79603 L
.17295 .79444 L
.17122 .79277 L
.16942 .79095 L
.16759 .78902 L
.16584 .7871 L
.16415 .78524 L
.16253 .78333 L
.16095 .78138 L
.15934 .77943 L
.15787 .77753 L
.15637 .77559 L
.15488 .77371 L
.15341 .77193 L
.15208 .7703 L
.15085 .76881 L
.14976 .76747 L
.1487 .76625 L
.14762 .76511 L
.14645 .76405 L
.14544 .76303 L
.14418 .762 L
.1427 .76091 L
.14111 .75968 L
.13927 .75847 L
.13745 .75712 L
.13538 .75562 L
.13329 .75399 L
.13142 .75221 L
.12947 .75033 L
.12732 .74832 L
.1252 .74625 L
.12307 .74414 L
.12106 .74203 L
.11902 .73994 L
.11715 .73802 L
.11537 .73619 L
.11365 .73454 L
.11213 .73301 L
.1107 .73165 L
.10935 .73043 L
.10813 .72933 L
.10714 .72834 L
.1063 .72744 L
.10565 .72665 L
Mistroke
.10519 .72603 L
.10495 .72558 L
.10488 .72526 L
.10495 .72503 L
.10509 .72485 L
.10527 .72469 L
.10545 .72455 L
.10562 .72441 L
.10577 .72426 L
.10587 .72409 L
.10592 .72395 L
.10591 .72386 L
.10585 .72381 L
.10572 .72373 L
.10551 .72358 L
.10525 .72333 L
.10495 .72294 L
.10464 .72241 L
.10433 .72168 L
.10408 .72097 L
.10383 .72012 L
.1036 .71922 L
.10337 .71825 L
.10315 .71712 L
.10291 .71576 L
.10269 .71414 L
.10249 .71231 L
.10228 .71046 L
.10206 .70864 L
.10181 .70689 L
.10153 .70531 L
.10121 .7039 L
.10085 .70271 L
.1005 .70173 L
.10019 .70096 L
.09994 .70035 L
.09975 .69988 L
.09962 .69953 L
.09956 .69935 L
.09957 .69931 L
.09964 .69934 L
.09982 .69936 L
.10008 .69932 L
.10038 .69924 L
.1007 .69913 L
.10099 .69899 L
.10122 .69884 L
.10137 .69874 L
.10141 .69878 L
.10134 .69889 L
Mistroke
.10115 .69905 L
.1009 .69915 L
.10059 .69909 L
.10023 .69879 L
.09981 .6983 L
.09931 .69772 L
.09872 .69686 L
.09808 .69576 L
.09742 .69437 L
.09678 .69274 L
.09619 .69089 L
.0956 .68901 L
.09502 .68682 L
.0944 .6842 L
.09374 .68144 L
.09301 .67832 L
.0922 .67497 L
.09138 .67114 L
.09057 .66726 L
.08981 .66302 L
.08911 .65942 L
.08849 .65567 L
.08794 .65252 L
.08745 .64971 L
.08706 .64698 L
.08674 .64447 L
.08653 .64251 L
.0864 .6413 L
.08637 .64066 L
.08639 .64027 L
.08639 .6399 L
.08633 .63945 L
.08619 .63887 L
.08595 .63782 L
.08559 .63606 L
.08519 .63385 L
.08474 .63132 L
.08425 .62864 L
.08377 .62584 L
.08329 .62305 L
.08282 .62033 L
.08244 .61788 L
.08213 .61567 L
.08189 .61385 L
.08177 .61244 L
.08179 .61142 L
.08194 .61081 L
.0822 .61055 L
.08254 .61056 L
.08291 .61075 L
Mistroke
.08328 .61105 L
.08363 .61143 L
.08395 .61183 L
.08421 .6122 L
.08441 .61252 L
.08458 .61277 L
.08473 .61294 L
.08484 .61304 L
.08491 .6131 L
.08493 .61311 L
.08491 .6131 L
.08487 .61307 L
.08483 .61303 L
.08479 .613 L
.08478 .61298 L
.08478 .61298 L
.0848 .613 L
.08486 .61302 L
.08494 .61306 L
.08501 .61313 L
.08505 .61324 L
.08503 .6134 L
.08495 .61357 L
.08478 .61371 L
.08451 .61376 L
.08413 .61365 L
.08366 .61329 L
.08311 .61264 L
.08251 .61164 L
.0819 .6103 L
.0813 .60857 L
.08068 .60645 L
.08006 .60417 L
.07948 .60156 L
.07896 .59856 L
.0785 .59562 L
.07811 .59241 L
.07777 .58919 L
.07747 .5859 L
.07719 .58275 L
.0769 .57962 L
.07658 .57654 L
.07619 .57346 L
.07574 .57038 L
.07525 .56724 L
.07473 .56397 L
.07417 .56043 L
.07356 .55706 L
.07291 .55352 L
.07227 .54996 L
Mistroke
.07162 .54641 L
.07097 .54299 L
.07035 .53974 L
.06975 .5365 L
.06919 .5335 L
.0687 .53052 L
.06832 .5277 L
.06803 .52496 L
.06784 .52232 L
.06776 .51961 L
.06779 .51687 L
.06794 .51389 L
.0682 .51094 L
.06856 .50777 L
.06903 .50451 L
.06956 .50111 L
.07017 .49786 L
.07076 .49474 L
.07136 .49194 L
.07193 .48943 L
.07245 .48722 L
.07291 .48539 L
.07331 .48389 L
.07365 .4826 L
.07394 .48151 L
.07416 .48058 L
.07431 .47978 L
.0744 .47907 L
.07444 .47841 L
.07444 .47773 L
.07445 .47705 L
.0745 .47627 L
.07459 .4754 L
.07473 .47449 L
.07494 .47357 L
.07522 .47274 L
.07553 .47204 L
.07584 .47148 L
.07613 .47104 L
.07641 .47069 L
.07666 .47039 L
.07686 .4701 L
.07701 .46978 L
.0771 .4694 L
.07716 .46898 L
.07723 .46854 L
.07731 .46811 L
.07742 .46772 L
.07753 .46733 L
.07763 .46694 L
Mistroke
.07775 .46654 L
.07792 .46614 L
.07814 .46573 L
.07842 .46534 L
.07875 .46497 L
.07912 .46461 L
.07954 .46427 L
.07998 .46392 L
.08044 .46356 L
.08085 .46318 L
.0812 .46275 L
.08148 .46236 L
.08177 .46198 L
.08204 .46165 L
.08231 .46139 L
.08256 .4612 L
.08278 .46109 L
.08295 .46103 L
Mfstroke
.07677 .49198 m
.07671 .49211 L
.07662 .49235 L
.07647 .49273 L
.07621 .49328 L
.07584 .49403 L
.07534 .49499 L
.0747 .4961 L
.07411 .4973 L
.07337 .49872 L
.07257 .50041 L
.07174 .50238 L
.071 .50427 L
.07017 .50665 L
.06945 .50872 L
.06879 .51099 L
.0682 .51356 L
.06772 .51617 L
.06738 .51821 L
.06719 .52059 L
.06715 .52304 L
.06722 .525 L
.06739 .5269 L
.06762 .52858 L
.06789 .53009 L
.06816 .53123 L
.06841 .53225 L
.06866 .53292 L
.06891 .53333 L
.06915 .5335 L
.06937 .53347 L
.06954 .53334 L
.06965 .53315 L
.06969 .53295 L
.06967 .53281 L
.06961 .53277 L
.06952 .5329 L
.06945 .53324 L
.06942 .53381 L
.06946 .53459 L
.0696 .53557 L
.06981 .53674 L
.07009 .53797 L
.07045 .53934 L
.07085 .54081 L
.07127 .54229 L
.07173 .5437 L
.0722 .54503 L
.07267 .54622 L
.07309 .54719 L
Mistroke
.07348 .54798 L
.07382 .54856 L
.07408 .54895 L
.07427 .54917 L
.07437 .54926 L
.07441 .54927 L
.0744 .54922 L
.07436 .54913 L
.07431 .549 L
.07427 .54884 L
.07424 .54867 L
.07423 .54853 L
.07423 .54845 L
.07423 .54844 L
.07423 .54852 L
.07422 .54872 L
.07419 .54907 L
.07414 .54956 L
.07407 .55021 L
.074 .55101 L
.07394 .55198 L
.0739 .55305 L
.07391 .55423 L
.07395 .55553 L
.07405 .5569 L
.07418 .55826 L
.07435 .55954 L
.07454 .56072 L
.07473 .56175 L
.07493 .56261 L
.07517 .56329 L
.07544 .56382 L
.07574 .56423 L
.07605 .56456 L
.07633 .56486 L
.07656 .56517 L
.07672 .56549 L
.07681 .56584 L
.07685 .56622 L
.07687 .56666 L
.0769 .56715 L
.07697 .56773 L
.07711 .56842 L
.07732 .56919 L
.07756 .56999 L
.07783 .57082 L
.07811 .57165 L
.07837 .57244 L
.07869 .57317 L
.07903 .57382 L
Mistroke
.07941 .57436 L
.07978 .57484 L
.08017 .57525 L
.08052 .57559 L
.08081 .57587 L
.08101 .57609 L
.08112 .57626 L
.08115 .57636 L
.08114 .57639 L
.0811 .57636 L
.08106 .57629 L
.08101 .57621 L
.08096 .57611 L
.08092 .576 L
.08088 .57589 L
.08085 .57579 L
.08083 .57573 L
.08084 .57573 L
.08089 .57581 L
.08099 .57601 L
.08113 .57636 L
.0813 .57688 L
.08147 .57755 L
.08166 .57837 L
.08185 .57935 L
.08204 .58043 L
.08223 .58158 L
.0824 .58275 L
.08257 .58388 L
.08273 .5849 L
.08288 .58574 L
.08299 .58633 L
.08306 .58669 L
.0831 .58684 L
.08311 .58676 L
.08311 .58648 L
.08312 .58606 L
.08315 .58555 L
.0832 .585 L
.08325 .58445 L
.0833 .5839 L
.08333 .58341 L
.08334 .58302 L
.08333 .5828 L
.08332 .5827 L
.08331 .58268 L
.08331 .58271 L
.08333 .58274 L
.08336 .58274 L
.0834 .58269 L
Mistroke
.08344 .58262 L
.08346 .58257 L
.08345 .5826 L
.08341 .58272 L
.08332 .58297 L
.08319 .58336 L
.08301 .58387 L
.08276 .58448 L
.08244 .58518 L
.08205 .58596 L
.08161 .5868 L
.08116 .58764 L
.08073 .58847 L
.08032 .58926 L
.07996 .58999 L
.07964 .59061 L
.07935 .59112 L
.07912 .59151 L
.07892 .59182 L
.07876 .59203 L
.07865 .59218 L
.07859 .59231 L
.07858 .59244 L
.07861 .5926 L
.07869 .59276 L
.0788 .59294 L
.07893 .59312 L
.07907 .59333 L
.07918 .59351 L
.0793 .59371 L
.07943 .59393 L
.07955 .59408 L
.07971 .59424 L
.0799 .59435 L
.08007 .59442 L
.0802 .59447 L
.08028 .59452 L
.08031 .59459 L
.0803 .59464 L
.08029 .59467 L
.08027 .59467 L
.08026 .59466 L
.08025 .59464 L
.08024 .59462 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
Mistroke
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .5946 L
.08023 .59459 L
.08023 .59455 L
.08023 .59446 L
.08024 .59435 L
.08024 .59423 L
.08024 .59416 L
.08024 .59417 L
.08024 .59428 L
.08023 .59454 L
.08022 .59494 L
.08019 .59551 L
.08017 .59624 L
.08013 .59712 L
.08009 .59813 L
.08005 .59916 L
.08001 .60022 L
.07997 .60129 L
.07993 .60239 L
.07989 .60334 L
.07986 .60415 L
.07982 .60476 L
.07978 .60515 L
.07973 .60537 L
.07968 .60547 L
.07965 .60547 L
.07964 .60549 L
.07965 .60559 L
.07969 .60585 L
.07978 .60632 L
.07992 .60705 L
.08014 .6081 L
.08042 .60953 L
Mistroke
.08079 .61121 L
.0812 .61325 L
.08167 .61568 L
.0822 .61835 L
.08279 .62154 L
.0834 .62488 L
.08402 .62809 L
.08463 .63183 L
.08521 .63591 L
.08574 .63937 L
.08624 .64331 L
.08672 .64752 L
.08718 .65087 L
.08761 .6546 L
.08802 .65797 L
.08842 .66125 L
.08878 .66399 L
.08912 .6665 L
.08941 .6686 L
.08966 .67012 L
.08989 .67139 L
.0901 .67238 L
.09032 .6731 L
.09053 .67361 L
.09074 .674 L
.09096 .67439 L
.09116 .67484 L
.09136 .67536 L
.09154 .67597 L
.09173 .67672 L
.09194 .67761 L
.0922 .67868 L
.09249 .67986 L
.09281 .68106 L
.09312 .68227 L
.09343 .6835 L
.09372 .68465 L
.094 .68579 L
.09429 .68701 L
.09458 .68839 L
.0949 .68995 L
.0953 .69177 L
.0957 .69341 L
.09615 .69551 L
.09663 .69785 L
.09709 .70004 L
.09756 .70248 L
.09803 .70505 L
.09851 .70758 L
.099 .71034 L
Mistroke
.09948 .71237 L
.09994 .71445 L
.10034 .7163 L
.10066 .7178 L
.10089 .71897 L
.10104 .71979 L
.10116 .72032 L
.10126 .72055 L
.10135 .72063 L
.10146 .72062 L
.10157 .72053 L
.10167 .72045 L
.10177 .72041 L
.10186 .72043 L
.10193 .72048 L
.102 .72058 L
.10208 .72069 L
.10218 .7208 L
.10231 .7209 L
.10246 .72102 L
.10261 .72117 L
.10275 .72137 L
.10286 .7216 L
.10294 .72184 L
.10296 .72206 L
.10293 .72221 L
.10283 .72226 L
.10269 .72221 L
.10253 .72211 L
.10232 .72196 L
.10209 .72179 L
.10185 .72162 L
.10164 .72156 L
.10146 .72154 L
.10134 .72154 L
.10129 .72154 L
.10132 .72158 L
.10144 .72169 L
.10165 .72188 L
.10197 .72219 L
.10238 .7226 L
.10284 .72307 L
.10332 .7236 L
.10379 .72405 L
.10423 .72451 L
.10464 .72486 L
.10501 .72507 L
.10533 .7252 L
.10565 .72526 L
.10599 .72528 L
Mistroke
.10637 .72525 L
.10679 .72517 L
.10725 .72507 L
.10771 .72498 L
.10821 .7249 L
.10868 .7249 L
.10915 .72493 L
.10956 .72497 L
.1099 .72507 L
.11013 .72522 L
.11022 .72542 L
.11017 .72558 L
.10999 .72569 L
.10967 .7258 L
.10925 .72591 L
.10877 .72602 L
.10825 .72608 L
.10773 .72609 L
.10726 .72607 L
.10686 .72604 L
.10657 .72605 L
.1064 .72612 L
.10635 .72624 L
.10645 .72641 L
.10667 .7267 L
.10697 .72709 L
.10735 .72756 L
.10778 .72809 L
.10826 .72864 L
.10882 .72925 L
.10927 .72975 L
.10978 .73033 L
.11024 .73093 L
.11064 .73152 L
.11096 .73205 L
.11118 .73247 L
.11129 .73279 L
.11133 .733 L
.11133 .73312 L
.11133 .73318 L
.11148 .73312 L
.11149 .73313 L
.11155 .73317 L
.11162 .73322 L
.11171 .73328 L
.11181 .73333 L
.11192 .73337 L
.11203 .73337 L
.11213 .73336 L
.11223 .73333 L
Mistroke
.11233 .73329 L
.11243 .73328 L
.1125 .7333 L
.11252 .73331 L
.11248 .73332 L
.11236 .73329 L
.11217 .7332 L
.11194 .73305 L
.11171 .73284 L
.11149 .73264 L
.11129 .73247 L
.11115 .73236 L
.11105 .73232 L
.11098 .73235 L
.11092 .73242 L
.11087 .73254 L
.11078 .73267 L
.11067 .7328 L
.11054 .73291 L
.11042 .73301 L
.11035 .73309 L
.11036 .73321 L
.11044 .73338 L
.1106 .73356 L
.1108 .7337 L
.11102 .73379 L
.11126 .73382 L
.11155 .73384 L
.11181 .73382 L
.1121 .7338 L
.11237 .73378 L
.11262 .73375 L
.11279 .73371 L
.11285 .73362 L
.11279 .73347 L
.11264 .73328 L
.11241 .73307 L
.11213 .73284 L
.11181 .73259 L
.1115 .73236 L
.11122 .73217 L
.11101 .73211 L
.11089 .7322 L
.11089 .73248 L
.11104 .73296 L
.11134 .73364 L
.11181 .73453 L
.11243 .73543 L
.11318 .73646 L
.114 .73754 L
Mistroke
.11495 .73863 L
.116 .73971 L
.11714 .74081 L
.11833 .74189 L
.11953 .74292 L
.12069 .74385 L
.12178 .74467 L
.12276 .74536 L
.12359 .74593 L
.12427 .74638 L
.1248 .7467 L
.12515 .74694 L
.12538 .74716 L
.12546 .7474 L
.12542 .74761 L
.12528 .7478 L
.12508 .74796 L
.12481 .74807 L
.12455 .74816 L
.1243 .74827 L
.12406 .74837 L
.12385 .74849 L
.12377 .74867 L
.12379 .74888 L
.12392 .7491 L
.12411 .74928 L
.12439 .74942 L
.12473 .74951 L
.12513 .74957 L
.12558 .74959 L
.12602 .74959 L
.12647 .74958 L
.12686 .74954 L
.12722 .74952 L
.12756 .74954 L
.12789 .74959 L
.12818 .74965 L
.12843 .7497 L
.12859 .74969 L
.12865 .74964 L
.12859 .74956 L
.12845 .74949 L
.12827 .74942 L
.12809 .74936 L
.12794 .74929 L
.12781 .74925 L
.12772 .74925 L
.12767 .74933 L
.12765 .74952 L
.12765 .7498 L
Mistroke
.12766 .75013 L
.12772 .75054 L
.1278 .751 L
.12789 .75152 L
.128 .75207 L
.12811 .75258 L
.12823 .7531 L
.12834 .75358 L
.12847 .75401 L
.12863 .7544 L
.12885 .75474 L
.12917 .75502 L
.1296 .75523 L
.13017 .75542 L
.13088 .75555 L
.13166 .75563 L
.13253 .75565 L
.13341 .75569 L
.13428 .75574 L
.13509 .75581 L
.13581 .75587 L
.13638 .75593 L
.13671 .75598 L
.13701 .75602 L
.13721 .75606 L
.13728 .75608 L
.13723 .75608 L
.13706 .75604 L
.1368 .756 L
.13649 .75596 L
.13616 .75591 L
.1358 .75584 L
.13542 .75574 L
.13503 .7556 L
.13463 .75546 L
.13425 .75534 L
.13395 .7553 L
.13376 .75538 L
.13371 .75562 L
.13381 .75601 L
.13405 .75656 L
.13443 .75727 L
.13497 .7581 L
.13557 .75902 L
.13613 .75994 L
.13687 .76089 L
.13775 .7619 L
.13869 .76288 L
.13972 .76389 L
.14082 .7649 L
Mistroke
.14197 .76594 L
.14319 .76701 L
.14447 .76812 L
.14575 .76923 L
.14707 .77039 L
.14856 .77171 L
.14979 .77284 L
.15118 .77415 L
.15249 .77543 L
.15373 .7767 L
.15482 .77791 L
.15568 .77896 L
.15633 .77982 L
.15679 .78049 L
.15705 .78096 L
.15713 .78126 L
.15705 .7814 L
.15685 .78142 L
.15655 .7813 L
.1562 .7811 L
.15585 .78086 L
.15554 .78064 L
.15535 .78052 L
.15535 .78056 L
.15559 .78083 L
.1561 .78132 L
.15691 .78209 L
.15798 .78313 L
.15938 .78444 L
.16112 .78606 L
.16317 .78796 L
.16546 .78991 L
.16797 .79206 L
.17076 .7946 L
.1735 .79698 L
.17641 .79954 L
.17935 .80216 L
.18233 .80478 L
.18523 .80746 L
.18817 .81009 L
.19115 .81281 L
.1942 .81557 L
.19732 .81844 L
.2006 .82167 L
.20366 .82444 L
.20695 .82768 L
.21033 .83097 L
.21368 .83413 L
.21698 .83729 L
.22024 .8404 L
Mistroke
.22326 .84331 L
.22615 .84604 L
.22874 .84847 L
.23109 .85066 L
.23311 .85239 L
.23483 .8538 L
.23622 .85484 L
.23741 .85555 L
.23818 .85596 L
.23881 .85619 L
.23924 .85627 L
.23948 .85625 L
.23964 .8562 L
.2397 .8561 L
.23973 .85602 L
.23976 .85599 L
.23986 .85609 L
.24003 .8563 L
.24032 .85664 L
.24076 .85711 L
.24137 .85774 L
.24214 .85846 L
.24306 .85919 L
.2441 .85992 L
.24535 .86066 L
.24673 .86138 L
.24825 .86213 L
.24985 .86287 L
.25144 .8636 L
.253 .86431 L
.2544 .8649 L
.25558 .86532 L
.25653 .86561 L
.25729 .86583 L
.25788 .866 L
.2583 .8661 L
.25859 .86613 L
.25875 .86613 L
.25876 .8661 L
.25865 .86608 L
.25844 .86607 L
.25816 .86604 L
.25783 .866 L
.25752 .86599 L
.25724 .86599 L
.25698 .86608 L
.25673 .86622 L
.25647 .86643 L
.25632 .86664 L
.25611 .86681 L
Mistroke
.25593 .86703 L
.25584 .8673 L
.25595 .86772 L
.25625 .86822 L
.25683 .86889 L
.25772 .8697 L
.2589 .87063 L
.26037 .87161 L
.26206 .87259 L
.26402 .87363 L
.26621 .87474 L
.26868 .87593 L
.27126 .87719 L
.27389 .87842 L
.27665 .87966 L
.27935 .88087 L
.28222 .88203 L
.28483 .88317 L
.28751 .88429 L
.29018 .88536 L
.29281 .88642 L
.29543 .88744 L
.29807 .88843 L
.30077 .88939 L
.30358 .89031 L
.30657 .8912 L
.3096 .89208 L
.31282 .89295 L
.31626 .89383 L
.31951 .89473 L
.32283 .89565 L
.3262 .89659 L
.32964 .89751 L
.3327 .89844 L
.33573 .89935 L
.33854 .9002 L
.34106 .90095 L
.3433 .90164 L
.34524 .90226 L
.34683 .90279 L
.34824 .90324 L
.34944 .90363 L
.35061 .90399 L
.35179 .90435 L
.35304 .90474 L
.35441 .90519 L
.35591 .90573 L
.35762 .90634 L
.35961 .90704 L
.36176 .90785 L
Mistroke
.36423 .90876 L
.36704 .90972 L
.37006 .91071 L
.37344 .91175 L
.37676 .91279 L
.38041 .91387 L
.38387 .91503 L
.38739 .91617 L
.39106 .9174 L
.39465 .91873 L
.39834 .91998 L
.4021 .92131 L
.40596 .92262 L
.40979 .92402 L
.41368 .92535 L
.41775 .92686 L
.42171 .92819 L
.42588 .92953 L
.42994 .93087 L
.4341 .93214 L
.43809 .93328 L
.44216 .93427 L
.44593 .93505 L
.44962 .9357 L
.45306 .93629 L
.45626 .93679 L
.45936 .93721 L
.46194 .93753 L
.46436 .93773 L
.46651 .9378 L
.46843 .93777 L
.47003 .93764 L
.47148 .93744 L
.47252 .93724 L
.47339 .93707 L
.47407 .93696 L
.47462 .93688 L
.47502 .93678 L
.47533 .93667 L
.47558 .93655 L
.47577 .93643 L
.47587 .93631 L
.4759 .93622 L
.47585 .93615 L
.47575 .93613 L
.47558 .93614 L
.4754 .93618 L
.47521 .93623 L
.47501 .93627 L
.47476 .9363 L
Mistroke
.47447 .93632 L
.47414 .93633 L
.47384 .93635 L
.47349 .93637 L
.47314 .93638 L
.47283 .93639 L
.47258 .93639 L
.47235 .93639 L
.47214 .93639 L
.47201 .9364 L
.47193 .93642 L
.4719 .93645 L
.47195 .93618 L
.47207 .93623 L
.47225 .93628 L
.47249 .93633 L
.47282 .93637 L
.4732 .9364 L
.47357 .93643 L
.47387 .93645 L
.47418 .93648 L
.47445 .93652 L
.47466 .93658 L
.47484 .93664 L
.47505 .93672 L
.47528 .9368 L
.47556 .9369 L
.47589 .93697 L
.47632 .93701 L
.47686 .93701 L
.47753 .93699 L
.47833 .93694 L
.47933 .93685 L
.48051 .9367 L
.48186 .93649 L
.48336 .93623 L
.48492 .93596 L
.48659 .93568 L
.48836 .93542 L
.49029 .93518 L
.4923 .93497 L
.49462 .93477 L
.49666 .93461 L
.49906 .93444 L
.50152 .93424 L
.5042 .93403 L
.50704 .93377 L
.51014 .93347 L
.51325 .93314 L
.51633 .93276 L
Mistroke
.51937 .93237 L
.52254 .93196 L
.52553 .93155 L
.52849 .93112 L
.53145 .93072 L
.53408 .93035 L
.53675 .92999 L
.53936 .92966 L
.54193 .92934 L
.54446 .92897 L
.54697 .92852 L
.54942 .92794 L
.55186 .92725 L
.5542 .92646 L
.55642 .92569 L
.55861 .92491 L
.56061 .9242 L
.56253 .92364 L
.56431 .92315 L
.56578 .92275 L
.56703 .92244 L
.5681 .92224 L
.56904 .92217 L
.56995 .92226 L
.57096 .92249 L
.57224 .92282 L
.57357 .9232 L
.5753 .92353 L
.5773 .92379 L
.57958 .92391 L
.58223 .92385 L
.58508 .92364 L
.5882 .92336 L
.59162 .92293 L
.59497 .92242 L
.5989 .92205 L
.60247 .92148 L
.60608 .92088 L
.60962 .92026 L
.61297 .91958 L
.6162 .9189 L
.61933 .91814 L
.62235 .91732 L
.62532 .9165 L
.62823 .91568 L
.63098 .91491 L
.63357 .91416 L
.63594 .91352 L
.63806 .91287 L
.63995 .91224 L
Mistroke
.64159 .91167 L
.64309 .91121 L
.64445 .91082 L
.64572 .91047 L
.64691 .91012 L
.64802 .90978 L
.64901 .90954 L
.64981 .9094 L
.65052 .90928 L
.65112 .90924 L
.65163 .9092 L
.6521 .9091 L
.65252 .90896 L
.65286 .90882 L
.65303 .90874 L
.65299 .90877 L
.65275 .90886 L
.65234 .90907 L
.65181 .90938 L
.65123 .90974 L
.65069 .91003 L
.65025 .91032 L
.6499 .91062 L
.64962 .91093 L
.64936 .91118 L
.64914 .91144 L
.64892 .91169 L
.64868 .91189 L
.6485 .91201 L
.64844 .91199 L
.64841 .91191 L
.64851 .9116 L
.64871 .91112 L
.64897 .91053 L
.64917 .91 L
.64933 .90949 L
.64943 .90896 L
.64956 .90839 L
.64968 .90796 L
.64987 .90753 L
.65008 .90716 L
.6503 .90695 L
.65044 .90693 L
.65054 .90701 L
.65058 .9072 L
.65052 .90742 L
.65038 .90777 L
.65024 .90809 L
.65016 .90832 L
.65022 .90849 L
Mistroke
.6504 .90861 L
.65069 .90865 L
.65112 .90853 L
.65159 .9084 L
.65199 .90826 L
.6523 .9081 L
.65252 .90787 L
.65263 .90777 L
.65255 .90783 L
.65233 .90804 L
.65194 .90834 L
.65141 .90879 L
.65081 .90931 L
.65026 .90979 L
.64982 .91006 L
.64951 .91021 L
.64925 .91029 L
.64906 .91033 L
.64906 .91028 L
.64919 .9102 L
.64938 .91013 L
.6497 .91001 L
.65006 .90985 L
.65039 .90973 L
.65063 .9097 L
.65075 .90971 L
.65072 .90985 L
.65059 .91008 L
.65043 .91033 L
.65023 .91059 L
.65007 .91081 L
.64996 .91092 L
.64991 .91094 L
.65001 .91076 L
.65024 .91047 L
.65055 .9101 L
.65082 .9098 L
.65112 .90947 L
.65142 .90918 L
.65177 .90891 L
.65203 .90875 L
.65229 .90861 L
.6525 .90853 L
.65268 .90853 L
.65285 .90861 L
.65307 .90872 L
.65336 .90879 L
.65367 .90886 L
.65391 .90898 L
.65402 .90915 L
Mistroke
.65402 .90935 L
.65391 .90959 L
.65373 .90982 L
.65352 .91 L
.65336 .91008 L
.65324 .91008 L
.65316 .91002 L
.65307 .90991 L
.65301 .90973 L
.65298 .90954 L
.65293 .90941 L
.6529 .90929 L
.65293 .90916 L
.6531 .909 L
.65341 .90882 L
.65378 .90866 L
.65422 .9085 L
.65462 .90838 L
.6549 .90835 L
.65504 .90842 L
.65505 .90857 L
.65498 .90878 L
.65483 .90902 L
.65466 .90924 L
.65449 .9094 L
.6543 .90938 L
.65412 .90948 L
.65394 .90956 L
.6538 .90959 L
.65376 .90953 L
.65375 .90946 L
.65384 .9093 L
.65399 .90909 L
.65418 .90883 L
.65431 .90864 L
.65444 .90845 L
.65455 .90828 L
.65461 .90817 L
.65454 .90817 L
.65442 .90822 L
.65426 .90827 L
.65404 .90839 L
.65371 .90862 L
.65337 .90891 L
.65309 .9092 L
.65287 .90953 L
.65265 .90993 L
.65247 .91036 L
.65236 .91074 L
.65227 .91116 L
Mistroke
.65222 .9116 L
.65223 .91205 L
.65228 .91247 L
.65231 .91284 L
.65232 .91316 L
.65232 .91337 L
.65242 .91345 L
.6526 .9134 L
.65289 .91325 L
.65335 .9129 L
.65393 .91239 L
.65455 .91183 L
.65512 .91131 L
.65568 .91074 L
.65617 .91023 L
.65657 .90981 L
.65691 .90948 L
.6572 .90923 L
.6574 .90908 L
.65753 .90906 L
.65761 .90911 L
.65771 .90917 L
.65777 .90921 L
.65779 .90925 L
.6578 .90927 L
.65788 .9092 L
.65807 .90905 L
.65841 .90888 L
.65886 .90869 L
.65945 .90848 L
.66008 .90825 L
.66076 .90801 L
.66141 .90775 L
.66204 .90749 L
.66263 .90723 L
.66318 .90701 L
.66366 .90687 L
.664 .90685 L
.66412 .90693 L
.66403 .90712 L
.66378 .90738 L
.66345 .90766 L
.66308 .90788 L
.66279 .90799 L
.66245 .90805 L
.66202 .90818 L
.6615 .90844 L
.66091 .9088 L
.66025 .90926 L
.65946 .90995 L
Mistroke
.65862 .91053 L
.65785 .91104 L
.65732 .9114 L
.657 .91162 L
.65683 .91169 L
.65675 .91168 L
.65665 .91163 L
.65638 .91168 L
.65623 .91162 L
.65614 .91151 L
.65624 .91126 L
.65666 .91083 L
.6573 .91033 L
.65807 .9098 L
.65882 .9093 L
.65949 .90887 L
.65987 .90862 L
.65988 .90858 L
.65962 .90866 L
.6591 .90875 L
.65845 .90885 L
.65767 .90895 L
.65695 .90901 L
.65635 .90897 L
.65594 .90882 L
.65567 .90861 L
.65542 .90844 L
.65516 .90836 L
.65494 .90838 L
.65481 .90851 L
.65481 .90873 L
.65495 .90897 L
.65521 .9092 L
.6555 .9094 L
.65571 .90958 L
.65577 .90977 L
.65562 .90999 L
.65536 .91022 L
.65503 .91046 L
.65471 .91067 L
.65445 .91074 L
.65435 .91071 L
.65433 .91061 L
.65438 .91049 L
.6545 .91036 L
.65461 .91028 L
.65471 .91024 L
.65477 .91019 L
.65481 .91018 L
.65491 .91017 L
Mistroke
.65514 .91014 L
.65547 .9101 L
.65594 .91002 L
.65639 .90997 L
.65673 .91001 L
.65697 .91009 L
.65711 .91026 L
.65718 .91045 L
.65726 .91059 L
.65739 .91059 L
.65756 .91048 L
.65768 .91032 L
.65766 .91013 L
.65741 .91 L
.65695 .90989 L
.65635 .90974 L
.65577 .9096 L
.65534 .90933 L
.65524 .90875 L
.65519 .90845 L
.65533 .90822 L
.65561 .90806 L
.65603 .90798 L
.65642 .908 L
.65679 .90809 L
.65708 .90819 L
.65729 .90831 L
.65742 .90845 L
.65742 .90864 L
.65731 .9089 L
.65704 .90923 L
.65661 .90962 L
.656 .91006 L
.65526 .91052 L
.65436 .91097 L
.65357 .91126 L
.65279 .91152 L
.65206 .91172 L
.65149 .91187 L
.65107 .91199 L
.65081 .91207 L
.65075 .91203 L
.65083 .91191 L
.65111 .91167 L
.65156 .91135 L
.65215 .91092 L
.65287 .9104 L
.65363 .90991 L
.65437 .90954 L
.65514 .9092 L
Mistroke
.65591 .90895 L
.65661 .90881 L
.65727 .90873 L
.65787 .90863 L
.6584 .90855 L
.65878 .90851 L
.65899 .90853 L
.65901 .90861 L
.65886 .90878 L
.65859 .90899 L
.65831 .90917 L
.65812 .90926 L
.65815 .90922 L
.65842 .90906 L
.65882 .90886 L
.65937 .9086 L
.66003 .90831 L
.6609 .90797 L
.66168 .90769 L
.66262 .90736 L
.66354 .90706 L
.66439 .9068 L
.6651 .90659 L
.66567 .9064 L
.66609 .90623 L
.66629 .90614 L
.6662 .90619 L
.66587 .90635 L
.66534 .90657 L
.66472 .90686 L
.66399 .90717 L
.66325 .90747 L
.66263 .90774 L
.66224 .90792 L
.66208 .90806 L
.66217 .90813 L
.66252 .90813 L
.66303 .90813 L
.66365 .90811 L
.66455 .90799 L
.66586 .90752 L
.66717 .90727 L
.66864 .90692 L
.67024 .90646 L
.67195 .90588 L
.67371 .90521 L
.67554 .90447 L
.67739 .90366 L
.6792 .90277 L
.68087 .90182 L
Mistroke
.68249 .90077 L
.68402 .89973 L
.68543 .89861 L
.68665 .89755 L
.68765 .89663 L
.68842 .89583 L
.68896 .89518 L
.68924 .89473 L
.68928 .89449 L
.68908 .89447 L
.68867 .89461 L
.68809 .89489 L
.68746 .89528 L
.68677 .8958 L
.68608 .89644 L
.68552 .89699 L
.68505 .89755 L
.68476 .89793 L
.6847 .89806 L
.68486 .89799 L
.68515 .89774 L
.68544 .89741 L
.68574 .89704 L
.68602 .8967 L
.68628 .89638 L
.68651 .89611 L
.6867 .89584 L
.68687 .8956 L
.687 .89545 L
.68712 .89539 L
.68721 .89542 L
.68721 .89558 L
.68712 .89585 L
.687 .89622 L
.68695 .89661 L
.68701 .89696 L
.6872 .89719 L
.68749 .89734 L
.6878 .89736 L
.6881 .89737 L
.68836 .89743 L
.68851 .89759 L
.68863 .89779 L
.68876 .89798 L
.68899 .89811 L
.68942 .89809 L
.69007 .89789 L
.69097 .89753 L
.69183 .89715 L
.69285 .89667 L
Mistroke
.69387 .89613 L
.69478 .89557 L
.69576 .89501 L
.69663 .89445 L
.69739 .89388 L
.69799 .89334 L
.69838 .8929 L
.69854 .89257 L
.69842 .89238 L
.69801 .89236 L
.69731 .89254 L
.69645 .89282 L
.69561 .89313 L
.6948 .89341 L
.69429 .89352 L
.69364 .89377 L
.69302 .89398 L
.69245 .89424 L
.6919 .89456 L
.6914 .89498 L
.6909 .89547 L
.69039 .896 L
.68988 .89649 L
.6894 .8969 L
.68891 .89727 L
.68852 .89751 L
.68812 .89772 L
.68778 .89784 L
.6875 .89789 L
.68731 .89791 L
.68723 .89792 L
.68716 .89793 L
.68712 .8979 L
.6871 .89789 L
.68705 .89788 L
.68698 .89788 L
.68682 .89799 L
.68657 .89825 L
.68625 .8986 L
.68589 .89896 L
.68548 .8993 L
.68501 .89959 L
.68446 .89981 L
.68386 .89994 L
.68322 .89999 L
.68258 .89998 L
.68202 .89997 L
.68143 .90001 L
.6809 .90012 L
.68045 .9003 L
Mistroke
.68006 .90055 L
.6797 .90086 L
.67938 .90123 L
.67913 .90163 L
.67894 .90206 L
.67878 .90249 L
.67862 .90291 L
.67843 .90334 L
.6782 .90375 L
.67793 .90411 L
.67762 .90441 L
.67733 .90464 L
.67707 .90481 L
.67686 .90491 L
.67668 .90495 L
.67659 .90494 L
.67654 .9049 L
.67652 .90484 L
.67654 .90479 L
.67658 .90478 L
.67662 .90482 L
.67665 .90488 L
.67667 .90495 L
.67667 .90496 L
.67669 .90491 L
.67669 .90477 L
.67667 .90457 L
.67661 .90435 L
.67651 .90413 L
.67636 .90392 L
.67622 .90368 L
.67615 .9034 L
.67616 .90308 L
.67624 .90274 L
.67636 .90242 L
.67647 .90215 L
.67654 .90196 L
.67654 .90189 L
.67649 .90196 L
.67641 .90218 L
.67631 .9025 L
.67619 .90285 L
.67611 .90317 L
.67607 .9034 L
.67612 .90352 L
.67608 .90361 L
.676 .90367 L
.67586 .90376 L
.67568 .90387 L
.67547 .90401 L
Mistroke
.6753 .90412 L
.6752 .90418 L
.67521 .90417 L
.67527 .90413 L
.67534 .9041 L
.67536 .90418 L
.67536 .90432 L
.67535 .90449 L
.67537 .90464 L
.6754 .90475 L
.67545 .90479 L
.67549 .90477 L
.67549 .90469 L
.67549 .90453 L
.67547 .90435 L
.67541 .9042 L
.67529 .90413 L
.67515 .90417 L
.67504 .90427 L
.67498 .9044 L
.67494 .90457 L
.67494 .90473 L
.67496 .90486 L
.67498 .90493 L
.67497 .90492 L
.67489 .9048 L
.67471 .90458 L
.67441 .90434 L
.67402 .90402 L
.6736 .90364 L
.67317 .9032 L
.67267 .90276 L
.67215 .90236 L
.67167 .90201 L
.67132 .90169 L
.67108 .9014 L
.67092 .90116 L
.6708 .901 L
.67068 .90098 L
.67048 .90106 L
.67022 .90123 L
.66989 .90141 L
.66951 .90159 L
.66906 .90173 L
.66858 .90183 L
.66814 .90191 L
.66783 .90199 L
.66757 .90205 L
.66737 .90209 L
.66726 .90213 L
Mistroke
.66721 .9022 L
.66727 .90223 L
.66741 .90225 L
.66757 .9023 L
.66763 .90248 L
.66757 .90276 L
.66733 .90312 L
.66696 .90352 L
.66646 .90394 L
.66589 .90438 L
.66515 .9048 L
.66457 .90511 L
.66399 .90533 L
.66341 .90549 L
.66282 .90556 L
.66231 .90556 L
.66188 .90554 L
.66148 .90543 L
.66125 .90561 L
.66102 .90539 L
.66088 .90509 L
.66072 .90478 L
.66038 .90444 L
.65997 .90418 L
.65955 .90398 L
.65908 .90379 L
.65866 .90366 L
.65832 .90353 L
.65824 .9035 L
.65835 .90351 L
.6587 .9036 L
.65924 .90376 L
.6599 .90396 L
.66057 .90415 L
.66125 .90431 L
.66193 .90442 L
.66271 .90448 L
.66352 .90447 L
.66433 .90443 L
.66508 .90438 L
.66576 .90427 L
.66634 .90404 L
.66684 .9037 L
.66729 .90329 L
.66769 .90287 L
.66807 .90249 L
.66851 .90218 L
.66909 .90198 L
.66985 .90189 L
.67071 .90188 L
Mistroke
.67163 .90189 L
.67273 .90187 L
.67398 .90178 L
.67538 .90158 L
.67688 .90128 L
.67848 .90093 L
.68014 .90049 L
.68186 .9 L
.68359 .89946 L
.68533 .89888 L
.68709 .89824 L
.68869 .89753 L
.69041 .89672 L
.69213 .89583 L
.69393 .89486 L
.69577 .89378 L
.69764 .89259 L
.69954 .89127 L
.70148 .88979 L
.70346 .88816 L
.70546 .88643 L
.70746 .8846 L
.70946 .88271 L
.71144 .8808 L
.71342 .8789 L
.71557 .87675 L
.71726 .87511 L
.71893 .87335 L
.72039 .87184 L
.72161 .87056 L
.72259 .86958 L
.72335 .86892 L
.7239 .86852 L
.72425 .86834 L
.72443 .8683 L
.72448 .86837 L
.72441 .8685 L
.72423 .86864 L
.72397 .86875 L
.72368 .86876 L
.72336 .86865 L
.72304 .86842 L
.72275 .86808 L
.72247 .86761 L
.72222 .86701 L
.72198 .86634 L
.72173 .8657 L
.72146 .86517 L
.72114 .86475 L
.72078 .8645 L
Mistroke
.72042 .86445 L
.72009 .86464 L
.71981 .86503 L
.71959 .8654 L
.71941 .86611 L
.71923 .86689 L
.71902 .86793 L
.71874 .86891 L
.71836 .86989 L
.71784 .87107 L
.71721 .87212 L
.71643 .87321 L
.7155 .87436 L
.71446 .87537 L
.71326 .87639 L
.71191 .87735 L
.71051 .87823 L
.70897 .87905 L
.70744 .87989 L
.70583 .88074 L
.70429 .88158 L
.70279 .88246 L
.70133 .88345 L
.69987 .88455 L
.69834 .88576 L
.69678 .88704 L
.69513 .88839 L
.69334 .88973 L
.69159 .89118 L
.68969 .89271 L
.68765 .89431 L
.68554 .8959 L
.68344 .89738 L
.68134 .89875 L
.6793 .89996 L
.67746 .90099 L
.67572 .90181 L
.67418 .90242 L
.67286 .90285 L
.67184 .90318 L
.67088 .9035 L
.67005 .90379 L
.66925 .90405 L
.66837 .90437 L
.66739 .90477 L
.6663 .90524 L
.66495 .90572 L
.66326 .90628 L
.6612 .90693 L
.65894 .90768 L
Mistroke
.65598 .90857 L
.65306 .90948 L
.64948 .91047 L
.64585 .91145 L
.6418 .91237 L
.63809 .91328 L
.63415 .91421 L
.63044 .91506 L
.6265 .91586 L
.62301 .91658 L
.61935 .91728 L
.61592 .91787 L
.6128 .91841 L
.60952 .91881 L
.60637 .91908 L
.60325 .9192 L
.60011 .9193 L
.59719 .91939 L
.59405 .9195 L
.59111 .91958 L
.5879 .9197 L
.58464 .91991 L
.58097 .92024 L
.57748 .92065 L
.5737 .92112 L
.56945 .92167 L
.56576 .92226 L
.56162 .92299 L
.55779 .9238 L
.55372 .92466 L
.54998 .92546 L
.54616 .92616 L
.54233 .92675 L
.53887 .9272 L
.53545 .92756 L
.53219 .92782 L
.5292 .92804 L
.52645 .92825 L
.52404 .92854 L
.52211 .92891 L
.52016 .92931 L
.51855 .92974 L
.51704 .93017 L
.51571 .93057 L
.51459 .93091 L
.51368 .9312 L
.51301 .93139 L
.51253 .93144 L
.51222 .93139 L
.51206 .93125 L
Mistroke
.512 .93102 L
.51195 .93071 L
.51185 .93029 L
.5117 .92979 L
.51149 .92927 L
.51123 .92878 L
.51094 .9284 L
.51063 .92817 L
.51033 .92811 L
.51002 .92819 L
.50971 .92839 L
.50939 .92864 L
.50909 .9289 L
.50875 .92913 L
.50843 .92931 L
.50814 .92946 L
.50784 .92959 L
.50752 .9297 L
.50722 .92974 L
.50688 .92975 L
.50645 .92971 L
.50588 .92963 L
.50517 .92951 L
.50437 .92933 L
.5034 .92911 L
.50229 .92886 L
.50111 .92858 L
.4999 .92827 L
.49874 .92794 L
.49762 .9276 L
.49655 .92724 L
.49569 .92693 L
.49489 .92663 L
.49424 .9263 L
.4938 .92598 L
.49359 .92573 L
.49363 .92559 L
.49388 .92555 L
.49428 .92559 L
.4948 .92568 L
.49533 .92582 L
.49578 .92597 L
.49609 .92612 L
.49625 .92618 L
.49628 .92621 L
.49624 .92629 L
.49613 .92639 L
.49597 .92651 L
.49578 .92665 L
.49553 .92679 L
Mistroke
.49528 .92692 L
.4951 .92702 L
.49504 .9271 L
.4951 .92715 L
.4953 .92713 L
.49564 .92709 L
.49609 .92703 L
.4965 .92701 L
.49695 .92696 L
.49735 .92677 L
.49765 .92658 L
.4978 .92628 L
.49783 .92597 L
.49781 .9257 L
.49782 .9255 L
.4978 .9254 L
.49779 .92542 L
.4978 .92556 L
.49781 .92573 L
.49776 .92594 L
.49765 .92615 L
.49755 .92634 L
.4975 .92658 L
.49749 .92683 L
.49751 .92711 L
.49756 .92742 L
.49757 .92773 L
.49751 .92795 L
.49733 .92806 L
.49709 .92806 L
.4969 .92801 L
.4968 .92795 L
.49682 .92786 L
.497 .92778 L
.49732 .92777 L
.49775 .92784 L
.49817 .9279 L
.4985 .92803 L
.49853 .92823 L
.49818 .92849 L
.49744 .92881 L
.4964 .92924 L
.49502 .92977 L
.49344 .93038 L
.49156 .9309 L
.48951 .93142 L
.48741 .93196 L
.48504 .93247 L
.48234 .93285 L
.47988 .93319 L
Mistroke
.47752 .93349 L
.47529 .93378 L
.47335 .9341 L
.47179 .93443 L
.47064 .93482 L
.46972 .93513 L
.46896 .9354 L
.46829 .93557 L
.46766 .93562 L
.467 .93554 L
.46627 .93532 L
.46544 .93499 L
.46464 .93455 L
.46373 .93401 L
.46277 .9334 L
.46171 .93274 L
.46057 .93207 L
.45927 .93142 L
.45783 .93077 L
.45627 .9301 L
.45474 .92955 L
.45316 .929 L
.45168 .92856 L
.45033 .92827 L
.44914 .92814 L
.44806 .92814 L
.44703 .92818 L
.44593 .92817 L
.44477 .92809 L
.44346 .92795 L
.44185 .92773 L
.44027 .92748 L
.43843 .92716 L
.4363 .92682 L
.43394 .92633 L
.4316 .92576 L
.42907 .92511 L
.42626 .92433 L
.42289 .92356 L
.41986 .9227 L
.41636 .92172 L
.41291 .92082 L
.4092 .91987 L
.40526 .91893 L
.40175 .91798 L
.39779 .91705 L
.39402 .91604 L
.38991 .91493 L
.38574 .91371 L
.38198 .91247 L
Mistroke
.37798 .91116 L
.37405 .90978 L
.36999 .90843 L
.3664 .90707 L
.36266 .9057 L
.35895 .90438 L
.35535 .90305 L
.35181 .90175 L
.34811 .90044 L
.34452 .89915 L
.34113 .89788 L
.33751 .89663 L
.33396 .89542 L
.33016 .89427 L
.32675 .89316 L
.32316 .89211 L
.31946 .8911 L
.31611 .89015 L
.31286 .88923 L
.30948 .8883 L
.30623 .88736 L
.30289 .88641 L
.29969 .88542 L
.29639 .88436 L
.29311 .88323 L
.29022 .88201 L
.28712 .88071 L
.28418 .87946 L
.2812 .87815 L
.27837 .87684 L
.27567 .87558 L
.27293 .87431 L
.27039 .87308 L
.26783 .87184 L
.26554 .87063 L
.26334 .86948 L
.26132 .86837 L
.25954 .86731 L
.25799 .86632 L
.25671 .86543 L
.25569 .86459 L
.25489 .86382 L
.25434 .86316 L
.254 .86264 L
.25383 .86221 L
.25374 .86183 L
.25367 .86152 L
.25351 .86122 L
.2532 .86092 L
.25268 .86058 L
Mistroke
.25194 .8602 L
.25088 .85958 L
.24946 .85871 L
.24763 .85754 L
.24546 .85613 L
.243 .85443 L
.24014 .85237 L
.23704 .85015 L
.23376 .84771 L
.23027 .84503 L
.2269 .84242 L
.22342 .83964 L
.22008 .83681 L
.21679 .83429 L
.21358 .83161 L
.21055 .82894 L
.20758 .82632 L
.20474 .82371 L
.20196 .82126 L
.19926 .81878 L
.19661 .8164 L
.19399 .81399 L
.19131 .81146 L
.18869 .80899 L
.18614 .8066 L
.18368 .80415 L
.18136 .80174 L
.17913 .79953 L
.17715 .79739 L
.17523 .79538 L
.17373 .79361 L
.17241 .79195 L
.1713 .79043 L
.17041 .78912 L
.16965 .78793 L
.16899 .78683 L
.1683 .78581 L
.16751 .78483 L
.16656 .78381 L
.16536 .78269 L
.16393 .78145 L
.16216 .78 L
.16001 .77829 L
.15801 .77649 L
.15564 .77444 L
.1529 .77231 L
.15054 .77013 L
.1479 .76779 L
.1451 .76535 L
.1427 .7631 L
Mistroke
.14006 .76069 L
.13736 .75818 L
.13506 .75569 L
.13267 .75324 L
.13026 .75077 L
.12824 .74855 L
.12613 .74633 L
.12404 .74415 L
.12207 .74203 L
.12011 .73997 L
.11823 .73792 L
.11656 .73618 L
.11496 .73455 L
.1135 .73307 L
.11222 .73175 L
.11123 .73066 L
.11031 .72968 L
.10955 .7288 L
.10885 .72787 L
.10818 .72684 L
.10753 .72571 L
.1069 .72445 L
.10629 .72307 L
.10574 .72171 L
.10529 .72024 L
.10489 .7188 L
.10456 .71748 L
.10426 .71626 L
.10396 .71496 L
.10367 .71377 L
.10338 .71262 L
.1031 .71148 L
.1028 .71032 L
.10246 .70912 L
.10207 .70782 L
.10161 .70631 L
.10108 .70455 L
.10045 .70255 L
.09977 .70061 L
.09902 .6983 L
.0982 .69578 L
.09736 .69304 L
.09655 .69011 L
.09579 .68728 L
.09512 .6845 L
.09458 .68164 L
.09418 .67906 L
.09391 .6767 L
.09373 .67441 L
.0936 .67226 L
Mistroke
.09346 .67025 L
.0933 .66834 L
.0931 .66646 L
.09286 .66469 L
.09259 .6629 L
.09229 .66111 L
.09195 .65927 L
.09158 .65746 L
.09113 .65544 L
.09059 .65329 L
.08999 .65081 L
.0893 .64832 L
.08854 .64546 L
.08772 .64239 L
.08688 .63917 L
.08604 .63592 L
.08526 .63224 L
.08457 .62897 L
.08395 .62554 L
.08338 .62202 L
.08288 .6191 L
.08242 .6162 L
.08202 .61359 L
.08169 .61137 L
.08141 .60944 L
.0812 .608 L
.08104 .6069 L
.08095 .60613 L
.08091 .60562 L
.08096 .60535 L
.08098 .60524 L
.08103 .60526 L
.08107 .60536 L
.08111 .60547 L
.08113 .60555 L
.08116 .60555 L
.08121 .60541 L
.08127 .6051 L
.08132 .60461 L
.08133 .60392 L
.08128 .603 L
.08115 .60191 L
.08092 .60049 L
.08057 .59878 L
.08023 .59669 L
.0798 .59436 L
.07933 .59158 L
.07886 .58873 L
.07837 .58544 L
.07787 .582 L
Mistroke
.07735 .57832 L
.07681 .57443 L
.07625 .57049 L
.07565 .56681 L
.07504 .56298 L
.07446 .5593 L
.07392 .55622 L
.07342 .5534 L
.07297 .55101 L
.07258 .54895 L
.07226 .54748 L
.07201 .54638 L
.07184 .54562 L
.07174 .54515 L
.07169 .54488 L
.07169 .54471 L
.07169 .54444 L
.07168 .54403 L
.07162 .54342 L
.07149 .54269 L
.07129 .54159 L
.071 .54014 L
.07064 .53817 L
.07023 .53582 L
.06981 .53331 L
.0694 .53037 L
.06902 .52752 L
.06871 .52395 L
.06848 .52094 L
.06832 .51771 L
.06827 .51422 L
.06832 .5107 L
.06849 .50682 L
.06876 .50336 L
.06916 .49973 L
.06961 .49617 L
.07013 .49277 L
.07072 .48965 L
.07126 .48669 L
.07183 .48421 L
.07235 .48197 L
.07281 .48008 L
.07321 .47865 L
.07355 .47756 L
.07384 .4768 L
.07409 .47635 L
.07431 .47613 L
.07448 .47608 L
Mfstroke
.07141 .48738 m
.07125 .48752 L
.07104 .48789 L
.07078 .48856 L
.07048 .48961 L
.07015 .49109 L
.06979 .49293 L
.0694 .49511 L
.069 .49783 L
.06859 .50109 L
.0682 .50393 L
.06786 .5077 L
.0676 .51125 L
.06745 .51522 L
.0674 .51918 L
.06747 .52313 L
.06763 .52673 L
.06788 .53045 L
.06822 .53404 L
.06861 .53727 L
.06909 .54039 L
.06964 .54343 L
.07026 .54644 L
.07091 .54922 L
.07159 .55224 L
.0723 .55503 L
.07296 .55813 L
.07362 .56115 L
.07426 .56463 L
.07488 .56794 L
.07545 .5711 L
.076 .575 L
.07651 .5785 L
.07697 .58285 L
.0774 .58637 L
.07783 .59067 L
.07826 .59488 L
.0787 .59877 L
.07915 .60291 L
.07966 .60706 L
.08024 .61127 L
.08089 .61549 L
.0816 .61966 L
.08226 .62381 L
.08301 .62807 L
.08373 .63258 L
.08447 .6366 L
.08519 .64121 L
.08587 .64493 L
.08652 .6493 L
Mistroke
.08715 .65304 L
.08769 .65682 L
.08818 .66004 L
.0886 .663 L
.08895 .66587 L
.08925 .66836 L
.08952 .67063 L
.08977 .67262 L
.09003 .67421 L
.0903 .67561 L
.09059 .67679 L
.0909 .67777 L
.09122 .6786 L
.09153 .6792 L
.09183 .67978 L
.09209 .68025 L
.0923 .68058 L
.09249 .68074 L
.09267 .68075 L
.09284 .68063 L
.09299 .68045 L
.0931 .68026 L
.09317 .6801 L
.09319 .68002 L
.09317 .68009 L
.09312 .68034 L
.09306 .68079 L
.093 .68144 L
.09298 .68229 L
.09302 .68335 L
.09312 .68462 L
.0933 .68613 L
.09359 .68798 L
.09402 .69022 L
.09455 .69277 L
.09519 .6954 L
.09592 .69836 L
.09674 .70145 L
.09757 .70447 L
.09842 .70763 L
.09925 .71031 L
.1 .71294 L
.10072 .7155 L
.10131 .71749 L
.10187 .71929 L
.10225 .72084 L
.10258 .72206 L
.1028 .72289 L
.10292 .72337 L
.10295 .72358 L
Mistroke
.10291 .72359 L
.10286 .72345 L
.1028 .72324 L
.10275 .72309 L
.10272 .72303 L
.10272 .72309 L
.10275 .72331 L
.10277 .72354 L
.10277 .72375 L
.10272 .72391 L
.10263 .72398 L
.10253 .72397 L
.10241 .72392 L
.10229 .72385 L
.10218 .72381 L
.1021 .72381 L
.10204 .72388 L
.102 .72399 L
.10199 .72414 L
.10199 .72434 L
.102 .72456 L
.10205 .72482 L
.10213 .7251 L
.10223 .72543 L
.10234 .72579 L
.10247 .72616 L
.10258 .72655 L
.10266 .72688 L
.10272 .7271 L
.10273 .72719 L
.10271 .7272 L
.10267 .72716 L
.10264 .72708 L
.10263 .72697 L
.10263 .72683 L
.10264 .72667 L
.10264 .72649 L
.10264 .72629 L
.10265 .72608 L
.10265 .7259 L
.10265 .72576 L
.10265 .72566 L
.10266 .7256 L
.10266 .7256 L
.10265 .72562 L
.10265 .72568 L
.10265 .72578 L
.10265 .72596 L
.10264 .72617 L
.10264 .72641 L
Mistroke
.10263 .72665 L
.10263 .72687 L
.10262 .72706 L
.1026 .72721 L
.10256 .7273 L
.10249 .72727 L
.10237 .72712 L
.10224 .72688 L
.10213 .72663 L
.10207 .72644 L
.10208 .72634 L
.10222 .72639 L
.10255 .72666 L
.10309 .72719 L
.10387 .72801 L
.10491 .72914 L
.1061 .73058 L
.10765 .73231 L
.10928 .73409 L
.11123 .73626 L
.11329 .73856 L
.11555 .74108 L
.1181 .74367 L
.12056 .74636 L
.12299 .74883 L
.12546 .75138 L
.1279 .75386 L
.13033 .7562 L
.13281 .7586 L
.13527 .76089 L
.13794 .76331 L
.1405 .76571 L
.14329 .76829 L
.14612 .77078 L
.14897 .77351 L
.15184 .7761 L
.15482 .77893 L
.15782 .78171 L
.16092 .78464 L
.16378 .7874 L
.16678 .79039 L
.16984 .7932 L
.17281 .7961 L
.17586 .79894 L
.17901 .80199 L
.18199 .80476 L
.1853 .80783 L
.18853 .8111 L
.19195 .81418 L
.19552 .81753 L
Mistroke
.19943 .82117 L
.20307 .82439 L
.20682 .82783 L
.21074 .83149 L
.21449 .83479 L
.21837 .83819 L
.22202 .84199 L
.22571 .84507 L
.22917 .84829 L
.23245 .8515 L
.23554 .85438 L
.23847 .85717 L
.241 .85944 L
.24336 .8615 L
.24531 .86311 L
.24703 .86443 L
.24845 .86545 L
.2496 .8662 L
.25049 .86667 L
.25114 .86689 L
.25156 .86689 L
.25181 .8667 L
.25193 .86637 L
.25193 .86595 L
.25186 .86553 L
.25176 .86517 L
.25167 .86491 L
.25158 .86474 L
.2515 .86464 L
.25145 .8646 L
.25143 .86464 L
.25142 .86471 L
.25142 .86476 L
.2514 .86477 L
.25135 .86475 L
.2513 .86473 L
.25124 .86471 L
.2512 .86468 L
.25117 .86466 L
.25118 .86466 L
.25127 .8647 L
.25146 .86479 L
.25175 .86494 L
.25215 .86517 L
.25268 .86548 L
.25333 .86583 L
.25403 .86621 L
.25474 .8666 L
.25547 .86699 L
.25617 .86735 L
Mistroke
.25686 .8677 L
.25747 .86802 L
.25801 .8683 L
.25846 .86852 L
.25881 .86869 L
.25906 .86881 L
.25922 .86888 L
.2593 .86889 L
.25929 .86888 L
.25925 .86886 L
.25919 .86883 L
.25914 .86882 L
.25912 .86884 L
.25913 .86888 L
.25914 .86892 L
.25915 .86896 L
.25914 .869 L
.25911 .86906 L
.25908 .86912 L
.25904 .86918 L
.25903 .86921 L
.25904 .86919 L
.25908 .8691 L
.25913 .86892 L
.2592 .86868 L
.25927 .86836 L
.25935 .86797 L
.25942 .86753 L
.25949 .86707 L
.25953 .86659 L
.25957 .86612 L
.2596 .86565 L
.25966 .86513 L
.25974 .86475 L
.25984 .8644 L
.25993 .86415 L
.25997 .86401 L
.25995 .86398 L
.25987 .86405 L
.25966 .8642 L
.25953 .86435 L
.25937 .86456 L
.25921 .86481 L
.25906 .86512 L
.25896 .86553 L
.2589 .86601 L
.25895 .8666 L
.25916 .86728 L
.25952 .86802 L
.26017 .86891 L
Mistroke
.26111 .86993 L
.26243 .87107 L
.26419 .87234 L
.26647 .87377 L
.26912 .87532 L
.27223 .87698 L
.27572 .87867 L
.27961 .88042 L
.28376 .88216 L
.2881 .88392 L
.29294 .88566 L
.29777 .88744 L
.30286 .88919 L
.30825 .89096 L
.31339 .89269 L
.31875 .89445 L
.32402 .89619 L
.32933 .8979 L
.33439 .89964 L
.33904 .90136 L
.34355 .90306 L
.34753 .90466 L
.35119 .90616 L
.35482 .90743 L
.3578 .90859 L
.36042 .90955 L
.3629 .91036 L
.36524 .91106 L
.36746 .91167 L
.36957 .9122 L
.37146 .91268 L
.37346 .91314 L
.3756 .91361 L
.37782 .91408 L
.38008 .91459 L
.38238 .91513 L
.38469 .91574 L
.38691 .91639 L
.38884 .91707 L
.39051 .91764 L
.3919 .9182 L
.39301 .91869 L
.3939 .91908 L
.39451 .91936 L
.39491 .91953 L
.3951 .91956 L
.39511 .91948 L
.39504 .91937 L
.39492 .91923 L
.39477 .91902 L
Mistroke
.3947 .91878 L
.39476 .91855 L
.39495 .91833 L
.39521 .91808 L
.39556 .9178 L
.39597 .9175 L
.39638 .91716 L
.39678 .91684 L
.39715 .91649 L
.39751 .91616 L
.39782 .91583 L
.39803 .91552 L
.39814 .91526 L
.39813 .91513 L
.39795 .91492 L
.3976 .91472 L
.39712 .91452 L
.39664 .91442 L
.39614 .91444 L
.39566 .91454 L
.39522 .91474 L
.39487 .91504 L
.39455 .91529 L
.39427 .91556 L
.39403 .91579 L
.39382 .91597 L
.39358 .91606 L
.39331 .91612 L
.39306 .91619 L
.39289 .9163 L
.3928 .91641 L
.39282 .91652 L
.39305 .91669 L
.39353 .91698 L
.39433 .91742 L
.3955 .91802 L
.39708 .91881 L
.39918 .91976 L
.40186 .92086 L
.40469 .92211 L
.40827 .92348 L
.41221 .92494 L
.4167 .92638 L
.42162 .92792 L
.42624 .92936 L
.43109 .93076 L
.43619 .93208 L
.44068 .93326 L
.44519 .9343 L
.44911 .9352 L
Mistroke
.45276 .93594 L
.4562 .93654 L
.45876 .937 L
.46102 .93735 L
.46297 .93761 L
.46459 .93779 L
.46591 .93791 L
.46707 .93794 L
.46797 .93788 L
.46876 .93775 L
.46954 .93759 L
.4703 .93742 L
.47102 .93726 L
.47171 .93712 L
.47238 .93699 L
.47306 .93685 L
.4737 .93671 L
.47431 .93657 L
.47491 .93647 L
.47555 .93642 L
.47623 .9364 L
.47704 .93638 L
.47801 .93632 L
.47923 .93623 L
.48065 .93605 L
.48216 .93573 L
.48399 .93527 L
.48607 .9347 L
.48836 .93404 L
.49075 .93334 L
.49311 .93264 L
.49536 .93191 L
.49745 .9313 L
.49921 .93072 L
.50064 .9302 L
.50167 .9297 L
.50241 .92927 L
.50284 .92891 L
.50307 .92869 L
.50325 .92857 L
.50345 .92854 L
.50371 .92859 L
.50414 .92872 L
.5048 .92892 L
.50582 .92921 L
.50712 .92952 L
.50889 .92989 L
.51084 .93028 L
.51322 .93065 L
.51621 .93111 L
Mistroke
.51915 .93147 L
.52243 .93175 L
.52588 .93189 L
.52941 .93188 L
.53313 .93175 L
.53676 .93152 L
.54057 .93111 L
.54439 .93055 L
.54832 .92985 L
.5524 .92908 L
.55669 .92825 L
.56105 .92741 L
.56552 .92662 L
.57004 .92594 L
.57449 .92536 L
.57883 .92485 L
.58311 .92441 L
.58732 .92402 L
.59149 .92366 L
.59543 .92329 L
.59943 .92294 L
.60314 .92257 L
.60679 .92217 L
.61047 .92171 L
.61406 .92117 L
.61761 .92053 L
.6212 .91977 L
.6246 .91887 L
.62791 .91788 L
.63109 .91683 L
.63408 .91576 L
.63696 .91468 L
.63958 .91369 L
.64193 .91279 L
.64393 .91204 L
.64555 .91143 L
.64674 .91099 L
.64761 .91074 L
.64821 .91066 L
.64856 .91072 L
.64884 .91078 L
.64911 .91087 L
.64939 .91096 L
.64974 .91095 L
.65014 .91087 L
.65051 .91077 L
.65101 .91053 L
.65145 .91022 L
.65202 .90971 L
.65265 .90908 L
Mistroke
.65331 .90835 L
.654 .90757 L
.65468 .90679 L
.65538 .90601 L
.65606 .90525 L
.65664 .90456 L
.65709 .90392 L
.65733 .9035 L
.65755 .90314 L
.65774 .90289 L
.658 .90272 L
.65826 .90272 L
.65861 .90282 L
.65899 .90303 L
.65941 .90333 L
.65987 .90364 L
.66034 .90395 L
.66082 .90423 L
.66138 .90449 L
.66206 .90478 L
.6629 .90503 L
.66385 .90521 L
.66486 .9053 L
.66586 .90533 L
.66685 .90531 L
.66778 .90523 L
.66864 .90511 L
.66937 .90501 L
.67 .90496 L
.67046 .90497 L
.67091 .90504 L
.67133 .90515 L
.6717 .90526 L
.67197 .90534 L
.67217 .9054 L
.67231 .90541 L
.67241 .90539 L
.67247 .90537 L
.6725 .90538 L
.67252 .90539 L
.67253 .90542 L
.67247 .90543 L
.67244 .90542 L
.67245 .90539 L
.67241 .90535 L
.6724 .90531 L
.67248 .90529 L
.67269 .9053 L
.67295 .90532 L
.67328 .90533 L
Mistroke
.67366 .90532 L
.67414 .90526 L
.67467 .90513 L
.67527 .90493 L
.67593 .90468 L
.6767 .90436 L
.67757 .90399 L
.67854 .90354 L
.67961 .90302 L
.68079 .90239 L
.68205 .90167 L
.68339 .90083 L
.68494 .89986 L
.68666 .89876 L
.68859 .89756 L
.69072 .89625 L
.69309 .89488 L
.69558 .89339 L
.69824 .89185 L
.70102 .89026 L
.70364 .88865 L
.70632 .88701 L
.70905 .88531 L
.71186 .88359 L
.71459 .88193 L
.71726 .88028 L
.71992 .87865 L
.72256 .87699 L
.7251 .8754 L
.72746 .87387 L
.72932 .87263 L
.73122 .87135 L
.73297 .87022 L
.73451 .8692 L
.73591 .86826 L
.73712 .86744 L
.73813 .86673 L
.73897 .86611 L
.73966 .86557 L
.74023 .86508 L
.74073 .86462 L
.74122 .86415 L
.74177 .8636 L
.74238 .86297 L
.74303 .86225 L
.74371 .86147 L
.7444 .86066 L
.74505 .85986 L
.74563 .8591 L
.74615 .85842 L
Mistroke
.74655 .85782 L
.74683 .85732 L
.74696 .85694 L
.74697 .85666 L
.74687 .85647 L
.7467 .85636 L
.74649 .85633 L
.74633 .85636 L
.74622 .85644 L
.7462 .85655 L
.74634 .85665 L
.74669 .85669 L
.74724 .85667 L
.74796 .85657 L
.74892 .85638 L
.75009 .85607 L
.75147 .85561 L
.75304 .85497 L
.75481 .85418 L
.75672 .85324 L
.75878 .85217 L
.76091 .85099 L
.76314 .84971 L
.76545 .84832 L
.76785 .8468 L
.77021 .84519 L
.77261 .84347 L
.77503 .84173 L
.77745 .83996 L
.77973 .83821 L
.78192 .83653 L
.78391 .83504 L
.78563 .83367 L
.78705 .83249 L
.78815 .83151 L
.78896 .83073 L
.78949 .83015 L
.7898 .82973 L
.78995 .82945 L
.79003 .82926 L
.79001 .82911 L
.78993 .82892 L
.7899 .82859 L
.78996 .82809 L
.79011 .82734 L
.79042 .82634 L
.79088 .82509 L
.7915 .82373 L
.7922 .82221 L
.7929 .8207 L
Mistroke
.7935 .81926 L
.79394 .81804 L
.79419 .81714 L
.79426 .81661 L
.7942 .81648 L
.7941 .81672 L
.79401 .81721 L
.79407 .81782 L
.79436 .81851 L
.79484 .81898 L
.79558 .81948 L
.79657 .81982 L
.79779 .81995 L
.79933 .81982 L
.80117 .81939 L
.80328 .81855 L
.80571 .81731 L
.80829 .81578 L
.81103 .81393 L
.81381 .81187 L
.81662 .80957 L
.81948 .80722 L
.82226 .80491 L
.82515 .80251 L
.82802 .80013 L
.83096 .79777 L
.83384 .79551 L
.83663 .79326 L
.83932 .79117 L
.84185 .78921 L
.84424 .78741 L
.8465 .78573 L
.84849 .78421 L
.85041 .78275 L
.85224 .78124 L
.85416 .77962 L
.85591 .77785 L
.85731 .77616 L
.85884 .77419 L
.86016 .77226 L
.86162 .77004 L
.86277 .76805 L
.86402 .76593 L
.86526 .76372 L
.86644 .76147 L
.86752 .75916 L
.86846 .75688 L
.86926 .75461 L
.86994 .75215 L
.87038 .75005 L
Mistroke
.87077 .74787 L
.87109 .74599 L
.87137 .74419 L
.87155 .74255 L
.87167 .74118 L
.87174 .74002 L
.87175 .73904 L
.87174 .73826 L
.87173 .73763 L
.87173 .73714 L
.87176 .73687 L
.87188 .73675 L
.87213 .73663 L
.87254 .73638 L
.87309 .73582 L
.8738 .73493 L
.87466 .73367 L
.87566 .73203 L
.87681 .73003 L
.87806 .72771 L
.87939 .72508 L
.88075 .7223 L
.88211 .71926 L
.88344 .71612 L
.88474 .71278 L
.88598 .7094 L
.88715 .70594 L
.88822 .70249 L
.88919 .69912 L
.89007 .69598 L
.89083 .69301 L
.89147 .69041 L
.89195 .68812 L
.89231 .68616 L
.89258 .68451 L
.89279 .68315 L
.89297 .68203 L
.89316 .68118 L
.89338 .68047 L
.89361 .67993 L
.89389 .6794 L
.89425 .67881 L
.89471 .67803 L
.89521 .67725 L
.89579 .67616 L
.89653 .67469 L
.89712 .67321 L
.89769 .67156 L
.89821 .66969 L
.89864 .66764 L
Mistroke
.89898 .66547 L
.89921 .66329 L
.89931 .66128 L
.8993 .65942 L
.8992 .65782 L
.89902 .65656 L
.89884 .65564 L
.89871 .65497 L
.89865 .65455 L
.89864 .65441 L
.89868 .65445 L
.89875 .65464 L
.89879 .65497 L
.89879 .65547 L
.89871 .65613 L
.89852 .65688 L
.89821 .65769 L
.89779 .65841 L
.89725 .65898 L
.89665 .65937 L
.89594 .65961 L
.89506 .65978 L
.89403 .65991 L
.89287 .66003 L
.89153 .6602 L
.89011 .66032 L
.88868 .66032 L
.88726 .66018 L
.88593 .65993 L
.88482 .6596 L
.88381 .65924 L
.88286 .65892 L
.88199 .65865 L
.88127 .65844 L
.8808 .65824 L
.88045 .65809 L
.88024 .65799 L
.88019 .65799 L
.88027 .65813 L
.88044 .65846 L
.88064 .65909 L
.88084 .66008 L
.881 .66146 L
.88113 .66327 L
.88125 .66549 L
.88132 .66793 L
.88131 .67076 L
.88126 .67372 L
.88121 .67693 L
.88118 .67984 L
Mistroke
.88115 .68274 L
.88114 .68553 L
.88113 .68801 L
.88111 .69012 L
.8811 .69192 L
.88108 .6934 L
.88107 .6945 L
.88105 .6953 L
.88103 .69586 L
.88101 .69621 L
.88099 .69641 L
.88098 .69649 L
.88097 .69651 L
.88099 .69647 L
.88103 .69642 L
.88108 .6964 L
.88112 .69644 L
.88114 .69652 L
.88112 .69666 L
.88107 .69683 L
.88098 .69701 L
.88087 .69721 L
.88072 .69748 L
.88055 .69786 L
.88038 .69838 L
.88021 .69902 L
.88007 .69981 L
.87997 .70077 L
.87991 .70193 L
.87991 .70328 L
.88 .7048 L
.88016 .70646 L
.88037 .70815 L
.88061 .71 L
.88082 .712 L
.88098 .71417 L
.88104 .71653 L
.88098 .71902 L
.88077 .72144 L
.88043 .72391 L
.87998 .7263 L
.87947 .72848 L
.87896 .73024 L
.87844 .73178 L
.87794 .7331 L
.8775 .73408 L
.87714 .73484 L
.87689 .73545 L
.87676 .73573 L
.87674 .73578 L
Mistroke
.87686 .73562 L
.8771 .73527 L
.87742 .7348 L
.87776 .73431 L
.87806 .7339 L
.87829 .73366 L
.87837 .73367 L
.87828 .73395 L
.87801 .73447 L
.87754 .73523 L
.87688 .73623 L
.87604 .73748 L
.87505 .73896 L
.87401 .74051 L
.87288 .74211 L
.87172 .74364 L
.87054 .7451 L
.86939 .74651 L
.86836 .7477 L
.86747 .74872 L
.86677 .74948 L
.86628 .74995 L
.866 .75016 L
.86594 .75009 L
.86605 .7498 L
.86629 .74938 L
.86661 .74889 L
.86691 .74853 L
.86721 .74824 L
.86747 .74813 L
.86764 .74828 L
.86772 .74863 L
.86776 .74915 L
.86774 .74979 L
.86767 .75058 L
.86757 .75145 L
.86746 .75238 L
.86733 .75342 L
.86718 .75445 L
.86701 .7556 L
.86689 .75669 L
.86683 .75765 L
.8668 .75843 L
.86676 .7591 L
.86669 .75966 L
.86656 .76013 L
.8664 .7605 L
.86622 .76074 L
.86607 .76081 L
.86594 .76071 L
Mistroke
.86589 .76047 L
.86585 .76016 L
.86584 .75979 L
.86586 .75937 L
.86592 .75898 L
.86599 .75867 L
.86609 .75835 L
.86622 .75801 L
.86634 .75764 L
.86644 .75727 L
.86651 .75696 L
.86655 .75672 L
.86655 .7566 L
.86651 .75663 L
.86635 .75686 L
.86609 .75732 L
.86572 .75803 L
.86526 .75892 L
.86472 .76003 L
.86408 .76135 L
.86333 .76278 L
.86243 .76447 L
.8614 .76632 L
.86027 .7683 L
.85908 .7703 L
.85799 .77214 L
.85693 .77384 L
.85597 .77532 L
.85512 .77653 L
.85444 .77742 L
.85391 .77802 L
.8535 .77841 L
.85322 .77865 L
.85306 .77877 L
.85302 .7788 L
.85303 .77877 L
.85303 .77875 L
.85299 .77875 L
.85296 .77876 L
.85297 .77874 L
.85296 .77871 L
.8529 .77872 L
.85276 .77879 L
.85257 .77888 L
.8524 .77897 L
.85223 .77904 L
.85208 .77909 L
.85195 .77905 L
.8518 .77902 L
.8515 .77902 L
Mistroke
.85105 .77907 L
.85047 .77908 L
.84977 .77921 L
.84892 .77938 L
.8479 .77949 L
.84685 .77951 L
.84583 .77945 L
.84492 .77936 L
.844 .77927 L
.84313 .77916 L
.84251 .77906 L
.84208 .77897 L
.84173 .77889 L
.84151 .77886 L
.84149 .77886 L
.84159 .77894 L
.84192 .77895 L
.8424 .7789 L
.84301 .77879 L
.84366 .77866 L
.84437 .77849 L
.84509 .77825 L
.84591 .77786 L
.84668 .77745 L
.8475 .77691 L
.84821 .77637 L
.8489 .77581 L
.84949 .77528 L
.85 .77478 L
.85046 .77431 L
.85084 .77391 L
.85119 .77357 L
.85151 .77327 L
.85182 .77296 L
.85209 .77268 L
.85224 .77251 L
.85228 .77247 L
.85228 .77249 L
.85232 .77253 L
.85238 .77257 L
.85244 .77263 L
.85248 .77272 L
.85249 .77284 L
.8525 .77296 L
.85249 .77308 L
.85245 .77319 L
.85238 .77332 L
.85228 .77346 L
.85219 .77358 L
.85218 .77356 L
Mistroke
.85228 .77344 L
.85249 .77321 L
.85268 .773 L
.85294 .77273 L
.85318 .77248 L
.85339 .77227 L
.85353 .77212 L
.8536 .77207 L
.8536 .77211 L
.85357 .77219 L
.85354 .77225 L
.85352 .77229 L
.85348 .77232 L
.85343 .77235 L
.85338 .77238 L
.85335 .77238 L
.85334 .77233 L
.85334 .77229 L
.85335 .77221 L
.85336 .77213 L
.85339 .77204 L
.85343 .77196 L
.85347 .77189 L
.85352 .77186 L
.85356 .77185 L
.8536 .77186 L
.85362 .77187 L
.85363 .77187 L
.85362 .77188 L
.8536 .77188 L
.85359 .77189 L
.85358 .77189 L
.85358 .77187 L
.85359 .77183 L
.85361 .77177 L
.85368 .77168 L
.85376 .77159 L
.85381 .77158 L
.85382 .77163 L
.8538 .77175 L
.8537 .772 L
.85349 .77241 L
.85317 .77296 L
.85274 .77359 L
.85225 .77423 L
.85175 .77484 L
.85128 .7754 L
.85083 .77588 L
.85048 .77622 L
.85018 .77647 L
Mistroke
.84993 .77662 L
.84979 .7766 L
.84976 .77645 L
.84985 .77617 L
.85015 .77566 L
.85062 .77499 L
.85129 .77417 L
.85212 .77331 L
.85312 .77239 L
.85427 .7714 L
.85557 .77031 L
.857 .76906 L
.85859 .76755 L
.8603 .76578 L
.86208 .76377 L
.86386 .76161 L
.8657 .75917 L
.86746 .75661 L
.86907 .75434 L
.87049 .75201 L
.87167 .74997 L
.87269 .74801 L
.87349 .74633 L
.87409 .74497 L
.87452 .74386 L
.87482 .74304 L
.87503 .74252 L
.87517 .74226 L
.87528 .7422 L
.87537 .74226 L
.87547 .74239 L
.8756 .74253 L
.87575 .74265 L
.8759 .74274 L
.87604 .74278 L
.87616 .74279 L
.87624 .74278 L
.87629 .74278 L
.8763 .74281 L
.87629 .74286 L
.87626 .74293 L
.87623 .743 L
.87621 .74305 L
.8762 .74308 L
.87619 .74305 L
.87618 .74295 L
.87615 .74275 L
.87612 .74244 L
.87608 .74202 L
.87606 .74147 L
Mistroke
.87606 .74081 L
.87608 .74006 L
.87615 .73922 L
.87624 .73831 L
.87637 .73737 L
.87652 .73643 L
.8767 .73555 L
.87688 .73473 L
.87706 .73401 L
.87725 .73341 L
.87744 .73294 L
.87761 .73259 L
.87776 .73234 L
.87788 .73219 L
.87796 .7321 L
.87803 .73207 L
.87808 .73208 L
.87814 .73211 L
.87817 .73215 L
.87817 .73219 L
.87812 .73223 L
.87801 .73227 L
.87785 .73231 L
.8776 .73233 L
.87729 .73237 L
.87693 .7324 L
.87654 .73244 L
.87614 .73248 L
.87573 .73251 L
.87532 .73255 L
.87494 .73259 L
.87456 .73262 L
.87422 .73265 L
.87397 .73267 L
.87382 .73268 L
.8738 .73271 L
.87388 .73276 L
.87405 .73285 L
.8743 .73294 L
.87461 .733 L
.87496 .73297 L
.87532 .73282 L
.87572 .73253 L
.87617 .73209 L
.87664 .7315 L
.87712 .73078 L
.87759 .72997 L
.87801 .7291 L
.87839 .72828 L
.87871 .72737 L
Mistroke
.87898 .72654 L
.87923 .72575 L
.87944 .72506 L
.87962 .72453 L
.87978 .72417 L
.87992 .724 L
.88006 .72398 L
.88021 .72402 L
.88037 .72405 L
.88057 .72399 L
.88082 .72371 L
.88115 .72314 L
.88155 .72222 L
.88204 .72096 L
.8826 .71945 L
.88321 .71769 L
.88389 .71563 L
.88461 .71343 L
.88537 .71106 L
.88614 .70876 L
.88688 .70648 L
.88765 .70432 L
.8883 .70229 L
.88893 .70063 L
.88946 .69916 L
.88989 .6979 L
.89021 .69688 L
.89044 .69604 L
.89058 .69531 L
.89065 .69462 L
.89065 .69388 L
.89062 .69308 L
.89055 .69214 L
.89048 .69102 L
.89041 .68968 L
.89035 .68821 L
.89029 .68661 L
.89024 .68504 L
.89021 .68355 L
.89018 .6823 L
.89015 .68118 L
.89013 .68034 L
.89012 .67973 L
.89012 .67933 L
.89014 .67915 L
.8902 .67916 L
.8903 .67935 L
.89039 .6797 L
.89044 .68016 L
.89045 .68067 L
Mistroke
.89039 .68118 L
.89024 .68164 L
.88997 .68195 L
.88958 .68211 L
.88907 .68214 L
.88846 .68212 L
.88779 .68209 L
.88707 .6821 L
.88632 .6822 L
.8855 .68238 L
.88462 .68265 L
.88369 .68298 L
.88274 .68335 L
.88182 .68374 L
.88091 .68413 L
.87998 .68454 L
.87907 .685 L
.87815 .68551 L
.87727 .68608 L
.87634 .68669 L
.87532 .68733 L
.87419 .688 L
.87302 .68868 L
.87183 .68939 L
.8706 .69016 L
.86934 .69101 L
.86822 .69192 L
.86712 .69289 L
.8661 .69392 L
.86516 .69494 L
.86437 .6959 L
.86363 .69674 L
.86294 .69744 L
.86231 .69801 L
.86176 .69843 L
.86127 .69873 L
.86083 .69894 L
.86039 .69909 L
.85988 .6992 L
.85927 .6993 L
.85853 .69939 L
.85761 .69948 L
.85666 .69961 L
.85549 .69978 L
.85423 .70001 L
.85307 .70027 L
.85189 .70056 L
.85074 .70086 L
.84968 .70116 L
.84877 .70142 L
Mistroke
.84796 .7016 L
.84728 .70169 L
.84675 .70171 L
.84643 .70165 L
.84633 .70152 L
.84644 .70136 L
.84667 .70125 L
.84697 .70125 L
.84725 .70142 L
.84746 .70179 L
.84758 .70237 L
.84756 .70323 L
.8474 .70437 L
.84714 .7057 L
.84679 .7073 L
.84634 .70913 L
.84585 .71099 L
.84524 .71306 L
.8446 .71503 L
.84391 .71698 L
.84322 .71881 L
.84259 .72043 L
.84207 .72185 L
.8417 .72303 L
.84147 .72393 L
.84136 .72465 L
.84137 .72521 L
.84146 .72562 L
.84159 .72594 L
.84175 .72618 L
.84192 .72637 L
.84212 .72652 L
.84234 .72662 L
.84257 .72671 L
.84279 .72681 L
.84297 .72691 L
.84311 .727 L
.84321 .72709 L
.84326 .72714 L
.84327 .72715 L
.84326 .72713 L
.84326 .72705 L
.84327 .72691 L
.84331 .72673 L
.84337 .72656 L
.84344 .72643 L
.84347 .72639 L
.84345 .72647 L
.84334 .7267 L
.84315 .72712 L
Mistroke
.84284 .72778 L
.8424 .72869 L
.84184 .72984 L
.84115 .73127 L
.84038 .73289 L
.83951 .73476 L
.83855 .7369 L
.83754 .73927 L
.83652 .74161 L
.83549 .74408 L
.83448 .74654 L
.83354 .74873 L
.83271 .75066 L
.832 .75241 L
.83142 .75393 L
.83099 .75518 L
.83071 .75607 L
.83057 .75676 L
.83057 .75727 L
.83067 .75762 L
.83081 .75785 L
.83093 .75799 L
.83104 .75808 L
.83112 .75817 L
.83114 .75822 L
.83109 .75825 L
.83098 .75828 L
.83081 .75838 L
.83054 .7586 L
.8301 .75894 L
.82956 .75942 L
.8289 .76003 L
.82818 .76078 L
.82738 .7617 L
.82656 .7628 L
.82573 .7641 L
.82488 .76551 L
.82418 .76717 L
.82343 .76911 L
.82266 .77129 L
.82182 .7737 L
.82096 .77623 L
.82006 .77881 L
.8191 .78107 L
.81829 .78347 L
.81754 .78529 L
.81694 .78711 L
.81642 .78869 L
.81597 .79002 L
.81561 .79111 L
Mistroke
.8153 .79195 L
.81508 .79253 L
.81497 .79286 L
.81498 .79299 L
.81509 .79295 L
.81524 .79282 L
.81541 .79267 L
.81555 .79256 L
.81564 .79247 L
.81567 .7924 L
.81565 .79236 L
.81559 .79236 L
.81548 .79238 L
.81532 .7924 L
.81517 .79241 L
.81506 .79242 L
.81497 .79242 L
.81489 .79242 L
.81483 .79243 L
.81476 .79243 L
.81469 .79244 L
.81462 .79244 L
.81456 .79245 L
.81454 .79244 L
.81454 .79244 L
.81452 .79242 L
.81448 .7924 L
.81444 .79239 L
.81435 .79238 L
.81425 .79238 L
.81415 .79237 L
.81405 .79237 L
.81397 .79236 L
.8139 .79233 L
.81384 .79233 L
.8138 .79241 L
.81371 .79261 L
.81362 .793 L
.81347 .79363 L
.8133 .79441 L
.81308 .79542 L
.81285 .79671 L
.81262 .79775 L
.81239 .79923 L
.81214 .80065 L
.81188 .80186 L
.81159 .80343 L
.81126 .80486 L
.81091 .80627 L
.81055 .80759 L
Mistroke
.81021 .80875 L
.80989 .8097 L
.8096 .81041 L
.80937 .81096 L
.80916 .81136 L
.80899 .81165 L
.80887 .81185 L
.80878 .81201 L
.80874 .81212 L
.80875 .81218 L
.80881 .81218 L
.80889 .81213 L
.80898 .81206 L
.80905 .81198 L
.80908 .81192 L
.80906 .8119 L
.80898 .8119 L
.80888 .81192 L
.80874 .81193 L
.80857 .81194 L
.80837 .81196 L
.80814 .81198 L
.80792 .812 L
.8077 .81202 L
.80749 .81204 L
.80735 .81206 L
.80724 .81207 L
.80721 .81207 L
.80724 .81207 L
.80736 .81206 L
.80752 .81204 L
.80773 .81202 L
.80796 .812 L
.80818 .81198 L
.80838 .81196 L
.80855 .81195 L
.80871 .81193 L
.80886 .81192 L
.80898 .8119 L
.80907 .81189 L
.80913 .81189 L
.80917 .81188 L
.80919 .81185 L
.80918 .81179 L
.80915 .81172 L
.80909 .81165 L
.80898 .81163 L
.80878 .81167 L
.80846 .81177 L
.80798 .81196 L
Mistroke
.80728 .81225 L
.80647 .81266 L
.80541 .81323 L
.80412 .81394 L
.80272 .81478 L
.80112 .81574 L
.79932 .81676 L
.79746 .8179 L
.79551 .81902 L
.79362 .82018 L
.79172 .82131 L
.78992 .82233 L
.78836 .82323 L
.78693 .824 L
.7857 .82463 L
.78471 .82513 L
.784 .82551 L
.78345 .82574 L
.78309 .82582 L
.7829 .82578 L
.78282 .82566 L
.78279 .82552 L
.78274 .82546 L
.78267 .82548 L
.78252 .82564 L
.7823 .8259 L
.78199 .82625 L
.78163 .8267 L
.78115 .82726 L
.7806 .8279 L
.77998 .82859 L
.77932 .82936 L
.77867 .83017 L
.77799 .83104 L
.77723 .83198 L
.77643 .83297 L
.77557 .83399 L
.77459 .83503 L
.77362 .83616 L
.77249 .83738 L
.77119 .83872 L
.7697 .84021 L
.76818 .84173 L
.76647 .84335 L
.76459 .84502 L
.76277 .84661 L
.76105 .84806 L
.75941 .84936 L
.75786 .85053 L
.75649 .85152 L
Mistroke
.75514 .85242 L
.75393 .85324 L
.75276 .85397 L
.75167 .85462 L
.75064 .85522 L
.74961 .85577 L
.74863 .85637 L
.74758 .85703 L
.74646 .85773 L
.74527 .85851 L
.74408 .85932 L
.7428 .8602 L
.74143 .86113 L
.74004 .86207 L
.73868 .863 L
.73734 .86387 L
.73614 .8646 L
.73504 .86522 L
.73402 .86576 L
.73304 .86629 L
.73211 .86683 L
.73119 .86739 L
.73031 .86799 L
.72936 .86864 L
.72831 .86941 L
.72711 .87034 L
.72573 .87144 L
.72414 .87275 L
.72231 .87428 L
.72057 .87581 L
.71854 .87743 L
.71632 .87925 L
.71417 .88123 L
.71165 .88326 L
.70943 .88506 L
.70716 .88687 L
.7049 .88858 L
.70285 .89005 L
.70094 .8914 L
.69931 .89257 L
.69786 .89357 L
.69654 .89446 L
.69531 .89527 L
.69423 .89603 L
.69313 .8967 L
.69203 .89735 L
.69092 .89795 L
.68989 .89856 L
.68888 .89914 L
.68795 .89968 L
Mistroke
.68713 .90014 L
.68645 .90049 L
.68591 .9007 L
.68548 .90082 L
.68513 .90087 L
.6849 .90083 L
.68476 .90072 L
.68468 .90056 L
.68465 .90034 L
.68465 .90014 L
.68467 .89998 L
.68468 .89991 L
.68463 .89996 L
.68447 .90014 L
.6842 .90047 L
.68381 .90085 L
.68332 .90131 L
.68273 .90182 L
.68198 .90238 L
.68135 .90287 L
.68065 .90336 L
.68003 .9038 L
.67954 .90417 L
.67913 .90446 L
.67881 .90466 L
.67854 .90479 L
.67833 .90485 L
.6781 .90486 L
.67787 .90482 L
.67763 .90477 L
.67741 .90473 L
.67716 .90473 L
.67688 .90475 L
.67656 .90478 L
.67623 .90481 L
.67588 .90484 L
.67555 .90487 L
.67527 .9049 L
.6751 .90492 L
.67507 .90492 L
.67514 .90492 L
.67528 .90491 L
.67548 .90489 L
.67573 .90488 L
.676 .90486 L
.67629 .90484 L
.67657 .90481 L
.67687 .90479 L
.67715 .90476 L
.67744 .90474 L
Mistroke
.67765 .90472 L
.67778 .9047 L
.67781 .9047 L
.67776 .9047 L
.67766 .9047 L
.67754 .90471 L
.67744 .90471 L
.67738 .9047 L
.67736 .9047 L
.67736 .90469 L
.67734 .90469 L
.67731 .90469 L
.67732 .90469 L
.67739 .90469 L
.67755 .90467 L
.67775 .90465 L
.67796 .90463 L
.67817 .9046 L
.6783 .90459 L
.67834 .90458 L
.67825 .90459 L
.67804 .9046 L
.67774 .90464 L
.67734 .90468 L
.67695 .90473 L
.67647 .90478 L
.67598 .90484 L
.67552 .90489 L
.67512 .90493 L
.67481 .90497 L
.67458 .90499 L
.67445 .90501 L
.67441 .90502 L
.67442 .90502 L
.67448 .90501 L
.67456 .905 L
.67463 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
Mistroke
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67466 .90499 L
.67467 .90499 L
.67469 .90498 L
.67474 .90498 L
.67481 .90497 L
.67488 .90496 L
.67491 .90496 L
.67489 .90496 L
.67478 .90497 L
.67458 .905 L
.67429 .90503 L
.67393 .90507 L
.67353 .90511 L
.67312 .90516 L
.67272 .9052 L
.67235 .90524 L
.672 .90528 L
.6717 .90532 L
.67148 .90536 L
.67138 .90541 L
.6714 .90546 L
.67153 .90548 L
.67173 .90544 L
.67199 .90534 L
.67226 .90519 L
.6725 .905 L
Mistroke
.67268 .90481 L
.67278 .90462 L
.6728 .90447 L
.67276 .90436 L
.6727 .90431 L
.67264 .90433 L
.67258 .9044 L
.67251 .90449 L
.67244 .90455 L
.67236 .9046 L
.67226 .90462 L
.67214 .90458 L
.672 .90446 L
.67186 .90426 L
.67174 .90401 L
.67164 .90375 L
.67158 .9035 L
.67153 .90325 L
.67146 .90303 L
.67137 .90287 L
.67129 .90281 L
.67124 .90287 L
.67122 .90302 L
.67124 .90325 L
.67129 .90357 L
.67133 .90397 L
.67136 .90441 L
.67134 .90486 L
.67128 .90526 L
.67117 .90555 L
.67104 .90573 L
.67091 .9058 L
.67088 .90579 L
.67097 .90573 L
.67119 .90563 L
.67144 .90555 L
.67179 .90548 L
.67217 .90541 L
.67253 .90535 L
.67284 .90528 L
.67306 .90523 L
.67319 .90518 L
.67326 .90515 L
.67332 .90512 L
.67338 .90511 L
.67344 .9051 L
.67341 .90511 L
.67332 .90514 L
.67321 .90516 L
.67318 .90517 L
Mistroke
.67319 .90517 L
.6733 .90516 L
.67347 .90513 L
.67371 .90511 L
.67397 .90508 L
.67425 .90504 L
.67454 .905 L
.6748 .90497 L
.675 .90494 L
.67509 .90493 L
.67505 .90494 L
.67488 .90497 L
.67456 .90501 L
.67412 .90507 L
.67361 .90513 L
.67307 .9052 L
.67254 .90526 L
.67203 .90532 L
.67157 .90538 L
.67121 .90542 L
.67092 .90547 L
.6707 .90552 L
.67061 .90554 L
.6707 .90552 L
.67096 .90546 L
.67134 .90537 L
.67179 .90525 L
.67227 .90511 L
.67276 .90498 L
.67319 .90487 L
.67353 .90478 L
.67374 .90472 L
.67387 .90468 L
.67398 .90466 L
.67408 .90465 L
.67421 .90462 L
.67432 .90461 L
.6744 .90462 L
.67445 .90467 L
.67446 .90475 L
.67445 .90487 L
.6744 .90499 L
.67431 .90513 L
.67416 .90526 L
.67398 .90537 L
.67381 .90545 L
.67366 .9055 L
.67329 .9056 L
.67302 .90567 L
.67268 .90574 L
Mistroke
.67219 .90584 L
.67152 .90595 L
.67064 .90607 L
.66947 .90621 L
.66813 .9064 L
.66644 .90663 L
.66447 .90692 L
.66236 .90725 L
.65998 .90763 L
.65736 .90806 L
.65459 .90855 L
.6517 .90911 L
.64921 .90963 L
.64686 .91022 L
.64493 .91083 L
.6433 .9114 L
.64217 .9119 L
.64139 .91231 L
.64096 .91261 L
.64087 .9128 L
.64096 .91288 L
.64123 .91289 L
.64164 .91282 L
.64214 .91264 L
.64267 .9124 L
.64315 .91212 L
.64352 .91182 L
.64372 .91148 L
.6438 .91115 L
.64377 .91085 L
.64368 .91057 L
.64352 .91035 L
.64328 .91019 L
.64298 .91002 L
.64264 .90981 L
.64229 .90955 L
.64196 .90923 L
.64166 .90885 L
.64139 .90837 L
.64116 .90779 L
.641 .9072 L
.64091 .90665 L
.64086 .90613 L
.64083 .90566 L
.64082 .90526 L
.64081 .90501 L
.64082 .9049 L
.64084 .90495 L
.64088 .90512 L
.64095 .90539 L
Mistroke
.64103 .90568 L
.64111 .90593 L
.64118 .90608 L
.64125 .9062 L
.64129 .90624 L
.64134 .90617 L
.64143 .90604 L
.64157 .90585 L
.64177 .90564 L
.64202 .90541 L
.64228 .90521 L
.64249 .90507 L
.6426 .90501 L
.64257 .90503 L
.6424 .90518 L
.64206 .90547 L
.64151 .90587 L
.64074 .9064 L
.63974 .90704 L
.63853 .90775 L
.63715 .90854 L
.63534 .90923 L
.63347 .90998 L
.63133 .91076 L
.62875 .91155 L
.62584 .91238 L
.62255 .91316 L
.61926 .91398 L
.61604 .91481 L
.61251 .91562 L
.60867 .91649 L
.60525 .91738 L
.60122 .91814 L
.59736 .91887 L
.59307 .91956 L
.58893 .92025 L
.58508 .92084 L
.581 .92142 L
.57687 .92198 L
.57354 .92248 L
.56985 .92294 L
.56649 .92336 L
.56294 .92375 L
.55963 .92414 L
.55612 .92453 L
.55259 .92492 L
.54933 .9253 L
.54591 .92571 L
.54237 .92618 L
.53924 .92667 L
Mistroke
.53628 .92717 L
.53285 .92766 L
.52997 .92811 L
.52701 .92849 L
.52395 .92881 L
.52092 .92905 L
.51827 .92917 L
.51563 .92913 L
.51316 .92894 L
.51078 .92862 L
.50865 .92821 L
.5066 .9277 L
.50467 .92715 L
.5031 .92661 L
.50172 .92616 L
.50052 .92576 L
.49956 .92544 L
.49879 .92524 L
.49816 .9251 L
.49758 .92502 L
.49696 .92496 L
.49623 .92496 L
.49532 .92499 L
.4941 .92505 L
.49255 .92513 L
.49077 .92526 L
.48859 .92538 L
.48602 .92548 L
.48301 .92555 L
.47979 .92566 L
.47637 .9258 L
.47249 .926 L
.46851 .92623 L
.46475 .92646 L
.46075 .92666 L
.45673 .92681 L
.45278 .92688 L
.44902 .92683 L
.4452 .92669 L
.44188 .92652 L
.43878 .92636 L
.43599 .92622 L
.43365 .92611 L
.43162 .926 L
.42993 .92592 L
.42867 .92585 L
.42771 .9258 L
.42705 .92576 L
.42669 .92572 L
.42657 .92569 L
Mistroke
.42662 .92568 L
.42676 .92564 L
.42693 .92557 L
.42708 .92543 L
.4272 .9252 L
.42727 .92498 L
.42729 .92475 L
.42725 .92452 L
.42716 .92427 L
.42706 .92401 L
.42696 .92377 L
.42687 .92358 L
.42675 .92336 L
.42661 .92309 L
.42647 .92279 L
.42632 .92245 L
.42617 .92211 L
.42602 .92174 L
.42588 .9214 L
.42577 .92108 L
.42565 .92077 L
.42552 .9205 L
.42538 .92029 L
.42525 .92016 L
.42513 .92014 L
.42507 .92024 L
.42508 .92049 L
.42516 .92087 L
.4253 .92133 L
.42545 .92181 L
.42562 .92228 L
.42578 .92271 L
.42594 .92306 L
.42609 .92333 L
.42623 .9235 L
.42638 .92357 L
.42655 .92352 L
.42672 .92331 L
.42689 .92296 L
.42706 .92255 L
.42722 .92211 L
.42735 .92167 L
.42743 .92126 L
.42748 .92094 L
.42751 .92076 L
.42752 .92072 L
.42751 .92076 L
.42748 .92085 L
.42741 .92096 L
.42729 .9211 L
Mistroke
.42711 .9212 L
.42687 .9213 L
.4266 .92136 L
.42631 .92134 L
.42603 .92127 L
.42579 .92115 L
.4256 .921 L
.42544 .92084 L
.42533 .92067 L
.42527 .92053 L
.42525 .92043 L
.42526 .92038 L
.42528 .92039 L
.42531 .92043 L
.42535 .92048 L
.42538 .92052 L
.42541 .92056 L
.42544 .92059 L
.42548 .92063 L
.42551 .92065 L
.42553 .92063 L
.42554 .92058 L
.42555 .92051 L
.42555 .92045 L
.42556 .92046 L
.42558 .92058 L
.42562 .92082 L
.42566 .92116 L
.42571 .92159 L
.42576 .9221 L
.42583 .92265 L
.42591 .92319 L
.426 .9237 L
.42612 .92411 L
.42626 .92455 L
.42641 .92495 L
.42656 .92525 L
.42672 .92547 L
.42686 .92553 L
.42697 .92545 L
.42706 .92529 L
.42713 .92506 L
.42719 .9248 L
.42721 .92455 L
.42723 .92431 L
.42725 .92411 L
.42728 .92393 L
.4273 .92374 L
.42734 .92355 L
.42736 .92335 L
Mistroke
.42736 .92311 L
.42731 .92283 L
.42724 .92253 L
.42714 .92224 L
.42702 .92194 L
.42689 .92163 L
.42675 .92135 L
.42661 .92108 L
.42647 .92089 L
.42632 .92073 L
.42624 .92064 L
.42627 .9206 L
.42634 .9206 L
.42641 .92061 L
.42645 .92061 L
.42645 .92059 L
.42637 .92056 L
.42609 .92053 L
.4255 .92054 L
.42454 .92059 L
.42311 .92062 L
.42117 .9206 L
.41872 .92049 L
.41626 .92029 L
.41339 .91998 L
.40982 .91955 L
.40636 .91901 L
.40186 .91832 L
.39824 .91751 L
.39366 .91664 L
.38961 .91559 L
.3854 .91449 L
.3807 .91328 L
.37702 .91195 L
.37275 .91057 L
.36889 .90915 L
.36494 .90772 L
.36108 .90627 L
.35687 .90489 L
.3533 .90356 L
.34922 .90228 L
.34546 .90103 L
.34156 .8998 L
.33767 .8986 L
.33398 .89739 L
.32993 .89619 L
.32652 .895 L
.32284 .8938 L
.3193 .8926 L
.31589 .89141 L
Mistroke
.31248 .89026 L
.30933 .88921 L
.30612 .88818 L
.30327 .88719 L
.30082 .88631 L
.29859 .88549 L
.29663 .88477 L
.29514 .8842 L
.29388 .88382 L
.29294 .88362 L
.29226 .88355 L
.29175 .88357 L
.29133 .88361 L
.29091 .8836 L
.29039 .88346 L
.28968 .88313 L
.28863 .8826 L
.28744 .88192 L
.28583 .88106 L
.2838 .88004 L
.28152 .87898 L
.27893 .87767 L
.27613 .87635 L
.27302 .87489 L
.27004 .87335 L
.2671 .87174 L
.26427 .87028 L
.26145 .86884 L
.25882 .86742 L
.25628 .8661 L
.25393 .86479 L
.25159 .86339 L
.24934 .86189 L
.24717 .86026 L
.24494 .85848 L
.24264 .85651 L
.24046 .85447 L
.23819 .85223 L
.2359 .84993 L
.23365 .84745 L
.23147 .84479 L
.22933 .84212 L
.22727 .83921 L
.22549 .8365 L
.22387 .83357 L
.22245 .83097 L
.22125 .82846 L
.22022 .82615 L
.21932 .82406 L
.21846 .82219 L
Mistroke
.21754 .82038 L
.21648 .81893 L
.21524 .81761 L
.21376 .81642 L
.21197 .81534 L
.20982 .81437 L
.20771 .81346 L
.20516 .81257 L
.2022 .81152 L
.19934 .81031 L
.19607 .80887 L
.19243 .80715 L
.18904 .80522 L
.18529 .80288 L
.18168 .80038 L
.17798 .79772 L
.17454 .79514 L
.17096 .79222 L
.16774 .78941 L
.16441 .78639 L
.16132 .78358 L
.1583 .78067 L
.15546 .77787 L
.15279 .77507 L
.15032 .77256 L
.14807 .77 L
.14603 .76746 L
.14424 .76505 L
.14262 .76252 L
.14119 .76019 L
.13988 .75777 L
.13863 .75537 L
.13736 .75295 L
.13607 .75053 L
.13479 .74795 L
.13347 .74558 L
.13219 .74306 L
.13089 .74047 L
.1297 .73804 L
.12855 .73555 L
.12748 .73325 L
.12646 .73112 L
.12559 .72898 L
.12527 .72702 L
.1245 .72506 L
.12383 .72337 L
.12334 .72178 L
.12306 .72038 L
.12295 .71921 L
.12295 .71825 L
Mistroke
.12301 .71748 L
.12307 .71688 L
.12306 .71634 L
.12294 .71581 L
.12265 .71519 L
.12212 .71445 L
.12132 .71351 L
.12029 .71237 L
.11905 .71102 L
.11784 .70963 L
.11626 .70802 L
.11442 .70622 L
.11241 .70432 L
.11024 .70212 L
.10805 .69997 L
.10569 .69763 L
.10347 .69513 L
.10145 .69274 L
.09945 .69011 L
.09771 .68746 L
.09615 .68461 L
.09476 .68156 L
.09358 .67815 L
.09253 .67462 L
.09163 .67076 L
.09081 .66655 L
.09005 .66233 L
.08934 .65767 L
.08866 .65325 L
.08799 .6493 L
.08732 .64486 L
.08668 .64034 L
.08598 .63626 L
.08523 .63203 L
.08446 .62789 L
.08363 .62398 L
.08282 .61989 L
.08201 .616 L
.08123 .61212 L
.08054 .60817 L
.07993 .60422 L
.07941 .60038 L
.07898 .59651 L
.07864 .59268 L
.07838 .58909 L
.07817 .58549 L
.07799 .58199 L
.0778 .57886 L
.07759 .57552 L
.07735 .57248 L
Mistroke
.07705 .56926 L
.07666 .56608 L
.07617 .5627 L
.07559 .55911 L
.07493 .55582 L
.07422 .55195 L
.07351 .54805 L
.07281 .54437 L
.07213 .54075 L
.07152 .53698 L
.07101 .53269 L
.07062 .52884 L
.07037 .52474 L
.07025 .52061 L
.07029 .51646 L
.07048 .51228 L
.07081 .50805 L
.07126 .50403 L
.07179 .50017 L
.07238 .49614 L
.073 .49266 L
.07363 .48926 L
.07426 .48618 L
.07485 .48366 L
.07538 .48155 L
.07584 .47992 L
.07621 .4787 L
.07649 .47777 L
.07667 .47712 L
.07678 .47667 L
.07686 .47629 L
.07695 .4759 L
.07708 .47542 L
.07727 .47484 L
.07753 .47415 L
.07787 .47334 L
.07829 .47251 L
.07878 .47153 L
.07933 .4705 L
.07988 .46943 L
.08048 .46839 L
.08103 .46751 L
.08156 .46674 L
.08204 .46613 L
.08244 .46567 L
.08274 .46538 L
.08294 .46524 L
Mfstroke
.09098 .45899 m
.09112 .45896 L
.09139 .45888 L
.09184 .45874 L
.09247 .45852 L
.09332 .45822 L
.09441 .45785 L
.09567 .45747 L
.09715 .45707 L
.09871 .45666 L
.10046 .45621 L
.1022 .45571 L
.10427 .45518 L
.10605 .45464 L
.10788 .4541 L
.10985 .45359 L
.11173 .45312 L
.11365 .45268 L
.11548 .45228 L
.11696 .45192 L
.11847 .45157 L
.11984 .45123 L
.12115 .45089 L
.12236 .45055 L
.1236 .4503 L
.12481 .45009 L
.12606 .44993 L
.12729 .44981 L
.12853 .4497 L
.12976 .44959 L
.13091 .44944 L
.13207 .44925 L
.13322 .44902 L
.13434 .44875 L
.13541 .44845 L
.13633 .44813 L
.13715 .44782 L
.1378 .44758 L
.13824 .44742 L
.13843 .44737 L
.13835 .44746 L
.13803 .4477 L
.13751 .44809 L
.13689 .44862 L
.13625 .44926 L
.13566 .44998 L
.13517 .45077 L
.13479 .45159 L
.13454 .45249 L
.13442 .45348 L
Mistroke
.13446 .45456 L
.13467 .4557 L
.13504 .45687 L
.13566 .45808 L
.13641 .45935 L
.13731 .46066 L
.13833 .46193 L
.13936 .46323 L
.14033 .46451 L
.14118 .46577 L
.1419 .46696 L
.14252 .46798 L
.14306 .46891 L
.14352 .46975 L
.14394 .47049 L
.14436 .47116 L
.1448 .47175 L
.14528 .47227 L
.14584 .47273 L
.14654 .47316 L
.14741 .47357 L
.14843 .47393 L
.14965 .47428 L
.15105 .47463 L
.15266 .47496 L
.1543 .47526 L
.15607 .47549 L
.15791 .47565 L
.15974 .47572 L
.16148 .47573 L
.163 .47568 L
.16434 .47559 L
.16538 .47551 L
.16613 .47547 L
.16659 .47549 L
.16678 .47555 L
.16675 .47562 L
.16652 .47565 L
.16617 .47565 L
.16574 .47558 L
.16529 .47545 L
.16479 .47523 L
.16429 .47492 L
.16383 .47452 L
.16344 .47405 L
.16319 .47349 L
.16311 .4729 L
.16323 .47227 L
.16349 .47163 L
.16382 .471 L
Mistroke
.16418 .47042 L
.1645 .46998 L
.16477 .4697 L
.16496 .46959 L
.16507 .46963 L
.16506 .46975 L
.16492 .46993 L
.16458 .47011 L
.16395 .47023 L
.16318 .47024 L
.16219 .47011 L
.1609 .46984 L
.15918 .46941 L
.15705 .4688 L
.15526 .46809 L
.15267 .46714 L
.15036 .46616 L
.14715 .46508 L
.14451 .46391 L
.14106 .46277 L
.13855 .46177 L
.13476 .46088 L
.13185 .46012 L
.12811 .45952 L
.12552 .45903 L
.12177 .45865 L
.11897 .45836 L
.11542 .45816 L
.11289 .45807 L
.10957 .45809 L
.10635 .45828 L
.10373 .45863 L
.10007 .45913 L
.0975 .45979 L
.09443 .4606 L
.09109 .46156 L
.08847 .46246 L
.0859 .46348 L
.08392 .46444 L
.08154 .46548 L
.0794 .46673 L
.07788 .46778 L
.07663 .46883 L
.07558 .46984 L
.07477 .47081 L
.07418 .47173 L
.07377 .47256 L
.07348 .4733 L
.07328 .47393 L
.0731 .47448 L
Mistroke
.07297 .475 L
.07292 .47558 L
.0729 .476 L
.07285 .47643 L
.07283 .47674 L
.07287 .47693 L
Mfstroke
.08407 .40185 m
.0842 .4016 L
.08434 .4012 L
.0845 .40056 L
.08468 .39968 L
.08488 .39848 L
.08512 .3969 L
.08539 .39522 L
.08568 .39296 L
.08601 .39053 L
.08637 .38788 L
.08678 .38482 L
.08722 .38138 L
.08769 .37772 L
.08815 .37367 L
.08863 .37021 L
.08911 .3657 L
.08963 .36208 L
.0902 .35785 L
.09085 .35342 L
.09157 .34913 L
.09229 .34478 L
.09304 .34104 L
.09381 .33696 L
.09457 .33365 L
.09523 .33043 L
.09598 .32739 L
.09662 .3246 L
.09724 .32253 L
.09785 .32058 L
.09843 .319 L
.09894 .31766 L
.09937 .31659 L
.09972 .31598 L
.09999 .31549 L
.1002 .31517 L
.10036 .31497 L
.10049 .31489 L
.10059 .31483 L
.10067 .31477 L
.1007 .31468 L
.10067 .31456 L
.10062 .31442 L
.10056 .31423 L
.10053 .31399 L
.10055 .31369 L
.10063 .31334 L
.10078 .31295 L
.10096 .31255 L
.10118 .31217 L
Mistroke
.1014 .31183 L
.10158 .31156 L
.10172 .31139 L
.10187 .31123 L
.10204 .31111 L
.10227 .31099 L
.10255 .31082 L
.1029 .31054 L
.10333 .31008 L
.10386 .30937 L
.10454 .30833 L
.10539 .30692 L
.10643 .30526 L
.10752 .30324 L
.10892 .30116 L
.11039 .29871 L
.11209 .29584 L
.11384 .29291 L
.11574 .29009 L
.11752 .28698 L
.11941 .28382 L
.12129 .28063 L
.12307 .27763 L
.1249 .27461 L
.12671 .27169 L
.12853 .26873 L
.13049 .26577 L
.1324 .26272 L
.13444 .25955 L
.13649 .2565 L
.1386 .25305 L
.14076 .24985 L
.14299 .24646 L
.14531 .24294 L
.1475 .23968 L
.14976 .23628 L
.15224 .23268 L
.15436 .22951 L
.15671 .22604 L
.15906 .22251 L
.16165 .21907 L
.1639 .21547 L
.16633 .21204 L
.16879 .20862 L
.17113 .20517 L
.17346 .20189 L
.17579 .19858 L
.17798 .19526 L
.17999 .19216 L
.18202 .18895 L
Mistroke
.18397 .18561 L
.18584 .1828 L
.18755 .17994 L
.18925 .17717 L
.19079 .17497 L
.19232 .17277 L
.19363 .17091 L
.19484 .1692 L
.19604 .16774 L
.197 .16655 L
.19786 .16558 L
.19859 .16485 L
.19917 .16436 L
.19957 .16411 L
.19978 .16408 L
.19982 .16418 L
.19975 .16434 L
.19964 .16444 L
.19956 .16443 L
.1996 .16424 L
.19979 .16384 L
.20016 .16321 L
.20073 .16237 L
.20149 .16137 L
.20247 .16018 L
.20371 .15882 L
.20515 .15733 L
.20678 .15572 L
.20874 .15397 L
.21096 .15206 L
.21312 .15017 L
.2157 .14816 L
.21838 .14621 L
.22103 .14427 L
.22393 .14242 L
.22664 .14063 L
.22936 .1391 L
.23195 .13763 L
.2343 .13642 L
.23642 .13532 L
.23828 .13444 L
.23985 .13373 L
.24105 .13321 L
.242 .13288 L
.24272 .13272 L
.24322 .13268 L
.24355 .13274 L
.24375 .13286 L
.24387 .13302 L
.24394 .13318 L
Mistroke
.24396 .13334 L
.24396 .13348 L
.24396 .13359 L
.24402 .13365 L
.24411 .13365 L
.24425 .13355 L
.24447 .13331 L
.24481 .13291 L
.24533 .13234 L
.24608 .1316 L
.2471 .13069 L
.24843 .12973 L
.24997 .12857 L
.25179 .1272 L
.25405 .1258 L
.25651 .1242 L
.25932 .12244 L
.2627 .1206 L
.26561 .11875 L
.26893 .11675 L
.27257 .11487 L
.27569 .11285 L
.27906 .11095 L
.28232 .10896 L
.28565 .10682 L
.28874 .10483 L
.29197 .10261 L
.2954 .10055 L
.29875 .09835 L
.30248 .09603 L
.30607 .09387 L
.30991 .09157 L
.31399 .08928 L
.318 .08691 L
.32208 .08451 L
.32671 .08195 L
.33062 .07948 L
.33505 .07688 L
.33922 .07435 L
.34365 .07179 L
.34758 .0695 L
.35139 .0673 L
.35495 .06519 L
.35829 .06338 L
.36117 .06192 L
.36375 .06062 L
.36607 .05951 L
.36783 .05865 L
.36939 .05801 L
.37057 .05761 L
Mistroke
.37147 .05739 L
.37209 .05731 L
.37245 .05734 L
.37259 .05744 L
.3726 .05758 L
.37251 .05771 L
.37236 .05779 L
.37219 .05782 L
.37204 .05784 L
.37195 .05785 L
.37191 .05785 L
.3719 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37189 .05785 L
.37188 .05785 L
.37185 .05785 L
.3718 .05785 L
.37173 .05785 L
.37166 .05785 L
.37159 .05785 L
.37153 .05784 L
.37153 .05784 L
.37161 .05785 L
.37178 .05788 L
.37207 .05793 L
.37251 .05801 L
.37313 .05809 L
.37392 .05815 L
.37491 .05815 L
.3761 .0581 L
.3775 .05797 L
.37906 .05777 L
.38089 .05751 L
.38273 .05719 L
.38483 .05684 L
Mistroke
.38699 .05647 L
.38932 .05611 L
.39142 .05575 L
.39365 .05539 L
.39576 .05507 L
.39777 .05478 L
.39958 .05456 L
.40122 .05442 L
.40265 .05435 L
.40388 .05436 L
.40483 .05441 L
.40557 .05449 L
.40612 .05458 L
.40648 .05464 L
.40666 .05467 L
.40672 .05468 L
.40668 .05467 L
.40659 .05467 L
.40648 .05467 L
.40637 .05466 L
.40628 .05466 L
.40622 .05466 L
.40617 .05466 L
.40613 .05466 L
.4061 .05466 L
.40608 .05466 L
.40609 .05466 L
.40614 .05466 L
.40624 .05466 L
.40637 .05466 L
.40654 .05466 L
.40674 .05467 L
.40697 .05468 L
.4072 .05469 L
.40744 .05471 L
.40768 .05472 L
.4079 .05472 L
.40811 .05468 L
.4083 .05462 L
.40844 .05456 L
.40855 .05454 L
.40861 .05457 L
.40862 .05468 L
.40861 .05491 L
.40858 .05522 L
.40854 .05559 L
.40851 .05597 L
.40848 .05634 L
.40845 .05665 L
.40841 .05689 L
Mistroke
.40836 .05704 L
.40829 .0571 L
.40821 .05707 L
.40813 .05695 L
.4081 .05671 L
.40811 .05643 L
.40821 .05612 L
.40842 .05582 L
.40879 .05556 L
.40934 .05544 L
.41011 .0555 L
.41111 .05575 L
.41241 .05613 L
.41393 .05658 L
.4158 .05705 L
.41784 .05751 L
.4202 .0579 L
.42281 .05818 L
.42581 .05833 L
.42851 .05836 L
.43164 .05829 L
.435 .0581 L
.43803 .05786 L
.44126 .05758 L
.44449 .05729 L
.44801 .05704 L
.4509 .05682 L
.45414 .05666 L
.45758 .05655 L
.46068 .05645 L
.46394 .05632 L
.46717 .05611 L
.47057 .05582 L
.47423 .05548 L
.47754 .05511 L
.48106 .05474 L
.48474 .05444 L
.48809 .05421 L
.49179 .05407 L
.49522 .05403 L
.49887 .05413 L
.50249 .05441 L
.50586 .05485 L
.50943 .05543 L
.51277 .05612 L
.51608 .05694 L
.51945 .05784 L
.52288 .05877 L
.52618 .05965 L
.52948 .06043 L
Mistroke
.53279 .06113 L
.53611 .06179 L
.53938 .06243 L
.54263 .06309 L
.54579 .06379 L
.54897 .06454 L
.55192 .06537 L
.55474 .06627 L
.5574 .06719 L
.55975 .06813 L
.56187 .06892 L
.5637 .06978 L
.56524 .07068 L
.5664 .07144 L
.56725 .07213 L
.56783 .07274 L
.56816 .07323 L
.56829 .07359 L
.56832 .07381 L
.56836 .0739 L
.56851 .0739 L
.56884 .07387 L
.56941 .07384 L
.57029 .07385 L
.57153 .07388 L
.57308 .07392 L
.57513 .07395 L
.57758 .07393 L
.58033 .07384 L
.58339 .07369 L
.5867 .07344 L
.58988 .07312 L
.59311 .07273 L
.59606 .07231 L
.59896 .07193 L
.60141 .07156 L
.60382 .07126 L
.60608 .07106 L
.608 .071 L
.60989 .07113 L
.61179 .07146 L
.61374 .072 L
.61579 .07276 L
.61783 .07367 L
.62 .07476 L
.62215 .07602 L
.62451 .07734 L
.62708 .07875 L
.63 .08013 L
.63257 .08146 L
Mistroke
.63533 .08273 L
.63805 .08385 L
.6409 .0848 L
.64344 .08564 L
.64607 .08637 L
.64869 .08697 L
.65132 .08751 L
.6542 .08801 L
.65707 .08851 L
.66011 .08902 L
.66342 .08959 L
.66668 .09024 L
.67012 .09096 L
.67371 .09172 L
.6771 .0926 L
.68062 .09363 L
.68395 .09483 L
.68741 .09605 L
.69048 .09738 L
.69368 .0988 L
.69688 .10024 L
.69977 .10164 L
.70295 .10305 L
.70566 .10427 L
.70825 .10552 L
.71068 .10661 L
.71285 .10762 L
.71491 .1085 L
.7164 .10921 L
.71767 .10972 L
.7187 .11002 L
.71942 .11011 L
.71984 .11003 L
.71998 .10979 L
.71989 .10946 L
.71965 .10912 L
.71935 .10884 L
.71907 .10865 L
.7188 .10856 L
.71862 .10857 L
.71859 .10871 L
.71871 .10897 L
.71889 .10932 L
.7191 .10971 L
.71934 .11013 L
.71959 .11053 L
.71982 .1109 L
.72001 .11117 L
.72009 .11133 L
.72006 .11138 L
Mistroke
.71997 .11131 L
.71983 .11118 L
.71969 .11099 L
.71961 .11076 L
.71967 .11056 L
.71992 .11046 L
.72042 .1105 L
.7212 .1107 L
.72227 .11109 L
.72366 .11167 L
.72525 .11243 L
.72702 .11326 L
.72906 .11421 L
.73131 .11524 L
.73377 .11631 L
.73614 .11729 L
.7384 .1182 L
.74059 .11903 L
.74258 .11972 L
.74426 .12027 L
.7457 .12067 L
.74687 .12094 L
.74775 .1211 L
.74843 .12117 L
.74895 .1212 L
.74936 .12119 L
.74965 .12116 L
.74986 .12112 L
.75002 .12109 L
.75013 .12106 L
.75023 .12104 L
.75033 .12101 L
.75045 .12098 L
.75057 .12095 L
.75068 .12093 L
.75076 .12093 L
.75081 .12094 L
.75081 .12097 L
.75077 .12103 L
.75067 .1211 L
.75054 .12119 L
.75039 .12131 L
.75026 .12148 L
.75018 .12171 L
.75019 .12204 L
.75032 .12242 L
.75061 .12288 L
.75109 .12341 L
.7518 .12397 L
.75274 .12465 L
Mistroke
.75389 .12542 L
.75538 .12632 L
.75705 .12735 L
.75895 .1285 L
.76111 .12981 L
.76346 .13122 L
.76585 .13273 L
.76824 .1343 L
.77057 .13572 L
.77271 .13714 L
.77456 .13834 L
.77625 .13945 L
.77777 .14052 L
.77895 .14142 L
.77995 .14223 L
.78078 .14298 L
.78146 .14376 L
.78204 .14463 L
.78253 .14553 L
.78295 .14649 L
.78334 .14746 L
.78372 .14856 L
.78404 .14954 L
.78429 .15062 L
.78451 .1516 L
.78474 .15258 L
.785 .15365 L
.78531 .15451 L
.78573 .15535 L
.78629 .15617 L
.7871 .15702 L
.7882 .15787 L
.7896 .15879 L
.79116 .15975 L
.79296 .16106 L
.79495 .16256 L
.79702 .16427 L
.79939 .16615 L
.80206 .16822 L
.80438 .17037 L
.80677 .17265 L
.80905 .17492 L
.8111 .17727 L
.81293 .17945 L
.81464 .18172 L
.81613 .18386 L
.8175 .18602 L
.81883 .18823 L
.8201 .19034 L
.82136 .19224 L
Mistroke
.82263 .19411 L
.82387 .1959 L
.82514 .19764 L
.82644 .19923 L
.82771 .20081 L
.82905 .20233 L
.83039 .20382 L
.8317 .20528 L
.83308 .20682 L
.83449 .20851 L
.83592 .21024 L
.8375 .21226 L
.83922 .21432 L
.84081 .21667 L
.84256 .21893 L
.8443 .22145 L
.84609 .22392 L
.84792 .22641 L
.84954 .22876 L
.85111 .23096 L
.85248 .23295 L
.85364 .23443 L
.85451 .23564 L
.85516 .23656 L
.85557 .23717 L
.8557 .23746 L
.8556 .23743 L
.85533 .23715 L
.85492 .2367 L
.85442 .23614 L
.8539 .23556 L
.85338 .23498 L
.85289 .23446 L
.85249 .23406 L
.85219 .23379 L
.852 .23361 L
.85189 .23349 L
.85184 .23343 L
.85181 .23339 L
.8518 .23336 L
.8518 .23333 L
.85178 .23331 L
.85173 .23328 L
.85167 .23327 L
.85168 .23334 L
.8518 .23353 L
.85206 .23386 L
.85247 .23435 L
.85305 .23501 L
.8538 .23584 L
Mistroke
.85467 .23682 L
.85571 .23804 L
.85693 .23943 L
.85824 .24107 L
.85977 .24289 L
.86154 .24504 L
.86315 .24724 L
.86487 .24977 L
.86681 .25233 L
.86891 .25512 L
.87071 .25795 L
.87266 .26096 L
.8746 .26409 L
.87647 .26696 L
.8783 .26998 L
.88015 .27313 L
.88189 .27591 L
.8835 .27859 L
.88513 .28142 L
.88668 .28407 L
.88814 .28651 L
.88958 .28897 L
.89089 .29141 L
.89216 .2936 L
.89342 .29584 L
.89455 .29779 L
.89563 .29974 L
.89663 .30136 L
.89753 .30288 L
.89835 .30424 L
.89901 .30531 L
.89954 .30616 L
.89994 .30679 L
.90019 .30719 L
.90031 .3074 L
.90034 .30745 L
.9003 .30738 L
.90023 .30727 L
.90015 .30715 L
.90008 .30704 L
.90003 .30697 L
.9 .30691 L
.89999 .30689 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
Mistroke
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89998 .30688 L
.89997 .30687 L
.89995 .30684 L
.89992 .30681 L
.89989 .30678 L
.89987 .30677 L
.89988 .30678 L
.89992 .30682 L
.9 .3069 L
.90012 .30702 L
.90026 .30717 L
.90043 .30734 L
.90062 .30754 L
.90082 .30774 L
.90102 .30795 L
.90123 .30815 L
.90142 .30835 L
.9016 .30853 L
.90175 .30869 L
.90188 .30882 L
.90196 .30891 L
.90201 .30896 L
.90203 .30897 L
.90202 .30896 L
.90199 .30893 L
.90195 .3089 L
.90193 .30887 L
.90192 .30886 L
.90191 .30886 L
.90191 .30886 L
.90191 .30886 L
.90191 .30886 L
.90192 .30885 L
.90193 .30884 L
.90195 .30883 L
.90198 .30882 L
.902 .30882 L
.90202 .30884 L
.90201 .30887 L
.90197 .30891 L
.9019 .30896 L
.9018 .30902 L
.90166 .30909 L
.9015 .30915 L
.90132 .30918 L
.90113 .30918 L
.90093 .30913 L
Mistroke
.90073 .30906 L
.90054 .30893 L
.90036 .30877 L
.90021 .30857 L
.90008 .30834 L
.89998 .30809 L
.89993 .30784 L
.8999 .30759 L
.8999 .30735 L
.89992 .30711 L
.89994 .30687 L
.89994 .30664 L
.89991 .30643 L
.89984 .30628 L
.89975 .30623 L
.89969 .3063 L
.89967 .30651 L
.89971 .3069 L
.89986 .30747 L
.90011 .30821 L
.9005 .30914 L
.901 .31026 L
.90161 .31144 L
.9023 .31283 L
.90301 .31446 L
.90382 .31624 L
.90459 .3181 L
.90536 .32016 L
.9061 .32218 L
.90678 .32458 L
.90735 .32642 L
.90782 .32866 L
.9082 .33095 L
.90851 .33298 L
.90876 .33503 L
.90898 .33722 L
.90918 .33938 L
.90941 .34142 L
.90962 .34334 L
.90981 .3451 L
.90993 .34656 L
.91 .34773 L
.91005 .34873 L
.91008 .34955 L
.91008 .35021 L
.91007 .35068 L
.91006 .35101 L
.91004 .35122 L
.91002 .35138 L
.91001 .35146 L
Mistroke
.91004 .35149 L
.91011 .35152 L
.91021 .35157 L
.91036 .35171 L
.91053 .35189 L
.91068 .35204 L
.91079 .35213 L
.91083 .35214 L
.91079 .35207 L
.91068 .35187 L
.9105 .35154 L
.91028 .35105 L
.91007 .35044 L
.90987 .34974 L
.90968 .34901 L
.90949 .34831 L
.9093 .34773 L
.90911 .34729 L
.9089 .34704 L
.90868 .34702 L
.90843 .34725 L
.90815 .34773 L
.90784 .34847 L
.90751 .34941 L
.90718 .35039 L
.90684 .35143 L
.9065 .35248 L
.90621 .35348 L
.90599 .35425 L
.90586 .35479 L
.90585 .35508 L
.90597 .35513 L
.90621 .35497 L
.90654 .35463 L
.90691 .35413 L
.9073 .35351 L
.90767 .35279 L
.90798 .35204 L
.90821 .35133 L
.90836 .35064 L
.90845 .35001 L
.90848 .34942 L
.90845 .34887 L
.90837 .34834 L
.90826 .34783 L
.90816 .34733 L
.90807 .34679 L
.90802 .34621 L
.90804 .34559 L
.90812 .34493 L
Mistroke
.90828 .34423 L
.90852 .34348 L
.90881 .34265 L
.90911 .34175 L
.90942 .34076 L
.90971 .33976 L
.90996 .33866 L
.91015 .33756 L
.91029 .33644 L
.91036 .33533 L
.91036 .33425 L
.91031 .33316 L
.91019 .33214 L
.91002 .3311 L
.90981 .33009 L
.90956 .32915 L
.90931 .32829 L
.90906 .32755 L
.90884 .32685 L
.90865 .32617 L
.90848 .32549 L
.90833 .32478 L
.9082 .32407 L
.90808 .32331 L
.90796 .32253 L
.90784 .32176 L
.90772 .32102 L
.90758 .32032 L
.90743 .31972 L
.90725 .31913 L
.90704 .31857 L
.90683 .31807 L
.90663 .31762 L
.90642 .31724 L
.90624 .31692 L
.90608 .31669 L
.90595 .31654 L
.90586 .31648 L
.90579 .31649 L
.90575 .31654 L
.90573 .3166 L
.90575 .31665 L
.90579 .31668 L
.90585 .31671 L
.90594 .31672 L
.90605 .31673 L
.90619 .31673 L
.90636 .31673 L
.90654 .31673 L
.90673 .31673 L
Mistroke
.90692 .31673 L
.90711 .31673 L
.9073 .31674 L
.90747 .31674 L
.90762 .31674 L
.90773 .31674 L
.90782 .31674 L
.90787 .31674 L
.90788 .31674 L
.90787 .31674 L
.90784 .31674 L
.90781 .31674 L
.90779 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90777 .31674 L
.90778 .31673 L
.9078 .3167 L
.90783 .31666 L
.90786 .31662 L
.90787 .31661 L
.90786 .31664 L
.90783 .3167 L
Mistroke
.90776 .31679 L
.90766 .31693 L
.90753 .31711 L
.90738 .31731 L
.90721 .31752 L
.90703 .31772 L
.90685 .31794 L
.90666 .31813 L
.90648 .31831 L
.90632 .31849 L
.90617 .31865 L
.90606 .31877 L
.90597 .31883 L
.90592 .31885 L
.9059 .31883 L
.90591 .31879 L
.90593 .31874 L
.90596 .31869 L
.90598 .31867 L
.906 .31868 L
.906 .31871 L
.906 .31876 L
.906 .31879 L
.90601 .3188 L
.906 .31879 L
.906 .31875 L
.906 .31867 L
.906 .31856 L
.90599 .31842 L
.90598 .31827 L
.90598 .31812 L
.90597 .31798 L
.90597 .31784 L
.90596 .31766 L
.90598 .31747 L
.90603 .31725 L
.90608 .31699 L
.90613 .3167 L
.90615 .31637 L
.90615 .31598 L
.90608 .31553 L
.90592 .31499 L
.90564 .31435 L
.90524 .31361 L
.90474 .3128 L
.90415 .31194 L
.9035 .31106 L
.90289 .31025 L
.90222 .30949 L
.90151 .30881 L
Mistroke
.90073 .30822 L
.9001 .30773 L
.89954 .30735 L
.89905 .30706 L
.89866 .30688 L
.89847 .30682 L
.89848 .30686 L
.89861 .30707 L
.89884 .3073 L
.8991 .30752 L
.89931 .30771 L
.89943 .30788 L
.89943 .30806 L
.8993 .30826 L
.89903 .3085 L
.89858 .30881 L
.89795 .30918 L
.89717 .30961 L
.89638 .31009 L
.89554 .31057 L
.89464 .31104 L
.89372 .31144 L
.89291 .31178 L
.8925 .31201 L
.89224 .3121 L
.89221 .31204 L
.8924 .31186 L
.89273 .31156 L
.89313 .3112 L
.89367 .31084 L
.89439 .31054 L
.89503 .31037 L
.89571 .31042 L
.89643 .31073 L
.89706 .31136 L
.89763 .3123 L
.8982 .31352 L
.89881 .31501 L
.89948 .31688 L
.90021 .31907 L
.90097 .32146 L
.90189 .32404 L
.90294 .32661 L
.90395 .32939 L
.90517 .33229 L
.90647 .33534 L
.9077 .33859 L
.90902 .34182 L
.9103 .34529 L
.9115 .34902 L
Mistroke
.91257 .35246 L
.91354 .35604 L
.9144 .36006 L
.91517 .36329 L
.91589 .36713 L
.91653 .37047 L
.91714 .3741 L
.9177 .37778 L
.9182 .38124 L
.91864 .3848 L
.91901 .38849 L
.91933 .39203 L
.91962 .39549 L
.91988 .39915 L
.92012 .40267 L
.92033 .40638 L
.92052 .40981 L
.92071 .41327 L
.92088 .41653 L
.92105 .41969 L
.92122 .42279 L
.92141 .42565 L
.92163 .42861 L
.92187 .43124 L
.92214 .43381 L
.92243 .43642 L
.92271 .43871 L
.92298 .44098 L
.92324 .44298 L
.92348 .44469 L
.92368 .44614 L
.92384 .44719 L
.92395 .44791 L
.92401 .44829 L
.92402 .44832 L
.924 .44805 L
.92395 .44755 L
.92389 .4469 L
.92384 .44616 L
.9238 .44538 L
.92377 .44466 L
.92375 .44402 L
.92373 .44351 L
.92372 .44313 L
.92373 .44289 L
.92377 .44277 L
.92382 .44275 L
.92387 .44279 L
.9239 .44286 L
.92389 .44294 L
Mistroke
.92381 .44301 L
.92365 .44304 L
.92341 .44306 L
.92309 .44307 L
.92273 .44307 L
.92235 .44308 L
.92199 .44309 L
.92166 .4431 L
.92138 .4431 L
.92114 .44306 L
.92096 .44299 L
.92085 .44289 L
.92083 .44276 L
.9209 .44261 L
.92105 .4425 L
.92123 .44246 L
.92139 .44254 L
.92151 .44281 L
.92155 .44335 L
.92145 .44416 L
.92122 .44527 L
.92087 .44672 L
.92045 .44831 L
.91996 .45021 L
.91941 .45238 L
.91884 .45463 L
.91832 .45684 L
.91784 .45929 L
.91743 .46217 L
.91712 .46461 L
.91694 .46711 L
.91691 .46972 L
.91702 .47241 L
.9173 .47484 L
.91769 .47751 L
.91815 .48014 L
.9187 .4829 L
.91929 .48587 L
.9199 .48867 L
.92054 .49161 L
.92119 .49426 L
.92183 .4968 L
.92249 .49907 L
.92311 .50097 L
.92373 .50258 L
.92432 .50398 L
.9249 .50523 L
.92546 .5063 L
.92601 .50734 L
.92658 .50841 L
Mistroke
.92716 .50949 L
.92775 .51078 L
.92836 .51231 L
.92899 .51399 L
.92962 .51609 L
.93024 .51842 L
.93081 .52118 L
.9313 .52398 L
.93168 .52721 L
.93196 .53004 L
.93211 .53304 L
.93215 .53604 L
.93209 .5388 L
.93193 .54151 L
.93171 .54383 L
.93146 .54598 L
.9312 .5478 L
.93093 .54941 L
.93069 .55074 L
.9305 .55175 L
.93037 .5525 L
.9303 .55299 L
.9303 .55325 L
.93036 .5533 L
.93049 .55316 L
.93068 .5529 L
.93091 .55256 L
.93114 .55222 L
.93134 .55193 L
.93147 .55172 L
.9315 .55165 L
.93141 .55173 L
.93121 .55203 L
.93093 .55254 L
.93058 .55331 L
.93015 .55437 L
.92965 .55571 L
.92909 .55726 L
.92845 .55904 L
.92773 .56109 L
.92693 .56325 L
.92607 .56571 L
.92524 .5681 L
.92438 .57074 L
.92362 .57344 L
.92287 .57632 L
.92223 .57905 L
.92161 .58197 L
.92101 .5848 L
.92042 .5877 L
Mistroke
.91983 .59051 L
.91923 .59328 L
.91861 .59597 L
.91803 .59843 L
.91746 .60068 L
.91694 .60269 L
.91648 .60441 L
.91608 .60592 L
.91573 .60706 L
.91544 .60793 L
.91524 .60855 L
.91514 .60891 L
.91516 .60903 L
.91527 .60896 L
.91547 .60877 L
.91571 .60854 L
.91597 .60834 L
.9162 .60823 L
.91638 .60826 L
.91644 .60843 L
.91636 .60878 L
.91612 .60929 L
.91567 .60998 L
.91503 .61087 L
.91422 .61194 L
.91328 .61319 L
.91215 .61462 L
.9108 .61618 L
.90954 .61776 L
.90812 .61935 L
.90667 .62099 L
.90556 .62257 L
.90426 .62437 L
.90325 .62601 L
.90234 .62772 L
.90152 .62954 L
.90084 .63148 L
.90036 .63354 L
.90005 .63551 L
.89986 .63769 L
.89972 .64012 L
.89958 .64252 L
.89944 .64518 L
.89926 .64804 L
.89895 .65096 L
.89854 .65412 L
.89805 .65697 L
.89759 .65971 L
.89714 .66222 L
.89672 .66442 L
Mistroke
.89635 .6664 L
.89603 .66798 L
.89578 .66934 L
.8956 .67043 L
.89548 .67121 L
.89542 .67169 L
.8954 .67191 L
.89542 .67191 L
.89548 .67175 L
.89558 .67152 L
.89569 .67126 L
.89577 .67103 L
.8958 .6709 L
.89575 .67088 L
.89563 .67096 L
.89542 .67114 L
.89515 .67138 L
.89483 .67167 L
.89451 .67197 L
.89421 .67229 L
.89395 .67258 L
.89371 .67286 L
.89349 .67317 L
.89329 .67353 L
.8931 .67397 L
.89295 .67453 L
.89285 .67522 L
.8928 .6761 L
.89275 .67725 L
.89267 .67877 L
.89251 .6806 L
.89222 .68284 L
.89177 .68558 L
.89112 .68861 L
.89027 .69191 L
.88923 .69583 L
.8881 .69964 L
.88687 .70363 L
.8856 .70797 L
.8843 .71179 L
.88295 .71618 L
.88157 .71998 L
.88015 .72409 L
.87874 .728 L
.87731 .73201 L
.8759 .73584 L
.87453 .73983 L
.87325 .74315 L
.87202 .74656 L
.87086 .74987 L
Mistroke
.86974 .75276 L
.86868 .75571 L
.86768 .75818 L
.86672 .76054 L
.86579 .76277 L
.86496 .76464 L
.86416 .76636 L
.86344 .7678 L
.86285 .76894 L
.86241 .76975 L
.86204 .77044 L
.8617 .77104 L
.86134 .77163 L
.86105 .77211 L
.86074 .77259 L
.86046 .77303 L
.86026 .77339 L
.86012 .77368 L
.86002 .77389 L
.85993 .77403 L
.8598 .77412 L
.85962 .77427 L
.85931 .77451 L
.85889 .77483 L
.85841 .77521 L
.8579 .7756 L
.8574 .77596 L
.85697 .77623 L
.85662 .77641 L
.85636 .7765 L
.85619 .77656 L
.85603 .77659 L
.85593 .77664 L
.85588 .7767 L
.85587 .77677 L
.85598 .77679 L
.85618 .77677 L
.85645 .77668 L
.85673 .77657 L
.85699 .77642 L
.85719 .77625 L
.85733 .77606 L
.85741 .77591 L
.85746 .77578 L
.85747 .77571 L
.85744 .77569 L
.85737 .77571 L
.8573 .77575 L
.85719 .77582 L
.85703 .77595 L
Mistroke
.85682 .77615 L
.85657 .77639 L
.85628 .77666 L
.85596 .77697 L
.85562 .77729 L
.85528 .77758 L
.85499 .77777 L
.85483 .77784 L
.85472 .77786 L
.85458 .77791 L
.85437 .77803 L
.8541 .77822 L
.85373 .77853 L
.85324 .77896 L
.85262 .77951 L
.85187 .78019 L
.85099 .781 L
.85003 .78191 L
.849 .7829 L
.848 .78388 L
.8469 .78471 L
.84567 .78588 L
.84438 .7871 L
.84309 .78826 L
.84189 .78926 L
.8408 .79006 L
.83987 .7907 L
.83905 .7912 L
.83832 .79161 L
.83764 .79196 L
.83703 .79227 L
.83641 .79258 L
.83587 .79283 L
.83546 .793 L
.8352 .79304 L
.83509 .79296 L
.83511 .79277 L
.83521 .79255 L
.83533 .79235 L
.83545 .79221 L
.83558 .79208 L
.83569 .79199 L
.83579 .79192 L
.83584 .7919 L
.83585 .79197 L
.83583 .79211 L
.83577 .79233 L
.83565 .79264 L
.83544 .79308 L
.83513 .79361 L
Mistroke
.83474 .79417 L
.83435 .79459 L
.83395 .79492 L
.83353 .79517 L
.83303 .79541 L
.83259 .79561 L
.83209 .79581 L
.83161 .79602 L
.83112 .79622 L
.83063 .79643 L
.83014 .79666 L
.82967 .79692 L
.82917 .79722 L
.82856 .7976 L
.82794 .79808 L
.82731 .79866 L
.82651 .79942 L
.82566 .80031 L
.82476 .80126 L
.82394 .80214 L
.82305 .80298 L
.82217 .80373 L
.82136 .80439 L
.82055 .805 L
.81995 .80556 L
.8194 .80608 L
.819 .80651 L
.81878 .80681 L
.81872 .80697 L
.81879 .80702 L
.81897 .80699 L
.81916 .80692 L
.81934 .80683 L
.81948 .80672 L
.8196 .80659 L
.81966 .80643 L
.81963 .80623 L
.81952 .80598 L
.81933 .80568 L
.81907 .80535 L
.81874 .805 L
.81836 .80464 L
.81801 .8043 L
.81773 .80395 L
.81755 .80361 L
.81752 .80328 L
.81764 .80299 L
.81787 .80276 L
.81818 .80258 L
.81856 .80245 L
Mistroke
.81902 .8024 L
.81952 .80241 L
.82005 .80244 L
.82059 .80246 L
.82115 .80241 L
.82172 .80228 L
.8223 .80204 L
.82291 .80169 L
.82352 .80122 L
.82416 .80061 L
.82492 .79983 L
.82588 .79888 L
.82705 .79776 L
.82852 .79654 L
.83023 .79516 L
.83218 .79367 L
.83442 .79209 L
.83674 .79046 L
.83926 .78878 L
.84192 .78708 L
.84449 .78533 L
.84703 .78366 L
.84965 .78196 L
.85191 .78027 L
.85418 .77871 L
.85622 .77714 L
.85806 .77562 L
.85969 .7741 L
.86114 .77264 L
.86228 .77123 L
.86327 .76985 L
.86411 .76856 L
.86478 .76737 L
.86533 .76625 L
.86575 .7652 L
.86605 .76425 L
.86624 .7633 L
.86634 .76241 L
.86635 .76148 L
.86627 .76064 L
.86613 .7598 L
.86597 .75901 L
.86579 .75827 L
.86562 .75764 L
.86546 .7571 L
.86533 .75664 L
.86523 .75628 L
.86519 .75601 L
.86519 .75585 L
.86524 .7558 L
Mistroke
.86535 .75588 L
.86554 .75604 L
.86579 .75628 L
.86612 .75651 L
.86657 .75667 L
.867 .75669 L
.86753 .75649 L
.86814 .756 L
.86883 .75518 L
.86963 .75399 L
.8705 .75245 L
.8715 .75049 L
.87255 .74813 L
.87371 .74519 L
.87487 .74248 L
.87611 .73896 L
.8773 .73589 L
.87855 .73216 L
.87983 .72829 L
.88105 .72477 L
.88231 .72119 L
.8835 .7176 L
.88465 .71411 L
.88573 .71076 L
.88673 .70763 L
.88757 .70473 L
.88832 .7022 L
.88899 .69977 L
.88953 .69783 L
.88998 .69608 L
.89032 .6946 L
.89057 .69349 L
.89074 .69268 L
.89085 .69214 L
.89089 .69183 L
.89087 .6917 L
.8908 .69168 L
.89066 .6917 L
.89046 .6917 L
.89018 .6916 L
.88982 .69137 L
.88938 .69103 L
.88887 .69058 L
.88828 .69004 L
.8877 .68946 L
.88709 .68887 L
.88648 .6883 L
.8859 .6878 L
.88542 .68737 L
.88506 .68702 L
Mistroke
.88484 .68677 L
.88478 .68662 L
.88488 .68654 L
.88511 .68653 L
.88546 .68657 L
.88587 .68662 L
.88632 .68665 L
.88678 .68664 L
.88722 .68658 L
.88762 .6865 L
.88796 .68641 L
.88822 .68631 L
.88838 .68623 L
.88844 .6862 L
.88842 .68621 L
.88833 .68628 L
.88818 .68643 L
.88799 .68663 L
.88779 .68687 L
.88757 .68715 L
.88734 .68737 L
.88709 .68761 L
.88682 .68786 L
.88652 .68813 L
.88619 .68842 L
.88585 .68875 L
.88549 .68909 L
.88515 .68948 L
.88481 .68986 L
.88448 .69027 L
.88415 .69069 L
.88383 .6911 L
.88352 .69154 L
.8832 .69195 L
.88292 .69229 L
.88267 .69254 L
.88249 .69268 L
.88238 .69272 L
.88236 .69267 L
.88242 .69249 L
.88257 .69219 L
.8828 .69174 L
.88307 .69116 L
.88343 .69043 L
.88388 .68955 L
.88438 .68848 L
.885 .68717 L
.8857 .68562 L
.88649 .6838 L
.8874 .68182 L
Mistroke
.88837 .67952 L
.88944 .67704 L
.8905 .67434 L
.89158 .67133 L
.89268 .66847 L
.89372 .66532 L
.89479 .66218 L
.89578 .65892 L
.89684 .65572 L
.8978 .65241 L
.89892 .64908 L
.89997 .64579 L
.90113 .64236 L
.90243 .63893 L
.90366 .63546 L
.90496 .63188 L
.90646 .62834 L
.90765 .62476 L
.90917 .62109 L
.91063 .6174 L
.91198 .61375 L
.9135 .61 L
.91497 .60622 L
.91631 .60247 L
.91757 .5988 L
.91874 .5952 L
.91974 .5916 L
.92073 .58802 L
.92165 .58453 L
.92252 .581 L
.92346 .57736 L
.92438 .57406 L
.92537 .57057 L
.9263 .56708 L
.92723 .56337 L
.92804 .56002 L
.9288 .55645 L
.92944 .55269 L
.92995 .54921 L
.93037 .54544 L
.93069 .54167 L
.93092 .53756 L
.93103 .53387 L
.93104 .52983 L
.93094 .52564 L
.93076 .52155 L
.93053 .5174 L
.93028 .51323 L
.93003 .50891 L
.92979 .50496 L
Mistroke
.92957 .50071 L
.92937 .49645 L
.92916 .4923 L
.92891 .4883 L
.92862 .48405 L
.9283 .47982 L
.92795 .47549 L
.92759 .47142 L
.92724 .46763 L
.9269 .46402 L
.92658 .4604 L
.92627 .45725 L
.92598 .45423 L
.92566 .45102 L
.92535 .44856 L
.92503 .44626 L
.92471 .44404 L
.92438 .44191 L
.92405 .43988 L
.92371 .43804 L
.92335 .43614 L
.92297 .43408 L
.9226 .43186 L
.92223 .4295 L
.92188 .4269 L
.92155 .42412 L
.92125 .42114 L
.92099 .41798 L
.92078 .41467 L
.9206 .41146 L
.92041 .40797 L
.92019 .40439 L
.91992 .40079 L
.91957 .39689 L
.91916 .39298 L
.91868 .38893 L
.91811 .38447 L
.91749 .38047 L
.91681 .37617 L
.91611 .3718 L
.9154 .36745 L
.91469 .3631 L
.914 .35893 L
.91334 .35497 L
.91271 .35118 L
.91211 .34762 L
.91155 .34434 L
.91102 .3414 L
.91054 .33879 L
.9101 .33657 L
Mistroke
.90971 .33466 L
.90937 .3331 L
.90909 .33182 L
.90884 .33083 L
.90864 .33007 L
.90848 .32947 L
.90836 .32899 L
.90829 .32854 L
.90825 .32809 L
.90822 .32763 L
.90821 .32714 L
.9082 .32654 L
.90819 .32579 L
.90816 .32488 L
.90808 .32384 L
.90793 .32264 L
.90768 .32126 L
.90733 .31975 L
.90688 .31805 L
.90632 .31621 L
.90565 .31424 L
.90487 .31225 L
.90399 .31012 L
.90297 .30786 L
.90182 .30546 L
.90043 .30283 L
.89902 .3002 L
.89741 .2973 L
.89565 .29422 L
.89375 .29098 L
.89163 .28765 L
.88962 .28421 L
.88745 .28082 L
.88504 .27731 L
.88294 .27399 L
.88062 .27047 L
.87813 .26683 L
.87581 .26338 L
.87339 .25986 L
.87101 .25638 L
.86849 .25303 L
.86629 .24992 L
.86402 .24672 L
.86184 .24366 L
.85951 .24049 L
.85736 .23756 L
.85514 .2345 L
.85295 .23142 L
.8508 .22837 L
.84871 .22542 L
Mistroke
.8467 .22242 L
.84462 .21937 L
.84267 .21664 L
.84061 .21357 L
.83847 .21045 L
.83642 .20757 L
.83422 .20474 L
.83188 .20154 L
.82975 .19857 L
.82742 .19556 L
.82513 .19251 L
.82279 .18957 L
.82039 .1865 L
.81814 .18365 L
.81586 .18072 L
.81365 .17782 L
.81149 .17507 L
.80948 .17233 L
.80751 .16976 L
.80555 .1671 L
.80366 .16471 L
.80169 .16219 L
.79972 .15976 L
.79777 .15727 L
.79578 .15486 L
.79385 .15249 L
.79195 .15013 L
.79017 .14813 L
.78852 .14629 L
.787 .14459 L
.78567 .14305 L
.78459 .14184 L
.78373 .14085 L
.78313 .1401 L
.78279 .13959 L
.78268 .1393 L
.78275 .13919 L
.78295 .13921 L
.78324 .13932 L
.78358 .13945 L
.78391 .13957 L
.78421 .13968 L
.78447 .13977 L
.78467 .13984 L
.78483 .13988 L
.78496 .13992 L
.78505 .13996 L
.78511 .14 L
.78512 .14002 L
.78511 .14004 L
Mistroke
.78508 .14005 L
.78505 .14005 L
.78502 .14005 L
.78501 .14004 L
.78501 .14001 L
.785 .13995 L
.785 .13988 L
.785 .13982 L
.785 .13978 L
.785 .13977 L
.785 .1398 L
.78502 .13987 L
.78503 .14001 L
.78503 .1402 L
.78503 .14044 L
.78501 .14069 L
.78499 .14093 L
.78497 .14115 L
.78494 .14132 L
.78492 .14144 L
.7849 .1415 L
.78488 .14149 L
.78487 .14144 L
.78486 .14134 L
.78486 .14115 L
.78486 .14096 L
.78489 .14072 L
.78495 .14048 L
.78503 .14025 L
.78512 .14006 L
.78518 .13991 L
.7852 .13981 L
.78517 .13972 L
.7851 .13964 L
.78498 .13958 L
.78479 .13956 L
.78451 .13955 L
.78411 .13956 L
.78358 .13961 L
.78292 .13973 L
.78212 .13992 L
.78121 .1402 L
.78022 .14057 L
.77917 .14102 L
.77812 .14154 L
.77717 .14212 L
.77623 .14274 L
.77543 .14338 L
.77476 .144 L
.77422 .14454 L
Mistroke
.77381 .14496 L
.77354 .14521 L
.77341 .14527 L
.77338 .14513 L
.77343 .14478 L
.7735 .14422 L
.77353 .14349 L
.7734 .14255 L
.77305 .14137 L
.77246 .14009 L
.77161 .13859 L
.77054 .13694 L
.76922 .13525 L
.76764 .13339 L
.76591 .1317 L
.76406 .12997 L
.76205 .12828 L
.76001 .12674 L
.75752 .12511 L
.75539 .12379 L
.75322 .12251 L
.75084 .12125 L
.74828 .12003 L
.74552 .11884 L
.74241 .11761 L
.73956 .11633 L
.73628 .1151 L
.73284 .11372 L
.72919 .11221 L
.72534 .11077 L
.72125 .10913 L
.71657 .10735 L
.71253 .1055 L
.70763 .10346 L
.70333 .10172 L
.6996 .09996 L
.69515 .09813 L
.69123 .0965 L
.68712 .09485 L
.68341 .09348 L
.67955 .09197 L
.67612 .09071 L
.67254 .08948 L
.66967 .08828 L
.66683 .08716 L
.66404 .08614 L
.6619 .08522 L
.65999 .08445 L
.65838 .08385 L
.65716 .08336 L
Mistroke
.65623 .08296 L
.65558 .08263 L
.65518 .08236 L
.65501 .08216 L
.655 .08204 L
.6551 .08199 L
.65525 .08199 L
.6554 .08204 L
.65552 .08211 L
.6556 .08218 L
.65566 .08223 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.65569 .08225 L
.6557 .08225 L
.65574 .08226 L
.65583 .08228 L
.65595 .08233 L
.65607 .0824 L
.65613 .08246 L
.65611 .08248 L
.65598 .08246 L
.65572 .08237 L
.65532 .0822 L
.65476 .08195 L
Mistroke
.65406 .08163 L
.65321 .08124 L
.65223 .08082 L
.65124 .08038 L
.6501 .07993 L
.64899 .07949 L
.64785 .07906 L
.64673 .07865 L
.64572 .07829 L
.6449 .078 L
.64429 .0778 L
.64386 .07768 L
.64359 .07764 L
.64339 .07766 L
.64322 .07771 L
.64301 .07777 L
.64271 .07782 L
.64231 .07785 L
.64184 .07788 L
.64132 .07789 L
.64081 .07789 L
.64034 .07786 L
.63988 .0778 L
.63944 .07771 L
.63899 .07757 L
.63855 .07741 L
.63813 .07722 L
.63775 .07701 L
.63741 .07679 L
.63712 .07657 L
.63688 .07636 L
.63669 .07615 L
.63651 .07596 L
.63634 .07579 L
.63608 .07566 L
.63575 .07556 L
.63538 .07549 L
.63503 .07547 L
.63473 .07547 L
.63449 .07549 L
.63433 .07552 L
.63426 .07554 L
.63427 .07556 L
.63434 .07556 L
.63446 .07557 L
.63459 .07557 L
.63474 .07558 L
.6349 .07558 L
.63509 .07559 L
.6353 .07559 L
Mistroke
.63552 .0756 L
.63574 .07561 L
.63596 .07562 L
.63617 .07562 L
.63637 .07563 L
.63653 .07563 L
.63667 .07564 L
.63676 .07564 L
.63682 .07564 L
.63683 .07564 L
.63682 .07564 L
.63679 .07564 L
.63675 .07564 L
.63672 .07564 L
.63671 .07564 L
.63671 .07564 L
.63671 .07564 L
.63674 .07562 L
.63679 .07558 L
.63685 .07551 L
.63691 .07542 L
.63694 .07536 L
.63692 .07534 L
.63684 .07538 L
.6367 .07553 L
.63649 .07582 L
.63621 .07622 L
.63584 .07671 L
.63539 .07729 L
.63485 .07793 L
.63428 .07858 L
.63368 .07928 L
.63311 .07986 L
.6326 .08035 L
.63219 .08073 L
.6319 .08099 L
.63175 .08112 L
.63174 .08112 L
.63183 .08102 L
.63198 .08084 L
.63213 .0806 L
.63234 .08035 L
.63259 .08016 L
.63292 .08007 L
.63336 .08009 L
.63398 .08036 L
.63482 .0806 L
.63588 .08095 L
.63717 .08143 L
.63863 .08203 L
Mistroke
.64037 .08268 L
.64224 .08335 L
.64419 .08399 L
.64648 .08459 L
.64877 .08512 L
.65142 .08559 L
.65379 .08603 L
.65625 .08647 L
.65864 .08691 L
.66092 .08737 L
.66303 .08783 L
.665 .08831 L
.66682 .08881 L
.66854 .08933 L
.6701 .08988 L
.67152 .09045 L
.67283 .09098 L
.67399 .09147 L
.67496 .09192 L
.67574 .0923 L
.67632 .09261 L
.67672 .09285 L
.67697 .09301 L
.67709 .09311 L
.67712 .09313 L
.67707 .09311 L
.67698 .09304 L
.67688 .09296 L
.67678 .09287 L
.67668 .09278 L
.6766 .09272 L
.67654 .09269 L
.67653 .0927 L
.67657 .09279 L
.67668 .09297 L
.67685 .09326 L
.67707 .09362 L
.67733 .09401 L
.67762 .09439 L
.67791 .09473 L
.67822 .09501 L
.67854 .09524 L
.67888 .0954 L
.67918 .09551 L
.67943 .09554 L
.67959 .09547 L
.67965 .09527 L
.67959 .09495 L
.67942 .0945 L
.67911 .09394 L
Mistroke
.67865 .09333 L
.67799 .09268 L
.67711 .09202 L
.67598 .09133 L
.67457 .0906 L
.67294 .08983 L
.67098 .08896 L
.66864 .08798 L
.6663 .08693 L
.66339 .08573 L
.66041 .08439 L
.65722 .0831 L
.6533 .08147 L
.64998 .0801 L
.64613 .07867 L
.64215 .07709 L
.63772 .07538 L
.63365 .07388 L
.62937 .0724 L
.62459 .07064 L
.62057 .06922 L
.61573 .06777 L
.61158 .06624 L
.6065 .06476 L
.60254 .06324 L
.59804 .06176 L
.59401 .06061 L
.59 .05946 L
.5864 .0584 L
.58317 .05757 L
.58025 .05683 L
.57763 .05619 L
.57526 .05569 L
.57365 .05535 L
.57224 .05514 L
.57115 .05504 L
.57035 .05504 L
.56984 .05509 L
.56957 .05517 L
.56948 .05526 L
.56954 .05533 L
.56971 .05537 L
.56996 .05538 L
.57027 .05539 L
.57058 .0554 L
.57084 .05541 L
.57107 .05542 L
.5713 .05542 L
.57152 .05543 L
.57175 .05544 L
Mistroke
.57197 .05544 L
.57217 .05545 L
.57234 .05546 L
.57248 .05546 L
.57257 .05546 L
.57263 .05547 L
.57265 .05547 L
.57263 .05547 L
.5726 .05546 L
.57256 .05546 L
.57253 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
Mistroke
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57252 .05546 L
.57254 .05546 L
.5726 .05546 L
.57266 .05547 L
.57273 .05547 L
.57276 .05547 L
.57276 .05547 L
.5727 .05547 L
.57261 .05546 L
.57246 .05546 L
.57223 .05545 L
.57191 .05544 L
.57148 .05543 L
.57095 .05541 L
.57031 .05539 L
.56958 .05537 L
.56877 .05534 L
.56788 .05531 L
.56689 .05528 L
.56581 .05525 L
.56465 .05521 L
.56346 .05517 L
.56222 .05513 L
.56096 .05509 L
.55969 .05505 L
.55849 .05501 L
.55728 .05497 L
.55605 .05494 L
.55472 .0549 L
.55344 .05486 L
.55209 .05481 L
.55065 .05477 L
.54914 .05472 L
.54757 .05468 L
.54604 .05463 L
.54482 .05459 L
.54358 .05455 L
.54242 .05451 L
.54154 .05449 L
Mistroke
.5407 .05449 L
.53992 .0545 L
.53921 .05451 L
.53856 .05449 L
.53787 .05444 L
.53704 .05434 L
.53597 .05421 L
.53457 .05404 L
.53286 .05385 L
.53052 .05366 L
.52755 .05346 L
.52476 .05328 L
.52105 .0531 L
.51654 .05294 L
.51267 .05281 L
.50794 .05269 L
.5033 .0526 L
.4993 .05254 L
.49487 .05252 L
.49121 .05254 L
.48752 .05258 L
.4847 .05263 L
.48218 .05268 L
.4801 .0527 L
.47858 .0527 L
.47734 .05266 L
.47639 .05261 L
.47572 .05256 L
.4752 .05252 L
.47473 .05249 L
.47427 .05248 L
.4738 .05246 L
.4733 .05245 L
.47276 .05244 L
.47221 .05242 L
.47164 .0524 L
.47103 .05238 L
.47042 .05236 L
.46989 .05235 L
.46947 .05234 L
.46917 .05233 L
.46901 .05232 L
.46896 .05232 L
.469 .05232 L
.4691 .05232 L
.46922 .05233 L
.46932 .05233 L
.46941 .05233 L
.46949 .05234 L
.46957 .05234 L
Mistroke
.46966 .05234 L
.46975 .05234 L
.46981 .05235 L
.46979 .05235 L
.46966 .05234 L
.46939 .05234 L
.4689 .05232 L
.46815 .0523 L
.46712 .05227 L
.46584 .05224 L
.46431 .05219 L
.46253 .05214 L
.46054 .05208 L
.45868 .05202 L
.45662 .05196 L
.45473 .0519 L
.45288 .05185 L
.45115 .0518 L
.44977 .05175 L
.44865 .0517 L
.44779 .05163 L
.4472 .05154 L
.44682 .05147 L
.4466 .05144 L
.44648 .05146 L
.4464 .05155 L
.44627 .05171 L
.44609 .05195 L
.44585 .05226 L
.44553 .05262 L
.4451 .05301 L
.44459 .05343 L
.44403 .05383 L
.44345 .05423 L
.44286 .05463 L
.4423 .055 L
.44179 .05532 L
.44139 .05558 L
.44112 .05576 L
.44096 .05586 L
.44089 .05589 L
.44086 .05588 L
.44085 .05584 L
.4408 .05578 L
.44068 .05571 L
.44046 .05565 L
.44008 .05559 L
.43947 .05551 L
.43857 .05543 L
.43733 .05533 L
Mistroke
.43574 .05524 L
.43377 .05515 L
.43133 .05506 L
.42862 .05496 L
.4254 .05487 L
.42215 .05477 L
.41865 .05466 L
.41497 .05454 L
.41097 .05441 L
.4075 .05429 L
.40366 .05419 L
.40003 .05414 L
.3964 .05412 L
.39311 .05417 L
.38963 .05429 L
.38645 .0545 L
.3832 .05481 L
.38012 .05526 L
.37691 .05585 L
.37412 .05651 L
.37144 .05724 L
.36879 .05804 L
.36651 .05887 L
.36426 .05973 L
.36238 .06062 L
.36063 .06152 L
.35914 .06235 L
.35786 .06315 L
.35679 .0639 L
.35593 .0646 L
.35529 .06523 L
.35481 .0658 L
.35445 .06628 L
.35416 .06671 L
.35393 .06708 L
.35371 .06738 L
.3535 .06764 L
.35334 .06784 L
.35324 .06798 L
.35321 .06806 L
.35323 .06809 L
.35328 .06806 L
.35335 .068 L
.3534 .06793 L
.35343 .06788 L
.35345 .06786 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
Mistroke
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35345 .06785 L
.35348 .06785 L
.35354 .06786 L
.35362 .06786 L
.35374 .06784 L
.35389 .06779 L
.35403 .0677 L
.35412 .06757 L
.35412 .06744 L
.354 .06732 L
.35369 .06726 L
.35315 .06728 L
.35232 .06745 L
.35115 .06783 L
.34964 .06845 L
.3477 .06933 L
.34527 .07049 L
.34269 .0718 L
.33959 .07329 L
.3363 .07509 L
.33265 .07702 L
.32896 .0791 L
.32485 .08142 L
.3211 .08354 L
.31713 .08588 L
.31302 .08806 L
.30937 .09015 L
.30547 .09233 L
.30211 .09419 L
.29864 .09611 L
.29567 .09782 L
.29277 .09954 L
.29025 .10111 L
.28803 .10258 L
.28616 .10386 L
.28458 .10501 L
.28336 .10598 L
.28245 .10672 L
.28177 .10732 L
.28127 .10781 L
Mistroke
.28087 .10822 L
.28049 .10859 L
.28007 .10897 L
.2796 .10939 L
.27909 .10985 L
.27851 .11035 L
.27787 .11088 L
.27725 .11139 L
.27662 .11198 L
.27609 .11253 L
.27563 .11307 L
.27524 .11357 L
.27492 .11399 L
.27468 .11429 L
.27446 .11444 L
.27415 .1145 L
.27367 .11452 L
.27293 .11455 L
.27185 .11468 L
.27033 .11499 L
.26834 .11557 L
.2663 .11647 L
.26346 .11759 L
.26065 .11899 L
.2572 .12075 L
.25351 .12279 L
.24949 .12502 L
.24575 .12724 L
.24106 .12974 L
.23718 .13236 L
.2324 .13524 L
.22875 .13787 L
.22455 .14071 L
.22062 .14347 L
.21651 .14632 L
.21297 .14888 L
.20922 .15146 L
.20633 .15378 L
.20353 .15602 L
.20112 .15799 L
.1991 .15972 L
.19746 .16126 L
.19625 .16247 L
.19535 .16343 L
.19474 .16413 L
.19436 .16458 L
.19418 .16483 L
.19413 .16492 L
.19418 .1649 L
.19428 .16481 L
Mistroke
.1944 .16468 L
.19454 .16453 L
.19465 .16442 L
.19473 .16436 L
.19476 .16433 L
.19477 .16432 L
.19477 .16432 L
.19477 .16432 L
.19477 .16432 L
.19477 .16432 L
.1948 .16428 L
.19485 .16419 L
.19493 .16409 L
.195 .16398 L
.19504 .16389 L
.19501 .16387 L
.19491 .16397 L
.19471 .16422 L
.19443 .16464 L
.19406 .16523 L
.19363 .16598 L
.19315 .16688 L
.19265 .16787 L
.19215 .16886 L
.19166 .16991 L
.19118 .17097 L
.19073 .17202 L
.19034 .17295 L
.19002 .17378 L
.1898 .17446 L
.18969 .17495 L
.18969 .17523 L
.18979 .17529 L
.18997 .17517 L
.19016 .17495 L
.19033 .17471 L
.19044 .17452 L
.19046 .17444 L
.19037 .17452 L
.19013 .17482 L
.18972 .17538 L
.18908 .17626 L
.18817 .1775 L
.18696 .17913 L
.18559 .18093 L
.1839 .18326 L
.182 .18578 L
.17981 .18882 L
.17758 .19182 L
.17527 .19518 L
Mistroke
.17277 .19888 L
.17036 .20228 L
.16782 .20601 L
.16535 .21001 L
.16295 .21365 L
.16052 .21753 L
.15802 .22169 L
.15562 .22559 L
.15325 .22942 L
.15074 .23378 L
.14837 .23743 L
.14581 .24167 L
.14335 .24537 L
.1408 .24937 L
.13817 .25346 L
.13566 .25722 L
.13314 .26099 L
.13068 .26468 L
.12822 .26841 L
.12592 .27184 L
.12363 .27534 L
.12132 .27904 L
.11904 .28261 L
.11688 .28594 L
.11461 .28969 L
.11236 .29333 L
.11015 .29664 L
.10791 .3003 L
.10592 .3036 L
.10397 .30695 L
.10217 .31018 L
.10057 .31308 L
.09909 .31582 L
.09791 .31812 L
.09692 .3202 L
.09611 .32197 L
.09552 .32334 L
.09513 .32442 L
.09495 .32517 L
.09493 .32561 L
.09503 .3258 L
.09518 .32577 L
.09535 .32561 L
.09549 .32536 L
.09557 .32511 L
.09557 .32492 L
.09548 .32485 L
.09532 .32498 L
.09508 .32536 L
.09478 .32605 L
Mistroke
.09438 .32715 L
.09389 .32868 L
.0933 .33066 L
.09261 .33328 L
.09183 .33618 L
.091 .33979 L
.09014 .3441 L
.08926 .34836 L
.08842 .35354 L
.08762 .3582 L
.08689 .36354 L
.08625 .36915 L
.08569 .37464 L
.08521 .37919 L
.08483 .38405 L
.08453 .389 L
.08433 .39302 L
.08422 .39616 L
.08416 .39914 L
.08415 .40179 L
.08417 .40366 L
.0842 .40511 L
.08423 .40613 L
.08425 .40677 L
.08426 .40709 L
Mfstroke
1 .999 0 r
.008 w
.08412 .41062 Mdot
.016 w
.08412 .41062 m
.08422 .41078 L
s
.008 w
.08422 .41078 Mdot
.016 w
.08422 .41078 m
.08438 .41095 L
s
1 .998 0 r
.008 w
.08438 .41095 Mdot
.016 w
.08438 .41095 m
.08458 .41113 L
s
.008 w
.08458 .41113 Mdot
.016 w
.08458 .41113 m
.08483 .4113 L
s
1 .997 0 r
.008 w
.08483 .4113 Mdot
.016 w
.08483 .4113 m
.08513 .41144 L
s
1 .996 0 r
.008 w
.08513 .41144 Mdot
.016 w
.08513 .41144 m
.08548 .41156 L
s
.008 w
.08548 .41156 Mdot
.016 w
.08548 .41156 m
.08589 .41168 L
s
1 .995 0 r
.008 w
.08589 .41168 Mdot
.016 w
.08589 .41168 m
.08638 .4118 L
s
1 .994 0 r
.008 w
.08638 .4118 Mdot
.016 w
.08638 .4118 m
.08698 .41194 L
s
.008 w
.08698 .41194 Mdot
.016 w
.08698 .41194 m
.08769 .41213 L
s
1 .993 0 r
.008 w
.08769 .41213 Mdot
.016 w
.08769 .41213 m
.08848 .41238 L
s
.008 w
.08848 .41238 Mdot
.016 w
.08848 .41238 m
.08934 .4127 L
s
1 .992 0 r
.008 w
.08934 .4127 Mdot
.016 w
.08934 .4127 m
.09027 .41312 L
s
1 .991 0 r
.008 w
.09027 .41312 Mdot
.016 w
.09027 .41312 m
.09123 .41367 L
s
.008 w
.09123 .41367 Mdot
.016 w
.09123 .41367 m
.09212 .41437 L
s
1 .99 0 r
.008 w
.09212 .41437 Mdot
.016 w
.09212 .41437 m
.09304 .41522 L
s
.008 w
.09304 .41522 Mdot
.016 w
.09304 .41522 m
.0939 .41618 L
s
1 .989 0 r
.008 w
.0939 .41618 Mdot
.016 w
.0939 .41618 m
.09478 .41734 L
s
1 .988 0 r
.008 w
.09478 .41734 Mdot
.016 w
.09478 .41734 m
.09551 .41871 L
s
.008 w
.09551 .41871 Mdot
.016 w
.09551 .41871 m
.09616 .42024 L
s
1 .987 0 r
.008 w
.09616 .42024 Mdot
.016 w
.09616 .42024 m
.09669 .42198 L
s
1 .986 0 r
.008 w
.09669 .42198 Mdot
.016 w
.09669 .42198 m
.09709 .42393 L
s
.008 w
.09709 .42393 Mdot
.016 w
.09709 .42393 m
.09732 .42615 L
s
1 .985 0 r
.008 w
.09732 .42615 Mdot
.016 w
.09732 .42615 m
.09738 .42856 L
s
.008 w
.09738 .42856 Mdot
.016 w
.09738 .42856 m
.09727 .43122 L
s
1 .984 0 r
.008 w
.09727 .43122 Mdot
.016 w
.09727 .43122 m
.09701 .43407 L
s
1 .983 0 r
.008 w
.09701 .43407 Mdot
.016 w
.09701 .43407 m
.09659 .43718 L
s
.008 w
.09659 .43718 Mdot
.016 w
.09659 .43718 m
.09603 .44009 L
s
1 .982 0 r
.008 w
.09603 .44009 Mdot
.016 w
.09603 .44009 m
.09532 .44324 L
s
1 .981 0 r
.008 w
.09532 .44324 Mdot
.016 w
.09532 .44324 m
.09445 .44662 L
s
.008 w
.09445 .44662 Mdot
.016 w
.09445 .44662 m
.09335 .44987 L
s
1 .98 0 r
.008 w
.09335 .44987 Mdot
.016 w
.09335 .44987 m
.092 .45328 L
s
.008 w
.092 .45328 Mdot
.016 w
.092 .45328 m
.09051 .45688 L
s
1 .979 0 r
.008 w
.09051 .45688 Mdot
.016 w
.09051 .45688 m
.08874 .46045 L
s
1 .978 0 r
.008 w
.08874 .46045 Mdot
.016 w
.08874 .46045 m
.08675 .4638 L
s
.008 w
.08675 .4638 Mdot
.016 w
.08675 .4638 m
.08434 .46741 L
s
1 .977 0 r
.008 w
.08434 .46741 Mdot
.016 w
.08434 .46741 m
.08251 .47101 L
s
.008 w
.08251 .47101 Mdot
.016 w
.08251 .47101 m
.08008 .4749 L
s
1 .976 0 r
.008 w
.08008 .4749 Mdot
.016 w
.08008 .4749 m
.07828 .47848 L
s
1 .975 0 r
.008 w
.07828 .47848 Mdot
.016 w
.07828 .47848 m
.07594 .48232 L
s
.008 w
.07594 .48232 Mdot
.016 w
.07594 .48232 m
.07407 .48632 L
s
1 .974 0 r
.008 w
.07407 .48632 Mdot
.016 w
.07407 .48632 m
.07243 .49043 L
s
1 .973 0 r
.008 w
.07243 .49043 Mdot
.016 w
.07243 .49043 m
.07099 .49445 L
s
.008 w
.07099 .49445 Mdot
.016 w
.07099 .49445 m
.06969 .49858 L
s
1 .972 0 r
.008 w
.06969 .49858 Mdot
.016 w
.06969 .49858 m
.06866 .50208 L
s
.008 w
.06866 .50208 Mdot
.016 w
.06866 .50208 m
.06793 .50554 L
s
1 .971 0 r
.008 w
.06793 .50554 Mdot
.016 w
.06793 .50554 m
.06748 .50854 L
s
1 .97 0 r
.008 w
.06748 .50854 Mdot
.016 w
.06748 .50854 m
.06726 .51115 L
s
.008 w
.06726 .51115 Mdot
.016 w
.06726 .51115 m
.06721 .51324 L
s
1 .969 0 r
.008 w
.06721 .51324 Mdot
.016 w
.06721 .51324 m
.06725 .51482 L
s
.008 w
.06725 .51482 Mdot
.016 w
.06725 .51482 m
.06733 .51597 L
s
1 .968 0 r
.008 w
.06733 .51597 Mdot
.016 w
.06733 .51597 m
.06743 .51674 L
s
1 .967 0 r
.008 w
.06743 .51674 Mdot
.016 w
.06743 .51674 m
.06745 .51724 L
s
.008 w
.06745 .51724 Mdot
.016 w
.06745 .51724 m
.0674 .51755 L
s
1 .966 0 r
.008 w
.0674 .51755 Mdot
.016 w
.0674 .51755 m
.06735 .51777 L
s
1 .965 0 r
.008 w
.06735 .51777 Mdot
.016 w
.06735 .51777 m
.06735 .51808 L
s
.008 w
.06735 .51808 Mdot
.016 w
.06735 .51808 m
.06741 .5186 L
s
1 .964 0 r
.008 w
.06741 .5186 Mdot
.016 w
.06741 .5186 m
.06753 .51942 L
s
.008 w
.06753 .51942 Mdot
.016 w
.06753 .51942 m
.0677 .5206 L
s
1 .963 0 r
.008 w
.0677 .5206 Mdot
.016 w
.0677 .5206 m
.06794 .52227 L
s
1 .962 0 r
.008 w
.06794 .52227 Mdot
.016 w
.06794 .52227 m
.06824 .52459 L
s
.008 w
.06824 .52459 Mdot
.016 w
.06824 .52459 m
.06863 .5274 L
s
1 .961 0 r
.008 w
.06863 .5274 Mdot
.016 w
.06863 .5274 m
.0691 .53086 L
s
.008 w
.0691 .53086 Mdot
.016 w
.0691 .53086 m
.06967 .53475 L
s
1 .96 0 r
.008 w
.06967 .53475 Mdot
.016 w
.06967 .53475 m
.07035 .53906 L
s
1 .959 0 r
.008 w
.07035 .53906 Mdot
.016 w
.07035 .53906 m
.07106 .54398 L
s
.008 w
.07106 .54398 Mdot
.016 w
.07106 .54398 m
.07183 .54856 L
s
1 .958 0 r
.008 w
.07183 .54856 Mdot
.016 w
.07183 .54856 m
.0726 .55408 L
s
1 .957 0 r
.008 w
.0726 .55408 Mdot
.016 w
.0726 .55408 m
.07331 .55892 L
s
.008 w
.07331 .55892 Mdot
.016 w
.07331 .55892 m
.07401 .56434 L
s
1 .956 0 r
.008 w
.07401 .56434 Mdot
.016 w
.07401 .56434 m
.0747 .57017 L
s
.008 w
.0747 .57017 Mdot
.016 w
.0747 .57017 m
.07537 .57512 L
s
1 .955 0 r
.008 w
.07537 .57512 Mdot
.016 w
.07537 .57512 m
.07608 .58116 L
s
1 .954 0 r
.008 w
.07608 .58116 Mdot
.016 w
.07608 .58116 m
.07679 .58609 L
s
.008 w
.07679 .58609 Mdot
.016 w
.07679 .58609 m
.07753 .59181 L
s
1 .953 0 r
.008 w
.07753 .59181 Mdot
.016 w
.07753 .59181 m
.07834 .59696 L
s
1 .952 0 r
.008 w
.07834 .59696 Mdot
.016 w
.07834 .59696 m
.0792 .60205 L
s
.008 w
.0792 .60205 Mdot
.016 w
.0792 .60205 m
.0801 .60727 L
s
1 .951 0 r
.008 w
.0801 .60727 Mdot
.016 w
.0801 .60727 m
.08099 .61224 L
s
.008 w
.08099 .61224 Mdot
.016 w
.08099 .61224 m
.08159 .61715 L
s
1 .95 0 r
.008 w
.08159 .61715 Mdot
.016 w
.08159 .61715 m
.08248 .62263 L
s
1 .949 0 r
.008 w
.08248 .62263 Mdot
.016 w
.08248 .62263 m
.08334 .62707 L
s
.008 w
.08334 .62707 Mdot
.016 w
.08334 .62707 m
.08422 .63203 L
s
1 .948 0 r
.008 w
.08422 .63203 Mdot
.016 w
.08422 .63203 m
.0851 .63675 L
s
.008 w
.0851 .63675 Mdot
.016 w
.0851 .63675 m
.08591 .64101 L
s
1 .947 0 r
.008 w
.08591 .64101 Mdot
.016 w
.08591 .64101 m
.08662 .64537 L
s
1 .946 0 r
.008 w
.08662 .64537 Mdot
.016 w
.08662 .64537 m
.08718 .64881 L
s
.008 w
.08718 .64881 Mdot
.016 w
.08718 .64881 m
.08759 .65206 L
s
1 .945 0 r
.008 w
.08759 .65206 Mdot
.016 w
.08759 .65206 m
.08789 .65519 L
s
1 .944 0 r
.008 w
.08789 .65519 Mdot
.016 w
.08789 .65519 m
.08808 .65752 L
s
.008 w
.08808 .65752 Mdot
.016 w
.08808 .65752 m
.0882 .65962 L
s
1 .943 0 r
.008 w
.0882 .65962 Mdot
.016 w
.0882 .65962 m
.0883 .66149 L
s
.008 w
.0883 .66149 Mdot
.016 w
.0883 .66149 m
.08841 .66304 L
s
1 .942 0 r
.008 w
.08841 .66304 Mdot
.016 w
.08841 .66304 m
.08857 .66432 L
s
1 .941 0 r
.008 w
.08857 .66432 Mdot
.016 w
.08857 .66432 m
.08877 .66537 L
s
.008 w
.08877 .66537 Mdot
.016 w
.08877 .66537 m
.08903 .66631 L
s
1 .94 0 r
.008 w
.08903 .66631 Mdot
.016 w
.08903 .66631 m
.08933 .66723 L
s
.008 w
.08933 .66723 Mdot
.016 w
.08933 .66723 m
.08969 .66817 L
s
1 .939 0 r
.008 w
.08969 .66817 Mdot
.016 w
.08969 .66817 m
.09008 .66924 L
s
1 .938 0 r
.008 w
.09008 .66924 Mdot
.016 w
.09008 .66924 m
.09051 .67049 L
s
.008 w
.09051 .67049 Mdot
.016 w
.09051 .67049 m
.09097 .67197 L
s
1 .937 0 r
.008 w
.09097 .67197 Mdot
.016 w
.09097 .67197 m
.09144 .67359 L
s
1 .936 0 r
.008 w
.09144 .67359 Mdot
.016 w
.09144 .67359 m
.09187 .67535 L
s
.008 w
.09187 .67535 Mdot
.016 w
.09187 .67535 m
.09226 .67712 L
s
1 .935 0 r
.008 w
.09226 .67712 Mdot
.016 w
.09226 .67712 m
.09259 .67884 L
s
.008 w
.09259 .67884 Mdot
.016 w
.09259 .67884 m
.09286 .68041 L
s
1 .934 0 r
.008 w
.09286 .68041 Mdot
.016 w
.09286 .68041 m
.09306 .68175 L
s
1 .933 0 r
.008 w
.09306 .68175 Mdot
.016 w
.09306 .68175 m
.09318 .68294 L
s
.008 w
.09318 .68294 Mdot
.016 w
.09318 .68294 m
.09324 .68392 L
s
1 .932 0 r
.008 w
.09324 .68392 Mdot
.016 w
.09324 .68392 m
.09324 .6847 L
s
.008 w
.09324 .6847 Mdot
.016 w
.09324 .6847 m
.09321 .68525 L
s
1 .931 0 r
.008 w
.09321 .68525 Mdot
.016 w
.09321 .68525 m
.09316 .68558 L
s
1 .93 0 r
.008 w
.09316 .68558 Mdot
.016 w
.09316 .68558 m
.09309 .6857 L
s
.008 w
.09309 .6857 Mdot
.016 w
.09309 .6857 m
.093 .68565 L
s
1 .929 0 r
.008 w
.093 .68565 Mdot
.016 w
.093 .68565 m
.09293 .68546 L
s
1 .928 0 r
.008 w
.09293 .68546 Mdot
.016 w
.09293 .68546 m
.09288 .68516 L
s
.008 w
.09288 .68516 Mdot
.016 w
.09288 .68516 m
.09287 .68481 L
s
1 .927 0 r
.008 w
.09287 .68481 Mdot
.016 w
.09287 .68481 m
.09289 .68451 L
s
.008 w
.09289 .68451 Mdot
.016 w
.09289 .68451 m
.09295 .68436 L
s
1 .926 0 r
.008 w
.09295 .68436 Mdot
.016 w
.09295 .68436 m
.09305 .68442 L
s
1 .925 0 r
.008 w
.09305 .68442 Mdot
.016 w
.09305 .68442 m
.09321 .68473 L
s
.008 w
.09321 .68473 Mdot
.016 w
.09321 .68473 m
.09344 .68533 L
s
1 .924 0 r
.008 w
.09344 .68533 Mdot
.016 w
.09344 .68533 m
.09375 .68626 L
s
.008 w
.09375 .68626 Mdot
.016 w
.09375 .68626 m
.09413 .68755 L
s
1 .923 0 r
.008 w
.09413 .68755 Mdot
.016 w
.09413 .68755 m
.09458 .68916 L
s
1 .922 0 r
.008 w
.09458 .68916 Mdot
.016 w
.09458 .68916 m
.0951 .69117 L
s
.008 w
.0951 .69117 Mdot
.016 w
.0951 .69117 m
.09571 .69353 L
s
1 .921 0 r
.008 w
.09571 .69353 Mdot
.016 w
.09571 .69353 m
.09638 .69579 L
s
1 .92 0 r
.008 w
.09638 .69579 Mdot
.016 w
.09638 .69579 m
.09708 .69871 L
s
.008 w
.09708 .69871 Mdot
.016 w
.09708 .69871 m
.09782 .70141 L
s
1 .919 0 r
.008 w
.09782 .70141 Mdot
.016 w
.09782 .70141 m
.09856 .70435 L
s
.008 w
.09856 .70435 Mdot
.016 w
.09856 .70435 m
.09928 .7074 L
s
1 .918 0 r
.008 w
.09928 .7074 Mdot
.016 w
.09928 .7074 m
.09995 .71018 L
s
1 .917 0 r
.008 w
.09995 .71018 Mdot
.016 w
.09995 .71018 m
.10056 .71283 L
s
.008 w
.10056 .71283 Mdot
.016 w
.10056 .71283 m
.10111 .71508 L
s
1 .916 0 r
.008 w
.10111 .71508 Mdot
.016 w
.10111 .71508 m
.10158 .71703 L
s
1 .915 0 r
.008 w
.10158 .71703 Mdot
.016 w
.10158 .71703 m
.10197 .71858 L
s
.008 w
.10197 .71858 Mdot
.016 w
.10197 .71858 m
.10229 .71986 L
s
1 .914 0 r
.008 w
.10229 .71986 Mdot
.016 w
.10229 .71986 m
.10254 .72088 L
s
.008 w
.10254 .72088 Mdot
.016 w
.10254 .72088 m
.10272 .72167 L
s
1 .913 0 r
.008 w
.10272 .72167 Mdot
.016 w
.10272 .72167 m
.10282 .72228 L
s
1 .912 0 r
.008 w
.10282 .72228 Mdot
.016 w
.10282 .72228 m
.10287 .72274 L
s
.008 w
.10287 .72274 Mdot
.016 w
.10287 .72274 m
.10289 .72306 L
s
1 .911 0 r
.008 w
.10289 .72306 Mdot
.016 w
.10289 .72306 m
.10287 .72331 L
s
.008 w
.10287 .72331 Mdot
.016 w
.10287 .72331 m
.10283 .72352 L
s
1 .91 0 r
.008 w
.10283 .72352 Mdot
.016 w
.10283 .72352 m
.10278 .72374 L
s
1 .909 0 r
.008 w
.10278 .72374 Mdot
.016 w
.10278 .72374 m
.10274 .72399 L
s
.008 w
.10274 .72399 Mdot
.016 w
.10274 .72399 m
.1027 .72431 L
s
1 .908 0 r
.008 w
.1027 .72431 Mdot
.016 w
.1027 .72431 m
.10267 .72471 L
s
1 .907 0 r
.008 w
.10267 .72471 Mdot
.016 w
.10267 .72471 m
.10266 .72516 L
s
.008 w
.10266 .72516 Mdot
.016 w
.10266 .72516 m
.10265 .72557 L
s
1 .906 0 r
.008 w
.10265 .72557 Mdot
.016 w
.10265 .72557 m
.10265 .72591 L
s
.008 w
.10265 .72591 Mdot
.016 w
.10265 .72591 m
.10264 .72621 L
s
1 .905 0 r
.008 w
.10264 .72621 Mdot
.016 w
.10264 .72621 m
.10264 .72643 L
s
1 .904 0 r
.008 w
.10264 .72643 Mdot
.016 w
.10264 .72643 m
.10264 .72659 L
s
.008 w
.10264 .72659 Mdot
.016 w
.10264 .72659 m
.10263 .7267 L
s
1 .903 0 r
.008 w
.10263 .7267 Mdot
.016 w
.10263 .7267 m
.10263 .72676 L
s
.008 w
.10263 .72676 Mdot
.016 w
.10263 .72676 m
.10263 .72677 L
s
1 .902 0 r
.008 w
.10263 .72677 Mdot
.016 w
.10263 .72677 m
.10264 .72673 L
s
1 .901 0 r
.008 w
.10264 .72673 Mdot
.016 w
.10264 .72673 m
.10264 .72665 L
s
.008 w
.10264 .72665 Mdot
.016 w
.10264 .72665 m
.10264 .72655 L
s
1 .9 0 r
.008 w
.10264 .72655 Mdot
.016 w
.10264 .72655 m
.10264 .72642 L
s
1 .899 0 r
.008 w
.10264 .72642 Mdot
.016 w
.10264 .72642 m
.10264 .72625 L
s
.008 w
.10264 .72625 Mdot
.016 w
.10264 .72625 m
.10265 .72606 L
s
1 .898 0 r
.008 w
.10265 .72606 Mdot
.016 w
.10265 .72606 m
.10265 .72587 L
s
.008 w
.10265 .72587 Mdot
.016 w
.10265 .72587 m
.10265 .72567 L
s
1 .897 0 r
.008 w
.10265 .72567 Mdot
.016 w
.10265 .72567 m
.10264 .72546 L
s
1 .896 0 r
.008 w
.10264 .72546 Mdot
.016 w
.10264 .72546 m
.10261 .72525 L
s
.008 w
.10261 .72525 Mdot
.016 w
.10261 .72525 m
.10257 .72506 L
s
1 .895 0 r
.008 w
.10257 .72506 Mdot
.016 w
.10257 .72506 m
.10251 .72488 L
s
.008 w
.10251 .72488 Mdot
.016 w
.10251 .72488 m
.10245 .72473 L
s
1 .894 0 r
.008 w
.10245 .72473 Mdot
.016 w
.10245 .72473 m
.10239 .72461 L
s
1 .893 0 r
.008 w
.10239 .72461 Mdot
.016 w
.10239 .72461 m
.10237 .72451 L
s
.008 w
.10237 .72451 Mdot
.016 w
.10237 .72451 m
.10239 .72449 L
s
1 .892 0 r
.008 w
.10239 .72449 Mdot
.016 w
.10239 .72449 m
.10247 .72455 L
s
1 .891 0 r
.008 w
.10247 .72455 Mdot
.016 w
.10247 .72455 m
.10262 .72474 L
s
.008 w
.10262 .72474 Mdot
.016 w
.10262 .72474 m
.10287 .72503 L
s
1 .89 0 r
.008 w
.10287 .72503 Mdot
.016 w
.10287 .72503 m
.10321 .72544 L
s
.008 w
.10321 .72544 Mdot
.016 w
.10321 .72544 m
.10368 .72595 L
s
1 .889 0 r
.008 w
.10368 .72595 Mdot
.016 w
.10368 .72595 m
.1043 .72657 L
s
1 .888 0 r
.008 w
.1043 .72657 Mdot
.016 w
.1043 .72657 m
.10509 .72731 L
s
.008 w
.10509 .72731 Mdot
.016 w
.10509 .72731 m
.10608 .72821 L
s
1 .887 0 r
.008 w
.10608 .72821 Mdot
.016 w
.10608 .72821 m
.10724 .72926 L
s
1 .886 0 r
.008 w
.10724 .72926 Mdot
.016 w
.10724 .72926 m
.10864 .73051 L
s
.008 w
.10864 .73051 Mdot
.016 w
.10864 .73051 m
.11017 .73185 L
s
1 .885 0 r
.008 w
.11017 .73185 Mdot
.016 w
.11017 .73185 m
.11198 .73339 L
s
.008 w
.11198 .73339 Mdot
.016 w
.11198 .73339 m
.11392 .73521 L
s
1 .884 0 r
.008 w
.11392 .73521 Mdot
.016 w
.11392 .73521 m
.11612 .73727 L
s
1 .883 0 r
.008 w
.11612 .73727 Mdot
.016 w
.11612 .73727 m
.11846 .73967 L
s
.008 w
.11846 .73967 Mdot
.016 w
.11846 .73967 m
.12125 .74234 L
s
1 .882 0 r
.008 w
.12125 .74234 Mdot
.016 w
.12125 .74234 m
.12417 .74527 L
s
.008 w
.12417 .74527 Mdot
.016 w
.12417 .74527 m
.12691 .74843 L
s
1 .881 0 r
.008 w
.12691 .74843 Mdot
.016 w
.12691 .74843 m
.12995 .75181 L
s
1 .88 0 r
.008 w
.12995 .75181 Mdot
.016 w
.12995 .75181 m
.13309 .75519 L
s
.008 w
.13309 .75519 Mdot
.016 w
.13309 .75519 m
.13626 .75879 L
s
1 .879 0 r
.008 w
.13626 .75879 Mdot
.016 w
.13626 .75879 m
.1395 .76253 L
s
1 .878 0 r
.008 w
.1395 .76253 Mdot
.016 w
.1395 .76253 m
.14289 .76611 L
s
.008 w
.14289 .76611 Mdot
.016 w
.14289 .76611 m
.14633 .76992 L
s
1 .877 0 r
.008 w
.14633 .76992 Mdot
.016 w
.14633 .76992 m
.14996 .77373 L
s
.008 w
.14996 .77373 Mdot
.016 w
.14996 .77373 m
.1533 .77734 L
s
1 .876 0 r
.008 w
.1533 .77734 Mdot
.016 w
.1533 .77734 m
.15706 .78101 L
s
1 .875 0 r
.008 w
.15706 .78101 Mdot
.016 w
.15706 .78101 m
.16064 .78472 L
s
.008 w
.16064 .78472 Mdot
.016 w
.16064 .78472 m
.16442 .78854 L
s
1 .874 0 r
.008 w
.16442 .78854 Mdot
.016 w
.16442 .78854 m
.16821 .79194 L
s
.008 w
.16821 .79194 Mdot
.016 w
.16821 .79194 m
.17204 .79562 L
s
1 .873 0 r
.008 w
.17204 .79562 Mdot
.016 w
.17204 .79562 m
.17613 .79927 L
s
1 .872 0 r
.008 w
.17613 .79927 Mdot
.016 w
.17613 .79927 m
.18001 .8031 L
s
.008 w
.18001 .8031 Mdot
.016 w
.18001 .8031 m
.18408 .80683 L
s
1 .871 0 r
.008 w
.18408 .80683 Mdot
.016 w
.18408 .80683 m
.18814 .81063 L
s
1 .87 0 r
.008 w
.18814 .81063 Mdot
.016 w
.18814 .81063 m
.19236 .81452 L
s
.008 w
.19236 .81452 Mdot
.016 w
.19236 .81452 m
.19642 .81828 L
s
1 .869 0 r
.008 w
.19642 .81828 Mdot
.016 w
.19642 .81828 m
.20051 .82198 L
s
.008 w
.20051 .82198 Mdot
.016 w
.20051 .82198 m
.20478 .82571 L
s
1 .868 0 r
.008 w
.20478 .82571 Mdot
.016 w
.20478 .82571 m
.2088 .8294 L
s
1 .867 0 r
.008 w
.2088 .8294 Mdot
.016 w
.2088 .8294 m
.21297 .83284 L
s
.008 w
.21297 .83284 Mdot
.016 w
.21297 .83284 m
.21701 .83639 L
s
1 .866 0 r
.008 w
.21701 .83639 Mdot
.016 w
.21701 .83639 m
.22109 .84005 L
s
.008 w
.22109 .84005 Mdot
.016 w
.22109 .84005 m
.22497 .84326 L
s
1 .865 0 r
.008 w
.22497 .84326 Mdot
.016 w
.22497 .84326 m
.22888 .84671 L
s
1 .864 0 r
.008 w
.22888 .84671 Mdot
.016 w
.22888 .84671 m
.23236 .84969 L
s
.008 w
.23236 .84969 Mdot
.016 w
.23236 .84969 m
.2357 .85248 L
s
1 .863 0 r
.008 w
.2357 .85248 Mdot
.016 w
.2357 .85248 m
.23855 .85504 L
s
1 .862 0 r
.008 w
.23855 .85504 Mdot
.016 w
.23855 .85504 m
.24118 .85731 L
s
.008 w
.24118 .85731 Mdot
.016 w
.24118 .85731 m
.24338 .85933 L
s
1 .861 0 r
.008 w
.24338 .85933 Mdot
.016 w
.24338 .85933 m
.24512 .86112 L
s
.008 w
.24512 .86112 Mdot
.016 w
.24512 .86112 m
.24647 .86242 L
s
1 .86 0 r
.008 w
.24647 .86242 Mdot
.016 w
.24647 .86242 m
.24739 .86344 L
s
1 .859 0 r
.008 w
.24739 .86344 Mdot
.016 w
.24739 .86344 m
.24791 .86416 L
s
.008 w
.24791 .86416 Mdot
.016 w
.24791 .86416 m
.2481 .86458 L
s
1 .858 0 r
.008 w
.2481 .86458 Mdot
.016 w
.2481 .86458 m
.24802 .86473 L
s
1 .857 0 r
.008 w
.24802 .86473 Mdot
.016 w
.24802 .86473 m
.24775 .8646 L
s
.008 w
.24775 .8646 Mdot
.016 w
.24775 .8646 m
.24735 .86433 L
s
1 .856 0 r
.008 w
.24735 .86433 Mdot
.016 w
.24735 .86433 m
.24696 .86402 L
s
.008 w
.24696 .86402 Mdot
.016 w
.24696 .86402 m
.24668 .86376 L
s
1 .855 0 r
.008 w
.24668 .86376 Mdot
.016 w
.24668 .86376 m
.24659 .86361 L
s
1 .854 0 r
.008 w
.24659 .86361 Mdot
.016 w
.24659 .86361 m
.24677 .86365 L
s
.008 w
.24677 .86365 Mdot
.016 w
.24677 .86365 m
.24725 .86391 L
s
1 .853 0 r
.008 w
.24725 .86391 Mdot
.016 w
.24725 .86391 m
.24804 .86436 L
s
.008 w
.24804 .86436 Mdot
.016 w
.24804 .86436 m
.24914 .86506 L
s
1 .852 0 r
.008 w
.24914 .86506 Mdot
.016 w
.24914 .86506 m
.25057 .86591 L
s
1 .851 0 r
.008 w
.25057 .86591 Mdot
.016 w
.25057 .86591 m
.25232 .86691 L
s
.008 w
.25232 .86691 Mdot
.016 w
.25232 .86691 m
.25419 .86799 L
s
1 .85 0 r
.008 w
.25419 .86799 Mdot
.016 w
.25419 .86799 m
.25649 .8692 L
s
1 .849 0 r
.008 w
.25649 .8692 Mdot
.016 w
.25649 .8692 m
.25898 .87058 L
s
.008 w
.25898 .87058 Mdot
.016 w
.25898 .87058 m
.26162 .87196 L
s
1 .848 0 r
.008 w
.26162 .87196 Mdot
.016 w
.26162 .87196 m
.26462 .87349 L
s
.008 w
.26462 .87349 Mdot
.016 w
.26462 .87349 m
.26775 .87505 L
s
1 .847 0 r
.008 w
.26775 .87505 Mdot
.016 w
.26775 .87505 m
.27116 .87667 L
s
1 .846 0 r
.008 w
.27116 .87667 Mdot
.016 w
.27116 .87667 m
.27464 .87831 L
s
.008 w
.27464 .87831 Mdot
.016 w
.27464 .87831 m
.27862 .87982 L
s
1 .845 0 r
.008 w
.27862 .87982 Mdot
.016 w
.27862 .87982 m
.28251 .88144 L
s
.008 w
.28251 .88144 Mdot
.016 w
.28251 .88144 m
.28619 .88303 L
s
1 .844 0 r
.008 w
.28619 .88303 Mdot
.016 w
.28619 .88303 m
.2903 .88464 L
s
1 .843 0 r
.008 w
.2903 .88464 Mdot
.016 w
.2903 .88464 m
.29485 .88629 L
s
.008 w
.29485 .88629 Mdot
.016 w
.29485 .88629 m
.29884 .88793 L
s
1 .842 0 r
.008 w
.29884 .88793 Mdot
.016 w
.29884 .88793 m
.3036 .88956 L
s
1 .841 0 r
.008 w
.3036 .88956 Mdot
.016 w
.3036 .88956 m
.30788 .8912 L
s
.008 w
.30788 .8912 Mdot
.016 w
.30788 .8912 m
.31246 .89275 L
s
1 .84 0 r
.008 w
.31246 .89275 Mdot
.016 w
.31246 .89275 m
.31702 .89429 L
s
.008 w
.31702 .89429 Mdot
.016 w
.31702 .89429 m
.32145 .89581 L
s
1 .839 0 r
.008 w
.32145 .89581 Mdot
.016 w
.32145 .89581 m
.32583 .89729 L
s
1 .838 0 r
.008 w
.32583 .89729 Mdot
.016 w
.32583 .89729 m
.33026 .89875 L
s
.008 w
.33026 .89875 Mdot
.016 w
.33026 .89875 m
.33471 .90024 L
s
1 .837 0 r
.008 w
.33471 .90024 Mdot
.016 w
.33471 .90024 m
.33901 .90166 L
s
.008 w
.33901 .90166 Mdot
.016 w
.33901 .90166 m
.34341 .90312 L
s
1 .836 0 r
.008 w
.34341 .90312 Mdot
.016 w
.34341 .90312 m
.34799 .90456 L
s
1 .835 0 r
.008 w
.34799 .90456 Mdot
.016 w
.34799 .90456 m
.35218 .90605 L
s
.008 w
.35218 .90605 Mdot
.016 w
.35218 .90605 m
.35669 .90744 L
s
1 .834 0 r
.008 w
.35669 .90744 Mdot
.016 w
.35669 .90744 m
.3612 .90899 L
s
1 .833 0 r
.008 w
.3612 .90899 Mdot
.016 w
.3612 .90899 m
.36562 .91038 L
s
.008 w
.36562 .91038 Mdot
.016 w
.36562 .91038 m
.37015 .9118 L
s
1 .832 0 r
.008 w
.37015 .9118 Mdot
.016 w
.37015 .9118 m
.37472 .91324 L
s
.008 w
.37472 .91324 Mdot
.016 w
.37472 .91324 m
.37928 .91472 L
s
1 .831 0 r
.008 w
.37928 .91472 Mdot
.016 w
.37928 .91472 m
.38383 .91622 L
s
1 .83 0 r
.008 w
.38383 .91622 Mdot
.016 w
.38383 .91622 m
.38824 .91763 L
s
.008 w
.38824 .91763 Mdot
.016 w
.38824 .91763 m
.39271 .91891 L
s
1 .829 0 r
.008 w
.39271 .91891 Mdot
.016 w
.39271 .91891 m
.39712 .92023 L
s
.008 w
.39712 .92023 Mdot
.016 w
.39712 .92023 m
.40157 .92158 L
s
1 .828 0 r
.008 w
.40157 .92158 Mdot
.016 w
.40157 .92158 m
.406 .92287 L
s
1 .827 0 r
.008 w
.406 .92287 Mdot
.016 w
.406 .92287 m
.41005 .92415 L
s
.008 w
.41005 .92415 Mdot
.016 w
.41005 .92415 m
.41409 .9254 L
s
1 .826 0 r
.008 w
.41409 .9254 Mdot
.016 w
.41409 .9254 m
.41824 .92668 L
s
1 .825 0 r
.008 w
.41824 .92668 Mdot
.016 w
.41824 .92668 m
.42224 .92794 L
s
.008 w
.42224 .92794 Mdot
.016 w
.42224 .92794 m
.42609 .92914 L
s
1 .824 0 r
.008 w
.42609 .92914 Mdot
.016 w
.42609 .92914 m
.43003 .93032 L
s
.008 w
.43003 .93032 Mdot
.016 w
.43003 .93032 m
.43382 .93144 L
s
1 .823 0 r
.008 w
.43382 .93144 Mdot
.016 w
.43382 .93144 m
.43765 .93255 L
s
1 .822 0 r
.008 w
.43765 .93255 Mdot
.016 w
.43765 .93255 m
.44139 .93352 L
s
.008 w
.44139 .93352 Mdot
.016 w
.44139 .93352 m
.44525 .93441 L
s
1 .821 0 r
.008 w
.44525 .93441 Mdot
.016 w
.44525 .93441 m
.44895 .93517 L
s
1 .82 0 r
.008 w
.44895 .93517 Mdot
.016 w
.44895 .93517 m
.45254 .93579 L
s
.008 w
.45254 .93579 Mdot
.016 w
.45254 .93579 m
.4561 .93628 L
s
1 .819 0 r
.008 w
.4561 .93628 Mdot
.016 w
.4561 .93628 m
.45955 .93666 L
s
.008 w
.45955 .93666 Mdot
.016 w
.45955 .93666 m
.46266 .93692 L
s
1 .818 0 r
.008 w
.46266 .93692 Mdot
.016 w
.46266 .93692 m
.46566 .93705 L
s
1 .817 0 r
.008 w
.46566 .93705 Mdot
.016 w
.46566 .93705 m
.46827 .93706 L
s
.008 w
.46827 .93706 Mdot
.016 w
.46827 .93706 m
.47065 .93698 L
s
1 .816 0 r
.008 w
.47065 .93698 Mdot
.016 w
.47065 .93698 m
.47275 .93681 L
s
.008 w
.47275 .93681 Mdot
.016 w
.47275 .93681 m
.47446 .9366 L
s
1 .815 0 r
.008 w
.47446 .9366 Mdot
.016 w
.47446 .9366 m
.47588 .9364 L
s
1 .814 0 r
.008 w
.47588 .9364 Mdot
.016 w
.47588 .9364 m
.47697 .93622 L
s
.008 w
.47697 .93622 Mdot
.016 w
.47697 .93622 m
.47774 .93607 L
s
1 .813 0 r
.008 w
.47774 .93607 Mdot
.016 w
.47774 .93607 m
.47822 .93595 L
s
1 .812 0 r
.008 w
.47822 .93595 Mdot
.016 w
.47822 .93595 m
.4785 .93588 L
s
.008 w
.4785 .93588 Mdot
.016 w
.4785 .93588 m
.47864 .93584 L
s
1 .811 0 r
.008 w
.47864 .93584 Mdot
.016 w
.47864 .93584 m
.47871 .93581 L
s
.008 w
.47871 .93581 Mdot
.016 w
.47871 .93581 m
.47877 .93578 L
s
1 .81 0 r
.008 w
.47877 .93578 Mdot
.016 w
.47877 .93578 m
.47883 .93575 L
s
1 .809 0 r
.008 w
.47883 .93575 Mdot
.016 w
.47883 .93575 m
.47891 .93573 L
s
.008 w
.47891 .93573 Mdot
.016 w
.47891 .93573 m
.47905 .9357 L
s
1 .808 0 r
.008 w
.47905 .9357 Mdot
.016 w
.47905 .9357 m
.47924 .93567 L
s
.008 w
.47924 .93567 Mdot
.016 w
.47924 .93567 m
.47946 .93565 L
s
1 .807 0 r
.008 w
.47946 .93565 Mdot
.016 w
.47946 .93565 m
.4797 .93563 L
s
1 .806 0 r
.008 w
.4797 .93563 Mdot
.016 w
.4797 .93563 m
.47993 .93562 L
s
.008 w
.47993 .93562 Mdot
.016 w
.47993 .93562 m
.48011 .93562 L
s
1 .805 0 r
.008 w
.48011 .93562 Mdot
.016 w
.48011 .93562 m
.48022 .93563 L
s
1 .804 0 r
.008 w
.48022 .93563 Mdot
.016 w
.48022 .93563 m
.48023 .93566 L
s
.008 w
.48023 .93566 Mdot
.016 w
.48023 .93566 m
.48011 .93569 L
s
1 .803 0 r
.008 w
.48011 .93569 Mdot
.016 w
.48011 .93569 m
.47986 .93572 L
s
.008 w
.47986 .93572 Mdot
.016 w
.47986 .93572 m
.47949 .93576 L
s
1 .802 0 r
.008 w
.47949 .93576 Mdot
.016 w
.47949 .93576 m
.47908 .9358 L
s
1 .801 0 r
.008 w
.47908 .9358 Mdot
.016 w
.47908 .9358 m
.47864 .93583 L
s
.008 w
.47864 .93583 Mdot
.016 w
.47864 .93583 m
.47819 .93586 L
s
1 .8 0 r
.008 w
.47819 .93586 Mdot
.016 w
.47819 .93586 m
.47776 .93588 L
s
.008 w
.47776 .93588 Mdot
.016 w
.47776 .93588 m
.47739 .93591 L
s
1 .799 0 r
.008 w
.47739 .93591 Mdot
.016 w
.47739 .93591 m
.47708 .93596 L
s
1 .798 0 r
.008 w
.47708 .93596 Mdot
.016 w
.47708 .93596 m
.47685 .93603 L
s
.008 w
.47685 .93603 Mdot
.016 w
.47685 .93603 m
.47664 .93608 L
s
1 .797 0 r
.008 w
.47664 .93608 Mdot
.016 w
.47664 .93608 m
.47644 .93609 L
s
1 .796 0 r
.008 w
.47644 .93609 Mdot
.016 w
.47644 .93609 m
.47624 .93605 L
s
.008 w
.47624 .93605 Mdot
.016 w
.47624 .93605 m
.47608 .93597 L
s
1 .795 0 r
.008 w
.47608 .93597 Mdot
.016 w
.47608 .93597 m
.47597 .93586 L
s
.008 w
.47597 .93586 Mdot
.016 w
.47597 .93586 m
.4759 .93572 L
s
1 .794 0 r
.008 w
.4759 .93572 Mdot
.016 w
.4759 .93572 m
.47585 .93559 L
s
1 .793 0 r
.008 w
.47585 .93559 Mdot
.016 w
.47585 .93559 m
.47581 .93547 L
s
.008 w
.47581 .93547 Mdot
.016 w
.47581 .93547 m
.47581 .93538 L
s
1 .792 0 r
.008 w
.47581 .93538 Mdot
.016 w
.47581 .93538 m
.47589 .93532 L
s
1 .791 0 r
.008 w
.47589 .93532 Mdot
.016 w
.47589 .93532 m
.47617 .93525 L
s
.008 w
.47617 .93525 Mdot
.016 w
.47617 .93525 m
.47671 .93518 L
s
1 .79 0 r
.008 w
.47671 .93518 Mdot
.016 w
.47671 .93518 m
.47757 .9351 L
s
.008 w
.47757 .9351 Mdot
.016 w
.47757 .9351 m
.47876 .935 L
s
1 .789 0 r
.008 w
.47876 .935 Mdot
.016 w
.47876 .935 m
.48039 .93492 L
s
1 .788 0 r
.008 w
.48039 .93492 Mdot
.016 w
.48039 .93492 m
.48239 .93485 L
s
.008 w
.48239 .93485 Mdot
.016 w
.48239 .93485 m
.4849 .9348 L
s
1 .787 0 r
.008 w
.4849 .9348 Mdot
.016 w
.4849 .9348 m
.48782 .93475 L
s
.008 w
.48782 .93475 Mdot
.016 w
.48782 .93475 m
.4911 .93466 L
s
1 .786 0 r
.008 w
.4911 .93466 Mdot
.016 w
.4911 .93466 m
.49492 .93451 L
s
1 .785 0 r
.008 w
.49492 .93451 Mdot
.016 w
.49492 .93451 m
.49912 .93422 L
s
.008 w
.49912 .93422 Mdot
.016 w
.49912 .93422 m
.5037 .93378 L
s
1 .784 0 r
.008 w
.5037 .93378 Mdot
.016 w
.5037 .93378 m
.50854 .93318 L
s
1 .783 0 r
.008 w
.50854 .93318 Mdot
.016 w
.50854 .93318 m
.51372 .9324 L
s
.008 w
.51372 .9324 Mdot
.016 w
.51372 .9324 m
.5191 .9315 L
s
1 .782 0 r
.008 w
.5191 .9315 Mdot
.016 w
.5191 .9315 m
.52438 .93053 L
s
.008 w
.52438 .93053 Mdot
.016 w
.52438 .93053 m
.5301 .92954 L
s
1 .781 0 r
.008 w
.5301 .92954 Mdot
.016 w
.5301 .92954 m
.53546 .92853 L
s
1 .78 0 r
.008 w
.53546 .92853 Mdot
.016 w
.53546 .92853 m
.54136 .92752 L
s
.008 w
.54136 .92752 Mdot
.016 w
.54136 .92752 m
.54686 .92653 L
s
1 .779 0 r
.008 w
.54686 .92653 Mdot
.016 w
.54686 .92653 m
.55274 .92554 L
s
.008 w
.55274 .92554 Mdot
.016 w
.55274 .92554 m
.5582 .92458 L
s
1 .778 0 r
.008 w
.5582 .92458 Mdot
.016 w
.5582 .92458 m
.56412 .92366 L
s
1 .777 0 r
.008 w
.56412 .92366 Mdot
.016 w
.56412 .92366 m
.56989 .92281 L
s
.008 w
.56989 .92281 Mdot
.016 w
.56989 .92281 m
.57564 .92201 L
s
1 .776 0 r
.008 w
.57564 .92201 Mdot
.016 w
.57564 .92201 m
.58143 .92126 L
s
1 .775 0 r
.008 w
.58143 .92126 Mdot
.016 w
.58143 .92126 m
.58668 .92052 L
s
.008 w
.58668 .92052 Mdot
.016 w
.58668 .92052 m
.59227 .91979 L
s
1 .774 0 r
.008 w
.59227 .91979 Mdot
.016 w
.59227 .91979 m
.59757 .91902 L
s
.008 w
.59757 .91902 Mdot
.016 w
.59757 .91902 m
.60304 .91819 L
s
1 .773 0 r
.008 w
.60304 .91819 Mdot
.016 w
.60304 .91819 m
.60815 .91742 L
s
1 .772 0 r
.008 w
.60815 .91742 Mdot
.016 w
.60815 .91742 m
.61344 .91654 L
s
.008 w
.61344 .91654 Mdot
.016 w
.61344 .91654 m
.61807 .91558 L
s
1 .771 0 r
.008 w
.61807 .91558 Mdot
.016 w
.61807 .91558 m
.62294 .91465 L
s
.008 w
.62294 .91465 Mdot
.016 w
.62294 .91465 m
.62756 .9137 L
s
1 .77 0 r
.008 w
.62756 .9137 Mdot
.016 w
.62756 .9137 m
.63235 .91275 L
s
1 .769 0 r
.008 w
.63235 .91275 Mdot
.016 w
.63235 .91275 m
.6363 .91184 L
s
.008 w
.6363 .91184 Mdot
.016 w
.6363 .91184 m
.6402 .911 L
s
1 .768 0 r
.008 w
.6402 .911 Mdot
.016 w
.6402 .911 m
.64405 .91023 L
s
1 .767 0 r
.008 w
.64405 .91023 Mdot
.016 w
.64405 .91023 m
.64765 .90953 L
s
.008 w
.64765 .90953 Mdot
.016 w
.64765 .90953 m
.65114 .9089 L
s
1 .766 0 r
.008 w
.65114 .9089 Mdot
.016 w
.65114 .9089 m
.65468 .90831 L
s
.008 w
.65468 .90831 Mdot
.016 w
.65468 .90831 m
.65778 .90774 L
s
1 .765 0 r
.008 w
.65778 .90774 Mdot
.016 w
.65778 .90774 m
.66071 .90716 L
s
1 .764 0 r
.008 w
.66071 .90716 Mdot
.016 w
.66071 .90716 m
.66365 .90652 L
s
.008 w
.66365 .90652 Mdot
.016 w
.66365 .90652 m
.6665 .9058 L
s
1 .763 0 r
.008 w
.6665 .9058 Mdot
.016 w
.6665 .9058 m
.66936 .90496 L
s
1 .762 0 r
.008 w
.66936 .90496 Mdot
.016 w
.66936 .90496 m
.67199 .904 L
s
.008 w
.67199 .904 Mdot
.016 w
.67199 .904 m
.67474 .90293 L
s
1 .761 0 r
.008 w
.67474 .90293 Mdot
.016 w
.67474 .90293 m
.67757 .90175 L
s
.008 w
.67757 .90175 Mdot
.016 w
.67757 .90175 m
.68057 .90043 L
s
1 .76 0 r
.008 w
.68057 .90043 Mdot
.016 w
.68057 .90043 m
.68376 .89892 L
s
1 .759 0 r
.008 w
.68376 .89892 Mdot
.016 w
.68376 .89892 m
.68708 .89719 L
s
.008 w
.68708 .89719 Mdot
.016 w
.68708 .89719 m
.69067 .89538 L
s
1 .758 0 r
.008 w
.69067 .89538 Mdot
.016 w
.69067 .89538 m
.69428 .89331 L
s
.008 w
.69428 .89331 Mdot
.016 w
.69428 .89331 m
.69824 .8911 L
s
1 .757 0 r
.008 w
.69824 .8911 Mdot
.016 w
.69824 .8911 m
.70216 .88872 L
s
1 .756 0 r
.008 w
.70216 .88872 Mdot
.016 w
.70216 .88872 m
.7061 .88636 L
s
.008 w
.7061 .88636 Mdot
.016 w
.7061 .88636 m
.71002 .88377 L
s
1 .755 0 r
.008 w
.71002 .88377 Mdot
.016 w
.71002 .88377 m
.71401 .88129 L
s
1 .754 0 r
.008 w
.71401 .88129 Mdot
.016 w
.71401 .88129 m
.7178 .87883 L
s
.008 w
.7178 .87883 Mdot
.016 w
.7178 .87883 m
.72179 .8761 L
s
1 .753 0 r
.008 w
.72179 .8761 Mdot
.016 w
.72179 .8761 m
.72573 .87335 L
s
.008 w
.72573 .87335 Mdot
.016 w
.72573 .87335 m
.72959 .87093 L
s
1 .752 0 r
.008 w
.72959 .87093 Mdot
.016 w
.72959 .87093 m
.73326 .86831 L
s
1 .751 0 r
.008 w
.73326 .86831 Mdot
.016 w
.73326 .86831 m
.73699 .86573 L
s
.008 w
.73699 .86573 Mdot
.016 w
.73699 .86573 m
.74073 .86306 L
s
1 .75 0 r
.008 w
.74073 .86306 Mdot
.016 w
.74073 .86306 m
.74445 .86044 L
s
.008 w
.74445 .86044 Mdot
.016 w
.74445 .86044 m
.74838 .85762 L
s
1 .749 0 r
.008 w
.74838 .85762 Mdot
.016 w
.74838 .85762 m
.75192 .85509 L
s
1 .748 0 r
.008 w
.75192 .85509 Mdot
.016 w
.75192 .85509 m
.75572 .8524 L
s
.008 w
.75572 .8524 Mdot
.016 w
.75572 .8524 m
.75967 .84967 L
s
1 .747 0 r
.008 w
.75967 .84967 Mdot
.016 w
.75967 .84967 m
.76346 .84692 L
s
1 .746 0 r
.008 w
.76346 .84692 Mdot
.016 w
.76346 .84692 m
.76737 .84421 L
s
.008 w
.76737 .84421 Mdot
.016 w
.76737 .84421 m
.7713 .84145 L
s
1 .745 0 r
.008 w
.7713 .84145 Mdot
.016 w
.7713 .84145 m
.77537 .83855 L
s
.008 w
.77537 .83855 Mdot
.016 w
.77537 .83855 m
.77909 .83585 L
s
1 .744 0 r
.008 w
.77909 .83585 Mdot
.016 w
.77909 .83585 m
.78286 .833 L
s
1 .743 0 r
.008 w
.78286 .833 Mdot
.016 w
.78286 .833 m
.78667 .83026 L
s
.008 w
.78667 .83026 Mdot
.016 w
.78667 .83026 m
.79005 .82758 L
s
1 .742 0 r
.008 w
.79005 .82758 Mdot
.016 w
.79005 .82758 m
.79354 .82497 L
s
.008 w
.79354 .82497 Mdot
.016 w
.79354 .82497 m
.79697 .82238 L
s
1 .741 0 r
.008 w
.79697 .82238 Mdot
.016 w
.79697 .82238 m
.80046 .81982 L
s
1 .74 0 r
.008 w
.80046 .81982 Mdot
.016 w
.80046 .81982 m
.80385 .81723 L
s
.008 w
.80385 .81723 Mdot
.016 w
.80385 .81723 m
.80736 .81466 L
s
1 .739 0 r
.008 w
.80736 .81466 Mdot
.016 w
.80736 .81466 m
.8108 .81206 L
s
1 .738 0 r
.008 w
.8108 .81206 Mdot
.016 w
.8108 .81206 m
.81423 .8094 L
s
.008 w
.81423 .8094 Mdot
.016 w
.81423 .8094 m
.81779 .80679 L
s
1 .737 0 r
.008 w
.81779 .80679 Mdot
.016 w
.81779 .80679 m
.82121 .80412 L
s
.008 w
.82121 .80412 Mdot
.016 w
.82121 .80412 m
.82459 .80156 L
s
1 .736 0 r
.008 w
.82459 .80156 Mdot
.016 w
.82459 .80156 m
.82794 .79904 L
s
1 .735 0 r
.008 w
.82794 .79904 Mdot
.016 w
.82794 .79904 m
.83111 .79652 L
s
.008 w
.83111 .79652 Mdot
.016 w
.83111 .79652 m
.8342 .79412 L
s
1 .734 0 r
.008 w
.8342 .79412 Mdot
.016 w
.8342 .79412 m
.83717 .79189 L
s
1 .733 0 r
.008 w
.83717 .79189 Mdot
.016 w
.83717 .79189 m
.83978 .78975 L
s
.008 w
.83978 .78975 Mdot
.016 w
.83978 .78975 m
.84222 .78773 L
s
1 .732 0 r
.008 w
.84222 .78773 Mdot
.016 w
.84222 .78773 m
.84433 .78587 L
s
.008 w
.84433 .78587 Mdot
.016 w
.84433 .78587 m
.84615 .78423 L
s
1 .731 0 r
.008 w
.84615 .78423 Mdot
.016 w
.84615 .78423 m
.84769 .7828 L
s
1 .73 0 r
.008 w
.84769 .7828 Mdot
.016 w
.84769 .7828 m
.84893 .7816 L
s
.008 w
.84893 .7816 Mdot
.016 w
.84893 .7816 m
.84995 .78062 L
s
1 .729 0 r
.008 w
.84995 .78062 Mdot
.016 w
.84995 .78062 m
.85075 .77986 L
s
.008 w
.85075 .77986 Mdot
.016 w
.85075 .77986 m
.85142 .77926 L
s
1 .728 0 r
.008 w
.85142 .77926 Mdot
.016 w
.85142 .77926 m
.85195 .77879 L
s
1 .727 0 r
.008 w
.85195 .77879 Mdot
.016 w
.85195 .77879 m
.85237 .77841 L
s
.008 w
.85237 .77841 Mdot
.016 w
.85237 .77841 m
.8527 .77808 L
s
1 .726 0 r
.008 w
.8527 .77808 Mdot
.016 w
.8527 .77808 m
.85294 .77777 L
s
1 .725 0 r
.008 w
.85294 .77777 Mdot
.016 w
.85294 .77777 m
.85314 .77747 L
s
.008 w
.85314 .77747 Mdot
.016 w
.85314 .77747 m
.85325 .77713 L
s
1 .724 0 r
.008 w
.85325 .77713 Mdot
.016 w
.85325 .77713 m
.85333 .77675 L
s
.008 w
.85333 .77675 Mdot
.016 w
.85333 .77675 m
.8534 .77629 L
s
1 .723 0 r
.008 w
.8534 .77629 Mdot
.016 w
.8534 .77629 m
.85348 .77572 L
s
1 .722 0 r
.008 w
.85348 .77572 Mdot
.016 w
.85348 .77572 m
.85359 .77506 L
s
.008 w
.85359 .77506 Mdot
.016 w
.85359 .77506 m
.85367 .77438 L
s
1 .721 0 r
.008 w
.85367 .77438 Mdot
.016 w
.85367 .77438 m
.85371 .77374 L
s
.008 w
.85371 .77374 Mdot
.016 w
.85371 .77374 m
.85369 .77317 L
s
1 .72 0 r
.008 w
.85369 .77317 Mdot
.016 w
.85369 .77317 m
.85363 .77271 L
s
1 .719 0 r
.008 w
.85363 .77271 Mdot
.016 w
.85363 .77271 m
.85355 .77241 L
s
.008 w
.85355 .77241 Mdot
.016 w
.85355 .77241 m
.85345 .7723 L
s
1 .718 0 r
.008 w
.85345 .7723 Mdot
.016 w
.85345 .7723 m
.85337 .77237 L
s
1 .717 0 r
.008 w
.85337 .77237 Mdot
.016 w
.85337 .77237 m
.85333 .77259 L
s
.008 w
.85333 .77259 Mdot
.016 w
.85333 .77259 m
.85332 .77292 L
s
1 .716 0 r
.008 w
.85332 .77292 Mdot
.016 w
.85332 .77292 m
.8533 .77334 L
s
.008 w
.8533 .77334 Mdot
.016 w
.8533 .77334 m
.85326 .77387 L
s
1 .715 0 r
.008 w
.85326 .77387 Mdot
.016 w
.85326 .77387 m
.85321 .77439 L
s
1 .714 0 r
.008 w
.85321 .77439 Mdot
.016 w
.85321 .77439 m
.85314 .77488 L
s
.008 w
.85314 .77488 Mdot
.016 w
.85314 .77488 m
.85308 .77541 L
s
1 .713 0 r
.008 w
.85308 .77541 Mdot
.016 w
.85308 .77541 m
.85304 .77585 L
s
.008 w
.85304 .77585 Mdot
.016 w
.85304 .77585 m
.85302 .77617 L
s
1 .712 0 r
.008 w
.85302 .77617 Mdot
.016 w
.85302 .77617 m
.85302 .77639 L
s
1 .711 0 r
.008 w
.85302 .77639 Mdot
.016 w
.85302 .77639 m
.85304 .77652 L
s
.008 w
.85304 .77652 Mdot
.016 w
.85304 .77652 m
.85305 .77659 L
s
1 .71 0 r
.008 w
.85305 .77659 Mdot
.016 w
.85305 .77659 m
.85303 .77665 L
s
1 .709 0 r
.008 w
.85303 .77665 Mdot
.016 w
.85303 .77665 m
.85296 .7767 L
s
.008 w
.85296 .7767 Mdot
.016 w
.85296 .7767 m
.85286 .77675 L
s
1 .708 0 r
.008 w
.85286 .77675 Mdot
.016 w
.85286 .77675 m
.85277 .77681 L
s
.008 w
.85277 .77681 Mdot
.016 w
.85277 .77681 m
.85272 .77692 L
s
1 .707 0 r
.008 w
.85272 .77692 Mdot
.016 w
.85272 .77692 m
.85276 .77702 L
s
1 .706 0 r
.008 w
.85276 .77702 Mdot
.016 w
.85276 .77702 m
.85295 .77706 L
s
.008 w
.85295 .77706 Mdot
.016 w
.85295 .77706 m
.8533 .77701 L
s
1 .705 0 r
.008 w
.8533 .77701 Mdot
.016 w
.8533 .77701 m
.85389 .77677 L
s
.008 w
.85389 .77677 Mdot
.016 w
.85389 .77677 m
.85452 .77637 L
s
1 .704 0 r
.008 w
.85452 .77637 Mdot
.016 w
.85452 .77637 m
.8554 .77568 L
s
1 .703 0 r
.008 w
.8554 .77568 Mdot
.016 w
.8554 .77568 m
.85646 .77467 L
s
.008 w
.85646 .77467 Mdot
.016 w
.85646 .77467 m
.85765 .77327 L
s
1 .702 0 r
.008 w
.85765 .77327 Mdot
.016 w
.85765 .77327 m
.85911 .77145 L
s
1 .701 0 r
.008 w
.85911 .77145 Mdot
.016 w
.85911 .77145 m
.86074 .76914 L
s
.008 w
.86074 .76914 Mdot
.016 w
.86074 .76914 m
.86257 .76642 L
s
1 .7 0 r
.008 w
.86257 .76642 Mdot
.016 w
.86257 .76642 m
.86455 .76324 L
s
.008 w
.86455 .76324 Mdot
.016 w
.86455 .76324 m
.86664 .75951 L
s
1 .699 0 r
.008 w
.86664 .75951 Mdot
.016 w
.86664 .75951 m
.86873 .75585 L
s
1 .698 0 r
.008 w
.86873 .75585 Mdot
.016 w
.86873 .75585 m
.87084 .75164 L
s
.008 w
.87084 .75164 Mdot
.016 w
.87084 .75164 m
.87287 .74713 L
s
1 .697 0 r
.008 w
.87287 .74713 Mdot
.016 w
.87287 .74713 m
.87479 .74278 L
s
1 .696 0 r
.008 w
.87479 .74278 Mdot
.016 w
.87479 .74278 m
.87656 .73823 L
s
.008 w
.87656 .73823 Mdot
.016 w
.87656 .73823 m
.8782 .73378 L
s
1 .695 0 r
.008 w
.8782 .73378 Mdot
.016 w
.8782 .73378 m
.87969 .72958 L
s
.008 w
.87969 .72958 Mdot
.016 w
.87969 .72958 m
.88099 .72568 L
s
1 .694 0 r
.008 w
.88099 .72568 Mdot
.016 w
.88099 .72568 m
.88214 .72226 L
s
1 .693 0 r
.008 w
.88214 .72226 Mdot
.016 w
.88214 .72226 m
.88312 .71897 L
s
.008 w
.88312 .71897 Mdot
.016 w
.88312 .71897 m
.88393 .71639 L
s
1 .692 0 r
.008 w
.88393 .71639 Mdot
.016 w
.88393 .71639 m
.8846 .71391 L
s
.008 w
.8846 .71391 Mdot
.016 w
.8846 .71391 m
.88516 .7118 L
s
1 .691 0 r
.008 w
.88516 .7118 Mdot
.016 w
.88516 .7118 m
.88564 .70984 L
s
1 .69 0 r
.008 w
.88564 .70984 Mdot
.016 w
.88564 .70984 m
.88606 .708 L
s
.008 w
.88606 .708 Mdot
.016 w
.88606 .708 m
.88643 .70626 L
s
1 .689 0 r
.008 w
.88643 .70626 Mdot
.016 w
.88643 .70626 m
.8868 .70458 L
s
1 .688 0 r
.008 w
.8868 .70458 Mdot
.016 w
.8868 .70458 m
.88724 .7028 L
s
.008 w
.88724 .7028 Mdot
.016 w
.88724 .7028 m
.8878 .70075 L
s
1 .687 0 r
.008 w
.8878 .70075 Mdot
.016 w
.8878 .70075 m
.88849 .69841 L
s
.008 w
.88849 .69841 Mdot
.016 w
.88849 .69841 m
.88935 .69574 L
s
1 .686 0 r
.008 w
.88935 .69574 Mdot
.016 w
.88935 .69574 m
.8903 .6925 L
s
1 .685 0 r
.008 w
.8903 .6925 Mdot
.016 w
.8903 .6925 m
.89144 .68901 L
s
.008 w
.89144 .68901 Mdot
.016 w
.89144 .68901 m
.89266 .68494 L
s
1 .684 0 r
.008 w
.89266 .68494 Mdot
.016 w
.89266 .68494 m
.89399 .68077 L
s
.008 w
.89399 .68077 Mdot
.016 w
.89399 .68077 m
.89549 .67598 L
s
1 .683 0 r
.008 w
.89549 .67598 Mdot
.016 w
.89549 .67598 m
.89694 .6715 L
s
1 .682 0 r
.008 w
.89694 .6715 Mdot
.016 w
.89694 .6715 m
.89868 .66651 L
s
.008 w
.89868 .66651 Mdot
.016 w
.89868 .66651 m
.90036 .66091 L
s
1 .681 0 r
.008 w
.90036 .66091 Mdot
.016 w
.90036 .66091 m
.90197 .65595 L
s
1 .68 0 r
.008 w
.90197 .65595 Mdot
.016 w
.90197 .65595 m
.90378 .65045 L
s
.008 w
.90378 .65045 Mdot
.016 w
.90378 .65045 m
.90545 .64484 L
s
1 .679 0 r
.008 w
.90545 .64484 Mdot
.016 w
.90545 .64484 m
.90721 .63891 L
s
.008 w
.90721 .63891 Mdot
.016 w
.90721 .63891 m
.90882 .63359 L
s
1 .678 0 r
.008 w
.90882 .63359 Mdot
.016 w
.90882 .63359 m
.91043 .62796 L
s
1 .677 0 r
.008 w
.91043 .62796 Mdot
.016 w
.91043 .62796 m
.91205 .62196 L
s
.008 w
.91205 .62196 Mdot
.016 w
.91205 .62196 m
.91341 .61691 L
s
1 .676 0 r
.008 w
.91341 .61691 Mdot
.016 w
.91341 .61691 m
.91483 .6115 L
s
.008 w
.91483 .6115 Mdot
.016 w
.91483 .6115 m
.91628 .60608 L
s
1 .675 0 r
.008 w
.91628 .60608 Mdot
.016 w
.91628 .60608 m
.9176 .60069 L
s
1 .674 0 r
.008 w
.9176 .60069 Mdot
.016 w
.9176 .60069 m
.91898 .59534 L
s
.008 w
.91898 .59534 Mdot
.016 w
.91898 .59534 m
.92027 .5901 L
s
1 .673 0 r
.008 w
.92027 .5901 Mdot
.016 w
.92027 .5901 m
.92151 .58528 L
s
1 .672 0 r
.008 w
.92151 .58528 Mdot
.016 w
.92151 .58528 m
.92268 .58064 L
s
.008 w
.92268 .58064 Mdot
.016 w
.92268 .58064 m
.9238 .57627 L
s
1 .671 0 r
.008 w
.9238 .57627 Mdot
.016 w
.9238 .57627 m
.92481 .57242 L
s
.008 w
.92481 .57242 Mdot
.016 w
.92481 .57242 m
.9257 .56899 L
s
1 .67 0 r
.008 w
.9257 .56899 Mdot
.016 w
.9257 .56899 m
.9265 .56596 L
s
1 .669 0 r
.008 w
.9265 .56596 Mdot
.016 w
.9265 .56596 m
.92716 .56336 L
s
.008 w
.92716 .56336 Mdot
.016 w
.92716 .56336 m
.92767 .56136 L
s
1 .668 0 r
.008 w
.92767 .56136 Mdot
.016 w
.92767 .56136 m
.92805 .55986 L
s
1 .667 0 r
.008 w
.92805 .55986 Mdot
.016 w
.92805 .55986 m
.92828 .55877 L
s
.008 w
.92828 .55877 Mdot
.016 w
.92828 .55877 m
.92839 .55812 L
s
1 .666 0 r
.008 w
.92839 .55812 Mdot
.016 w
.92839 .55812 m
.92841 .55785 L
s
.008 w
.92841 .55785 Mdot
.016 w
.92841 .55785 m
.92835 .55789 L
s
1 .665 0 r
.008 w
.92835 .55789 Mdot
.016 w
.92835 .55789 m
.92823 .55812 L
s
1 .664 0 r
.008 w
.92823 .55812 Mdot
.016 w
.92823 .55812 m
.92808 .55845 L
s
.008 w
.92808 .55845 Mdot
.016 w
.92808 .55845 m
.92793 .55881 L
s
1 .663 0 r
.008 w
.92793 .55881 Mdot
.016 w
.92793 .55881 m
.92779 .55915 L
s
.008 w
.92779 .55915 Mdot
.016 w
.92779 .55915 m
.92769 .55941 L
s
1 .662 0 r
.008 w
.92769 .55941 Mdot
.016 w
.92769 .55941 m
.92762 .55961 L
s
1 .661 0 r
.008 w
.92762 .55961 Mdot
.016 w
.92762 .55961 m
.92758 .55969 L
s
.008 w
.92758 .55969 Mdot
.016 w
.92758 .55969 m
.92759 .55967 L
s
1 .66 0 r
.008 w
.92759 .55967 Mdot
.016 w
.92759 .55967 m
.92762 .55959 L
s
1 .659 0 r
.008 w
.92762 .55959 Mdot
.016 w
.92762 .55959 m
.92767 .55949 L
s
.008 w
.92767 .55949 Mdot
.016 w
.92767 .55949 m
.92771 .55937 L
s
1 .658 0 r
.008 w
.92771 .55937 Mdot
.016 w
.92771 .55937 m
.92773 .55925 L
s
.008 w
.92773 .55925 Mdot
.016 w
.92773 .55925 m
.92773 .55913 L
s
1 .657 0 r
.008 w
.92773 .55913 Mdot
.016 w
.92773 .55913 m
.92771 .559 L
s
1 .656 0 r
.008 w
.92771 .559 Mdot
.016 w
.92771 .559 m
.92768 .55886 L
s
.008 w
.92768 .55886 Mdot
.016 w
.92768 .55886 m
.92766 .55871 L
s
1 .655 0 r
.008 w
.92766 .55871 Mdot
.016 w
.92766 .55871 m
.92765 .55854 L
s
.008 w
.92765 .55854 Mdot
.016 w
.92765 .55854 m
.92766 .55832 L
s
1 .654 0 r
.008 w
.92766 .55832 Mdot
.016 w
.92766 .55832 m
.92771 .558 L
s
1 .653 0 r
.008 w
.92771 .558 Mdot
.016 w
.92771 .558 m
.92779 .55757 L
s
.008 w
.92779 .55757 Mdot
.016 w
.92779 .55757 m
.92791 .55704 L
s
1 .652 0 r
.008 w
.92791 .55704 Mdot
.016 w
.92791 .55704 m
.92807 .55643 L
s
1 .651 0 r
.008 w
.92807 .55643 Mdot
.016 w
.92807 .55643 m
.92826 .55575 L
s
.008 w
.92826 .55575 Mdot
.016 w
.92826 .55575 m
.9285 .55504 L
s
1 .65 0 r
.008 w
.9285 .55504 Mdot
.016 w
.9285 .55504 m
.92876 .55432 L
s
.008 w
.92876 .55432 Mdot
.016 w
.92876 .55432 m
.92905 .55358 L
s
1 .649 0 r
.008 w
.92905 .55358 Mdot
.016 w
.92905 .55358 m
.92936 .55285 L
s
1 .648 0 r
.008 w
.92936 .55285 Mdot
.016 w
.92936 .55285 m
.92968 .55213 L
s
.008 w
.92968 .55213 Mdot
.016 w
.92968 .55213 m
.92998 .55146 L
s
1 .647 0 r
.008 w
.92998 .55146 Mdot
.016 w
.92998 .55146 m
.93026 .55083 L
s
.008 w
.93026 .55083 Mdot
.016 w
.93026 .55083 m
.9305 .55026 L
s
1 .646 0 r
.008 w
.9305 .55026 Mdot
.016 w
.9305 .55026 m
.93071 .54977 L
s
1 .645 0 r
.008 w
.93071 .54977 Mdot
.016 w
.93071 .54977 m
.93087 .54942 L
s
.008 w
.93087 .54942 Mdot
.016 w
.93087 .54942 m
.931 .54916 L
s
1 .644 0 r
.008 w
.931 .54916 Mdot
.016 w
.931 .54916 m
.93108 .549 L
s
1 .643 0 r
.008 w
.93108 .549 Mdot
.016 w
.93108 .549 m
.93113 .54892 L
s
.008 w
.93113 .54892 Mdot
.016 w
.93113 .54892 m
.93117 .54888 L
s
1 .642 0 r
.008 w
.93117 .54888 Mdot
.016 w
.93117 .54888 m
.93118 .54886 L
s
.008 w
.93118 .54886 Mdot
.016 w
.93118 .54886 m
.93119 .54886 L
s
1 .641 0 r
.008 w
.93119 .54886 Mdot
.016 w
.93119 .54886 m
.93118 .54886 L
s
1 .64 0 r
.008 w
.93118 .54886 Mdot
.016 w
.93118 .54886 m
.93116 .54887 L
s
.008 w
.93116 .54887 Mdot
.016 w
.93116 .54887 m
.93114 .54887 L
s
1 .639 0 r
.008 w
.93114 .54887 Mdot
.016 w
.93114 .54887 m
.93112 .54887 L
s
1 .638 0 r
.008 w
.93112 .54887 Mdot
.016 w
.93112 .54887 m
.93111 .54888 L
s
.008 w
.93111 .54888 Mdot
.016 w
.93111 .54888 m
.93111 .54891 L
s
1 .637 0 r
.008 w
.93111 .54891 Mdot
.016 w
.93111 .54891 m
.93111 .54892 L
s
.008 w
.93111 .54892 Mdot
.016 w
.93111 .54892 m
.93111 .54893 L
s
1 .636 0 r
.008 w
.93111 .54893 Mdot
.016 w
.93111 .54893 m
.93111 .54894 L
s
1 .635 0 r
.008 w
.93111 .54894 Mdot
.016 w
.93111 .54894 m
.93111 .54897 L
s
.008 w
.93111 .54897 Mdot
.016 w
.93111 .54897 m
.93111 .549 L
s
1 .634 0 r
.008 w
.93111 .549 Mdot
.016 w
.93111 .549 m
.93111 .54903 L
s
.008 w
.93111 .54903 Mdot
.016 w
.93111 .54903 m
.93111 .54905 L
s
1 .633 0 r
.008 w
.93111 .54905 Mdot
.016 w
.93111 .54905 m
.93111 .54904 L
s
1 .632 0 r
.008 w
.93111 .54904 Mdot
.016 w
.93111 .54904 m
.93111 .54899 L
s
.008 w
.93111 .54899 Mdot
.016 w
.93111 .54899 m
.93111 .54891 L
s
1 .631 0 r
.008 w
.93111 .54891 Mdot
.016 w
.93111 .54891 m
.9311 .54879 L
s
1 .63 0 r
.008 w
.9311 .54879 Mdot
.016 w
.9311 .54879 m
.9311 .54864 L
s
.008 w
.9311 .54864 Mdot
.016 w
.9311 .54864 m
.93109 .54847 L
s
1 .629 0 r
.008 w
.93109 .54847 Mdot
.016 w
.93109 .54847 m
.93109 .54831 L
s
.008 w
.93109 .54831 Mdot
.016 w
.93109 .54831 m
.93107 .54821 L
s
1 .628 0 r
.008 w
.93107 .54821 Mdot
.016 w
.93107 .54821 m
.93105 .54821 L
s
1 .627 0 r
.008 w
.93105 .54821 Mdot
.016 w
.93105 .54821 m
.93102 .54825 L
s
.008 w
.93102 .54825 Mdot
.016 w
.93102 .54825 m
.931 .5483 L
s
1 .626 0 r
.008 w
.931 .5483 Mdot
.016 w
.931 .5483 m
.93099 .54832 L
s
.008 w
.93099 .54832 Mdot
.016 w
.93099 .54832 m
.931 .54825 L
s
1 .625 0 r
.008 w
.931 .54825 Mdot
.016 w
.931 .54825 m
.93103 .54804 L
s
1 .624 0 r
.008 w
.93103 .54804 Mdot
.016 w
.93103 .54804 m
.9311 .5476 L
s
.008 w
.9311 .5476 Mdot
.016 w
.9311 .5476 m
.93119 .54683 L
s
1 .623 0 r
.008 w
.93119 .54683 Mdot
.016 w
.93119 .54683 m
.9313 .54557 L
s
1 .622 0 r
.008 w
.9313 .54557 Mdot
.016 w
.9313 .54557 m
.93142 .54372 L
s
.008 w
.93142 .54372 Mdot
.016 w
.93142 .54372 m
.93154 .54128 L
s
1 .621 0 r
.008 w
.93154 .54128 Mdot
.016 w
.93154 .54128 m
.93164 .53848 L
s
.008 w
.93164 .53848 Mdot
.016 w
.93164 .53848 m
.93172 .53521 L
s
1 .62 0 r
.008 w
.93172 .53521 Mdot
.016 w
.93172 .53521 m
.93176 .53143 L
s
1 .619 0 r
.008 w
.93176 .53143 Mdot
.016 w
.93176 .53143 m
.93177 .52725 L
s
.008 w
.93177 .52725 Mdot
.016 w
.93177 .52725 m
.93175 .52286 L
s
1 .618 0 r
.008 w
.93175 .52286 Mdot
.016 w
.93175 .52286 m
.93166 .51807 L
s
.008 w
.93166 .51807 Mdot
.016 w
.93166 .51807 m
.9315 .51377 L
s
1 .617 0 r
.008 w
.9315 .51377 Mdot
.016 w
.9315 .51377 m
.93126 .50914 L
s
1 .616 0 r
.008 w
.93126 .50914 Mdot
.016 w
.93126 .50914 m
.93095 .50465 L
s
.008 w
.93095 .50465 Mdot
.016 w
.93095 .50465 m
.93059 .5004 L
s
1 .615 0 r
.008 w
.93059 .5004 Mdot
.016 w
.93059 .5004 m
.93016 .49641 L
s
1 .614 0 r
.008 w
.93016 .49641 Mdot
.016 w
.93016 .49641 m
.92967 .49227 L
s
.008 w
.92967 .49227 Mdot
.016 w
.92967 .49227 m
.92922 .48817 L
s
1 .613 0 r
.008 w
.92922 .48817 Mdot
.016 w
.92922 .48817 m
.92874 .48385 L
s
.008 w
.92874 .48385 Mdot
.016 w
.92874 .48385 m
.92826 .47962 L
s
1 .612 0 r
.008 w
.92826 .47962 Mdot
.016 w
.92826 .47962 m
.92782 .47556 L
s
1 .611 0 r
.008 w
.92782 .47556 Mdot
.016 w
.92782 .47556 m
.92738 .47126 L
s
.008 w
.92738 .47126 Mdot
.016 w
.92738 .47126 m
.927 .46673 L
s
1 .61 0 r
.008 w
.927 .46673 Mdot
.016 w
.927 .46673 m
.92666 .46294 L
s
.008 w
.92666 .46294 Mdot
.016 w
.92666 .46294 m
.92638 .4589 L
s
1 .609 0 r
.008 w
.92638 .4589 Mdot
.016 w
.92638 .4589 m
.92613 .45517 L
s
1 .608 0 r
.008 w
.92613 .45517 Mdot
.016 w
.92613 .45517 m
.92594 .4522 L
s
.008 w
.92594 .4522 Mdot
.016 w
.92594 .4522 m
.9258 .44931 L
s
1 .607 0 r
.008 w
.9258 .44931 Mdot
.016 w
.9258 .44931 m
.9257 .44715 L
s
1 .606 0 r
.008 w
.9257 .44715 Mdot
.016 w
.9257 .44715 m
.92562 .44534 L
s
.008 w
.92562 .44534 Mdot
.016 w
.92562 .44534 m
.92555 .44397 L
s
1 .605 0 r
.008 w
.92555 .44397 Mdot
.016 w
.92555 .44397 m
.92546 .44306 L
s
.008 w
.92546 .44306 Mdot
.016 w
.92546 .44306 m
.92534 .44239 L
s
1 .604 0 r
.008 w
.92534 .44239 Mdot
.016 w
.92534 .44239 m
.92516 .44171 L
s
1 .603 0 r
.008 w
.92516 .44171 Mdot
.016 w
.92516 .44171 m
.92491 .44088 L
s
.008 w
.92491 .44088 Mdot
.016 w
.92491 .44088 m
.9246 .43973 L
s
1 .602 0 r
.008 w
.9246 .43973 Mdot
.016 w
.9246 .43973 m
.92425 .43825 L
s
1 .601 0 r
.008 w
.92425 .43825 Mdot
.016 w
.92425 .43825 m
.92386 .43622 L
s
.008 w
.92386 .43622 Mdot
.016 w
.92386 .43622 m
.92342 .43375 L
s
1 .6 0 r
.008 w
.92342 .43375 Mdot
.016 w
.92342 .43375 m
.92297 .43074 L
s
.008 w
.92297 .43074 Mdot
.016 w
.92297 .43074 m
.92253 .42727 L
s
1 .599 0 r
.008 w
.92253 .42727 Mdot
.016 w
.92253 .42727 m
.92211 .42359 L
s
1 .598 0 r
.008 w
.92211 .42359 Mdot
.016 w
.92211 .42359 m
.92171 .41962 L
s
.008 w
.92171 .41962 Mdot
.016 w
.92171 .41962 m
.92132 .41547 L
s
1 .597 0 r
.008 w
.92132 .41547 Mdot
.016 w
.92132 .41547 m
.92095 .4117 L
s
.008 w
.92095 .4117 Mdot
.016 w
.92095 .4117 m
.92059 .4076 L
s
1 .596 0 r
.008 w
.92059 .4076 Mdot
.016 w
.92059 .4076 m
.92023 .40345 L
s
1 .595 0 r
.008 w
.92023 .40345 Mdot
.016 w
.92023 .40345 m
.91985 .3994 L
s
.008 w
.91985 .3994 Mdot
.016 w
.91985 .3994 m
.91943 .39549 L
s
1 .594 0 r
.008 w
.91943 .39549 Mdot
.016 w
.91943 .39549 m
.91894 .39142 L
s
1 .593 0 r
.008 w
.91894 .39142 Mdot
.016 w
.91894 .39142 m
.91839 .38727 L
s
.008 w
.91839 .38727 Mdot
.016 w
.91839 .38727 m
.9178 .3829 L
s
1 .592 0 r
.008 w
.9178 .3829 Mdot
.016 w
.9178 .3829 m
.91722 .37917 L
s
.008 w
.91722 .37917 Mdot
.016 w
.91722 .37917 m
.91657 .37517 L
s
1 .591 0 r
.008 w
.91657 .37517 Mdot
.016 w
.91657 .37517 m
.91591 .37125 L
s
1 .59 0 r
.008 w
.91591 .37125 Mdot
.016 w
.91591 .37125 m
.91525 .3674 L
s
.008 w
.91525 .3674 Mdot
.016 w
.91525 .3674 m
.91462 .36381 L
s
1 .589 0 r
.008 w
.91462 .36381 Mdot
.016 w
.91462 .36381 m
.91406 .36033 L
s
.008 w
.91406 .36033 Mdot
.016 w
.91406 .36033 m
.91358 .35723 L
s
1 .588 0 r
.008 w
.91358 .35723 Mdot
.016 w
.91358 .35723 m
.91319 .35462 L
s
1 .587 0 r
.008 w
.91319 .35462 Mdot
.016 w
.91319 .35462 m
.91286 .35227 L
s
.008 w
.91286 .35227 Mdot
.016 w
.91286 .35227 m
.91263 .35033 L
s
1 .586 0 r
.008 w
.91263 .35033 Mdot
.016 w
.91263 .35033 m
.91249 .3488 L
s
1 .585 0 r
.008 w
.91249 .3488 Mdot
.016 w
.91249 .3488 m
.91243 .34771 L
s
.008 w
.91243 .34771 Mdot
.016 w
.91243 .34771 m
.91244 .34705 L
s
1 .584 0 r
.008 w
.91244 .34705 Mdot
.016 w
.91244 .34705 m
.91249 .34666 L
s
.008 w
.91249 .34666 Mdot
.016 w
.91249 .34666 m
.91255 .34648 L
s
1 .583 0 r
.008 w
.91255 .34648 Mdot
.016 w
.91255 .34648 m
.91261 .34646 L
s
1 .582 0 r
.008 w
.91261 .34646 Mdot
.016 w
.91261 .34646 m
.91266 .34651 L
s
.008 w
.91266 .34651 Mdot
.016 w
.91266 .34651 m
.91267 .34654 L
s
1 .581 0 r
.008 w
.91267 .34654 Mdot
.016 w
.91267 .34654 m
.91264 .34647 L
s
.008 w
.91264 .34647 Mdot
.016 w
.91264 .34647 m
.91256 .34624 L
s
1 .58 0 r
.008 w
.91256 .34624 Mdot
.016 w
.91256 .34624 m
.91243 .34584 L
s
1 .579 0 r
.008 w
.91243 .34584 Mdot
.016 w
.91243 .34584 m
.91226 .34522 L
s
.008 w
.91226 .34522 Mdot
.016 w
.91226 .34522 m
.91207 .34439 L
s
1 .578 0 r
.008 w
.91207 .34439 Mdot
.016 w
.91207 .34439 m
.91185 .34332 L
s
1 .577 0 r
.008 w
.91185 .34332 Mdot
.016 w
.91185 .34332 m
.91163 .3421 L
s
.008 w
.91163 .3421 Mdot
.016 w
.91163 .3421 m
.91139 .3407 L
s
1 .576 0 r
.008 w
.91139 .3407 Mdot
.016 w
.91139 .3407 m
.91114 .33921 L
s
.008 w
.91114 .33921 Mdot
.016 w
.91114 .33921 m
.91092 .33778 L
s
1 .575 0 r
.008 w
.91092 .33778 Mdot
.016 w
.91092 .33778 m
.9107 .33629 L
s
1 .574 0 r
.008 w
.9107 .33629 Mdot
.016 w
.9107 .33629 m
.91051 .3349 L
s
.008 w
.91051 .3349 Mdot
.016 w
.91051 .3349 m
.91035 .33355 L
s
1 .573 0 r
.008 w
.91035 .33355 Mdot
.016 w
.91035 .33355 m
.91023 .33233 L
s
1 .572 0 r
.008 w
.91023 .33233 Mdot
.016 w
.91023 .33233 m
.91016 .33127 L
s
.008 w
.91016 .33127 Mdot
.016 w
.91016 .33127 m
.91013 .33042 L
s
1 .571 0 r
.008 w
.91013 .33042 Mdot
.016 w
.91013 .33042 m
.91013 .3298 L
s
.008 w
.91013 .3298 Mdot
.016 w
.91013 .3298 m
.91015 .32937 L
s
1 .57 0 r
.008 w
.91015 .32937 Mdot
.016 w
.91015 .32937 m
.91018 .32907 L
s
1 .569 0 r
.008 w
.91018 .32907 Mdot
.016 w
.91018 .32907 m
.91019 .32882 L
s
.008 w
.91019 .32882 Mdot
.016 w
.91019 .32882 m
.91018 .32853 L
s
1 .568 0 r
.008 w
.91018 .32853 Mdot
.016 w
.91018 .32853 m
.91014 .32811 L
s
.008 w
.91014 .32811 Mdot
.016 w
.91014 .32811 m
.91005 .3275 L
s
1 .567 0 r
.008 w
.91005 .3275 Mdot
.016 w
.91005 .3275 m
.9099 .32667 L
s
1 .566 0 r
.008 w
.9099 .32667 Mdot
.016 w
.9099 .32667 m
.90968 .32562 L
s
.008 w
.90968 .32562 Mdot
.016 w
.90968 .32562 m
.90939 .32438 L
s
1 .565 0 r
.008 w
.90939 .32438 Mdot
.016 w
.90939 .32438 m
.90902 .32299 L
s
1 .564 0 r
.008 w
.90902 .32299 Mdot
.016 w
.90902 .32299 m
.90859 .32155 L
s
.008 w
.90859 .32155 Mdot
.016 w
.90859 .32155 m
.90811 .32001 L
s
1 .563 0 r
.008 w
.90811 .32001 Mdot
.016 w
.90811 .32001 m
.90757 .31842 L
s
.008 w
.90757 .31842 Mdot
.016 w
.90757 .31842 m
.90701 .31683 L
s
1 .562 0 r
.008 w
.90701 .31683 Mdot
.016 w
.90701 .31683 m
.90645 .31525 L
s
1 .561 0 r
.008 w
.90645 .31525 Mdot
.016 w
.90645 .31525 m
.9059 .31377 L
s
.008 w
.9059 .31377 Mdot
.016 w
.9059 .31377 m
.90539 .31237 L
s
1 .56 0 r
.008 w
.90539 .31237 Mdot
.016 w
.90539 .31237 m
.90492 .31115 L
s
.008 w
.90492 .31115 Mdot
.016 w
.90492 .31115 m
.90453 .31016 L
s
1 .559 0 r
.008 w
.90453 .31016 Mdot
.016 w
.90453 .31016 m
.90421 .30942 L
s
1 .558 0 r
.008 w
.90421 .30942 Mdot
.016 w
.90421 .30942 m
.90396 .30891 L
s
.008 w
.90396 .30891 Mdot
.016 w
.90396 .30891 m
.90378 .3086 L
s
1 .557 0 r
.008 w
.90378 .3086 Mdot
.016 w
.90378 .3086 m
.90366 .30846 L
s
1 .556 0 r
.008 w
.90366 .30846 Mdot
.016 w
.90366 .30846 m
.9036 .30847 L
s
.008 w
.9036 .30847 Mdot
.016 w
.9036 .30847 m
.90359 .30859 L
s
1 .555 0 r
.008 w
.90359 .30859 Mdot
.016 w
.90359 .30859 m
.90362 .3088 L
s
.008 w
.90362 .3088 Mdot
.016 w
.90362 .3088 m
.90367 .30906 L
s
1 .554 0 r
.008 w
.90367 .30906 Mdot
.016 w
.90367 .30906 m
.90372 .30932 L
s
1 .553 0 r
.008 w
.90372 .30932 Mdot
.016 w
.90372 .30932 m
.90377 .30956 L
s
.008 w
.90377 .30956 Mdot
.016 w
.90377 .30956 m
.90381 .30975 L
s
1 .552 0 r
.008 w
.90381 .30975 Mdot
.016 w
.90381 .30975 m
.90383 .30986 L
s
.008 w
.90383 .30986 Mdot
.016 w
.90383 .30986 m
.90384 .30992 L
s
1 .551 0 r
.008 w
.90384 .30992 Mdot
.016 w
.90384 .30992 m
.90384 .30994 L
s
1 .55 0 r
.008 w
.90384 .30994 Mdot
.016 w
.90384 .30994 m
.90384 .30991 L
s
.008 w
.90384 .30991 Mdot
.016 w
.90384 .30991 m
.90384 .30986 L
s
1 .549 0 r
.008 w
.90384 .30986 Mdot
.016 w
.90384 .30986 m
.90384 .3098 L
s
1 .548 0 r
.008 w
.90384 .3098 Mdot
.016 w
.90384 .3098 m
.90383 .30969 L
s
.008 w
.90383 .30969 Mdot
.016 w
.90383 .30969 m
.90382 .30955 L
s
1 .547 0 r
.008 w
.90382 .30955 Mdot
.016 w
.90382 .30955 m
.90381 .30939 L
s
.008 w
.90381 .30939 Mdot
.016 w
.90381 .30939 m
.9038 .30922 L
s
1 .546 0 r
.008 w
.9038 .30922 Mdot
.016 w
.9038 .30922 m
.90379 .30906 L
s
1 .545 0 r
.008 w
.90379 .30906 Mdot
.016 w
.90379 .30906 m
.90377 .30892 L
s
.008 w
.90377 .30892 Mdot
.016 w
.90377 .30892 m
.90376 .30881 L
s
1 .544 0 r
.008 w
.90376 .30881 Mdot
.016 w
.90376 .30881 m
.90376 .30873 L
s
1 .543 0 r
.008 w
.90376 .30873 Mdot
.016 w
.90376 .30873 m
.90375 .30869 L
s
.008 w
.90375 .30869 Mdot
.016 w
.90375 .30869 m
.90376 .30871 L
s
1 .542 0 r
.008 w
.90376 .30871 Mdot
.016 w
.90376 .30871 m
.90376 .30877 L
s
.008 w
.90376 .30877 Mdot
.016 w
.90376 .30877 m
.90377 .30886 L
s
1 .541 0 r
.008 w
.90377 .30886 Mdot
.016 w
.90377 .30886 m
.90377 .30895 L
s
1 .54 0 r
.008 w
.90377 .30895 Mdot
.016 w
.90377 .30895 m
.90377 .30903 L
s
.008 w
.90377 .30903 Mdot
.016 w
.90377 .30903 m
.90378 .30913 L
s
1 .539 0 r
.008 w
.90378 .30913 Mdot
.016 w
.90378 .30913 m
.90378 .30923 L
s
.008 w
.90378 .30923 Mdot
.016 w
.90378 .30923 m
.90379 .30932 L
s
1 .538 0 r
.008 w
.90379 .30932 Mdot
.016 w
.90379 .30932 m
.90379 .3094 L
s
1 .537 0 r
.008 w
.90379 .3094 Mdot
.016 w
.90379 .3094 m
.90379 .30945 L
s
.008 w
.90379 .30945 Mdot
.016 w
.90379 .30945 m
.9038 .30949 L
s
1 .536 0 r
.008 w
.9038 .30949 Mdot
.016 w
.9038 .30949 m
.9038 .30951 L
s
1 .535 0 r
.008 w
.9038 .30951 Mdot
.016 w
.9038 .30951 m
.9038 .3095 L
s
.008 w
.9038 .3095 Mdot
.016 w
.9038 .3095 m
.90379 .30946 L
s
1 .534 0 r
.008 w
.90379 .30946 Mdot
.016 w
.90379 .30946 m
.90379 .30942 L
s
.008 w
.90379 .30942 Mdot
.016 w
.90379 .30942 m
.90379 .30934 L
s
1 .533 0 r
.008 w
.90379 .30934 Mdot
.016 w
.90379 .30934 m
.90378 .30925 L
s
1 .532 0 r
.008 w
.90378 .30925 Mdot
.016 w
.90378 .30925 m
.90378 .30915 L
s
.008 w
.90378 .30915 Mdot
.016 w
.90378 .30915 m
.90378 .30905 L
s
1 .531 0 r
.008 w
.90378 .30905 Mdot
.016 w
.90378 .30905 m
.90377 .30896 L
s
.008 w
.90377 .30896 Mdot
.016 w
.90377 .30896 m
.90377 .30889 L
s
1 .53 0 r
.008 w
.90377 .30889 Mdot
.016 w
.90377 .30889 m
.90377 .30885 L
s
1 .529 0 r
.008 w
.90377 .30885 Mdot
.016 w
.90377 .30885 m
.90377 .30883 L
s
.008 w
.90377 .30883 Mdot
.016 w
.90377 .30883 m
.90378 .30882 L
s
1 .528 0 r
.008 w
.90378 .30882 Mdot
.016 w
.90378 .30882 m
.90379 .30879 L
s
1 .527 0 r
.008 w
.90379 .30879 Mdot
.016 w
.90379 .30879 m
.9038 .30876 L
s
.008 w
.9038 .30876 Mdot
.016 w
.9038 .30876 m
.90381 .30876 L
s
1 .526 0 r
.008 w
.90381 .30876 Mdot
.016 w
.90381 .30876 m
.90382 .30878 L
s
.008 w
.90382 .30878 Mdot
.016 w
.90382 .30878 m
.90383 .30883 L
s
1 .525 0 r
.008 w
.90383 .30883 Mdot
.016 w
.90383 .30883 m
.90382 .30889 L
s
1 .524 0 r
.008 w
.90382 .30889 Mdot
.016 w
.90382 .30889 m
.9038 .30899 L
s
.008 w
.9038 .30899 Mdot
.016 w
.9038 .30899 m
.90376 .30911 L
s
1 .523 0 r
.008 w
.90376 .30911 Mdot
.016 w
.90376 .30911 m
.90371 .30923 L
s
.008 w
.90371 .30923 Mdot
.016 w
.90371 .30923 m
.90364 .30934 L
s
1 .522 0 r
.008 w
.90364 .30934 Mdot
.016 w
.90364 .30934 m
.90355 .30942 L
s
1 .521 0 r
.008 w
.90355 .30942 Mdot
.016 w
.90355 .30942 m
.90343 .30945 L
s
.008 w
.90343 .30945 Mdot
.016 w
.90343 .30945 m
.90326 .30942 L
s
1 .52 0 r
.008 w
.90326 .30942 Mdot
.016 w
.90326 .30942 m
.90304 .30937 L
s
1 .519 0 r
.008 w
.90304 .30937 Mdot
.016 w
.90304 .30937 m
.90275 .30928 L
s
.008 w
.90275 .30928 Mdot
.016 w
.90275 .30928 m
.90238 .30912 L
s
1 .518 0 r
.008 w
.90238 .30912 Mdot
.016 w
.90238 .30912 m
.90192 .30891 L
s
.008 w
.90192 .30891 Mdot
.016 w
.90192 .30891 m
.90136 .30863 L
s
1 .517 0 r
.008 w
.90136 .30863 Mdot
.016 w
.90136 .30863 m
.9007 .3083 L
s
1 .516 0 r
.008 w
.9007 .3083 Mdot
.016 w
.9007 .3083 m
.9 .30796 L
s
.008 w
.9 .30796 Mdot
.016 w
.9 .30796 m
.89924 .30764 L
s
1 .515 0 r
.008 w
.89924 .30764 Mdot
.016 w
.89924 .30764 m
.89846 .30735 L
s
1 .514 0 r
.008 w
.89846 .30735 Mdot
.016 w
.89846 .30735 m
.89774 .30711 L
s
.008 w
.89774 .30711 Mdot
.016 w
.89774 .30711 m
.89709 .30693 L
s
1 .513 0 r
.008 w
.89709 .30693 Mdot
.016 w
.89709 .30693 m
.89656 .30681 L
s
.008 w
.89656 .30681 Mdot
.016 w
.89656 .30681 m
.89617 .30676 L
s
1 .512 0 r
.008 w
.89617 .30676 Mdot
.016 w
.89617 .30676 m
.89594 .30673 L
s
1 .511 0 r
.008 w
.89594 .30673 Mdot
.016 w
.89594 .30673 m
.89586 .30666 L
s
.008 w
.89586 .30666 Mdot
.016 w
.89586 .30666 m
.89591 .30654 L
s
1 .51 0 r
.008 w
.89591 .30654 Mdot
.016 w
.89591 .30654 m
.89609 .30635 L
s
.008 w
.89609 .30635 Mdot
.016 w
.89609 .30635 m
.89632 .30602 L
s
1 .509 0 r
.008 w
.89632 .30602 Mdot
.016 w
.89632 .30602 m
.89659 .3055 L
s
1 .508 0 r
.008 w
.89659 .3055 Mdot
.016 w
.89659 .3055 m
.89681 .30477 L
s
.008 w
.89681 .30477 Mdot
.016 w
.89681 .30477 m
.89696 .30377 L
s
1 .507 0 r
.008 w
.89696 .30377 Mdot
.016 w
.89696 .30377 m
.89695 .30248 L
s
1 .506 0 r
.008 w
.89695 .30248 Mdot
.016 w
.89695 .30248 m
.89673 .30086 L
s
.008 w
.89673 .30086 Mdot
.016 w
.89673 .30086 m
.89631 .29904 L
s
1 .505 0 r
.008 w
.89631 .29904 Mdot
.016 w
.89631 .29904 m
.89566 .29688 L
s
.008 w
.89566 .29688 Mdot
.016 w
.89566 .29688 m
.89472 .29441 L
s
1 .504 0 r
.008 w
.89472 .29441 Mdot
.016 w
.89472 .29441 m
.89351 .29163 L
s
1 .503 0 r
.008 w
.89351 .29163 Mdot
.016 w
.89351 .29163 m
.89202 .28869 L
s
.008 w
.89202 .28869 Mdot
.016 w
.89202 .28869 m
.8902 .2851 L
s
1 .502 0 r
.008 w
.8902 .2851 Mdot
.016 w
.8902 .2851 m
.88834 .282 L
s
.008 w
.88834 .282 Mdot
.016 w
.88834 .282 m
.88615 .27843 L
s
1 .501 0 r
.008 w
.88615 .27843 Mdot
.016 w
.88615 .27843 m
.88382 .2747 L
s
1 .5 0 r
.008 w
.88382 .2747 Mdot
.016 w
.88382 .2747 m
.88147 .27079 L
s
.008 w
.88147 .27079 Mdot
.016 w
.88147 .27079 m
.87878 .26659 L
s
1 .499 0 r
.008 w
.87878 .26659 Mdot
.016 w
.87878 .26659 m
.87638 .26276 L
s
1 .498 0 r
.008 w
.87638 .26276 Mdot
.016 w
.87638 .26276 m
.87372 .25874 L
s
.008 w
.87372 .25874 Mdot
.016 w
.87372 .25874 m
.87084 .25431 L
s
1 .497 0 r
.008 w
.87084 .25431 Mdot
.016 w
.87084 .25431 m
.86826 .25063 L
s
.008 w
.86826 .25063 Mdot
.016 w
.86826 .25063 m
.86549 .24658 L
s
1 .496 0 r
.008 w
.86549 .24658 Mdot
.016 w
.86549 .24658 m
.86274 .24251 L
s
1 .495 0 r
.008 w
.86274 .24251 Mdot
.016 w
.86274 .24251 m
.85979 .23875 L
s
.008 w
.85979 .23875 Mdot
.016 w
.85979 .23875 m
.85737 .23483 L
s
1 .494 0 r
.008 w
.85737 .23483 Mdot
.016 w
.85737 .23483 m
.85479 .23137 L
s
.008 w
.85479 .23137 Mdot
.016 w
.85479 .23137 m
.85236 .22791 L
s
1 .493 0 r
.008 w
.85236 .22791 Mdot
.016 w
.85236 .22791 m
.8499 .22469 L
s
1 .492 0 r
.008 w
.8499 .22469 Mdot
.016 w
.8499 .22469 m
.84766 .22156 L
s
.008 w
.84766 .22156 Mdot
.016 w
.84766 .22156 m
.84546 .21849 L
s
1 .491 0 r
.008 w
.84546 .21849 Mdot
.016 w
.84546 .21849 m
.84327 .21559 L
s
1 .49 0 r
.008 w
.84327 .21559 Mdot
.016 w
.84327 .21559 m
.8411 .21266 L
s
.008 w
.8411 .21266 Mdot
.016 w
.8411 .21266 m
.83889 .20973 L
s
1 .489 0 r
.008 w
.83889 .20973 Mdot
.016 w
.83889 .20973 m
.83666 .20674 L
s
.008 w
.83666 .20674 Mdot
.016 w
.83666 .20674 m
.83438 .20371 L
s
1 .488 0 r
.008 w
.83438 .20371 Mdot
.016 w
.83438 .20371 m
.83197 .20039 L
s
1 .487 0 r
.008 w
.83197 .20039 Mdot
.016 w
.83197 .20039 m
.82958 .19726 L
s
.008 w
.82958 .19726 Mdot
.016 w
.82958 .19726 m
.82701 .19387 L
s
1 .486 0 r
.008 w
.82701 .19387 Mdot
.016 w
.82701 .19387 m
.82444 .19079 L
s
.008 w
.82444 .19079 Mdot
.016 w
.82444 .19079 m
.82153 .18717 L
s
1 .485 0 r
.008 w
.82153 .18717 Mdot
.016 w
.82153 .18717 m
.81886 .18361 L
s
1 .484 0 r
.008 w
.81886 .18361 Mdot
.016 w
.81886 .18361 m
.81617 .17999 L
s
.008 w
.81617 .17999 Mdot
.016 w
.81617 .17999 m
.81352 .1766 L
s
1 .483 0 r
.008 w
.81352 .1766 Mdot
.016 w
.81352 .1766 m
.81069 .17291 L
s
1 .482 0 r
.008 w
.81069 .17291 Mdot
.016 w
.81069 .17291 m
.80795 .16933 L
s
.008 w
.80795 .16933 Mdot
.016 w
.80795 .16933 m
.80518 .16577 L
s
1 .481 0 r
.008 w
.80518 .16577 Mdot
.016 w
.80518 .16577 m
.80256 .16231 L
s
.008 w
.80256 .16231 Mdot
.016 w
.80256 .16231 m
.79999 .15904 L
s
1 .48 0 r
.008 w
.79999 .15904 Mdot
.016 w
.79999 .15904 m
.79755 .15589 L
s
1 .479 0 r
.008 w
.79755 .15589 Mdot
.016 w
.79755 .15589 m
.79539 .15298 L
s
.008 w
.79539 .15298 Mdot
.016 w
.79539 .15298 m
.79333 .15029 L
s
1 .478 0 r
.008 w
.79333 .15029 Mdot
.016 w
.79333 .15029 m
.79146 .14781 L
s
1 .477 0 r
.008 w
.79146 .14781 Mdot
.016 w
.79146 .14781 m
.78982 .14566 L
s
.008 w
.78982 .14566 Mdot
.016 w
.78982 .14566 m
.78841 .14385 L
s
1 .476 0 r
.008 w
.78841 .14385 Mdot
.016 w
.78841 .14385 m
.78724 .14233 L
s
.008 w
.78724 .14233 Mdot
.016 w
.78724 .14233 m
.78635 .14119 L
s
1 .475 0 r
.008 w
.78635 .14119 Mdot
.016 w
.78635 .14119 m
.78565 .14033 L
s
1 .474 0 r
.008 w
.78565 .14033 Mdot
.016 w
.78565 .14033 m
.78514 .13974 L
s
.008 w
.78514 .13974 Mdot
.016 w
.78514 .13974 m
.7848 .13938 L
s
1 .473 0 r
.008 w
.7848 .13938 Mdot
.016 w
.7848 .13938 m
.78461 .13922 L
s
.008 w
.78461 .13922 Mdot
.016 w
.78461 .13922 m
.78454 .13921 L
s
1 .472 0 r
.008 w
.78454 .13921 Mdot
.016 w
.78454 .13921 m
.78456 .13929 L
s
1 .471 0 r
.008 w
.78456 .13929 Mdot
.016 w
.78456 .13929 m
.78462 .13941 L
s
.008 w
.78462 .13941 Mdot
.016 w
.78462 .13941 m
.78471 .13955 L
s
1 .47 0 r
.008 w
.78471 .13955 Mdot
.016 w
.78471 .13955 m
.78481 .13966 L
s
1 .469 0 r
.008 w
.78481 .13966 Mdot
.016 w
.78481 .13966 m
.7849 .13975 L
s
.008 w
.7849 .13975 Mdot
.016 w
.7849 .13975 m
.78496 .13981 L
s
1 .468 0 r
.008 w
.78496 .13981 Mdot
.016 w
.78496 .13981 m
.78499 .13984 L
s
.008 w
.78499 .13984 Mdot
.016 w
.78499 .13984 m
.785 .13984 L
s
1 .467 0 r
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
1 .466 0 r
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
1 .465 0 r
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
1 .464 0 r
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13984 L
s
1 .463 0 r
.008 w
.785 .13984 Mdot
.016 w
.785 .13984 m
.785 .13985 L
s
.008 w
.785 .13985 Mdot
.016 w
.785 .13985 m
.78501 .13986 L
s
1 .462 0 r
.008 w
.78501 .13986 Mdot
.016 w
.78501 .13986 m
.78503 .1399 L
s
1 .461 0 r
.008 w
.78503 .1399 Mdot
.016 w
.78503 .1399 m
.78507 .13995 L
s
.008 w
.78507 .13995 Mdot
.016 w
.78507 .13995 m
.7851 .13998 L
s
1 .46 0 r
.008 w
.7851 .13998 Mdot
.016 w
.7851 .13998 m
.78511 .14 L
s
.008 w
.78511 .14 Mdot
.016 w
.78511 .14 m
.7851 .13999 L
s
1 .459 0 r
.008 w
.7851 .13999 Mdot
.016 w
.7851 .13999 m
.78506 .13993 L
s
1 .458 0 r
.008 w
.78506 .13993 Mdot
.016 w
.78506 .13993 m
.78498 .13982 L
s
.008 w
.78498 .13982 Mdot
.016 w
.78498 .13982 m
.78487 .13966 L
s
1 .457 0 r
.008 w
.78487 .13966 Mdot
.016 w
.78487 .13966 m
.78473 .13947 L
s
.008 w
.78473 .13947 Mdot
.016 w
.78473 .13947 m
.78458 .13924 L
s
1 .456 0 r
.008 w
.78458 .13924 Mdot
.016 w
.78458 .13924 m
.78446 .13898 L
s
1 .455 0 r
.008 w
.78446 .13898 Mdot
.016 w
.78446 .13898 m
.78435 .13873 L
s
.008 w
.78435 .13873 Mdot
.016 w
.78435 .13873 m
.78424 .13845 L
s
1 .454 0 r
.008 w
.78424 .13845 Mdot
.016 w
.78424 .13845 m
.78407 .13815 L
s
1 .453 0 r
.008 w
.78407 .13815 Mdot
.016 w
.78407 .13815 m
.78382 .13778 L
s
.008 w
.78382 .13778 Mdot
.016 w
.78382 .13778 m
.78348 .13738 L
s
1 .452 0 r
.008 w
.78348 .13738 Mdot
.016 w
.78348 .13738 m
.78305 .13694 L
s
.008 w
.78305 .13694 Mdot
.016 w
.78305 .13694 m
.7825 .13647 L
s
1 .451 0 r
.008 w
.7825 .13647 Mdot
.016 w
.7825 .13647 m
.78185 .13607 L
s
1 .45 0 r
.008 w
.78185 .13607 Mdot
.016 w
.78185 .13607 m
.78112 .13568 L
s
.008 w
.78112 .13568 Mdot
.016 w
.78112 .13568 m
.78034 .1353 L
s
1 .449 0 r
.008 w
.78034 .1353 Mdot
.016 w
.78034 .1353 m
.77955 .13493 L
s
1 .448 0 r
.008 w
.77955 .13493 Mdot
.016 w
.77955 .13493 m
.77888 .13455 L
s
.008 w
.77888 .13455 Mdot
.016 w
.77888 .13455 m
.77812 .13417 L
s
1 .447 0 r
.008 w
.77812 .13417 Mdot
.016 w
.77812 .13417 m
.77739 .13379 L
s
.008 w
.77739 .13379 Mdot
.016 w
.77739 .13379 m
.77662 .13343 L
s
1 .446 0 r
.008 w
.77662 .13343 Mdot
.016 w
.77662 .13343 m
.77583 .13312 L
s
1 .445 0 r
.008 w
.77583 .13312 Mdot
.016 w
.77583 .13312 m
.77507 .13292 L
s
.008 w
.77507 .13292 Mdot
.016 w
.77507 .13292 m
.77437 .13287 L
s
1 .444 0 r
.008 w
.77437 .13287 Mdot
.016 w
.77437 .13287 m
.7737 .13293 L
s
.008 w
.7737 .13293 Mdot
.016 w
.7737 .13293 m
.77299 .13315 L
s
1 .443 0 r
.008 w
.77299 .13315 Mdot
.016 w
.77299 .13315 m
.77219 .13347 L
s
1 .442 0 r
.008 w
.77219 .13347 Mdot
.016 w
.77219 .13347 m
.77123 .13387 L
s
.008 w
.77123 .13387 Mdot
.016 w
.77123 .13387 m
.77005 .13432 L
s
1 .441 0 r
.008 w
.77005 .13432 Mdot
.016 w
.77005 .13432 m
.76879 .13485 L
s
1 .44 0 r
.008 w
.76879 .13485 Mdot
.016 w
.76879 .13485 m
.76728 .13542 L
s
.008 w
.76728 .13542 Mdot
.016 w
.76728 .13542 m
.76546 .13603 L
s
1 .439 0 r
.008 w
.76546 .13603 Mdot
.016 w
.76546 .13603 m
.76347 .1367 L
s
.008 w
.76347 .1367 Mdot
.016 w
.76347 .1367 m
.76143 .13741 L
s
1 .438 0 r
.008 w
.76143 .13741 Mdot
.016 w
.76143 .13741 m
.75911 .1382 L
s
1 .437 0 r
.008 w
.75911 .1382 Mdot
.016 w
.75911 .1382 m
.75679 .13907 L
s
.008 w
.75679 .13907 Mdot
.016 w
.75679 .13907 m
.75425 .14 L
s
1 .436 0 r
.008 w
.75425 .14 Mdot
.016 w
.75425 .14 m
.75199 .14099 L
s
.008 w
.75199 .14099 Mdot
.016 w
.75199 .14099 m
.74956 .14196 L
s
1 .435 0 r
.008 w
.74956 .14196 Mdot
.016 w
.74956 .14196 m
.74708 .143 L
s
1 .434 0 r
.008 w
.74708 .143 Mdot
.016 w
.74708 .143 m
.74504 .14407 L
s
.008 w
.74504 .14407 Mdot
.016 w
.74504 .14407 m
.74297 .14519 L
s
1 .433 0 r
.008 w
.74297 .14519 Mdot
.016 w
.74297 .14519 m
.7409 .14636 L
s
1 .432 0 r
.008 w
.7409 .14636 Mdot
.016 w
.7409 .14636 m
.73896 .14751 L
s
.008 w
.73896 .14751 Mdot
.016 w
.73896 .14751 m
.73712 .14882 L
s
1 .431 0 r
.008 w
.73712 .14882 Mdot
.016 w
.73712 .14882 m
.73542 .15005 L
s
.008 w
.73542 .15005 Mdot
.016 w
.73542 .15005 m
.73375 .15128 L
s
1 .43 0 r
.008 w
.73375 .15128 Mdot
.016 w
.73375 .15128 m
.73225 .15247 L
s
1 .429 0 r
.008 w
.73225 .15247 Mdot
.016 w
.73225 .15247 m
.73086 .15354 L
s
.008 w
.73086 .15354 Mdot
.016 w
.73086 .15354 m
.7296 .15445 L
s
1 .428 0 r
.008 w
.7296 .15445 Mdot
.016 w
.7296 .15445 m
.72852 .15517 L
s
.008 w
.72852 .15517 Mdot
.016 w
.72852 .15517 m
.72769 .15563 L
s
1 .427 0 r
.008 w
.72769 .15563 Mdot
.016 w
.72769 .15563 m
.727 .15588 L
s
1 .426 0 r
.008 w
.727 .15588 Mdot
.016 w
.727 .15588 m
.72645 .15594 L
s
.008 w
.72645 .15594 Mdot
.016 w
.72645 .15594 m
.72606 .15588 L
s
1 .425 0 r
.008 w
.72606 .15588 Mdot
.016 w
.72606 .15588 m
.72584 .15572 L
s
1 .424 0 r
.008 w
.72584 .15572 Mdot
.016 w
.72584 .15572 m
.7258 .15551 L
s
.008 w
.7258 .15551 Mdot
.016 w
.7258 .15551 m
.72593 .15528 L
s
1 .423 0 r
.008 w
.72593 .15528 Mdot
.016 w
.72593 .15528 m
.72624 .15506 L
s
.008 w
.72624 .15506 Mdot
.016 w
.72624 .15506 m
.72668 .15494 L
s
1 .422 0 r
.008 w
.72668 .15494 Mdot
.016 w
.72668 .15494 m
.72725 .15498 L
s
1 .421 0 r
.008 w
.72725 .15498 Mdot
.016 w
.72725 .15498 m
.72794 .15524 L
s
.008 w
.72794 .15524 Mdot
.016 w
.72794 .15524 m
.72872 .15579 L
s
1 .42 0 r
.008 w
.72872 .15579 Mdot
.016 w
.72872 .15579 m
.72957 .15672 L
s
1 .419 0 r
.008 w
.72957 .15672 Mdot
.016 w
.72957 .15672 m
.73053 .15793 L
s
.008 w
.73053 .15793 Mdot
.016 w
.73053 .15793 m
.73159 .15963 L
s
1 .418 0 r
.008 w
.73159 .15963 Mdot
.016 w
.73159 .15963 m
.73282 .16152 L
s
.008 w
.73282 .16152 Mdot
.016 w
.73282 .16152 m
.73423 .16384 L
s
1 .417 0 r
.008 w
.73423 .16384 Mdot
.016 w
.73423 .16384 m
.73565 .16634 L
s
1 .416 0 r
.008 w
.73565 .16634 Mdot
.016 w
.73565 .16634 m
.73727 .16912 L
s
.008 w
.73727 .16912 Mdot
.016 w
.73727 .16912 m
.73899 .17175 L
s
1 .415 0 r
.008 w
.73899 .17175 Mdot
.016 w
.73899 .17175 m
.74078 .17473 L
s
.008 w
.74078 .17473 Mdot
.016 w
.74078 .17473 m
.74268 .17749 L
s
1 .414 0 r
.008 w
.74268 .17749 Mdot
.016 w
.74268 .17749 m
.74463 .18045 L
s
1 .413 0 r
.008 w
.74463 .18045 Mdot
.016 w
.74463 .18045 m
.7466 .1834 L
s
.008 w
.7466 .1834 Mdot
.016 w
.7466 .1834 m
.7487 .18642 L
s
1 .412 0 r
.008 w
.7487 .18642 Mdot
.016 w
.7487 .18642 m
.7508 .18956 L
s
1 .411 0 r
.008 w
.7508 .18956 Mdot
.016 w
.7508 .18956 m
.75287 .1926 L
s
.008 w
.75287 .1926 Mdot
.016 w
.75287 .1926 m
.75505 .19582 L
s
1 .41 0 r
.008 w
.75505 .19582 Mdot
.016 w
.75505 .19582 m
.75707 .19908 L
s
.008 w
.75707 .19908 Mdot
.016 w
.75707 .19908 m
.75915 .20239 L
s
1 .409 0 r
.008 w
.75915 .20239 Mdot
.016 w
.75915 .20239 m
.76127 .20594 L
s
1 .408 0 r
.008 w
.76127 .20594 Mdot
.016 w
.76127 .20594 m
.76321 .20899 L
s
.008 w
.76321 .20899 Mdot
.016 w
.76321 .20899 m
.76515 .21213 L
s
1 .407 0 r
.008 w
.76515 .21213 Mdot
.016 w
.76515 .21213 m
.76707 .21526 L
s
.008 w
.76707 .21526 Mdot
.016 w
.76707 .21526 m
.76876 .21787 L
s
1 .406 0 r
.008 w
.76876 .21787 Mdot
.016 w
.76876 .21787 m
.77039 .22041 L
s
1 .405 0 r
.008 w
.77039 .22041 Mdot
.016 w
.77039 .22041 m
.77182 .2226 L
s
.008 w
.77182 .2226 Mdot
.016 w
.77182 .2226 m
.77305 .22458 L
s
1 .404 0 r
.008 w
.77305 .22458 Mdot
.016 w
.77305 .22458 m
.77406 .22606 L
s
1 .403 0 r
.008 w
.77406 .22606 Mdot
.016 w
.77406 .22606 m
.77484 .22733 L
s
.008 w
.77484 .22733 Mdot
.016 w
.77484 .22733 m
.7754 .22813 L
s
1 .402 0 r
.008 w
.7754 .22813 Mdot
.016 w
.7754 .22813 m
.77577 .2287 L
s
.008 w
.77577 .2287 Mdot
.016 w
.77577 .2287 m
.77601 .22899 L
s
1 .401 0 r
.008 w
.77601 .22899 Mdot
.016 w
.77601 .22899 m
.77612 .22903 L
s
1 .4 0 r
.008 w
.77612 .22903 Mdot
.016 w
.77612 .22903 m
.77615 .22892 L
s
.008 w
.77615 .22892 Mdot
.016 w
.77615 .22892 m
.7761 .22872 L
s
1 .399 0 r
.008 w
.7761 .22872 Mdot
.016 w
.7761 .22872 m
.77597 .2285 L
s
.008 w
.77597 .2285 Mdot
.016 w
.77597 .2285 m
.77578 .2283 L
s
1 .398 0 r
.008 w
.77578 .2283 Mdot
.016 w
.77578 .2283 m
.77559 .22817 L
s
1 .397 0 r
.008 w
.77559 .22817 Mdot
.016 w
.77559 .22817 m
.77545 .22816 L
s
.008 w
.77545 .22816 Mdot
.016 w
.77545 .22816 m
.77541 .22829 L
s
1 .396 0 r
.008 w
.77541 .22829 Mdot
.016 w
.77541 .22829 m
.77552 .22857 L
s
1 .395 0 r
.008 w
.77552 .22857 Mdot
.016 w
.77552 .22857 m
.77579 .22901 L
s
.008 w
.77579 .22901 Mdot
.016 w
.77579 .22901 m
.77624 .22962 L
s
1 .394 0 r
.008 w
.77624 .22962 Mdot
.016 w
.77624 .22962 m
.7769 .23043 L
s
.008 w
.7769 .23043 Mdot
.016 w
.7769 .23043 m
.77778 .23136 L
s
1 .393 0 r
.008 w
.77778 .23136 Mdot
.016 w
.77778 .23136 m
.77887 .23245 L
s
1 .392 0 r
.008 w
.77887 .23245 Mdot
.016 w
.77887 .23245 m
.78015 .23368 L
s
.008 w
.78015 .23368 Mdot
.016 w
.78015 .23368 m
.78137 .23496 L
s
1 .391 0 r
.008 w
.78137 .23496 Mdot
.016 w
.78137 .23496 m
.78295 .23625 L
s
1 .39 0 r
.008 w
.78295 .23625 Mdot
.016 w
.78295 .23625 m
.78442 .2375 L
s
.008 w
.78442 .2375 Mdot
.016 w
.78442 .2375 m
.78594 .2386 L
s
1 .389 0 r
.008 w
.78594 .2386 Mdot
.016 w
.78594 .2386 m
.78744 .23958 L
s
.008 w
.78744 .23958 Mdot
.016 w
.78744 .23958 m
.7888 .24036 L
s
1 .388 0 r
.008 w
.7888 .24036 Mdot
.016 w
.7888 .24036 m
.78998 .24104 L
s
1 .387 0 r
.008 w
.78998 .24104 Mdot
.016 w
.78998 .24104 m
.79104 .24165 L
s
.008 w
.79104 .24165 Mdot
.016 w
.79104 .24165 m
.79188 .24209 L
s
1 .386 0 r
.008 w
.79188 .24209 Mdot
.016 w
.79188 .24209 m
.79264 .2425 L
s
.008 w
.79264 .2425 Mdot
.016 w
.79264 .2425 m
.79334 .24288 L
s
1 .385 0 r
.008 w
.79334 .24288 Mdot
.016 w
.79334 .24288 m
.79403 .24327 L
s
1 .384 0 r
.008 w
.79403 .24327 Mdot
.016 w
.79403 .24327 m
.79478 .24371 L
s
.008 w
.79478 .24371 Mdot
.016 w
.79478 .24371 m
.79566 .24424 L
s
1 .383 0 r
.008 w
.79566 .24424 Mdot
.016 w
.79566 .24424 m
.79672 .24492 L
s
1 .382 0 r
.008 w
.79672 .24492 Mdot
.016 w
.79672 .24492 m
.79794 .24572 L
s
.008 w
.79794 .24572 Mdot
.016 w
.79794 .24572 m
.7994 .24678 L
s
1 .381 0 r
.008 w
.7994 .24678 Mdot
.016 w
.7994 .24678 m
.80114 .24804 L
s
.008 w
.80114 .24804 Mdot
.016 w
.80114 .24804 m
.80316 .24957 L
s
1 .38 0 r
.008 w
.80316 .24957 Mdot
.016 w
.80316 .24957 m
.80549 .25131 L
s
1 .379 0 r
.008 w
.80549 .25131 Mdot
.016 w
.80549 .25131 m
.80817 .25319 L
s
.008 w
.80817 .25319 Mdot
.016 w
.80817 .25319 m
.81094 .25527 L
s
1 .378 0 r
.008 w
.81094 .25527 Mdot
.016 w
.81094 .25527 m
.81401 .25726 L
s
.008 w
.81401 .25726 Mdot
.016 w
.81401 .25726 m
.81702 .25931 L
s
1 .377 0 r
.008 w
.81702 .25931 Mdot
.016 w
.81702 .25931 m
.82028 .26146 L
s
1 .376 0 r
.008 w
.82028 .26146 Mdot
.016 w
.82028 .26146 m
.82364 .26351 L
s
.008 w
.82364 .26351 Mdot
.016 w
.82364 .26351 m
.82685 .2654 L
s
1 .375 0 r
.008 w
.82685 .2654 Mdot
.016 w
.82685 .2654 m
.83032 .26732 L
s
1 .374 0 r
.008 w
.83032 .26732 Mdot
.016 w
.83032 .26732 m
.83374 .26913 L
s
.008 w
.83374 .26913 Mdot
.016 w
.83374 .26913 m
.83725 .27082 L
s
1 .373 0 r
.008 w
.83725 .27082 Mdot
.016 w
.83725 .27082 m
.8408 .27227 L
s
.008 w
.8408 .27227 Mdot
.016 w
.8408 .27227 m
.8447 .27353 L
s
1 .372 0 r
.008 w
.8447 .27353 Mdot
.016 w
.8447 .27353 m
.84788 .27458 L
s
1 .371 0 r
.008 w
.84788 .27458 Mdot
.016 w
.84788 .27458 m
.85135 .2754 L
s
.008 w
.85135 .2754 Mdot
.016 w
.85135 .2754 m
.8549 .27604 L
s
1 .37 0 r
.008 w
.8549 .27604 Mdot
.016 w
.8549 .27604 m
.85797 .27652 L
s
.008 w
.85797 .27652 Mdot
.016 w
.85797 .27652 m
.86101 .27687 L
s
1 .369 0 r
.008 w
.86101 .27687 Mdot
.016 w
.86101 .27687 m
.86384 .27709 L
s
1 .368 0 r
.008 w
.86384 .27709 Mdot
.016 w
.86384 .27709 m
.86644 .27723 L
s
.008 w
.86644 .27723 Mdot
.016 w
.86644 .27723 m
.86861 .2773 L
s
1 .367 0 r
.008 w
.86861 .2773 Mdot
.016 w
.86861 .2773 m
.87061 .27732 L
s
1 .366 0 r
.008 w
.87061 .27732 Mdot
.016 w
.87061 .27732 m
.87232 .2773 L
s
.008 w
.87232 .2773 Mdot
.016 w
.87232 .2773 m
.87377 .27726 L
s
1 .365 0 r
.008 w
.87377 .27726 Mdot
.016 w
.87377 .27726 m
.87508 .27723 L
s
.008 w
.87508 .27723 Mdot
.016 w
.87508 .27723 m
.87625 .27724 L
s
1 .364 0 r
.008 w
.87625 .27724 Mdot
.016 w
.87625 .27724 m
.87737 .27732 L
s
1 .363 0 r
.008 w
.87737 .27732 Mdot
.016 w
.87737 .27732 m
.87846 .2775 L
s
.008 w
.87846 .2775 Mdot
.016 w
.87846 .2775 m
.87949 .27778 L
s
1 .362 0 r
.008 w
.87949 .27778 Mdot
.016 w
.87949 .27778 m
.88055 .27814 L
s
.008 w
.88055 .27814 Mdot
.016 w
.88055 .27814 m
.88154 .27856 L
s
1 .361 0 r
.008 w
.88154 .27856 Mdot
.016 w
.88154 .27856 m
.88257 .27902 L
s
1 .36 0 r
.008 w
.88257 .27902 Mdot
.016 w
.88257 .27902 m
.88358 .2795 L
s
.008 w
.88358 .2795 Mdot
.016 w
.88358 .2795 m
.88457 .28002 L
s
1 .359 0 r
.008 w
.88457 .28002 Mdot
.016 w
.88457 .28002 m
.88546 .28056 L
s
1 .358 0 r
.008 w
.88546 .28056 Mdot
.016 w
.88546 .28056 m
.88625 .28111 L
s
.008 w
.88625 .28111 Mdot
.016 w
.88625 .28111 m
.88689 .28167 L
s
1 .357 0 r
.008 w
.88689 .28167 Mdot
.016 w
.88689 .28167 m
.88739 .28226 L
s
.008 w
.88739 .28226 Mdot
.016 w
.88739 .28226 m
.88776 .28287 L
s
1 .356 0 r
.008 w
.88776 .28287 Mdot
.016 w
.88776 .28287 m
.88802 .28349 L
s
1 .355 0 r
.008 w
.88802 .28349 Mdot
.016 w
.88802 .28349 m
.88819 .28412 L
s
.008 w
.88819 .28412 Mdot
.016 w
.88819 .28412 m
.88831 .28475 L
s
1 .354 0 r
.008 w
.88831 .28475 Mdot
.016 w
.88831 .28475 m
.88843 .28539 L
s
1 .353 0 r
.008 w
.88843 .28539 Mdot
.016 w
.88843 .28539 m
.88857 .28599 L
s
.008 w
.88857 .28599 Mdot
.016 w
.88857 .28599 m
.88872 .28658 L
s
1 .352 0 r
.008 w
.88872 .28658 Mdot
.016 w
.88872 .28658 m
.88887 .28712 L
s
.008 w
.88887 .28712 Mdot
.016 w
.88887 .28712 m
.88905 .2876 L
s
1 .351 0 r
.008 w
.88905 .2876 Mdot
.016 w
.88905 .2876 m
.88923 .28798 L
s
1 .35 0 r
.008 w
.88923 .28798 Mdot
.016 w
.88923 .28798 m
.88939 .28826 L
s
.008 w
.88939 .28826 Mdot
.016 w
.88939 .28826 m
.8895 .28844 L
s
1 .349 0 r
.008 w
.8895 .28844 Mdot
.016 w
.8895 .28844 m
.88953 .28853 L
s
.008 w
.88953 .28853 Mdot
.016 w
.88953 .28853 m
.88948 .28855 L
s
1 .348 0 r
.008 w
.88948 .28855 Mdot
.016 w
.88948 .28855 m
.88933 .28855 L
s
1 .347 0 r
.008 w
.88933 .28855 Mdot
.016 w
.88933 .28855 m
.88908 .28857 L
s
.008 w
.88908 .28857 Mdot
.016 w
.88908 .28857 m
.88875 .28866 L
s
1 .346 0 r
.008 w
.88875 .28866 Mdot
.016 w
.88875 .28866 m
.88836 .28882 L
s
1 .345 0 r
.008 w
.88836 .28882 Mdot
.016 w
.88836 .28882 m
.88798 .28904 L
s
.008 w
.88798 .28904 Mdot
.016 w
.88798 .28904 m
.88761 .28929 L
s
1 .344 0 r
.008 w
.88761 .28929 Mdot
.016 w
.88761 .28929 m
.8873 .28955 L
s
.008 w
.8873 .28955 Mdot
.016 w
.8873 .28955 m
.88705 .28983 L
s
1 .343 0 r
.008 w
.88705 .28983 Mdot
.016 w
.88705 .28983 m
.88685 .29012 L
s
1 .342 0 r
.008 w
.88685 .29012 Mdot
.016 w
.88685 .29012 m
.88671 .29044 L
s
.008 w
.88671 .29044 Mdot
.016 w
.88671 .29044 m
.8866 .29073 L
s
1 .341 0 r
.008 w
.8866 .29073 Mdot
.016 w
.8866 .29073 m
.88656 .29099 L
s
.008 w
.88656 .29099 Mdot
.016 w
.88656 .29099 m
.88658 .2912 L
s
1 .34 0 r
.008 w
.88658 .2912 Mdot
.016 w
.88658 .2912 m
.88668 .29133 L
s
1 .339 0 r
.008 w
.88668 .29133 Mdot
.016 w
.88668 .29133 m
.88683 .29132 L
s
.008 w
.88683 .29132 Mdot
.016 w
.88683 .29132 m
.88704 .29117 L
s
1 .338 0 r
.008 w
.88704 .29117 Mdot
.016 w
.88704 .29117 m
.88725 .29086 L
s
1 .337 0 r
.008 w
.88725 .29086 Mdot
.016 w
.88725 .29086 m
.88744 .29045 L
s
.008 w
.88744 .29045 Mdot
.016 w
.88744 .29045 m
.88753 .28991 L
s
1 .336 0 r
.008 w
.88753 .28991 Mdot
.016 w
.88753 .28991 m
.88749 .28925 L
s
.008 w
.88749 .28925 Mdot
.016 w
.88749 .28925 m
.88731 .28847 L
s
1 .335 0 r
.008 w
.88731 .28847 Mdot
.016 w
.88731 .28847 m
.88697 .2875 L
s
1 .334 0 r
.008 w
.88697 .2875 Mdot
.016 w
.88697 .2875 m
.88648 .28629 L
s
.008 w
.88648 .28629 Mdot
.016 w
.88648 .28629 m
.88586 .28479 L
s
1 .333 0 r
.008 w
.88586 .28479 Mdot
.016 w
.88586 .28479 m
.88511 .28309 L
s
.008 w
.88511 .28309 Mdot
.016 w
.88511 .28309 m
.88415 .28096 L
s
1 .332 0 r
.008 w
.88415 .28096 Mdot
.016 w
.88415 .28096 m
.88293 .27856 L
s
1 .331 0 r
.008 w
.88293 .27856 Mdot
.016 w
.88293 .27856 m
.88149 .27578 L
s
.008 w
.88149 .27578 Mdot
.016 w
.88149 .27578 m
.87983 .27279 L
s
1 .33 0 r
.008 w
.87983 .27279 Mdot
.016 w
.87983 .27279 m
.87791 .2695 L
s
1 .329 0 r
.008 w
.87791 .2695 Mdot
.016 w
.87791 .2695 m
.87595 .26617 L
s
.008 w
.87595 .26617 Mdot
.016 w
.87595 .26617 m
.87381 .2628 L
s
1 .328 0 r
.008 w
.87381 .2628 Mdot
.016 w
.87381 .2628 m
.87177 .25951 L
s
.008 w
.87177 .25951 Mdot
.016 w
.87177 .25951 m
.86986 .25629 L
s
1 .327 0 r
.008 w
.86986 .25629 Mdot
.016 w
.86986 .25629 m
.86813 .25353 L
s
1 .326 0 r
.008 w
.86813 .25353 Mdot
.016 w
.86813 .25353 m
.86655 .25098 L
s
.008 w
.86655 .25098 Mdot
.016 w
.86655 .25098 m
.86513 .2486 L
s
1 .325 0 r
.008 w
.86513 .2486 Mdot
.016 w
.86513 .2486 m
.86405 .24687 L
s
1 .324 0 r
.008 w
.86405 .24687 Mdot
.016 w
.86405 .24687 m
.86318 .2454 L
s
.008 w
.86318 .2454 Mdot
.016 w
.86318 .2454 m
.86253 .24419 L
s
1 .323 0 r
.008 w
.86253 .24419 Mdot
.016 w
.86253 .24419 m
.86213 .24342 L
s
.008 w
.86213 .24342 Mdot
.016 w
.86213 .24342 m
.86196 .24293 L
s
1 .322 0 r
.008 w
.86196 .24293 Mdot
.016 w
.86196 .24293 m
.86199 .24272 L
s
1 .321 0 r
.008 w
.86199 .24272 Mdot
.016 w
.86199 .24272 m
.86218 .24273 L
s
.008 w
.86218 .24273 Mdot
.016 w
.86218 .24273 m
.86247 .24288 L
s
1 .32 0 r
.008 w
.86247 .24288 Mdot
.016 w
.86247 .24288 m
.8628 .24309 L
s
.008 w
.8628 .24309 Mdot
.016 w
.8628 .24309 m
.86312 .24331 L
s
1 .319 0 r
.008 w
.86312 .24331 Mdot
.016 w
.86312 .24331 m
.86341 .24351 L
s
1 .318 0 r
.008 w
.86341 .24351 Mdot
.016 w
.86341 .24351 m
.86365 .24366 L
s
.008 w
.86365 .24366 Mdot
.016 w
.86365 .24366 m
.86384 .24373 L
s
1 .317 0 r
.008 w
.86384 .24373 Mdot
.016 w
.86384 .24373 m
.86399 .24375 L
s
1 .316 0 r
.008 w
.86399 .24375 Mdot
.016 w
.86399 .24375 m
.86414 .24374 L
s
.008 w
.86414 .24374 Mdot
.016 w
.86414 .24374 m
.86424 .24375 L
s
1 .315 0 r
.008 w
.86424 .24375 Mdot
.016 w
.86424 .24375 m
.86429 .24379 L
s
.008 w
.86429 .24379 Mdot
.016 w
.86429 .24379 m
.86425 .24385 L
s
1 .314 0 r
.008 w
.86425 .24385 Mdot
.016 w
.86425 .24385 m
.86411 .24391 L
s
1 .313 0 r
.008 w
.86411 .24391 Mdot
.016 w
.86411 .24391 m
.86385 .24393 L
s
.008 w
.86385 .24393 Mdot
.016 w
.86385 .24393 m
.86348 .24391 L
s
1 .312 0 r
.008 w
.86348 .24391 Mdot
.016 w
.86348 .24391 m
.86298 .24381 L
s
.008 w
.86298 .24381 Mdot
.016 w
.86298 .24381 m
.86237 .24365 L
s
1 .311 0 r
.008 w
.86237 .24365 Mdot
.016 w
.86237 .24365 m
.86167 .2434 L
s
1 .31 0 r
.008 w
.86167 .2434 Mdot
.016 w
.86167 .2434 m
.86092 .24309 L
s
.008 w
.86092 .24309 Mdot
.016 w
.86092 .24309 m
.86019 .24273 L
s
1 .309 0 r
.008 w
.86019 .24273 Mdot
.016 w
.86019 .24273 m
.85943 .24233 L
s
1 .308 0 r
.008 w
.85943 .24233 Mdot
.016 w
.85943 .24233 m
.85867 .24191 L
s
.008 w
.85867 .24191 Mdot
.016 w
.85867 .24191 m
.85793 .24149 L
s
1 .307 0 r
.008 w
.85793 .24149 Mdot
.016 w
.85793 .24149 m
.85727 .24107 L
s
.008 w
.85727 .24107 Mdot
.016 w
.85727 .24107 m
.85671 .24064 L
s
1 .306 0 r
.008 w
.85671 .24064 Mdot
.016 w
.85671 .24064 m
.85628 .24023 L
s
1 .305 0 r
.008 w
.85628 .24023 Mdot
.016 w
.85628 .24023 m
.85599 .23984 L
s
.008 w
.85599 .23984 Mdot
.016 w
.85599 .23984 m
.85582 .23953 L
s
1 .304 0 r
.008 w
.85582 .23953 Mdot
.016 w
.85582 .23953 m
.85576 .23932 L
s
.008 w
.85576 .23932 Mdot
.016 w
.85576 .23932 m
.8558 .23925 L
s
1 .303 0 r
.008 w
.8558 .23925 Mdot
.016 w
.8558 .23925 m
.85588 .2393 L
s
1 .302 0 r
.008 w
.85588 .2393 Mdot
.016 w
.85588 .2393 m
.85597 .23949 L
s
.008 w
.85597 .23949 Mdot
.016 w
.85597 .23949 m
.85605 .23978 L
s
1 .301 0 r
.008 w
.85605 .23978 Mdot
.016 w
.85605 .23978 m
.85613 .24015 L
s
1 .3 0 r
.008 w
.85613 .24015 Mdot
.016 w
.85613 .24015 m
.8562 .24057 L
s
.008 w
.8562 .24057 Mdot
.016 w
.8562 .24057 m
.85625 .24103 L
s
1 .299 0 r
.008 w
.85625 .24103 Mdot
.016 w
.85625 .24103 m
.85627 .24152 L
s
.008 w
.85627 .24152 Mdot
.016 w
.85627 .24152 m
.85626 .24198 L
s
1 .298 0 r
.008 w
.85626 .24198 Mdot
.016 w
.85626 .24198 m
.85624 .24244 L
s
1 .297 0 r
.008 w
.85624 .24244 Mdot
.016 w
.85624 .24244 m
.85622 .24288 L
s
.008 w
.85622 .24288 Mdot
.016 w
.85622 .24288 m
.85619 .24328 L
s
1 .296 0 r
.008 w
.85619 .24328 Mdot
.016 w
.85619 .24328 m
.85613 .24358 L
s
1 .295 0 r
.008 w
.85613 .24358 Mdot
.016 w
.85613 .24358 m
.85603 .24376 L
s
.008 w
.85603 .24376 Mdot
.016 w
.85603 .24376 m
.85588 .24377 L
s
1 .294 0 r
.008 w
.85588 .24377 Mdot
.016 w
.85588 .24377 m
.85563 .24359 L
s
.008 w
.85563 .24359 Mdot
.016 w
.85563 .24359 m
.85534 .24318 L
s
1 .293 0 r
.008 w
.85534 .24318 Mdot
.016 w
.85534 .24318 m
.8549 .24254 L
s
1 .292 0 r
.008 w
.8549 .24254 Mdot
.016 w
.8549 .24254 m
.85417 .24164 L
s
.008 w
.85417 .24164 Mdot
.016 w
.85417 .24164 m
.85351 .24054 L
s
1 .291 0 r
.008 w
.85351 .24054 Mdot
.016 w
.85351 .24054 m
.85274 .23918 L
s
.008 w
.85274 .23918 Mdot
.016 w
.85274 .23918 m
.85187 .23751 L
s
1 .29 0 r
.008 w
.85187 .23751 Mdot
.016 w
.85187 .23751 m
.85091 .23562 L
s
1 .289 0 r
.008 w
.85091 .23562 Mdot
.016 w
.85091 .23562 m
.84979 .23333 L
s
.008 w
.84979 .23333 Mdot
.016 w
.84979 .23333 m
.84854 .23102 L
s
1 .288 0 r
.008 w
.84854 .23102 Mdot
.016 w
.84854 .23102 m
.84713 .22829 L
s
1 .287 0 r
.008 w
.84713 .22829 Mdot
.016 w
.84713 .22829 m
.84556 .22542 L
s
.008 w
.84556 .22542 Mdot
.016 w
.84556 .22542 m
.84382 .22223 L
s
1 .286 0 r
.008 w
.84382 .22223 Mdot
.016 w
.84382 .22223 m
.84194 .21903 L
s
.008 w
.84194 .21903 Mdot
.016 w
.84194 .21903 m
.83992 .21563 L
s
1 .285 0 r
.008 w
.83992 .21563 Mdot
.016 w
.83992 .21563 m
.83777 .21199 L
s
1 .284 0 r
.008 w
.83777 .21199 Mdot
.016 w
.83777 .21199 m
.83546 .20822 L
s
.008 w
.83546 .20822 Mdot
.016 w
.83546 .20822 m
.83291 .20435 L
s
1 .283 0 r
.008 w
.83291 .20435 Mdot
.016 w
.83291 .20435 m
.83025 .19999 L
s
.008 w
.83025 .19999 Mdot
.016 w
.83025 .19999 m
.82742 .19609 L
s
1 .282 0 r
.008 w
.82742 .19609 Mdot
.016 w
.82742 .19609 m
.82438 .19169 L
s
1 .281 0 r
.008 w
.82438 .19169 Mdot
.016 w
.82438 .19169 m
.82116 .18717 L
s
.008 w
.82116 .18717 Mdot
.016 w
.82116 .18717 m
.81791 .18282 L
s
1 .28 0 r
.008 w
.81791 .18282 Mdot
.016 w
.81791 .18282 m
.81461 .1782 L
s
1 .279 0 r
.008 w
.81461 .1782 Mdot
.016 w
.81461 .1782 m
.81118 .17352 L
s
.008 w
.81118 .17352 Mdot
.016 w
.81118 .17352 m
.80779 .16891 L
s
1 .278 0 r
.008 w
.80779 .16891 Mdot
.016 w
.80779 .16891 m
.80444 .16457 L
s
.008 w
.80444 .16457 Mdot
.016 w
.80444 .16457 m
.80091 .15977 L
s
1 .277 0 r
.008 w
.80091 .15977 Mdot
.016 w
.80091 .15977 m
.79763 .1558 L
s
1 .276 0 r
.008 w
.79763 .1558 Mdot
.016 w
.79763 .1558 m
.79419 .15167 L
s
.008 w
.79419 .15167 Mdot
.016 w
.79419 .15167 m
.79078 .14786 L
s
1 .275 0 r
.008 w
.79078 .14786 Mdot
.016 w
.79078 .14786 m
.78725 .14438 L
s
.008 w
.78725 .14438 Mdot
.016 w
.78725 .14438 m
.78406 .14135 L
s
1 .274 0 r
.008 w
.78406 .14135 Mdot
.016 w
.78406 .14135 m
.78077 .13859 L
s
1 .273 0 r
.008 w
.78077 .13859 Mdot
.016 w
.78077 .13859 m
.77764 .13604 L
s
.008 w
.77764 .13604 Mdot
.016 w
.77764 .13604 m
.77466 .13405 L
s
1 .272 0 r
.008 w
.77466 .13405 Mdot
.016 w
.77466 .13405 m
.77169 .1322 L
s
1 .271 0 r
.008 w
.77169 .1322 Mdot
.016 w
.77169 .1322 m
.76854 .13051 L
s
.008 w
.76854 .13051 Mdot
.016 w
.76854 .13051 m
.7658 .12897 L
s
1 .27 0 r
.008 w
.7658 .12897 Mdot
.016 w
.7658 .12897 m
.76293 .12749 L
s
.008 w
.76293 .12749 Mdot
.016 w
.76293 .12749 m
.7599 .12613 L
s
1 .269 0 r
.008 w
.7599 .12613 Mdot
.016 w
.7599 .12613 m
.75695 .12474 L
s
1 .268 0 r
.008 w
.75695 .12474 Mdot
.016 w
.75695 .12474 m
.75375 .12327 L
s
.008 w
.75375 .12327 Mdot
.016 w
.75375 .12327 m
.75062 .12178 L
s
1 .267 0 r
.008 w
.75062 .12178 Mdot
.016 w
.75062 .12178 m
.74706 .12016 L
s
.008 w
.74706 .12016 Mdot
.016 w
.74706 .12016 m
.74354 .11845 L
s
1 .266 0 r
.008 w
.74354 .11845 Mdot
.016 w
.74354 .11845 m
.73949 .11656 L
s
1 .265 0 r
.008 w
.73949 .11656 Mdot
.016 w
.73949 .11656 m
.73545 .11469 L
s
.008 w
.73545 .11469 Mdot
.016 w
.73545 .11469 m
.73103 .11264 L
s
1 .264 0 r
.008 w
.73103 .11264 Mdot
.016 w
.73103 .11264 m
.7259 .11059 L
s
1 .263 0 r
.008 w
.7259 .11059 Mdot
.016 w
.7259 .11059 m
.72143 .10861 L
s
.008 w
.72143 .10861 Mdot
.016 w
.72143 .10861 m
.71609 .10653 L
s
1 .262 0 r
.008 w
.71609 .10653 Mdot
.016 w
.71609 .10653 m
.71118 .10453 L
s
.008 w
.71118 .10453 Mdot
.016 w
.71118 .10453 m
.70575 .10243 L
s
1 .261 0 r
.008 w
.70575 .10243 Mdot
.016 w
.70575 .10243 m
.70078 .10048 L
s
1 .26 0 r
.008 w
.70078 .10048 Mdot
.016 w
.70078 .10048 m
.69564 .09848 L
s
.008 w
.69564 .09848 Mdot
.016 w
.69564 .09848 m
.69063 .09654 L
s
1 .259 0 r
.008 w
.69063 .09654 Mdot
.016 w
.69063 .09654 m
.68597 .0946 L
s
1 .258 0 r
.008 w
.68597 .0946 Mdot
.016 w
.68597 .0946 m
.68151 .09289 L
s
.008 w
.68151 .09289 Mdot
.016 w
.68151 .09289 m
.6773 .09116 L
s
1 .257 0 r
.008 w
.6773 .09116 Mdot
.016 w
.6773 .09116 m
.67317 .0896 L
s
.008 w
.67317 .0896 Mdot
.016 w
.67317 .0896 m
.66971 .08811 L
s
1 .256 0 r
.008 w
.66971 .08811 Mdot
.016 w
.66971 .08811 m
.66631 .08674 L
s
1 .255 0 r
.008 w
.66631 .08674 Mdot
.016 w
.66631 .08674 m
.66298 .08544 L
s
.008 w
.66298 .08544 Mdot
.016 w
.66298 .08544 m
.66022 .08435 L
s
1 .254 0 r
.008 w
.66022 .08435 Mdot
.016 w
.66022 .08435 m
.65754 .08333 L
s
.008 w
.65754 .08333 Mdot
.016 w
.65754 .08333 m
.65495 .08237 L
s
1 .253 0 r
.008 w
.65495 .08237 Mdot
.016 w
.65495 .08237 m
.65262 .08148 L
s
1 .252 0 r
.008 w
.65262 .08148 Mdot
.016 w
.65262 .08148 m
.65028 .08062 L
s
.008 w
.65028 .08062 Mdot
.016 w
.65028 .08062 m
.64786 .07975 L
s
1 .251 0 r
.008 w
.64786 .07975 Mdot
.016 w
.64786 .07975 m
.64552 .07887 L
s
1 .25 0 r
.008 w
.64552 .07887 Mdot
.016 w
.64552 .07887 m
.64283 .07789 L
s
.008 w
.64283 .07789 Mdot
.016 w
.64283 .07789 m
.64019 .07682 L
s
1 .249 0 r
.008 w
.64019 .07682 Mdot
.016 w
.64019 .07682 m
.63723 .0757 L
s
.008 w
.63723 .0757 Mdot
.016 w
.63723 .0757 m
.63396 .0745 L
s
1 .248 0 r
.008 w
.63396 .0745 Mdot
.016 w
.63396 .0745 m
.63066 .07324 L
s
1 .247 0 r
.008 w
.63066 .07324 Mdot
.016 w
.63066 .07324 m
.62697 .07192 L
s
.008 w
.62697 .07192 Mdot
.016 w
.62697 .07192 m
.62336 .07051 L
s
1 .246 0 r
.008 w
.62336 .07051 Mdot
.016 w
.62336 .07051 m
.61938 .06906 L
s
.008 w
.61938 .06906 Mdot
.016 w
.61938 .06906 m
.61566 .06763 L
s
1 .245 0 r
.008 w
.61566 .06763 Mdot
.016 w
.61566 .06763 m
.61178 .06618 L
s
1 .244 0 r
.008 w
.61178 .06618 Mdot
.016 w
.61178 .06618 m
.60789 .06476 L
s
.008 w
.60789 .06476 Mdot
.016 w
.60789 .06476 m
.60399 .06336 L
s
1 .243 0 r
.008 w
.60399 .06336 Mdot
.016 w
.60399 .06336 m
.60037 .062 L
s
1 .242 0 r
.008 w
.60037 .062 Mdot
.016 w
.60037 .062 m
.59674 .0608 L
s
.008 w
.59674 .0608 Mdot
.016 w
.59674 .0608 m
.59316 .05968 L
s
1 .241 0 r
.008 w
.59316 .05968 Mdot
.016 w
.59316 .05968 m
.58992 .05865 L
s
.008 w
.58992 .05865 Mdot
.016 w
.58992 .05865 m
.58679 .05778 L
s
1 .24 0 r
.008 w
.58679 .05778 Mdot
.016 w
.58679 .05778 m
.58372 .057 L
s
1 .239 0 r
.008 w
.58372 .057 Mdot
.016 w
.58372 .057 m
.58088 .05633 L
s
.008 w
.58088 .05633 Mdot
.016 w
.58088 .05633 m
.57796 .0558 L
s
1 .238 0 r
.008 w
.57796 .0558 Mdot
.016 w
.57796 .0558 m
.57523 .0554 L
s
.008 w
.57523 .0554 Mdot
.016 w
.57523 .0554 m
.5724 .05514 L
s
1 .237 0 r
.008 w
.5724 .05514 Mdot
.016 w
.5724 .05514 m
.56944 .05499 L
s
1 .236 0 r
.008 w
.56944 .05499 Mdot
.016 w
.56944 .05499 m
.56659 .05493 L
s
.008 w
.56659 .05493 Mdot
.016 w
.56659 .05493 m
.56341 .05493 L
s
1 .235 0 r
.008 w
.56341 .05493 Mdot
.016 w
.56341 .05493 m
.56019 .05495 L
s
1 .234 0 r
.008 w
.56019 .05495 Mdot
.016 w
.56019 .05495 m
.55691 .05494 L
s
.008 w
.55691 .05494 Mdot
.016 w
.55691 .05494 m
.55316 .05488 L
s
1 .233 0 r
.008 w
.55316 .05488 Mdot
.016 w
.55316 .05488 m
.54972 .05476 L
s
.008 w
.54972 .05476 Mdot
.016 w
.54972 .05476 m
.54595 .05457 L
s
1 .232 0 r
.008 w
.54595 .05457 Mdot
.016 w
.54595 .05457 m
.54162 .05434 L
s
1 .231 0 r
.008 w
.54162 .05434 Mdot
.016 w
.54162 .05434 m
.53797 .05409 L
s
.008 w
.53797 .05409 Mdot
.016 w
.53797 .05409 m
.53379 .05383 L
s
1 .23 0 r
.008 w
.53379 .05383 Mdot
.016 w
.53379 .05383 m
.52953 .05357 L
s
1 .229 0 r
.008 w
.52953 .05357 Mdot
.016 w
.52953 .05357 m
.52515 .05334 L
s
.008 w
.52515 .05334 Mdot
.016 w
.52515 .05334 m
.5207 .05313 L
s
1 .228 0 r
.008 w
.5207 .05313 Mdot
.016 w
.5207 .05313 m
.51631 .05294 L
s
.008 w
.51631 .05294 Mdot
.016 w
.51631 .05294 m
.51153 .05278 L
s
1 .227 0 r
.008 w
.51153 .05278 Mdot
.016 w
.51153 .05278 m
.50736 .05265 L
s
1 .226 0 r
.008 w
.50736 .05265 Mdot
.016 w
.50736 .05265 m
.50264 .05255 L
s
.008 w
.50264 .05255 Mdot
.016 w
.50264 .05255 m
.49839 .05248 L
s
1 .225 0 r
.008 w
.49839 .05248 Mdot
.016 w
.49839 .05248 m
.49461 .05244 L
s
.008 w
.49461 .05244 Mdot
.016 w
.49461 .05244 m
.49059 .05243 L
s
1 .224 0 r
.008 w
.49059 .05243 Mdot
.016 w
.49059 .05243 m
.48731 .05246 L
s
1 .223 0 r
.008 w
.48731 .05246 Mdot
.016 w
.48731 .05246 m
.48399 .0525 L
s
.008 w
.48399 .0525 Mdot
.016 w
.48399 .0525 m
.48158 .05255 L
s
1 .222 0 r
.008 w
.48158 .05255 Mdot
.016 w
.48158 .05255 m
.47948 .0526 L
s
1 .221 0 r
.008 w
.47948 .0526 Mdot
.016 w
.47948 .0526 m
.47767 .05262 L
s
.008 w
.47767 .05262 Mdot
.016 w
.47767 .05262 m
.47628 .05262 L
s
1 .22 0 r
.008 w
.47628 .05262 Mdot
.016 w
.47628 .05262 m
.47511 .05259 L
s
.008 w
.47511 .05259 Mdot
.016 w
.47511 .05259 m
.4741 .05254 L
s
1 .219 0 r
.008 w
.4741 .05254 Mdot
.016 w
.4741 .05254 m
.4732 .05249 L
s
1 .218 0 r
.008 w
.4732 .05249 Mdot
.016 w
.4732 .05249 m
.47225 .05243 L
s
.008 w
.47225 .05243 Mdot
.016 w
.47225 .05243 m
.4711 .05239 L
s
1 .217 0 r
.008 w
.4711 .05239 Mdot
.016 w
.4711 .05239 m
.46959 .05235 L
s
.008 w
.46959 .05235 Mdot
.016 w
.46959 .05235 m
.46781 .0523 L
s
1 .216 0 r
.008 w
.46781 .0523 Mdot
.016 w
.46781 .0523 m
.46549 .05223 L
s
1 .215 0 r
.008 w
.46549 .05223 Mdot
.016 w
.46549 .05223 m
.46255 .05215 L
s
.008 w
.46255 .05215 Mdot
.016 w
.46255 .05215 m
.45948 .05205 L
s
1 .214 0 r
.008 w
.45948 .05205 Mdot
.016 w
.45948 .05205 m
.45581 .05194 L
s
1 .213 0 r
.008 w
.45581 .05194 Mdot
.016 w
.45581 .05194 m
.45192 .05182 L
s
.008 w
.45192 .05182 Mdot
.016 w
.45192 .05182 m
.44795 .05169 L
s
1 .212 0 r
.008 w
.44795 .05169 Mdot
.016 w
.44795 .05169 m
.44401 .05154 L
s
.008 w
.44401 .05154 Mdot
.016 w
.44401 .05154 m
.4402 .05141 L
s
1 .211 0 r
.008 w
.4402 .05141 Mdot
.016 w
.4402 .05141 m
.43661 .0513 L
s
1 .21 0 r
.008 w
.43661 .0513 Mdot
.016 w
.43661 .0513 m
.43372 .05122 L
s
.008 w
.43372 .05122 Mdot
.016 w
.43372 .05122 m
.43073 .05117 L
s
1 .209 0 r
.008 w
.43073 .05117 Mdot
.016 w
.43073 .05117 m
.4285 .05115 L
s
.008 w
.4285 .05115 Mdot
.016 w
.4285 .05115 m
.42657 .05114 L
s
1 .208 0 r
.008 w
.42657 .05114 Mdot
.016 w
.42657 .05114 m
.425 .05112 L
s
1 .207 0 r
.008 w
.425 .05112 Mdot
.016 w
.425 .05112 m
.42385 .05109 L
s
.008 w
.42385 .05109 Mdot
.016 w
.42385 .05109 m
.42311 .05108 L
s
1 .206 0 r
.008 w
.42311 .05108 Mdot
.016 w
.42311 .05108 m
.42266 .05109 L
s
1 .205 0 r
.008 w
.42266 .05109 Mdot
.016 w
.42266 .05109 m
.42244 .05114 L
s
.008 w
.42244 .05114 Mdot
.016 w
.42244 .05114 m
.42238 .05126 L
s
1 .204 0 r
.008 w
.42238 .05126 Mdot
.016 w
.42238 .05126 m
.4224 .05143 L
s
.008 w
.4224 .05143 Mdot
.016 w
.4224 .05143 m
.42244 .05162 L
s
1 .203 0 r
.008 w
.42244 .05162 Mdot
.016 w
.42244 .05162 m
.42241 .05186 L
s
1 .202 0 r
.008 w
.42241 .05186 Mdot
.016 w
.42241 .05186 m
.4223 .05211 L
s
.008 w
.4223 .05211 Mdot
.016 w
.4223 .05211 m
.42214 .05238 L
s
1 .201 0 r
.008 w
.42214 .05238 Mdot
.016 w
.42214 .05238 m
.42196 .05266 L
s
1 .2 0 r
.008 w
.42196 .05266 Mdot
.016 w
.42196 .05266 m
.42177 .05295 L
s
.008 w
.42177 .05295 Mdot
.016 w
.42177 .05295 m
.42156 .05327 L
s
1 .199 0 r
.008 w
.42156 .05327 Mdot
.016 w
.42156 .05327 m
.42128 .05358 L
s
.008 w
.42128 .05358 Mdot
.016 w
.42128 .05358 m
.42091 .05391 L
s
1 .198 0 r
.008 w
.42091 .05391 Mdot
.016 w
.42091 .05391 m
.42039 .05418 L
s
1 .197 0 r
.008 w
.42039 .05418 Mdot
.016 w
.42039 .05418 m
.41971 .05446 L
s
.008 w
.41971 .05446 Mdot
.016 w
.41971 .05446 m
.41886 .05471 L
s
1 .196 0 r
.008 w
.41886 .05471 Mdot
.016 w
.41886 .05471 m
.41789 .05484 L
s
.008 w
.41789 .05484 Mdot
.016 w
.41789 .05484 m
.41684 .05489 L
s
1 .195 0 r
.008 w
.41684 .05489 Mdot
.016 w
.41684 .05489 m
.41573 .05485 L
s
1 .194 0 r
.008 w
.41573 .05485 Mdot
.016 w
.41573 .05485 m
.41461 .05476 L
s
.008 w
.41461 .05476 Mdot
.016 w
.41461 .05476 m
.41353 .05465 L
s
1 .193 0 r
.008 w
.41353 .05465 Mdot
.016 w
.41353 .05465 m
.41247 .05453 L
s
1 .192 0 r
.008 w
.41247 .05453 Mdot
.016 w
.41247 .05453 m
.41144 .05443 L
s
.008 w
.41144 .05443 Mdot
.016 w
.41144 .05443 m
.41045 .05433 L
s
1 .191 0 r
.008 w
.41045 .05433 Mdot
.016 w
.41045 .05433 m
.40955 .05427 L
s
.008 w
.40955 .05427 Mdot
.016 w
.40955 .05427 m
.40875 .0542 L
s
1 .19 0 r
.008 w
.40875 .0542 Mdot
.016 w
.40875 .0542 m
.40806 .05415 L
s
1 .189 0 r
.008 w
.40806 .05415 Mdot
.016 w
.40806 .05415 m
.40752 .05413 L
s
.008 w
.40752 .05413 Mdot
.016 w
.40752 .05413 m
.40712 .05413 L
s
1 .188 0 r
.008 w
.40712 .05413 Mdot
.016 w
.40712 .05413 m
.40684 .05414 L
s
.008 w
.40684 .05414 Mdot
.016 w
.40684 .05414 m
.40664 .0542 L
s
1 .187 0 r
.008 w
.40664 .0542 Mdot
.016 w
.40664 .0542 m
.40651 .05427 L
s
1 .186 0 r
.008 w
.40651 .05427 Mdot
.016 w
.40651 .05427 m
.4064 .05436 L
s
.008 w
.4064 .05436 Mdot
.016 w
.4064 .05436 m
.4063 .05445 L
s
1 .185 0 r
.008 w
.4063 .05445 Mdot
.016 w
.4063 .05445 m
.4062 .05454 L
s
1 .184 0 r
.008 w
.4062 .05454 Mdot
.016 w
.4062 .05454 m
.40613 .05462 L
s
.008 w
.40613 .05462 Mdot
.016 w
.40613 .05462 m
.40609 .05467 L
s
1 .183 0 r
.008 w
.40609 .05467 Mdot
.016 w
.40609 .05467 m
.40608 .05471 L
s
.008 w
.40608 .05471 Mdot
.016 w
.40608 .05471 m
.40609 .05473 L
s
1 .182 0 r
.008 w
.40609 .05473 Mdot
.016 w
.40609 .05473 m
.40613 .05473 L
s
1 .181 0 r
.008 w
.40613 .05473 Mdot
.016 w
.40613 .05473 m
.40617 .0547 L
s
.008 w
.40617 .0547 Mdot
.016 w
.40617 .0547 m
.4062 .05468 L
s
1 .18 0 r
.008 w
.4062 .05468 Mdot
.016 w
.4062 .05468 m
.40621 .05466 L
s
.008 w
.40621 .05466 Mdot
.016 w
.40621 .05466 m
.40622 .05466 L
s
1 .179 0 r
.008 w
.40622 .05466 Mdot
.016 w
.40622 .05466 m
.40628 .05466 L
s
1 .178 0 r
.008 w
.40628 .05466 Mdot
.016 w
.40628 .05466 m
.40639 .05467 L
s
.008 w
.40639 .05467 Mdot
.016 w
.40639 .05467 m
.40655 .05467 L
s
1 .177 0 r
.008 w
.40655 .05467 Mdot
.016 w
.40655 .05467 m
.40673 .05468 L
s
1 .176 0 r
.008 w
.40673 .05468 Mdot
.016 w
.40673 .05468 m
.40688 .05468 L
s
.008 w
.40688 .05468 Mdot
.016 w
.40688 .05468 m
.40699 .05465 L
s
1 .175 0 r
.008 w
.40699 .05465 Mdot
.016 w
.40699 .05465 m
.40703 .0546 L
s
.008 w
.40703 .0546 Mdot
.016 w
.40703 .0546 m
.40694 .05452 L
s
1 .174 0 r
.008 w
.40694 .05452 Mdot
.016 w
.40694 .05452 m
.40664 .05443 L
s
1 .173 0 r
.008 w
.40664 .05443 Mdot
.016 w
.40664 .05443 m
.40604 .05435 L
s
.008 w
.40604 .05435 Mdot
.016 w
.40604 .05435 m
.40505 .05431 L
s
1 .172 0 r
.008 w
.40505 .05431 Mdot
.016 w
.40505 .05431 m
.40361 .05432 L
s
1 .171 0 r
.008 w
.40361 .05432 Mdot
.016 w
.40361 .05432 m
.40162 .0544 L
s
.008 w
.40162 .0544 Mdot
.016 w
.40162 .0544 m
.39931 .05456 L
s
1 .17 0 r
.008 w
.39931 .05456 Mdot
.016 w
.39931 .05456 m
.39654 .05479 L
s
.008 w
.39654 .05479 Mdot
.016 w
.39654 .05479 m
.39312 .05512 L
s
1 .169 0 r
.008 w
.39312 .05512 Mdot
.016 w
.39312 .05512 m
.3897 .05555 L
s
1 .168 0 r
.008 w
.3897 .05555 Mdot
.016 w
.3897 .05555 m
.38557 .05611 L
s
.008 w
.38557 .05611 Mdot
.016 w
.38557 .05611 m
.38185 .05678 L
s
1 .167 0 r
.008 w
.38185 .05678 Mdot
.016 w
.38185 .05678 m
.37767 .05757 L
s
.008 w
.37767 .05757 Mdot
.016 w
.37767 .05757 m
.37372 .05851 L
s
1 .166 0 r
.008 w
.37372 .05851 Mdot
.016 w
.37372 .05851 m
.37024 .05952 L
s
1 .165 0 r
.008 w
.37024 .05952 Mdot
.016 w
.37024 .05952 m
.36679 .06062 L
s
.008 w
.36679 .06062 Mdot
.016 w
.36679 .06062 m
.36397 .06176 L
s
1 .164 0 r
.008 w
.36397 .06176 Mdot
.016 w
.36397 .06176 m
.36131 .06282 L
s
1 .163 0 r
.008 w
.36131 .06282 Mdot
.016 w
.36131 .06282 m
.35931 .06383 L
s
.008 w
.35931 .06383 Mdot
.016 w
.35931 .06383 m
.35775 .06477 L
s
1 .162 0 r
.008 w
.35775 .06477 Mdot
.016 w
.35775 .06477 m
.35662 .06561 L
s
.008 w
.35662 .06561 Mdot
.016 w
.35662 .06561 m
.35588 .0663 L
s
1 .161 0 r
.008 w
.35588 .0663 Mdot
.016 w
.35588 .0663 m
.35545 .0669 L
s
1 .16 0 r
.008 w
.35545 .0669 Mdot
.016 w
.35545 .0669 m
.35524 .06739 L
s
.008 w
.35524 .06739 Mdot
.016 w
.35524 .06739 m
.35518 .06777 L
s
1 .159 0 r
.008 w
.35518 .06777 Mdot
.016 w
.35518 .06777 m
.35521 .06805 L
s
.008 w
.35521 .06805 Mdot
.016 w
.35521 .06805 m
.35529 .06821 L
s
1 .158 0 r
.008 w
.35529 .06821 Mdot
.016 w
.35529 .06821 m
.3554 .06826 L
s
1 .157 0 r
.008 w
.3554 .06826 Mdot
.016 w
.3554 .06826 m
.35551 .06824 L
s
.008 w
.35551 .06824 Mdot
.016 w
.35551 .06824 m
.3556 .06817 L
s
1 .156 0 r
.008 w
.3556 .06817 Mdot
.016 w
.3556 .06817 m
.35567 .06809 L
s
1 .155 0 r
.008 w
.35567 .06809 Mdot
.016 w
.35567 .06809 m
.35571 .06801 L
s
.008 w
.35571 .06801 Mdot
.016 w
.35571 .06801 m
.35574 .06795 L
s
1 .154 0 r
.008 w
.35574 .06795 Mdot
.016 w
.35574 .06795 m
.35576 .06792 L
s
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
1 .153 0 r
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
1 .152 0 r
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
1 .151 0 r
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35576 .06792 L
s
1 .15 0 r
.008 w
.35576 .06792 Mdot
.016 w
.35576 .06792 m
.35577 .06792 L
s
1 .149 0 r
.008 w
.35577 .06792 Mdot
.016 w
.35577 .06792 m
.3558 .06792 L
s
.008 w
.3558 .06792 Mdot
.016 w
.3558 .06792 m
.35587 .06792 L
s
1 .148 0 r
.008 w
.35587 .06792 Mdot
.016 w
.35587 .06792 m
.35598 .06792 L
s
1 .147 0 r
.008 w
.35598 .06792 Mdot
.016 w
.35598 .06792 m
.35608 .06791 L
s
.008 w
.35608 .06791 Mdot
.016 w
.35608 .06791 m
.35613 .06789 L
s
1 .146 0 r
.008 w
.35613 .06789 Mdot
.016 w
.35613 .06789 m
.3561 .06785 L
s
.008 w
.3561 .06785 Mdot
.016 w
.3561 .06785 m
.35596 .06779 L
s
1 .145 0 r
.008 w
.35596 .06779 Mdot
.016 w
.35596 .06779 m
.35571 .06773 L
s
1 .144 0 r
.008 w
.35571 .06773 Mdot
.016 w
.35571 .06773 m
.35534 .06766 L
s
.008 w
.35534 .06766 Mdot
.016 w
.35534 .06766 m
.35486 .06764 L
s
1 .143 0 r
.008 w
.35486 .06764 Mdot
.016 w
.35486 .06764 m
.35428 .06767 L
s
.008 w
.35428 .06767 Mdot
.016 w
.35428 .06767 m
.35362 .0678 L
s
1 .142 0 r
.008 w
.35362 .0678 Mdot
.016 w
.35362 .0678 m
.35289 .06802 L
s
1 .141 0 r
.008 w
.35289 .06802 Mdot
.016 w
.35289 .06802 m
.35212 .06834 L
s
.008 w
.35212 .06834 Mdot
.016 w
.35212 .06834 m
.35134 .06876 L
s
1 .14 0 r
.008 w
.35134 .06876 Mdot
.016 w
.35134 .06876 m
.35053 .06927 L
s
1 .139 0 r
.008 w
.35053 .06927 Mdot
.016 w
.35053 .06927 m
.34971 .06982 L
s
.008 w
.34971 .06982 Mdot
.016 w
.34971 .06982 m
.34893 .07043 L
s
1 .138 0 r
.008 w
.34893 .07043 Mdot
.016 w
.34893 .07043 m
.34823 .07105 L
s
.008 w
.34823 .07105 Mdot
.016 w
.34823 .07105 m
.34763 .07168 L
s
1 .137 0 r
.008 w
.34763 .07168 Mdot
.016 w
.34763 .07168 m
.34717 .07229 L
s
1 .136 0 r
.008 w
.34717 .07229 Mdot
.016 w
.34717 .07229 m
.34682 .07288 L
s
.008 w
.34682 .07288 Mdot
.016 w
.34682 .07288 m
.3466 .07342 L
s
1 .135 0 r
.008 w
.3466 .07342 Mdot
.016 w
.3466 .07342 m
.34649 .07388 L
s
1 .134 0 r
.008 w
.34649 .07388 Mdot
.016 w
.34649 .07388 m
.34648 .07419 L
s
.008 w
.34648 .07419 Mdot
.016 w
.34648 .07419 m
.34653 .07433 L
s
1 .133 0 r
.008 w
.34653 .07433 Mdot
.016 w
.34653 .07433 m
.34665 .07429 L
s
.008 w
.34665 .07429 Mdot
.016 w
.34665 .07429 m
.34682 .07411 L
s
1 .132 0 r
.008 w
.34682 .07411 Mdot
.016 w
.34682 .07411 m
.34703 .07385 L
s
1 .131 0 r
.008 w
.34703 .07385 Mdot
.016 w
.34703 .07385 m
.34727 .07355 L
s
.008 w
.34727 .07355 Mdot
.016 w
.34727 .07355 m
.34749 .07327 L
s
1 .13 0 r
.008 w
.34749 .07327 Mdot
.016 w
.34749 .07327 m
.34768 .07304 L
s
.008 w
.34768 .07304 Mdot
.016 w
.34768 .07304 m
.3478 .07288 L
s
1 .129 0 r
.008 w
.3478 .07288 Mdot
.016 w
.3478 .07288 m
.34785 .07278 L
s
1 .128 0 r
.008 w
.34785 .07278 Mdot
.016 w
.34785 .07278 m
.34783 .07271 L
s
.008 w
.34783 .07271 Mdot
.016 w
.34783 .07271 m
.34778 .07262 L
s
1 .127 0 r
.008 w
.34778 .07262 Mdot
.016 w
.34778 .07262 m
.34773 .07248 L
s
1 .126 0 r
.008 w
.34773 .07248 Mdot
.016 w
.34773 .07248 m
.34768 .0723 L
s
.008 w
.34768 .0723 Mdot
.016 w
.34768 .0723 m
.34761 .07212 L
s
1 .125 0 r
.008 w
.34761 .07212 Mdot
.016 w
.34761 .07212 m
.34751 .07199 L
s
.008 w
.34751 .07199 Mdot
.016 w
.34751 .07199 m
.3474 .07192 L
s
1 .124 0 r
.008 w
.3474 .07192 Mdot
.016 w
.3474 .07192 m
.34732 .07191 L
s
1 .123 0 r
.008 w
.34732 .07191 Mdot
.016 w
.34732 .07191 m
.34725 .07191 L
s
.008 w
.34725 .07191 Mdot
.016 w
.34725 .07191 m
.34717 .07194 L
s
1 .122 0 r
.008 w
.34717 .07194 Mdot
.016 w
.34717 .07194 m
.34706 .07199 L
s
.008 w
.34706 .07199 Mdot
.016 w
.34706 .07199 m
.3469 .07202 L
s
1 .121 0 r
.008 w
.3469 .07202 Mdot
.016 w
.3469 .07202 m
.34666 .07204 L
s
1 .12 0 r
.008 w
.34666 .07204 Mdot
.016 w
.34666 .07204 m
.34629 .07209 L
s
.008 w
.34629 .07209 Mdot
.016 w
.34629 .07209 m
.34581 .07223 L
s
1 .119 0 r
.008 w
.34581 .07223 Mdot
.016 w
.34581 .07223 m
.34514 .07252 L
s
1 .118 0 r
.008 w
.34514 .07252 Mdot
.016 w
.34514 .07252 m
.34428 .07294 L
s
.008 w
.34428 .07294 Mdot
.016 w
.34428 .07294 m
.34321 .07345 L
s
1 .117 0 r
.008 w
.34321 .07345 Mdot
.016 w
.34321 .07345 m
.34193 .07404 L
s
.008 w
.34193 .07404 Mdot
.016 w
.34193 .07404 m
.34047 .07469 L
s
1 .116 0 r
.008 w
.34047 .07469 Mdot
.016 w
.34047 .07469 m
.33893 .07539 L
s
1 .115 0 r
.008 w
.33893 .07539 Mdot
.016 w
.33893 .07539 m
.33721 .07612 L
s
.008 w
.33721 .07612 Mdot
.016 w
.33721 .07612 m
.33532 .07687 L
s
1 .114 0 r
.008 w
.33532 .07687 Mdot
.016 w
.33532 .07687 m
.33346 .07766 L
s
.008 w
.33346 .07766 Mdot
.016 w
.33346 .07766 m
.33153 .07845 L
s
1 .113 0 r
.008 w
.33153 .07845 Mdot
.016 w
.33153 .07845 m
.32957 .07925 L
s
1 .112 0 r
.008 w
.32957 .07925 Mdot
.016 w
.32957 .07925 m
.32776 .08002 L
s
.008 w
.32776 .08002 Mdot
.016 w
.32776 .08002 m
.32602 .08081 L
s
1 .111 0 r
.008 w
.32602 .08081 Mdot
.016 w
.32602 .08081 m
.32435 .08158 L
s
1 .11 0 r
.008 w
.32435 .08158 Mdot
.016 w
.32435 .08158 m
.32283 .08229 L
s
.008 w
.32283 .08229 Mdot
.016 w
.32283 .08229 m
.32143 .08297 L
s
1 .109 0 r
.008 w
.32143 .08297 Mdot
.016 w
.32143 .08297 m
.32029 .08364 L
s
.008 w
.32029 .08364 Mdot
.016 w
.32029 .08364 m
.31934 .08428 L
s
1 .108 0 r
.008 w
.31934 .08428 Mdot
.016 w
.31934 .08428 m
.3186 .08492 L
s
1 .107 0 r
.008 w
.3186 .08492 Mdot
.016 w
.3186 .08492 m
.31807 .08547 L
s
.008 w
.31807 .08547 Mdot
.016 w
.31807 .08547 m
.31774 .086 L
s
1 .106 0 r
.008 w
.31774 .086 Mdot
.016 w
.31774 .086 m
.31759 .08644 L
s
1 .105 0 r
.008 w
.31759 .08644 Mdot
.016 w
.31759 .08644 m
.31759 .08676 L
s
.008 w
.31759 .08676 Mdot
.016 w
.31759 .08676 m
.31767 .08707 L
s
1 .104 0 r
.008 w
.31767 .08707 Mdot
.016 w
.31767 .08707 m
.31781 .08736 L
s
.008 w
.31781 .08736 Mdot
.016 w
.31781 .08736 m
.31798 .08762 L
s
1 .103 0 r
.008 w
.31798 .08762 Mdot
.016 w
.31798 .08762 m
.31816 .08785 L
s
1 .102 0 r
.008 w
.31816 .08785 Mdot
.016 w
.31816 .08785 m
.31833 .08803 L
s
.008 w
.31833 .08803 Mdot
.016 w
.31833 .08803 m
.31848 .08816 L
s
1 .101 0 r
.008 w
.31848 .08816 Mdot
.016 w
.31848 .08816 m
.3186 .08823 L
s
.008 w
.3186 .08823 Mdot
.016 w
.3186 .08823 m
.3187 .08822 L
s
1 .1 0 r
.008 w
.3187 .08822 Mdot
.016 w
.3187 .08822 m
.31879 .08813 L
s
1 .099 0 r
.008 w
.31879 .08813 Mdot
.016 w
.31879 .08813 m
.31885 .08792 L
s
.008 w
.31885 .08792 Mdot
.016 w
.31885 .08792 m
.31891 .08767 L
s
1 .098 0 r
.008 w
.31891 .08767 Mdot
.016 w
.31891 .08767 m
.31896 .08735 L
s
1 .097 0 r
.008 w
.31896 .08735 Mdot
.016 w
.31896 .08735 m
.31901 .08702 L
s
.008 w
.31901 .08702 Mdot
.016 w
.31901 .08702 m
.31906 .08669 L
s
1 .096 0 r
.008 w
.31906 .08669 Mdot
.016 w
.31906 .08669 m
.31915 .08639 L
s
.008 w
.31915 .08639 Mdot
.016 w
.31915 .08639 m
.31925 .0861 L
s
1 .095 0 r
.008 w
.31925 .0861 Mdot
.016 w
.31925 .0861 m
.31932 .08585 L
s
1 .094 0 r
.008 w
.31932 .08585 Mdot
.016 w
.31932 .08585 m
.3193 .08569 L
s
.008 w
.3193 .08569 Mdot
.016 w
.3193 .08569 m
.31913 .08563 L
s
1 .093 0 r
.008 w
.31913 .08563 Mdot
.016 w
.31913 .08563 m
.31878 .08569 L
s
.008 w
.31878 .08569 Mdot
.016 w
.31878 .08569 m
.31819 .08591 L
s
1 .092 0 r
.008 w
.31819 .08591 Mdot
.016 w
.31819 .08591 m
.3173 .08639 L
s
1 .091 0 r
.008 w
.3173 .08639 Mdot
.016 w
.3173 .08639 m
.31604 .08705 L
s
.008 w
.31604 .08705 Mdot
.016 w
.31604 .08705 m
.31432 .08802 L
s
1 .09 0 r
.008 w
.31432 .08802 Mdot
.016 w
.31432 .08802 m
.31218 .08927 L
s
1 .089 0 r
.008 w
.31218 .08927 Mdot
.016 w
.31218 .08927 m
.30952 .0908 L
s
.008 w
.30952 .0908 Mdot
.016 w
.30952 .0908 m
.30614 .09269 L
s
1 .088 0 r
.008 w
.30614 .09269 Mdot
.016 w
.30614 .09269 m
.30307 .09461 L
s
.008 w
.30307 .09461 Mdot
.016 w
.30307 .09461 m
.29929 .09683 L
s
1 .087 0 r
.008 w
.29929 .09683 Mdot
.016 w
.29929 .09683 m
.29484 .0991 L
s
1 .086 0 r
.008 w
.29484 .0991 Mdot
.016 w
.29484 .0991 m
.29103 .10148 L
s
.008 w
.29103 .10148 Mdot
.016 w
.29103 .10148 m
.28657 .10382 L
s
1 .085 0 r
.008 w
.28657 .10382 Mdot
.016 w
.28657 .10382 m
.28236 .1063 L
s
.008 w
.28236 .1063 Mdot
.016 w
.28236 .1063 m
.27752 .10866 L
s
1 .084 0 r
.008 w
.27752 .10866 Mdot
.016 w
.27752 .10866 m
.27389 .111 L
s
1 .083 0 r
.008 w
.27389 .111 Mdot
.016 w
.27389 .111 m
.26981 .1133 L
s
.008 w
.26981 .1133 Mdot
.016 w
.26981 .1133 m
.26584 .11566 L
s
1 .082 0 r
.008 w
.26584 .11566 Mdot
.016 w
.26584 .11566 m
.26231 .11772 L
s
1 .081 0 r
.008 w
.26231 .11772 Mdot
.016 w
.26231 .11772 m
.25849 .11986 L
s
.008 w
.25849 .11986 Mdot
.016 w
.25849 .11986 m
.2553 .12191 L
s
1 .08 0 r
.008 w
.2553 .12191 Mdot
.016 w
.2553 .12191 m
.25194 .12388 L
s
.008 w
.25194 .12388 Mdot
.016 w
.25194 .12388 m
.24872 .12588 L
s
1 .079 0 r
.008 w
.24872 .12588 Mdot
.016 w
.24872 .12588 m
.2456 .12779 L
s
1 .078 0 r
.008 w
.2456 .12779 Mdot
.016 w
.2456 .12779 m
.24235 .12967 L
s
.008 w
.24235 .12967 Mdot
.016 w
.24235 .12967 m
.23942 .13153 L
s
1 .077 0 r
.008 w
.23942 .13153 Mdot
.016 w
.23942 .13153 m
.23634 .13332 L
s
1 .076 0 r
.008 w
.23634 .13332 Mdot
.016 w
.23634 .13332 m
.23328 .1351 L
s
.008 w
.23328 .1351 Mdot
.016 w
.23328 .1351 m
.2301 .13689 L
s
1 .075 0 r
.008 w
.2301 .13689 Mdot
.016 w
.2301 .13689 m
.2273 .13859 L
s
.008 w
.2273 .13859 Mdot
.016 w
.2273 .13859 m
.22434 .1403 L
s
1 .074 0 r
.008 w
.22434 .1403 Mdot
.016 w
.22434 .1403 m
.2215 .14196 L
s
1 .073 0 r
.008 w
.2215 .14196 Mdot
.016 w
.2215 .14196 m
.21892 .14355 L
s
.008 w
.21892 .14355 Mdot
.016 w
.21892 .14355 m
.21635 .1451 L
s
1 .072 0 r
.008 w
.21635 .1451 Mdot
.016 w
.21635 .1451 m
.21394 .14659 L
s
.008 w
.21394 .14659 Mdot
.016 w
.21394 .14659 m
.21202 .1479 L
s
1 .071 0 r
.008 w
.21202 .1479 Mdot
.016 w
.21202 .1479 m
.2103 .14912 L
s
1 .07 0 r
.008 w
.2103 .14912 Mdot
.016 w
.2103 .14912 m
.20877 .15022 L
s
.008 w
.20877 .15022 Mdot
.016 w
.20877 .15022 m
.20744 .15119 L
s
1 .069 0 r
.008 w
.20744 .15119 Mdot
.016 w
.20744 .15119 m
.20638 .152 L
s
1 .068 0 r
.008 w
.20638 .152 Mdot
.016 w
.20638 .152 m
.2055 .15268 L
s
.008 w
.2055 .15268 Mdot
.016 w
.2055 .15268 m
.20482 .15323 L
s
1 .067 0 r
.008 w
.20482 .15323 Mdot
.016 w
.20482 .15323 m
.20433 .15366 L
s
.008 w
.20433 .15366 Mdot
.016 w
.20433 .15366 m
.20397 .15397 L
s
1 .066 0 r
.008 w
.20397 .15397 Mdot
.016 w
.20397 .15397 m
.20373 .15419 L
s
1 .065 0 r
.008 w
.20373 .15419 Mdot
.016 w
.20373 .15419 m
.20355 .15433 L
s
.008 w
.20355 .15433 Mdot
.016 w
.20355 .15433 m
.20342 .15444 L
s
1 .064 0 r
.008 w
.20342 .15444 Mdot
.016 w
.20342 .15444 m
.20326 .15458 L
s
.008 w
.20326 .15458 Mdot
.016 w
.20326 .15458 m
.20306 .15477 L
s
1 .063 0 r
.008 w
.20306 .15477 Mdot
.016 w
.20306 .15477 m
.20282 .15501 L
s
1 .062 0 r
.008 w
.20282 .15501 Mdot
.016 w
.20282 .15501 m
.20256 .15533 L
s
.008 w
.20256 .15533 Mdot
.016 w
.20256 .15533 m
.20223 .15574 L
s
1 .061 0 r
.008 w
.20223 .15574 Mdot
.016 w
.20223 .15574 m
.20184 .15625 L
s
1 .06 0 r
.008 w
.20184 .15625 Mdot
.016 w
.20184 .15625 m
.20144 .15685 L
s
.008 w
.20144 .15685 Mdot
.016 w
.20144 .15685 m
.20101 .15749 L
s
1 .059 0 r
.008 w
.20101 .15749 Mdot
.016 w
.20101 .15749 m
.20059 .1582 L
s
.008 w
.20059 .1582 Mdot
.016 w
.20059 .1582 m
.20018 .15893 L
s
1 .058 0 r
.008 w
.20018 .15893 Mdot
.016 w
.20018 .15893 m
.19978 .15972 L
s
1 .057 0 r
.008 w
.19978 .15972 Mdot
.016 w
.19978 .15972 m
.1994 .1605 L
s
.008 w
.1994 .1605 Mdot
.016 w
.1994 .1605 m
.19903 .16126 L
s
1 .056 0 r
.008 w
.19903 .16126 Mdot
.016 w
.19903 .16126 m
.19868 .16197 L
s
.008 w
.19868 .16197 Mdot
.016 w
.19868 .16197 m
.19834 .16256 L
s
1 .055 0 r
.008 w
.19834 .16256 Mdot
.016 w
.19834 .16256 m
.19801 .16305 L
s
1 .054 0 r
.008 w
.19801 .16305 Mdot
.016 w
.19801 .16305 m
.19772 .1634 L
s
.008 w
.19772 .1634 Mdot
.016 w
.19772 .1634 m
.19748 .1636 L
s
1 .053 0 r
.008 w
.19748 .1636 Mdot
.016 w
.19748 .1636 m
.1973 .16365 L
s
1 .052 0 r
.008 w
.1973 .16365 Mdot
.016 w
.1973 .16365 m
.19717 .16356 L
s
.008 w
.19717 .16356 Mdot
.016 w
.19717 .16356 m
.19713 .16334 L
s
1 .051 0 r
.008 w
.19713 .16334 Mdot
.016 w
.19713 .16334 m
.19718 .16302 L
s
.008 w
.19718 .16302 Mdot
.016 w
.19718 .16302 m
.1973 .16267 L
s
1 .05 0 r
.008 w
.1973 .16267 Mdot
.016 w
.1973 .16267 m
.19744 .16234 L
s
1 .049 0 r
.008 w
.19744 .16234 Mdot
.016 w
.19744 .16234 m
.19755 .16207 L
s
.008 w
.19755 .16207 Mdot
.016 w
.19755 .16207 m
.19758 .16192 L
s
1 .048 0 r
.008 w
.19758 .16192 Mdot
.016 w
.19758 .16192 m
.19749 .16194 L
s
.008 w
.19749 .16194 Mdot
.016 w
.19749 .16194 m
.19725 .16216 L
s
1 .047 0 r
.008 w
.19725 .16216 Mdot
.016 w
.19725 .16216 m
.19683 .16266 L
s
1 .046 0 r
.008 w
.19683 .16266 Mdot
.016 w
.19683 .16266 m
.19624 .16337 L
s
.008 w
.19624 .16337 Mdot
.016 w
.19624 .16337 m
.19549 .16435 L
s
1 .045 0 r
.008 w
.19549 .16435 Mdot
.016 w
.19549 .16435 m
.1946 .16556 L
s
1 .044 0 r
.008 w
.1946 .16556 Mdot
.016 w
.1946 .16556 m
.1936 .16698 L
s
.008 w
.1936 .16698 Mdot
.016 w
.1936 .16698 m
.19259 .16847 L
s
1 .043 0 r
.008 w
.19259 .16847 Mdot
.016 w
.19259 .16847 m
.19159 .16997 L
s
.008 w
.19159 .16997 Mdot
.016 w
.19159 .16997 m
.19057 .17148 L
s
1 .042 0 r
.008 w
.19057 .17148 Mdot
.016 w
.19057 .17148 m
.18954 .17292 L
s
1 .041 0 r
.008 w
.18954 .17292 Mdot
.016 w
.18954 .17292 m
.1886 .17427 L
s
.008 w
.1886 .17427 Mdot
.016 w
.1886 .17427 m
.18774 .17558 L
s
1 .04 0 r
.008 w
.18774 .17558 Mdot
.016 w
.18774 .17558 m
.18697 .17691 L
s
1 .039 0 r
.008 w
.18697 .17691 Mdot
.016 w
.18697 .17691 m
.18628 .17812 L
s
.008 w
.18628 .17812 Mdot
.016 w
.18628 .17812 m
.18558 .17938 L
s
1 .038 0 r
.008 w
.18558 .17938 Mdot
.016 w
.18558 .17938 m
.18483 .18075 L
s
.008 w
.18483 .18075 Mdot
.016 w
.18483 .18075 m
.18396 .18229 L
s
1 .037 0 r
.008 w
.18396 .18229 Mdot
.016 w
.18396 .18229 m
.18294 .18406 L
s
1 .036 0 r
.008 w
.18294 .18406 Mdot
.016 w
.18294 .18406 m
.18166 .18612 L
s
.008 w
.18166 .18612 Mdot
.016 w
.18166 .18612 m
.18024 .18829 L
s
1 .035 0 r
.008 w
.18024 .18829 Mdot
.016 w
.18024 .18829 m
.17847 .19085 L
s
.008 w
.17847 .19085 Mdot
.016 w
.17847 .19085 m
.17643 .19377 L
s
1 .034 0 r
.008 w
.17643 .19377 Mdot
.016 w
.17643 .19377 m
.1742 .19695 L
s
1 .033 0 r
.008 w
.1742 .19695 Mdot
.016 w
.1742 .19695 m
.17176 .20054 L
s
.008 w
.17176 .20054 Mdot
.016 w
.17176 .20054 m
.16904 .20436 L
s
1 .032 0 r
.008 w
.16904 .20436 Mdot
.016 w
.16904 .20436 m
.16644 .20832 L
s
1 .031 0 r
.008 w
.16644 .20832 Mdot
.016 w
.16644 .20832 m
.16367 .21242 L
s
.008 w
.16367 .21242 Mdot
.016 w
.16367 .21242 m
.16085 .21653 L
s
1 .03 0 r
.008 w
.16085 .21653 Mdot
.016 w
.16085 .21653 m
.15814 .22074 L
s
.008 w
.15814 .22074 Mdot
.016 w
.15814 .22074 m
.15554 .22464 L
s
1 .029 0 r
.008 w
.15554 .22464 Mdot
.016 w
.15554 .22464 m
.15289 .22862 L
s
1 .028 0 r
.008 w
.15289 .22862 Mdot
.016 w
.15289 .22862 m
.15033 .23301 L
s
.008 w
.15033 .23301 Mdot
.016 w
.15033 .23301 m
.14779 .23663 L
s
1 .027 0 r
.008 w
.14779 .23663 Mdot
.016 w
.14779 .23663 m
.1451 .2407 L
s
.008 w
.1451 .2407 Mdot
.016 w
.1451 .2407 m
.14257 .24475 L
s
1 .026 0 r
.008 w
.14257 .24475 Mdot
.016 w
.14257 .24475 m
.13994 .24894 L
s
1 .025 0 r
.008 w
.13994 .24894 Mdot
.016 w
.13994 .24894 m
.13727 .25346 L
s
.008 w
.13727 .25346 Mdot
.016 w
.13727 .25346 m
.13459 .25755 L
s
1 .024 0 r
.008 w
.13459 .25755 Mdot
.016 w
.13459 .25755 m
.13192 .26185 L
s
1 .023 0 r
.008 w
.13192 .26185 Mdot
.016 w
.13192 .26185 m
.12919 .2665 L
s
.008 w
.12919 .2665 Mdot
.016 w
.12919 .2665 m
.12661 .27043 L
s
1 .022 0 r
.008 w
.12661 .27043 Mdot
.016 w
.12661 .27043 m
.1239 .27475 L
s
.008 w
.1239 .27475 Mdot
.016 w
.1239 .27475 m
.12116 .2792 L
s
1 .021 0 r
.008 w
.12116 .2792 Mdot
.016 w
.12116 .2792 m
.11836 .2835 L
s
1 .02 0 r
.008 w
.11836 .2835 Mdot
.016 w
.11836 .2835 m
.11573 .28771 L
s
.008 w
.11573 .28771 Mdot
.016 w
.11573 .28771 m
.1131 .29194 L
s
1 .019 0 r
.008 w
.1131 .29194 Mdot
.016 w
.1131 .29194 m
.11058 .29618 L
s
.008 w
.11058 .29618 Mdot
.016 w
.11058 .29618 m
.1081 .30058 L
s
1 .018 0 r
.008 w
.1081 .30058 Mdot
.016 w
.1081 .30058 m
.10591 .30458 L
s
1 .017 0 r
.008 w
.10591 .30458 Mdot
.016 w
.10591 .30458 m
.10377 .30875 L
s
.008 w
.10377 .30875 Mdot
.016 w
.10377 .30875 m
.10167 .31338 L
s
1 .016 0 r
.008 w
.10167 .31338 Mdot
.016 w
.10167 .31338 m
.09984 .3172 L
s
1 .015 0 r
.008 w
.09984 .3172 Mdot
.016 w
.09984 .3172 m
.09806 .32163 L
s
.008 w
.09806 .32163 Mdot
.016 w
.09806 .32163 m
.09638 .32594 L
s
1 .014 0 r
.008 w
.09638 .32594 Mdot
.016 w
.09638 .32594 m
.09482 .33002 L
s
.008 w
.09482 .33002 Mdot
.016 w
.09482 .33002 m
.0934 .33429 L
s
1 .013 0 r
.008 w
.0934 .33429 Mdot
.016 w
.0934 .33429 m
.09209 .33846 L
s
1 .012 0 r
.008 w
.09209 .33846 Mdot
.016 w
.09209 .33846 m
.09092 .34252 L
s
.008 w
.09092 .34252 Mdot
.016 w
.09092 .34252 m
.0899 .3465 L
s
1 .011 0 r
.008 w
.0899 .3465 Mdot
.016 w
.0899 .3465 m
.08896 .35055 L
s
1 .01 0 r
.008 w
.08896 .35055 Mdot
.016 w
.08896 .35055 m
.08812 .35481 L
s
.008 w
.08812 .35481 Mdot
.016 w
.08812 .35481 m
.08734 .35876 L
s
1 .009 0 r
.008 w
.08734 .35876 Mdot
.016 w
.08734 .35876 m
.08663 .36335 L
s
.008 w
.08663 .36335 Mdot
.016 w
.08663 .36335 m
.08599 .36734 L
s
1 .008 0 r
.008 w
.08599 .36734 Mdot
.016 w
.08599 .36734 m
.08548 .37182 L
s
1 .007 0 r
.008 w
.08548 .37182 Mdot
.016 w
.08548 .37182 m
.08507 .37606 L
s
.008 w
.08507 .37606 Mdot
.016 w
.08507 .37606 m
.08475 .38032 L
s
1 .006 0 r
.008 w
.08475 .38032 Mdot
.016 w
.08475 .38032 m
.08452 .38423 L
s
.008 w
.08452 .38423 Mdot
.016 w
.08452 .38423 m
.08438 .38824 L
s
1 .005 0 r
.008 w
.08438 .38824 Mdot
.016 w
.08438 .38824 m
.0843 .39143 L
s
1 .004 0 r
.008 w
.0843 .39143 Mdot
.016 w
.0843 .39143 m
.08426 .39441 L
s
.008 w
.08426 .39441 Mdot
.016 w
.08426 .39441 m
.08425 .39713 L
s
1 .003 0 r
.008 w
.08425 .39713 Mdot
.016 w
.08425 .39713 m
.08426 .39928 L
s
1 .002 0 r
.008 w
.08426 .39928 Mdot
.016 w
.08426 .39928 m
.08427 .40095 L
s
.008 w
.08427 .40095 Mdot
.016 w
.08427 .40095 m
.0843 .40208 L
s
1 .001 0 r
.008 w
.0843 .40208 Mdot
.016 w
.0843 .40208 m
.08433 .4027 L
s
.008 w
.08433 .4027 Mdot
.016 w
.08433 .4027 m
.08433 .40293 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0231426 0.0219148 scale
4.03152 31.2898 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0356652 0.033773 scale
2.87787 21.5143 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0425158 0.04026 scale
11.2561 23.2471 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0356652 0.033773 scale
23.9348 22.8727 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0245465 0.0232442 scale
37.8005 24.074 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0448155 0.0424378 scale
20.7761 12.9368 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0703856 0.0666512 scale
12.8423 4.63157 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0400842 0.0379575 scale
19.5793 3.67305 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0200421 0.0189788 scale
38.7284 12.0719 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0306148 0.0289905 scale
29.063 9.9598 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0200421 0.0189788 scale
43.1077 12.8491 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0327286 0.0309922 scale
12.4194 1.76819 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0374954 0.035506 scale
9.47744 1.92305 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0365917 0.0346503 scale
9.47345 2.14803 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001bOol7002WOol0071oo`80
00Moo`03001oogoo0:Aoo`00Kgoo00<007ooOol027oo0P00Y7oo001SOol90002Ool00`00Oomoo`0;
Ool00`00Oomoo`2QOol0065oo`L000Aoo`<000Moo`03?Nmoocg_00Aoo`03001oogoo0:1oo`00H7oo
0`001Goo0`000Woo0P001Woo13g_17oo00<007ooOol03Goo1@00SWoo001OOol2000:Ool01@00Ool0
07oo000017oo1Cg_0Wc00goo0P000Sg_10000Sg_1@001Goo2P0000=lh00000000P00Ogoo001NOol2
000<Ool20002?Nl00`00O:1lX004O:07O<000`00O<1l`009O<0DO>03Ool00`00?Nlmk`0300000gcP
Oomoo`1fOol005eoo`8000Yoo`=lX080009lX003001lX7bP00ElX0Il`003001l`7c000Ul`1mlh003
001lh00007Aoo`00GGoo0P0027oo00<mkgbPO:000WbP00<007bP00000WbP00<007bPO:0017bP1Wc0
00<007c0O<002Gc08WcP00<007cP00000P00Kgoo001LOol20007Ool00cg_O:1lX004O:000`00O:00
0003O:000`00O:1lX002O:07O<000`00O<1l`009O<0UO>000gooO>000002001/Ool005aoo`8000Eo
o`03?NmlP7b000AlP0=lX08000=lX003001lX7bP009lX0Al`0<mk`03000mkcg_01XmkaQlh003Ool0
000000<006Moo`00Fgoo00<007oo00000goo00<mkgaPO6000gaP0gb017bP0P000Sg_00<003g_?Nl0
2Cg_00<003g_?Nl08cg_0Woo3WcP00<mkgooOol00Woo0`00I7oo001KOol01000Ool007oo27aP0gb0
00AlX3g_?Nlmk`80008mk`03000mkcg_00Pmk`03001oogoo00Ioo`lmk`Aooa0mk`ilh003?Nmoogoo
009oo`<0065oo`00Fgoo00<007oo00002GaP0gb01Cg_00<007oo00002cg_00<007ooOol01Woo0cg_
57oo3cg_3GcP0Wd017oo0P00Ggoo001KOol01000O61lH00027aP00=lP3g_?Nl00cg_0Woo0`0017oo
1Cg_0P002Goo0Sg_5Woo4Cg_2WcP0gd000=oogd0Ool00Woo0`00G7oo001IOol00`00O4000002O400
0`00O61lH005O6000gb0?Nmoo`06Ool01000Ool000001Goo0`002goo00<mkgooOol05goo2Cg_17oo
13g_27cP1gd017oo0P00FWoo001GOol01@00O41l@7a000000ga000<007aPO6000WaP2goo00@007oo
001oo`D003Moo`@mk`Ilh0Qm0003Oomm07oo009oo`8005Qoo`00EGoo0P001Ga000H007a0O41lH000
?Nl<Ool30010Ool5?Nl>O@04Ool2001FOol005=oo`03000mkcg_00Il@0800004O40mk`00?Nl;Ool2
0012Ool2?Nl00goo?Nlmk`03?Nl>O@03Ool2001DOol0055oo`8000]l@003000mkgoo008000Uoo`80
04=oo`03?Nmoogoo00Aoo`@mk`am0004?Nmm07ooOol2001BOol004moo`8000]l@0<mk`04001oogoo
Ool20005Ool3001@Ool00cg_O@1m000;O@000gooO@1oo`02000;Ool50010Ool004ioo`03001ooga0
00Ql@0@mk`9oo`8000Aoo`H005Ioo`03?Nmm07d000]m0003Ool007oo00Moo`8000Eoo`8003ioo`00
C7oo0P002ga013g_17oo2@00FGoo3gd000<007ooOol00Woo0P002Goo0P00?7oo001:Ool20009O405
?Nm[Ool?O@03000=Ool2000jOol004Qoo`800003Ooml@7a000Ql@0Dmkfioo`am0003001m000000mo
o`03001oogoo03Moo`00AWoo0P0000=ooga0O4001ga023g_Kgoo0Sg_2Gd000<007d0O@000P003Woo
00<007ooOol0=Woo0015Ool00`00Ooml@00:O407?NmbOol4?Nl4O@000`00O@1m0002O@000gooO@1o
o`0<Ool00`00Oomoo`0fOol004Aoo`03001ooga000Ul@0PmkgAoo`03?Nmoogoo00Am0003001m07d0
00Em00eoo`03001oogoo03Eoo`00@goo00<007a0O4001ga023g_Ngoo0Sg_00=m0000O@001gd00Wg0
2Woo00<007ooOol0=Goo0011Ool00`00O41l@009O406?NmoOol00cg_001mX009O@000gg0Oomoo`07
Ool00`00Oomoo`0eOol003moo`03001l@7a000Ul@0Pmkgioo`04OJ0007fPOJ0:O@000ggPOomoo`06
Ool00`00Oomoo`0eOol003ioo`03001l@7a000Ml@0@mkhAoo`9mX003001mX7fP00=mX003OL1m07d0
00Em0003ON0007oo00Eoo`03001oogoo03Eoo`00?7oo00<007a0O4002Ga00cg_Pgoo17fP00<007fP
OJ000gfP0Wg01gd000=oo`00Ool017oo00<007ooOol0=Goo000kOol00`00O41l@008O404?Nn3Ool6
OJ000`00OJ1mX002OJ02?Nl8O@000goo001oo`03Ool00`00Oomoo`0eOol003Yoo`03001l87`P009l
80El@0Dmkh9oo`QmX003001mX7oo009oo`@mk`03ON1m07d000Em0080009oo`03001oogoo03Eoo`00
>Goo00<003g_O2000g`P0ga01Sg_Pgoo27fP00=oo`00Ool01Goo0Sg_00=mh7d0O@0017d00Woo0P00
>7oo000hOol00`00?Nml8005O2000ga0?Nlmk`04?Nn4Ool7OJ02Ool00`00Oomoo`04Ool3?Nl00ggP
O@1m0004O@02Ool00`00Oomoo`0fOol003Moo`03001oog`P00El8003O40mkcg_00@mkhEoo`MmX0=o
o`03001oogoo00=oo`<mk`9mh0Em0003Ool0000003Qoo`00=Woo00<007ooO2001W`P0cg_RWoo1gfP
0Woo0P001Goo0cg_0WgP17d000@007ooOol003Moo`00=Goo00<007ooOol01G`P1Cg_Rgoo1WfP17oo
0P0017oo13g_0gd000<007d0O@000Woo00<007ooOol0=7oo000dOol00`00Oomoo`06O204?Nn=Ool6
OJ05Ool20005Ool40003O@03Ool00`00Oomoo`0cOol0039oo`80009oo`Ml80@mkheoo`MmX0Ioo`D0
0003Oolmkgd000Em00=oo`8003=oo`00<Goo00<007ooOol00Woo1W`P1Cg_Sgoo1GfP3Goo1Wd000=m
h7ooOol00Woo00<007ooOol0<7oo000`Ool00`00Oomoo`02Ool6O206?Nn?Ool6OJ0=Ool00cg_O@1m
0003O@000ggPOomoo`02Ool00`00Oomoo`0_Ool002moo`03001oogoo009oo`03?Nml87`P00Al80Dm
ki1oo`ImX0ioo`Im00Eoo`03001oogoo02ioo`00;Woo00<007ooOol00goo1W`P1Cg_TWoo1WfP3Goo
00<mkgd0O@0017d01Goo00<007ooOol0;Goo000]Ool00`00Oomoo`03Ool00cg_O21l8004O204?NnC
Ool7OJ0<Ool00cg_ON1m0003O@02OB05Ool00`00Oomoo`0/Ool002aoo`03001oogoo00=oo`03?Nml
87`P00Al80@mkiIoo`ImX0aoo`8mk`9m00Am80Eoo`03001oogoo02]oo`00;7oo00<007ooOol00goo
1W`P13g_V7oo1GfP3Goo00<mkggPOB000gdP00=mh7ooOol00goo00<007ooOol0:goo000[Ool00`00
Oomoo`03Ool4O003O204?NnHOol6OJ0<Ool00cg_ON1m8004OB000ggPOomoo`03Ool00`00Oomoo`0Z
Ool002Yoo`03001oogoo00=oo`03?Nml07`0009l0003O20mkgoo09aoo`AmX0D000Yoo`03?Nmm87dP
00Am8003ON1oogoo00=oo`03001oogoo02Uoo`00:Goo00<007ooOol017oo1W`0Wgoo0WfP00@007f0
OH1mP09oo`8000Uoo`Mm8003ON1oogoo00=oo`03001oogoo02Qoo`00:7oo00<007ooOol017oo1W`0
X7oo0WfP00@007f0OH1mP0Aoo`03001oogoo00Qoo`Em8003ON1oogoo00Aoo`03001oogoo02Moo`00
:7oo00<007ooOol00goo1g`0XGoo00<007f0OH000gf017oo00<007ooOol01goo1WdP00=mh7ooOol0
0goo00<007ooOol09goo000WOol00`00Oomoo`04Ool5O002?NnQOol00`00OH1mP004OH03Ool00`00
Oomoo`07Ool6OB02ON030002Ool00`00Oomoo`0VOol002Ioo`03001oogoo00Aoo`Il00<mkimoo`03
001oogf000ImP09oo`03001oogoo00Qoo`Em80800003ON1oogoo00800003Ool007oo02Ioo`009Goo
00<007ooOol017oo1W`013g_X7oo00<007ooOH001Wf000=oo`00Ool02Goo17dP00@007dPOB1mh0Ao
o`03001oo`0002Ioo`0097oo00<007ooOol01Goo1W`00cg_XGoo00<007ooOH001gf000<007ooOol0
2Goo0WdP00<007dPOB000WdP00=mh7ooOol00Woo00<007oo00009Goo000TOol00`00Oomoo`04Ool0
0cg_O01l0002O004?NnSOol00`00OommP006OH000`00OH1oo`0:Ool00gdP001m8005OB03Ool00`00
Ool0000UOol002=oo`03001oogoo00Eoo`Il008mkjAoo`800003OommP7f0009mP08000=mP0Yoo`03
001m87dP00Em8003ON1oogoo00/001eoo`008Woo00<007ooOol01Goo1W`00cg_YWoo0P0000=mP000
00001Wf02Woo00<007dPOB0017dP00Am@7gP000000=oo`03001oogoo00Aoo`@001Uoo`008Goo00<0
07ooOol01Goo1g`000<mkgooOol0Z7oo00<007ooOH0027f027oo00<007dPOB000gdP0`0000=oo`00
Ool00goo00<007ooOol01goo00<007ooOol05Woo000POol00`00Oomoo`06Ool5O002?Nn^Ool:OH07
Ool01@00?Nmm@7e000000ge000=mh000Ool017oo00<007ooOol01goo0P005Woo000POol00`00Oomo
o`05Ool6O002?NnaOol8OH000gePOomoo`03Ool200000ge0001m@002OD020006Ool00`00Oomoo`09
Ool00`00Oomoo`0COol001moo`03001oogoo00Ioo`El00<mkk5oo`MmP0AmH0Eoo`800004OD000000
OD0700000goo001oo`0:Ool2000COol001moo`03001oogoo00Eoo`Il008mkk=oo`EmP0MmH007Ool0
0000Oolmk`00OD000P000We01Goo00<007oo000037oo00<007ooOol047oo000NOol00`00Oomoo`05
Ool6O002?NnfOol3OH07OF001`00OomoogePOomm@00000Am@003ON1oogoo00=oo`8000eoo`03001o
ogoo00moo`007Goo00<007ooOol01Woo1G`00cg_^7oo0Wf01WeP00<007ePOF000WeP00<007e0OD00
17e000=mh7ooOol00goo0P0037oo00<007ooOol03goo000MOol00`00Oomoo`05Ool6O003?NnjOol5
OF000`00OF1mH002OF000`00OF1m@006OD06Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool001aoo`03
001oogoo00Eoo`Il00<mkkeoo`9mH003001mH7eP00=mH003001mH7eP00Im@003OF1oogoo00Aoo`03
001oogoo00Yoo`03001oogoo00ioo`0077oo00<007ooOol017oo1g`00cg__goo00<007ePOF000geP
00@007ePOF1mH0Em@003OF1n07oo00Aoo`03001oogoo00]oo`03001oogoo00eoo`006goo00<007oo
Ool01Goo1G`01Cg__goo00@007ooOomoo`9mH004001mH7ePOF05OD000gePOP1oo`04Ool2000<Ool0
0`00Oomoo`0=Ool001]oo`03001oogoo00Eoo`Al00Dmkl1oo`03001oogoo00=oo`04001oogooOol5
OD000gePOP1n0004Ool2000<Ool00`00Oomoo`0=Ool001Yoo`03001oogoo00Eoo`Il00@mkkmoo`03
001oogoo00Aoo`03001oogoo009oo`Am@003OF1n07h000Aoo`03001oo`0000aoo`03001oogoo00ao
o`006Woo00<007ooOol017oo1W`013g_`7oo00<007ooOol017oo00<007ooOol00Woo17e000AmH7h0
OP1n00=oo`03001oo`0000aoo`03001oogoo00aoo`006Goo00<007ooOol01Goo1W`00cg_`Goo00<0
07ooOol01Goo00<007ooOol00Woo00<mkgh0OP000gh000DmkgooOomoo`00009oo`03001oogoo00Uo
o`03001oogoo00aoo`006Goo00<007ooOol017oo1W`000<mkgooOol0`Woo00<007ooOol01Goo00<0
07ooOol017oo1Wh000=oo`00Ool00goo00<007ooOol027oo00<007ooOol037oo000HOol00`00Oomo
o`04Ool00cg_O01l0003O002?No4Ool00`00Oomoo`06Ool00`00Oomoo`03Ool6OP000`00Oomoo`03
Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool001Qoo`03001oogoo00Aoo`03?Nml07`000=l008mklAo
o`03001oogoo00Moo`80009oo`03?Nmn07h0009n00800003OR0mkcg_00=oo`03001oogoo00Qoo`03
001oogoo00aoo`005goo00<007ooOol017oo00<mkg`0O00017`00Sg_a7oo00<007ooOol02Goo00<0
07oo?Nl00Wh00P000Wh000=n83g_Ool017oo00<007ooOol01goo00<007ooOol037oo000GOol00`00
Oomoo`04Ool00cg_O01l0003O002?No5Ool00`00Oomoo`0:Ool40005OR06Ool00`00Oomoo`07Ool0
0`00Oomoo`0<Ool001Ioo`03001oogoo00Eoo`Il0003?Nmoogoo0<Aoo`03001oogoo00aoo`8mk`En
8003OT1oogoo00Aoo`03001oogoo00Ioo`03001oogoo00aoo`005Woo00<007ooOol017oo00<mkg`0
O0000g`00Sg_aWoo00<007ooOol02goo13g_1Gi01Woo00<007ooOol01Woo00<007ooOol037oo000E
Ool00`00Oomoo`05Ool6O002?No7Ool00`00Oomoo`0=Ool00cg_OT1n@003OT07Ool00`00Oomoo`04
Ool00`00Oomoo`0=Ool001Eoo`03001oogoo00Eoo`El008mklQoo`03001oogoo00eoo`03?Nmn@7i0
00=n@0Moo`03001oogoo00Aoo`03001oogoo00eoo`0057oo00<007ooOol01Woo1G`00Sg_b7oo00<0
07ooOol03Goo0Sg_17i000<mkgooOol01Goo00<007ooOol00goo00<007ooOol03Goo000DOol00`00
Oomoo`05Ool00cg_O01l0002O002?No:Ool00`00Oomoo`0=Ool00cg_OT1n@002OT08Ool00`00Oomo
o`02Ool00`00Oomoo`0>Ool001Aoo`03001oogoo00Eoo`Il0003?Nmoogoo0<Qoo`03001oogoo00eo
o`03?Nmn@7i000=n@0Moo`03001oogoo009oo`03001oogoo00ioo`004goo00<007ooOol01Woo1G`0
0Sg_bgoo00<007ooOol037oo00<mkgi0OT000gi027oo00@007ooOol0015oo`004goo00<007ooOol0
1Woo1G`000<mkgooOol0bgoo00<007ooOol02goo00<mkgi0OT000Wi000<mkgooOol01Woo0`004Woo
000COol00`00Oomoo`06Ool4O0000cg_Oomoo`3=Ool00`00Oomoo`0:Ool00cg_OT1n@003OT08Ool0
0`00Oomoo`0BOol0019oo`03001oogoo00Moo`Al0003?Nmoogoo0<ioo`8000]oo`In@0Ioo`03001o
o`0001=oo`004Woo00<007ooOol01Woo1W`0dWoo00<007ooOol027oo1Gi01Woo00@007ooOol001=o
o`004Woo00<007ooOol01Woo1G`000<mkgooOol0dGoo0P002Goo17i01Goo00D007ooOomoo`0001=o
o`004Goo00<007ooOol01goo1G`000<mkgooOol0dgoo0P001goo17i000<mk`0000000P001Goo00<0
07ooOol047oo000AOol00`00Oomoo`07Ool4O0000cg_Oomoo`3FOol50002Ool00gi0000000020009
Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`Al008mkmaoo`<000An@0Uoo`03001oogoo011o
o`0047oo00<007ooOol027oo17`00Sg_gWoo1Wi02Goo00<007ooOol03goo000@Ool00`00Oomoo`08
Ool4O0000cg_Oomoo`3MOol5OT0:Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Al0003?Nmo
ogoo0=ioo`An@0Yoo`03001oogoo00moo`0047oo00<007ooOol027oo17`000<mkgooOol0gWoo17i0
2Woo00<007ooOol03goo000@Ool00`00Oomoo`08Ool4O0000cg_Oomoo`3NOol4OT0:Ool00`00Oomo
o`0?Ool000moo`03001oogoo00Uoo`Al0003?Nmoogoo0=ioo`An@0Yoo`03001oogoo00moo`003goo
00<007ooOol02Goo17`000<mkgooOol0gWoo17iP2goo00<007ooOol03Woo000?Ool00`00Oomoo`09
Ool4O03QOol4OV0;Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al009oh=moo`EnH0Yoo`03
001oogoo00ioo`003Woo00<007ooOol02Woo1goPgWoo1GiP2goo00<007ooOol03Goo000>Ool00`00
Oomoo`0:Ool7On3OOol5OV0:Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Yoo`Moh=moo`AnH0]o
o`03001oogoo00eoo`003Woo00<007ooOol037oo1GoPggoo17iP2goo00<007ooOol03Goo000>Ool0
0`00Oomoo`0=Ool4On3OOol4OV0;Ool00`00Oomoo`0=Ool000eoo`03001oogoo00ioo`Aoh=moo`An
H0aoo`03001oogoo00aoo`003Goo00<007ooOol03Woo17oPggoo1GiP2goo00<007ooOol037oo000=
Ool00`00Oomoo`0>Ool4On3OOol5OV0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00ioo`Aoh0Mo
o`Lmkm5oo`EnH0]oo`03001oogoo00aoo`003Goo00<007ooOol03Goo1WoP00=oocg_?Nl02Cg_dGoo
00<mkgiPOV000giP2goo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool5On0<?NoBOol2?Nl4OV0;
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`Eoh0/mkm=oo`8mk`AnH0]oo`03001oogoo00ao
o`003Goo00<007ooOol02Goo0cg_1WoP33g_dWoo0Sg_17iP2goo00<007ooOol037oo000=Ool00`00
Oomoo`08Ool4?Nl5On0@?No?Ool2?Nl4OV0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`<m
k`Ioh1@mklYoo`<mk`AnH0]oo`03001oogoo00aoo`003Goo00<007ooOol027oo0Sg_1WoP0Sg_00=o
ocg_?Nl04Cg_b7oo13g_17iP2goo00<007ooOol037oo000<Ool00`00Oomoo`09Ool2?Nl6On03OolC
?No9Ool3?Nl4OV000cg_Oomoo`09Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`03?Nmoh7oP
00Aoh08mk`=oo`Hmk`03Oolmkcg_00TmklYoo`8mk`EnH0]oo`03001oogoo00]oo`0037oo00<007oo
Ool027oo0Sg_1GoP63g_bWoo0Sg_1WiP2Woo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_
On1oh004On0G?No;Ool2?Nl5OV0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`03?Nmoh7oP
00=oh0lmkmAoo`<mk`AnH0]oo`03001oogoo00]oo`0037oo00<007ooOol027oo1WoP0Woo3Cg_e7oo
0cg_17iP2goo00<007ooOol02goo000<Ool00`00Oomoo`08Ool5On000cg_Oomoo`05Ool9?NoCOol3
?Nl4OV0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Eoh003?Nmoogoo00Qoo`HmkmAoo`8m
k`AnH0]oo`03001oogoo00]oo`0037oo00<007ooOol01goo1WoP00<mkgooOol027oo1Sg_e7oo0Sg_
17iP2goo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5On000cg_Oomoo`09Ool7?NoCOol2?Nl4
OV0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`Eoh003?Nmoogoo00Uoo`Pmkm5oo`/000Mo
o`03001oogoo00]oo`0037oo00<007ooOol01goo17o000<mkgooOol02Woo2Sg_cWoo00@007ooOolm
k`AnH0Aoo`8000Eoo`03001oogoo00]oo`0037oo00<007ooOol01goo17o000<mkgooOol02Woo2Sg_
cGoo00D007ooOomoocg_00EnH0Eoo`03001oogoo009oo`03001oogoo00]oo`003Goo00<007ooOol0
1Woo17o000<mkgooOol02Woo2cg_bgoo00<007ooOol00Woo00<mkgiPOV0017iP1Goo00D007ooOomo
o`0000eoo`003Goo00<007ooOol01Woo1Go047oo23g_bGoo00<007ooOol017oo1GiP1goo00<007oo
00003Woo000=Ool00`00Oomoo`06Ool5Ol0@Ool8?No8Ool00`00Oomoo`05Ool00cg_OV1nH002OV08
Ool2000>Ool000eoo`03001oogoo00Ioo`Eo`11oo`PmklMoo`03001oogoo00Ioo`03?NmnH7iP009n
H0Qoo`8000ioo`003Goo00<007ooOol01Woo1Go000<mkgooOol03Goo23g_agoo00<007ooOol01Woo
00<mkgiPOV000WiP2Goo00<007ooOol037oo000=Ool00`00Oomoo`06Ool00cg_Ol1o`002Ol000cg_
Oomoo`0=Ool9?No5Ool00`00Oomoo`05Ool80008Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Mo
o`Ao`003?Nmoogoo00ioo`PmklEoo`03001oogoo00Aoo`03001oogoo00EnH003Ool007oo00Ioo`80
00eoo`003Goo00<007ooOol01goo17o000<mkgooOol03Woo23g_aGoo00<007ooOol00goo00@007oo
Oomoo`EnH09oo`03001oogoo00Aoo`8000eoo`003Goo00<007ooOol01goo17o00Sg_3goo2Sg_`goo
00<007ooOol00Woo00<007ooOol00Woo17iP00EnP7ooOomoo`0000Eoo`8000eoo`003Goo00<007oo
Ool01goo1Go000<mkgooOol03Goo2cg_`Woo00<007ooOol00Woo00D007ooOomoogj000AnH005OX1o
ogooOol00005Ool2000=Ool000eoo`03001oogoo00Moo`Eo`1=oo`Pmkl9oo`03001oogoo009oo`05
001oogooOomnP004OV001Cg_Oomoogoo00001Goo00<007ooOol037oo000>Ool00`00Oomoo`07Ool5
Ol0BOol7?No4Ool01@00Oomoogoo00000goo1Gj000EnX7ooOomoo`0000Eoo`03001oogoo00aoo`00
3Woo00<007ooOol01goo17o000<mkgooOol047oo23g_`goo00D007ooOomoo`0000=oo`EnP0Aoo`03
001oogoo009oo`8000ioo`003Woo00<007ooOol01goo17o000<mkgooOol0g7oo00@007ooOol000=o
o`AnP003OZ1oogoo009oo`03001oogoo009oo`8000ioo`003Woo00<007ooOol01goo17o00Sg_gGoo
00L007ooOomoo`00Oolmk`04OZ05Ool00`00Oomoo`02Ool2000>Ool000ioo`03001oogoo00Moo`Ao
`08mkmioo`05001oogooOol00006OZ03Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool000moo`03001o
ogoo00Ioo`Eo`08mkmeoo`03001oogoo009oo`03001nX7jP009nX09oo`8000Eoo`03001oogoo00io
o`003goo00<007ooOol01Woo1Go00Sg_gWoo00D007ooOomoogjP0080009nX08000Eoo`<0011oo`00
3goo00<007ooOol01goo1Go000<mkgooOol0gGoo0P0000@mkgjPOZ1nX08000Eoo`80009oo`03001o
ogoo00ioo`003goo00<007ooOol01goo17o00Sg_hGoo0P000gjP17oo0P0017oo00<007ooOol03Woo
000@Ool00`00Oomoo`06Ool4Ol02?NoQOol2OZ070005Ool00`00Oomoo`0?Ool0011oo`03001oogoo
00Ioo`Ao`003?Nmoogoo0>1oo`EnX0Uoo`03001oogoo00moo`0047oo00<007ooOol01Woo17o000<m
kgooOol0ggoo00<mkgjPOZ000WjP2Woo00<007ooOol03goo000@Ool00`00Oomoo`06Ool5Ol3QOol5
OZ0:Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Ioo`Io`>1oo`EnX0Yoo`03001oogoo00moo`00
47oo00<007ooOol01Woo1Go00Sg_gWoo00<mkgjPOZ000WjP00<mkgooOol027oo00<007ooOol03goo
000AOol00`00Oomoo`06Ool4Ol02?NoMOol2?Nl4OZ0:Ool00`00Oomoo`0@Ool0015oo`03001oogoo
00Ioo`Ao`003?Nmoogoo0=]oo`8mk`InX0Uoo`03001oogoo011oo`004Goo00<007ooOol01Woo17o0
00<mkgooOol0fgoo0Sg_1GjP2Woo00<007ooOol047oo000BOol00`00Oomoo`05Ool5Ol3LOol3?Nl5
OZ09Ool00`00Oomoo`0AOol0019oo`03001oogoo00Eoo`Eo`=aoo`8mk`InX0Uoo`03001oogoo015o
o`004Woo00<007ooOol01Woo1Go0fgoo0Sg_1GjP2Woo00<007ooOol04Goo000COol00`00Oomoo`05
Ool4Ol000cg_Oomoo`3IOol2?Nl5OZ09Ool00`00Oomoo`0BOol001=oo`03001oogoo00Eoo`Ao`003
?Nmoogoo0=Qoo`<mk`AnX0Yoo`03001oogoo019oo`004goo00<007ooOol01Goo1Go0fWoo0Sg_1GjP
2Woo00<007ooOol04Woo000DOol00`00Oomoo`04Ool5Ol000cg_Oomoo`3GOol2?Nl5OZ09Ool00`00
Oomoo`0COol001Aoo`03001oogoo00Aoo`03?Nmo`7o000=o`=Uoo`8mk`AnX0Yoo`03001oogoo01=o
o`005Goo00<007ooOol00goo00<mkgo0Ol000Wo000<mkgooOol0e7oo13g_1GjP2Woo00<007ooOol0
4goo000EOol00`00Oomoo`03Ool00cg_Ol1o`002Ol000cg_Oomoo`3COol5?Nl5OZ09Ool00`00Oomo
o`0DOol001Ioo`03001oogoo00=oo`Ao`003?Nmoogoo0==oo`@mk`InX0Uoo`03001oogoo01Aoo`00
5Woo00<007ooOol00goo1`00dgoo13g_1GjP2Goo00<007ooOol05Goo000GOol01P00Oomoogoo001o
`0AoX09oo`03001oogoo0=1oo`@mk`EnX0Qoo`03001oogoo01Ioo`005goo00H007ooOomoo`00Ol04
Oj0017o0Oomoo`00dGoo13g_17jP2Goo00<007ooOol05Woo000HOol01@00Ool007ooOl0017nP00Dm
kgooOomoo`000=1oo`<mk`InX0Moo`03001oogoo01Moo`0067oo00D007oo001oocg_00AoX005?Nmo
ogooOol0003?Ool4?Nl5OZ08Ool00`00Oomoo`0GOol001Qoo`80009oo`03?NmoX7nP00=oX005?Nmo
ogooOol0003=Ool5?Nl5OZ08Ool00`00Oomoo`0GOol001Uoo`04001oogooOol5Oj001Cg_Oomoogoo
0000bgoo1Sg_1WjP1goo00<007ooOol067oo000IOol01000Oomoogoo1GnP0Sg_0Woo00<007ooOol0
b7oo1cg_1GjP27oo00<007ooOol067oo000IOol20002Ool00gnP00000006003:Ool8?Nl5OZ07Ool0
0`00Oomoo`0IOol001Yoo`04001oo`000005Oj02?Nl20035Ool;?Nl6OZ07Ool00`00Oomoo`0IOol0
01]oo`800003OomoX7nP00=oX080008mk`800<=oo`/mk`EnX0Moo`03001oogoo01Yoo`006Woo00<0
07oo00000P000WnP0P001Cg_00=oo`00Ool0`Goo2cg_00=n`7jPOZ000WjP1goo00<007ooOol06Woo
000JOol01@00Ool007oo?Nl00P000WnP1Sg_00=oo`00Ool0`7oo23g_00=oocg_?Nl00Wk000=nX7k0
Ool01Woo00<007ooOol06goo000IOol01P00Oomoogoo001oo`EoX0Dmk`9oo`03001oogoo0;eoo`Dm
k`Eoo`03?Nmn`7k000=n`0Ioo`03001oogoo01aoo`006Goo00H007ooOomoo`00Ool5Oj06?Nl00goo
001oo`2nOol5?Nl5Ool00cg_O/1n`003O/06Ool00`00Oomoo`0LOol001Qoo`03001oogoo00=oo`03
001oX7n000=oP0Hmk`9oo`03001oogoo0;aoo`Dmk`Eoo`03?Nmn`7k000=n`0Eoo`03001oogoo01eo
o`0067oo00<007ooOol00goo00<007nPOh0017n01Cg_0Woo00<007ooOol0_7oo1Cg_1Goo00<mkgk0
O/000gk01Goo00<007ooOol07Goo000HOol00`00Oomoo`04Ool00cg_Oh1oP004Oh04?Nl2Ool00`00
Oomoo`2lOol5?Nl4Ool00cg_O/1n`004O/04Ool00`00Oomoo`0NOol001Qoo`03001oogoo00Aoo`03
001oP7n000EoP0@mk`03Ool007oo0;aoo`Hmk`Aoo`03?Nmn`7k000=n`003?Nmoogoo009oo`03001o
ogoo01ioo`006Goo00<007ooOol017oo27n00cg_00<007ooOol0_7oo1Cg_17oo00<mkgk0O/0017k0
17oo00<007ooOol07goo000IOol00`00Oomoo`05Ool8Oh02?Nl00`00Oomoo`2kOol5?Nl500000cg_
O/1n`003O/04Ool00`00Oomoo`0POol001Yoo`03001oogoo00Aoo`03?NmoP7n000IoP003?Nl007oo
0;aoo`<mk`8000Aoo`04?Nl000000003O/03Ool00`00Oomoo`0QOol001Yoo`03001oogoo00Eoo`8m
k`IoP003000mkcg_0;aoo`8mk`03000mkgoo00Aoo`07?Nmn`7k0O/0007k0?Nl00goo00<007ooOol0
8Goo000KOol00`00Oomoo`05Ool00`00Oh1oP004Oh000`00Oh0mk`2kOol2?Nl00`00?Nlmk`05Ool0
0cg_O/1n`002O/001@00Oomoogoo000097oo000LOol00`00Oomoo`05Ool01000?Nlmkgn00P000Wn0
0Sg_^Woo00<mk`00?Nl00Sg_17oo00<mkgk0O/0017k000<007oo00009Goo000LOol40004Ool01000
Ool000001Gn00Sg_^7oo00<mk`00?Nl00Sg_1Goo00<mkgk0O/000gk00Woo0P009Goo000POol60000
0gooOh1oP005Oh02?NnfOol00cg_000mk`03?Nl4Ool00cg_O/1n`004O/02Ool00`00Oomoo`0TOol0
02Ioo`03000mkcg_00IoP0@mkk=oo`03?Nl003g_00<mk`=oo`8mk`En`09oo`8002Ioo`009goo00<0
03g_?Nl01Wn013g_/Woo00<mk`00?Nl00cg_0Woo0Sg_1Wk000Eoo`00Oomoo`0002Eoo`00:7oo00<0
07oo?Nl01Wn00cg_/Goo00<mk`00?Nl00cg_0Woo00<mkgk0O/001Gk000<mk`00Ool00Woo00<007oo
Ool08goo000YOol00`00?Nlmk`05Oh0017mP?Nlmkcg_/7oo00<mk`00?Nl00Sg_0Woo00<mkgkPO/00
1Wk000<007ooOol00Woo00<007ooOol08goo000ZOol00`00Oomoo`03Oh03Of02?Nn`Ool013g_000m
kcg_0Woo00<mkgkPO^001Gk00Sg_1Goo00<007ooOol08goo000ZOol01@00Oomoocg_Oh001GmP0Sg_
[Woo0cg_00D003g_Oomoocg_009nh0An`08mk`03001oogoo00=oo`03001oogoo02=oo`00:goo00@0
07oo?Nlmk`IoH08mkjeoo`<mk`03000mkgoo00Anh0An`003?Nl007oo00Aoo`03001oogoo02Aoo`00
;7oo00@007ooOolmk`IoH003?Nmoogoo0:Yoo`Dmk`03001nh7kP00Inh003?Nl007oo00Eoo`03001o
ogoo02Aoo`00;Goo00@007oo?Nlmk`IoH003?Nmoogoo0:Uoo`Dmk`03O^0007kP00Enh003?Nl007oo
00Eoo`03001oogoo02Eoo`00;Woo00@007ooOolmk`IoH08mkjUoo`<mk`=nh003001nh7kP00=nh003
?Nl007oo00Aoo`8002Qoo`00;goo00@007ooOolmk`IoH08mkjMoo`<mk`Enh080009nh003Ool007oo
00Aoo`03001oogoo02Qoo`00<7oo00@007ooOolmk`IoH0<mkjAoo`8mk`Unh0<000Aoo`8002]oo`00
<7oo00<007ooOol00Woo27mP0Sg_XGoo0Sg_27kP00@mkgooOomoo`D002eoo`00<Goo00<007ooOol0
0Woo27mP13g_WGoo0Sg_2GkP0goo00<007ooOol0<7oo000bOol20002Ool00cg_Of1oH005Of05?NnK
Ool2?Nl7O^02?Nl2Ool2000cOol003Aoo`04001oogoo?Nl7Of05?NnIOol2?Nl8O^02?Nl00goo001o
o`0dOol003Eoo`05001oogooOolmk`06Of04?NnFOol3?Nl7O^001Sg_Oomoogoo?Nl003Ioo`00=Woo
00D007ooOomoocg_00IoH0<mkiIoo`8mk`Mnh003?Nmoogoo009oo`03001oogoo03Eoo`00=goo00D0
07ooOomoocg_00IoH0<mkiAoo`8mk`Mnh0Eoo`03001oogoo03Ioo`00>7oo00D007ooOomoocg_00Io
H0<mki9oo`8mk`Mnh0Eoo`03001oogoo03Moo`00>Goo0P000Woo00<mkgmPOf0017mP0Sg_TGoo2WkP
0goo0P00>Woo000kOol01000Oomoocg_27mPSgoo27kP0Sg_0goo00<007ooOol0>Woo000lOol01000
Oomoocg_27mPSGoo2GkP00DmkgooOomoo`0003eoo`00?Goo00@007ooOolmk`MoH08mkhUoo`Ynh005
?NmoogooOol0000nOol003ioo`800003OolmkgmP00IoH08mkhMoo`Unh08mk`9oo`8003moo`00@7oo
00@007ooOolmk`MoH08mkh=oo`03O`1nh7kP00Enh08mk`Aoo`03001oogoo03moo`00@Goo0P0000=o
ogmPOf001GmP13g_P7oo27kP00<mkgooOol00Woo0P00@Woo0013Ool00`00Of1oH007Of03?NmiOol5
?Nl00gl0O^1nh006O^04Ool00`00Oomoo`12Ool004Aoo`03000mkgmP00QoH003?Nmoogoo00Aoo`03
?Nmoogoo071oo`<mk`=o00Enh08mk`Aoo`03001oogoo04=oo`00AGoo0P002WmP00<mkgooOol00Woo
0Sg_L7oo0cg_17l01GkP17oo0P00AWoo0017Ool<Of000cg_Oomoo`03?Nm^Ool2?Nl8O`000cg_Oomo
o`02Ool20018Ool004Uoo`]oH09o@0@mkfaoo`8mk`Qo008mk`9oo`8004Yoo`00Bgoo2GmP1Gm00Sg_
JGoo0cg_2Gl00Woo0P00C7oo001<Ool00cg_Of1oH004Of08Od02?NmVOol00cg_O`1o0007O`02?Nl0
0goo0000001>Ool004moo`AoH0ao@003?Nmoogoo061oo`]o009oo`03001oogoo04ioo`00D7oo00@0
07mPOf1oH0eo@08mkeeoo`03?Nmo07l000Mo0003?Nmoogoo0080055oo`00DWoo00<003g_?Nl047m0
00<mkgooOol08Goo0`00;goo00<mkgoo?Nl02gl00Sg_0P00Dgoo001DOol200000cg_Od1o@00>Od02
?Nl7Ool5?Nl?Ool50003Ool2000WOol6?Nl>O`02001EOol005Ioo`80009ooa5o@004OolmkgooOol6
?Nl=Ool2000:Ool2000TOol3?Nl2O`000cg_O`1o000:O`02?Nl00`00Oomoo`1EOol005Qoo`<0009o
o`mo@003?Nmo@3g_00Hmk`aoo`03001oogoo00aoo`8001moo`9o0003?Nmo07l000io008mk`03001o
ogoo05Moo`00Fgoo0`000Woo4Gm013g_37oo00<007ooOol03Woo00<007ooOol067oo0Wl000<mkgl0
O`004Gl00Sg_Fgoo001NOol00`00Oomoo`02OolAOd02?Nl:Ool00`00Oomoo`0@Ool00`00Oomoo`0>
Ool2O`04OolFO`03?NmMOol005moo`8000Eoo`mo@003?Nmo@3g_00Dmk`=oo`03001oogoo00moo`03
?Nl007oo00Yoo`9o008mkaYo0003?Nl00000061oo`00HGoo100017oo3gm00Sg_00Io@3g_?Nlmkgoo
000;Ool9?Nl00`00Oomoo`02Ool2O`000cg_O`1o000IO`05?Nl00`00Oomoo`1QOol006Eoo`<000Ao
oa1o@004?Nmo@3g_000C?Nl00glP000mk`0MO`07?NmVOol006Qoo`D0009oo`03?Nmo@7m000ao@005
000mkcg_?Nmo@00??Nl3Ob000`00O`1o000EO`06?Nl40002?NmWOol006eoo`<0009oo`ao@003001o
@7m000=o@08mk`mo8003001o07l000io00Pmk`04Ool00000001^Ool0071oo`D000Qo@003001o@7m0
00Io@0mo8003001o07l000Mo00Dmk`Ioo`D0075oo`00MGoo10001Gm000<007m0Od001Gm03glP00@0
07l0O`1o80Dmk`Eoo`L007Ioo`00O7oo0Wm000<007m0Od001Gm03glP00<007ooOol00goo2000OGoo
001nOol00`00Oomoo`05Od05Ob000cg_0000000=0025Ool007ioo`03001oogoo01Aoo`03001oogoo
08Qoo`00Ogoo00<007ooOol04Woo00<007ooOol0RGoo001oOol00`00Oomoo`0BOol00`00Oomoo`29
Ool0081oo`03001oogoo00moo`8008aoo`00PGoo00<007ooOol03Goo00<007ooOol0S7oo0022Ool0
0`00Oomoo`0;Ool00`00Oomoo`2=Ool008=oo`03001oogoo00Qoo`80091oo`00Q7oo1@0000=oo`00
00000P00TWoo0029Ool00`00Oomoo`2DOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool008Yoo`D0009oo`8008eoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00S7oo00D0
07ooOomoo`00009oo`03001oogoo08Yoo`00S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00
S7oo00D007ooOomoo`00009oo`03001oogoo08Yoo`00Rgoo0P0017oo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -186.431, 1.30024, \
1.37309}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00280112 0.497213 0.00273065 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(11)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.47619 0.464211 scale
1.05 1.07109 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.08438 .3952 m
.08448 .39507 L
.08463 .39488 L
.08481 .39462 L
.08501 .39429 L
.08522 .39386 L
.08542 .39334 L
.08562 .39273 L
.08581 .39207 L
.08602 .39133 L
.08626 .3905 L
.08654 .3896 L
.08686 .38869 L
.08716 .38775 L
.08743 .3868 L
.08772 .3859 L
.088 .38506 L
.08829 .38423 L
.08859 .38337 L
.08891 .38248 L
.08923 .38155 L
.08951 .38063 L
.08973 .37966 L
.08987 .37862 L
.08993 .37752 L
.0899 .37645 L
.08981 .37526 L
.08971 .37409 L
.08963 .3729 L
.08956 .37163 L
.08951 .37033 L
.0895 .36914 L
.0895 .36796 L
.08949 .36686 L
.08949 .3659 L
.08952 .36504 L
.08958 .3643 L
.08969 .36366 L
.08983 .36308 L
.09 .36248 L
.09019 .36183 L
.09037 .3611 L
.09055 .36026 L
.09073 .35927 L
.09096 .35812 L
.09126 .35704 L
.09164 .35574 L
.0921 .35439 L
.09264 .35279 L
.09322 .35129 L
Mistroke
.09382 .34957 L
.09442 .34768 L
.09499 .34592 L
.09554 .34409 L
.09606 .34231 L
.09658 .34056 L
.09711 .33915 L
.09765 .33771 L
.09819 .33642 L
.09867 .33533 L
.09908 .33432 L
.09941 .33351 L
.09966 .33285 L
.09987 .33236 L
.10005 .33203 L
.10024 .33188 L
.10045 .33187 L
.10063 .33198 L
.10076 .33215 L
.10083 .33233 L
.10083 .33245 L
.10076 .33246 L
.10062 .33232 L
.10043 .33203 L
.10021 .33159 L
.09997 .331 L
.09971 .33029 L
.09945 .32947 L
.09919 .32867 L
.09893 .32777 L
.09868 .32682 L
.09844 .32584 L
.09823 .32501 L
.09807 .32426 L
.09794 .32366 L
.09785 .32327 L
.09779 .32312 L
.09776 .32325 L
.09778 .3236 L
.09782 .3241 L
.09787 .32467 L
.09794 .32525 L
.09806 .32576 L
.09823 .32617 L
.09845 .32645 L
.09873 .32657 L
.09906 .32652 L
.09944 .32629 L
.09988 .32587 L
.10037 .32529 L
Mistroke
.1009 .3246 L
.10147 .3238 L
.10202 .32292 L
.10254 .322 L
.10305 .32115 L
.10353 .32045 L
.10397 .31986 L
.10439 .31935 L
.10479 .31889 L
.10519 .31848 L
.1056 .31808 L
.10604 .31766 L
.10652 .31716 L
.10703 .31655 L
.10757 .31582 L
.10816 .31493 L
.1088 .31385 L
.10946 .31271 L
.11008 .3113 L
.1107 .30972 L
.11132 .30818 L
.11189 .30649 L
.11238 .3048 L
.11278 .30311 L
.1131 .3016 L
.11332 .30018 L
.11347 .29892 L
.11356 .29789 L
.11358 .29702 L
.11356 .29628 L
.11352 .2957 L
.11346 .29524 L
.1134 .29495 L
.11333 .2948 L
.11327 .29477 L
.11321 .29485 L
.11316 .295 L
.11312 .29517 L
.11309 .29534 L
.11309 .29546 L
.11315 .29552 L
.11331 .29549 L
.11361 .29537 L
.11404 .29511 L
.11463 .29473 L
.11536 .29423 L
.11625 .29358 L
.11731 .29281 L
.11842 .29194 L
.11967 .29101 L
Mistroke
.12087 .28999 L
.12212 .28895 L
.12336 .28794 L
.12444 .28707 L
.12548 .28633 L
.12644 .28572 L
.12728 .28523 L
.12797 .28484 L
.12853 .28452 L
.129 .2842 L
.12937 .28386 L
.12968 .28344 L
.12996 .28293 L
.13026 .28232 L
.13061 .28159 L
.131 .28074 L
.13143 .27987 L
.13189 .27892 L
.13238 .27793 L
.13287 .2769 L
.13336 .27596 L
.13384 .27508 L
.13429 .27432 L
.1347 .27373 L
.13507 .2733 L
.13539 .27298 L
.13564 .27274 L
.13582 .27251 L
.13594 .27224 L
.13603 .27186 L
.1361 .27134 L
.13619 .27067 L
.13631 .26988 L
.13647 .26902 L
.13664 .26825 L
.13684 .26721 L
.13706 .26624 L
.13727 .26519 L
.13747 .26406 L
.13764 .26285 L
.13778 .26164 L
.13789 .2604 L
.13801 .25909 L
.13814 .25773 L
.1383 .2565 L
.13846 .25507 L
.13867 .25362 L
.13892 .2521 L
.13923 .25051 L
.13964 .2488 L
Mistroke
.14014 .24733 L
.14076 .24587 L
.1415 .24444 L
.14228 .24312 L
.14313 .24191 L
.14402 .24075 L
.14494 .23961 L
.14581 .23851 L
.14671 .23738 L
.1476 .23628 L
.14857 .23521 L
.14952 .23412 L
.15056 .233 L
.15171 .23186 L
.15289 .23072 L
.15413 .22951 L
.1554 .22833 L
.15654 .22712 L
.15766 .22592 L
.15872 .22477 L
.15972 .22381 L
.16067 .22284 L
.16146 .22195 L
.16215 .22125 L
.1627 .22065 L
.16311 .22013 L
.16339 .21969 L
.16351 .21931 L
.16352 .21897 L
.16346 .21866 L
.16339 .21832 L
.16332 .21793 L
.16328 .21743 L
.16326 .21686 L
.16326 .21631 L
.16324 .21587 L
.16318 .21549 L
.16308 .21527 L
.16294 .21526 L
.16275 .21546 L
.16251 .21591 L
.16224 .21657 L
.16195 .2174 L
.16165 .21825 L
.16137 .21934 L
.1611 .22034 L
.16088 .22133 L
.16072 .22223 L
.16066 .22298 L
.16071 .22354 L
Mistroke
.16091 .22388 L
.16125 .22403 L
.16173 .22406 L
.16232 .22401 L
.16302 .22391 L
.1638 .2238 L
.16461 .22373 L
.16534 .22371 L
.16601 .22372 L
.16657 .22374 L
.16697 .22374 L
.16721 .22375 L
.16727 .22374 L
.16717 .22371 L
.16698 .22365 L
.16672 .22356 L
.16633 .22346 L
.16586 .22334 L
.16527 .22325 L
.16457 .22323 L
.1638 .2233 L
.16296 .22349 L
.16206 .22383 L
.1611 .22434 L
.16008 .22504 L
.15901 .22596 L
.15802 .22703 L
.15693 .22833 L
.15568 .22983 L
.15413 .23146 L
.15273 .23305 L
.15127 .23475 L
.14976 .23653 L
.14833 .23823 L
.14687 .23979 L
.14544 .24132 L
.14415 .24284 L
.14295 .24421 L
.14174 .24559 L
.14051 .24702 L
.13927 .24852 L
.1381 .25 L
.137 .25159 L
.13592 .25333 L
.13488 .25523 L
.13392 .25704 L
.13302 .25908 L
.13217 .26105 L
.13136 .26307 L
.13065 .26494 L
Mistroke
.13006 .26656 L
.12958 .26803 L
.12923 .26929 L
.12897 .27024 L
.12877 .27099 L
.12859 .27159 L
.12841 .27204 L
.12819 .2724 L
.12788 .27272 L
.12747 .27305 L
.12697 .27341 L
.12639 .2738 L
.12573 .27424 L
.12509 .27474 L
.12428 .27539 L
.1235 .27613 L
.12264 .27699 L
.12172 .27796 L
.12078 .27902 L
.11987 .28017 L
.119 .2814 L
.11823 .28259 L
.11745 .28387 L
.1167 .28519 L
.11598 .28654 L
.11528 .28785 L
.11457 .28926 L
.11392 .29079 L
.11341 .29231 L
.11302 .29377 L
.11269 .29519 L
.11239 .29659 L
.11208 .29775 L
.11172 .29896 L
.11124 .30007 L
.11062 .30126 L
.10995 .30252 L
.10908 .30373 L
.10808 .30497 L
.107 .30624 L
.10597 .30753 L
.10488 .30883 L
.10369 .31003 L
.10243 .31127 L
.10117 .31254 L
.10008 .31388 L
.09911 .31515 L
.09828 .31647 L
.09758 .31785 L
.09701 .31926 L
Mistroke
.09655 .32059 L
.09619 .3219 L
.09591 .32323 L
.09569 .32463 L
.09552 .32606 L
.09537 .32754 L
.09524 .32906 L
.09508 .33059 L
.0949 .33197 L
.0947 .33323 L
.09451 .33434 L
.09433 .33531 L
.09413 .33617 L
.09389 .33688 L
.09362 .33751 L
.09333 .33808 L
.09303 .33861 L
.09274 .33913 L
.09247 .33969 L
.09221 .34034 L
.09195 .34112 L
.09169 .34208 L
.09142 .34318 L
.0911 .34443 L
.09072 .34591 L
.09028 .34769 L
.0898 .34951 L
.08933 .35155 L
.08888 .35376 L
.08848 .35572 L
.08811 .35799 L
.08775 .36002 L
.08741 .36222 L
.08708 .36461 L
.08674 .36702 L
.08641 .36916 L
.0861 .37137 L
.08582 .37371 L
.08559 .3761 L
.08541 .37812 L
.08524 .38028 L
.08507 .38234 L
.08492 .38434 L
.08477 .38625 L
.08464 .38795 L
.08451 .38948 L
.08444 .39078 L
.08441 .39188 L
.0844 .39278 L
.08442 .39349 L
Mistroke
.08445 .39405 L
.08447 .39449 L
.08447 .39488 L
.08447 .39529 L
.08446 .39575 L
.08445 .39629 L
.08444 .39695 L
.08443 .39774 L
.08441 .39856 L
.08439 .39949 L
.08438 .40049 L
.08436 .40155 L
.08434 .40262 L
.08432 .40354 L
.08431 .4044 L
.0843 .40515 L
.08429 .40578 L
.08428 .40624 L
.08427 .40652 L
Mfstroke
.0843 .40624 m
.08431 .40608 L
.08431 .40586 L
.08429 .40559 L
.08426 .40523 L
.08422 .40496 L
.08421 .40455 L
.08422 .40411 L
.08427 .40362 L
.08436 .40295 L
.08451 .40229 L
.08473 .40175 L
.08498 .40102 L
.08526 .4003 L
.08553 .39952 L
.08578 .39866 L
.08603 .39764 L
.08628 .39677 L
.08654 .39587 L
.08679 .39483 L
.087 .39365 L
.08714 .39247 L
.08722 .3915 L
.08725 .39044 L
.08726 .38935 L
.08724 .3884 L
.08721 .38747 L
.0872 .38659 L
.08721 .38584 L
.08722 .38524 L
.08723 .38472 L
.08723 .38429 L
.08723 .38395 L
.08724 .38372 L
.08724 .38358 L
.08724 .38352 L
.08724 .38351 L
.08724 .38354 L
.08724 .3836 L
.08724 .38368 L
.08724 .38374 L
.08724 .38376 L
.08724 .38377 L
.08724 .38377 L
.08723 .38378 L
.08723 .38382 L
.08723 .38389 L
.08723 .38395 L
.0872 .38398 L
.08716 .38396 L
Mistroke
.08713 .38387 L
.08712 .3837 L
.08714 .38344 L
.0872 .38308 L
.08731 .38267 L
.08747 .38222 L
.08768 .38175 L
.08794 .38128 L
.08825 .38081 L
.08859 .38035 L
.08888 .37989 L
.08913 .3795 L
.08937 .37921 L
.08961 .37907 L
.08978 .37911 L
.08982 .37931 L
.08972 .37964 L
.08952 .38007 L
.08926 .38056 L
.08897 .38107 L
.08865 .38145 L
.08835 .38172 L
.08806 .38204 L
.0878 .38241 L
.0876 .38282 L
.08744 .38321 L
.08732 .38358 L
.08724 .38397 L
.08718 .38447 L
.08708 .38517 L
.08694 .38609 L
.08675 .3872 L
.08648 .38845 L
.08625 .3897 L
.08595 .39137 L
.08567 .39354 L
.08542 .39518 L
.08515 .39749 L
.08487 .39934 L
.08461 .40133 L
.0844 .40344 L
.08427 .40492 L
.08419 .40648 L
.08414 .40795 L
.08413 .40893 L
.08415 .40973 L
.08417 .41036 L
.08419 .41082 L
.08419 .41108 L
Mfstroke
.11421 .46695 m
.11439 .46704 L
.11462 .46717 L
.1149 .46734 L
.11523 .46754 L
.11562 .46777 L
.11603 .46806 L
.11655 .46845 L
.11707 .46891 L
.11765 .46948 L
.11831 .47018 L
.11899 .47094 L
.11961 .47166 L
.12027 .4725 L
.12087 .47332 L
.12145 .47415 L
.12199 .47495 L
.1225 .4757 L
.12298 .47635 L
.12341 .47691 L
.1238 .4774 L
.12411 .47779 L
.12431 .47804 L
.1244 .47818 L
.12438 .47829 L
.1243 .47844 L
.12419 .47869 L
.12409 .47902 L
.12404 .47943 L
.12408 .47995 L
.12425 .48055 L
.12456 .48119 L
.12501 .48187 L
.12557 .48253 L
.12624 .48317 L
.12696 .48373 L
.12764 .48421 L
.12833 .48459 L
.12902 .48483 L
.12975 .48497 L
.13039 .48501 L
.13097 .48501 L
.13148 .48503 L
.13191 .4851 L
.13226 .48526 L
.13254 .48553 L
.1328 .48588 L
.13303 .48625 L
.13327 .48667 L
.13349 .48709 L
Mistroke
.13369 .48748 L
.13385 .48788 L
.13396 .48825 L
.134 .48859 L
.13395 .48886 L
.13382 .48903 L
.13361 .48908 L
.13333 .48907 L
.13301 .48902 L
.13268 .48894 L
.13236 .48889 L
.13209 .48898 L
.13189 .48926 L
.13177 .48973 L
.13173 .49039 L
.13178 .49121 L
.13191 .49217 L
.13209 .49322 L
.13232 .49418 L
.13256 .49518 L
.13277 .49618 L
.13298 .49715 L
.13314 .49809 L
.13331 .49877 L
.13347 .49943 L
.13362 .49997 L
.13375 .50041 L
.13388 .50083 L
.13404 .50129 L
.13426 .50188 L
.13454 .50266 L
.13492 .50363 L
.13538 .50465 L
.13592 .50586 L
.13652 .50722 L
.13717 .50874 L
.13782 .51021 L
.13837 .51155 L
.13891 .51285 L
.13937 .51391 L
.13982 .51484 L
.14026 .51563 L
.14069 .51623 L
.14113 .51666 L
.14158 .51696 L
.14205 .51716 L
.14254 .51732 L
.143 .51743 L
.14346 .51753 L
.1439 .51766 L
Mistroke
.14438 .51784 L
.14489 .51805 L
.14538 .51828 L
.14581 .51846 L
.14613 .51859 L
.1463 .51863 L
.14632 .51855 L
.14621 .51834 L
.146 .51804 L
.14571 .5177 L
.14538 .51734 L
.14503 .51701 L
.1447 .51677 L
.14438 .51665 L
.14409 .51669 L
.14384 .51695 L
.14367 .5175 L
.14358 .51836 L
.14358 .51957 L
.14365 .52099 L
.14376 .52263 L
.14392 .52457 L
.1441 .5268 L
.14431 .52884 L
.14453 .53123 L
.14477 .53333 L
.14504 .53552 L
.1453 .53769 L
.14557 .53943 L
.14584 .541 L
.1461 .54238 L
.14632 .54349 L
.14652 .54432 L
.1467 .54495 L
.14689 .54539 L
.14707 .54567 L
.14724 .54586 L
.14739 .54597 L
.14747 .54602 L
.1475 .54599 L
.14748 .54591 L
.14743 .54579 L
.14737 .54567 L
.14734 .54557 L
.14734 .54556 L
.14739 .54564 L
.14751 .54582 L
.1477 .5461 L
.148 .54647 L
.14841 .54693 L
Mistroke
.14893 .54747 L
.14955 .54807 L
.15027 .54872 L
.15108 .54946 L
.15192 .55026 L
.15282 .55109 L
.15376 .55191 L
.15469 .55268 L
.15554 .5534 L
.15636 .55409 L
.15712 .55477 L
.1578 .55542 L
.15838 .55607 L
.15885 .55673 L
.15922 .55745 L
.1595 .55819 L
.15969 .55892 L
.1598 .55956 L
.15984 .56008 L
.1598 .56051 L
.15969 .56084 L
.15949 .56103 L
.15921 .56105 L
.15888 .56091 L
.15851 .56063 L
.15817 .56024 L
.15787 .55978 L
.15762 .55928 L
.15747 .55874 L
.15747 .55822 L
.15767 .55776 L
.15809 .5574 L
.15876 .55716 L
.15962 .557 L
.16074 .55691 L
.16203 .55688 L
.16355 .55688 L
.16511 .5569 L
.16675 .55689 L
.16815 .55687 L
.1695 .55682 L
.17054 .55678 L
.17134 .55677 L
.17182 .55679 L
.17193 .55682 L
.17169 .55687 L
.17118 .55692 L
.17044 .55695 L
.16952 .55699 L
.1686 .55704 L
Mistroke
.16761 .55709 L
.16655 .55714 L
.16553 .55713 L
.16466 .55702 L
.16396 .55676 L
.16343 .55631 L
.16301 .55564 L
.16267 .55474 L
.16236 .55355 L
.16205 .55204 L
.16168 .55021 L
.16119 .54839 L
.16058 .54623 L
.15984 .5437 L
.15897 .54126 L
.15809 .53861 L
.15707 .53579 L
.15598 .53311 L
.1549 .53058 L
.1538 .52818 L
.15273 .52584 L
.15179 .52408 L
.15098 .52244 L
.1503 .52107 L
.14978 .52009 L
.14942 .51928 L
.14918 .51868 L
.14898 .51827 L
.14877 .518 L
.1485 .51783 L
.1481 .51774 L
.14751 .51768 L
.1467 .51764 L
.14565 .51756 L
.14448 .51742 L
.14307 .51721 L
.14144 .51693 L
.13966 .51658 L
.13802 .51621 L
.13636 .51583 L
.13475 .51548 L
.13329 .51519 L
.13207 .51492 L
.13112 .5147 L
.13039 .51446 L
.12989 .51416 L
.1296 .51374 L
.1295 .51327 L
.12958 .51281 L
.12976 .51221 L
Mistroke
.13003 .51152 L
.13035 .5107 L
.13066 .5097 L
.13094 .5086 L
.1311 .50731 L
.1311 .50578 L
.13094 .50406 L
.13068 .50226 L
.13034 .50052 L
.12996 .49866 L
.12956 .49714 L
.12916 .49569 L
.12879 .49457 L
.12848 .49364 L
.12822 .49292 L
.12804 .49251 L
.12793 .49226 L
.12789 .49215 L
.12792 .49217 L
.12803 .49234 L
.12819 .49264 L
.12839 .49303 L
.12858 .49343 L
.12876 .49378 L
.12891 .49405 L
.12901 .4942 L
.12907 .49422 L
.12907 .49408 L
.12905 .49378 L
.12902 .49338 L
.129 .49293 L
.12901 .49245 L
.12902 .49197 L
.12904 .49151 L
.12906 .49106 L
.12908 .49062 L
.12914 .49019 L
.12928 .48981 L
.1295 .48953 L
.12972 .48937 L
.12988 .48933 L
.12994 .48936 L
.12986 .48942 L
.1296 .48949 L
.12902 .4895 L
.12805 .48941 L
.12672 .4892 L
.12504 .48886 L
.12299 .48843 L
.12101 .48792 L
Mistroke
.11853 .48736 L
.1159 .48679 L
.11321 .48622 L
.11041 .48566 L
.1077 .48514 L
.10474 .48465 L
.10239 .48422 L
.10015 .48383 L
.09785 .48346 L
.09582 .48312 L
.09386 .48279 L
.09199 .48245 L
.09027 .48211 L
.08881 .48177 L
.0878 .48143 L
.08656 .48109 L
.08561 .48073 L
.08467 .48032 L
.08374 .47986 L
.08287 .47937 L
.08207 .47888 L
.08133 .47838 L
.08064 .47786 L
.08002 .47729 L
.07945 .47667 L
.07891 .47603 L
.07826 .47531 L
.07757 .47448 L
.07687 .47352 L
.0762 .47256 L
.07561 .4716 L
.07513 .4707 L
.07478 .46989 L
.07458 .46922 L
.07452 .46866 L
.07459 .46822 L
.07477 .46791 L
.07502 .4677 L
.0753 .46757 L
.07561 .46747 L
.07592 .46738 L
.0762 .46725 L
.07645 .46705 L
.07669 .46678 L
.07693 .46644 L
.07717 .46601 L
.07741 .46554 L
.07765 .46507 L
.07789 .46462 L
.07813 .46417 L
Mistroke
.07836 .46375 L
.07859 .46337 L
.07883 .46306 L
.07907 .46285 L
.07933 .46273 L
.0796 .46269 L
.07984 .46271 L
.08005 .46277 L
.08021 .46284 L
Mfstroke
.08429 .40207 m
.0843 .40195 L
.08432 .40173 L
.08436 .40138 L
.08441 .40088 L
.08449 .4002 L
.08459 .39931 L
.08472 .39818 L
.08489 .3968 L
.0851 .39522 L
.08529 .39326 L
.08547 .39117 L
.08569 .38877 L
.08595 .38615 L
.08623 .38366 L
.08648 .38063 L
.08677 .37807 L
.08707 .37502 L
.08739 .37223 L
.08773 .36925 L
.08811 .36589 L
.08852 .36328 L
.08894 .3605 L
.08937 .35772 L
.08979 .3549 L
.09022 .35199 L
.09066 .34976 L
.09111 .34719 L
.09157 .34482 L
.09202 .34263 L
.09246 .34048 L
.09289 .33866 L
.09331 .33695 L
.0937 .33558 L
.09406 .3344 L
.09438 .3335 L
.09467 .33278 L
.09491 .33226 L
.09511 .33193 L
.09528 .33174 L
.09541 .33165 L
.0955 .33166 L
.09555 .33173 L
.09556 .33184 L
.09555 .33195 L
.09551 .33205 L
.09546 .33211 L
.09543 .33212 L
.09542 .33213 L
.09542 .33213 L
Mistroke
.09542 .33213 L
.09542 .33213 L
.09542 .33213 L
.09542 .33213 L
.09542 .33213 L
.09542 .33213 L
.09542 .33213 L
.09543 .33216 L
.09546 .33221 L
.0955 .33228 L
.09554 .33235 L
.09556 .33237 L
.09554 .33235 L
.09548 .33225 L
.09538 .33206 L
.09522 .33178 L
.09501 .33142 L
.09475 .33096 L
.09444 .33043 L
.09413 .32988 L
.09386 .3294 L
.09361 .32901 L
.0934 .32869 L
.09326 .32845 L
.09319 .3283 L
.09322 .32826 L
.09334 .32832 L
.09354 .32846 L
.09378 .32864 L
.09407 .32884 L
.09436 .32901 L
.09467 .32913 L
.09495 .32916 L
.09518 .32906 L
.09536 .32879 L
.09548 .32837 L
.09555 .32781 L
.09558 .32714 L
.09557 .32643 L
.09554 .32573 L
.0955 .32509 L
.09546 .32453 L
.09545 .32407 L
.09545 .3237 L
.09545 .32341 L
.09545 .32317 L
.09545 .323 L
.09545 .3229 L
.09545 .32287 L
.09545 .3229 L
Mistroke
.09545 .32296 L
.09545 .32304 L
.09545 .3231 L
.09545 .32312 L
.09545 .32313 L
.09544 .32313 L
.09541 .32315 L
.09537 .3232 L
.09533 .32327 L
.09531 .32334 L
.09532 .32337 L
.09538 .32335 L
.09548 .32325 L
.09563 .32308 L
.09583 .32282 L
.09606 .32248 L
.09631 .32208 L
.09657 .32165 L
.09684 .32119 L
.09709 .32074 L
.09735 .32029 L
.09759 .31985 L
.0978 .31944 L
.09797 .31907 L
.09809 .31878 L
.09815 .31858 L
.09817 .31847 L
.09816 .31843 L
.09812 .31845 L
.09808 .31852 L
.09805 .31859 L
.09803 .31865 L
.09803 .31867 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31868 L
.09803 .31869 L
.09803 .31873 L
.09801 .31878 L
.09798 .31886 L
.09793 .31895 L
.09789 .319 L
Mistroke
.09785 .31901 L
.09783 .31896 L
.09784 .31881 L
.09792 .31852 L
.09807 .3181 L
.09829 .31754 L
.09858 .31684 L
.09895 .31606 L
.09939 .31513 L
.09989 .31412 L
.10046 .31308 L
.10108 .31199 L
.10175 .31088 L
.1024 .30981 L
.10304 .30885 L
.10364 .30799 L
.10419 .30724 L
.10464 .30664 L
.10501 .30618 L
.1053 .30583 L
.10552 .30558 L
.10567 .30539 L
.10578 .30527 L
.10585 .30521 L
.10588 .30518 L
.10588 .30519 L
.10586 .3052 L
.10582 .30522 L
.10578 .30526 L
.10574 .3053 L
.10573 .30533 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
Mistroke
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10573 .30534 L
.10572 .30534 L
.10571 .30534 L
.10567 .30534 L
.10563 .30534 L
.10559 .30534 L
.10555 .30534 L
.10555 .30535 L
.1056 .30538 L
.10571 .30542 L
.10587 .30545 L
.10608 .30547 L
.10634 .30548 L
.10665 .30547 L
.10698 .30544 L
.1073 .30538 L
.10761 .3053 L
.1079 .30518 L
.10819 .30501 L
.10844 .30476 L
.10868 .30439 L
.10893 .30395 L
.1092 .30342 L
.10954 .30277 L
.11003 .30208 L
.11067 .30122 L
.11139 .30022 L
.11236 .29907 L
.11344 .29786 L
.11477 .29655 L
.11614 .29515 L
.11765 .29375 L
.11913 .29239 L
.12057 .29123 L
.12169 .29018 L
.12292 .28917 L
.12389 .28834 L
.12473 .28754 L
.12541 .28673 L
.12599 .2859 L
Mistroke
.12652 .28501 L
.12703 .28398 L
.12755 .28278 L
.12811 .28139 L
.12868 .27997 L
.12916 .27848 L
.12974 .27664 L
.13035 .27484 L
.13103 .27288 L
.13162 .27079 L
.13218 .269 L
.1327 .26721 L
.13317 .26547 L
.13362 .26383 L
.13409 .26237 L
.13461 .26097 L
.13522 .25958 L
.13591 .25814 L
.1368 .25665 L
.1378 .25533 L
.13898 .2538 L
.1403 .25222 L
.14177 .25068 L
.14326 .24902 L
.14497 .24734 L
.14637 .24572 L
.14776 .24407 L
.14917 .24255 L
.15041 .24106 L
.1516 .23972 L
.15265 .23844 L
.15369 .23722 L
.15456 .23612 L
.15538 .23505 L
.15614 .23398 L
.15684 .23285 L
.15751 .23175 L
.15809 .23056 L
.15865 .22923 L
.15917 .22781 L
.15963 .22624 L
.16007 .22451 L
.16051 .22291 L
.16097 .22102 L
.16147 .21915 L
.162 .21697 L
.16258 .2148 L
.16323 .21268 L
.16399 .21035 L
.16488 .20798 L
Mistroke
.16579 .20594 L
.16684 .20396 L
.1679 .20196 L
.16907 .20004 L
.17032 .19832 L
.17153 .19656 L
.17285 .19477 L
.17427 .19308 L
.17573 .19138 L
.17727 .18978 L
.17872 .18821 L
.18019 .18683 L
.18167 .18548 L
.18304 .1842 L
.18438 .18308 L
.18567 .18206 L
.1868 .1812 L
.18786 .18047 L
.18869 .17989 L
.18937 .1795 L
.18987 .1793 L
.19018 .17926 L
.19029 .17937 L
.19023 .17955 L
.19006 .17975 L
.18986 .17992 L
.18969 .17997 L
.18961 .17984 L
.18969 .17948 L
.18996 .17889 L
.19043 .17802 L
.1911 .17687 L
.19192 .17556 L
.19287 .17393 L
.19393 .17199 L
.19497 .17009 L
.19612 .1679 L
.19748 .16531 L
.19881 .16314 L
.20025 .16092 L
.20156 .15868 L
.20281 .15659 L
.20395 .1547 L
.20494 .15325 L
.20586 .15192 L
.20672 .1509 L
.20757 .15006 L
.20838 .14937 L
.20915 .14882 L
.20987 .14838 L
Mistroke
.21052 .14805 L
.21111 .14779 L
.2117 .14761 L
.21232 .14749 L
.21302 .14742 L
.21384 .14733 L
.2148 .14721 L
.21591 .14707 L
.21715 .14694 L
.21831 .14684 L
.21958 .14678 L
.22064 .14676 L
.22178 .14678 L
.22287 .14686 L
.22376 .147 L
.22455 .14718 L
.2252 .14737 L
.22566 .14751 L
.22595 .14758 L
.22611 .14755 L
.22622 .14738 L
.22637 .14705 L
.22667 .14655 L
.22718 .14585 L
.22795 .14492 L
.22902 .14375 L
.23027 .14248 L
.23183 .14084 L
.23354 .13911 L
.23562 .1371 L
.23751 .13491 L
.23967 .13266 L
.24197 .13033 L
.24385 .12813 L
.24582 .12598 L
.24764 .12401 L
.24917 .12234 L
.25055 .12081 L
.25172 .11946 L
.25268 .11838 L
.2535 .11751 L
.2542 .11687 L
.25482 .11646 L
.2554 .11625 L
.25596 .1162 L
.25655 .11625 L
.25716 .11636 L
.25782 .11649 L
.25848 .11662 L
.2591 .11674 L
Mistroke
.25968 .11684 L
.26023 .11692 L
.26073 .11695 L
.26118 .11694 L
.26158 .1169 L
.26192 .11684 L
.26219 .11676 L
.26243 .11669 L
.26263 .11664 L
.26281 .11662 L
.26299 .11662 L
.26318 .11664 L
.26336 .11685 L
.26357 .1168 L
.2638 .11669 L
.26401 .11655 L
.2642 .11641 L
.26435 .11627 L
.26444 .11613 L
.26448 .11597 L
.26445 .11576 L
.2644 .11556 L
.26433 .11529 L
.26428 .11503 L
.26426 .11473 L
.2643 .11438 L
.26442 .11407 L
.26459 .11379 L
.26482 .11356 L
.26509 .1133 L
.2654 .11302 L
.26574 .11273 L
.26614 .11244 L
.26659 .11215 L
.26711 .11186 L
.26769 .11158 L
.26835 .11128 L
.26908 .11098 L
.2699 .11066 L
.27079 .1103 L
.27171 .10988 L
.27271 .10942 L
.27375 .10896 L
.27486 .10851 L
.27599 .1081 L
.27713 .10772 L
.27823 .10735 L
.27929 .10703 L
.28021 .10677 L
.28101 .1066 L
Mistroke
.28164 .10651 L
.28213 .10648 L
.2825 .10646 L
.28282 .10641 L
.2831 .10628 L
.2834 .10604 L
.28371 .10567 L
.28406 .10517 L
.28443 .10457 L
.28484 .10393 L
.28527 .1033 L
.28567 .10265 L
.28606 .10201 L
.28641 .10146 L
.28674 .10098 L
.28704 .10058 L
.28733 .10027 L
.28763 .10006 L
.28797 .09991 L
.28838 .09977 L
.28888 .0996 L
.28949 .09936 L
.29027 .09901 L
.29119 .09852 L
.29234 .0979 L
.29363 .09721 L
.29508 .09643 L
.29673 .0956 L
.29829 .09475 L
.2999 .09392 L
.30149 .09317 L
.30304 .09248 L
.30451 .09184 L
.30593 .09124 L
.30734 .09068 L
.30871 .09012 L
.31011 .08953 L
.31151 .08887 L
.31295 .08807 L
.31441 .08712 L
.31575 .08611 L
.31712 .08492 L
.31839 .08353 L
.31963 .08211 L
.32086 .0806 L
.32204 .07913 L
.32322 .0776 L
.32441 .07615 L
.32557 .07477 L
.3268 .07336 L
Mistroke
.32809 .07217 L
.32955 .07102 L
.33115 .06989 L
.33301 .06878 L
.33497 .06773 L
.33703 .06665 L
.33929 .06562 L
.34171 .06458 L
.34402 .06353 L
.34627 .0625 L
.34837 .06155 L
.35013 .06067 L
.35198 .05989 L
.35372 .05927 L
.35535 .05883 L
.357 .05857 L
.35864 .05848 L
.36036 .05852 L
.3621 .05867 L
.36373 .05891 L
.36507 .05919 L
.36639 .05952 L
.36752 .05984 L
.36866 .06014 L
.3698 .06039 L
.37083 .06059 L
.37162 .06073 L
.37213 .06081 L
.3724 .06085 L
.37248 .06086 L
.37239 .06086 L
.37215 .06085 L
.37187 .06083 L
.37164 .06083 L
.37149 .06084 L
.37144 .06083 L
.37152 .06081 L
.37174 .06074 L
.37215 .06058 L
.37273 .06031 L
.37349 .05991 L
.37441 .05937 L
.37547 .0587 L
.37653 .05792 L
.37768 .05705 L
.37893 .05612 L
.38029 .05524 L
.38158 .05429 L
.3829 .0533 L
.38423 .05242 L
Mistroke
.38549 .05159 L
.38673 .05083 L
.38794 .05016 L
.38922 .04961 L
.39063 .04918 L
.39215 .04888 L
.39379 .04869 L
.39563 .04857 L
.39765 .0485 L
.39964 .04846 L
.40168 .04843 L
.40377 .04842 L
.40572 .04842 L
.40759 .04847 L
.40932 .04853 L
.41083 .04862 L
.41223 .04871 L
.41344 .04879 L
.41439 .04886 L
.41502 .0489 L
.41534 .04894 L
.41535 .04896 L
.41509 .04897 L
.41462 .04897 L
.41401 .04896 L
.41332 .04893 L
.41259 .0489 L
.41187 .04887 L
.41115 .04885 L
.41044 .04883 L
.40976 .04881 L
.40915 .04879 L
.40868 .04878 L
.40836 .04877 L
.40818 .04876 L
.40812 .04876 L
.40815 .04876 L
.40825 .04877 L
.40836 .04877 L
.40843 .04875 L
.40843 .0487 L
.40838 .04862 L
.40831 .04852 L
.40825 .04844 L
.40825 .0484 L
.40831 .04843 L
.40845 .04854 L
.40868 .04879 L
.40899 .0492 L
.40936 .04977 L
Mistroke
.40979 .05049 L
.41025 .05135 L
.41071 .05227 L
.41119 .05331 L
.41167 .05436 L
.41214 .05543 L
.41257 .05643 L
.41293 .05729 L
.4132 .05787 L
.41335 .05822 L
.41338 .05833 L
.41329 .05819 L
.41312 .0578 L
.41291 .05719 L
.4127 .05648 L
.41252 .05565 L
.41237 .05479 L
.41223 .05392 L
.41207 .05314 L
.41187 .0524 L
.4116 .05175 L
.41123 .05122 L
.41073 .05081 L
.41009 .05054 L
.4093 .05041 L
.40827 .05037 L
.40705 .05039 L
.40557 .05041 L
.40385 .05041 L
.40185 .05036 L
.39968 .05025 L
.39749 .05009 L
.39513 .0499 L
.39288 .04969 L
.39078 .04947 L
.38872 .04926 L
.38671 .04905 L
.38508 .04883 L
.38356 .0486 L
.38216 .04835 L
.38084 .0481 L
.3796 .04786 L
.37838 .04764 L
.37719 .04748 L
.37599 .0474 L
.37468 .04739 L
.37324 .04748 L
.37181 .0477 L
.37028 .04804 L
.36857 .04848 L
Mistroke
.36675 .04899 L
.36496 .04957 L
.36339 .05026 L
.36187 .05102 L
.36043 .05181 L
.35912 .05253 L
.35797 .05323 L
.35701 .05403 L
.3562 .05475 L
.35548 .05548 L
.35481 .05623 L
.35418 .05694 L
.35358 .05769 L
.35297 .05847 L
.35235 .05928 L
.35175 .06011 L
.3512 .06093 L
.35073 .06169 L
.35029 .0624 L
.34987 .06307 L
.34946 .06367 L
.34912 .06414 L
.34886 .06449 L
.34868 .0647 L
.34858 .06482 L
.34855 .06485 L
.34858 .0648 L
.34865 .06469 L
.34872 .06456 L
.34876 .06446 L
.34878 .0644 L
.34879 .06435 L
.34881 .06431 L
.34883 .06427 L
.34887 .0642 L
.3489 .06409 L
.34894 .06396 L
.34899 .0638 L
.34905 .06365 L
.34911 .06349 L
.34918 .06334 L
.34927 .06322 L
.34936 .06313 L
.34941 .06307 L
.34937 .06304 L
.34922 .06302 L
.34895 .06299 L
.34853 .06301 L
.34796 .06309 L
.34725 .06326 L
Mistroke
.34643 .06346 L
.34548 .06375 L
.34445 .06411 L
.34332 .06451 L
.3422 .06491 L
.34098 .06531 L
.33965 .06571 L
.33827 .06611 L
.33688 .06654 L
.33543 .06703 L
.33399 .0676 L
.33252 .06823 L
.33098 .06893 L
.32938 .0697 L
.32786 .07053 L
.32632 .07144 L
.32467 .0724 L
.32301 .07335 L
.32146 .07434 L
.31995 .07532 L
.31854 .07627 L
.31731 .0771 L
.31616 .07784 L
.31511 .07844 L
.31417 .07888 L
.3134 .07916 L
.31274 .07931 L
.31217 .07941 L
.31166 .0795 L
.31119 .07965 L
.31075 .07989 L
.31029 .08028 L
.30991 .08071 L
.30946 .08136 L
.30895 .08219 L
.30839 .08318 L
.30776 .08423 L
.30702 .08547 L
.30622 .08684 L
.30536 .08815 L
.30449 .08944 L
.30363 .09065 L
.30281 .09175 L
.30206 .09273 L
.30139 .09357 L
.30082 .09432 L
.30036 .095 L
.3 .09562 L
.29976 .09619 L
.29962 .09673 L
Mistroke
.29956 .09725 L
.29955 .09772 L
.29959 .09814 L
.29969 .09846 L
.29983 .09872 L
.29997 .09896 L
.30009 .09923 L
.30018 .09949 L
.30023 .09975 L
.30021 .10004 L
.3001 .10041 L
.29986 .10087 L
.29946 .10145 L
.29887 .10215 L
.29809 .10297 L
.29712 .10392 L
.29606 .10486 L
.29488 .10588 L
.29364 .10693 L
.29246 .10799 L
.29136 .1089 L
.29026 .1097 L
.28914 .11036 L
.28817 .11084 L
.28729 .11115 L
.28651 .1113 L
.28582 .11131 L
.28527 .11125 L
.28485 .11116 L
.28454 .11107 L
.28431 .11099 L
.2841 .11092 L
.28386 .11087 L
.28357 .11082 L
.28323 .11077 L
.28288 .1107 L
.28256 .11063 L
.28231 .11056 L
.28216 .1105 L
.28211 .11045 L
.28214 .11041 L
.28217 .11039 L
.28218 .11038 L
.2822 .11038 L
.28224 .11041 L
.28234 .11044 L
.28253 .11051 L
.28278 .11059 L
.28305 .11068 L
.28329 .11078 L
Mistroke
.28348 .11085 L
.28357 .11091 L
.28352 .11093 L
.28332 .11091 L
.283 .11083 L
.28258 .11072 L
.28208 .11053 L
.28149 .11026 L
.2808 .10994 L
.28015 .10958 L
.27937 .10926 L
.27855 .10895 L
.27771 .10872 L
.27693 .10855 L
.2762 .10846 L
.27557 .10843 L
.27503 .10845 L
.27464 .10855 L
.27433 .10871 L
.27414 .10891 L
.27404 .10916 L
.27399 .10943 L
.27398 .10967 L
.27397 .10984 L
.2739 .10997 L
.27374 .11003 L
.27344 .11007 L
.27298 .1101 L
.27239 .11021 L
.27165 .11048 L
.27077 .11095 L
.26982 .11163 L
.26885 .11247 L
.26782 .11341 L
.26673 .11437 L
.26564 .11518 L
.26461 .11598 L
.26366 .11671 L
.26283 .11739 L
.26212 .11789 L
.26153 .11826 L
.26105 .11848 L
.26066 .11856 L
.26036 .11844 L
.26016 .11816 L
.26005 .11777 L
.26001 .11734 L
.26001 .11698 L
.26 .11671 L
.25996 .11655 L
Mistroke
.25982 .1165 L
.2595 .1166 L
.25897 .11683 L
.25824 .11716 L
.25729 .11757 L
.25609 .11807 L
.25485 .11863 L
.25335 .11927 L
.25173 .1199 L
.25011 .12059 L
.24837 .12128 L
.24663 .12198 L
.24495 .12267 L
.24342 .12337 L
.24187 .12411 L
.24032 .1249 L
.23884 .12573 L
.23745 .1266 L
.23627 .12749 L
.23503 .12845 L
.23384 .1295 L
.23274 .13056 L
.23171 .13173 L
.23069 .13307 L
.22976 .13438 L
.2289 .13575 L
.22815 .13711 L
.22752 .13836 L
.22702 .13941 L
.22666 .14018 L
.2264 .14075 L
.22621 .14108 L
.22606 .14118 L
.22596 .14107 L
.22588 .14079 L
.22583 .14043 L
.22581 .14007 L
.22582 .13972 L
.22587 .13947 L
.22593 .13935 L
.226 .13944 L
.22606 .13982 L
.2261 .14045 L
.22615 .14128 L
.22621 .14214 L
.22629 .14323 L
.22635 .14419 L
.22641 .14509 L
.22643 .14587 L
.22644 .14645 L
Mistroke
.22643 .1468 L
.22638 .14693 L
.22626 .14689 L
.22604 .14674 L
.22572 .14652 L
.22528 .14627 L
.22469 .14602 L
.22395 .14583 L
.22303 .14569 L
.22194 .14559 L
.22068 .14555 L
.21923 .1456 L
.21761 .14576 L
.21608 .14607 L
.21438 .14651 L
.21244 .14709 L
.21033 .14784 L
.20831 .14871 L
.2064 .14975 L
.20437 .15096 L
.20236 .15225 L
.20037 .15377 L
.19858 .15549 L
.19669 .15732 L
.19513 .15919 L
.19357 .16123 L
.19193 .16328 L
.1904 .16552 L
.18885 .16758 L
.18731 .16975 L
.18579 .17198 L
.18455 .17388 L
.18327 .1759 L
.18215 .17783 L
.18116 .17964 L
.18018 .18148 L
.17933 .18294 L
.1786 .18436 L
.17803 .18577 L
.17762 .18712 L
.17738 .18839 L
.1773 .18947 L
.17733 .19049 L
.17743 .19138 L
.17754 .19212 L
.17764 .19268 L
.17772 .19307 L
.17776 .19333 L
.17776 .19348 L
.17773 .19349 L
Mistroke
.17769 .19341 L
.17763 .19316 L
.17756 .19277 L
.1775 .1923 L
.17748 .19181 L
.17754 .19133 L
.1777 .19088 L
.17796 .1905 L
.17834 .19025 L
.17882 .19016 L
.17939 .19018 L
.18001 .19025 L
.18072 .19033 L
.18148 .19041 L
.18229 .19047 L
.18307 .19053 L
.18386 .19056 L
.18461 .19059 L
.18531 .1906 L
.1859 .19062 L
.18639 .19063 L
.18675 .19064 L
.18702 .19065 L
.18722 .19065 L
.18737 .19066 L
.18748 .19066 L
.18756 .19066 L
.18764 .19067 L
.18768 .19067 L
.1877 .19067 L
.18768 .19067 L
.18764 .19067 L
.1876 .19066 L
.18757 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
Mistroke
.18755 .19066 L
.18755 .19066 L
.18755 .19066 L
.18753 .19066 L
.1875 .19066 L
.18746 .19066 L
.18743 .19066 L
.18741 .19066 L
.18742 .19066 L
.18748 .19066 L
.18757 .19066 L
.18772 .19067 L
.1879 .19067 L
.18812 .19068 L
.18836 .19069 L
.18861 .19069 L
.18886 .1907 L
.18912 .19074 L
.18935 .1908 L
.18954 .19088 L
.18968 .19097 L
.18978 .19106 L
.18983 .19111 L
.18985 .19109 L
.18985 .19097 L
.18987 .19076 L
.18992 .19042 L
.19007 .18996 L
.19035 .18938 L
.19077 .18865 L
.19134 .18779 L
.19203 .18677 L
.19288 .18555 L
.19388 .18411 L
.19502 .18259 L
.19629 .18093 L
.19761 .17924 L
.19898 .17751 L
.20035 .17595 L
.20161 .17445 L
.2028 .17309 L
.20379 .172 L
.20468 .17096 L
.20543 .17011 L
.20609 .16935 L
.20655 .16887 L
.20691 .16852 L
.20713 .16833 L
.20724 .1683 L
.20727 .16837 L
Mistroke
.20725 .16848 L
.20719 .1686 L
.20711 .1687 L
.20702 .16877 L
.20695 .1688 L
.20692 .16882 L
.20692 .16883 L
.20693 .16885 L
.20693 .16891 L
.20693 .16899 L
.20691 .16908 L
.20688 .16918 L
.20683 .16926 L
.20677 .16929 L
.20672 .16922 L
.2067 .16899 L
.20674 .16859 L
.20685 .168 L
.20704 .16718 L
.20732 .16613 L
.20767 .16496 L
.20809 .16354 L
.20855 .16191 L
.20901 .16033 L
.2095 .1586 L
.20998 .15675 L
.21039 .15521 L
.21074 .15374 L
.21105 .15239 L
.21129 .15125 L
.21145 .15036 L
.21158 .1497 L
.21172 .14923 L
.21189 .14891 L
.21213 .14866 L
.21248 .14844 L
.21297 .14821 L
.21362 .14794 L
.21436 .14762 L
.21528 .14725 L
.21627 .1468 L
.2174 .14623 L
.21865 .14553 L
.21981 .1447 L
.22104 .14383 L
.22235 .14293 L
.22363 .14202 L
.22494 .14114 L
.22621 .14029 L
.22753 .13951 L
Mistroke
.22878 .13874 L
.23007 .13795 L
.23132 .1372 L
.23259 .13647 L
.23379 .13575 L
.23489 .13507 L
.23596 .13443 L
.23694 .13387 L
.23779 .13341 L
.23853 .13302 L
.23916 .13269 L
.23965 .13238 L
.24002 .1321 L
.2403 .13187 L
.24049 .13171 L
.24062 .13161 L
.24069 .13159 L
.24073 .13163 L
.24074 .1317 L
.24072 .1318 L
.24067 .13191 L
.24057 .13201 L
.24045 .1321 L
.24031 .13217 L
.2402 .13219 L
.24016 .13214 L
.24022 .13201 L
.2404 .13174 L
.24072 .13134 L
.2412 .1308 L
.24185 .13011 L
.24266 .12928 L
.2436 .12842 L
.24451 .12745 L
.24559 .12643 L
.24661 .12542 L
.2477 .12443 L
.24858 .1235 L
.24945 .12272 L
.25028 .12205 L
.25103 .12152 L
.25166 .12114 L
.25225 .12092 L
.25283 .12085 L
.25346 .12089 L
.25416 .121 L
.25496 .12109 L
.25584 .12112 L
.25675 .12109 L
.2577 .12099 L
Mistroke
.25874 .12082 L
.25992 .1206 L
.26117 .1204 L
.26246 .12026 L
.26376 .12019 L
.26507 .12015 L
.26635 .12014 L
.26759 .12015 L
.2688 .12019 L
.26987 .12025 L
.27089 .12036 L
.27182 .12051 L
.2726 .12066 L
.2732 .12078 L
.27365 .12086 L
.27398 .12085 L
.27419 .12073 L
.27433 .1205 L
.27444 .12007 L
.27453 .1195 L
.27464 .11889 L
.2748 .11821 L
.27503 .11752 L
.27533 .11682 L
.27565 .11613 L
.27603 .11546 L
.27646 .11485 L
.27695 .1143 L
.27745 .11382 L
.27793 .11345 L
.27836 .11322 L
.27872 .1131 L
.27903 .11308 L
.27929 .11312 L
.27953 .11319 L
.27978 .11321 L
.28007 .11316 L
.28041 .11297 L
.28081 .1126 L
.28126 .112 L
.2818 .11114 L
.28244 .11009 L
.28315 .10874 L
.28403 .10727 L
.28499 .10557 L
.28612 .10371 L
.28742 .1018 L
.28888 .09994 L
.29057 .098 L
.2922 .09629 L
Mistroke
.29406 .09451 L
.29577 .09302 L
.29772 .09157 L
.29967 .09031 L
.30176 .08914 L
.30398 .08805 L
.30609 .08701 L
.30825 .08608 L
.3104 .08514 L
.31248 .08415 L
.31458 .08308 L
.31668 .08198 L
.31875 .08072 L
.32101 .07928 L
.32313 .07779 L
.32538 .0762 L
.32775 .07456 L
.32997 .07279 L
.33231 .07111 L
.33478 .06934 L
.3371 .06754 L
.33952 .06601 L
.34202 .0645 L
.34432 .06303 L
.34663 .06172 L
.34879 .06055 L
.35084 .05948 L
.35252 .05854 L
.35404 .0577 L
.3553 .05695 L
.35635 .0563 L
.35715 .05574 L
.35774 .05529 L
.35814 .05488 L
.35837 .05453 L
.35845 .05424 L
.35841 .05401 L
.35829 .05383 L
.35813 .0537 L
.35797 .05364 L
.35781 .05362 L
.35768 .05366 L
.35761 .05373 L
.35761 .0538 L
.35771 .05386 L
.35794 .05389 L
.35833 .05389 L
.35891 .0539 L
.35969 .0539 L
.36066 .05391 L
Mistroke
.36184 .05394 L
.36321 .05401 L
.36453 .05411 L
.36596 .0542 L
.36731 .05427 L
.3687 .05429 L
.36985 .05425 L
.37092 .05412 L
.37191 .05389 L
.37271 .05359 L
.37341 .05322 L
.37404 .05281 L
.37462 .05238 L
.37517 .05196 L
.37568 .05153 L
.37616 .05111 L
.37666 .05073 L
.37722 .05039 L
.37784 .05011 L
.37848 .0499 L
.37912 .04977 L
.37968 .04972 L
.38018 .04973 L
.3806 .04981 L
.38095 .04996 L
.38122 .05015 L
.38142 .05039 L
.38158 .05068 L
.38178 .05099 L
.38202 .05128 L
.3823 .05149 L
.3826 .05163 L
.38294 .05171 L
.3833 .05178 L
.38366 .05185 L
.38403 .05195 L
.38441 .05205 L
.3848 .05218 L
.38525 .05227 L
.38579 .05235 L
.38641 .05242 L
.3872 .05252 L
.38798 .05267 L
.38898 .05295 L
.39016 .05338 L
.39139 .05393 L
.39285 .05457 L
.39439 .05525 L
.39621 .05594 L
.39826 .05658 L
Mistroke
.40015 .05715 L
.40225 .05762 L
.40436 .05806 L
.40648 .05848 L
.4087 .05889 L
.41075 .05928 L
.41277 .05964 L
.41472 .05994 L
.41647 .06015 L
.4182 .06026 L
.41971 .06027 L
.42102 .06016 L
.42201 .05997 L
.42277 .05971 L
.4233 .05942 L
.42368 .05912 L
.42394 .05881 L
.42415 .05848 L
.42439 .0581 L
.42474 .05768 L
.42526 .05718 L
.42598 .05661 L
.42689 .05597 L
.42794 .05522 L
.4292 .0546 L
.43065 .05392 L
.43227 .05327 L
.43392 .05269 L
.43556 .05214 L
.43721 .05158 L
.43852 .05106 L
.43969 .05056 L
.44058 .05012 L
.4413 .04977 L
.44182 .04953 L
.44214 .04942 L
.44237 .04941 L
.44262 .04946 L
.44298 .04954 L
.44348 .04962 L
.44419 .04969 L
.44513 .04974 L
.44633 .04978 L
.44759 .04982 L
.44929 .04989 L
.45106 .04999 L
.45309 .05013 L
.45538 .05031 L
.45752 .05052 L
.45987 .05076 L
Mistroke
.46208 .05102 L
.46425 .05129 L
.46633 .05156 L
.46818 .05179 L
.46987 .05199 L
.47139 .05214 L
.47267 .05228 L
.4738 .05241 L
.47474 .05256 L
.47546 .05273 L
.47597 .05296 L
.47629 .05323 L
.47646 .05355 L
.47651 .05392 L
.47648 .05434 L
.4764 .05477 L
.4763 .05522 L
.47621 .05568 L
.47613 .05613 L
.47602 .05654 L
.47589 .05685 L
.47574 .05704 L
.4756 .05708 L
.47553 .05695 L
.47556 .05669 L
.47572 .05634 L
.47605 .05591 L
.47658 .05549 L
.47734 .05504 L
.47836 .05465 L
.47955 .05426 L
.48106 .05391 L
.48255 .05359 L
.48442 .05333 L
.48635 .05312 L
.48826 .05292 L
.49045 .05271 L
.4927 .05246 L
.49499 .05219 L
.49727 .05186 L
.49946 .05146 L
.50154 .05105 L
.50359 .05057 L
.50529 .05008 L
.50682 .04958 L
.5083 .04913 L
.5095 .0487 L
.51055 .04828 L
.51133 .04787 L
.51191 .04758 L
Mistroke
.51228 .04736 L
.51246 .04726 L
.51246 .04728 L
.51231 .04741 L
.51205 .04764 L
.51174 .04792 L
.51145 .04825 L
.51122 .04862 L
.51105 .049 L
.51093 .04941 L
.51085 .04982 L
.5108 .05024 L
.5108 .05068 L
.51085 .05101 L
.51094 .05132 L
.51109 .05156 L
.5113 .05173 L
.51157 .05182 L
.51188 .05186 L
.51222 .05189 L
.5126 .05192 L
.51296 .05196 L
.5133 .05201 L
.51357 .05204 L
.51374 .05202 L
.51382 .05193 L
.51382 .05175 L
.51377 .0515 L
.51369 .05118 L
.51354 .05081 L
.51332 .05042 L
.51302 .05001 L
.51267 .04961 L
.51226 .0492 L
.51181 .04876 L
.51133 .0483 L
.51085 .04785 L
.51035 .04745 L
.50986 .04712 L
.50938 .04686 L
.50895 .04665 L
.50856 .04647 L
.50813 .04628 L
.50769 .04604 L
.50719 .04577 L
.50664 .04545 L
.50599 .04508 L
.50521 .04471 L
.50418 .04435 L
.50285 .04406 L
Mistroke
.5012 .04377 L
.49914 .0435 L
.49694 .04326 L
.49431 .04303 L
.49146 .0428 L
.48856 .04259 L
.48527 .04239 L
.48253 .04223 L
.47911 .04213 L
.47637 .04208 L
.47295 .04205 L
.47022 .042 L
.46738 .04193 L
.46439 .04185 L
.4618 .04177 L
.45899 .04168 L
.45596 .04158 L
.4534 .04145 L
.45009 .04129 L
.44739 .04114 L
.44436 .04101 L
.44077 .04093 L
.43764 .04093 L
.43413 .041 L
.43076 .04115 L
.42708 .04138 L
.42413 .04168 L
.42105 .04204 L
.41822 .04244 L
.41552 .04286 L
.4132 .04327 L
.41119 .04364 L
.40942 .04392 L
.40808 .0441 L
.40702 .04416 L
.40624 .0441 L
.4057 .04393 L
.4054 .0437 L
.40528 .04345 L
.40531 .04318 L
.40542 .04297 L
.4056 .04282 L
.40578 .04275 L
.40592 .04274 L
.40603 .04279 L
.40611 .0429 L
.40616 .04307 L
.40619 .04333 L
.40623 .04357 L
.40624 .04384 L
Mistroke
.40625 .04409 L
.40624 .04429 L
.40623 .04442 L
.40625 .04448 L
.40633 .04449 L
.40643 .04448 L
.40653 .04447 L
.40658 .04445 L
.40654 .0444 L
.4064 .04434 L
.40613 .04427 L
.40573 .04421 L
.40521 .0442 L
.4046 .04424 L
.40393 .04434 L
.40323 .0445 L
.40256 .04472 L
.40196 .04502 L
.40134 .04537 L
.4007 .04576 L
.40009 .04617 L
.39961 .04657 L
.3993 .047 L
.39914 .04737 L
.39908 .04774 L
.3991 .04808 L
.39919 .04834 L
.3993 .04853 L
.39936 .04863 L
.39937 .04867 L
.39934 .04866 L
.39931 .04863 L
.39927 .04858 L
.39925 .04855 L
.39927 .04854 L
.39931 .04852 L
.39941 .04851 L
.39954 .04851 L
.39971 .04852 L
.39992 .04852 L
.40014 .04853 L
.40038 .04854 L
.40061 .04855 L
.40085 .04856 L
.40107 .04858 L
.40128 .04862 L
.40147 .04868 L
.40162 .04872 L
.40173 .04875 L
.4018 .04875 L
Mistroke
.40181 .0487 L
.40179 .04858 L
.40174 .04836 L
.40168 .04805 L
.40162 .04767 L
.40158 .04728 L
.40156 .0469 L
.40155 .04656 L
.40155 .04631 L
.40155 .04618 L
.40156 .04615 L
.40158 .04616 L
.40159 .04622 L
.40161 .04635 L
.40162 .04656 L
.40164 .04684 L
.40168 .04717 L
.40171 .04751 L
.40177 .04785 L
.40186 .04816 L
.40199 .04841 L
.40218 .04855 L
.4024 .04862 L
.40268 .04864 L
.40302 .0486 L
.40337 .04855 L
.40377 .04855 L
.40418 .04858 L
.40459 .04863 L
.40499 .04868 L
.40535 .04871 L
.40566 .04873 L
.40592 .04874 L
.40613 .04873 L
.40628 .04872 L
.40636 .04871 L
.40638 .04871 L
.40637 .04871 L
.40634 .04871 L
.40631 .04871 L
.40627 .04871 L
.40624 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
Mistroke
.40622 .04871 L
.40622 .04871 L
.40622 .04871 L
.40621 .04871 L
.40618 .04871 L
.40614 .04871 L
.40611 .0487 L
.40609 .0487 L
.4061 .0487 L
.40615 .04871 L
.40623 .04872 L
.40636 .04873 L
.40652 .04876 L
.40669 .04877 L
.40688 .04876 L
.40708 .04874 L
.4073 .04871 L
.40755 .04868 L
.40784 .04864 L
.40816 .04862 L
.40851 .04861 L
.40885 .0486 L
.40915 .04858 L
.40939 .04854 L
.40958 .0485 L
.40972 .04846 L
.40983 .04842 L
.40993 .04841 L
.41003 .04841 L
.41013 .04843 L
.41023 .04846 L
.41031 .04852 L
.41036 .04856 L
.41039 .0486 L
.41039 .04863 L
.41041 .04867 L
.41048 .04872 L
.41059 .04882 L
.41074 .04894 L
.41087 .04903 L
.41094 .04906 L
.41092 .049 L
.41077 .04885 L
.41049 .0486 L
.41008 .04825 L
.40959 .04782 L
.40909 .04737 L
.40862 .04691 L
.40822 .04646 L
.40788 .04602 L
Mistroke
.40756 .04558 L
.4073 .04518 L
.40712 .04482 L
.40704 .04454 L
.40708 .04434 L
.4072 .04423 L
.40741 .04421 L
.40766 .04424 L
.40795 .04431 L
.40822 .04439 L
.40843 .04445 L
.40855 .04447 L
.40861 .04447 L
.40862 .04447 L
.40861 .04447 L
.40857 .04447 L
.40854 .04448 L
.40851 .04449 L
.40849 .0445 L
.40849 .0445 L
.40849 .04451 L
.40849 .04452 L
.40849 .04452 L
.40849 .04452 L
.40849 .04452 L
.40849 .04452 L
.40849 .04452 L
.40849 .04452 L
.40849 .04451 L
.40849 .04451 L
.40849 .0445 L
.40849 .04449 L
.40849 .04448 L
.40849 .04447 L
.40849 .04447 L
.40849 .04447 L
.40849 .04447 L
.40849 .04447 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
Mistroke
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.40849 .04448 L
.4085 .04448 L
.40852 .04449 L
.40853 .04449 L
.40854 .04448 L
.40852 .04447 L
.40849 .04446 L
.40845 .04445 L
.40839 .04444 L
.40834 .04443 L
.40829 .04442 L
.40824 .04442 L
.40821 .04441 L
.40819 .04441 L
.40818 .04441 L
.40819 .04441 L
.40822 .04442 L
.40826 .04443 L
.40831 .04444 L
.40835 .04445 L
.40836 .04446 L
.40836 .04446 L
.40832 .04446 L
.40827 .04445 L
.40821 .04445 L
.40814 .04444 L
.40807 .04443 L
Mistroke
.408 .04442 L
.40796 .04442 L
.40794 .04442 L
.40793 .04442 L
.40791 .04442 L
.40792 .04443 L
.40795 .04443 L
.40802 .04444 L
.40813 .04445 L
.40828 .04447 L
.40846 .04448 L
.40867 .04449 L
.40889 .04449 L
.4091 .0445 L
.40931 .0445 L
.40952 .04451 L
.40973 .04451 L
.40995 .04452 L
.41018 .04453 L
.41039 .04453 L
.41057 .04454 L
.41072 .04454 L
.41082 .04455 L
.41088 .04455 L
.41089 .04455 L
.41088 .04455 L
.41085 .04455 L
.41081 .04454 L
.41078 .04454 L
.41077 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41077 .04454 L
.41078 .04454 L
.41083 .04455 L
.4109 .04455 L
Mistroke
.41096 .04455 L
.41099 .04455 L
.41097 .04455 L
.41088 .04455 L
.41071 .04454 L
.41044 .04453 L
.41009 .04452 L
.40968 .04451 L
.40924 .0445 L
.40877 .04448 L
.40832 .04447 L
.40788 .04446 L
.40744 .04444 L
.407 .04443 L
.4066 .04442 L
.40627 .04441 L
.40603 .0444 L
.40589 .0444 L
.40586 .0444 L
.40593 .0444 L
.40608 .0444 L
.40628 .04441 L
.4065 .04442 L
.40673 .04442 L
.40696 .04443 L
.4072 .04444 L
.40744 .04444 L
.40767 .04445 L
.4079 .04446 L
.40811 .04447 L
.4083 .04447 L
.40844 .04448 L
.40855 .04448 L
.4086 .04449 L
.40862 .04448 L
.40861 .04448 L
.4086 .04447 L
.40858 .04446 L
.40855 .04446 L
.40853 .04445 L
.40849 .04444 L
.40845 .04444 L
.40839 .04444 L
.40834 .04445 L
.40828 .04447 L
.40824 .04447 L
.40821 .04446 L
.40819 .04444 L
.40818 .04441 L
.40816 .04438 L
Mistroke
.40814 .04434 L
.40812 .04431 L
.40811 .04428 L
.40814 .04427 L
.40821 .04426 L
.40831 .04425 L
.40846 .04426 L
.40865 .04426 L
.40885 .04428 L
.40907 .0443 L
.40929 .04434 L
.40951 .04438 L
.40972 .04443 L
.40995 .04448 L
.41018 .04453 L
.41039 .04456 L
.41057 .04458 L
.41072 .04458 L
.41082 .04457 L
.41088 .04456 L
.41089 .04455 L
.41088 .04455 L
.41085 .04455 L
.41081 .04454 L
.41078 .04454 L
.41077 .04454 L
.41076 .04454 L
.41076 .04454 L
.41076 .04454 L
.41077 .04452 L
.41079 .04447 L
.41081 .0444 L
.41081 .04434 L
.4108 .04431 L
.41077 .04433 L
.41072 .04442 L
.41067 .04459 L
.41061 .04484 L
.41056 .04517 L
.41052 .04555 L
.41049 .04597 L
.41047 .04641 L
.41046 .04684 L
.41046 .04728 L
.41046 .0477 L
.41048 .0481 L
.41051 .04845 L
.41055 .04873 L
.41061 .04893 L
.41067 .04904 L
Mistroke
.41073 .04907 L
.41079 .04904 L
.41087 .04895 L
.41095 .04885 L
.41101 .04875 L
.41102 .04866 L
.41099 .0486 L
.41089 .04859 L
.41071 .04863 L
.41045 .04877 L
.4101 .04901 L
.4097 .04935 L
.40925 .04979 L
.40879 .05032 L
.40833 .05089 L
.40789 .05155 L
.40746 .05225 L
.40704 .05295 L
.40667 .0536 L
.40636 .05418 L
.40615 .05467 L
.40606 .055 L
.40609 .05516 L
.4062 .05511 L
.40633 .05488 L
.40644 .05452 L
.4065 .05407 L
.40645 .05358 L
.40625 .05309 L
.40597 .05261 L
.4055 .05215 L
.40479 .05171 L
.40385 .05129 L
.40274 .05088 L
.40159 .05052 L
.4004 .05019 L
.39897 .04991 L
.39724 .04967 L
.39573 .04947 L
.39406 .04932 L
.39257 .04916 L
.39104 .04899 L
.38964 .04878 L
.38852 .04855 L
.38751 .04829 L
.38661 .048 L
.38587 .04767 L
.38532 .04731 L
.38496 .04693 L
.38477 .04653 L
Mistroke
.38473 .04612 L
.38477 .04572 L
.38486 .04531 L
.38496 .04489 L
.38505 .04449 L
.38508 .04414 L
.38504 .04387 L
.38497 .04368 L
.38487 .04358 L
.38475 .04355 L
.38462 .04356 L
.38446 .04362 L
.38427 .04368 L
.38405 .04374 L
.38382 .04376 L
.38359 .04376 L
.38341 .04375 L
.38328 .04374 L
.3832 .04374 L
.38316 .04373 L
.38318 .04374 L
.38325 .04376 L
.38335 .04378 L
.38346 .04381 L
.38356 .04384 L
.38363 .04388 L
.38368 .04391 L
.38371 .04395 L
.38375 .04398 L
.3838 .04401 L
.38388 .04403 L
.384 .04404 L
.38416 .04404 L
.38435 .04403 L
.38453 .044 L
.38469 .04394 L
.38482 .04403 L
.38492 .04398 L
.38499 .04395 L
.38503 .04395 L
.38503 .04398 L
.38498 .04405 L
.38487 .04417 L
.38467 .04433 L
.38438 .04458 L
.384 .04485 L
.38355 .04517 L
.38308 .04552 L
.38261 .04588 L
.3822 .04628 L
Mistroke
.38184 .04665 L
.38155 .04694 L
.38132 .04723 L
.38115 .04748 L
.38104 .04768 L
.38097 .04784 L
.38095 .04796 L
.38098 .04804 L
.38107 .04808 L
.38121 .0481 L
.38134 .0481 L
.38142 .04808 L
.3814 .04804 L
.38126 .048 L
.381 .04797 L
.3806 .04796 L
.38007 .04794 L
.37945 .04792 L
.37878 .0479 L
.37807 .04788 L
.37739 .04786 L
.37672 .04784 L
.37605 .04782 L
.37541 .0478 L
.37483 .04778 L
.37438 .04777 L
.37406 .04776 L
.37389 .04775 L
.37383 .04775 L
.37386 .04775 L
.37396 .04776 L
.37407 .04776 L
.37415 .04776 L
.37419 .04776 L
.3742 .04774 L
.37421 .04771 L
.37424 .04769 L
.37427 .04768 L
.37431 .04769 L
.37432 .04772 L
.3743 .04778 L
.37422 .04789 L
.37409 .04805 L
.37392 .04824 L
.37374 .04844 L
.37355 .0486 L
.37337 .04875 L
.37323 .04885 L
.37313 .04891 L
.37307 .04898 L
Mistroke
.37304 .04898 L
.37306 .04894 L
.37311 .04885 L
.37319 .04871 L
.37333 .04853 L
.37349 .04834 L
.37369 .04814 L
.37389 .04795 L
.37407 .0478 L
.37421 .04771 L
.3743 .04767 L
.37433 .04766 L
.37431 .04766 L
.37428 .04769 L
.37424 .04772 L
.37421 .04775 L
.3742 .04776 L
.37419 .04777 L
.37419 .04777 L
.37419 .04777 L
.37419 .04777 L
.3742 .04777 L
.37422 .04777 L
.37427 .04777 L
.37434 .04777 L
.37441 .04777 L
.37444 .04777 L
.37443 .04777 L
.37434 .04777 L
.37418 .04776 L
.37393 .04775 L
.37363 .04771 L
.3733 .04761 L
.37294 .0475 L
.37257 .04739 L
.37219 .04732 L
.3718 .04731 L
.37135 .04738 L
.37082 .04758 L
.37021 .04794 L
.36951 .04846 L
.3687 .04913 L
.36773 .04993 L
.3666 .05084 L
.36542 .05176 L
.36403 .05271 L
.36243 .05369 L
.36085 .05467 L
.35895 .0556 L
.35725 .05638 L
Mistroke
.35554 .05704 L
.35389 .05754 L
.35244 .0579 L
.35126 .05812 L
.35028 .0582 L
.34951 .0582 L
.34897 .05815 L
.34862 .05809 L
.34842 .05801 L
.34836 .05794 L
.34838 .05788 L
.34844 .05785 L
.34855 .05785 L
.34867 .05785 L
.34877 .05785 L
.34881 .05785 L
.34882 .05785 L
.34884 .05782 L
.3489 .05775 L
.34902 .05766 L
.34912 .05757 L
.34919 .05753 L
.34919 .05756 L
.34909 .05769 L
.34884 .05794 L
.3484 .05831 L
.34778 .0588 L
.34704 .05936 L
.34622 .05999 L
.34538 .06066 L
.34454 .06129 L
.34387 .06189 L
.34311 .06249 L
.34239 .06306 L
.34177 .06357 L
.34133 .06396 L
.34111 .0642 L
.3411 .06428 L
.34123 .06424 L
.34144 .06413 L
.34167 .06401 L
.34187 .06391 L
.34194 .06388 L
.34181 .06395 L
.34147 .06412 L
.34091 .06436 L
.34011 .06469 L
.33904 .06508 L
.33789 .06557 L
.3364 .06615 L
Mistroke
.33504 .06681 L
.33356 .06759 L
.33186 .06848 L
.33023 .06946 L
.32853 .07053 L
.32675 .07161 L
.32495 .07266 L
.32324 .07363 L
.3215 .07458 L
.31979 .07546 L
.31839 .07626 L
.31694 .07695 L
.31559 .07755 L
.31452 .07806 L
.31358 .07848 L
.31276 .07881 L
.31209 .07906 L
.31157 .07925 L
.31123 .07942 L
.31106 .07958 L
.31104 .07974 L
.31112 .07989 L
.31125 .08006 L
.31139 .08025 L
.3115 .08045 L
.31155 .08062 L
.31156 .08076 L
.31156 .08086 L
.31156 .08092 L
.31156 .08093 L
.31156 .08092 L
.31156 .08088 L
.31156 .08085 L
.31156 .08082 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31156 .0808 L
.31159 .08078 L
.31165 .08073 L
.31176 .08067 L
.31186 .0806 L
.31192 .08057 L
.31189 .08059 L
Mistroke
.31177 .08067 L
.31153 .08082 L
.31115 .08105 L
.31067 .08134 L
.31011 .08165 L
.30952 .08199 L
.30888 .08236 L
.30818 .08277 L
.30745 .08323 L
.30666 .08375 L
.30582 .08432 L
.30495 .08492 L
.30412 .08552 L
.30339 .08609 L
.3028 .08663 L
.30233 .08711 L
.30196 .08753 L
.30159 .08792 L
.30118 .0883 L
.30068 .08866 L
.30007 .089 L
.29937 .08928 L
.29863 .08948 L
.29786 .08958 L
.29713 .0896 L
.29647 .08955 L
.29589 .08943 L
.29532 .08931 L
.29472 .08921 L
.29408 .08914 L
.29346 .08913 L
.29292 .08915 L
.29247 .08922 L
.29212 .08933 L
.29185 .08948 L
.29165 .08965 L
.29151 .08985 L
.29138 .0901 L
.29121 .0903 L
.29098 .09055 L
.29074 .09079 L
.29052 .091 L
.29034 .09117 L
.29022 .09127 L
.29017 .0913 L
.29021 .09127 L
.29032 .09123 L
.29049 .09119 L
.29071 .09119 L
.29095 .09125 L
Mistroke
.29119 .09139 L
.29144 .09162 L
.29169 .09189 L
.29195 .09218 L
.29221 .09242 L
.29249 .09257 L
.29276 .09266 L
.293 .09268 L
.29322 .09269 L
.29338 .0927 L
.29343 .0928 L
.29334 .09282 L
.29311 .09287 L
.29269 .09295 L
.29208 .09309 L
.29122 .09336 L
.29008 .09378 L
.28879 .09433 L
.2872 .09512 L
.28527 .0961 L
.28312 .09728 L
.28111 .09851 L
.27888 .09982 L
.2764 .10117 L
.27416 .10247 L
.27183 .10372 L
.26986 .10482 L
.26809 .10584 L
.26662 .10675 L
.26542 .10757 L
.26435 .10825 L
.26347 .10883 L
.26274 .10931 L
.26213 .10969 L
.26156 .11001 L
.26098 .11029 L
.26036 .11058 L
.25962 .11091 L
.2587 .11134 L
.25764 .11188 L
.25642 .11255 L
.25496 .11337 L
.25321 .11436 L
.25137 .11547 L
.24944 .11669 L
.24746 .11798 L
.24571 .11924 L
.24401 .12043 L
.2426 .12156 L
.24124 .12257 L
Mistroke
.24013 .12342 L
.23919 .12413 L
.23846 .12469 L
.23797 .12509 L
.23768 .12534 L
.23758 .12546 L
.23761 .12549 L
.23773 .12545 L
.23788 .12538 L
.23803 .12529 L
.23812 .1252 L
.23818 .12513 L
.23827 .12505 L
.23839 .12496 L
.23849 .12486 L
.23854 .12478 L
.23852 .12473 L
.23839 .12475 L
.23815 .12486 L
.23776 .1251 L
.23722 .12549 L
.23655 .12603 L
.23577 .12672 L
.23492 .12755 L
.23406 .12845 L
.23319 .12945 L
.23229 .13047 L
.2314 .13151 L
.23056 .13253 L
.22984 .13348 L
.22927 .1343 L
.22885 .13499 L
.22858 .13554 L
.22842 .13592 L
.22837 .13616 L
.22837 .13627 L
.2284 .13629 L
.22842 .13626 L
.22845 .1362 L
.22849 .13613 L
.22853 .13605 L
.2286 .13598 L
.22867 .13592 L
.22876 .13588 L
.22887 .13582 L
.22899 .13575 L
.22909 .13568 L
.22913 .13562 L
.22906 .13561 L
.22885 .13569 L
Mistroke
.22844 .13591 L
.22779 .13625 L
.22688 .13674 L
.22569 .13738 L
.22436 .1381 L
.22275 .13892 L
.22086 .13981 L
.21891 .14077 L
.21686 .14181 L
.21452 .14306 L
.21235 .14428 L
.21003 .14559 L
.20779 .14696 L
.20588 .14836 L
.20405 .14974 L
.2024 .15104 L
.20106 .1521 L
.19991 .15317 L
.19898 .15416 L
.1983 .15493 L
.19782 .15563 L
.1975 .15623 L
.1973 .1567 L
.19716 .15704 L
.19703 .15735 L
.19684 .15772 L
.19655 .15818 L
.19617 .1588 L
.19568 .15962 L
.19508 .16063 L
.1944 .16178 L
.19372 .16288 L
.19302 .16412 L
.19234 .16538 L
.19175 .16645 L
.19119 .1675 L
.19073 .16839 L
.19039 .16915 L
.19016 .16977 L
.18996 .17031 L
.18976 .17083 L
.18949 .1714 L
.18909 .1721 L
.18847 .17303 L
.18759 .17425 L
.18653 .17556 L
.18524 .17726 L
.18368 .17917 L
.18189 .18144 L
.17999 .18385 L
Mistroke
.17822 .18658 L
.17634 .18911 L
.17433 .19193 L
.17238 .19478 L
.17052 .19756 L
.16866 .20052 L
.16697 .20306 L
.16528 .20577 L
.16374 .20829 L
.16221 .2108 L
.16073 .21317 L
.15939 .21558 L
.15805 .21768 L
.15673 .21979 L
.1555 .2218 L
.15438 .22366 L
.15332 .22544 L
.15232 .2271 L
.15144 .22847 L
.15065 .22977 L
.14997 .23094 L
.14944 .23198 L
.14902 .23283 L
.14873 .23353 L
.14854 .23405 L
.14845 .23438 L
.14841 .23457 L
.1484 .23464 L
.14838 .23464 L
.14835 .2346 L
.14828 .23457 L
.14815 .23458 L
.14793 .23465 L
.14762 .23481 L
.1472 .23509 L
.14666 .23555 L
.14598 .23623 L
.1452 .2371 L
.1443 .2382 L
.14327 .23955 L
.1421 .24118 L
.14084 .24311 L
.1396 .24497 L
.1383 .24722 L
.13697 .24965 L
.13562 .25207 L
.13419 .25479 L
.13266 .25772 L
.13111 .26047 L
.12943 .26361 L
Mistroke
.12775 .26657 L
.12611 .26969 L
.12443 .2726 L
.1227 .27571 L
.12116 .27837 L
.11929 .28127 L
.1176 .28408 L
.1157 .28704 L
.11388 .29006 L
.11193 .2927 L
.10991 .29556 L
.10795 .29855 L
.10646 .301 L
.10485 .30366 L
.10339 .30593 L
.10193 .30822 L
.10084 .31007 L
.09987 .31179 L
.09902 .31335 L
.09837 .3146 L
.09791 .31562 L
.09764 .31636 L
.09754 .31681 L
.09756 .31703 L
.09765 .31706 L
.09777 .31696 L
.0979 .31679 L
.098 .31662 L
.09805 .31648 L
.09804 .31637 L
.09804 .3163 L
.09804 .31629 L
.09802 .31632 L
.09798 .31641 L
.0979 .31656 L
.09779 .31682 L
.09766 .31721 L
.09753 .31774 L
.09741 .3184 L
.09731 .3192 L
.09723 .32011 L
.0972 .3211 L
.09719 .32208 L
.09721 .32308 L
.09726 .32405 L
.09731 .32498 L
.0974 .32579 L
.09752 .32644 L
.09766 .32685 L
.09782 .3271 L
Mistroke
.09799 .32723 L
.09815 .32727 L
.09827 .32727 L
.09831 .32731 L
.09825 .32751 L
.0981 .32799 L
.09786 .32884 L
.09755 .33009 L
.09719 .33174 L
.09677 .3338 L
.09628 .33592 L
.0957 .3383 L
.09501 .34117 L
.09421 .34416 L
.09334 .34749 L
.09239 .35074 L
.09139 .35421 L
.09042 .3576 L
.08946 .36065 L
.08854 .364 L
.08773 .36704 L
.08695 .37016 L
.08629 .37307 L
.08569 .37614 L
.08518 .37875 L
.08478 .3815 L
.08449 .38406 L
.08431 .38671 L
.08422 .38924 L
.08422 .39132 L
.08425 .39329 L
.08431 .39515 L
.08436 .39682 L
.08439 .39826 L
.08439 .39937 L
.08438 .40031 L
.08437 .40103 L
.08437 .40156 L
.08436 .40191 L
.08436 .4021 L
Mfstroke
.07165 .48341 m
.07162 .48366 L
.07158 .48402 L
.07156 .48447 L
.07155 .48498 L
.07154 .48551 L
.07152 .48608 L
.07148 .4867 L
.07143 .48738 L
.07136 .48815 L
.0713 .48897 L
.07126 .48983 L
.07123 .49074 L
.07121 .49171 L
.07118 .49273 L
.07111 .49385 L
.07099 .49507 L
.07082 .49647 L
.07061 .49814 L
.07034 .50014 L
.07002 .50234 L
.06967 .5049 L
.0693 .50768 L
.06895 .51021 L
.0686 .51274 L
.06828 .51544 L
.06799 .51801 L
.06776 .52077 L
.06761 .5231 L
.06756 .52546 L
.06766 .52775 L
.06787 .52983 L
.0682 .53179 L
.0686 .5335 L
.06905 .53503 L
.06952 .53637 L
.06998 .53756 L
.07039 .53858 L
.07076 .5394 L
.07109 .54009 L
.07138 .54066 L
.07165 .54113 L
.07189 .5415 L
.07212 .54179 L
.07234 .54201 L
.07258 .54218 L
.07283 .54232 L
.07311 .54241 L
.07339 .54247 L
.07364 .5425 L
Mistroke
.0739 .54257 L
.07413 .5427 L
.07431 .5429 L
.07438 .54319 L
.07433 .54359 L
.07416 .5441 L
.07388 .54477 L
.07354 .54562 L
.07319 .54669 L
.07287 .54791 L
.07261 .5494 L
.07243 .55112 L
.07236 .55298 L
.07241 .55508 L
.07257 .55733 L
.07285 .55955 L
.07322 .56193 L
.0737 .56429 L
.07429 .56673 L
.0749 .56896 L
.07551 .5712 L
.07611 .5734 L
.07664 .57526 L
.07708 .57705 L
.07743 .57867 L
.07771 .58004 L
.07791 .58121 L
.07806 .58224 L
.07817 .58292 L
.07825 .58346 L
.07832 .5838 L
.07835 .58395 L
.07834 .58395 L
.0783 .58388 L
.07826 .58382 L
.07824 .58382 L
.07824 .5839 L
.07828 .58405 L
.07833 .58425 L
.07839 .58449 L
.07844 .58477 L
.07848 .58505 L
.0785 .58535 L
.07852 .58566 L
.07851 .58603 L
.07847 .58654 L
.07842 .58722 L
.07833 .58798 L
.07821 .58892 L
.07809 .59002 L
Mistroke
.07796 .5913 L
.07784 .59268 L
.07777 .59433 L
.07776 .59621 L
.07781 .59835 L
.07793 .60082 L
.07814 .60329 L
.07843 .60604 L
.0788 .60895 L
.07925 .61208 L
.07979 .615 L
.08041 .61797 L
.08108 .62106 L
.08178 .62397 L
.08248 .62704 L
.08315 .6299 L
.08376 .63277 L
.08434 .63532 L
.08491 .63775 L
.08543 .63981 L
.08591 .64164 L
.08636 .64325 L
.08676 .64467 L
.08711 .64595 L
.08742 .64717 L
.08771 .64834 L
.08799 .64947 L
.08828 .65056 L
.08859 .65161 L
.08894 .65253 L
.08931 .65343 L
.08968 .65423 L
.09001 .65498 L
.09029 .6556 L
.09054 .65615 L
.09076 .65664 L
.09097 .65703 L
.09117 .6574 L
.09138 .65782 L
.09159 .65832 L
.09179 .65893 L
.09197 .6598 L
.09214 .66094 L
.0923 .66231 L
.09245 .66377 L
.09261 .6654 L
.09277 .66713 L
.09292 .6688 L
.09304 .67062 L
.09315 .67228 L
Mistroke
.09324 .67398 L
.09332 .67567 L
.09339 .67739 L
.09346 .67914 L
.09354 .68092 L
.09365 .68256 L
.09381 .68433 L
.09407 .68619 L
.09444 .68802 L
.0949 .68994 L
.09547 .69187 L
.09616 .69363 L
.09695 .6953 L
.0979 .6968 L
.09861 .69783 L
.09944 .69881 L
.10029 .69959 L
.10098 .70018 L
.10162 .70064 L
.10222 .70101 L
.10274 .7013 L
.10315 .70154 L
.10343 .70178 L
.10358 .70208 L
.10362 .7025 L
.10358 .70305 L
.1035 .70378 L
.10341 .70471 L
.10332 .70577 L
.10326 .70694 L
.10321 .7082 L
.10314 .7095 L
.10305 .7109 L
.10295 .71243 L
.10285 .71422 L
.10275 .71584 L
.10265 .71767 L
.10258 .71956 L
.10252 .72136 L
.10247 .72302 L
.10245 .72454 L
.10243 .72576 L
.10243 .72682 L
.10245 .72772 L
.10249 .72848 L
.10255 .7291 L
.10261 .72955 L
.10268 .72982 L
.10274 .72993 L
.10279 .72993 L
Mistroke
.10281 .72985 L
.10281 .72974 L
.10279 .72962 L
.10276 .72952 L
.10275 .72948 L
.10275 .72945 L
.10275 .72941 L
.10275 .72934 L
.10276 .72925 L
.10276 .72914 L
.10276 .72901 L
.10276 .72889 L
.10275 .72881 L
.10272 .72878 L
.10268 .72877 L
.10264 .72878 L
.10261 .72877 L
.10261 .72878 L
.10263 .7288 L
.10266 .72887 L
.10272 .72899 L
.10281 .72919 L
.10297 .72952 L
.10324 .72999 L
.10361 .73059 L
.10409 .73134 L
.10471 .73223 L
.10545 .73328 L
.1063 .73438 L
.10723 .7356 L
.10813 .7369 L
.10904 .73825 L
.10992 .73962 L
.11073 .74091 L
.11151 .74218 L
.11225 .74339 L
.11298 .7445 L
.11372 .74555 L
.11451 .74656 L
.1154 .74767 L
.11633 .74878 L
.11737 .75008 L
.11855 .75153 L
.11978 .75303 L
.12121 .75465 L
.1228 .75641 L
.12452 .75825 L
.1263 .7599 L
.12808 .76162 L
.12968 .76302 L
Mistroke
.13121 .76427 L
.13241 .76533 L
.13338 .7661 L
.13402 .76659 L
.13432 .76681 L
.13431 .76682 L
.13413 .76669 L
.13387 .76647 L
.13361 .76623 L
.13336 .76606 L
.13319 .76603 L
.13309 .76619 L
.13308 .76657 L
.13322 .7671 L
.13362 .76777 L
.13443 .76859 L
.13532 .76941 L
.13666 .77034 L
.13819 .77131 L
.13996 .77233 L
.14183 .77336 L
.14384 .77434 L
.1458 .77527 L
.14777 .77613 L
.14977 .77688 L
.15167 .77751 L
.15346 .77803 L
.15507 .77846 L
.15643 .77882 L
.15753 .77911 L
.15846 .77941 L
.15907 .77965 L
.15956 .77995 L
.15993 .7803 L
.16021 .78072 L
.16042 .78125 L
.16064 .78191 L
.16086 .78275 L
.16112 .78369 L
.16142 .78492 L
.16186 .78639 L
.16247 .78802 L
.16328 .78982 L
.16432 .79186 L
.16555 .79413 L
.16689 .79646 L
.16837 .79882 L
.17 .80133 L
.17169 .80381 L
.17352 .80635 L
Mistroke
.17552 .80891 L
.17765 .81138 L
.17993 .81379 L
.18217 .8161 L
.18442 .81822 L
.18647 .82013 L
.18831 .82168 L
.18994 .82304 L
.19128 .8241 L
.19242 .82495 L
.19334 .82564 L
.19412 .8262 L
.19483 .82673 L
.19553 .8273 L
.19627 .82796 L
.19704 .82873 L
.19793 .82964 L
.19892 .83068 L
.20013 .83191 L
.20161 .83336 L
.2033 .83506 L
.20522 .83686 L
.20719 .83874 L
.20925 .84058 L
.21133 .8425 L
.21313 .84398 L
.21488 .84546 L
.21639 .84676 L
.2177 .84784 L
.21874 .84872 L
.21956 .84945 L
.22016 .84999 L
.22055 .85038 L
.22078 .85067 L
.22089 .85089 L
.22093 .85108 L
.22097 .85129 L
.22107 .85153 L
.22128 .85184 L
.22161 .85221 L
.22209 .85264 L
.22271 .85311 L
.22343 .85361 L
.22418 .85412 L
.22495 .85453 L
.22572 .85496 L
.22644 .85531 L
.22704 .85557 L
.22753 .85574 L
.22788 .85583 L
Mistroke
.22811 .85587 L
.22823 .85586 L
.22828 .85586 L
.22833 .85592 L
.22848 .85608 L
.2288 .85637 L
.22934 .85685 L
.23013 .85749 L
.23117 .85829 L
.23242 .8593 L
.23397 .86047 L
.23579 .86183 L
.2377 .86331 L
.23976 .86484 L
.24184 .86641 L
.24387 .86785 L
.24574 .86912 L
.24752 .87044 L
.24918 .87173 L
.25059 .87297 L
.25188 .87416 L
.25292 .87521 L
.25389 .87618 L
.25454 .87706 L
.25513 .87783 L
.25566 .87847 L
.25604 .87916 L
.25644 .87987 L
.25686 .88064 L
.25737 .88148 L
.25793 .88227 L
.25865 .88311 L
.25952 .88393 L
.26064 .88472 L
.26166 .88549 L
.26298 .88627 L
.26445 .8871 L
.26613 .88802 L
.26807 .88904 L
.27026 .89015 L
.27261 .89129 L
.27497 .89237 L
.27731 .8934 L
.27963 .89437 L
.28169 .89527 L
.28357 .89606 L
.28502 .89674 L
.2862 .89734 L
.28716 .89785 L
.28791 .8982 L
Mistroke
.28844 .89837 L
.28882 .89838 L
.28907 .89823 L
.28928 .89796 L
.28958 .89763 L
.29005 .89732 L
.29068 .89704 L
.29154 .89681 L
.29252 .89662 L
.29367 .89646 L
.29491 .89627 L
.29619 .89607 L
.29738 .89583 L
.29838 .89557 L
.29914 .89527 L
.29964 .89495 L
.29994 .89465 L
.30008 .89445 L
.30008 .89435 L
.29994 .89432 L
.29986 .89441 L
.29989 .89464 L
.30014 .89498 L
.30065 .89548 L
.30153 .89627 L
.3028 .89731 L
.30455 .89856 L
.30663 .89995 L
.30922 .90145 L
.31199 .90308 L
.31519 .90479 L
.31838 .90652 L
.32183 .90821 L
.32519 .90984 L
.32863 .91136 L
.33204 .91269 L
.33545 .91395 L
.33855 .91505 L
.34169 .91605 L
.34475 .91696 L
.34774 .91779 L
.35061 .91857 L
.35341 .91929 L
.35611 .91998 L
.35882 .92067 L
.36149 .92135 L
.36403 .92206 L
.36656 .9228 L
.36905 .92359 L
.37135 .92441 L
Mistroke
.37348 .92522 L
.37536 .92598 L
.37692 .92666 L
.37818 .92723 L
.37918 .92767 L
.37992 .92795 L
.38049 .92807 L
.38093 .92805 L
.38132 .92786 L
.38176 .92749 L
.38234 .92696 L
.3831 .9263 L
.384 .92553 L
.38514 .92465 L
.38639 .9237 L
.38775 .92272 L
.38919 .92178 L
.39067 .92082 L
.39208 .92021 L
.39333 .91955 L
.39431 .91908 L
.39501 .9188 L
.39543 .91876 L
.39559 .91893 L
.39548 .91927 L
.39519 .91975 L
.39485 .92038 L
.39454 .9211 L
.39434 .92182 L
.39432 .92245 L
.39453 .92299 L
.39498 .92348 L
.39564 .92392 L
.39649 .92428 L
.39735 .92463 L
.39822 .92503 L
.399 .92543 L
.39964 .92582 L
.40006 .92622 L
.40026 .92662 L
.40026 .92687 L
.40011 .92703 L
.39982 .92701 L
.39945 .92684 L
.39886 .92648 L
.39838 .92581 L
.39781 .92497 L
.39728 .92411 L
.39682 .92293 L
.39651 .92166 L
Mistroke
.39635 .92021 L
.39631 .91891 L
.39634 .91768 L
.39639 .91668 L
.39643 .91595 L
.39639 .91547 L
.39623 .91523 L
.39594 .91523 L
.39558 .91552 L
.39518 .91604 L
.3948 .9167 L
.39446 .9175 L
.39423 .91846 L
.39411 .91948 L
.39413 .92063 L
.39431 .92185 L
.39467 .92312 L
.39524 .92449 L
.39602 .92593 L
.39699 .92742 L
.39818 .92893 L
.39961 .93042 L
.40123 .93193 L
.40309 .93344 L
.40509 .9349 L
.40734 .93637 L
.40986 .93775 L
.41241 .93898 L
.41515 .94012 L
.41805 .9412 L
.42099 .94224 L
.42394 .94323 L
.42675 .94419 L
.42957 .94509 L
.43222 .94592 L
.43474 .94667 L
.43688 .94732 L
.43881 .94784 L
.44052 .94821 L
.442 .94849 L
.44333 .94876 L
.44454 .94904 L
.44575 .94934 L
.4468 .94959 L
.44799 .94983 L
.44926 .95 L
.45057 .95005 L
.45199 .94998 L
.45351 .94983 L
.45502 .94963 L
Mistroke
.45655 .94948 L
.45806 .94945 L
.45957 .94953 L
.46103 .94969 L
.46253 .94978 L
.46407 .94986 L
.46568 .94996 L
.46738 .95007 L
.46915 .95021 L
.47098 .95035 L
.47301 .95055 L
.47515 .95081 L
.47741 .95107 L
.47972 .95128 L
.48213 .95137 L
.48457 .95132 L
.48707 .95116 L
.48989 .95094 L
.49223 .95075 L
.49468 .95057 L
.49698 .95043 L
.49903 .95034 L
.50067 .9503 L
.50191 .9503 L
.50268 .95031 L
.50317 .9503 L
.5034 .95028 L
.50344 .95029 L
.50335 .95034 L
.50307 .9504 L
.50269 .95043 L
.5023 .95041 L
.50194 .9503 L
.50162 .95009 L
.50142 .94976 L
.50128 .94931 L
.50129 .9488 L
.50149 .94825 L
.50186 .94769 L
.50233 .94713 L
.50261 .94652 L
.50277 .94584 L
.50282 .94513 L
.50277 .94445 L
.50273 .9438 L
.50268 .94324 L
.50261 .94277 L
.50261 .94247 L
.50261 .94226 L
.50259 .94219 L
Mistroke
.50249 .94225 L
.50229 .9424 L
.50194 .94253 L
.50141 .94256 L
.50068 .94255 L
.49969 .94253 L
.49843 .94251 L
.49695 .94253 L
.49526 .94262 L
.49344 .94279 L
.49134 .94299 L
.48889 .94317 L
.48663 .94331 L
.48413 .94348 L
.48152 .94364 L
.47884 .94376 L
.47611 .94396 L
.4733 .94423 L
.47056 .94457 L
.46778 .94488 L
.46498 .94529 L
.46226 .94555 L
.45944 .94572 L
.45664 .94577 L
.45387 .9458 L
.45114 .94583 L
.44841 .94587 L
.44583 .94592 L
.44322 .94599 L
.44088 .94605 L
.43852 .94598 L
.43608 .94578 L
.43402 .94543 L
.43194 .94495 L
.42991 .94438 L
.42783 .94373 L
.42576 .94303 L
.42371 .94233 L
.42162 .9416 L
.41945 .94085 L
.41719 .94009 L
.41493 .93927 L
.4125 .9384 L
.40984 .93746 L
.4071 .93651 L
.40424 .93557 L
.4013 .93463 L
.39819 .93369 L
.39505 .93276 L
.39194 .93179 L
Mistroke
.38871 .93078 L
.38559 .92973 L
.38241 .92866 L
.37931 .92753 L
.37623 .92639 L
.37304 .92527 L
.36996 .92419 L
.36688 .92322 L
.36385 .9223 L
.36079 .92141 L
.35785 .92052 L
.35495 .91961 L
.35189 .91865 L
.34877 .91763 L
.34579 .91658 L
.34267 .91549 L
.33945 .91441 L
.33649 .91339 L
.33362 .9124 L
.3307 .91145 L
.32817 .91055 L
.32549 .90972 L
.32341 .90899 L
.32153 .90838 L
.31982 .90792 L
.31837 .90761 L
.31722 .90744 L
.31637 .90738 L
.31571 .90736 L
.31513 .90728 L
.31451 .90707 L
.3138 .90671 L
.31296 .90617 L
.31191 .90546 L
.31058 .9046 L
.3092 .90369 L
.30772 .9027 L
.30625 .9017 L
.30487 .90073 L
.30353 .89982 L
.30223 .89904 L
.30114 .8984 L
.30026 .89793 L
.29958 .89765 L
.29912 .89751 L
.29888 .89746 L
.29883 .89746 L
.29892 .89742 L
.29908 .89726 L
.29925 .89694 L
Mistroke
.29938 .89649 L
.29944 .89594 L
.29944 .89532 L
.29941 .89472 L
.2994 .89422 L
.29959 .89386 L
.29976 .89365 L
.29997 .89359 L
.30013 .89371 L
.30025 .894 L
.30024 .89442 L
.30004 .89489 L
.29958 .89536 L
.29883 .89589 L
.29777 .89635 L
.29638 .89665 L
.29477 .89672 L
.29279 .89652 L
.29063 .89601 L
.28826 .89533 L
.28555 .89444 L
.28271 .89344 L
.2798 .89246 L
.27725 .89149 L
.27461 .89059 L
.27226 .88987 L
.27015 .88921 L
.26837 .88866 L
.26687 .88817 L
.26558 .88771 L
.26458 .88726 L
.26372 .88682 L
.26296 .88639 L
.26244 .886 L
.26199 .88558 L
.26163 .88515 L
.26137 .88478 L
.2612 .88443 L
.26106 .88407 L
.26091 .88373 L
.2607 .88342 L
.26048 .88317 L
.26014 .88295 L
.2597 .88276 L
.25914 .88254 L
.25842 .88224 L
.25751 .88181 L
.25644 .88121 L
.25521 .88041 L
.25388 .87945 L
Mistroke
.25238 .87829 L
.25069 .87695 L
.24885 .87551 L
.24701 .87401 L
.24516 .87248 L
.24341 .87095 L
.24186 .86949 L
.24052 .86823 L
.23942 .86719 L
.23851 .86636 L
.23773 .86565 L
.23709 .86511 L
.23648 .86459 L
.23581 .86401 L
.23517 .86343 L
.23457 .8629 L
.23384 .86222 L
.23299 .86144 L
.23196 .86048 L
.2307 .85938 L
.22925 .85808 L
.22766 .8567 L
.22587 .85516 L
.22392 .85346 L
.22186 .85163 L
.21973 .84976 L
.21754 .8478 L
.21542 .84586 L
.21329 .84391 L
.21114 .84197 L
.20909 .84023 L
.20708 .83849 L
.20513 .83672 L
.20328 .83506 L
.20151 .83335 L
.19986 .83157 L
.19832 .82985 L
.19685 .82811 L
.19546 .82639 L
.19418 .82479 L
.19298 .82325 L
.19186 .82198 L
.19084 .82073 L
.18986 .81967 L
.18891 .81864 L
.18794 .81761 L
.18695 .81667 L
.18589 .81578 L
.18474 .81495 L
.18351 .81414 L
Mistroke
.18218 .81331 L
.18077 .81242 L
.17939 .81141 L
.17788 .81037 L
.17632 .80903 L
.1747 .80762 L
.17295 .80599 L
.17122 .80426 L
.16942 .80239 L
.16759 .8004 L
.16584 .79843 L
.16415 .79651 L
.16253 .79454 L
.16095 .79254 L
.15934 .79053 L
.15787 .78857 L
.15637 .78658 L
.15488 .78464 L
.15341 .78281 L
.15208 .78113 L
.15085 .7796 L
.14976 .77822 L
.1487 .77696 L
.14762 .77579 L
.14645 .77469 L
.14544 .77364 L
.14418 .77259 L
.1427 .77147 L
.14111 .7702 L
.13927 .76895 L
.13745 .76756 L
.13538 .76602 L
.13329 .76434 L
.13142 .76251 L
.12947 .76057 L
.12732 .7585 L
.1252 .75637 L
.12307 .7542 L
.12106 .75203 L
.11902 .74988 L
.11715 .7479 L
.11537 .74602 L
.11365 .74431 L
.11213 .74275 L
.1107 .74134 L
.10935 .74008 L
.10813 .73896 L
.10714 .73794 L
.1063 .73701 L
.10565 .7362 L
Mistroke
.10519 .73556 L
.10495 .73509 L
.10488 .73477 L
.10495 .73453 L
.10509 .73434 L
.10527 .73418 L
.10545 .73403 L
.10562 .73389 L
.10577 .73373 L
.10587 .73356 L
.10592 .73341 L
.10591 .73332 L
.10585 .73328 L
.10572 .73319 L
.10551 .73304 L
.10525 .73278 L
.10495 .73238 L
.10464 .73183 L
.10433 .73107 L
.10408 .73035 L
.10383 .72947 L
.1036 .72855 L
.10337 .72755 L
.10315 .72639 L
.10291 .72498 L
.10269 .72331 L
.10249 .72143 L
.10228 .71953 L
.10206 .71766 L
.10181 .71586 L
.10153 .71422 L
.10121 .71277 L
.10085 .71155 L
.1005 .71054 L
.10019 .70974 L
.09994 .70912 L
.09975 .70863 L
.09962 .70827 L
.09956 .70809 L
.09957 .70805 L
.09964 .70808 L
.09982 .7081 L
.10008 .70806 L
.10038 .70798 L
.1007 .70787 L
.10099 .70772 L
.10122 .70757 L
.10137 .70747 L
.10141 .7075 L
.10134 .70762 L
Mistroke
.10115 .70778 L
.1009 .70788 L
.10059 .70782 L
.10023 .70751 L
.09981 .70701 L
.09931 .70641 L
.09872 .70553 L
.09808 .70439 L
.09742 .70296 L
.09678 .70129 L
.09619 .69938 L
.0956 .69745 L
.09502 .69519 L
.0944 .6925 L
.09374 .68965 L
.09301 .68644 L
.0922 .68299 L
.09138 .67906 L
.09057 .67505 L
.08981 .67069 L
.08911 .66698 L
.08849 .66312 L
.08794 .65988 L
.08745 .65699 L
.08706 .65418 L
.08674 .6516 L
.08653 .64957 L
.0864 .64833 L
.08637 .64767 L
.08639 .64728 L
.08639 .64689 L
.08633 .64643 L
.08619 .64583 L
.08595 .64475 L
.08559 .64293 L
.08519 .64066 L
.08474 .63805 L
.08425 .63529 L
.08377 .63242 L
.08329 .62955 L
.08282 .62674 L
.08244 .62422 L
.08213 .62195 L
.08189 .62007 L
.08177 .61862 L
.08179 .61757 L
.08194 .61694 L
.0822 .61668 L
.08254 .61669 L
.08291 .61688 L
Mistroke
.08328 .61719 L
.08363 .61758 L
.08395 .61799 L
.08421 .61838 L
.08441 .61871 L
.08458 .61896 L
.08473 .61913 L
.08484 .61924 L
.08491 .6193 L
.08493 .61931 L
.08491 .6193 L
.08487 .61927 L
.08483 .61923 L
.08479 .6192 L
.08478 .61918 L
.08478 .61918 L
.0848 .61919 L
.08486 .61922 L
.08494 .61926 L
.08501 .61933 L
.08505 .61944 L
.08503 .6196 L
.08495 .61978 L
.08478 .61993 L
.08451 .61998 L
.08413 .61986 L
.08366 .6195 L
.08311 .61882 L
.08251 .6178 L
.0819 .61642 L
.0813 .61464 L
.08068 .61246 L
.08006 .61011 L
.07948 .60741 L
.07896 .60433 L
.0785 .6013 L
.07811 .598 L
.07777 .59469 L
.07747 .5913 L
.07719 .58805 L
.0769 .58483 L
.07658 .58167 L
.07619 .57849 L
.07574 .57533 L
.07525 .57209 L
.07473 .56872 L
.07417 .56508 L
.07356 .56161 L
.07291 .55796 L
.07227 .5543 L
Mistroke
.07162 .55065 L
.07097 .54713 L
.07035 .54378 L
.06975 .54044 L
.06919 .53735 L
.0687 .53429 L
.06832 .53138 L
.06803 .52857 L
.06784 .52584 L
.06776 .52305 L
.06779 .52024 L
.06794 .51717 L
.0682 .51413 L
.06856 .51086 L
.06903 .50751 L
.06956 .50401 L
.07017 .50066 L
.07076 .49745 L
.07136 .49457 L
.07193 .49199 L
.07245 .48972 L
.07291 .48783 L
.07331 .48628 L
.07365 .48496 L
.07394 .48383 L
.07416 .48288 L
.07431 .48205 L
.0744 .48132 L
.07444 .48064 L
.07444 .47994 L
.07445 .47924 L
.0745 .47844 L
.07459 .47755 L
.07473 .4766 L
.07494 .47566 L
.07522 .4748 L
.07553 .47408 L
.07584 .4735 L
.07613 .47305 L
.07641 .47269 L
.07666 .47239 L
.07686 .47209 L
.07701 .47176 L
.0771 .47137 L
.07716 .47093 L
.07723 .47048 L
.07731 .47004 L
.07742 .46963 L
.07753 .46923 L
.07763 .46883 L
Mistroke
.07775 .46843 L
.07792 .46801 L
.07814 .46759 L
.07842 .46719 L
.07875 .4668 L
.07912 .46644 L
.07954 .46608 L
.07998 .46572 L
.08044 .46536 L
.08085 .46496 L
.0812 .46452 L
.08148 .46412 L
.08177 .46372 L
.08204 .46339 L
.08231 .46312 L
.08256 .46293 L
.08278 .46281 L
.08295 .46275 L
Mfstroke
.07677 .49461 m
.07671 .49474 L
.07662 .49499 L
.07647 .49539 L
.07621 .49595 L
.07584 .49673 L
.07534 .49771 L
.0747 .49885 L
.07411 .50009 L
.07337 .50155 L
.07257 .50329 L
.07174 .50532 L
.071 .50727 L
.07017 .50972 L
.06945 .51184 L
.06879 .51418 L
.0682 .51683 L
.06772 .51951 L
.06738 .52161 L
.06719 .52406 L
.06715 .52659 L
.06722 .5286 L
.06739 .53056 L
.06762 .53229 L
.06789 .53384 L
.06816 .53501 L
.06841 .53607 L
.06866 .53676 L
.06891 .53718 L
.06915 .53735 L
.06937 .53733 L
.06954 .53719 L
.06965 .53699 L
.06969 .53679 L
.06967 .53665 L
.06961 .53661 L
.06952 .53674 L
.06945 .53709 L
.06942 .53767 L
.06946 .53848 L
.0696 .53949 L
.06981 .54069 L
.07009 .54196 L
.07045 .54337 L
.07085 .54488 L
.07127 .5464 L
.07173 .54786 L
.0722 .54923 L
.07267 .55045 L
.07309 .55145 L
Mistroke
.07348 .55226 L
.07382 .55286 L
.07408 .55326 L
.07427 .55348 L
.07437 .55358 L
.07441 .55359 L
.0744 .55354 L
.07436 .55345 L
.07431 .55331 L
.07427 .55314 L
.07424 .55297 L
.07423 .55283 L
.07423 .55275 L
.07423 .55273 L
.07423 .55281 L
.07422 .55303 L
.07419 .55338 L
.07414 .55389 L
.07407 .55455 L
.074 .55538 L
.07394 .55638 L
.0739 .55748 L
.07391 .5587 L
.07395 .56003 L
.07405 .56144 L
.07418 .56285 L
.07435 .56417 L
.07454 .56538 L
.07473 .56644 L
.07493 .56732 L
.07517 .56802 L
.07544 .56857 L
.07574 .56899 L
.07605 .56933 L
.07633 .56964 L
.07656 .56996 L
.07672 .57029 L
.07681 .57064 L
.07685 .57104 L
.07687 .57149 L
.0769 .572 L
.07697 .5726 L
.07711 .5733 L
.07732 .57409 L
.07756 .57492 L
.07783 .57577 L
.07811 .57662 L
.07837 .57744 L
.07869 .57819 L
.07903 .57886 L
Mistroke
.07941 .57942 L
.07978 .57992 L
.08017 .58033 L
.08052 .58069 L
.08081 .58097 L
.08101 .5812 L
.08112 .58137 L
.08115 .58148 L
.08114 .58151 L
.0811 .58148 L
.08106 .58141 L
.08101 .58132 L
.08096 .58122 L
.08092 .58111 L
.08088 .58099 L
.08085 .58089 L
.08083 .58083 L
.08084 .58083 L
.08089 .58091 L
.08099 .58112 L
.08113 .58148 L
.0813 .58201 L
.08147 .5827 L
.08166 .58355 L
.08185 .58456 L
.08204 .58566 L
.08223 .58685 L
.0824 .58806 L
.08257 .58922 L
.08273 .59027 L
.08288 .59113 L
.08299 .59174 L
.08306 .59212 L
.0831 .59226 L
.08311 .59218 L
.08311 .5919 L
.08312 .59146 L
.08315 .59093 L
.0832 .59037 L
.08325 .5898 L
.0833 .58924 L
.08333 .58873 L
.08334 .58834 L
.08333 .5881 L
.08332 .58801 L
.08331 .58798 L
.08331 .58801 L
.08333 .58804 L
.08336 .58804 L
.0834 .58799 L
Mistroke
.08344 .58792 L
.08346 .58787 L
.08345 .5879 L
.08341 .58803 L
.08332 .58828 L
.08319 .58868 L
.08301 .58921 L
.08276 .58983 L
.08244 .59055 L
.08205 .59136 L
.08161 .59222 L
.08116 .59309 L
.08073 .59395 L
.08032 .59476 L
.07996 .5955 L
.07964 .59615 L
.07935 .59667 L
.07912 .59708 L
.07892 .59739 L
.07876 .59761 L
.07865 .59777 L
.07859 .5979 L
.07858 .59803 L
.07861 .59819 L
.07869 .59836 L
.0788 .59854 L
.07893 .59873 L
.07907 .59894 L
.07918 .59913 L
.0793 .59934 L
.07943 .59956 L
.07955 .59972 L
.07971 .59988 L
.0799 .6 L
.08007 .60007 L
.0802 .60012 L
.08028 .60017 L
.08031 .60024 L
.0803 .6003 L
.08029 .60033 L
.08027 .60033 L
.08026 .60031 L
.08025 .60029 L
.08024 .60027 L
.08023 .60026 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
Mistroke
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .60025 L
.08023 .6002 L
.08023 .60011 L
.08024 .59999 L
.08024 .59988 L
.08024 .5998 L
.08024 .59981 L
.08024 .59993 L
.08023 .60019 L
.08022 .60061 L
.08019 .60119 L
.08017 .60194 L
.08013 .60285 L
.08009 .60389 L
.08005 .60494 L
.08001 .60604 L
.07997 .60714 L
.07993 .60828 L
.07989 .60926 L
.07986 .61009 L
.07982 .61071 L
.07978 .61112 L
.07973 .61135 L
.07968 .61144 L
.07965 .61145 L
.07964 .61147 L
.07965 .61156 L
.07969 .61183 L
.07978 .61232 L
.07992 .61308 L
.08014 .61415 L
.08042 .61562 L
Mistroke
.08079 .61735 L
.0812 .61945 L
.08167 .62195 L
.0822 .6247 L
.08279 .62799 L
.0834 .63143 L
.08402 .63473 L
.08463 .63858 L
.08521 .64278 L
.08574 .64635 L
.08624 .6504 L
.08672 .65474 L
.08718 .65818 L
.08761 .66202 L
.08802 .66549 L
.08842 .66887 L
.08878 .67169 L
.08912 .67428 L
.08941 .67643 L
.08966 .678 L
.08989 .67931 L
.0901 .68033 L
.09032 .68107 L
.09053 .68159 L
.09074 .68199 L
.09096 .68239 L
.09116 .68285 L
.09136 .68339 L
.09154 .68402 L
.09173 .6848 L
.09194 .68571 L
.0922 .68681 L
.09249 .68802 L
.09281 .68926 L
.09312 .69051 L
.09343 .69177 L
.09372 .69296 L
.094 .69413 L
.09429 .69539 L
.09458 .69681 L
.0949 .69841 L
.0953 .70029 L
.0957 .70198 L
.09615 .70414 L
.09663 .70655 L
.09709 .70881 L
.09756 .71131 L
.09803 .71396 L
.09851 .71656 L
.099 .71941 L
Mistroke
.09948 .72149 L
.09994 .72364 L
.10034 .72554 L
.10066 .72709 L
.10089 .72829 L
.10104 .72913 L
.10116 .72967 L
.10126 .72991 L
.10135 .73 L
.10146 .72999 L
.10157 .72989 L
.10167 .72982 L
.10177 .72978 L
.10186 .72979 L
.10193 .72985 L
.102 .72994 L
.10208 .73006 L
.10218 .73017 L
.10231 .73028 L
.10246 .7304 L
.10261 .73056 L
.10275 .73076 L
.10286 .73099 L
.10294 .73124 L
.10296 .73147 L
.10293 .73162 L
.10283 .73168 L
.10269 .73163 L
.10253 .73152 L
.10232 .73137 L
.10209 .73119 L
.10185 .73102 L
.10164 .73095 L
.10146 .73094 L
.10134 .73093 L
.10129 .73094 L
.10132 .73098 L
.10144 .73109 L
.10165 .73129 L
.10197 .7316 L
.10238 .73203 L
.10284 .73251 L
.10332 .73306 L
.10379 .73352 L
.10423 .73399 L
.10464 .73435 L
.10501 .73457 L
.10533 .7347 L
.10565 .73477 L
.10599 .73479 L
Mistroke
.10637 .73475 L
.10679 .73467 L
.10725 .73457 L
.10771 .73448 L
.10821 .73439 L
.10868 .73439 L
.10915 .73442 L
.10956 .73447 L
.1099 .73457 L
.11013 .73472 L
.11022 .73493 L
.11017 .73509 L
.10999 .7352 L
.10967 .73532 L
.10925 .73543 L
.10877 .73554 L
.10825 .73561 L
.10773 .73562 L
.10726 .7356 L
.10686 .73556 L
.10657 .73558 L
.1064 .73565 L
.10635 .73578 L
.10645 .73595 L
.10667 .73624 L
.10697 .73665 L
.10735 .73714 L
.10778 .73768 L
.10826 .73825 L
.10882 .73887 L
.10927 .73939 L
.10978 .73999 L
.11024 .7406 L
.11064 .74121 L
.11096 .74175 L
.11118 .74219 L
.11129 .74251 L
.11133 .74273 L
.11133 .74286 L
.11133 .74292 L
.11148 .74286 L
.11149 .74287 L
.11155 .7429 L
.11162 .74295 L
.11171 .74302 L
.11181 .74307 L
.11192 .74311 L
.11203 .74311 L
.11213 .74311 L
.11223 .74307 L
Mistroke
.11233 .74303 L
.11243 .74302 L
.1125 .74304 L
.11252 .74306 L
.11248 .74306 L
.11236 .74303 L
.11217 .74294 L
.11194 .74278 L
.11171 .74257 L
.11149 .74236 L
.11129 .74218 L
.11115 .74207 L
.11105 .74203 L
.11098 .74206 L
.11092 .74214 L
.11087 .74226 L
.11078 .7424 L
.11067 .74253 L
.11054 .74264 L
.11042 .74274 L
.11035 .74282 L
.11036 .74295 L
.11044 .74312 L
.1106 .74331 L
.1108 .74346 L
.11102 .74354 L
.11126 .74358 L
.11155 .74359 L
.11181 .74358 L
.1121 .74356 L
.11237 .74353 L
.11262 .74351 L
.11279 .74347 L
.11285 .74337 L
.11279 .74321 L
.11264 .74302 L
.11241 .7428 L
.11213 .74257 L
.11181 .74231 L
.1115 .74207 L
.11122 .74188 L
.11101 .74181 L
.11089 .74191 L
.11089 .7422 L
.11104 .7427 L
.11134 .74339 L
.11181 .74431 L
.11243 .74523 L
.11318 .74629 L
.114 .74741 L
Mistroke
.11495 .74853 L
.116 .74964 L
.11714 .75077 L
.11833 .75189 L
.11953 .75295 L
.12069 .75391 L
.12178 .75475 L
.12276 .75545 L
.12359 .75605 L
.12427 .7565 L
.1248 .75684 L
.12515 .75708 L
.12538 .75731 L
.12546 .75755 L
.12542 .75777 L
.12528 .75797 L
.12508 .75813 L
.12481 .75824 L
.12455 .75834 L
.1243 .75845 L
.12406 .75856 L
.12385 .75868 L
.12377 .75886 L
.12379 .75908 L
.12392 .7593 L
.12411 .75949 L
.12439 .75963 L
.12473 .75973 L
.12513 .75979 L
.12558 .75981 L
.12602 .75981 L
.12647 .7598 L
.12686 .75976 L
.12722 .75974 L
.12756 .75976 L
.12789 .75981 L
.12818 .75988 L
.12843 .75992 L
.12859 .75992 L
.12865 .75986 L
.12859 .75978 L
.12845 .75971 L
.12827 .75964 L
.12809 .75957 L
.12794 .75951 L
.12781 .75946 L
.12772 .75946 L
.12767 .75955 L
.12765 .75974 L
.12765 .76003 L
Mistroke
.12766 .76037 L
.12772 .76078 L
.1278 .76126 L
.12789 .7618 L
.128 .76236 L
.12811 .76289 L
.12823 .76343 L
.12834 .76392 L
.12847 .76436 L
.12863 .76477 L
.12885 .76512 L
.12917 .7654 L
.1296 .76562 L
.13017 .76581 L
.13088 .76595 L
.13166 .76603 L
.13253 .76605 L
.13341 .76609 L
.13428 .76614 L
.13509 .76621 L
.13581 .76628 L
.13638 .76634 L
.13671 .76639 L
.13701 .76644 L
.13721 .76647 L
.13728 .76649 L
.13723 .76649 L
.13706 .76645 L
.1368 .76641 L
.13649 .76637 L
.13616 .76632 L
.1358 .76625 L
.13542 .76614 L
.13503 .766 L
.13463 .76585 L
.13425 .76573 L
.13395 .76569 L
.13376 .76577 L
.13371 .76602 L
.13381 .76642 L
.13405 .76699 L
.13443 .76772 L
.13497 .76857 L
.13557 .76952 L
.13613 .77047 L
.13687 .77144 L
.13775 .77248 L
.13869 .77349 L
.13972 .77453 L
.14082 .77558 L
Mistroke
.14197 .77665 L
.14319 .77775 L
.14447 .77888 L
.14575 .78003 L
.14707 .78122 L
.14856 .78258 L
.14979 .78374 L
.15118 .78509 L
.15249 .78641 L
.15373 .78772 L
.15482 .78896 L
.15568 .79004 L
.15633 .79093 L
.15679 .79162 L
.15705 .79211 L
.15713 .79241 L
.15705 .79256 L
.15685 .79258 L
.15655 .79246 L
.1562 .79225 L
.15585 .792 L
.15554 .79178 L
.15535 .79165 L
.15535 .79169 L
.15559 .79198 L
.1561 .79247 L
.15691 .79327 L
.15798 .79434 L
.15938 .79569 L
.16112 .79735 L
.16317 .79931 L
.16546 .80132 L
.16797 .80353 L
.17076 .80615 L
.1735 .8086 L
.17641 .81123 L
.17935 .81393 L
.18233 .81663 L
.18523 .81939 L
.18817 .82209 L
.19115 .82489 L
.1942 .82774 L
.19732 .83069 L
.2006 .83402 L
.20366 .83687 L
.20695 .8402 L
.21033 .84359 L
.21368 .84684 L
.21698 .85009 L
.22024 .8533 L
Mistroke
.22326 .85629 L
.22615 .85911 L
.22874 .86161 L
.23109 .86386 L
.23311 .86564 L
.23483 .86709 L
.23622 .86816 L
.23741 .86889 L
.23818 .86931 L
.23881 .86955 L
.23924 .86964 L
.23948 .86961 L
.23964 .86956 L
.2397 .86946 L
.23973 .86938 L
.23976 .86934 L
.23986 .86944 L
.24003 .86966 L
.24032 .87001 L
.24076 .8705 L
.24137 .87115 L
.24214 .87188 L
.24306 .87264 L
.2441 .87339 L
.24535 .87415 L
.24673 .87489 L
.24825 .87566 L
.24985 .87642 L
.25144 .87718 L
.253 .87791 L
.2544 .87852 L
.25558 .87895 L
.25653 .87925 L
.25729 .87947 L
.25788 .87965 L
.2583 .87975 L
.25859 .87979 L
.25875 .87978 L
.25876 .87976 L
.25865 .87974 L
.25844 .87972 L
.25816 .87969 L
.25783 .87965 L
.25752 .87964 L
.25724 .87964 L
.25698 .87973 L
.25673 .87988 L
.25647 .88009 L
.25632 .88031 L
.25611 .88049 L
Mistroke
.25593 .88071 L
.25584 .88099 L
.25595 .88142 L
.25625 .88193 L
.25683 .88262 L
.25772 .88346 L
.2589 .88442 L
.26037 .88543 L
.26206 .88643 L
.26402 .88751 L
.26621 .88865 L
.26868 .88987 L
.27126 .89117 L
.27389 .89244 L
.27665 .89371 L
.27935 .89496 L
.28222 .89615 L
.28483 .89733 L
.28751 .89848 L
.29018 .89958 L
.29281 .90067 L
.29543 .90173 L
.29807 .90275 L
.30077 .90373 L
.30358 .90468 L
.30657 .9056 L
.3096 .9065 L
.31282 .9074 L
.31626 .9083 L
.31951 .90923 L
.32283 .91017 L
.3262 .91114 L
.32964 .91209 L
.3327 .91305 L
.33573 .91399 L
.33854 .91485 L
.34106 .91563 L
.3433 .91634 L
.34524 .91698 L
.34683 .91753 L
.34824 .91799 L
.34944 .91839 L
.35061 .91876 L
.35179 .91913 L
.35304 .91953 L
.35441 .91999 L
.35591 .92055 L
.35762 .92118 L
.35961 .9219 L
.36176 .92273 L
Mistroke
.36423 .92367 L
.36704 .92466 L
.37006 .92568 L
.37344 .92674 L
.37676 .92782 L
.38041 .92894 L
.38387 .93013 L
.38739 .93129 L
.39106 .93256 L
.39465 .93393 L
.39834 .93522 L
.4021 .9366 L
.40596 .93794 L
.40979 .93938 L
.41368 .94075 L
.41775 .9423 L
.42171 .94367 L
.42588 .94506 L
.42994 .94643 L
.4341 .94774 L
.43809 .94892 L
.44216 .94993 L
.44593 .95074 L
.44962 .95141 L
.45306 .95201 L
.45626 .95253 L
.45936 .95296 L
.46194 .95329 L
.46436 .95349 L
.46651 .95357 L
.46843 .95353 L
.47003 .9534 L
.47148 .95319 L
.47252 .95299 L
.47339 .95281 L
.47407 .95271 L
.47462 .95262 L
.47502 .95252 L
.47533 .95241 L
.47558 .95228 L
.47577 .95215 L
.47587 .95203 L
.4759 .95193 L
.47585 .95187 L
.47575 .95185 L
.47558 .95186 L
.4754 .9519 L
.47521 .95194 L
.47501 .95199 L
.47476 .95202 L
Mistroke
.47447 .95204 L
.47414 .95206 L
.47384 .95207 L
.47349 .95209 L
.47314 .95211 L
.47283 .95212 L
.47258 .95212 L
.47235 .95211 L
.47214 .95211 L
.47201 .95212 L
.47193 .95214 L
.4719 .95217 L
.47195 .9519 L
.47207 .95195 L
.47225 .95201 L
.47249 .95206 L
.47282 .9521 L
.4732 .95212 L
.47357 .95215 L
.47387 .95218 L
.47418 .95221 L
.47445 .95225 L
.47466 .95231 L
.47484 .95237 L
.47505 .95245 L
.47528 .95254 L
.47556 .95264 L
.47589 .95271 L
.47632 .95275 L
.47686 .95275 L
.47753 .95273 L
.47833 .95268 L
.47933 .95258 L
.48051 .95243 L
.48186 .95221 L
.48336 .95195 L
.48492 .95167 L
.48659 .95139 L
.48836 .95112 L
.49029 .95087 L
.4923 .95065 L
.49462 .95045 L
.49666 .95028 L
.49906 .9501 L
.50152 .9499 L
.5042 .94968 L
.50704 .94941 L
.51014 .94911 L
.51325 .94877 L
.51633 .94838 L
Mistroke
.51937 .94797 L
.52254 .94756 L
.52553 .94713 L
.52849 .94669 L
.53145 .94628 L
.53408 .94589 L
.53675 .94553 L
.53936 .94519 L
.54193 .94486 L
.54446 .94448 L
.54697 .94401 L
.54942 .94341 L
.55186 .94271 L
.5542 .9419 L
.55642 .9411 L
.55861 .94029 L
.56061 .93957 L
.56253 .93899 L
.56431 .93848 L
.56578 .93807 L
.56703 .93776 L
.5681 .93755 L
.56904 .93748 L
.56995 .93757 L
.57096 .93781 L
.57224 .93814 L
.57357 .93853 L
.5753 .93888 L
.5773 .93915 L
.57958 .93927 L
.58223 .93921 L
.58508 .93899 L
.5882 .9387 L
.59162 .93826 L
.59497 .93774 L
.5989 .93735 L
.60247 .93677 L
.60608 .93615 L
.60962 .93551 L
.61297 .9348 L
.6162 .93411 L
.61933 .93333 L
.62235 .93248 L
.62532 .93163 L
.62823 .93079 L
.63098 .93 L
.63357 .92923 L
.63594 .92857 L
.63806 .9279 L
.63995 .92725 L
Mistroke
.64159 .92667 L
.64309 .92619 L
.64445 .92579 L
.64572 .92543 L
.64691 .92507 L
.64802 .92472 L
.64901 .92447 L
.64981 .92433 L
.65052 .92421 L
.65112 .92417 L
.65163 .92412 L
.6521 .92402 L
.65252 .92387 L
.65286 .92373 L
.65303 .92365 L
.65299 .92368 L
.65275 .92377 L
.65234 .92399 L
.65181 .92431 L
.65123 .92468 L
.65069 .92497 L
.65025 .92527 L
.6499 .92559 L
.64962 .9259 L
.64936 .92617 L
.64914 .92643 L
.64892 .92669 L
.64868 .9269 L
.6485 .92701 L
.64844 .927 L
.64841 .92691 L
.64851 .9266 L
.64871 .9261 L
.64897 .92549 L
.64917 .92495 L
.64933 .92442 L
.64943 .92388 L
.64956 .92329 L
.64968 .92285 L
.64987 .9224 L
.65008 .92203 L
.6503 .92181 L
.65044 .92178 L
.65054 .92187 L
.65058 .92207 L
.65052 .9223 L
.65038 .92265 L
.65024 .92298 L
.65016 .92322 L
.65022 .9234 L
Mistroke
.6504 .92351 L
.65069 .92356 L
.65112 .92343 L
.65159 .9233 L
.65199 .92316 L
.6523 .923 L
.65252 .92276 L
.65263 .92265 L
.65255 .92271 L
.65233 .92293 L
.65194 .92324 L
.65141 .9237 L
.65081 .92424 L
.65026 .92473 L
.64982 .92501 L
.64951 .92516 L
.64925 .92525 L
.64906 .92529 L
.64906 .92523 L
.64919 .92515 L
.64938 .92508 L
.6497 .92496 L
.65006 .92479 L
.65039 .92467 L
.65063 .92463 L
.65075 .92465 L
.65072 .92479 L
.65059 .92503 L
.65043 .92528 L
.65023 .92555 L
.65007 .92578 L
.64996 .92589 L
.64991 .92591 L
.65001 .92573 L
.65024 .92543 L
.65055 .92505 L
.65082 .92474 L
.65112 .9244 L
.65142 .9241 L
.65177 .92382 L
.65203 .92366 L
.65229 .92351 L
.6525 .92344 L
.65268 .92343 L
.65285 .92351 L
.65307 .92363 L
.65336 .9237 L
.65367 .92377 L
.65391 .92389 L
.65402 .92408 L
Mistroke
.65402 .92428 L
.65391 .92452 L
.65373 .92477 L
.65352 .92495 L
.65336 .92503 L
.65324 .92503 L
.65316 .92496 L
.65307 .92485 L
.65301 .92466 L
.65298 .92448 L
.65293 .92434 L
.6529 .92422 L
.65293 .92408 L
.6531 .92392 L
.65341 .92374 L
.65378 .92357 L
.65422 .9234 L
.65462 .92328 L
.6549 .92325 L
.65504 .92332 L
.65505 .92348 L
.65498 .92369 L
.65483 .92394 L
.65466 .92416 L
.65449 .92433 L
.6543 .92431 L
.65412 .92441 L
.65394 .92449 L
.6538 .92452 L
.65376 .92446 L
.65375 .92439 L
.65384 .92423 L
.65399 .92401 L
.65418 .92374 L
.65431 .92355 L
.65444 .92335 L
.65455 .92317 L
.65461 .92307 L
.65454 .92307 L
.65442 .92311 L
.65426 .92317 L
.65404 .92329 L
.65371 .92353 L
.65337 .92382 L
.65309 .92413 L
.65287 .92446 L
.65265 .92488 L
.65247 .92532 L
.65236 .92571 L
.65227 .92614 L
Mistroke
.65222 .92659 L
.65223 .92706 L
.65228 .92749 L
.65231 .92787 L
.65232 .9282 L
.65232 .92842 L
.65242 .9285 L
.6526 .92845 L
.65289 .92829 L
.65335 .92794 L
.65393 .92741 L
.65455 .92683 L
.65512 .9263 L
.65568 .92571 L
.65617 .92518 L
.65657 .92475 L
.65691 .92441 L
.6572 .92415 L
.6574 .924 L
.65753 .92398 L
.65761 .92404 L
.65771 .92409 L
.65777 .92414 L
.65779 .92418 L
.6578 .9242 L
.65788 .92412 L
.65807 .92397 L
.65841 .9238 L
.65886 .9236 L
.65945 .92338 L
.66008 .92314 L
.66076 .92289 L
.66141 .92263 L
.66204 .92237 L
.66263 .9221 L
.66318 .92187 L
.66366 .92172 L
.664 .9217 L
.66412 .92179 L
.66403 .92199 L
.66378 .92225 L
.66345 .92253 L
.66308 .92276 L
.66279 .92287 L
.66245 .92294 L
.66202 .92307 L
.6615 .92334 L
.66091 .92372 L
.66025 .92418 L
.65946 .9249 L
Mistroke
.65862 .92549 L
.65785 .92601 L
.65732 .92639 L
.657 .92661 L
.65683 .92668 L
.65675 .92668 L
.65665 .92662 L
.65638 .92668 L
.65623 .92662 L
.65614 .9265 L
.65624 .92624 L
.65666 .9258 L
.6573 .92529 L
.65807 .92474 L
.65882 .92423 L
.65949 .92379 L
.65987 .92353 L
.65988 .92348 L
.65962 .92357 L
.6591 .92366 L
.65845 .92376 L
.65767 .92386 L
.65695 .92392 L
.65635 .92388 L
.65594 .92373 L
.65567 .92352 L
.65542 .92335 L
.65516 .92326 L
.65494 .92328 L
.65481 .92341 L
.65481 .92364 L
.65495 .92389 L
.65521 .92412 L
.6555 .92433 L
.65571 .92451 L
.65577 .92471 L
.65562 .92493 L
.65536 .92517 L
.65503 .92543 L
.65471 .92564 L
.65445 .92571 L
.65435 .92568 L
.65433 .92558 L
.65438 .92546 L
.6545 .92532 L
.65461 .92523 L
.65471 .9252 L
.65477 .92515 L
.65481 .92514 L
.65491 .92513 L
Mistroke
.65514 .9251 L
.65547 .92505 L
.65594 .92496 L
.65639 .92492 L
.65673 .92495 L
.65697 .92504 L
.65711 .92521 L
.65718 .92541 L
.65726 .92556 L
.65739 .92556 L
.65756 .92544 L
.65768 .92527 L
.65766 .92508 L
.65741 .92495 L
.65695 .92484 L
.65635 .92468 L
.65577 .92454 L
.65534 .92426 L
.65524 .92366 L
.65519 .92336 L
.65533 .92311 L
.65561 .92295 L
.65603 .92287 L
.65642 .92289 L
.65679 .92298 L
.65708 .92309 L
.65729 .9232 L
.65742 .92335 L
.65742 .92355 L
.65731 .92382 L
.65704 .92415 L
.65661 .92455 L
.656 .92501 L
.65526 .92548 L
.65436 .92594 L
.65357 .92624 L
.65279 .92651 L
.65206 .92672 L
.65149 .92687 L
.65107 .92699 L
.65081 .92708 L
.65075 .92704 L
.65083 .92691 L
.65111 .92667 L
.65156 .92633 L
.65215 .9259 L
.65287 .92535 L
.65363 .92486 L
.65437 .92447 L
.65514 .92412 L
Mistroke
.65591 .92386 L
.65661 .92373 L
.65727 .92364 L
.65787 .92354 L
.6584 .92345 L
.65878 .92341 L
.65899 .92343 L
.65901 .92352 L
.65886 .92369 L
.65859 .92391 L
.65831 .92409 L
.65812 .92418 L
.65815 .92415 L
.65842 .92398 L
.65882 .92378 L
.65937 .9235 L
.66003 .9232 L
.6609 .92286 L
.66168 .92257 L
.66262 .92223 L
.66354 .92192 L
.66439 .92165 L
.6651 .92144 L
.66567 .92124 L
.66609 .92106 L
.66629 .92098 L
.6662 .92102 L
.66587 .92119 L
.66534 .92142 L
.66472 .92171 L
.66399 .92203 L
.66325 .92234 L
.66263 .92262 L
.66224 .92281 L
.66208 .92295 L
.66217 .92302 L
.66252 .92302 L
.66303 .92302 L
.66365 .923 L
.66455 .92287 L
.66586 .9224 L
.66717 .92214 L
.66864 .92178 L
.67024 .9213 L
.67195 .92071 L
.67371 .92002 L
.67554 .91926 L
.67739 .91842 L
.6792 .91751 L
.68087 .91652 L
Mistroke
.68249 .91545 L
.68402 .91437 L
.68543 .91322 L
.68665 .91213 L
.68765 .91118 L
.68842 .91036 L
.68896 .90969 L
.68924 .90923 L
.68928 .90898 L
.68908 .90895 L
.68867 .9091 L
.68809 .9094 L
.68746 .9098 L
.68677 .91033 L
.68608 .91098 L
.68552 .91155 L
.68505 .91213 L
.68476 .91252 L
.6847 .91266 L
.68486 .91258 L
.68515 .91233 L
.68544 .91198 L
.68574 .91161 L
.68602 .91125 L
.68628 .91093 L
.68651 .91065 L
.6867 .91037 L
.68687 .91013 L
.687 .90997 L
.68712 .9099 L
.68721 .90993 L
.68721 .9101 L
.68712 .91038 L
.687 .91076 L
.68695 .91117 L
.68701 .91152 L
.6872 .91176 L
.68749 .91191 L
.6878 .91193 L
.6881 .91194 L
.68836 .91201 L
.68851 .91217 L
.68863 .91238 L
.68876 .91258 L
.68899 .9127 L
.68942 .91268 L
.69007 .91248 L
.69097 .91211 L
.69183 .91171 L
.69285 .91122 L
Mistroke
.69387 .91067 L
.69478 .91009 L
.69576 .90952 L
.69663 .90894 L
.69739 .90835 L
.69799 .90779 L
.69838 .90735 L
.69854 .907 L
.69842 .90681 L
.69801 .90679 L
.69731 .90697 L
.69645 .90726 L
.69561 .90758 L
.6948 .90787 L
.69429 .90799 L
.69364 .90824 L
.69302 .90845 L
.69245 .90872 L
.6919 .90905 L
.6914 .90948 L
.6909 .90999 L
.69039 .91053 L
.68988 .91104 L
.6894 .91146 L
.68891 .91184 L
.68852 .91209 L
.68812 .91231 L
.68778 .91242 L
.6875 .91248 L
.68731 .9125 L
.68723 .91251 L
.68716 .91252 L
.68712 .91249 L
.6871 .91248 L
.68705 .91247 L
.68698 .91247 L
.68682 .91258 L
.68657 .91285 L
.68625 .91321 L
.68589 .91358 L
.68548 .91393 L
.68501 .91423 L
.68446 .91445 L
.68386 .9146 L
.68322 .91465 L
.68258 .91463 L
.68202 .91462 L
.68143 .91466 L
.6809 .91478 L
.68045 .91496 L
Mistroke
.68006 .91522 L
.6797 .91554 L
.67938 .91592 L
.67913 .91633 L
.67894 .91677 L
.67878 .91722 L
.67862 .91765 L
.67843 .91809 L
.6782 .91851 L
.67793 .91889 L
.67762 .91919 L
.67733 .91943 L
.67707 .9196 L
.67686 .9197 L
.67668 .91974 L
.67659 .91973 L
.67654 .91969 L
.67652 .91964 L
.67654 .91959 L
.67658 .91957 L
.67662 .91961 L
.67665 .91968 L
.67667 .91974 L
.67667 .91976 L
.67669 .9197 L
.67669 .91956 L
.67667 .91936 L
.67661 .91913 L
.67651 .91891 L
.67636 .91869 L
.67622 .91844 L
.67615 .91815 L
.67616 .91782 L
.67624 .91748 L
.67636 .91714 L
.67647 .91686 L
.67654 .91667 L
.67654 .9166 L
.67649 .91667 L
.67641 .91689 L
.67631 .91722 L
.67619 .91759 L
.67611 .91792 L
.67607 .91815 L
.67612 .91828 L
.67608 .91837 L
.676 .91843 L
.67586 .91852 L
.67568 .91864 L
.67547 .91878 L
Mistroke
.6753 .91889 L
.6752 .91896 L
.67521 .91895 L
.67527 .91891 L
.67534 .91888 L
.67536 .91895 L
.67536 .9191 L
.67535 .91927 L
.67537 .91943 L
.6754 .91954 L
.67545 .91959 L
.67549 .91956 L
.67549 .91948 L
.67549 .91932 L
.67547 .91913 L
.67541 .91898 L
.67529 .91891 L
.67515 .91894 L
.67504 .91905 L
.67498 .91919 L
.67494 .91936 L
.67494 .91953 L
.67496 .91966 L
.67498 .91973 L
.67497 .91971 L
.67489 .91959 L
.67471 .91936 L
.67441 .91912 L
.67402 .91879 L
.6736 .91839 L
.67317 .91795 L
.67267 .91749 L
.67215 .91708 L
.67167 .91672 L
.67132 .91639 L
.67108 .9161 L
.67092 .91585 L
.6708 .91568 L
.67068 .91566 L
.67048 .91575 L
.67022 .91591 L
.66989 .91611 L
.66951 .91629 L
.66906 .91643 L
.66858 .91654 L
.66814 .91662 L
.66783 .9167 L
.66757 .91676 L
.66737 .9168 L
.66726 .91685 L
Mistroke
.66721 .91692 L
.66727 .91695 L
.66741 .91696 L
.66757 .91702 L
.66763 .9172 L
.66757 .91749 L
.66733 .91787 L
.66696 .91828 L
.66646 .91871 L
.66589 .91916 L
.66515 .9196 L
.66457 .91991 L
.66399 .92014 L
.66341 .9203 L
.66282 .92038 L
.66231 .92038 L
.66188 .92035 L
.66148 .92024 L
.66125 .92043 L
.66102 .9202 L
.66088 .91989 L
.66072 .91957 L
.66038 .91922 L
.65997 .91895 L
.65955 .91875 L
.65908 .91855 L
.65866 .91842 L
.65832 .91828 L
.65824 .91826 L
.65835 .91827 L
.6587 .91836 L
.65924 .91852 L
.6599 .91873 L
.66057 .91892 L
.66125 .91909 L
.66193 .91921 L
.66271 .91927 L
.66352 .91925 L
.66433 .91921 L
.66508 .91916 L
.66576 .91904 L
.66634 .91881 L
.66684 .91846 L
.66729 .91804 L
.66769 .91761 L
.66807 .91722 L
.66851 .9169 L
.66909 .91669 L
.66985 .9166 L
.67071 .91659 L
Mistroke
.67163 .9166 L
.67273 .91658 L
.67398 .91648 L
.67538 .91628 L
.67688 .91597 L
.67848 .91561 L
.68014 .91516 L
.68186 .91465 L
.68359 .9141 L
.68533 .9135 L
.68709 .91284 L
.68869 .91211 L
.69041 .91128 L
.69213 .91036 L
.69393 .90936 L
.69577 .90825 L
.69764 .90703 L
.69954 .90566 L
.70148 .90414 L
.70346 .90246 L
.70546 .90068 L
.70746 .8988 L
.70946 .89686 L
.71144 .89489 L
.71342 .89293 L
.71557 .89072 L
.71726 .88903 L
.71893 .88722 L
.72039 .88566 L
.72161 .88434 L
.72259 .88334 L
.72335 .88265 L
.7239 .88224 L
.72425 .88206 L
.72443 .88202 L
.72448 .88209 L
.72441 .88222 L
.72423 .88237 L
.72397 .88249 L
.72368 .88249 L
.72336 .88238 L
.72304 .88214 L
.72275 .88179 L
.72247 .88131 L
.72222 .88069 L
.72198 .88 L
.72173 .87934 L
.72146 .87879 L
.72114 .87836 L
.72078 .87811 L
Mistroke
.72042 .87806 L
.72009 .87825 L
.71981 .87865 L
.71959 .87903 L
.71941 .87977 L
.71923 .88057 L
.71902 .88164 L
.71874 .88265 L
.71836 .88365 L
.71784 .88487 L
.71721 .88595 L
.71643 .88708 L
.7155 .88825 L
.71446 .8893 L
.71326 .89035 L
.71191 .89133 L
.71051 .89224 L
.70897 .89309 L
.70744 .89395 L
.70583 .89482 L
.70429 .89569 L
.70279 .8966 L
.70133 .89761 L
.69987 .89875 L
.69834 .89999 L
.69678 .90132 L
.69513 .90271 L
.69334 .90408 L
.69159 .90557 L
.68969 .90715 L
.68765 .90879 L
.68554 .91043 L
.68344 .91196 L
.68134 .91337 L
.6793 .91461 L
.67746 .91567 L
.67572 .91652 L
.67418 .91715 L
.67286 .91759 L
.67184 .91793 L
.67088 .91825 L
.67005 .91855 L
.66925 .91882 L
.66837 .91915 L
.66739 .91956 L
.6663 .92005 L
.66495 .92054 L
.66326 .92112 L
.6612 .92179 L
.65894 .92256 L
Mistroke
.65598 .92347 L
.65306 .92441 L
.64948 .92543 L
.64585 .92644 L
.6418 .92738 L
.63809 .92833 L
.63415 .92928 L
.63044 .93016 L
.6265 .93098 L
.62301 .93172 L
.61935 .93244 L
.61592 .93305 L
.6128 .9336 L
.60952 .93401 L
.60637 .9343 L
.60325 .93442 L
.60011 .93452 L
.59719 .93462 L
.59405 .93473 L
.59111 .93481 L
.5879 .93494 L
.58464 .93515 L
.58097 .93549 L
.57748 .93591 L
.5737 .93639 L
.56945 .93696 L
.56576 .93757 L
.56162 .93832 L
.55779 .93916 L
.55372 .94004 L
.54998 .94086 L
.54616 .94159 L
.54233 .94219 L
.53887 .94266 L
.53545 .94303 L
.53219 .9433 L
.5292 .94352 L
.52645 .94374 L
.52404 .94403 L
.52211 .94441 L
.52016 .94483 L
.51855 .94527 L
.51704 .94571 L
.51571 .94612 L
.51459 .94648 L
.51368 .94677 L
.51301 .94696 L
.51253 .94702 L
.51222 .94697 L
.51206 .94683 L
Mistroke
.512 .94659 L
.51195 .94627 L
.51185 .94583 L
.5117 .94532 L
.51149 .94478 L
.51123 .94428 L
.51094 .94389 L
.51063 .94365 L
.51033 .94359 L
.51002 .94368 L
.50971 .94388 L
.50939 .94414 L
.50909 .9444 L
.50875 .94464 L
.50843 .94483 L
.50814 .94498 L
.50784 .94512 L
.50752 .94522 L
.50722 .94527 L
.50688 .94528 L
.50645 .94524 L
.50588 .94516 L
.50517 .94503 L
.50437 .94485 L
.5034 .94462 L
.50229 .94436 L
.50111 .94407 L
.4999 .94375 L
.49874 .94342 L
.49762 .94307 L
.49655 .94269 L
.49569 .94238 L
.49489 .94206 L
.49424 .94172 L
.4938 .9414 L
.49359 .94114 L
.49363 .94099 L
.49388 .94096 L
.49428 .94099 L
.4948 .94109 L
.49533 .94123 L
.49578 .94139 L
.49609 .94154 L
.49625 .9416 L
.49628 .94164 L
.49624 .94171 L
.49613 .94181 L
.49597 .94194 L
.49578 .94209 L
.49553 .94224 L
Mistroke
.49528 .94236 L
.4951 .94247 L
.49504 .94255 L
.4951 .9426 L
.4953 .94258 L
.49564 .94254 L
.49609 .94248 L
.4965 .94246 L
.49695 .94241 L
.49735 .94221 L
.49765 .94202 L
.4978 .94171 L
.49783 .94139 L
.49781 .94111 L
.49782 .9409 L
.4978 .9408 L
.49779 .94082 L
.4978 .94096 L
.49781 .94114 L
.49776 .94136 L
.49765 .94157 L
.49755 .94177 L
.4975 .94201 L
.49749 .94227 L
.49751 .94256 L
.49756 .94288 L
.49757 .9432 L
.49751 .94343 L
.49733 .94354 L
.49709 .94354 L
.4969 .94349 L
.4968 .94342 L
.49682 .94333 L
.497 .94325 L
.49732 .94324 L
.49775 .94331 L
.49817 .94338 L
.4985 .94351 L
.49853 .94371 L
.49818 .94398 L
.49744 .94431 L
.4964 .94476 L
.49502 .9453 L
.49344 .94593 L
.49156 .94646 L
.48951 .947 L
.48741 .94755 L
.48504 .94808 L
.48234 .94847 L
.47988 .94882 L
Mistroke
.47752 .94913 L
.47529 .94943 L
.47335 .94975 L
.47179 .9501 L
.47064 .95049 L
.46972 .95082 L
.46896 .95109 L
.46829 .95127 L
.46766 .95132 L
.467 .95124 L
.46627 .95101 L
.46544 .95067 L
.46464 .95022 L
.46373 .94966 L
.46277 .94904 L
.46171 .94836 L
.46057 .94767 L
.45927 .947 L
.45783 .94633 L
.45627 .94564 L
.45474 .94507 L
.45316 .94451 L
.45168 .94405 L
.45033 .94376 L
.44914 .94362 L
.44806 .94362 L
.44703 .94366 L
.44593 .94365 L
.44477 .94357 L
.44346 .94342 L
.44185 .9432 L
.44027 .94294 L
.43843 .94262 L
.4363 .94226 L
.43394 .94176 L
.4316 .94118 L
.42907 .9405 L
.42626 .9397 L
.42289 .9389 L
.41986 .93802 L
.41636 .93701 L
.41291 .93608 L
.4092 .93511 L
.40526 .93414 L
.40175 .93316 L
.39779 .93221 L
.39402 .93116 L
.38991 .93002 L
.38574 .92877 L
.38198 .92749 L
Mistroke
.37798 .92614 L
.37405 .92472 L
.36999 .92333 L
.3664 .92193 L
.36266 .92052 L
.35895 .91916 L
.35535 .9178 L
.35181 .91645 L
.34811 .9151 L
.34452 .91378 L
.34113 .91247 L
.33751 .91118 L
.33396 .90994 L
.33016 .90875 L
.32675 .90761 L
.32316 .90653 L
.31946 .90549 L
.31611 .90451 L
.31286 .90356 L
.30948 .90261 L
.30623 .90164 L
.30289 .90066 L
.29969 .89965 L
.29639 .89855 L
.29311 .89738 L
.29022 .89613 L
.28712 .8948 L
.28418 .89351 L
.2812 .89216 L
.27837 .89081 L
.27567 .88951 L
.27293 .88821 L
.27039 .88694 L
.26783 .88567 L
.26554 .88442 L
.26334 .88323 L
.26132 .88209 L
.25954 .881 L
.25799 .87998 L
.25671 .87907 L
.25569 .8782 L
.25489 .87741 L
.25434 .87673 L
.254 .87619 L
.25383 .87574 L
.25374 .87536 L
.25367 .87504 L
.25351 .87473 L
.2532 .87442 L
.25268 .87407 L
Mistroke
.25194 .87368 L
.25088 .87305 L
.24946 .87214 L
.24763 .87094 L
.24546 .86948 L
.243 .86774 L
.24014 .86562 L
.23704 .86333 L
.23376 .86082 L
.23027 .85807 L
.2269 .85538 L
.22342 .85251 L
.22008 .8496 L
.21679 .84701 L
.21358 .84425 L
.21055 .8415 L
.20758 .83881 L
.20474 .83611 L
.20196 .8336 L
.19926 .83104 L
.19661 .82859 L
.19399 .8261 L
.19131 .82351 L
.18869 .82096 L
.18614 .81851 L
.18368 .81598 L
.18136 .8135 L
.17913 .81122 L
.17715 .80902 L
.17523 .80695 L
.17373 .80513 L
.17241 .80342 L
.1713 .80185 L
.17041 .80051 L
.16965 .79928 L
.16899 .79815 L
.1683 .7971 L
.16751 .79609 L
.16656 .79503 L
.16536 .79389 L
.16393 .79261 L
.16216 .79112 L
.16001 .78936 L
.15801 .7875 L
.15564 .78539 L
.1529 .7832 L
.15054 .78096 L
.1479 .77855 L
.1451 .77603 L
.1427 .77372 L
Mistroke
.14006 .77124 L
.13736 .76865 L
.13506 .76609 L
.13267 .76357 L
.13026 .76102 L
.12824 .75875 L
.12613 .75645 L
.12404 .75421 L
.12207 .75203 L
.12011 .7499 L
.11823 .74779 L
.11656 .74601 L
.11496 .74433 L
.1135 .7428 L
.11222 .74145 L
.11123 .74032 L
.11031 .73932 L
.10955 .73841 L
.10885 .73745 L
.10818 .73639 L
.10753 .73522 L
.1069 .73393 L
.10629 .73251 L
.10574 .73111 L
.10529 .72959 L
.10489 .72812 L
.10456 .72676 L
.10426 .7255 L
.10396 .72416 L
.10367 .72294 L
.10338 .72175 L
.1031 .72057 L
.1028 .71939 L
.10246 .71815 L
.10207 .71681 L
.10161 .71526 L
.10108 .71345 L
.10045 .71138 L
.09977 .70939 L
.09902 .70701 L
.0982 .70442 L
.09736 .7016 L
.09655 .69858 L
.09579 .69566 L
.09512 .6928 L
.09458 .68986 L
.09418 .6872 L
.09391 .68477 L
.09373 .68242 L
.0936 .68021 L
Mistroke
.09346 .67814 L
.0933 .67617 L
.0931 .67423 L
.09286 .67241 L
.09259 .67057 L
.09229 .66873 L
.09195 .66683 L
.09158 .66496 L
.09113 .66289 L
.09059 .66067 L
.08999 .65812 L
.0893 .65556 L
.08854 .65261 L
.08772 .64946 L
.08688 .64614 L
.08604 .64279 L
.08526 .63901 L
.08457 .63564 L
.08395 .63211 L
.08338 .62848 L
.08288 .62548 L
.08242 .62249 L
.08202 .6198 L
.08169 .61752 L
.08141 .61553 L
.0812 .61405 L
.08104 .61292 L
.08095 .61212 L
.08091 .6116 L
.08096 .61132 L
.08098 .61121 L
.08103 .61123 L
.08107 .61134 L
.08111 .61144 L
.08113 .61153 L
.08116 .61153 L
.08121 .61139 L
.08127 .61106 L
.08132 .61056 L
.08133 .60985 L
.08128 .6089 L
.08115 .60778 L
.08092 .60631 L
.08057 .60456 L
.08023 .60241 L
.0798 .60001 L
.07933 .59715 L
.07886 .59421 L
.07837 .59082 L
.07787 .58728 L
Mistroke
.07735 .5835 L
.07681 .57949 L
.07625 .57543 L
.07565 .57165 L
.07504 .5677 L
.07446 .56391 L
.07392 .56074 L
.07342 .55784 L
.07297 .55538 L
.07258 .55326 L
.07226 .55175 L
.07201 .55061 L
.07184 .54984 L
.07174 .54935 L
.07169 .54908 L
.07169 .54889 L
.07169 .54862 L
.07168 .54819 L
.07162 .54757 L
.07149 .54682 L
.07129 .54568 L
.071 .54419 L
.07064 .54216 L
.07023 .53975 L
.06981 .53716 L
.0694 .53413 L
.06902 .5312 L
.06871 .52753 L
.06848 .52442 L
.06832 .5211 L
.06827 .51751 L
.06832 .51388 L
.06849 .50989 L
.06876 .50632 L
.06916 .50258 L
.06961 .49892 L
.07013 .49543 L
.07072 .49222 L
.07126 .48917 L
.07183 .48661 L
.07235 .4843 L
.07281 .48236 L
.07321 .48089 L
.07355 .47976 L
.07384 .47898 L
.07409 .47852 L
.07431 .4783 L
.07448 .47824 L
Mfstroke
.07141 .48988 m
.07125 .49002 L
.07104 .4904 L
.07078 .49109 L
.07048 .49217 L
.07015 .4937 L
.06979 .49559 L
.0694 .49783 L
.069 .50063 L
.06859 .50399 L
.0682 .50691 L
.06786 .51079 L
.0676 .51445 L
.06745 .51853 L
.0674 .52261 L
.06747 .52668 L
.06763 .53038 L
.06788 .53422 L
.06822 .53791 L
.06861 .54124 L
.06909 .54445 L
.06964 .54758 L
.07026 .55068 L
.07091 .55354 L
.07159 .55665 L
.0723 .55952 L
.07296 .56271 L
.07362 .56582 L
.07426 .56941 L
.07488 .5728 L
.07545 .57606 L
.076 .58007 L
.07651 .58368 L
.07697 .58816 L
.0774 .59178 L
.07783 .59621 L
.07826 .60054 L
.0787 .60455 L
.07915 .60881 L
.07966 .61309 L
.08024 .61741 L
.08089 .62176 L
.0816 .62605 L
.08226 .63033 L
.08301 .63471 L
.08373 .63936 L
.08447 .64349 L
.08519 .64823 L
.08587 .65207 L
.08652 .65657 L
Mistroke
.08715 .66042 L
.08769 .6643 L
.08818 .66762 L
.0886 .67067 L
.08895 .67363 L
.08925 .67619 L
.08952 .67852 L
.08977 .68058 L
.09003 .68221 L
.0903 .68365 L
.09059 .68487 L
.0909 .68588 L
.09122 .68673 L
.09153 .68735 L
.09183 .68795 L
.09209 .68843 L
.0923 .68877 L
.09249 .68894 L
.09267 .68894 L
.09284 .68881 L
.09299 .68863 L
.0931 .68844 L
.09317 .68828 L
.09319 .6882 L
.09317 .68826 L
.09312 .68852 L
.09306 .68898 L
.093 .68966 L
.09298 .69053 L
.09302 .69162 L
.09312 .69292 L
.0933 .69448 L
.09359 .69639 L
.09402 .6987 L
.09455 .70132 L
.09519 .70403 L
.09592 .70707 L
.09674 .71025 L
.09757 .71336 L
.09842 .71662 L
.09925 .71938 L
.1 .72209 L
.10072 .72472 L
.10131 .72676 L
.10187 .72862 L
.10225 .73022 L
.10258 .73147 L
.1028 .73233 L
.10292 .73282 L
.10295 .73304 L
Mistroke
.10291 .73304 L
.10286 .7329 L
.1028 .73269 L
.10275 .73253 L
.10272 .73247 L
.10272 .73253 L
.10275 .73275 L
.10277 .73299 L
.10277 .73321 L
.10272 .73338 L
.10263 .73345 L
.10253 .73344 L
.10241 .73338 L
.10229 .73331 L
.10218 .73327 L
.1021 .73327 L
.10204 .73334 L
.102 .73346 L
.10199 .73362 L
.10199 .73381 L
.102 .73405 L
.10205 .73432 L
.10213 .7346 L
.10223 .73494 L
.10234 .73531 L
.10247 .73569 L
.10258 .73609 L
.10266 .73643 L
.10272 .73665 L
.10273 .73675 L
.10271 .73676 L
.10267 .73672 L
.10264 .73664 L
.10263 .73653 L
.10263 .73638 L
.10264 .73621 L
.10264 .73603 L
.10264 .73582 L
.10265 .73561 L
.10265 .73542 L
.10265 .73528 L
.10265 .73517 L
.10266 .73512 L
.10266 .73511 L
.10265 .73513 L
.10265 .7352 L
.10265 .7353 L
.10265 .73548 L
.10264 .7357 L
.10264 .73594 L
Mistroke
.10263 .73619 L
.10263 .73642 L
.10262 .73662 L
.1026 .73677 L
.10256 .73686 L
.10249 .73683 L
.10237 .73667 L
.10224 .73643 L
.10213 .73618 L
.10207 .73598 L
.10208 .73588 L
.10222 .73593 L
.10255 .7362 L
.10309 .73675 L
.10387 .73759 L
.10491 .73876 L
.1061 .74024 L
.10765 .74203 L
.10928 .74385 L
.11123 .74609 L
.11329 .74846 L
.11555 .75105 L
.1181 .75371 L
.12056 .75649 L
.12299 .75903 L
.12546 .76165 L
.1279 .76421 L
.13033 .76661 L
.13281 .76909 L
.13527 .77144 L
.13794 .77393 L
.1405 .7764 L
.14329 .77906 L
.14612 .78162 L
.14897 .78444 L
.15184 .78711 L
.15482 .79001 L
.15782 .79287 L
.16092 .79589 L
.16378 .79874 L
.16678 .80181 L
.16984 .8047 L
.17281 .80769 L
.17586 .81062 L
.17901 .81375 L
.18199 .81661 L
.1853 .81977 L
.18853 .82313 L
.19195 .8263 L
.19552 .82975 L
Mistroke
.19943 .8335 L
.20307 .83681 L
.20682 .84036 L
.21074 .84412 L
.21449 .84752 L
.21837 .85102 L
.22202 .85493 L
.22571 .8581 L
.22917 .86142 L
.23245 .86472 L
.23554 .86769 L
.23847 .87057 L
.241 .8729 L
.24336 .87502 L
.24531 .87668 L
.24703 .87803 L
.24845 .87909 L
.2496 .87985 L
.25049 .88034 L
.25114 .88057 L
.25156 .88057 L
.25181 .88037 L
.25193 .88003 L
.25193 .8796 L
.25186 .87917 L
.25176 .8788 L
.25167 .87853 L
.25158 .87835 L
.2515 .87825 L
.25145 .87821 L
.25143 .87825 L
.25142 .87832 L
.25142 .87837 L
.2514 .87838 L
.25135 .87837 L
.2513 .87835 L
.25124 .87832 L
.2512 .8783 L
.25117 .87827 L
.25118 .87827 L
.25127 .87831 L
.25146 .8784 L
.25175 .87856 L
.25215 .8788 L
.25268 .87911 L
.25333 .87948 L
.25403 .87987 L
.25474 .88027 L
.25547 .88067 L
.25617 .88104 L
Mistroke
.25686 .8814 L
.25747 .88173 L
.25801 .88202 L
.25846 .88225 L
.25881 .88242 L
.25906 .88254 L
.25922 .88261 L
.2593 .88263 L
.25929 .88262 L
.25925 .88259 L
.25919 .88256 L
.25914 .88255 L
.25912 .88257 L
.25913 .88261 L
.25914 .88266 L
.25915 .8827 L
.25914 .88274 L
.25911 .8828 L
.25908 .88286 L
.25904 .88292 L
.25903 .88296 L
.25904 .88294 L
.25908 .88284 L
.25913 .88266 L
.2592 .88241 L
.25927 .88208 L
.25935 .88168 L
.25942 .88123 L
.25949 .88075 L
.25953 .88025 L
.25957 .87978 L
.2596 .87929 L
.25966 .87876 L
.25974 .87836 L
.25984 .878 L
.25993 .87774 L
.25997 .8776 L
.25995 .87757 L
.25987 .87764 L
.25966 .87779 L
.25953 .87796 L
.25937 .87817 L
.25921 .87843 L
.25906 .87875 L
.25896 .87917 L
.2589 .87967 L
.25895 .88027 L
.25916 .88096 L
.25952 .88173 L
.26017 .88265 L
Mistroke
.26111 .88369 L
.26243 .88487 L
.26419 .88618 L
.26647 .88765 L
.26912 .88924 L
.27223 .89095 L
.27572 .89269 L
.27961 .89449 L
.28376 .89629 L
.2881 .89809 L
.29294 .89989 L
.29777 .90172 L
.30286 .90352 L
.30825 .90534 L
.31339 .90713 L
.31875 .90894 L
.32402 .91073 L
.32933 .91249 L
.33439 .91428 L
.33904 .91606 L
.34355 .9178 L
.34753 .91945 L
.35119 .92099 L
.35482 .9223 L
.3578 .9235 L
.36042 .92448 L
.3629 .92532 L
.36524 .92604 L
.36746 .92667 L
.36957 .92722 L
.37146 .9277 L
.37346 .92818 L
.3756 .92866 L
.37782 .92915 L
.38008 .92967 L
.38238 .93023 L
.38469 .93086 L
.38691 .93153 L
.38884 .93222 L
.39051 .93282 L
.3919 .93339 L
.39301 .93389 L
.3939 .93429 L
.39451 .93458 L
.39491 .93476 L
.3951 .93479 L
.39511 .93471 L
.39504 .9346 L
.39492 .93445 L
.39477 .93423 L
Mistroke
.3947 .93399 L
.39476 .93375 L
.39495 .93352 L
.39521 .93327 L
.39556 .93298 L
.39597 .93267 L
.39638 .93232 L
.39678 .93198 L
.39715 .93163 L
.39751 .93129 L
.39782 .93094 L
.39803 .93063 L
.39814 .93036 L
.39813 .93023 L
.39795 .93001 L
.3976 .9298 L
.39712 .9296 L
.39664 .9295 L
.39614 .92951 L
.39566 .92963 L
.39522 .92983 L
.39487 .93013 L
.39455 .93039 L
.39427 .93067 L
.39403 .93091 L
.39382 .93109 L
.39358 .93118 L
.39331 .93124 L
.39306 .93132 L
.39289 .93143 L
.3928 .93154 L
.39282 .93166 L
.39305 .93183 L
.39353 .93213 L
.39433 .93258 L
.3955 .93321 L
.39708 .93401 L
.39918 .93499 L
.40186 .93613 L
.40469 .93741 L
.40827 .93882 L
.41221 .94033 L
.4167 .94181 L
.42162 .9434 L
.42624 .94488 L
.43109 .94632 L
.43619 .94768 L
.44068 .94889 L
.44519 .94996 L
.44911 .95089 L
Mistroke
.45276 .95165 L
.4562 .95227 L
.45876 .95274 L
.46102 .9531 L
.46297 .95337 L
.46459 .95356 L
.46591 .95368 L
.46707 .95371 L
.46797 .95365 L
.46876 .95351 L
.46954 .95335 L
.4703 .95317 L
.47102 .95301 L
.47171 .95287 L
.47238 .95273 L
.47306 .95259 L
.4737 .95244 L
.47431 .9523 L
.47491 .9522 L
.47555 .95214 L
.47623 .95213 L
.47704 .9521 L
.47801 .95204 L
.47923 .95195 L
.48065 .95176 L
.48216 .95143 L
.48399 .95096 L
.48607 .95037 L
.48836 .9497 L
.49075 .94898 L
.49311 .94825 L
.49536 .94751 L
.49745 .94687 L
.49921 .94628 L
.50064 .94574 L
.50167 .94523 L
.50241 .94479 L
.50284 .94441 L
.50307 .94419 L
.50325 .94407 L
.50345 .94404 L
.50371 .94409 L
.50414 .94421 L
.5048 .94442 L
.50582 .94472 L
.50712 .94504 L
.50889 .94543 L
.51084 .94582 L
.51322 .94621 L
.51621 .94668 L
Mistroke
.51915 .94705 L
.52243 .94734 L
.52588 .94748 L
.52941 .94747 L
.53313 .94734 L
.53676 .9471 L
.54057 .94668 L
.54439 .9461 L
.54832 .94539 L
.5524 .94459 L
.55669 .94373 L
.56105 .94287 L
.56552 .94206 L
.57004 .94136 L
.57449 .94076 L
.57883 .94024 L
.58311 .93978 L
.58732 .93938 L
.59149 .93901 L
.59543 .93863 L
.59943 .93826 L
.60314 .93788 L
.60679 .93747 L
.61047 .937 L
.61406 .93645 L
.61761 .93579 L
.6212 .935 L
.6246 .93407 L
.62791 .93306 L
.63109 .93198 L
.63408 .93088 L
.63696 .92977 L
.63958 .92874 L
.64193 .92782 L
.64393 .92705 L
.64555 .92642 L
.64674 .92597 L
.64761 .92571 L
.64821 .92563 L
.64856 .92569 L
.64884 .92575 L
.64911 .92585 L
.64939 .92593 L
.64974 .92593 L
.65014 .92584 L
.65051 .92574 L
.65101 .9255 L
.65145 .92518 L
.65202 .92465 L
.65265 .924 L
Mistroke
.65331 .92325 L
.654 .92245 L
.65468 .92164 L
.65538 .92084 L
.65606 .92006 L
.65664 .91935 L
.65709 .91869 L
.65733 .91826 L
.65755 .91788 L
.65774 .91763 L
.658 .91745 L
.65826 .91745 L
.65861 .91755 L
.65899 .91778 L
.65941 .91808 L
.65987 .9184 L
.66034 .91872 L
.66082 .91901 L
.66138 .91927 L
.66206 .91957 L
.6629 .91983 L
.66385 .92002 L
.66486 .92011 L
.66586 .92014 L
.66685 .92012 L
.66778 .92003 L
.66864 .91992 L
.66937 .91981 L
.67 .91976 L
.67046 .91977 L
.67091 .91984 L
.67133 .91995 L
.6717 .92007 L
.67197 .92015 L
.67217 .92021 L
.67231 .92022 L
.67241 .9202 L
.67247 .92018 L
.6725 .92019 L
.67252 .92021 L
.67253 .92023 L
.67247 .92024 L
.67244 .92023 L
.67245 .9202 L
.67241 .92016 L
.6724 .92012 L
.67248 .9201 L
.67269 .92011 L
.67295 .92013 L
.67328 .92014 L
Mistroke
.67366 .92013 L
.67414 .92007 L
.67467 .91993 L
.67527 .91973 L
.67593 .91947 L
.6767 .91914 L
.67757 .91876 L
.67854 .9183 L
.67961 .91776 L
.68079 .91712 L
.68205 .91637 L
.68339 .9155 L
.68494 .9145 L
.68666 .91338 L
.68859 .91214 L
.69072 .91079 L
.69309 .90938 L
.69558 .90784 L
.69824 .90626 L
.70102 .90463 L
.70364 .90297 L
.70632 .90128 L
.70905 .89953 L
.71186 .89776 L
.71459 .89605 L
.71726 .89435 L
.71992 .89267 L
.72256 .89096 L
.7251 .88933 L
.72746 .88775 L
.72932 .88647 L
.73122 .88515 L
.73297 .884 L
.73451 .88294 L
.73591 .88198 L
.73712 .88114 L
.73813 .8804 L
.73897 .87976 L
.73966 .87921 L
.74023 .8787 L
.74073 .87823 L
.74122 .87774 L
.74177 .87718 L
.74238 .87654 L
.74303 .87579 L
.74371 .87499 L
.7444 .87416 L
.74505 .87333 L
.74563 .87255 L
.74615 .87184 L
Mistroke
.74655 .87123 L
.74683 .87072 L
.74696 .87032 L
.74697 .87003 L
.74687 .86984 L
.7467 .86973 L
.74649 .8697 L
.74633 .86973 L
.74622 .86981 L
.7462 .86992 L
.74634 .87002 L
.74669 .87007 L
.74724 .87004 L
.74796 .86994 L
.74892 .86974 L
.75009 .86943 L
.75147 .86895 L
.75304 .8683 L
.75481 .86748 L
.75672 .86651 L
.75878 .86541 L
.76091 .8642 L
.76314 .86288 L
.76545 .86145 L
.76785 .85988 L
.77021 .85822 L
.77261 .85646 L
.77503 .85467 L
.77745 .85284 L
.77973 .85104 L
.78192 .84931 L
.78391 .84778 L
.78563 .84637 L
.78705 .84516 L
.78815 .84414 L
.78896 .84334 L
.78949 .84274 L
.7898 .84232 L
.78995 .84203 L
.79003 .84183 L
.79001 .84167 L
.78993 .84148 L
.7899 .84114 L
.78996 .84062 L
.79011 .83985 L
.79042 .83882 L
.79088 .83754 L
.7915 .83613 L
.7922 .83458 L
.7929 .83301 L
Mistroke
.7935 .83154 L
.79394 .83027 L
.79419 .82935 L
.79426 .8288 L
.7942 .82867 L
.7941 .82892 L
.79401 .82942 L
.79407 .83005 L
.79436 .83076 L
.79484 .83125 L
.79558 .83176 L
.79657 .83211 L
.79779 .83224 L
.79933 .83211 L
.80117 .83167 L
.80328 .8308 L
.80571 .82952 L
.80829 .82795 L
.81103 .82604 L
.81381 .82392 L
.81662 .82156 L
.81948 .81914 L
.82226 .81676 L
.82515 .81429 L
.82802 .81184 L
.83096 .80941 L
.83384 .80708 L
.83663 .80477 L
.83932 .80261 L
.84185 .80059 L
.84424 .79875 L
.8465 .79702 L
.84849 .79545 L
.85041 .79395 L
.85224 .7924 L
.85416 .79073 L
.85591 .7889 L
.85731 .78716 L
.85884 .78514 L
.86016 .78314 L
.86162 .78087 L
.86277 .77882 L
.86402 .77663 L
.86526 .77436 L
.86644 .77204 L
.86752 .76967 L
.86846 .76732 L
.86926 .76498 L
.86994 .76244 L
.87038 .76029 L
Mistroke
.87077 .75804 L
.87109 .75611 L
.87137 .75425 L
.87155 .75257 L
.87167 .75115 L
.87174 .74995 L
.87175 .74895 L
.87174 .74815 L
.87173 .7475 L
.87173 .747 L
.87176 .74672 L
.87188 .74659 L
.87213 .74647 L
.87254 .74621 L
.87309 .74564 L
.8738 .74472 L
.87466 .74342 L
.87566 .74173 L
.87681 .73967 L
.87806 .73729 L
.87939 .73458 L
.88075 .73172 L
.88211 .72859 L
.88344 .72536 L
.88474 .72192 L
.88598 .71844 L
.88715 .71488 L
.88822 .71132 L
.88919 .70785 L
.89007 .70462 L
.89083 .70156 L
.89147 .69889 L
.89195 .69653 L
.89231 .69451 L
.89258 .69281 L
.89279 .69141 L
.89297 .69026 L
.89316 .68938 L
.89338 .68866 L
.89361 .6881 L
.89389 .68755 L
.89425 .68695 L
.89471 .68615 L
.89521 .68534 L
.89579 .68422 L
.89653 .68271 L
.89712 .68118 L
.89769 .67948 L
.89821 .67755 L
.89864 .67544 L
Mistroke
.89898 .67321 L
.89921 .67097 L
.89931 .6689 L
.8993 .66698 L
.8992 .66534 L
.89902 .66404 L
.89884 .66309 L
.89871 .6624 L
.89865 .66197 L
.89864 .66182 L
.89868 .66187 L
.89875 .66206 L
.89879 .66241 L
.89879 .66292 L
.89871 .66359 L
.89852 .66437 L
.89821 .6652 L
.89779 .66595 L
.89725 .66653 L
.89665 .66694 L
.89594 .66718 L
.89506 .66736 L
.89403 .66749 L
.89287 .66762 L
.89153 .66778 L
.89011 .66791 L
.88868 .66791 L
.88726 .66777 L
.88593 .66751 L
.88482 .66717 L
.88381 .6668 L
.88286 .66647 L
.88199 .66619 L
.88127 .66598 L
.8808 .66577 L
.88045 .66561 L
.88024 .66551 L
.88019 .66551 L
.88027 .66566 L
.88044 .666 L
.88064 .66664 L
.88084 .66766 L
.881 .66909 L
.88113 .67094 L
.88125 .67323 L
.88132 .67575 L
.88131 .67866 L
.88126 .6817 L
.88121 .68501 L
.88118 .68801 L
Mistroke
.88115 .69099 L
.88114 .69386 L
.88113 .69642 L
.88111 .69858 L
.8811 .70045 L
.88108 .70196 L
.88107 .7031 L
.88105 .70392 L
.88103 .7045 L
.88101 .70486 L
.88099 .70506 L
.88098 .70515 L
.88097 .70517 L
.88099 .70513 L
.88103 .70508 L
.88108 .70506 L
.88112 .70509 L
.88114 .70518 L
.88112 .70532 L
.88107 .70549 L
.88098 .70568 L
.88087 .70589 L
.88072 .70616 L
.88055 .70656 L
.88038 .70709 L
.88021 .70776 L
.88007 .70857 L
.87997 .70955 L
.87991 .71075 L
.87991 .71214 L
.88 .7137 L
.88016 .71541 L
.88037 .71715 L
.88061 .71905 L
.88082 .72112 L
.88098 .72335 L
.88104 .72578 L
.88098 .72834 L
.88077 .73084 L
.88043 .73337 L
.87998 .73583 L
.87947 .73807 L
.87896 .73989 L
.87844 .74148 L
.87794 .74284 L
.8775 .74385 L
.87714 .74463 L
.87689 .74525 L
.87676 .74554 L
.87674 .74559 L
Mistroke
.87686 .74543 L
.8771 .74507 L
.87742 .74459 L
.87776 .74408 L
.87806 .74366 L
.87829 .74341 L
.87837 .74343 L
.87828 .74371 L
.87801 .74425 L
.87754 .74503 L
.87688 .74606 L
.87604 .74734 L
.87505 .74887 L
.87401 .75047 L
.87288 .75211 L
.87172 .75369 L
.87054 .75519 L
.86939 .75664 L
.86836 .75786 L
.86747 .75892 L
.86677 .7597 L
.86628 .76018 L
.866 .76039 L
.86594 .76033 L
.86605 .76003 L
.86629 .7596 L
.86661 .75909 L
.86691 .75872 L
.86721 .75843 L
.86747 .75831 L
.86764 .75846 L
.86772 .75882 L
.86776 .75936 L
.86774 .76002 L
.86767 .76083 L
.86757 .76173 L
.86746 .76269 L
.86733 .76375 L
.86718 .76482 L
.86701 .76599 L
.86689 .76712 L
.86683 .76811 L
.8668 .76892 L
.86676 .7696 L
.86669 .77018 L
.86656 .77066 L
.8664 .77105 L
.86622 .77129 L
.86607 .77136 L
.86594 .77126 L
Mistroke
.86589 .77102 L
.86585 .77069 L
.86584 .77032 L
.86586 .76988 L
.86592 .76948 L
.86599 .76916 L
.86609 .76882 L
.86622 .76848 L
.86634 .7681 L
.86644 .76772 L
.86651 .7674 L
.86655 .76715 L
.86655 .76703 L
.86651 .76706 L
.86635 .76729 L
.86609 .76777 L
.86572 .7685 L
.86526 .76942 L
.86472 .77056 L
.86408 .77192 L
.86333 .77339 L
.86243 .77513 L
.8614 .77704 L
.86027 .77907 L
.85908 .78113 L
.85799 .78303 L
.85693 .78477 L
.85597 .7863 L
.85512 .78755 L
.85444 .78846 L
.85391 .78907 L
.8535 .78948 L
.85322 .78972 L
.85306 .78985 L
.85302 .78988 L
.85303 .78985 L
.85303 .78983 L
.85299 .78983 L
.85296 .78984 L
.85297 .78982 L
.85296 .78979 L
.8529 .7898 L
.85276 .78987 L
.85257 .78997 L
.8524 .79006 L
.85223 .79013 L
.85208 .79018 L
.85195 .79014 L
.8518 .79011 L
.8515 .79011 L
Mistroke
.85105 .79016 L
.85047 .79017 L
.84977 .79031 L
.84892 .79048 L
.8479 .79059 L
.84685 .79061 L
.84583 .79055 L
.84492 .79046 L
.844 .79036 L
.84313 .79026 L
.84251 .79015 L
.84208 .79005 L
.84173 .78997 L
.84151 .78994 L
.84149 .78995 L
.84159 .79002 L
.84192 .79003 L
.8424 .78999 L
.84301 .78987 L
.84366 .78974 L
.84437 .78956 L
.84509 .78932 L
.84591 .78892 L
.84668 .7885 L
.8475 .78794 L
.84821 .78738 L
.8489 .78681 L
.84949 .78626 L
.85 .78574 L
.85046 .78526 L
.85084 .78485 L
.85119 .7845 L
.85151 .78419 L
.85182 .78387 L
.85209 .78358 L
.85224 .7834 L
.85228 .78337 L
.85228 .78339 L
.85232 .78343 L
.85238 .78347 L
.85244 .78353 L
.85248 .78363 L
.85249 .78375 L
.8525 .78387 L
.85249 .784 L
.85245 .7841 L
.85238 .78424 L
.85228 .78439 L
.85219 .78451 L
.85218 .78449 L
Mistroke
.85228 .78436 L
.85249 .78413 L
.85268 .78391 L
.85294 .78363 L
.85318 .78337 L
.85339 .78316 L
.85353 .78301 L
.8536 .78295 L
.8536 .78299 L
.85357 .78308 L
.85354 .78314 L
.85352 .78318 L
.85348 .78321 L
.85343 .78325 L
.85338 .78327 L
.85335 .78327 L
.85334 .78323 L
.85334 .78318 L
.85335 .7831 L
.85336 .78301 L
.85339 .78292 L
.85343 .78284 L
.85347 .78277 L
.85352 .78274 L
.85356 .78273 L
.8536 .78274 L
.85362 .78274 L
.85363 .78275 L
.85362 .78275 L
.8536 .78276 L
.85359 .78277 L
.85358 .78276 L
.85358 .78274 L
.85359 .78271 L
.85361 .78264 L
.85368 .78255 L
.85376 .78246 L
.85381 .78244 L
.85382 .7825 L
.8538 .78263 L
.8537 .78289 L
.85349 .78331 L
.85317 .78387 L
.85274 .78451 L
.85225 .78518 L
.85175 .7858 L
.85128 .78638 L
.85083 .78687 L
.85048 .78723 L
.85018 .78748 L
Mistroke
.84993 .78764 L
.84979 .78762 L
.84976 .78746 L
.84985 .78718 L
.85015 .78665 L
.85062 .78596 L
.85129 .78511 L
.85212 .78423 L
.85312 .78328 L
.85427 .78226 L
.85557 .78114 L
.857 .77985 L
.85859 .7783 L
.8603 .77648 L
.86208 .7744 L
.86386 .77219 L
.8657 .76968 L
.86746 .76704 L
.86907 .7647 L
.87049 .7623 L
.87167 .7602 L
.87269 .75818 L
.87349 .75646 L
.87409 .75505 L
.87452 .75391 L
.87482 .75307 L
.87503 .75253 L
.87517 .75227 L
.87528 .7522 L
.87537 .75227 L
.87547 .7524 L
.8756 .75254 L
.87575 .75267 L
.8759 .75276 L
.87604 .7528 L
.87616 .75281 L
.87624 .7528 L
.87629 .7528 L
.8763 .75283 L
.87629 .75288 L
.87626 .75295 L
.87623 .75302 L
.87621 .75308 L
.8762 .75311 L
.87619 .75308 L
.87618 .75297 L
.87615 .75277 L
.87612 .75245 L
.87608 .75202 L
.87606 .75146 L
Mistroke
.87606 .75077 L
.87608 .75 L
.87615 .74914 L
.87624 .7482 L
.87637 .74723 L
.87652 .74627 L
.8767 .74536 L
.87688 .74451 L
.87706 .74377 L
.87725 .74316 L
.87744 .74267 L
.87761 .74231 L
.87776 .74205 L
.87788 .7419 L
.87796 .74181 L
.87803 .74177 L
.87808 .74178 L
.87814 .74182 L
.87817 .74186 L
.87817 .7419 L
.87812 .74194 L
.87801 .74198 L
.87785 .74202 L
.8776 .74205 L
.87729 .74208 L
.87693 .74212 L
.87654 .74215 L
.87614 .74219 L
.87573 .74223 L
.87532 .74227 L
.87494 .74231 L
.87456 .74234 L
.87422 .74237 L
.87397 .74239 L
.87382 .7424 L
.8738 .74243 L
.87388 .74249 L
.87405 .74258 L
.8743 .74267 L
.87461 .74273 L
.87496 .7427 L
.87532 .74255 L
.87572 .74225 L
.87617 .7418 L
.87664 .74119 L
.87712 .74045 L
.87759 .73961 L
.87801 .73872 L
.87839 .73788 L
.87871 .73694 L
Mistroke
.87898 .73608 L
.87923 .73527 L
.87944 .73456 L
.87962 .73401 L
.87978 .73365 L
.87992 .73347 L
.88006 .73345 L
.88021 .73349 L
.88037 .73352 L
.88057 .73345 L
.88082 .73317 L
.88115 .73258 L
.88155 .73164 L
.88204 .73034 L
.8826 .72878 L
.88321 .72698 L
.88389 .72485 L
.88461 .72259 L
.88537 .72014 L
.88614 .71777 L
.88688 .71543 L
.88765 .7132 L
.8883 .71112 L
.88893 .70941 L
.88946 .7079 L
.88989 .7066 L
.89021 .70555 L
.89044 .70468 L
.89058 .70393 L
.89065 .70322 L
.89065 .70246 L
.89062 .70164 L
.89055 .70067 L
.89048 .69952 L
.89041 .69813 L
.89035 .69663 L
.89029 .69498 L
.89024 .69336 L
.89021 .69183 L
.89018 .69054 L
.89015 .68938 L
.89013 .68853 L
.89012 .68789 L
.89012 .68749 L
.89014 .68729 L
.8902 .6873 L
.8903 .68751 L
.89039 .68787 L
.89044 .68834 L
.89045 .68886 L
Mistroke
.89039 .68939 L
.89024 .68986 L
.88997 .69018 L
.88958 .69034 L
.88907 .69038 L
.88846 .69035 L
.88779 .69033 L
.88707 .69034 L
.88632 .69043 L
.8855 .69062 L
.88462 .6909 L
.88369 .69124 L
.88274 .69162 L
.88182 .69202 L
.88091 .69243 L
.87998 .69285 L
.87907 .69331 L
.87815 .69384 L
.87727 .69443 L
.87634 .69505 L
.87532 .69572 L
.87419 .6964 L
.87302 .69711 L
.87183 .69784 L
.8706 .69863 L
.86934 .6995 L
.86822 .70044 L
.86712 .70144 L
.8661 .7025 L
.86516 .70355 L
.86437 .70454 L
.86363 .7054 L
.86294 .70613 L
.86231 .70671 L
.86176 .70714 L
.86127 .70745 L
.86083 .70767 L
.86039 .70783 L
.85988 .70794 L
.85927 .70804 L
.85853 .70813 L
.85761 .70823 L
.85666 .70836 L
.85549 .70853 L
.85423 .70877 L
.85307 .70904 L
.85189 .70934 L
.85074 .70965 L
.84968 .70995 L
.84877 .71022 L
Mistroke
.84796 .71041 L
.84728 .7105 L
.84675 .71052 L
.84643 .71045 L
.84633 .71032 L
.84644 .71016 L
.84667 .71005 L
.84697 .71004 L
.84725 .71022 L
.84746 .71061 L
.84758 .7112 L
.84756 .71209 L
.8474 .71326 L
.84714 .71463 L
.84679 .71628 L
.84634 .71816 L
.84585 .72007 L
.84524 .72221 L
.8446 .72423 L
.84391 .72624 L
.84322 .72813 L
.84259 .7298 L
.84207 .73125 L
.8417 .73247 L
.84147 .7334 L
.84136 .73414 L
.84137 .73471 L
.84146 .73514 L
.84159 .73546 L
.84175 .73571 L
.84192 .73591 L
.84212 .73606 L
.84234 .73617 L
.84257 .73626 L
.84279 .73636 L
.84297 .73646 L
.84311 .73656 L
.84321 .73665 L
.84326 .7367 L
.84327 .73671 L
.84326 .73669 L
.84326 .7366 L
.84327 .73646 L
.84331 .73628 L
.84337 .73611 L
.84344 .73597 L
.84347 .73592 L
.84345 .73601 L
.84334 .73624 L
.84315 .73668 L
Mistroke
.84284 .73736 L
.8424 .73829 L
.84184 .73948 L
.84115 .74095 L
.84038 .74262 L
.83951 .74454 L
.83855 .74674 L
.83754 .74918 L
.83652 .7516 L
.83549 .75414 L
.83448 .75667 L
.83354 .75893 L
.83271 .76091 L
.832 .76271 L
.83142 .76428 L
.83099 .76556 L
.83071 .76648 L
.83057 .76719 L
.83057 .76772 L
.83067 .76808 L
.83081 .76831 L
.83093 .76846 L
.83104 .76856 L
.83112 .76864 L
.83114 .7687 L
.83109 .76873 L
.83098 .76876 L
.83081 .76886 L
.83054 .76909 L
.8301 .76944 L
.82956 .76993 L
.8289 .77056 L
.82818 .77133 L
.82738 .77228 L
.82656 .77341 L
.82573 .77475 L
.82488 .7762 L
.82418 .77791 L
.82343 .77991 L
.82266 .78215 L
.82182 .78464 L
.82096 .78723 L
.82006 .78989 L
.8191 .79222 L
.81829 .79469 L
.81754 .79657 L
.81694 .79844 L
.81642 .80007 L
.81597 .80143 L
.81561 .80256 L
Mistroke
.8153 .80342 L
.81508 .80402 L
.81497 .80436 L
.81498 .80449 L
.81509 .80445 L
.81524 .80431 L
.81541 .80416 L
.81555 .80405 L
.81564 .80396 L
.81567 .80388 L
.81565 .80384 L
.81559 .80385 L
.81548 .80386 L
.81532 .80388 L
.81517 .80389 L
.81506 .8039 L
.81497 .8039 L
.81489 .80391 L
.81483 .80391 L
.81476 .80392 L
.81469 .80392 L
.81462 .80393 L
.81456 .80393 L
.81454 .80393 L
.81454 .80392 L
.81452 .80391 L
.81448 .80389 L
.81444 .80387 L
.81435 .80386 L
.81425 .80386 L
.81415 .80385 L
.81405 .80385 L
.81397 .80384 L
.8139 .80381 L
.81384 .80381 L
.8138 .80389 L
.81371 .8041 L
.81362 .8045 L
.81347 .80515 L
.8133 .80596 L
.81308 .80699 L
.81285 .80832 L
.81262 .80939 L
.81239 .81091 L
.81214 .81238 L
.81188 .81363 L
.81159 .81524 L
.81126 .81671 L
.81091 .81816 L
.81055 .81952 L
Mistroke
.81021 .82071 L
.80989 .82169 L
.8096 .82243 L
.80937 .82299 L
.80916 .8234 L
.80899 .8237 L
.80887 .82391 L
.80878 .82407 L
.80874 .82418 L
.80875 .82424 L
.80881 .82424 L
.80889 .8242 L
.80898 .82412 L
.80905 .82404 L
.80908 .82398 L
.80906 .82396 L
.80898 .82396 L
.80888 .82397 L
.80874 .82399 L
.80857 .824 L
.80837 .82402 L
.80814 .82404 L
.80792 .82406 L
.8077 .82409 L
.80749 .82411 L
.80735 .82412 L
.80724 .82413 L
.80721 .82413 L
.80724 .82413 L
.80736 .82412 L
.80752 .8241 L
.80773 .82408 L
.80796 .82406 L
.80818 .82404 L
.80838 .82402 L
.80855 .82401 L
.80871 .82399 L
.80886 .82397 L
.80898 .82396 L
.80907 .82395 L
.80913 .82394 L
.80917 .82393 L
.80919 .8239 L
.80918 .82384 L
.80915 .82377 L
.80909 .8237 L
.80898 .82368 L
.80878 .82372 L
.80846 .82382 L
.80798 .82401 L
Mistroke
.80728 .82431 L
.80647 .82474 L
.80541 .82532 L
.80412 .82605 L
.80272 .82692 L
.80112 .82791 L
.79932 .82896 L
.79746 .83013 L
.79551 .83129 L
.79362 .83249 L
.79172 .83365 L
.78992 .8347 L
.78836 .83562 L
.78693 .83641 L
.7857 .83707 L
.78471 .83758 L
.784 .83796 L
.78345 .8382 L
.78309 .83829 L
.7829 .83825 L
.78282 .83812 L
.78279 .83798 L
.78274 .83791 L
.78267 .83794 L
.78252 .8381 L
.7823 .83836 L
.78199 .83873 L
.78163 .8392 L
.78115 .83977 L
.7806 .84043 L
.77998 .84114 L
.77932 .84193 L
.77867 .84276 L
.77799 .84366 L
.77723 .84462 L
.77643 .84564 L
.77557 .8467 L
.77459 .84777 L
.77362 .84893 L
.77249 .85018 L
.77119 .85157 L
.7697 .8531 L
.76818 .85466 L
.76647 .85634 L
.76459 .85805 L
.76277 .85969 L
.76105 .86118 L
.75941 .86252 L
.75786 .86372 L
.75649 .86475 L
Mistroke
.75514 .86567 L
.75393 .86651 L
.75276 .86726 L
.75167 .86793 L
.75064 .86856 L
.74961 .86912 L
.74863 .86974 L
.74758 .87041 L
.74646 .87114 L
.74527 .87194 L
.74408 .87277 L
.7428 .87368 L
.74143 .87464 L
.74004 .87561 L
.73868 .87656 L
.73734 .87745 L
.73614 .87821 L
.73504 .87885 L
.73402 .8794 L
.73304 .87995 L
.73211 .8805 L
.73119 .88109 L
.73031 .8817 L
.72936 .88237 L
.72831 .88317 L
.72711 .88412 L
.72573 .88525 L
.72414 .8866 L
.72231 .88817 L
.72057 .88975 L
.71854 .89142 L
.71632 .89329 L
.71417 .89533 L
.71165 .89742 L
.70943 .89927 L
.70716 .90113 L
.7049 .9029 L
.70285 .90441 L
.70094 .9058 L
.69931 .907 L
.69786 .90803 L
.69654 .90895 L
.69531 .90979 L
.69423 .91056 L
.69313 .91125 L
.69203 .91193 L
.69092 .91254 L
.68989 .91317 L
.68888 .91377 L
.68795 .91432 L
Mistroke
.68713 .91479 L
.68645 .91516 L
.68591 .91537 L
.68548 .9155 L
.68513 .91555 L
.6849 .91551 L
.68476 .91539 L
.68468 .91523 L
.68465 .915 L
.68465 .91479 L
.68467 .91464 L
.68468 .91456 L
.68463 .91461 L
.68447 .91479 L
.6842 .91513 L
.68381 .91553 L
.68332 .916 L
.68273 .91652 L
.68198 .9171 L
.68135 .9176 L
.68065 .91812 L
.68003 .91857 L
.67954 .91894 L
.67913 .91924 L
.67881 .91945 L
.67854 .91958 L
.67833 .91965 L
.6781 .91966 L
.67787 .91962 L
.67763 .91956 L
.67741 .91952 L
.67716 .91952 L
.67688 .91954 L
.67656 .91957 L
.67623 .9196 L
.67588 .91964 L
.67555 .91967 L
.67527 .9197 L
.6751 .91971 L
.67507 .91972 L
.67514 .91972 L
.67528 .91971 L
.67548 .91969 L
.67573 .91967 L
.676 .91965 L
.67629 .91963 L
.67657 .91961 L
.67687 .91958 L
.67715 .91955 L
.67744 .91953 L
Mistroke
.67765 .91951 L
.67778 .91949 L
.67781 .91949 L
.67776 .91949 L
.67766 .91949 L
.67754 .9195 L
.67744 .9195 L
.67738 .91949 L
.67736 .91949 L
.67736 .91948 L
.67734 .91948 L
.67731 .91948 L
.67732 .91948 L
.67739 .91948 L
.67755 .91946 L
.67775 .91944 L
.67796 .91941 L
.67817 .91939 L
.6783 .91937 L
.67834 .91937 L
.67825 .91937 L
.67804 .91939 L
.67774 .91943 L
.67734 .91947 L
.67695 .91952 L
.67647 .91957 L
.67598 .91963 L
.67552 .91968 L
.67512 .91973 L
.67481 .91977 L
.67458 .91979 L
.67445 .91981 L
.67441 .91982 L
.67442 .91982 L
.67448 .91981 L
.67456 .9198 L
.67463 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
Mistroke
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67466 .91979 L
.67467 .91979 L
.67469 .91978 L
.67474 .91978 L
.67481 .91977 L
.67488 .91976 L
.67491 .91976 L
.67489 .91976 L
.67478 .91977 L
.67458 .9198 L
.67429 .91983 L
.67393 .91987 L
.67353 .91991 L
.67312 .91996 L
.67272 .92001 L
.67235 .92005 L
.672 .92009 L
.6717 .92013 L
.67148 .92017 L
.67138 .92022 L
.6714 .92028 L
.67153 .9203 L
.67173 .92025 L
.67199 .92015 L
.67226 .91999 L
.6725 .9198 L
Mistroke
.67268 .9196 L
.67278 .91941 L
.6728 .91925 L
.67276 .91914 L
.6727 .91909 L
.67264 .91911 L
.67258 .91919 L
.67251 .91927 L
.67244 .91933 L
.67236 .91939 L
.67226 .91941 L
.67214 .91937 L
.672 .91925 L
.67186 .91904 L
.67174 .91878 L
.67164 .91851 L
.67158 .91825 L
.67153 .918 L
.67146 .91777 L
.67137 .9176 L
.67129 .91755 L
.67124 .91761 L
.67122 .91776 L
.67124 .918 L
.67129 .91833 L
.67133 .91874 L
.67136 .9192 L
.67134 .91966 L
.67128 .92006 L
.67117 .92037 L
.67104 .92055 L
.67091 .92062 L
.67088 .92061 L
.67097 .92055 L
.67119 .92045 L
.67144 .92037 L
.67179 .92029 L
.67217 .92022 L
.67253 .92016 L
.67284 .92009 L
.67306 .92003 L
.67319 .91999 L
.67326 .91995 L
.67332 .91993 L
.67338 .91991 L
.67344 .9199 L
.67341 .91992 L
.67332 .91994 L
.67321 .91997 L
.67318 .91997 L
Mistroke
.67319 .91997 L
.6733 .91996 L
.67347 .91994 L
.67371 .91991 L
.67397 .91988 L
.67425 .91984 L
.67454 .9198 L
.6748 .91976 L
.675 .91974 L
.67509 .91973 L
.67505 .91974 L
.67488 .91976 L
.67456 .91981 L
.67412 .91987 L
.67361 .91994 L
.67307 .92 L
.67254 .92007 L
.67203 .92013 L
.67157 .92019 L
.67121 .92024 L
.67092 .92028 L
.6707 .92033 L
.67061 .92036 L
.6707 .92034 L
.67096 .92028 L
.67134 .92018 L
.67179 .92006 L
.67227 .91992 L
.67276 .91978 L
.67319 .91966 L
.67353 .91957 L
.67374 .91951 L
.67387 .91947 L
.67398 .91945 L
.67408 .91943 L
.67421 .91941 L
.67432 .9194 L
.6744 .91941 L
.67445 .91946 L
.67446 .91955 L
.67445 .91966 L
.6744 .91979 L
.67431 .91993 L
.67416 .92007 L
.67398 .92018 L
.67381 .92026 L
.67366 .92031 L
.67329 .92042 L
.67302 .92048 L
.67268 .92057 L
Mistroke
.67219 .92066 L
.67152 .92077 L
.67064 .9209 L
.66947 .92104 L
.66813 .92124 L
.66644 .92148 L
.66447 .92177 L
.66236 .92212 L
.65998 .92251 L
.65736 .92295 L
.65459 .92346 L
.6517 .92403 L
.64921 .92457 L
.64686 .92518 L
.64493 .92581 L
.6433 .92638 L
.64217 .9269 L
.64139 .92732 L
.64096 .92763 L
.64087 .92783 L
.64096 .92791 L
.64123 .92792 L
.64164 .92785 L
.64214 .92766 L
.64267 .92742 L
.64315 .92713 L
.64352 .92682 L
.64372 .92647 L
.6438 .92613 L
.64377 .92582 L
.64368 .92554 L
.64352 .92531 L
.64328 .92514 L
.64298 .92497 L
.64264 .92475 L
.64229 .92448 L
.64196 .92416 L
.64166 .92377 L
.64139 .92326 L
.64116 .92267 L
.641 .92207 L
.64091 .92149 L
.64086 .92096 L
.64083 .92048 L
.64082 .92006 L
.64081 .91981 L
.64082 .9197 L
.64084 .91974 L
.64088 .91993 L
.64095 .9202 L
Mistroke
.64103 .9205 L
.64111 .92075 L
.64118 .92091 L
.64125 .92104 L
.64129 .92108 L
.64134 .921 L
.64143 .92087 L
.64157 .92067 L
.64177 .92046 L
.64202 .92022 L
.64228 .92002 L
.64249 .91987 L
.6426 .91981 L
.64257 .91983 L
.6424 .91998 L
.64206 .92028 L
.64151 .92069 L
.64074 .92124 L
.63974 .9219 L
.63853 .92263 L
.63715 .92344 L
.63534 .92416 L
.63347 .92493 L
.63133 .92573 L
.62875 .92655 L
.62584 .92739 L
.62255 .9282 L
.61926 .92904 L
.61604 .9299 L
.61251 .93074 L
.60867 .93163 L
.60525 .93254 L
.60122 .93333 L
.59736 .93408 L
.59307 .93479 L
.58893 .93549 L
.58508 .9361 L
.581 .9367 L
.57687 .93728 L
.57354 .93779 L
.56985 .93826 L
.56649 .9387 L
.56294 .9391 L
.55963 .9395 L
.55612 .9399 L
.55259 .94031 L
.54933 .9407 L
.54591 .94112 L
.54237 .9416 L
.53924 .94211 L
Mistroke
.53628 .94263 L
.53285 .94313 L
.52997 .94359 L
.52701 .94398 L
.52395 .94431 L
.52092 .94456 L
.51827 .94468 L
.51563 .94464 L
.51316 .94445 L
.51078 .94412 L
.50865 .94369 L
.5066 .94317 L
.50467 .9426 L
.5031 .94205 L
.50172 .94159 L
.50052 .94117 L
.49956 .94085 L
.49879 .94063 L
.49816 .9405 L
.49758 .9404 L
.49696 .94035 L
.49623 .94034 L
.49532 .94038 L
.4941 .94044 L
.49255 .94052 L
.49077 .94065 L
.48859 .94078 L
.48602 .94088 L
.48301 .94096 L
.47979 .94107 L
.47637 .94122 L
.47249 .94142 L
.46851 .94166 L
.46475 .94189 L
.46075 .9421 L
.45673 .94226 L
.45278 .94232 L
.44902 .94228 L
.4452 .94213 L
.44188 .94195 L
.43878 .94178 L
.43599 .94165 L
.43365 .94153 L
.43162 .94142 L
.42993 .94133 L
.42867 .94126 L
.42771 .94122 L
.42705 .94117 L
.42669 .94113 L
.42657 .9411 L
Mistroke
.42662 .94109 L
.42676 .94104 L
.42693 .94098 L
.42708 .94083 L
.4272 .94059 L
.42727 .94037 L
.42729 .94013 L
.42725 .93989 L
.42716 .93964 L
.42706 .93937 L
.42696 .93912 L
.42687 .93892 L
.42675 .9387 L
.42661 .93842 L
.42647 .93811 L
.42632 .93776 L
.42617 .93741 L
.42602 .93703 L
.42588 .93668 L
.42577 .93635 L
.42565 .93604 L
.42552 .93575 L
.42538 .93554 L
.42525 .93541 L
.42513 .93538 L
.42507 .93549 L
.42508 .93574 L
.42516 .93614 L
.4253 .93661 L
.42545 .93711 L
.42562 .93759 L
.42578 .93803 L
.42594 .93839 L
.42609 .93867 L
.42623 .93885 L
.42638 .93892 L
.42655 .93887 L
.42672 .93865 L
.42689 .93829 L
.42706 .93787 L
.42722 .93742 L
.42735 .93696 L
.42743 .93654 L
.42748 .93621 L
.42751 .93603 L
.42752 .93598 L
.42751 .93602 L
.42748 .93612 L
.42741 .93623 L
.42729 .93638 L
Mistroke
.42711 .93648 L
.42687 .93658 L
.4266 .93664 L
.42631 .93662 L
.42603 .93655 L
.42579 .93643 L
.4256 .93627 L
.42544 .9361 L
.42533 .93594 L
.42527 .93579 L
.42525 .93568 L
.42526 .93563 L
.42528 .93564 L
.42531 .93569 L
.42535 .93574 L
.42538 .93578 L
.42541 .93581 L
.42544 .93585 L
.42548 .93589 L
.42551 .93592 L
.42553 .93589 L
.42554 .93583 L
.42555 .93576 L
.42555 .93571 L
.42556 .93572 L
.42558 .93584 L
.42562 .93608 L
.42566 .93643 L
.42571 .93688 L
.42576 .93741 L
.42583 .93797 L
.42591 .93852 L
.426 .93905 L
.42612 .93948 L
.42626 .93993 L
.42641 .94033 L
.42656 .94065 L
.42672 .94087 L
.42686 .94093 L
.42697 .94086 L
.42706 .94068 L
.42713 .94045 L
.42719 .94018 L
.42721 .93992 L
.42723 .93968 L
.42725 .93947 L
.42728 .93929 L
.4273 .93909 L
.42734 .9389 L
.42736 .93869 L
Mistroke
.42736 .93844 L
.42731 .93815 L
.42724 .93785 L
.42714 .93755 L
.42702 .93724 L
.42689 .93692 L
.42675 .93663 L
.42661 .93636 L
.42647 .93615 L
.42632 .93599 L
.42624 .9359 L
.42627 .93586 L
.42634 .93586 L
.42641 .93587 L
.42645 .93587 L
.42645 .93585 L
.42637 .93582 L
.42609 .93579 L
.4255 .9358 L
.42454 .93585 L
.42311 .93588 L
.42117 .93586 L
.41872 .93575 L
.41626 .93554 L
.41339 .93522 L
.40982 .93478 L
.40636 .93422 L
.40186 .93351 L
.39824 .93267 L
.39366 .93178 L
.38961 .93071 L
.3854 .92957 L
.3807 .92832 L
.37702 .92695 L
.37275 .92554 L
.36889 .92407 L
.36494 .9226 L
.36108 .92111 L
.35687 .91969 L
.3533 .91832 L
.34922 .917 L
.34546 .91571 L
.34156 .91445 L
.33767 .91321 L
.33398 .91197 L
.32993 .91073 L
.32652 .90951 L
.32284 .90827 L
.3193 .90703 L
.31589 .90581 L
Mistroke
.31248 .90462 L
.30933 .90354 L
.30612 .90249 L
.30327 .90147 L
.30082 .90056 L
.29859 .89972 L
.29663 .89897 L
.29514 .89839 L
.29388 .89799 L
.29294 .89778 L
.29226 .89772 L
.29175 .89774 L
.29133 .89778 L
.29091 .89777 L
.29039 .89763 L
.28968 .89729 L
.28863 .89674 L
.28744 .89604 L
.28583 .89515 L
.2838 .8941 L
.28152 .89302 L
.27893 .89167 L
.27613 .8903 L
.27302 .8888 L
.27004 .88722 L
.2671 .88556 L
.26427 .88406 L
.26145 .88257 L
.25882 .88112 L
.25628 .87976 L
.25393 .8784 L
.25159 .87696 L
.24934 .87542 L
.24717 .87374 L
.24494 .8719 L
.24264 .86988 L
.24046 .86779 L
.23819 .86548 L
.2359 .86311 L
.23365 .86055 L
.23147 .85781 L
.22933 .85507 L
.22727 .85207 L
.22549 .84928 L
.22387 .84627 L
.22245 .84359 L
.22125 .841 L
.22022 .83863 L
.21932 .83647 L
.21846 .83455 L
Mistroke
.21754 .83269 L
.21648 .83119 L
.21524 .82983 L
.21376 .82861 L
.21197 .8275 L
.20982 .8265 L
.20771 .82556 L
.20516 .82465 L
.2022 .82357 L
.19934 .82232 L
.19607 .82083 L
.19243 .81907 L
.18904 .81708 L
.18529 .81467 L
.18168 .81209 L
.17798 .80936 L
.17454 .8067 L
.17096 .8037 L
.16774 .80081 L
.16441 .79769 L
.16132 .7948 L
.1583 .79181 L
.15546 .78893 L
.15279 .78605 L
.15032 .78346 L
.14807 .78083 L
.14603 .77821 L
.14424 .77573 L
.14262 .77312 L
.14119 .77073 L
.13988 .76823 L
.13863 .76576 L
.13736 .76327 L
.13607 .76078 L
.13479 .75812 L
.13347 .75569 L
.13219 .75309 L
.13089 .75042 L
.1297 .74792 L
.12855 .74535 L
.12748 .74299 L
.12646 .7408 L
.12559 .73859 L
.12527 .73658 L
.1245 .73456 L
.12383 .73282 L
.12334 .73118 L
.12306 .72974 L
.12295 .72853 L
.12295 .72755 L
Mistroke
.12301 .72676 L
.12307 .72614 L
.12306 .72558 L
.12294 .72503 L
.12265 .7244 L
.12212 .72363 L
.12132 .72267 L
.12029 .72149 L
.11905 .72011 L
.11784 .71868 L
.11626 .71701 L
.11442 .71517 L
.11241 .71321 L
.11024 .71094 L
.10805 .70873 L
.10569 .70632 L
.10347 .70375 L
.10145 .70129 L
.09945 .69858 L
.09771 .69585 L
.09615 .69292 L
.09476 .68978 L
.09358 .68627 L
.09253 .68263 L
.09163 .67866 L
.09081 .67433 L
.09005 .66998 L
.08934 .66519 L
.08866 .66063 L
.08799 .65657 L
.08732 .652 L
.08668 .64734 L
.08598 .64314 L
.08523 .63878 L
.08446 .63453 L
.08363 .6305 L
.08282 .62629 L
.08201 .62228 L
.08123 .61829 L
.08054 .61422 L
.07993 .61016 L
.07941 .60621 L
.07898 .60222 L
.07864 .59828 L
.07838 .59458 L
.07817 .59088 L
.07799 .58728 L
.0778 .58405 L
.07759 .58061 L
.07735 .57748 L
Mistroke
.07705 .57417 L
.07666 .57089 L
.07617 .56742 L
.07559 .56372 L
.07493 .56034 L
.07422 .55635 L
.07351 .55234 L
.07281 .54855 L
.07213 .54482 L
.07152 .54094 L
.07101 .53653 L
.07062 .53255 L
.07037 .52834 L
.07025 .52408 L
.07029 .51981 L
.07048 .51551 L
.07081 .51116 L
.07126 .50702 L
.07179 .50305 L
.07238 .49889 L
.073 .49532 L
.07363 .49181 L
.07426 .48864 L
.07485 .48604 L
.07538 .48388 L
.07584 .4822 L
.07621 .48094 L
.07649 .47999 L
.07667 .47932 L
.07678 .47885 L
.07686 .47846 L
.07695 .47805 L
.07708 .47757 L
.07727 .47697 L
.07753 .47626 L
.07787 .47543 L
.07829 .47457 L
.07878 .47356 L
.07933 .4725 L
.07988 .47139 L
.08048 .47033 L
.08103 .46942 L
.08156 .46863 L
.08204 .468 L
.08244 .46753 L
.08274 .46723 L
.08294 .46708 L
Mfstroke
.09098 .46065 m
.09112 .46062 L
.09139 .46054 L
.09184 .4604 L
.09247 .46017 L
.09332 .45986 L
.09441 .45948 L
.09567 .45908 L
.09715 .45867 L
.09871 .45825 L
.10046 .45778 L
.1022 .45728 L
.10427 .45673 L
.10605 .45617 L
.10788 .45562 L
.10985 .45509 L
.11173 .4546 L
.11365 .45415 L
.11548 .45375 L
.11696 .45337 L
.11847 .45301 L
.11984 .45266 L
.12115 .45231 L
.12236 .45196 L
.1236 .45171 L
.12481 .45149 L
.12606 .45132 L
.12729 .4512 L
.12853 .45109 L
.12976 .45097 L
.13091 .45082 L
.13207 .45063 L
.13322 .45039 L
.13434 .4501 L
.13541 .44979 L
.13633 .44947 L
.13715 .44916 L
.1378 .4489 L
.13824 .44874 L
.13843 .44869 L
.13835 .44878 L
.13803 .44903 L
.13751 .44943 L
.13689 .44998 L
.13625 .45063 L
.13566 .45137 L
.13517 .45219 L
.13479 .45303 L
.13454 .45396 L
.13442 .45498 L
Mistroke
.13446 .45609 L
.13467 .45727 L
.13504 .45847 L
.13566 .45971 L
.13641 .46102 L
.13731 .46237 L
.13833 .46367 L
.13936 .46501 L
.14033 .46633 L
.14118 .46763 L
.1419 .46885 L
.14252 .46991 L
.14306 .47087 L
.14352 .47173 L
.14394 .47249 L
.14436 .47318 L
.1448 .47378 L
.14528 .47432 L
.14584 .4748 L
.14654 .47524 L
.14741 .47566 L
.14843 .47603 L
.14965 .47639 L
.15105 .47675 L
.15266 .47709 L
.1543 .47739 L
.15607 .47763 L
.15791 .4778 L
.15974 .47788 L
.16148 .47788 L
.163 .47783 L
.16434 .47774 L
.16538 .47766 L
.16613 .47761 L
.16659 .47764 L
.16678 .4777 L
.16675 .47777 L
.16652 .47781 L
.16617 .4778 L
.16574 .47773 L
.16529 .47759 L
.16479 .47737 L
.16429 .47705 L
.16383 .47664 L
.16344 .47615 L
.16319 .47558 L
.16311 .47496 L
.16323 .47432 L
.16349 .47366 L
.16382 .47301 L
Mistroke
.16418 .47242 L
.1645 .47196 L
.16477 .47167 L
.16496 .47156 L
.16507 .4716 L
.16506 .47173 L
.16492 .47191 L
.16458 .4721 L
.16395 .47223 L
.16318 .47223 L
.16219 .4721 L
.1609 .47182 L
.15918 .47138 L
.15705 .47075 L
.15526 .47002 L
.15267 .46904 L
.15036 .46804 L
.14715 .46692 L
.14451 .46571 L
.14106 .46454 L
.13855 .46352 L
.13476 .4626 L
.13185 .46181 L
.12811 .46119 L
.12552 .46069 L
.12177 .46029 L
.11897 .46 L
.11542 .4598 L
.11289 .4597 L
.10957 .45973 L
.10635 .45992 L
.10373 .46028 L
.10007 .4608 L
.0975 .46147 L
.09443 .46231 L
.09109 .4633 L
.08847 .46422 L
.0859 .46527 L
.08392 .46626 L
.08154 .46733 L
.0794 .46861 L
.07788 .4697 L
.07663 .47078 L
.07558 .47182 L
.07477 .47282 L
.07418 .47376 L
.07377 .47462 L
.07348 .47539 L
.07328 .47603 L
.0731 .4766 L
Mistroke
.07297 .47713 L
.07292 .47772 L
.0729 .47816 L
.07285 .4786 L
.07283 .47892 L
.07287 .47912 L
Mfstroke
.08407 .40182 m
.0842 .40157 L
.08434 .40115 L
.0845 .4005 L
.08468 .39959 L
.08488 .39835 L
.08512 .39673 L
.08539 .39501 L
.08568 .39267 L
.08601 .39017 L
.08637 .38744 L
.08678 .3843 L
.08722 .38075 L
.08769 .37698 L
.08815 .37282 L
.08863 .36925 L
.08911 .36461 L
.08963 .36088 L
.0902 .35653 L
.09085 .35197 L
.09157 .34756 L
.09229 .34308 L
.09304 .33923 L
.09381 .33502 L
.09457 .33162 L
.09523 .3283 L
.09598 .32517 L
.09662 .3223 L
.09724 .32017 L
.09785 .31816 L
.09843 .31653 L
.09894 .31515 L
.09937 .31406 L
.09972 .31343 L
.09999 .31292 L
.1002 .31259 L
.10036 .31239 L
.10049 .3123 L
.10059 .31225 L
.10067 .31218 L
.1007 .31208 L
.10067 .31197 L
.10062 .31182 L
.10056 .31163 L
.10053 .31138 L
.10055 .31107 L
.10063 .31071 L
.10078 .31031 L
.10096 .3099 L
.10118 .3095 L
Mistroke
.1014 .30915 L
.10158 .30887 L
.10172 .3087 L
.10187 .30854 L
.10204 .30841 L
.10227 .30829 L
.10255 .30811 L
.1029 .30782 L
.10333 .30735 L
.10386 .30662 L
.10454 .30555 L
.10539 .3041 L
.10643 .30239 L
.10752 .30031 L
.10892 .29817 L
.11039 .29565 L
.11209 .29269 L
.11384 .28968 L
.11574 .28677 L
.11752 .28358 L
.11941 .28031 L
.12129 .27704 L
.12307 .27395 L
.1249 .27084 L
.12671 .26783 L
.12853 .26478 L
.13049 .26173 L
.1324 .2586 L
.13444 .25533 L
.13649 .25219 L
.1386 .24864 L
.14076 .24535 L
.14299 .24186 L
.14531 .23824 L
.1475 .23488 L
.14976 .23138 L
.15224 .22768 L
.15436 .22441 L
.15671 .22084 L
.15906 .2172 L
.16165 .21366 L
.1639 .20996 L
.16633 .20642 L
.16879 .2029 L
.17113 .19936 L
.17346 .19598 L
.17579 .19256 L
.17798 .18915 L
.17999 .18596 L
.18202 .18265 L
Mistroke
.18397 .17922 L
.18584 .17633 L
.18755 .17338 L
.18925 .17053 L
.19079 .16826 L
.19232 .16599 L
.19363 .16409 L
.19484 .16232 L
.19604 .16082 L
.197 .1596 L
.19786 .15859 L
.19859 .15784 L
.19917 .15734 L
.19957 .15709 L
.19978 .15705 L
.19982 .15715 L
.19975 .15731 L
.19964 .15743 L
.19956 .15741 L
.1996 .15721 L
.19979 .1568 L
.20016 .15616 L
.20073 .15529 L
.20149 .15426 L
.20247 .15304 L
.20371 .15163 L
.20515 .15011 L
.20678 .14844 L
.20874 .14664 L
.21096 .14468 L
.21312 .14273 L
.2157 .14067 L
.21838 .13865 L
.22103 .13666 L
.22393 .13475 L
.22664 .13291 L
.22936 .13133 L
.23195 .12982 L
.2343 .12858 L
.23642 .12745 L
.23828 .12654 L
.23985 .12581 L
.24105 .12527 L
.242 .12493 L
.24272 .12476 L
.24322 .12473 L
.24355 .12479 L
.24375 .12491 L
.24387 .12508 L
.24394 .12524 L
Mistroke
.24396 .1254 L
.24396 .12555 L
.24396 .12566 L
.24402 .12572 L
.24411 .12572 L
.24425 .12562 L
.24447 .12537 L
.24481 .12496 L
.24533 .12438 L
.24608 .12362 L
.2471 .12268 L
.24843 .12169 L
.24997 .12049 L
.25179 .11908 L
.25405 .11764 L
.25651 .116 L
.25932 .11418 L
.2627 .11229 L
.26561 .11038 L
.26893 .10832 L
.27257 .10639 L
.27569 .10431 L
.27906 .10236 L
.28232 .10031 L
.28565 .0981 L
.28874 .09606 L
.29197 .09377 L
.2954 .09165 L
.29875 .08939 L
.30248 .087 L
.30607 .08477 L
.30991 .0824 L
.31399 .08005 L
.318 .07761 L
.32208 .07514 L
.32671 .0725 L
.33062 .06996 L
.33505 .06728 L
.33922 .06468 L
.34365 .06204 L
.34758 .05968 L
.35139 .05742 L
.35495 .05525 L
.35829 .05339 L
.36117 .05188 L
.36375 .05054 L
.36607 .0494 L
.36783 .04851 L
.36939 .04786 L
.37057 .04744 L
Mistroke
.37147 .04722 L
.37209 .04714 L
.37245 .04716 L
.37259 .04727 L
.3726 .04742 L
.37251 .04755 L
.37236 .04763 L
.37219 .04766 L
.37204 .04768 L
.37195 .0477 L
.37191 .0477 L
.3719 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37189 .0477 L
.37188 .0477 L
.37185 .0477 L
.3718 .04769 L
.37173 .04769 L
.37166 .04769 L
.37159 .04769 L
.37153 .04769 L
.37153 .04768 L
.37161 .04769 L
.37178 .04772 L
.37207 .04778 L
.37251 .04786 L
.37313 .04794 L
.37392 .048 L
.37491 .048 L
.3761 .04795 L
.3775 .04782 L
.37906 .04761 L
.38089 .04734 L
.38273 .04701 L
.38483 .04665 L
Mistroke
.38699 .04627 L
.38932 .0459 L
.39142 .04553 L
.39365 .04516 L
.39576 .04483 L
.39777 .04453 L
.39958 .04431 L
.40122 .04416 L
.40265 .04409 L
.40388 .04409 L
.40483 .04415 L
.40557 .04424 L
.40612 .04432 L
.40648 .04439 L
.40666 .04442 L
.40672 .04442 L
.40668 .04442 L
.40659 .04442 L
.40648 .04442 L
.40637 .04441 L
.40628 .04441 L
.40622 .04441 L
.40617 .04441 L
.40613 .04441 L
.4061 .0444 L
.40608 .0444 L
.40609 .0444 L
.40614 .04441 L
.40624 .04441 L
.40637 .0444 L
.40654 .04441 L
.40674 .04441 L
.40697 .04443 L
.4072 .04444 L
.40744 .04446 L
.40768 .04447 L
.4079 .04447 L
.40811 .04443 L
.4083 .04437 L
.40844 .04431 L
.40855 .04428 L
.40861 .04431 L
.40862 .04443 L
.40861 .04466 L
.40858 .04498 L
.40854 .04536 L
.40851 .04576 L
.40848 .04614 L
.40845 .04646 L
.40841 .0467 L
Mistroke
.40836 .04686 L
.40829 .04692 L
.40821 .04689 L
.40813 .04676 L
.4081 .04652 L
.40811 .04623 L
.40821 .04591 L
.40842 .0456 L
.40879 .04534 L
.40934 .04521 L
.41011 .04527 L
.41111 .04553 L
.41241 .04592 L
.41393 .04638 L
.4158 .04687 L
.41784 .04734 L
.4202 .04775 L
.42281 .04804 L
.42581 .04819 L
.42851 .04822 L
.43164 .04814 L
.435 .04795 L
.43803 .0477 L
.44126 .04742 L
.44449 .04711 L
.44801 .04686 L
.4509 .04663 L
.45414 .04647 L
.45758 .04635 L
.46068 .04625 L
.46394 .04611 L
.46717 .0459 L
.47057 .0456 L
.47423 .04525 L
.47754 .04487 L
.48106 .04449 L
.48474 .04418 L
.48809 .04395 L
.49179 .0438 L
.49522 .04376 L
.49887 .04387 L
.50249 .04415 L
.50586 .0446 L
.50943 .0452 L
.51277 .04592 L
.51608 .04676 L
.51945 .04769 L
.52288 .04864 L
.52618 .04955 L
.52948 .05035 L
Mistroke
.53279 .05107 L
.53611 .05174 L
.53938 .0524 L
.54263 .05308 L
.54579 .05381 L
.54897 .05458 L
.55192 .05544 L
.55474 .05636 L
.5574 .05731 L
.55975 .05827 L
.56187 .05909 L
.5637 .05997 L
.56524 .0609 L
.5664 .06168 L
.56725 .06239 L
.56783 .06302 L
.56816 .06352 L
.56829 .06389 L
.56832 .06412 L
.56836 .06422 L
.56851 .06422 L
.56884 .06418 L
.56941 .06416 L
.57029 .06416 L
.57153 .06419 L
.57308 .06423 L
.57513 .06426 L
.57758 .06424 L
.58033 .06416 L
.58339 .06399 L
.5867 .06374 L
.58988 .06341 L
.59311 .06301 L
.59606 .06258 L
.59896 .06218 L
.60141 .06181 L
.60382 .0615 L
.60608 .06129 L
.608 .06123 L
.60989 .06136 L
.61179 .0617 L
.61374 .06226 L
.61579 .06304 L
.61783 .06398 L
.62 .0651 L
.62215 .0664 L
.62451 .06776 L
.62708 .06921 L
.63 .07063 L
.63257 .07199 L
Mistroke
.63533 .0733 L
.63805 .07446 L
.6409 .07544 L
.64344 .0763 L
.64607 .07705 L
.64869 .07767 L
.65132 .07822 L
.6542 .07874 L
.65707 .07925 L
.66011 .07978 L
.66342 .08037 L
.66668 .08104 L
.67012 .08178 L
.67371 .08256 L
.6771 .08346 L
.68062 .08452 L
.68395 .08576 L
.68741 .08701 L
.69048 .08839 L
.69368 .08985 L
.69688 .09133 L
.69977 .09277 L
.70295 .09423 L
.70566 .09548 L
.70825 .09677 L
.71068 .09789 L
.71285 .09893 L
.71491 .09984 L
.7164 .10056 L
.71767 .10109 L
.7187 .1014 L
.71942 .10149 L
.71984 .10141 L
.71998 .10117 L
.71989 .10082 L
.71965 .10047 L
.71935 .10019 L
.71907 .09999 L
.7188 .09989 L
.71862 .09991 L
.71859 .10005 L
.71871 .10032 L
.71889 .10068 L
.7191 .10108 L
.71934 .10151 L
.71959 .10193 L
.71982 .1023 L
.72001 .10258 L
.72009 .10275 L
.72006 .1028 L
Mistroke
.71997 .10273 L
.71983 .10259 L
.71969 .1024 L
.71961 .10216 L
.71967 .10196 L
.71992 .10185 L
.72042 .10189 L
.7212 .1021 L
.72227 .1025 L
.72366 .1031 L
.72525 .10388 L
.72702 .10474 L
.72906 .10571 L
.73131 .10677 L
.73377 .10787 L
.73614 .10888 L
.7384 .10982 L
.74059 .11067 L
.74258 .11138 L
.74426 .11195 L
.7457 .11236 L
.74687 .11264 L
.74775 .1128 L
.74843 .11288 L
.74895 .11291 L
.74936 .1129 L
.74965 .11287 L
.74986 .11283 L
.75002 .1128 L
.75013 .11277 L
.75023 .11274 L
.75033 .11272 L
.75045 .11268 L
.75057 .11265 L
.75068 .11263 L
.75076 .11263 L
.75081 .11264 L
.75081 .11268 L
.75077 .11273 L
.75067 .1128 L
.75054 .1129 L
.75039 .11302 L
.75026 .11319 L
.75018 .11343 L
.75019 .11377 L
.75032 .11417 L
.75061 .11464 L
.75109 .11518 L
.7518 .11576 L
.75274 .11646 L
Mistroke
.75389 .11725 L
.75538 .11818 L
.75705 .11924 L
.75895 .12043 L
.76111 .12177 L
.76346 .12322 L
.76585 .12477 L
.76824 .12639 L
.77057 .12786 L
.77271 .12932 L
.77456 .13055 L
.77625 .1317 L
.77777 .1328 L
.77895 .13373 L
.77995 .13456 L
.78078 .13533 L
.78146 .13614 L
.78204 .13703 L
.78253 .13796 L
.78295 .13894 L
.78334 .13995 L
.78372 .14107 L
.78404 .14208 L
.78429 .1432 L
.78451 .1442 L
.78474 .14521 L
.785 .14631 L
.78531 .1472 L
.78573 .14806 L
.78629 .14891 L
.7871 .14979 L
.7882 .15066 L
.7896 .15161 L
.79116 .1526 L
.79296 .15394 L
.79495 .15549 L
.79702 .15725 L
.79939 .15919 L
.80206 .16132 L
.80438 .16353 L
.80677 .16587 L
.80905 .16821 L
.8111 .17063 L
.81293 .17287 L
.81464 .17521 L
.81613 .17741 L
.8175 .17964 L
.81883 .18191 L
.8201 .18408 L
.82136 .18604 L
Mistroke
.82263 .18797 L
.82387 .18981 L
.82514 .1916 L
.82644 .19324 L
.82771 .19486 L
.82905 .19642 L
.83039 .19797 L
.8317 .19947 L
.83308 .20105 L
.83449 .20279 L
.83592 .20457 L
.8375 .20666 L
.83922 .20877 L
.84081 .21119 L
.84256 .21352 L
.8443 .21611 L
.84609 .21865 L
.84792 .22122 L
.84954 .22364 L
.85111 .2259 L
.85248 .22795 L
.85364 .22948 L
.85451 .23072 L
.85516 .23167 L
.85557 .2323 L
.8557 .23259 L
.8556 .23256 L
.85533 .23228 L
.85492 .23181 L
.85442 .23124 L
.8539 .23064 L
.85338 .23004 L
.85289 .22951 L
.85249 .22909 L
.85219 .22881 L
.852 .22863 L
.85189 .22851 L
.85184 .22845 L
.85181 .22841 L
.8518 .22837 L
.8518 .22835 L
.85178 .22832 L
.85173 .22829 L
.85167 .22828 L
.85168 .22835 L
.8518 .22855 L
.85206 .22889 L
.85247 .22939 L
.85305 .23007 L
.8538 .23093 L
Mistroke
.85467 .23194 L
.85571 .23319 L
.85693 .23462 L
.85824 .23631 L
.85977 .23819 L
.86154 .24039 L
.86315 .24266 L
.86487 .24526 L
.86681 .2479 L
.86891 .25078 L
.87071 .25369 L
.87266 .25679 L
.8746 .26001 L
.87647 .26297 L
.8783 .26607 L
.88015 .26931 L
.88189 .27218 L
.8835 .27493 L
.88513 .27785 L
.88668 .28058 L
.88814 .28309 L
.88958 .28562 L
.89089 .28813 L
.89216 .29039 L
.89342 .2927 L
.89455 .2947 L
.89563 .29671 L
.89663 .29838 L
.89753 .29994 L
.89835 .30134 L
.89901 .30244 L
.89954 .30332 L
.89994 .30396 L
.90019 .30438 L
.90031 .3046 L
.90034 .30464 L
.9003 .30458 L
.90023 .30446 L
.90015 .30433 L
.90008 .30423 L
.90003 .30415 L
.9 .30409 L
.89999 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
Mistroke
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89998 .30406 L
.89997 .30405 L
.89995 .30402 L
.89992 .30399 L
.89989 .30396 L
.89987 .30394 L
.89988 .30395 L
.89992 .304 L
.9 .30408 L
.90012 .3042 L
.90026 .30435 L
.90043 .30453 L
.90062 .30473 L
.90082 .30494 L
.90102 .30516 L
.90123 .30537 L
.90142 .30557 L
.9016 .30576 L
.90175 .30593 L
.90188 .30606 L
.90196 .30615 L
.90201 .3062 L
.90203 .30621 L
.90202 .3062 L
.90199 .30617 L
.90195 .30614 L
.90193 .30611 L
.90192 .3061 L
.90191 .30609 L
.90191 .30609 L
.90191 .30609 L
.90191 .30609 L
.90192 .30609 L
.90193 .30608 L
.90195 .30607 L
.90198 .30606 L
.902 .30606 L
.90202 .30608 L
.90201 .30611 L
.90197 .30614 L
.9019 .3062 L
.9018 .30626 L
.90166 .30633 L
.9015 .30639 L
.90132 .30643 L
.90113 .30643 L
.90093 .30638 L
Mistroke
.90073 .3063 L
.90054 .30617 L
.90036 .306 L
.90021 .3058 L
.90008 .30556 L
.89998 .30531 L
.89993 .30505 L
.8999 .30479 L
.8999 .30455 L
.89992 .3043 L
.89994 .30405 L
.89994 .30381 L
.89991 .3036 L
.89984 .30344 L
.89975 .30339 L
.89969 .30346 L
.89967 .30368 L
.89971 .30408 L
.89986 .30466 L
.90011 .30543 L
.9005 .30639 L
.901 .30754 L
.90161 .30875 L
.9023 .31019 L
.90301 .31186 L
.90382 .31369 L
.90459 .31561 L
.90536 .31773 L
.9061 .31981 L
.90678 .32228 L
.90735 .32418 L
.90782 .32648 L
.9082 .32884 L
.90851 .33093 L
.90876 .33304 L
.90898 .3353 L
.90918 .33751 L
.90941 .33962 L
.90962 .34159 L
.90981 .3434 L
.90993 .34491 L
.91 .34611 L
.91005 .34714 L
.91008 .34799 L
.91008 .34866 L
.91007 .34915 L
.91006 .34949 L
.91004 .34971 L
.91002 .34987 L
.91001 .34995 L
Mistroke
.91004 .34999 L
.91011 .35001 L
.91021 .35006 L
.91036 .35021 L
.91053 .35039 L
.91068 .35055 L
.91079 .35064 L
.91083 .35066 L
.91079 .35058 L
.91068 .35038 L
.9105 .35003 L
.91028 .34953 L
.91007 .3489 L
.90987 .34818 L
.90968 .34743 L
.90949 .34671 L
.9093 .34611 L
.90911 .34566 L
.9089 .34541 L
.90868 .34538 L
.90843 .34561 L
.90815 .34611 L
.90784 .34687 L
.90751 .34784 L
.90718 .34885 L
.90684 .34992 L
.9065 .351 L
.90621 .35203 L
.90599 .35282 L
.90586 .35338 L
.90585 .35368 L
.90597 .35373 L
.90621 .35356 L
.90654 .35321 L
.90691 .3527 L
.9073 .35206 L
.90767 .35133 L
.90798 .35055 L
.90821 .34982 L
.90836 .34911 L
.90845 .34845 L
.90848 .34786 L
.90845 .34729 L
.90837 .34674 L
.90826 .34622 L
.90816 .3457 L
.90807 .34514 L
.90802 .34455 L
.90804 .3439 L
.90812 .34323 L
Mistroke
.90828 .34251 L
.90852 .34174 L
.90881 .34088 L
.90911 .33995 L
.90942 .33894 L
.90971 .33791 L
.90996 .33677 L
.91015 .33564 L
.91029 .33449 L
.91036 .33334 L
.91036 .33223 L
.91031 .33111 L
.91019 .33006 L
.91002 .329 L
.90981 .32795 L
.90956 .32698 L
.90931 .3261 L
.90906 .32534 L
.90884 .32462 L
.90865 .32392 L
.90848 .32321 L
.90833 .32249 L
.9082 .32175 L
.90808 .32098 L
.90796 .32017 L
.90784 .31937 L
.90772 .31861 L
.90758 .3179 L
.90743 .31727 L
.90725 .31667 L
.90704 .3161 L
.90683 .31557 L
.90663 .31512 L
.90642 .31472 L
.90624 .31439 L
.90608 .31415 L
.90595 .314 L
.90586 .31394 L
.90579 .31395 L
.90575 .314 L
.90573 .31406 L
.90575 .31411 L
.90579 .31415 L
.90585 .31418 L
.90594 .31419 L
.90605 .3142 L
.90619 .3142 L
.90636 .3142 L
.90654 .3142 L
.90673 .3142 L
Mistroke
.90692 .3142 L
.90711 .3142 L
.9073 .3142 L
.90747 .31421 L
.90762 .31421 L
.90773 .31421 L
.90782 .31421 L
.90787 .31421 L
.90788 .31421 L
.90787 .31421 L
.90784 .31421 L
.90781 .31421 L
.90779 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90777 .31421 L
.90778 .3142 L
.9078 .31417 L
.90783 .31412 L
.90786 .31409 L
.90787 .31408 L
.90786 .3141 L
.90783 .31416 L
Mistroke
.90776 .31426 L
.90766 .31441 L
.90753 .31459 L
.90738 .3148 L
.90721 .31501 L
.90703 .31522 L
.90685 .31545 L
.90666 .31564 L
.90648 .31583 L
.90632 .31602 L
.90617 .31618 L
.90606 .31629 L
.90597 .31636 L
.90592 .31638 L
.9059 .31636 L
.90591 .31632 L
.90593 .31627 L
.90596 .31622 L
.90598 .31619 L
.906 .3162 L
.906 .31624 L
.906 .31628 L
.906 .31632 L
.90601 .31633 L
.906 .31632 L
.906 .31628 L
.906 .3162 L
.906 .31608 L
.90599 .31594 L
.90598 .31578 L
.90598 .31563 L
.90597 .31549 L
.90597 .31534 L
.90596 .31516 L
.90598 .31496 L
.90603 .31473 L
.90608 .31447 L
.90613 .31417 L
.90615 .31383 L
.90615 .31343 L
.90608 .31297 L
.90592 .31241 L
.90564 .31174 L
.90524 .31098 L
.90474 .31015 L
.90415 .30926 L
.9035 .30836 L
.90289 .30752 L
.90222 .30675 L
.90151 .30605 L
Mistroke
.90073 .30544 L
.9001 .30494 L
.89954 .30454 L
.89905 .30424 L
.89866 .30406 L
.89847 .30399 L
.89848 .30403 L
.89861 .30425 L
.89884 .30449 L
.8991 .30472 L
.89931 .30491 L
.89943 .30509 L
.89943 .30527 L
.8993 .30548 L
.89903 .30572 L
.89858 .30604 L
.89795 .30642 L
.89717 .30687 L
.89638 .30736 L
.89554 .30786 L
.89464 .30834 L
.89372 .30875 L
.89291 .3091 L
.8925 .30934 L
.89224 .30943 L
.89221 .30937 L
.8924 .30918 L
.89273 .30887 L
.89313 .30851 L
.89367 .30813 L
.89439 .30783 L
.89503 .30766 L
.89571 .3077 L
.89643 .30802 L
.89706 .30867 L
.89763 .30964 L
.8982 .31089 L
.89881 .31243 L
.89948 .31436 L
.90021 .31661 L
.90097 .31906 L
.90189 .32173 L
.90294 .32437 L
.90395 .32724 L
.90517 .33021 L
.90647 .33336 L
.9077 .3367 L
.90902 .34003 L
.9103 .3436 L
.9115 .34744 L
Mistroke
.91257 .35098 L
.91354 .35467 L
.9144 .3588 L
.91517 .36213 L
.91589 .36608 L
.91653 .36953 L
.91714 .37326 L
.9177 .37705 L
.9182 .38061 L
.91864 .38427 L
.91901 .38808 L
.91933 .39171 L
.91962 .39528 L
.91988 .39905 L
.92012 .40267 L
.92033 .40649 L
.92052 .41002 L
.92071 .41358 L
.92088 .41694 L
.92105 .42019 L
.92122 .42338 L
.92141 .42633 L
.92163 .42937 L
.92187 .43208 L
.92214 .43472 L
.92243 .43742 L
.92271 .43977 L
.92298 .44211 L
.92324 .44417 L
.92348 .44593 L
.92368 .44742 L
.92384 .4485 L
.92395 .44924 L
.92401 .44963 L
.92402 .44967 L
.924 .44939 L
.92395 .44887 L
.92389 .4482 L
.92384 .44744 L
.9238 .44664 L
.92377 .4459 L
.92375 .44524 L
.92373 .44471 L
.92372 .44432 L
.92373 .44408 L
.92377 .44396 L
.92382 .44393 L
.92387 .44397 L
.9239 .44405 L
.92389 .44413 L
Mistroke
.92381 .44419 L
.92365 .44423 L
.92341 .44425 L
.92309 .44426 L
.92273 .44427 L
.92235 .44427 L
.92199 .44428 L
.92166 .44429 L
.92138 .44429 L
.92114 .44425 L
.92096 .44418 L
.92085 .44407 L
.92083 .44394 L
.9209 .44379 L
.92105 .44368 L
.92123 .44364 L
.92139 .44371 L
.92151 .444 L
.92155 .44454 L
.92145 .44538 L
.92122 .44653 L
.92087 .44801 L
.92045 .44965 L
.91996 .45161 L
.91941 .45385 L
.91884 .45616 L
.91832 .45843 L
.91784 .46096 L
.91743 .46393 L
.91712 .46644 L
.91694 .46901 L
.91691 .47169 L
.91702 .47447 L
.9173 .47697 L
.91769 .47972 L
.91815 .48242 L
.9187 .48526 L
.91929 .48832 L
.9199 .49121 L
.92054 .49423 L
.92119 .49696 L
.92183 .49957 L
.92249 .50191 L
.92311 .50387 L
.92373 .50552 L
.92432 .50697 L
.9249 .50825 L
.92546 .50935 L
.92601 .51043 L
.92658 .51153 L
Mistroke
.92716 .51264 L
.92775 .51397 L
.92836 .51554 L
.92899 .51727 L
.92962 .51943 L
.93024 .52183 L
.93081 .52467 L
.9313 .52756 L
.93168 .53088 L
.93196 .5338 L
.93211 .53689 L
.93215 .53997 L
.93209 .54281 L
.93193 .5456 L
.93171 .54799 L
.93146 .55021 L
.9312 .55208 L
.93093 .55373 L
.93069 .5551 L
.9305 .55614 L
.93037 .55691 L
.9303 .55742 L
.9303 .55769 L
.93036 .55773 L
.93049 .5576 L
.93068 .55732 L
.93091 .55698 L
.93114 .55663 L
.93134 .55633 L
.93147 .55611 L
.9315 .55604 L
.93141 .55613 L
.93121 .55643 L
.93093 .55695 L
.93058 .55775 L
.93015 .55883 L
.92965 .56022 L
.92909 .56181 L
.92845 .56365 L
.92773 .56576 L
.92693 .56798 L
.92607 .57051 L
.92524 .57298 L
.92438 .5757 L
.92362 .57847 L
.92287 .58144 L
.92223 .58425 L
.92161 .58725 L
.92101 .59017 L
.92042 .59315 L
Mistroke
.91983 .59604 L
.91923 .5989 L
.91861 .60167 L
.91803 .60419 L
.91746 .60652 L
.91694 .60858 L
.91648 .61036 L
.91608 .61191 L
.91573 .61308 L
.91544 .61398 L
.91524 .61462 L
.91514 .61498 L
.91516 .61511 L
.91527 .61504 L
.91547 .61484 L
.91571 .6146 L
.91597 .6144 L
.9162 .61429 L
.91638 .61432 L
.91644 .6145 L
.91636 .61485 L
.91612 .61538 L
.91567 .61609 L
.91503 .617 L
.91422 .61811 L
.91328 .61939 L
.91215 .62086 L
.9108 .62247 L
.90954 .62409 L
.90812 .62574 L
.90667 .62742 L
.90556 .62905 L
.90426 .63091 L
.90325 .63259 L
.90234 .63435 L
.90152 .63622 L
.90084 .63822 L
.90036 .64034 L
.90005 .64238 L
.89986 .64462 L
.89972 .64712 L
.89958 .64958 L
.89944 .65233 L
.89926 .65527 L
.89895 .65827 L
.89854 .66153 L
.89805 .66446 L
.89759 .66728 L
.89714 .66986 L
.89672 .67213 L
Mistroke
.89635 .67417 L
.89603 .6758 L
.89578 .6772 L
.8956 .67832 L
.89548 .67912 L
.89542 .67962 L
.8954 .67984 L
.89542 .67984 L
.89548 .67968 L
.89558 .67944 L
.89569 .67917 L
.89577 .67894 L
.8958 .6788 L
.89575 .67878 L
.89563 .67887 L
.89542 .67905 L
.89515 .6793 L
.89483 .6796 L
.89451 .67991 L
.89421 .68023 L
.89395 .68053 L
.89371 .68082 L
.89349 .68114 L
.89329 .68151 L
.8931 .68197 L
.89295 .68254 L
.89285 .68325 L
.8928 .68415 L
.89275 .68534 L
.89267 .68691 L
.89251 .68878 L
.89222 .69109 L
.89177 .69391 L
.89112 .69703 L
.89027 .70044 L
.88923 .70447 L
.8881 .70839 L
.88687 .7125 L
.8856 .71696 L
.8843 .7209 L
.88295 .72542 L
.88157 .72933 L
.88015 .73356 L
.87874 .73759 L
.87731 .74171 L
.8759 .74566 L
.87453 .74976 L
.87325 .75318 L
.87202 .7567 L
.87086 .7601 L
Mistroke
.86974 .76308 L
.86868 .76611 L
.86768 .76865 L
.86672 .77109 L
.86579 .77338 L
.86496 .77531 L
.86416 .77707 L
.86344 .77856 L
.86285 .77973 L
.86241 .78056 L
.86204 .78128 L
.8617 .78189 L
.86134 .7825 L
.86105 .78299 L
.86074 .78348 L
.86046 .78394 L
.86026 .78432 L
.86012 .78462 L
.86002 .78483 L
.85993 .78497 L
.8598 .78506 L
.85962 .78522 L
.85931 .78546 L
.85889 .78579 L
.85841 .78618 L
.8579 .78659 L
.8574 .78696 L
.85697 .78724 L
.85662 .78742 L
.85636 .78752 L
.85619 .78757 L
.85603 .78761 L
.85593 .78766 L
.85588 .78772 L
.85587 .78779 L
.85598 .78782 L
.85618 .78779 L
.85645 .7877 L
.85673 .78758 L
.85699 .78743 L
.85719 .78726 L
.85733 .78706 L
.85741 .7869 L
.85746 .78677 L
.85747 .7867 L
.85744 .78668 L
.85737 .78671 L
.8573 .78674 L
.85719 .78682 L
.85703 .78695 L
Mistroke
.85682 .78715 L
.85657 .7874 L
.85628 .78768 L
.85596 .788 L
.85562 .78833 L
.85528 .78863 L
.85499 .78882 L
.85483 .7889 L
.85472 .78892 L
.85458 .78897 L
.85437 .78909 L
.8541 .78929 L
.85373 .7896 L
.85324 .79004 L
.85262 .79061 L
.85187 .79131 L
.85099 .79215 L
.85003 .79308 L
.849 .7941 L
.848 .79511 L
.8469 .79597 L
.84567 .79717 L
.84438 .79843 L
.84309 .79962 L
.84189 .80065 L
.8408 .80148 L
.83987 .80213 L
.83905 .80265 L
.83832 .80307 L
.83764 .80343 L
.83703 .80375 L
.83641 .80406 L
.83587 .80432 L
.83546 .8045 L
.8352 .80454 L
.83509 .80445 L
.83511 .80426 L
.83521 .80404 L
.83533 .80383 L
.83545 .80369 L
.83558 .80355 L
.83569 .80346 L
.83579 .80339 L
.83584 .80337 L
.83585 .80344 L
.83583 .80358 L
.83577 .80381 L
.83565 .80413 L
.83544 .80458 L
.83513 .80512 L
Mistroke
.83474 .80571 L
.83435 .80613 L
.83395 .80647 L
.83353 .80673 L
.83303 .80698 L
.83259 .80718 L
.83209 .80739 L
.83161 .80761 L
.83112 .80781 L
.83063 .80803 L
.83014 .80827 L
.82967 .80854 L
.82917 .80884 L
.82856 .80923 L
.82794 .80973 L
.82731 .81033 L
.82651 .81111 L
.82566 .81203 L
.82476 .81301 L
.82394 .81391 L
.82305 .81477 L
.82217 .81554 L
.82136 .81623 L
.82055 .81685 L
.81995 .81743 L
.8194 .81796 L
.819 .81841 L
.81878 .81872 L
.81872 .81888 L
.81879 .81893 L
.81897 .8189 L
.81916 .81883 L
.81934 .81874 L
.81948 .81863 L
.8196 .81849 L
.81966 .81833 L
.81963 .81812 L
.81952 .81786 L
.81933 .81756 L
.81907 .81721 L
.81874 .81685 L
.81836 .81648 L
.81801 .81613 L
.81773 .81577 L
.81755 .81542 L
.81752 .81509 L
.81764 .81479 L
.81787 .81454 L
.81818 .81436 L
.81856 .81423 L
Mistroke
.81902 .81418 L
.81952 .81418 L
.82005 .81422 L
.82059 .81423 L
.82115 .81419 L
.82172 .81405 L
.8223 .8138 L
.82291 .81344 L
.82352 .81296 L
.82416 .81233 L
.82492 .81153 L
.82588 .81055 L
.82705 .8094 L
.82852 .80814 L
.83023 .80673 L
.83218 .80518 L
.83442 .80356 L
.83674 .80189 L
.83926 .80015 L
.84192 .7984 L
.84449 .79661 L
.84703 .79488 L
.84965 .79313 L
.85191 .79139 L
.85418 .78978 L
.85622 .78817 L
.85806 .78661 L
.85969 .78505 L
.86114 .78354 L
.86228 .78209 L
.86327 .78067 L
.86411 .77934 L
.86478 .77812 L
.86533 .77697 L
.86575 .77589 L
.86605 .7749 L
.86624 .77392 L
.86634 .77301 L
.86635 .77205 L
.86627 .77119 L
.86613 .77033 L
.86597 .7695 L
.86579 .76874 L
.86562 .7681 L
.86546 .76754 L
.86533 .76707 L
.86523 .7667 L
.86519 .76642 L
.86519 .76625 L
.86524 .7662 L
Mistroke
.86535 .76628 L
.86554 .76645 L
.86579 .7667 L
.86612 .76694 L
.86657 .7671 L
.867 .76712 L
.86753 .76692 L
.86814 .76641 L
.86883 .76557 L
.86963 .76434 L
.8705 .76275 L
.8715 .76074 L
.87255 .75831 L
.87371 .75529 L
.87487 .75249 L
.87611 .74886 L
.8773 .74571 L
.87855 .74186 L
.87983 .73788 L
.88105 .73426 L
.88231 .73057 L
.8835 .72688 L
.88465 .72329 L
.88573 .71984 L
.88673 .71661 L
.88757 .71363 L
.88832 .71102 L
.88899 .70852 L
.88953 .70652 L
.88998 .70473 L
.89032 .7032 L
.89057 .70206 L
.89074 .70122 L
.89085 .70067 L
.89089 .70035 L
.89087 .70022 L
.8908 .7002 L
.89066 .70022 L
.89046 .70021 L
.89018 .70011 L
.88982 .69988 L
.88938 .69952 L
.88887 .69907 L
.88828 .69851 L
.8877 .69791 L
.88709 .6973 L
.88648 .69672 L
.8859 .6962 L
.88542 .69575 L
.88506 .6954 L
Mistroke
.88484 .69514 L
.88478 .69498 L
.88488 .69491 L
.88511 .6949 L
.88546 .69493 L
.88587 .69498 L
.88632 .69502 L
.88678 .695 L
.88722 .69495 L
.88762 .69487 L
.88796 .69477 L
.88822 .69466 L
.88838 .69458 L
.88844 .69455 L
.88842 .69456 L
.88833 .69464 L
.88818 .69479 L
.88799 .695 L
.88779 .69525 L
.88757 .69553 L
.88734 .69575 L
.88709 .696 L
.88682 .69626 L
.88652 .69654 L
.88619 .69684 L
.88585 .69717 L
.88549 .69753 L
.88515 .69793 L
.88481 .69832 L
.88448 .69874 L
.88415 .69917 L
.88383 .6996 L
.88352 .70005 L
.8832 .70048 L
.88292 .70083 L
.88267 .70108 L
.88249 .70122 L
.88238 .70127 L
.88236 .70121 L
.88242 .70103 L
.88257 .70072 L
.8828 .70025 L
.88307 .69966 L
.88343 .69891 L
.88388 .698 L
.88438 .6969 L
.885 .69555 L
.8857 .69395 L
.88649 .69208 L
.8874 .69004 L
Mistroke
.88837 .68768 L
.88944 .68512 L
.8905 .68234 L
.89158 .67925 L
.89268 .6763 L
.89372 .67305 L
.89479 .66983 L
.89578 .66647 L
.89684 .66318 L
.8978 .65977 L
.89892 .65634 L
.89997 .65295 L
.90113 .64942 L
.90243 .6459 L
.90366 .64232 L
.90496 .63863 L
.90646 .63499 L
.90765 .63131 L
.90917 .62753 L
.91063 .62372 L
.91198 .61997 L
.9135 .6161 L
.91497 .61222 L
.91631 .60836 L
.91757 .60458 L
.91874 .60087 L
.91974 .59717 L
.92073 .59348 L
.92165 .58988 L
.92252 .58626 L
.92346 .5825 L
.92438 .57911 L
.92537 .57551 L
.9263 .57192 L
.92723 .5681 L
.92804 .56466 L
.9288 .56099 L
.92944 .55711 L
.92995 .55352 L
.93037 .54965 L
.93069 .54576 L
.93092 .54153 L
.93103 .53774 L
.93104 .53358 L
.93094 .52927 L
.93076 .52505 L
.93053 .52078 L
.93028 .51649 L
.93003 .51204 L
.92979 .50798 L
Mistroke
.92957 .50359 L
.92937 .49921 L
.92916 .49495 L
.92891 .49082 L
.92862 .48644 L
.9283 .48209 L
.92795 .47763 L
.92759 .47345 L
.92724 .46955 L
.9269 .46583 L
.92658 .4621 L
.92627 .45885 L
.92598 .45575 L
.92566 .45245 L
.92535 .44991 L
.92503 .44754 L
.92471 .44526 L
.92438 .44307 L
.92405 .44098 L
.92371 .43908 L
.92335 .43713 L
.92297 .435 L
.9226 .43272 L
.92223 .43029 L
.92188 .42761 L
.92155 .42475 L
.92125 .42169 L
.92099 .41843 L
.92078 .41503 L
.9206 .41172 L
.92041 .40813 L
.92019 .40444 L
.91992 .40073 L
.91957 .39672 L
.91916 .3927 L
.91868 .38852 L
.91811 .38394 L
.91749 .37982 L
.91681 .37539 L
.91611 .37089 L
.9154 .36642 L
.91469 .36194 L
.914 .35764 L
.91334 .35357 L
.91271 .34966 L
.91211 .346 L
.91155 .34262 L
.91102 .3396 L
.91054 .33691 L
.9101 .33463 L
Mistroke
.90971 .33266 L
.90937 .33105 L
.90909 .32973 L
.90884 .32871 L
.90864 .32793 L
.90848 .32731 L
.90836 .32682 L
.90829 .32635 L
.90825 .3259 L
.90822 .32542 L
.90821 .32492 L
.9082 .32429 L
.90819 .32352 L
.90816 .32259 L
.90808 .32152 L
.90793 .32029 L
.90768 .31886 L
.90733 .3173 L
.90688 .31555 L
.90632 .31367 L
.90565 .31163 L
.90487 .30959 L
.90399 .30739 L
.90297 .30507 L
.90182 .3026 L
.90043 .29989 L
.89902 .29718 L
.89741 .2942 L
.89565 .29102 L
.89375 .28769 L
.89163 .28426 L
.88962 .28072 L
.88745 .27724 L
.88504 .27361 L
.88294 .2702 L
.88062 .26658 L
.87813 .26283 L
.87581 .25928 L
.87339 .25565 L
.87101 .25207 L
.86849 .24862 L
.86629 .24542 L
.86402 .24212 L
.86184 .23897 L
.85951 .23572 L
.85736 .2327 L
.85514 .22955 L
.85295 .22637 L
.8508 .22323 L
.84871 .2202 L
Mistroke
.8467 .21711 L
.84462 .21397 L
.84267 .21116 L
.84061 .208 L
.83847 .20479 L
.83642 .20182 L
.83422 .19891 L
.83188 .19562 L
.82975 .19256 L
.82742 .18946 L
.82513 .18632 L
.82279 .18329 L
.82039 .18014 L
.81814 .1772 L
.81586 .17419 L
.81365 .1712 L
.81149 .16836 L
.80948 .16555 L
.80751 .1629 L
.80555 .16016 L
.80366 .1577 L
.80169 .15511 L
.79972 .1526 L
.79777 .15004 L
.79578 .14756 L
.79385 .14512 L
.79195 .14269 L
.79017 .14064 L
.78852 .13874 L
.787 .13699 L
.78567 .1354 L
.78459 .13416 L
.78373 .13313 L
.78313 .13236 L
.78279 .13184 L
.78268 .13154 L
.78275 .13143 L
.78295 .13145 L
.78324 .13156 L
.78358 .1317 L
.78391 .13182 L
.78421 .13193 L
.78447 .13203 L
.78467 .13209 L
.78483 .13214 L
.78496 .13218 L
.78505 .13222 L
.78511 .13226 L
.78512 .13229 L
.78511 .1323 L
Mistroke
.78508 .13231 L
.78505 .13231 L
.78502 .13232 L
.78501 .1323 L
.78501 .13227 L
.785 .13221 L
.785 .13214 L
.785 .13208 L
.785 .13204 L
.785 .13203 L
.785 .13205 L
.78502 .13213 L
.78503 .13227 L
.78503 .13247 L
.78503 .13271 L
.78501 .13298 L
.78499 .13322 L
.78497 .13345 L
.78494 .13362 L
.78492 .13374 L
.7849 .1338 L
.78488 .1338 L
.78487 .13374 L
.78486 .13364 L
.78486 .13345 L
.78486 .13325 L
.78489 .133 L
.78495 .13275 L
.78503 .13252 L
.78512 .13232 L
.78518 .13217 L
.7852 .13207 L
.78517 .13197 L
.7851 .13189 L
.78498 .13183 L
.78479 .13181 L
.78451 .1318 L
.78411 .13181 L
.78358 .13186 L
.78292 .13198 L
.78212 .13218 L
.78121 .13247 L
.78022 .13285 L
.77917 .13331 L
.77812 .13385 L
.77717 .13444 L
.77623 .13509 L
.77543 .13574 L
.77476 .13638 L
.77422 .13693 L
Mistroke
.77381 .13736 L
.77354 .13763 L
.77341 .13769 L
.77338 .13754 L
.77343 .13718 L
.7735 .13661 L
.77353 .13585 L
.7734 .13489 L
.77305 .13367 L
.77246 .13235 L
.77161 .13081 L
.77054 .12911 L
.76922 .12737 L
.76764 .12546 L
.76591 .12372 L
.76406 .12193 L
.76205 .12019 L
.76001 .11861 L
.75752 .11693 L
.75539 .11557 L
.75322 .11425 L
.75084 .11296 L
.74828 .11171 L
.74552 .11048 L
.74241 .10921 L
.73956 .10789 L
.73628 .10663 L
.73284 .10521 L
.72919 .10366 L
.72534 .10218 L
.72125 .10048 L
.71657 .09865 L
.71253 .09675 L
.70763 .09464 L
.70333 .09286 L
.6996 .09105 L
.69515 .08916 L
.69123 .08748 L
.68712 .08578 L
.68341 .08437 L
.67955 .08282 L
.67612 .08152 L
.67254 .08025 L
.66967 .07901 L
.66683 .07787 L
.66404 .07681 L
.6619 .07587 L
.65999 .07508 L
.65838 .07446 L
.65716 .07395 L
Mistroke
.65623 .07354 L
.65558 .0732 L
.65518 .07293 L
.65501 .07272 L
.655 .07259 L
.6551 .07254 L
.65525 .07255 L
.6554 .07259 L
.65552 .07266 L
.6556 .07274 L
.65566 .07279 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.65569 .07281 L
.6557 .07281 L
.65574 .07282 L
.65583 .07284 L
.65595 .07289 L
.65607 .07296 L
.65613 .07302 L
.65611 .07305 L
.65598 .07303 L
.65572 .07293 L
.65532 .07276 L
.65476 .0725 L
Mistroke
.65406 .07217 L
.65321 .07178 L
.65223 .07134 L
.65124 .07088 L
.6501 .07043 L
.64899 .06997 L
.64785 .06953 L
.64673 .06911 L
.64572 .06874 L
.6449 .06844 L
.64429 .06823 L
.64386 .06811 L
.64359 .06806 L
.64339 .06808 L
.64322 .06813 L
.64301 .0682 L
.64271 .06825 L
.64231 .06829 L
.64184 .06831 L
.64132 .06832 L
.64081 .06832 L
.64034 .06829 L
.63988 .06823 L
.63944 .06813 L
.63899 .068 L
.63855 .06783 L
.63813 .06763 L
.63775 .06741 L
.63741 .06719 L
.63712 .06697 L
.63688 .06675 L
.63669 .06653 L
.63651 .06634 L
.63634 .06616 L
.63608 .06602 L
.63575 .06592 L
.63538 .06585 L
.63503 .06583 L
.63473 .06583 L
.63449 .06585 L
.63433 .06588 L
.63426 .06591 L
.63427 .06592 L
.63434 .06593 L
.63446 .06593 L
.63459 .06593 L
.63474 .06594 L
.6349 .06595 L
.63509 .06595 L
.6353 .06596 L
Mistroke
.63552 .06597 L
.63574 .06597 L
.63596 .06598 L
.63617 .06599 L
.63637 .06599 L
.63653 .066 L
.63667 .066 L
.63676 .06601 L
.63682 .06601 L
.63683 .06601 L
.63682 .06601 L
.63679 .06601 L
.63675 .06601 L
.63672 .06601 L
.63671 .06601 L
.63671 .06601 L
.63671 .066 L
.63674 .06599 L
.63679 .06594 L
.63685 .06587 L
.63691 .06578 L
.63694 .06571 L
.63692 .06569 L
.63684 .06574 L
.6367 .0659 L
.63649 .06619 L
.63621 .06661 L
.63584 .06711 L
.63539 .0677 L
.63485 .06837 L
.63428 .06903 L
.63368 .06975 L
.63311 .07035 L
.6326 .07085 L
.63219 .07125 L
.6319 .07152 L
.63175 .07164 L
.63174 .07165 L
.63183 .07155 L
.63198 .07136 L
.63213 .07111 L
.63234 .07085 L
.63259 .07066 L
.63292 .07056 L
.63336 .07059 L
.63398 .07086 L
.63482 .07111 L
.63588 .07147 L
.63717 .07197 L
.63863 .07258 L
Mistroke
.64037 .07326 L
.64224 .07394 L
.64419 .0746 L
.64648 .07522 L
.64877 .07577 L
.65142 .07625 L
.65379 .0767 L
.65625 .07715 L
.65864 .07761 L
.66092 .07808 L
.66303 .07856 L
.665 .07905 L
.66682 .07957 L
.66854 .0801 L
.6701 .08066 L
.67152 .08125 L
.67283 .0818 L
.67399 .08231 L
.67496 .08276 L
.67574 .08316 L
.67632 .08348 L
.67672 .08373 L
.67697 .08389 L
.67709 .08399 L
.67712 .08401 L
.67707 .08399 L
.67698 .08392 L
.67688 .08383 L
.67678 .08374 L
.67668 .08365 L
.6766 .08359 L
.67654 .08355 L
.67653 .08357 L
.67657 .08366 L
.67668 .08385 L
.67685 .08415 L
.67707 .08452 L
.67733 .08492 L
.67762 .08531 L
.67791 .08566 L
.67822 .08595 L
.67854 .08618 L
.67888 .08635 L
.67918 .08646 L
.67943 .08649 L
.67959 .08642 L
.67965 .08622 L
.67959 .08588 L
.67942 .08542 L
.67911 .08485 L
Mistroke
.67865 .08421 L
.67799 .08355 L
.67711 .08286 L
.67598 .08216 L
.67457 .08141 L
.67294 .08061 L
.67098 .07972 L
.66864 .07871 L
.6663 .07762 L
.66339 .07639 L
.66041 .07501 L
.65722 .07369 L
.6533 .07201 L
.64998 .0706 L
.64613 .06913 L
.64215 .0675 L
.63772 .06574 L
.63365 .06419 L
.62937 .06268 L
.62459 .06086 L
.62057 .05939 L
.61573 .05791 L
.61158 .05633 L
.6065 .05481 L
.60254 .05325 L
.59804 .05172 L
.59401 .05053 L
.59 .04935 L
.5864 .04826 L
.58317 .04741 L
.58025 .04664 L
.57763 .04598 L
.57526 .04546 L
.57365 .04511 L
.57224 .0449 L
.57115 .0448 L
.57035 .0448 L
.56984 .04485 L
.56957 .04494 L
.56948 .04502 L
.56954 .04509 L
.56971 .04514 L
.56996 .04515 L
.57027 .04516 L
.57058 .04517 L
.57084 .04518 L
.57107 .04519 L
.5713 .04519 L
.57152 .0452 L
.57175 .04521 L
Mistroke
.57197 .04522 L
.57217 .04522 L
.57234 .04523 L
.57248 .04523 L
.57257 .04524 L
.57263 .04524 L
.57265 .04524 L
.57263 .04524 L
.5726 .04524 L
.57256 .04524 L
.57253 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
Mistroke
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57252 .04523 L
.57254 .04523 L
.5726 .04524 L
.57266 .04524 L
.57273 .04524 L
.57276 .04524 L
.57276 .04524 L
.5727 .04524 L
.57261 .04524 L
.57246 .04523 L
.57223 .04522 L
.57191 .04521 L
.57148 .0452 L
.57095 .04518 L
.57031 .04516 L
.56958 .04514 L
.56877 .04511 L
.56788 .04508 L
.56689 .04505 L
.56581 .04501 L
.56465 .04497 L
.56346 .04493 L
.56222 .04489 L
.56096 .04485 L
.55969 .04481 L
.55849 .04477 L
.55728 .04473 L
.55605 .04469 L
.55472 .04465 L
.55344 .04461 L
.55209 .04457 L
.55065 .04452 L
.54914 .04447 L
.54757 .04442 L
.54604 .04438 L
.54482 .04433 L
.54358 .04429 L
.54242 .04426 L
.54154 .04424 L
Mistroke
.5407 .04423 L
.53992 .04424 L
.53921 .04425 L
.53856 .04423 L
.53787 .04418 L
.53704 .04408 L
.53597 .04394 L
.53457 .04377 L
.53286 .04357 L
.53052 .04337 L
.52755 .04318 L
.52476 .04299 L
.52105 .0428 L
.51654 .04264 L
.51267 .0425 L
.50794 .04238 L
.5033 .04228 L
.4993 .04222 L
.49487 .0422 L
.49121 .04222 L
.48752 .04226 L
.4847 .04232 L
.48218 .04237 L
.4801 .04239 L
.47858 .04239 L
.47734 .04235 L
.47639 .0423 L
.47572 .04224 L
.4752 .0422 L
.47473 .04217 L
.47427 .04216 L
.4738 .04215 L
.4733 .04213 L
.47276 .04212 L
.47221 .0421 L
.47164 .04208 L
.47103 .04206 L
.47042 .04204 L
.46989 .04203 L
.46947 .04202 L
.46917 .04201 L
.46901 .042 L
.46896 .042 L
.469 .042 L
.4691 .042 L
.46922 .04201 L
.46932 .04201 L
.46941 .04201 L
.46949 .04202 L
.46957 .04202 L
Mistroke
.46966 .04202 L
.46975 .04202 L
.46981 .04203 L
.46979 .04203 L
.46966 .04202 L
.46939 .04201 L
.4689 .042 L
.46815 .04198 L
.46712 .04195 L
.46584 .04191 L
.46431 .04187 L
.46253 .04181 L
.46054 .04175 L
.45868 .04169 L
.45662 .04163 L
.45473 .04157 L
.45288 .04151 L
.45115 .04146 L
.44977 .04141 L
.44865 .04136 L
.44779 .04128 L
.4472 .0412 L
.44682 .04113 L
.4466 .04109 L
.44648 .04111 L
.4464 .0412 L
.44627 .04137 L
.44609 .04162 L
.44585 .04194 L
.44553 .04231 L
.4451 .04271 L
.44459 .04314 L
.44403 .04356 L
.44345 .04397 L
.44286 .04438 L
.4423 .04476 L
.44179 .04509 L
.44139 .04535 L
.44112 .04554 L
.44096 .04564 L
.44089 .04567 L
.44086 .04566 L
.44085 .04562 L
.4408 .04556 L
.44068 .04549 L
.44046 .04543 L
.44008 .04536 L
.43947 .04529 L
.43857 .0452 L
.43733 .0451 L
Mistroke
.43574 .045 L
.43377 .04491 L
.43133 .04481 L
.42862 .04472 L
.4254 .04462 L
.42215 .04453 L
.41865 .04441 L
.41497 .04428 L
.41097 .04415 L
.4075 .04403 L
.40366 .04393 L
.40003 .04387 L
.3964 .04386 L
.39311 .0439 L
.38963 .04403 L
.38645 .04424 L
.3832 .04456 L
.38012 .04502 L
.37691 .04563 L
.37412 .04631 L
.37144 .04707 L
.36879 .04788 L
.36651 .04875 L
.36426 .04963 L
.36238 .05055 L
.36063 .05147 L
.35914 .05232 L
.35786 .05314 L
.35679 .05392 L
.35593 .05464 L
.35529 .05529 L
.35481 .05588 L
.35445 .05637 L
.35416 .05682 L
.35393 .05719 L
.35371 .05751 L
.3535 .05777 L
.35334 .05797 L
.35324 .05812 L
.35321 .05821 L
.35323 .05823 L
.35328 .0582 L
.35335 .05814 L
.3534 .05807 L
.35343 .05802 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
Mistroke
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35345 .05799 L
.35348 .05799 L
.35354 .05799 L
.35362 .05799 L
.35374 .05798 L
.35389 .05792 L
.35403 .05783 L
.35412 .0577 L
.35412 .05756 L
.354 .05744 L
.35369 .05737 L
.35315 .0574 L
.35232 .05758 L
.35115 .05797 L
.34964 .0586 L
.3477 .05951 L
.34527 .0607 L
.34269 .06205 L
.33959 .06359 L
.3363 .06544 L
.33265 .06742 L
.32896 .06957 L
.32485 .07196 L
.3211 .07414 L
.31713 .07654 L
.31302 .07879 L
.30937 .08094 L
.30547 .08318 L
.30211 .0851 L
.29864 .08708 L
.29567 .08884 L
.29277 .09061 L
.29025 .09222 L
.28803 .09374 L
.28616 .09506 L
.28458 .09624 L
.28336 .09724 L
.28245 .098 L
.28177 .09862 L
.28127 .09912 L
Mistroke
.28087 .09954 L
.28049 .09993 L
.28007 .10032 L
.2796 .10075 L
.27909 .10122 L
.27851 .10174 L
.27787 .10229 L
.27725 .10281 L
.27662 .10341 L
.27609 .10398 L
.27563 .10454 L
.27524 .10505 L
.27492 .10548 L
.27468 .10579 L
.27446 .10595 L
.27415 .10601 L
.27367 .10603 L
.27293 .10607 L
.27185 .10619 L
.27033 .10652 L
.26834 .10711 L
.2663 .10804 L
.26346 .10919 L
.26065 .11063 L
.2572 .11245 L
.25351 .11455 L
.24949 .11684 L
.24575 .11913 L
.24106 .1217 L
.23718 .12439 L
.2324 .12736 L
.22875 .13007 L
.22455 .133 L
.22062 .13584 L
.21651 .13877 L
.21297 .1414 L
.20922 .14406 L
.20633 .14645 L
.20353 .14876 L
.20112 .15078 L
.1991 .15256 L
.19746 .15414 L
.19625 .15539 L
.19535 .15638 L
.19474 .1571 L
.19436 .15756 L
.19418 .15782 L
.19413 .15791 L
.19418 .15789 L
.19428 .1578 L
Mistroke
.1944 .15767 L
.19454 .15752 L
.19465 .1574 L
.19473 .15734 L
.19476 .15731 L
.19477 .1573 L
.19477 .1573 L
.19477 .1573 L
.19477 .1573 L
.19477 .15729 L
.1948 .15725 L
.19485 .15717 L
.19493 .15706 L
.195 .15694 L
.19504 .15686 L
.19501 .15684 L
.19491 .15694 L
.19471 .15719 L
.19443 .15763 L
.19406 .15824 L
.19363 .15901 L
.19315 .15993 L
.19265 .16096 L
.19215 .16198 L
.19166 .16305 L
.19118 .16415 L
.19073 .16523 L
.19034 .16619 L
.19002 .16704 L
.1898 .16773 L
.18969 .16824 L
.18969 .16853 L
.18979 .16859 L
.18997 .16847 L
.19016 .16824 L
.19033 .16799 L
.19044 .1678 L
.19046 .16771 L
.19037 .1678 L
.19013 .16811 L
.18972 .16869 L
.18908 .16959 L
.18817 .17087 L
.18696 .17255 L
.18559 .1744 L
.1839 .1768 L
.182 .1794 L
.17981 .18252 L
.17758 .18561 L
.17527 .18906 L
Mistroke
.17277 .19288 L
.17036 .19638 L
.16782 .20022 L
.16535 .20433 L
.16295 .20808 L
.16052 .21208 L
.15802 .21636 L
.15562 .22037 L
.15325 .22431 L
.15074 .2288 L
.14837 .23256 L
.14581 .23693 L
.14335 .24073 L
.1408 .24485 L
.13817 .24906 L
.13566 .25293 L
.13314 .25682 L
.13068 .26061 L
.12822 .26446 L
.12592 .26798 L
.12363 .27159 L
.12132 .2754 L
.11904 .27908 L
.11688 .2825 L
.11461 .28636 L
.11236 .29011 L
.11015 .29352 L
.10791 .29729 L
.10592 .30069 L
.10397 .30413 L
.10217 .30746 L
.10057 .31044 L
.09909 .31327 L
.09791 .31563 L
.09692 .31777 L
.09611 .31959 L
.09552 .32101 L
.09513 .32211 L
.09495 .32288 L
.09493 .32334 L
.09503 .32353 L
.09518 .32351 L
.09535 .32334 L
.09549 .32309 L
.09557 .32283 L
.09557 .32263 L
.09548 .32256 L
.09532 .32269 L
.09508 .32309 L
.09478 .32379 L
Mistroke
.09438 .32492 L
.09389 .3265 L
.0933 .32854 L
.09261 .33124 L
.09183 .33422 L
.091 .33794 L
.09014 .34238 L
.08926 .34676 L
.08842 .35209 L
.08762 .35689 L
.08689 .36239 L
.08625 .36816 L
.08569 .37381 L
.08521 .3785 L
.08483 .3835 L
.08453 .3886 L
.08433 .39273 L
.08422 .39597 L
.08416 .39903 L
.08415 .40176 L
.08417 .40369 L
.0842 .40519 L
.08423 .40623 L
.08425 .40689 L
.08426 .40722 L
Mfstroke
.08412 .41085 m
.08422 .41102 L
.08438 .4112 L
.08458 .41138 L
.08483 .41155 L
.08513 .4117 L
.08548 .41183 L
.08589 .41194 L
.08638 .41206 L
.08698 .41222 L
.08769 .41241 L
.08848 .41267 L
.08934 .413 L
.09027 .41343 L
.09123 .414 L
.09212 .41471 L
.09304 .41559 L
.0939 .41658 L
.09478 .41777 L
.09551 .41919 L
.09616 .42076 L
.09669 .42255 L
.09709 .42456 L
.09732 .42684 L
.09738 .42932 L
.09727 .43206 L
.09701 .43499 L
.09659 .43819 L
.09603 .44119 L
.09532 .44444 L
.09445 .44791 L
.09335 .45127 L
.092 .45478 L
.09051 .45848 L
.08874 .46215 L
.08675 .4656 L
.08434 .46932 L
.08251 .47302 L
.08008 .47703 L
.07828 .48072 L
.07594 .48466 L
.07407 .48879 L
.07243 .49301 L
.07099 .49715 L
.06969 .50141 L
.06866 .505 L
.06793 .50857 L
.06748 .51166 L
.06726 .51435 L
.06721 .5165 L
Mistroke
.06725 .51812 L
.06733 .5193 L
.06743 .5201 L
.06745 .52061 L
.0674 .52093 L
.06735 .52116 L
.06735 .52148 L
.06741 .52201 L
.06753 .52286 L
.0677 .52407 L
.06794 .5258 L
.06824 .52818 L
.06863 .53107 L
.0691 .53463 L
.06967 .53865 L
.07035 .54308 L
.07106 .54815 L
.07183 .55286 L
.0726 .55854 L
.07331 .56352 L
.07401 .5691 L
.0747 .57511 L
.07537 .58021 L
.07608 .58641 L
.07679 .59149 L
.07753 .59739 L
.07834 .60269 L
.0792 .60793 L
.0801 .6133 L
.08099 .61842 L
.08159 .62347 L
.08248 .62911 L
.08334 .63368 L
.08422 .63879 L
.0851 .64364 L
.08591 .64804 L
.08662 .65252 L
.08718 .65606 L
.08759 .65941 L
.08789 .66263 L
.08808 .66503 L
.0882 .66719 L
.0883 .66912 L
.08841 .67071 L
.08857 .67203 L
.08877 .67311 L
.08903 .67408 L
.08933 .67503 L
.08969 .67599 L
.09008 .67709 L
Mistroke
.09051 .67838 L
.09097 .6799 L
.09144 .68157 L
.09187 .68338 L
.09226 .68521 L
.09259 .68698 L
.09286 .68859 L
.09306 .68998 L
.09318 .69119 L
.09324 .69221 L
.09324 .69301 L
.09321 .69358 L
.09316 .69392 L
.09309 .69404 L
.093 .69399 L
.09293 .69379 L
.09288 .69348 L
.09287 .69312 L
.09289 .69282 L
.09295 .69266 L
.09305 .69272 L
.09321 .69304 L
.09344 .69366 L
.09375 .69461 L
.09413 .69594 L
.09458 .6976 L
.0951 .69967 L
.09571 .7021 L
.09638 .70443 L
.09708 .70743 L
.09782 .71021 L
.09856 .71324 L
.09928 .71637 L
.09995 .71924 L
.10056 .72197 L
.10111 .72428 L
.10158 .72629 L
.10197 .72789 L
.10229 .72921 L
.10254 .73025 L
.10272 .73107 L
.10282 .73169 L
.10287 .73217 L
.10289 .7325 L
.10287 .73276 L
.10283 .73297 L
.10278 .7332 L
.10274 .73346 L
.1027 .73378 L
.10267 .7342 L
Mistroke
.10266 .73466 L
.10265 .73509 L
.10265 .73543 L
.10264 .73574 L
.10264 .73597 L
.10264 .73614 L
.10263 .73625 L
.10263 .73631 L
.10263 .73632 L
.10264 .73628 L
.10264 .7362 L
.10264 .73609 L
.10264 .73595 L
.10264 .73578 L
.10265 .73559 L
.10265 .73539 L
.10265 .73519 L
.10264 .73497 L
.10261 .73476 L
.10257 .73456 L
.10251 .73437 L
.10245 .73422 L
.10239 .7341 L
.10237 .73399 L
.10239 .73397 L
.10247 .73404 L
.10262 .73423 L
.10287 .73453 L
.10321 .73495 L
.10368 .73547 L
.1043 .73611 L
.10509 .73688 L
.10608 .7378 L
.10724 .73888 L
.10864 .74017 L
.11017 .74155 L
.11198 .74314 L
.11392 .74501 L
.11612 .74713 L
.11846 .7496 L
.12125 .75234 L
.12417 .75536 L
.12691 .75862 L
.12995 .76209 L
.13309 .76557 L
.13626 .76929 L
.1395 .77313 L
.14289 .77682 L
.14633 .78074 L
.14996 .78466 L
Mistroke
.1533 .78838 L
.15706 .79215 L
.16064 .79597 L
.16442 .79991 L
.16821 .80341 L
.17204 .80719 L
.17613 .81095 L
.18001 .8149 L
.18408 .81873 L
.18814 .82265 L
.19236 .82666 L
.19642 .83053 L
.20051 .83434 L
.20478 .83817 L
.2088 .84197 L
.21297 .84552 L
.21701 .84917 L
.22109 .85293 L
.22497 .85624 L
.22888 .85979 L
.23236 .86286 L
.2357 .86573 L
.23855 .86837 L
.24118 .87071 L
.24338 .87278 L
.24512 .87463 L
.24647 .87597 L
.24739 .87701 L
.24791 .87775 L
.2481 .87819 L
.24802 .87834 L
.24775 .87821 L
.24735 .87793 L
.24696 .87761 L
.24668 .87734 L
.24659 .87719 L
.24677 .87724 L
.24725 .8775 L
.24804 .87796 L
.24914 .87868 L
.25057 .87956 L
.25232 .88059 L
.25419 .8817 L
.25649 .88294 L
.25898 .88436 L
.26162 .88579 L
.26462 .88736 L
.26775 .88897 L
.27116 .89063 L
.27464 .89233 L
Mistroke
.27862 .89388 L
.28251 .89555 L
.28619 .89718 L
.2903 .89884 L
.29485 .90054 L
.29884 .90223 L
.3036 .90391 L
.30788 .9056 L
.31246 .90719 L
.31702 .90877 L
.32145 .91033 L
.32583 .91187 L
.33026 .91337 L
.33471 .9149 L
.33901 .91636 L
.34341 .91786 L
.34799 .91934 L
.35218 .92088 L
.35669 .92232 L
.3612 .92391 L
.36562 .92533 L
.37015 .9268 L
.37472 .92828 L
.37928 .92981 L
.38383 .93135 L
.38824 .9328 L
.39271 .93412 L
.39712 .93547 L
.40157 .93686 L
.406 .9382 L
.41005 .93951 L
.41409 .9408 L
.41824 .94212 L
.42224 .94341 L
.42609 .94465 L
.43003 .94587 L
.43382 .94701 L
.43765 .94816 L
.44139 .94916 L
.44525 .95007 L
.44895 .95086 L
.45254 .9515 L
.4561 .952 L
.45955 .95239 L
.46266 .95266 L
.46566 .95279 L
.46827 .95281 L
.47065 .95272 L
.47275 .95255 L
.47446 .95233 L
Mistroke
.47588 .95212 L
.47697 .95194 L
.47774 .95178 L
.47822 .95166 L
.4785 .95158 L
.47864 .95155 L
.47871 .95151 L
.47877 .95148 L
.47883 .95146 L
.47891 .95143 L
.47905 .9514 L
.47924 .95138 L
.47946 .95135 L
.4797 .95133 L
.47993 .95132 L
.48011 .95132 L
.48022 .95134 L
.48023 .95136 L
.48011 .95139 L
.47986 .95143 L
.47949 .95147 L
.47908 .95151 L
.47864 .95154 L
.47819 .95157 L
.47776 .95159 L
.47739 .95162 L
.47708 .95167 L
.47685 .95175 L
.47664 .9518 L
.47644 .95181 L
.47624 .95176 L
.47608 .95168 L
.47597 .95156 L
.4759 .95143 L
.47585 .95129 L
.47581 .95117 L
.47581 .95108 L
.47589 .95101 L
.47617 .95094 L
.47671 .95087 L
.47757 .95078 L
.47876 .95069 L
.48039 .9506 L
.48239 .95053 L
.4849 .95048 L
.48782 .95043 L
.4911 .95034 L
.49492 .95017 L
.49912 .94988 L
.5037 .94943 L
Mistroke
.50854 .94881 L
.51372 .94801 L
.5191 .94708 L
.52438 .94609 L
.5301 .94507 L
.53546 .94402 L
.54136 .94298 L
.54686 .94196 L
.55274 .94094 L
.5582 .93996 L
.56412 .93901 L
.56989 .93813 L
.57564 .93731 L
.58143 .93653 L
.58668 .93578 L
.59227 .93502 L
.59757 .93424 L
.60304 .93338 L
.60815 .93259 L
.61344 .93168 L
.61807 .93069 L
.62294 .92973 L
.62756 .92875 L
.63235 .92778 L
.6363 .92684 L
.6402 .92597 L
.64405 .92518 L
.64765 .92447 L
.65114 .92382 L
.65468 .92321 L
.65778 .92262 L
.66071 .92202 L
.66365 .92137 L
.6665 .92062 L
.66936 .91976 L
.67199 .91877 L
.67474 .91767 L
.67757 .91645 L
.68057 .9151 L
.68376 .91354 L
.68708 .91176 L
.69067 .90989 L
.69428 .90777 L
.69824 .90549 L
.70216 .90304 L
.7061 .90061 L
.71002 .89794 L
.71401 .89539 L
.7178 .89286 L
.72179 .89005 L
Mistroke
.72573 .88722 L
.72959 .88472 L
.73326 .88203 L
.73699 .87937 L
.74073 .87663 L
.74445 .87393 L
.74838 .87102 L
.75192 .86842 L
.75572 .86564 L
.75967 .86284 L
.76346 .86001 L
.76737 .85722 L
.7713 .85437 L
.77537 .85139 L
.77909 .84862 L
.78286 .84568 L
.78667 .84286 L
.79005 .8401 L
.79354 .83741 L
.79697 .83474 L
.80046 .83211 L
.80385 .82944 L
.80736 .8268 L
.8108 .82412 L
.81423 .82138 L
.81779 .81869 L
.82121 .81595 L
.82459 .81331 L
.82794 .81072 L
.83111 .80813 L
.8342 .80566 L
.83717 .80336 L
.83978 .80115 L
.84222 .79908 L
.84433 .79716 L
.84615 .79548 L
.84769 .794 L
.84893 .79276 L
.84995 .79176 L
.85075 .79097 L
.85142 .79035 L
.85195 .78987 L
.85237 .78948 L
.8527 .78914 L
.85294 .78883 L
.85314 .78851 L
.85325 .78817 L
.85333 .78777 L
.8534 .7873 L
.85348 .78671 L
Mistroke
.85359 .78603 L
.85367 .78533 L
.85371 .78467 L
.85369 .78409 L
.85363 .78361 L
.85355 .78331 L
.85345 .78319 L
.85337 .78326 L
.85333 .78348 L
.85332 .78383 L
.8533 .78426 L
.85326 .78481 L
.85321 .78534 L
.85314 .78585 L
.85308 .78639 L
.85304 .78684 L
.85302 .78718 L
.85302 .7874 L
.85304 .78753 L
.85305 .78761 L
.85303 .78767 L
.85296 .78772 L
.85286 .78777 L
.85277 .78784 L
.85272 .78794 L
.85276 .78805 L
.85295 .78809 L
.8533 .78803 L
.85389 .78779 L
.85452 .78738 L
.8554 .78667 L
.85646 .78563 L
.85765 .78419 L
.85911 .78232 L
.86074 .77994 L
.86257 .77713 L
.86455 .77387 L
.86664 .77003 L
.86873 .76626 L
.87084 .76192 L
.87287 .75728 L
.87479 .75281 L
.87656 .74811 L
.8782 .74353 L
.87969 .73921 L
.88099 .73519 L
.88214 .73167 L
.88312 .72829 L
.88393 .72563 L
.8846 .72307 L
Mistroke
.88516 .72091 L
.88564 .71889 L
.88606 .71699 L
.88643 .7152 L
.8868 .71348 L
.88724 .71164 L
.8878 .70953 L
.88849 .70713 L
.88935 .70438 L
.8903 .70104 L
.89144 .69744 L
.89266 .69326 L
.89399 .68896 L
.89549 .68403 L
.89694 .67942 L
.89868 .67428 L
.90036 .66851 L
.90197 .66341 L
.90378 .65775 L
.90545 .65198 L
.90721 .64587 L
.90882 .6404 L
.91043 .6346 L
.91205 .62842 L
.91341 .62322 L
.91483 .61765 L
.91628 .61208 L
.9176 .60653 L
.91898 .60102 L
.92027 .59563 L
.92151 .59066 L
.92268 .58588 L
.9238 .58138 L
.92481 .57742 L
.9257 .57389 L
.9265 .57077 L
.92716 .5681 L
.92767 .56604 L
.92805 .56449 L
.92828 .56337 L
.92839 .5627 L
.92841 .56243 L
.92835 .56246 L
.92823 .5627 L
.92808 .56304 L
.92793 .56341 L
.92779 .56376 L
.92769 .56403 L
.92762 .56423 L
.92758 .56432 L
Mistroke
.92759 .56429 L
.92762 .56422 L
.92767 .56411 L
.92771 .56398 L
.92773 .56386 L
.92773 .56374 L
.92771 .56361 L
.92768 .56346 L
.92766 .56331 L
.92765 .56313 L
.92766 .56291 L
.92771 .56258 L
.92779 .56213 L
.92791 .56159 L
.92807 .56096 L
.92826 .56026 L
.9285 .55953 L
.92876 .55879 L
.92905 .55803 L
.92936 .55727 L
.92968 .55654 L
.92998 .55584 L
.93026 .55519 L
.9305 .55461 L
.93071 .55411 L
.93087 .55374 L
.931 .55348 L
.93108 .55331 L
.93113 .55323 L
.93117 .55319 L
.93118 .55317 L
.93119 .55316 L
.93118 .55317 L
.93116 .55318 L
.93114 .55317 L
.93112 .55318 L
.93111 .55319 L
.93111 .55322 L
.93111 .55323 L
.93111 .55324 L
.93111 .55325 L
.93111 .55328 L
.93111 .55331 L
.93111 .55334 L
.93111 .55336 L
.93111 .55335 L
.93111 .5533 L
.93111 .55322 L
.9311 .5531 L
.9311 .55294 L
Mistroke
.93109 .55277 L
.93109 .5526 L
.93107 .5525 L
.93105 .5525 L
.93102 .55254 L
.931 .55259 L
.93099 .55261 L
.931 .55254 L
.93103 .55232 L
.9311 .55187 L
.93119 .55108 L
.9313 .54978 L
.93142 .54787 L
.93154 .54536 L
.93164 .54248 L
.93172 .53911 L
.93176 .53522 L
.93177 .53092 L
.93175 .5264 L
.93166 .52147 L
.9315 .51704 L
.93126 .51228 L
.93095 .50766 L
.93059 .50328 L
.93016 .49918 L
.92967 .49491 L
.92922 .49069 L
.92874 .48624 L
.92826 .48189 L
.92782 .47771 L
.92738 .47328 L
.927 .46862 L
.92666 .46471 L
.92638 .46056 L
.92613 .45671 L
.92594 .45366 L
.9258 .45068 L
.9257 .44846 L
.92562 .44659 L
.92555 .44519 L
.92546 .44425 L
.92534 .44357 L
.92516 .44287 L
.92491 .442 L
.9246 .44083 L
.92425 .4393 L
.92386 .43721 L
.92342 .43467 L
.92297 .43156 L
.92253 .42799 L
Mistroke
.92211 .42421 L
.92171 .42012 L
.92132 .41584 L
.92095 .41197 L
.92059 .40775 L
.92023 .40348 L
.91985 .39931 L
.91943 .39528 L
.91894 .39108 L
.91839 .38682 L
.9178 .38232 L
.91722 .37848 L
.91657 .37437 L
.91591 .37033 L
.91525 .36636 L
.91462 .36266 L
.91406 .35908 L
.91358 .35589 L
.91319 .35321 L
.91286 .35079 L
.91263 .34879 L
.91249 .34721 L
.91243 .34609 L
.91244 .34541 L
.91249 .34501 L
.91255 .34483 L
.91261 .3448 L
.91266 .34485 L
.91267 .34488 L
.91264 .34481 L
.91256 .34458 L
.91243 .34416 L
.91226 .34353 L
.91207 .34267 L
.91185 .34158 L
.91163 .34032 L
.91139 .33887 L
.91114 .33734 L
.91092 .33587 L
.9107 .33433 L
.91051 .33291 L
.91035 .33151 L
.91023 .33026 L
.91016 .32917 L
.91013 .32829 L
.91013 .32765 L
.91015 .32721 L
.91018 .32691 L
.91019 .32665 L
.91018 .32635 L
Mistroke
.91014 .32591 L
.91005 .32528 L
.9099 .32443 L
.90968 .32335 L
.90939 .32208 L
.90902 .32064 L
.90859 .31916 L
.90811 .31757 L
.90757 .31594 L
.90701 .3143 L
.90645 .31267 L
.9059 .31115 L
.90539 .30971 L
.90492 .30845 L
.90453 .30744 L
.90421 .30667 L
.90396 .30614 L
.90378 .30583 L
.90366 .30569 L
.9036 .3057 L
.90359 .30582 L
.90362 .30604 L
.90367 .3063 L
.90372 .30657 L
.90377 .30681 L
.90381 .30701 L
.90383 .30713 L
.90384 .30719 L
.90384 .30721 L
.90384 .30718 L
.90384 .30712 L
.90384 .30707 L
.90383 .30695 L
.90382 .30681 L
.90381 .30664 L
.9038 .30647 L
.90379 .3063 L
.90377 .30616 L
.90376 .30604 L
.90376 .30596 L
.90375 .30592 L
.90376 .30594 L
.90376 .30601 L
.90377 .3061 L
.90377 .30619 L
.90377 .30628 L
.90378 .30637 L
.90378 .30647 L
.90379 .30657 L
.90379 .30665 L
Mistroke
.90379 .30671 L
.9038 .30675 L
.9038 .30677 L
.9038 .30676 L
.90379 .30672 L
.90379 .30667 L
.90379 .30659 L
.90378 .3065 L
.90378 .3064 L
.90378 .3063 L
.90377 .3062 L
.90377 .30613 L
.90377 .30609 L
.90377 .30607 L
.90378 .30605 L
.90379 .30602 L
.9038 .306 L
.90381 .306 L
.90382 .30602 L
.90383 .30606 L
.90382 .30613 L
.9038 .30623 L
.90376 .30635 L
.90371 .30648 L
.90364 .30659 L
.90355 .30667 L
.90343 .3067 L
.90326 .30668 L
.90304 .30662 L
.90275 .30653 L
.90238 .30637 L
.90192 .30614 L
.90136 .30586 L
.9007 .30552 L
.9 .30517 L
.89924 .30484 L
.89846 .30455 L
.89774 .3043 L
.89709 .30411 L
.89656 .30399 L
.89617 .30393 L
.89594 .30391 L
.89586 .30383 L
.89591 .30371 L
.89609 .30351 L
.89632 .30318 L
.89659 .30264 L
.89681 .30188 L
.89696 .30086 L
.89695 .29953 L
Mistroke
.89673 .29786 L
.89631 .29599 L
.89566 .29376 L
.89472 .29122 L
.89351 .28836 L
.89202 .28534 L
.8902 .28164 L
.88834 .27845 L
.88615 .27477 L
.88382 .27093 L
.88147 .2669 L
.87878 .26258 L
.87638 .25864 L
.87372 .2545 L
.87084 .24994 L
.86826 .24615 L
.86549 .24198 L
.86274 .2378 L
.85979 .23392 L
.85737 .22988 L
.85479 .22632 L
.85236 .22277 L
.8499 .21944 L
.84766 .21622 L
.84546 .21307 L
.84327 .21008 L
.8411 .20706 L
.83889 .20405 L
.83666 .20097 L
.83438 .19785 L
.83197 .19443 L
.82958 .19121 L
.82701 .18772 L
.82444 .18454 L
.82153 .18082 L
.81886 .17716 L
.81617 .17343 L
.81352 .16994 L
.81069 .16614 L
.80795 .16245 L
.80518 .15879 L
.80256 .15523 L
.79999 .15186 L
.79755 .14862 L
.79539 .14563 L
.79333 .14285 L
.79146 .1403 L
.78982 .13809 L
.78841 .13622 L
.78724 .13466 L
Mistroke
.78635 .13349 L
.78565 .1326 L
.78514 .13199 L
.7848 .13163 L
.78461 .13146 L
.78454 .13145 L
.78456 .13153 L
.78462 .13165 L
.78471 .13179 L
.78481 .13192 L
.7849 .13201 L
.78496 .13207 L
.78499 .13209 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.785 .1321 L
.78501 .13212 L
.78503 .13216 L
.78507 .13221 L
.7851 .13224 L
.78511 .13226 L
.7851 .13225 L
.78506 .13219 L
.78498 .13207 L
.78487 .13192 L
.78473 .13172 L
.78458 .13148 L
.78446 .13122 L
.78435 .13095 L
.78424 .13067 L
.78407 .13035 L
.78382 .12998 L
.78348 .12957 L
.78305 .12911 L
.7825 .12863 L
.78185 .12822 L
.78112 .12782 L
.78034 .12743 L
.77955 .12704 L
.77888 .12665 L
.77812 .12626 L
.77739 .12587 L
.77662 .1255 L
.77583 .12518 L
.77507 .12498 L
Mistroke
.77437 .12492 L
.7737 .12498 L
.77299 .12521 L
.77219 .12554 L
.77123 .12595 L
.77005 .12641 L
.76879 .12696 L
.76728 .12755 L
.76546 .12818 L
.76347 .12887 L
.76143 .12959 L
.75911 .13041 L
.75679 .13131 L
.75425 .13227 L
.75199 .13328 L
.74956 .13428 L
.74708 .13535 L
.74504 .13645 L
.74297 .13761 L
.7409 .13881 L
.73896 .14 L
.73712 .14134 L
.73542 .1426 L
.73375 .14388 L
.73225 .1451 L
.73086 .1462 L
.7296 .14714 L
.72852 .14788 L
.72769 .14835 L
.727 .14861 L
.72645 .14867 L
.72606 .14861 L
.72584 .14845 L
.7258 .14822 L
.72593 .14799 L
.72624 .14777 L
.72668 .14765 L
.72725 .14769 L
.72794 .14795 L
.72872 .14852 L
.72957 .14948 L
.73053 .15072 L
.73159 .15247 L
.73282 .15442 L
.73423 .15681 L
.73565 .15937 L
.73727 .16224 L
.73899 .16495 L
.74078 .16802 L
.74268 .17085 L
Mistroke
.74463 .17391 L
.7466 .17694 L
.7487 .18005 L
.7508 .18328 L
.75287 .18641 L
.75505 .18973 L
.75707 .19309 L
.75915 .19649 L
.76127 .20015 L
.76321 .20328 L
.76515 .20651 L
.76707 .20974 L
.76876 .21242 L
.77039 .21504 L
.77182 .21729 L
.77305 .21934 L
.77406 .22086 L
.77484 .22217 L
.7754 .22299 L
.77577 .22358 L
.77601 .22387 L
.77612 .22392 L
.77615 .2238 L
.7761 .2236 L
.77597 .22336 L
.77578 .22316 L
.77559 .22303 L
.77545 .22302 L
.77541 .22315 L
.77552 .22344 L
.77579 .22389 L
.77624 .22452 L
.7769 .22535 L
.77778 .22632 L
.77887 .22744 L
.78015 .2287 L
.78137 .23002 L
.78295 .23135 L
.78442 .23264 L
.78594 .23376 L
.78744 .23477 L
.7888 .23558 L
.78998 .23628 L
.79104 .23691 L
.79188 .23736 L
.79264 .23778 L
.79334 .23818 L
.79403 .23858 L
.79478 .23902 L
.79566 .23957 L
Mistroke
.79672 .24027 L
.79794 .2411 L
.7994 .24219 L
.80114 .24349 L
.80316 .24506 L
.80549 .24685 L
.80817 .24878 L
.81094 .25092 L
.81401 .25298 L
.81702 .25508 L
.82028 .2573 L
.82364 .25941 L
.82685 .26135 L
.83032 .26333 L
.83374 .26519 L
.83725 .26693 L
.8408 .26843 L
.8447 .26973 L
.84788 .27081 L
.85135 .27165 L
.8549 .27231 L
.85797 .27281 L
.86101 .27316 L
.86384 .2734 L
.86644 .27354 L
.86861 .27361 L
.87061 .27363 L
.87232 .27361 L
.87377 .27357 L
.87508 .27354 L
.87625 .27354 L
.87737 .27363 L
.87846 .27381 L
.87949 .2741 L
.88055 .27447 L
.88154 .2749 L
.88257 .27537 L
.88358 .27588 L
.88457 .2764 L
.88546 .27696 L
.88625 .27753 L
.88689 .27811 L
.88739 .27871 L
.88776 .27934 L
.88802 .27998 L
.88819 .28062 L
.88831 .28128 L
.88843 .28193 L
.88857 .28255 L
.88872 .28316 L
Mistroke
.88887 .28372 L
.88905 .28421 L
.88923 .2846 L
.88939 .28489 L
.8895 .28508 L
.88953 .28516 L
.88948 .28519 L
.88933 .28518 L
.88908 .28521 L
.88875 .2853 L
.88836 .28547 L
.88798 .28569 L
.88761 .28595 L
.8873 .28622 L
.88705 .28651 L
.88685 .28681 L
.88671 .28713 L
.8866 .28743 L
.88656 .2877 L
.88658 .28791 L
.88668 .28805 L
.88683 .28804 L
.88704 .28789 L
.88725 .28757 L
.88744 .28715 L
.88753 .28659 L
.88749 .28591 L
.88731 .2851 L
.88697 .28411 L
.88648 .28286 L
.88586 .28131 L
.88511 .27956 L
.88415 .27737 L
.88293 .2749 L
.88149 .27204 L
.87983 .26896 L
.87791 .26558 L
.87595 .26215 L
.87381 .25868 L
.87177 .25529 L
.86986 .25198 L
.86813 .24913 L
.86655 .24651 L
.86513 .24406 L
.86405 .24228 L
.86318 .24077 L
.86253 .23953 L
.86213 .23873 L
.86196 .23822 L
.86199 .23801 L
Mistroke
.86218 .23802 L
.86247 .23817 L
.8628 .23839 L
.86312 .23861 L
.86341 .23882 L
.86365 .23898 L
.86384 .23905 L
.86399 .23906 L
.86414 .23906 L
.86424 .23907 L
.86429 .23911 L
.86425 .23917 L
.86411 .23923 L
.86385 .23926 L
.86348 .23923 L
.86298 .23913 L
.86237 .23896 L
.86167 .23871 L
.86092 .23839 L
.86019 .23802 L
.85943 .23761 L
.85867 .23718 L
.85793 .23674 L
.85727 .23631 L
.85671 .23587 L
.85628 .23544 L
.85599 .23505 L
.85582 .23473 L
.85576 .23451 L
.8558 .23443 L
.85588 .23449 L
.85597 .23468 L
.85605 .23499 L
.85613 .23536 L
.8562 .2358 L
.85625 .23627 L
.85627 .23677 L
.85626 .23725 L
.85624 .23772 L
.85622 .23818 L
.85619 .23858 L
.85613 .23889 L
.85603 .23908 L
.85588 .23909 L
.85563 .23891 L
.85534 .23848 L
.8549 .23782 L
.85417 .2369 L
.85351 .23577 L
.85274 .23436 L
Mistroke
.85187 .23265 L
.85091 .2307 L
.84979 .22834 L
.84854 .22597 L
.84713 .22316 L
.84556 .2202 L
.84382 .21692 L
.84194 .21362 L
.83992 .21012 L
.83777 .20637 L
.83546 .2025 L
.83291 .1985 L
.83025 .19402 L
.82742 .19001 L
.82438 .18548 L
.82116 .18082 L
.81791 .17635 L
.81461 .17158 L
.81118 .16677 L
.80779 .16202 L
.80444 .15756 L
.80091 .15262 L
.79763 .14853 L
.79419 .14427 L
.79078 .14035 L
.78725 .13677 L
.78406 .13365 L
.78077 .13081 L
.77764 .12819 L
.77466 .12614 L
.77169 .12424 L
.76854 .12249 L
.7658 .12091 L
.76293 .11939 L
.7599 .11799 L
.75695 .11655 L
.75375 .11504 L
.75062 .11351 L
.74706 .11184 L
.74354 .11007 L
.73949 .10813 L
.73545 .1062 L
.73103 .10409 L
.7259 .10199 L
.72143 .09995 L
.71609 .0978 L
.71118 .09575 L
.70575 .09358 L
.70078 .09158 L
.69564 .08952 L
Mistroke
.69063 .08752 L
.68597 .08552 L
.68151 .08376 L
.6773 .08199 L
.67317 .08038 L
.66971 .07884 L
.66631 .07743 L
.66298 .0761 L
.66022 .07497 L
.65754 .07392 L
.65495 .07294 L
.65262 .07202 L
.65028 .07113 L
.64786 .07023 L
.64552 .06933 L
.64283 .06832 L
.64019 .06722 L
.63723 .06607 L
.63396 .06483 L
.63066 .06353 L
.62697 .06218 L
.62336 .06073 L
.61938 .05923 L
.61566 .05776 L
.61178 .05627 L
.60789 .05481 L
.60399 .05336 L
.60037 .05196 L
.59674 .05073 L
.59316 .04957 L
.58992 .04851 L
.58679 .04762 L
.58372 .04682 L
.58088 .04613 L
.57796 .04558 L
.57523 .04517 L
.5724 .0449 L
.56944 .04475 L
.56659 .04469 L
.56341 .04469 L
.56019 .0447 L
.55691 .0447 L
.55316 .04464 L
.54972 .04451 L
.54595 .04431 L
.54162 .04408 L
.53797 .04382 L
.53379 .04355 L
.52953 .04329 L
.52515 .04305 L
Mistroke
.5207 .04283 L
.51631 .04264 L
.51153 .04248 L
.50736 .04234 L
.50264 .04224 L
.49839 .04216 L
.49461 .04212 L
.49059 .04211 L
.48731 .04214 L
.48399 .04219 L
.48158 .04224 L
.47948 .04228 L
.47767 .04231 L
.47628 .04231 L
.47511 .04227 L
.4741 .04223 L
.4732 .04217 L
.47225 .04212 L
.4711 .04207 L
.46959 .04203 L
.46781 .04198 L
.46549 .04191 L
.46255 .04182 L
.45948 .04172 L
.45581 .04161 L
.45192 .04148 L
.44795 .04135 L
.44401 .0412 L
.4402 .04106 L
.43661 .04094 L
.43372 .04086 L
.43073 .04082 L
.4285 .0408 L
.42657 .04079 L
.425 .04077 L
.42385 .04074 L
.42311 .04072 L
.42266 .04073 L
.42244 .04079 L
.42238 .04091 L
.4224 .04108 L
.42244 .04128 L
.42241 .04152 L
.4223 .04178 L
.42214 .04206 L
.42196 .04235 L
.42177 .04265 L
.42156 .04297 L
.42128 .0433 L
.42091 .04363 L
Mistroke
.42039 .04391 L
.41971 .0442 L
.41886 .04446 L
.41789 .0446 L
.41684 .04464 L
.41573 .04461 L
.41461 .04451 L
.41353 .0444 L
.41247 .04428 L
.41144 .04417 L
.41045 .04407 L
.40955 .044 L
.40875 .04393 L
.40806 .04388 L
.40752 .04386 L
.40712 .04386 L
.40684 .04388 L
.40664 .04393 L
.40651 .04401 L
.4064 .0441 L
.4063 .04419 L
.4062 .04429 L
.40613 .04436 L
.40609 .04442 L
.40608 .04446 L
.40609 .04448 L
.40613 .04448 L
.40617 .04445 L
.4062 .04442 L
.40621 .04441 L
.40622 .04441 L
.40628 .04441 L
.40639 .04441 L
.40655 .04442 L
.40673 .04442 L
.40688 .04442 L
.40699 .0444 L
.40703 .04435 L
.40694 .04427 L
.40664 .04417 L
.40604 .04409 L
.40505 .04405 L
.40361 .04406 L
.40162 .04414 L
.39931 .0443 L
.39654 .04454 L
.39312 .04488 L
.3897 .04533 L
.38557 .0459 L
.38185 .04659 L
Mistroke
.37767 .0474 L
.37372 .04837 L
.37024 .04941 L
.36679 .05054 L
.36397 .05172 L
.36131 .0528 L
.35931 .05385 L
.35775 .05482 L
.35662 .05568 L
.35588 .0564 L
.35545 .05701 L
.35524 .05751 L
.35518 .05791 L
.35521 .05819 L
.35529 .05835 L
.3554 .05841 L
.35551 .05838 L
.3556 .05831 L
.35567 .05823 L
.35571 .05815 L
.35574 .05809 L
.35576 .05806 L
.35576 .05806 L
.35576 .05806 L
.35576 .05806 L
.35576 .05806 L
.35576 .05806 L
.35576 .05806 L
.35577 .05806 L
.3558 .05806 L
.35587 .05806 L
.35598 .05806 L
.35608 .05805 L
.35613 .05802 L
.3561 .05798 L
.35596 .05793 L
.35571 .05786 L
.35534 .05779 L
.35486 .05777 L
.35428 .0578 L
.35362 .05793 L
.35289 .05816 L
.35212 .05849 L
.35134 .05893 L
.35053 .05945 L
.34971 .06002 L
.34893 .06064 L
.34823 .06128 L
.34763 .06193 L
.34717 .06255 L
Mistroke
.34682 .06316 L
.3466 .06372 L
.34649 .06419 L
.34648 .06451 L
.34653 .06465 L
.34665 .06462 L
.34682 .06443 L
.34703 .06416 L
.34727 .06386 L
.34749 .06357 L
.34768 .06333 L
.3478 .06316 L
.34785 .06306 L
.34783 .06299 L
.34778 .0629 L
.34773 .06275 L
.34768 .06256 L
.34761 .06239 L
.34751 .06225 L
.3474 .06217 L
.34732 .06216 L
.34725 .06217 L
.34717 .0622 L
.34706 .06225 L
.3469 .06228 L
.34666 .0623 L
.34629 .06235 L
.34581 .0625 L
.34514 .0628 L
.34428 .06322 L
.34321 .06375 L
.34193 .06436 L
.34047 .06503 L
.33893 .06575 L
.33721 .0665 L
.33532 .06728 L
.33346 .06808 L
.33153 .0689 L
.32957 .06973 L
.32776 .07052 L
.32602 .07133 L
.32435 .07212 L
.32283 .07285 L
.32143 .07355 L
.32029 .07424 L
.31934 .0749 L
.3186 .07556 L
.31807 .07613 L
.31774 .07667 L
.31759 .07712 L
Mistroke
.31759 .07746 L
.31767 .07778 L
.31781 .07807 L
.31798 .07834 L
.31816 .07858 L
.31833 .07876 L
.31848 .07889 L
.3186 .07897 L
.3187 .07896 L
.31879 .07886 L
.31885 .07865 L
.31891 .07839 L
.31896 .07806 L
.31901 .07772 L
.31906 .07739 L
.31915 .07708 L
.31925 .07677 L
.31932 .07652 L
.3193 .07635 L
.31913 .07629 L
.31878 .07635 L
.31819 .07658 L
.3173 .07707 L
.31604 .07775 L
.31432 .07875 L
.31218 .08004 L
.30952 .08161 L
.30614 .08355 L
.30307 .08554 L
.29929 .08782 L
.29484 .09016 L
.29103 .0926 L
.28657 .09501 L
.28236 .09757 L
.27752 .1 L
.27389 .1024 L
.26981 .10477 L
.26584 .10721 L
.26231 .10933 L
.25849 .11153 L
.2553 .11364 L
.25194 .11567 L
.24872 .11772 L
.2456 .11969 L
.24235 .12163 L
.23942 .12354 L
.23634 .12539 L
.23328 .12722 L
.2301 .12906 L
.2273 .13081 L
Mistroke
.22434 .13257 L
.2215 .13428 L
.21892 .13592 L
.21635 .13752 L
.21394 .13905 L
.21202 .1404 L
.2103 .14165 L
.20877 .14278 L
.20744 .14378 L
.20638 .14462 L
.2055 .14532 L
.20482 .14588 L
.20433 .14632 L
.20397 .14664 L
.20373 .14687 L
.20355 .14702 L
.20342 .14713 L
.20326 .14727 L
.20306 .14746 L
.20282 .14772 L
.20256 .14805 L
.20223 .14847 L
.20184 .14899 L
.20144 .14961 L
.20101 .15027 L
.20059 .151 L
.20018 .15175 L
.19978 .15256 L
.1994 .15337 L
.19903 .15415 L
.19868 .15488 L
.19834 .15549 L
.19801 .15599 L
.19772 .15635 L
.19748 .15656 L
.1973 .15661 L
.19717 .15652 L
.19713 .15629 L
.19718 .15596 L
.1973 .1556 L
.19744 .15526 L
.19755 .15498 L
.19758 .15483 L
.19749 .15485 L
.19725 .15508 L
.19683 .15559 L
.19624 .15633 L
.19549 .15733 L
.1946 .15857 L
.1936 .16003 L
Mistroke
.19259 .16157 L
.19159 .16312 L
.19057 .16467 L
.18954 .16615 L
.1886 .16755 L
.18774 .16889 L
.18697 .17026 L
.18628 .1715 L
.18558 .1728 L
.18483 .17421 L
.18396 .1758 L
.18294 .17762 L
.18166 .17974 L
.18024 .18197 L
.17847 .18461 L
.17643 .18762 L
.1742 .19089 L
.17176 .19458 L
.16904 .19852 L
.16644 .2026 L
.16367 .20681 L
.16085 .21105 L
.15814 .21538 L
.15554 .2194 L
.15289 .22349 L
.15033 .22801 L
.14779 .23174 L
.1451 .23593 L
.14257 .2401 L
.13994 .24441 L
.13727 .24907 L
.13459 .25328 L
.13192 .2577 L
.12919 .26249 L
.12661 .26654 L
.1239 .27098 L
.12116 .27556 L
.11836 .27999 L
.11573 .28432 L
.1131 .28868 L
.11058 .29304 L
.1081 .29757 L
.10591 .30169 L
.10377 .30599 L
.10167 .31075 L
.09984 .31468 L
.09806 .31924 L
.09638 .32368 L
.09482 .32788 L
.0934 .33227 L
Mistroke
.09209 .33657 L
.09092 .34075 L
.0899 .34485 L
.08896 .34901 L
.08812 .3534 L
.08734 .35747 L
.08663 .36219 L
.08599 .3663 L
.08548 .37091 L
.08507 .37528 L
.08475 .37966 L
.08452 .38369 L
.08438 .38782 L
.0843 .39109 L
.08426 .39417 L
.08425 .39696 L
.08426 .39918 L
.08427 .4009 L
.0843 .40206 L
.08433 .4027 L
.08433 .40294 L
Mfstroke
1 1 0 r
.008 w
.08405 .4024 Mdot
.016 w
.08405 .4024 m
.08396 .40256 L
s
.008 w
.08396 .40256 Mdot
.016 w
.08396 .40256 m
.08391 .40285 L
s
1 .999 0 r
.008 w
.08391 .40285 Mdot
.016 w
.08391 .40285 m
.08394 .40324 L
s
.008 w
.08394 .40324 Mdot
.016 w
.08394 .40324 m
.08413 .40377 L
s
.008 w
.08413 .40377 Mdot
.016 w
.08413 .40377 m
.08448 .40444 L
s
.008 w
.08448 .40444 Mdot
.016 w
.08448 .40444 m
.085 .40528 L
s
.008 w
.085 .40528 Mdot
.016 w
.085 .40528 m
.08574 .40631 L
s
1 .998 0 r
.008 w
.08574 .40631 Mdot
.016 w
.08574 .40631 m
.08672 .40755 L
s
.008 w
.08672 .40755 Mdot
.016 w
.08672 .40755 m
.08777 .40897 L
s
.008 w
.08777 .40897 Mdot
.016 w
.08777 .40897 m
.08906 .4106 L
s
.008 w
.08906 .4106 Mdot
.016 w
.08906 .4106 m
.09025 .41245 L
s
1 .997 0 r
.008 w
.09025 .41245 Mdot
.016 w
.09025 .41245 m
.09145 .41455 L
s
.008 w
.09145 .41455 Mdot
.016 w
.09145 .41455 m
.09278 .41676 L
s
.008 w
.09278 .41676 Mdot
.016 w
.09278 .41676 m
.09377 .4193 L
s
.008 w
.09377 .4193 Mdot
.016 w
.09377 .4193 m
.09465 .42206 L
s
.008 w
.09465 .42206 Mdot
.016 w
.09465 .42206 m
.09537 .42518 L
s
1 .996 0 r
.008 w
.09537 .42518 Mdot
.016 w
.09537 .42518 m
.09586 .42838 L
s
.008 w
.09586 .42838 Mdot
.016 w
.09586 .42838 m
.0961 .43193 L
s
.008 w
.0961 .43193 Mdot
.016 w
.0961 .43193 m
.09607 .43549 L
s
.008 w
.09607 .43549 Mdot
.016 w
.09607 .43549 m
.09574 .43929 L
s
.008 w
.09574 .43929 Mdot
.016 w
.09574 .43929 m
.09516 .4428 L
s
1 .995 0 r
.008 w
.09516 .4428 Mdot
.016 w
.09516 .4428 m
.0944 .44649 L
s
.008 w
.0944 .44649 Mdot
.016 w
.0944 .44649 m
.0934 .45021 L
s
.008 w
.0934 .45021 Mdot
.016 w
.0934 .45021 m
.09235 .45354 L
s
.008 w
.09235 .45354 Mdot
.016 w
.09235 .45354 m
.09114 .45691 L
s
.008 w
.09114 .45691 Mdot
.016 w
.09114 .45691 m
.0898 .46018 L
s
1 .994 0 r
.008 w
.0898 .46018 Mdot
.016 w
.0898 .46018 m
.08829 .46334 L
s
.008 w
.08829 .46334 Mdot
.016 w
.08829 .46334 m
.08678 .46645 L
s
.008 w
.08678 .46645 Mdot
.016 w
.08678 .46645 m
.08496 .46959 L
s
.008 w
.08496 .46959 Mdot
.016 w
.08496 .46959 m
.08331 .47272 L
s
.008 w
.08331 .47272 Mdot
.016 w
.08331 .47272 m
.0814 .47602 L
s
1 .993 0 r
.008 w
.0814 .47602 Mdot
.016 w
.0814 .47602 m
.07955 .47941 L
s
.008 w
.07955 .47941 Mdot
.016 w
.07955 .47941 m
.0775 .4832 L
s
.008 w
.0775 .4832 Mdot
.016 w
.0775 .4832 m
.0755 .48707 L
s
.008 w
.0755 .48707 Mdot
.016 w
.0755 .48707 m
.07386 .49111 L
s
1 .992 0 r
.008 w
.07386 .49111 Mdot
.016 w
.07386 .49111 m
.07227 .49575 L
s
.008 w
.07227 .49575 Mdot
.016 w
.07227 .49575 m
.07078 .50029 L
s
.008 w
.07078 .50029 Mdot
.016 w
.07078 .50029 m
.06959 .50524 L
s
.008 w
.06959 .50524 Mdot
.016 w
.06959 .50524 m
.0687 .51026 L
s
.008 w
.0687 .51026 Mdot
.016 w
.0687 .51026 m
.0681 .51532 L
s
1 .991 0 r
.008 w
.0681 .51532 Mdot
.016 w
.0681 .51532 m
.06779 .52042 L
s
.008 w
.06779 .52042 Mdot
.016 w
.06779 .52042 m
.06771 .52543 L
s
.008 w
.06771 .52543 Mdot
.016 w
.06771 .52543 m
.06781 .53019 L
s
.008 w
.06781 .53019 Mdot
.016 w
.06781 .53019 m
.06806 .53461 L
s
.008 w
.06806 .53461 Mdot
.016 w
.06806 .53461 m
.06843 .53858 L
s
1 .99 0 r
.008 w
.06843 .53858 Mdot
.016 w
.06843 .53858 m
.0689 .5423 L
s
.008 w
.0689 .5423 Mdot
.016 w
.0689 .5423 m
.0694 .5453 L
s
.008 w
.0694 .5453 Mdot
.016 w
.0694 .5453 m
.06992 .54819 L
s
.008 w
.06992 .54819 Mdot
.016 w
.06992 .54819 m
.07043 .55063 L
s
.008 w
.07043 .55063 Mdot
.016 w
.07043 .55063 m
.07094 .55296 L
s
1 .989 0 r
.008 w
.07094 .55296 Mdot
.016 w
.07094 .55296 m
.07145 .55538 L
s
.008 w
.07145 .55538 Mdot
.016 w
.07145 .55538 m
.07194 .55792 L
s
.008 w
.07194 .55792 Mdot
.016 w
.07194 .55792 m
.07244 .56037 L
s
.008 w
.07244 .56037 Mdot
.016 w
.07244 .56037 m
.07292 .56313 L
s
1 .988 0 r
.008 w
.07292 .56313 Mdot
.016 w
.07292 .56313 m
.07341 .56626 L
s
.008 w
.07341 .56626 Mdot
.016 w
.07341 .56626 m
.07391 .56921 L
s
.008 w
.07391 .56921 Mdot
.016 w
.07391 .56921 m
.07442 .57259 L
s
.008 w
.07442 .57259 Mdot
.016 w
.07442 .57259 m
.07494 .57619 L
s
.008 w
.07494 .57619 Mdot
.016 w
.07494 .57619 m
.07543 .57912 L
s
1 .987 0 r
.008 w
.07543 .57912 Mdot
.016 w
.07543 .57912 m
.07593 .58246 L
s
.008 w
.07593 .58246 Mdot
.016 w
.07593 .58246 m
.0764 .58559 L
s
.008 w
.0764 .58559 Mdot
.016 w
.0764 .58559 m
.07681 .58802 L
s
.008 w
.07681 .58802 Mdot
.016 w
.07681 .58802 m
.07715 .59015 L
s
.008 w
.07715 .59015 Mdot
.016 w
.07715 .59015 m
.07741 .59192 L
s
1 .986 0 r
.008 w
.07741 .59192 Mdot
.016 w
.07741 .59192 m
.07761 .59321 L
s
.008 w
.07761 .59321 Mdot
.016 w
.07761 .59321 m
.07777 .59398 L
s
.008 w
.07777 .59398 Mdot
.016 w
.07777 .59398 m
.07789 .59433 L
s
.008 w
.07789 .59433 Mdot
.016 w
.07789 .59433 m
.07799 .59437 L
s
.008 w
.07799 .59437 Mdot
.016 w
.07799 .59437 m
.07807 .59425 L
s
1 .985 0 r
.008 w
.07807 .59425 Mdot
.016 w
.07807 .59425 m
.07814 .59408 L
s
.008 w
.07814 .59408 Mdot
.016 w
.07814 .59408 m
.07824 .59392 L
s
.008 w
.07824 .59392 Mdot
.016 w
.07824 .59392 m
.07838 .59384 L
s
.008 w
.07838 .59384 Mdot
.016 w
.07838 .59384 m
.07857 .59391 L
s
1 .984 0 r
.008 w
.07857 .59391 Mdot
.016 w
.07857 .59391 m
.07884 .59412 L
s
.008 w
.07884 .59412 Mdot
.016 w
.07884 .59412 m
.07916 .59439 L
s
.008 w
.07916 .59439 Mdot
.016 w
.07916 .59439 m
.07954 .59462 L
s
.008 w
.07954 .59462 Mdot
.016 w
.07954 .59462 m
.07996 .59477 L
s
.008 w
.07996 .59477 Mdot
.016 w
.07996 .59477 m
.0804 .59485 L
s
1 .983 0 r
.008 w
.0804 .59485 Mdot
.016 w
.0804 .59485 m
.08084 .59487 L
s
.008 w
.08084 .59487 Mdot
.016 w
.08084 .59487 m
.08126 .59485 L
s
.008 w
.08126 .59485 Mdot
.016 w
.08126 .59485 m
.08164 .59481 L
s
.008 w
.08164 .59481 Mdot
.016 w
.08164 .59481 m
.08195 .59478 L
s
.008 w
.08195 .59478 Mdot
.016 w
.08195 .59478 m
.0822 .59483 L
s
1 .982 0 r
.008 w
.0822 .59483 Mdot
.016 w
.0822 .59483 m
.08238 .59502 L
s
.008 w
.08238 .59502 Mdot
.016 w
.08238 .59502 m
.0825 .59541 L
s
.008 w
.0825 .59541 Mdot
.016 w
.0825 .59541 m
.08257 .59608 L
s
.008 w
.08257 .59608 Mdot
.016 w
.08257 .59608 m
.08263 .59709 L
s
.008 w
.08263 .59709 Mdot
.016 w
.08263 .59709 m
.08266 .59849 L
s
1 .981 0 r
.008 w
.08266 .59849 Mdot
.016 w
.08266 .59849 m
.08267 .60026 L
s
.008 w
.08267 .60026 Mdot
.016 w
.08267 .60026 m
.08265 .60254 L
s
.008 w
.08265 .60254 Mdot
.016 w
.08265 .60254 m
.08263 .60522 L
s
.008 w
.08263 .60522 Mdot
.016 w
.08263 .60522 m
.08262 .60843 L
s
.008 w
.08262 .60843 Mdot
.016 w
.08262 .60843 m
.08267 .61188 L
s
1 .98 0 r
.008 w
.08267 .61188 Mdot
.016 w
.08267 .61188 m
.0828 .61587 L
s
.008 w
.0828 .61587 Mdot
.016 w
.0828 .61587 m
.08302 .61998 L
s
.008 w
.08302 .61998 Mdot
.016 w
.08302 .61998 m
.08333 .62439 L
s
.008 w
.08333 .62439 Mdot
.016 w
.08333 .62439 m
.0837 .62902 L
s
1 .979 0 r
.008 w
.0837 .62902 Mdot
.016 w
.0837 .62902 m
.08414 .63379 L
s
.008 w
.08414 .63379 Mdot
.016 w
.08414 .63379 m
.08463 .63878 L
s
.008 w
.08463 .63878 Mdot
.016 w
.08463 .63878 m
.08519 .64401 L
s
.008 w
.08519 .64401 Mdot
.016 w
.08519 .64401 m
.08579 .64924 L
s
.008 w
.08579 .64924 Mdot
.016 w
.08579 .64924 m
.08646 .65448 L
s
1 .978 0 r
.008 w
.08646 .65448 Mdot
.016 w
.08646 .65448 m
.0872 .66006 L
s
.008 w
.0872 .66006 Mdot
.016 w
.0872 .66006 m
.08797 .66532 L
s
.008 w
.08797 .66532 Mdot
.016 w
.08797 .66532 m
.0888 .67035 L
s
.008 w
.0888 .67035 Mdot
.016 w
.0888 .67035 m
.08967 .67585 L
s
.008 w
.08967 .67585 Mdot
.016 w
.08967 .67585 m
.09053 .68046 L
s
1 .977 0 r
.008 w
.09053 .68046 Mdot
.016 w
.09053 .68046 m
.09142 .68531 L
s
.008 w
.09142 .68531 Mdot
.016 w
.09142 .68531 m
.09229 .68997 L
s
.008 w
.09229 .68997 Mdot
.016 w
.09229 .68997 m
.09313 .69391 L
s
.008 w
.09313 .69391 Mdot
.016 w
.09313 .69391 m
.09396 .69784 L
s
.008 w
.09396 .69784 Mdot
.016 w
.09396 .69784 m
.09474 .70134 L
s
1 .976 0 r
.008 w
.09474 .70134 Mdot
.016 w
.09474 .70134 m
.09551 .70456 L
s
.008 w
.09551 .70456 Mdot
.016 w
.09551 .70456 m
.09627 .7072 L
s
.008 w
.09627 .7072 Mdot
.016 w
.09627 .7072 m
.09699 .70957 L
s
.008 w
.09699 .70957 Mdot
.016 w
.09699 .70957 m
.09764 .71151 L
s
1 .975 0 r
.008 w
.09764 .71151 Mdot
.016 w
.09764 .71151 m
.09818 .71317 L
s
.008 w
.09818 .71317 Mdot
.016 w
.09818 .71317 m
.09861 .71456 L
s
.008 w
.09861 .71456 Mdot
.016 w
.09861 .71456 m
.09893 .71569 L
s
.008 w
.09893 .71569 Mdot
.016 w
.09893 .71569 m
.09915 .71658 L
s
.008 w
.09915 .71658 Mdot
.016 w
.09915 .71658 m
.09931 .71727 L
s
1 .974 0 r
.008 w
.09931 .71727 Mdot
.016 w
.09931 .71727 m
.0994 .71777 L
s
.008 w
.0994 .71777 Mdot
.016 w
.0994 .71777 m
.09947 .71808 L
s
.008 w
.09947 .71808 Mdot
.016 w
.09947 .71808 m
.09954 .71824 L
s
.008 w
.09954 .71824 Mdot
.016 w
.09954 .71824 m
.09962 .71829 L
s
.008 w
.09962 .71829 Mdot
.016 w
.09962 .71829 m
.09972 .71831 L
s
1 .973 0 r
.008 w
.09972 .71831 Mdot
.016 w
.09972 .71831 m
.09985 .71831 L
s
.008 w
.09985 .71831 Mdot
.016 w
.09985 .71831 m
.10001 .71832 L
s
.008 w
.10001 .71832 Mdot
.016 w
.10001 .71832 m
.1002 .71833 L
s
.008 w
.1002 .71833 Mdot
.016 w
.1002 .71833 m
.10043 .71833 L
s
.008 w
.10043 .71833 Mdot
.016 w
.10043 .71833 m
.10072 .71838 L
s
1 .972 0 r
.008 w
.10072 .71838 Mdot
.016 w
.10072 .71838 m
.10105 .71849 L
s
.008 w
.10105 .71849 Mdot
.016 w
.10105 .71849 m
.10143 .71866 L
s
.008 w
.10143 .71866 Mdot
.016 w
.10143 .71866 m
.10183 .71887 L
s
.008 w
.10183 .71887 Mdot
.016 w
.10183 .71887 m
.1022 .71908 L
s
1 .971 0 r
.008 w
.1022 .71908 Mdot
.016 w
.1022 .71908 m
.10254 .71927 L
s
.008 w
.10254 .71927 Mdot
.016 w
.10254 .71927 m
.10281 .71945 L
s
.008 w
.10281 .71945 Mdot
.016 w
.10281 .71945 m
.10299 .71959 L
s
.008 w
.10299 .71959 Mdot
.016 w
.10299 .71959 m
.10309 .71966 L
s
.008 w
.10309 .71966 Mdot
.016 w
.10309 .71966 m
.10312 .71968 L
s
1 .97 0 r
.008 w
.10312 .71968 Mdot
.016 w
.10312 .71968 m
.10311 .71967 L
s
.008 w
.10311 .71967 Mdot
.016 w
.10311 .71967 m
.10307 .71965 L
s
.008 w
.10307 .71965 Mdot
.016 w
.10307 .71965 m
.10303 .71964 L
s
.008 w
.10303 .71964 Mdot
.016 w
.10303 .71964 m
.10298 .71969 L
s
.008 w
.10298 .71969 Mdot
.016 w
.10298 .71969 m
.10294 .71985 L
s
1 .969 0 r
.008 w
.10294 .71985 Mdot
.016 w
.10294 .71985 m
.10292 .72013 L
s
.008 w
.10292 .72013 Mdot
.016 w
.10292 .72013 m
.10291 .72056 L
s
.008 w
.10291 .72056 Mdot
.016 w
.10291 .72056 m
.1029 .72117 L
s
.008 w
.1029 .72117 Mdot
.016 w
.1029 .72117 m
.10288 .7218 L
s
.008 w
.10288 .7218 Mdot
.016 w
.10288 .7218 m
.10287 .72257 L
s
1 .968 0 r
.008 w
.10287 .72257 Mdot
.016 w
.10287 .72257 m
.10285 .72338 L
s
.008 w
.10285 .72338 Mdot
.016 w
.10285 .72338 m
.10284 .72426 L
s
.008 w
.10284 .72426 Mdot
.016 w
.10284 .72426 m
.10281 .72518 L
s
.008 w
.10281 .72518 Mdot
.016 w
.10281 .72518 m
.10276 .72607 L
s
.008 w
.10276 .72607 Mdot
.016 w
.10276 .72607 m
.10271 .7269 L
s
1 .967 0 r
.008 w
.10271 .7269 Mdot
.016 w
.10271 .7269 m
.10265 .72765 L
s
.008 w
.10265 .72765 Mdot
.016 w
.10265 .72765 m
.10262 .7283 L
s
.008 w
.10262 .7283 Mdot
.016 w
.10262 .7283 m
.10263 .72884 L
s
.008 w
.10263 .72884 Mdot
.016 w
.10263 .72884 m
.10268 .72927 L
s
1 .966 0 r
.008 w
.10268 .72927 Mdot
.016 w
.10268 .72927 m
.10278 .72957 L
s
.008 w
.10278 .72957 Mdot
.016 w
.10278 .72957 m
.10293 .72972 L
s
.008 w
.10293 .72972 Mdot
.016 w
.10293 .72972 m
.10312 .72976 L
s
.008 w
.10312 .72976 Mdot
.016 w
.10312 .72976 m
.10336 .72972 L
s
.008 w
.10336 .72972 Mdot
.016 w
.10336 .72972 m
.10361 .72965 L
s
1 .965 0 r
.008 w
.10361 .72965 Mdot
.016 w
.10361 .72965 m
.10389 .72956 L
s
.008 w
.10389 .72956 Mdot
.016 w
.10389 .72956 m
.10416 .72947 L
s
.008 w
.10416 .72947 Mdot
.016 w
.10416 .72947 m
.10443 .72939 L
s
.008 w
.10443 .72939 Mdot
.016 w
.10443 .72939 m
.10468 .72933 L
s
.008 w
.10468 .72933 Mdot
.016 w
.10468 .72933 m
.10487 .72928 L
s
1 .964 0 r
.008 w
.10487 .72928 Mdot
.016 w
.10487 .72928 m
.10501 .72926 L
s
.008 w
.10501 .72926 Mdot
.016 w
.10501 .72926 m
.1051 .72925 L
s
.008 w
.1051 .72925 Mdot
.016 w
.1051 .72925 m
.10514 .72925 L
s
.008 w
.10514 .72925 Mdot
.016 w
.10514 .72925 m
.10516 .72925 L
s
.008 w
.10516 .72925 Mdot
.016 w
.10516 .72925 m
.10518 .72926 L
s
1 .963 0 r
.008 w
.10518 .72926 Mdot
.016 w
.10518 .72926 m
.10527 .72927 L
s
.008 w
.10527 .72927 Mdot
.016 w
.10527 .72927 m
.10547 .72931 L
s
.008 w
.10547 .72931 Mdot
.016 w
.10547 .72931 m
.10579 .72938 L
s
.008 w
.10579 .72938 Mdot
.016 w
.10579 .72938 m
.10623 .72953 L
s
1 .962 0 r
.008 w
.10623 .72953 Mdot
.016 w
.10623 .72953 m
.10681 .72974 L
s
.008 w
.10681 .72974 Mdot
.016 w
.10681 .72974 m
.10751 .73003 L
s
.008 w
.10751 .73003 Mdot
.016 w
.10751 .73003 m
.10825 .7304 L
s
.008 w
.10825 .7304 Mdot
.016 w
.10825 .7304 m
.10908 .73079 L
s
.008 w
.10908 .73079 Mdot
.016 w
.10908 .73079 m
.10989 .73122 L
s
1 .961 0 r
.008 w
.10989 .73122 Mdot
.016 w
.10989 .73122 m
.11073 .73165 L
s
.008 w
.11073 .73165 Mdot
.016 w
.11073 .73165 m
.11155 .73204 L
s
.008 w
.11155 .73204 Mdot
.016 w
.11155 .73204 m
.1124 .73238 L
s
.008 w
.1124 .73238 Mdot
.016 w
.1124 .73238 m
.11319 .73265 L
s
.008 w
.11319 .73265 Mdot
.016 w
.11319 .73265 m
.114 .73285 L
s
1 .96 0 r
.008 w
.114 .73285 Mdot
.016 w
.114 .73285 m
.11486 .73299 L
s
.008 w
.11486 .73299 Mdot
.016 w
.11486 .73299 m
.11577 .73306 L
s
.008 w
.11577 .73306 Mdot
.016 w
.11577 .73306 m
.11675 .733 L
s
.008 w
.11675 .733 Mdot
.016 w
.11675 .733 m
.11786 .73277 L
s
.008 w
.11786 .73277 Mdot
.016 w
.11786 .73277 m
.11903 .73242 L
s
1 .959 0 r
.008 w
.11903 .73242 Mdot
.016 w
.11903 .73242 m
.12046 .73188 L
s
.008 w
.12046 .73188 Mdot
.016 w
.12046 .73188 m
.12192 .73116 L
s
.008 w
.12192 .73116 Mdot
.016 w
.12192 .73116 m
.12351 .73032 L
s
.008 w
.12351 .73032 Mdot
.016 w
.12351 .73032 m
.12536 .72942 L
s
1 .958 0 r
.008 w
.12536 .72942 Mdot
.016 w
.12536 .72942 m
.12699 .72849 L
s
.008 w
.12699 .72849 Mdot
.016 w
.12699 .72849 m
.12874 .72757 L
s
.008 w
.12874 .72757 Mdot
.016 w
.12874 .72757 m
.13053 .72665 L
s
.008 w
.13053 .72665 Mdot
.016 w
.13053 .72665 m
.13211 .72578 L
s
.008 w
.13211 .72578 Mdot
.016 w
.13211 .72578 m
.13346 .72499 L
s
1 .957 0 r
.008 w
.13346 .72499 Mdot
.016 w
.13346 .72499 m
.13462 .72429 L
s
.008 w
.13462 .72429 Mdot
.016 w
.13462 .72429 m
.1355 .72373 L
s
.008 w
.1355 .72373 Mdot
.016 w
.1355 .72373 m
.13609 .72335 L
s
.008 w
.13609 .72335 Mdot
.016 w
.13609 .72335 m
.13637 .72315 L
s
.008 w
.13637 .72315 Mdot
.016 w
.13637 .72315 m
.13632 .72311 L
s
1 .956 0 r
.008 w
.13632 .72311 Mdot
.016 w
.13632 .72311 m
.13596 .72323 L
s
.008 w
.13596 .72323 Mdot
.016 w
.13596 .72323 m
.13539 .72351 L
s
.008 w
.13539 .72351 Mdot
.016 w
.13539 .72351 m
.1348 .72394 L
s
.008 w
.1348 .72394 Mdot
.016 w
.1348 .72394 m
.13431 .72454 L
s
.008 w
.13431 .72454 Mdot
.016 w
.13431 .72454 m
.13392 .7253 L
s
1 .955 0 r
.008 w
.13392 .7253 Mdot
.016 w
.13392 .7253 m
.13366 .7262 L
s
.008 w
.13366 .7262 Mdot
.016 w
.13366 .7262 m
.13352 .72723 L
s
.008 w
.13352 .72723 Mdot
.016 w
.13352 .72723 m
.13351 .7284 L
s
.008 w
.13351 .7284 Mdot
.016 w
.13351 .7284 m
.13369 .72969 L
s
.008 w
.13369 .72969 Mdot
.016 w
.13369 .72969 m
.13417 .73104 L
s
1 .954 0 r
.008 w
.13417 .73104 Mdot
.016 w
.13417 .73104 m
.13481 .73225 L
s
.008 w
.13481 .73225 Mdot
.016 w
.13481 .73225 m
.13585 .73355 L
s
.008 w
.13585 .73355 Mdot
.016 w
.13585 .73355 m
.13694 .73493 L
s
.008 w
.13694 .73493 Mdot
.016 w
.13694 .73493 m
.13822 .7365 L
s
1 .953 0 r
.008 w
.13822 .7365 Mdot
.016 w
.13822 .7365 m
.1395 .7382 L
s
.008 w
.1395 .7382 Mdot
.016 w
.1395 .7382 m
.14082 .73997 L
s
.008 w
.14082 .73997 Mdot
.016 w
.14082 .73997 m
.14207 .74198 L
s
.008 w
.14207 .74198 Mdot
.016 w
.14207 .74198 m
.14314 .74435 L
s
.008 w
.14314 .74435 Mdot
.016 w
.14314 .74435 m
.14409 .74698 L
s
1 .952 0 r
.008 w
.14409 .74698 Mdot
.016 w
.14409 .74698 m
.145 .74998 L
s
.008 w
.145 .74998 Mdot
.016 w
.145 .74998 m
.14589 .75346 L
s
.008 w
.14589 .75346 Mdot
.016 w
.14589 .75346 m
.1468 .75709 L
s
.008 w
.1468 .75709 Mdot
.016 w
.1468 .75709 m
.14773 .76049 L
s
.008 w
.14773 .76049 Mdot
.016 w
.14773 .76049 m
.1488 .76406 L
s
1 .951 0 r
.008 w
.1488 .76406 Mdot
.016 w
.1488 .76406 m
.15005 .76821 L
s
.008 w
.15005 .76821 Mdot
.016 w
.15005 .76821 m
.15144 .77265 L
s
.008 w
.15144 .77265 Mdot
.016 w
.15144 .77265 m
.15298 .77705 L
s
.008 w
.15298 .77705 Mdot
.016 w
.15298 .77705 m
.15458 .78116 L
s
.008 w
.15458 .78116 Mdot
.016 w
.15458 .78116 m
.15626 .7853 L
s
1 .95 0 r
.008 w
.15626 .7853 Mdot
.016 w
.15626 .7853 m
.15786 .78909 L
s
.008 w
.15786 .78909 Mdot
.016 w
.15786 .78909 m
.15942 .79235 L
s
.008 w
.15942 .79235 Mdot
.016 w
.15942 .79235 m
.16093 .79547 L
s
.008 w
.16093 .79547 Mdot
.016 w
.16093 .79547 m
.16229 .79796 L
s
1 .949 0 r
.008 w
.16229 .79796 Mdot
.016 w
.16229 .79796 m
.16356 .80015 L
s
.008 w
.16356 .80015 Mdot
.016 w
.16356 .80015 m
.16462 .80174 L
s
.008 w
.16462 .80174 Mdot
.016 w
.16462 .80174 m
.16555 .80297 L
s
.008 w
.16555 .80297 Mdot
.016 w
.16555 .80297 m
.16631 .80389 L
s
.008 w
.16631 .80389 Mdot
.016 w
.16631 .80389 m
.16687 .8045 L
s
1 .948 0 r
.008 w
.16687 .8045 Mdot
.016 w
.16687 .8045 m
.16722 .80484 L
s
.008 w
.16722 .80484 Mdot
.016 w
.16722 .80484 m
.16739 .80495 L
s
.008 w
.16739 .80495 Mdot
.016 w
.16739 .80495 m
.16741 .8049 L
s
.008 w
.16741 .8049 Mdot
.016 w
.16741 .8049 m
.16738 .80477 L
s
.008 w
.16738 .80477 Mdot
.016 w
.16738 .80477 m
.16737 .8046 L
s
1 .947 0 r
.008 w
.16737 .8046 Mdot
.016 w
.16737 .8046 m
.16744 .80443 L
s
.008 w
.16744 .80443 Mdot
.016 w
.16744 .80443 m
.16762 .80429 L
s
.008 w
.16762 .80429 Mdot
.016 w
.16762 .80429 m
.16796 .80425 L
s
.008 w
.16796 .80425 Mdot
.016 w
.16796 .80425 m
.16845 .80432 L
s
.008 w
.16845 .80432 Mdot
.016 w
.16845 .80432 m
.16905 .80446 L
s
1 .946 0 r
.008 w
.16905 .80446 Mdot
.016 w
.16905 .80446 m
.16974 .80463 L
s
.008 w
.16974 .80463 Mdot
.016 w
.16974 .80463 m
.17049 .80484 L
s
.008 w
.17049 .80484 Mdot
.016 w
.17049 .80484 m
.17125 .80507 L
s
.008 w
.17125 .80507 Mdot
.016 w
.17125 .80507 m
.17203 .80535 L
s
.008 w
.17203 .80535 Mdot
.016 w
.17203 .80535 m
.1728 .80564 L
s
1 .945 0 r
.008 w
.1728 .80564 Mdot
.016 w
.1728 .80564 m
.1735 .80593 L
s
.008 w
.1735 .80593 Mdot
.016 w
.1735 .80593 m
.17411 .80618 L
s
.008 w
.17411 .80618 Mdot
.016 w
.17411 .80618 m
.17457 .80635 L
s
.008 w
.17457 .80635 Mdot
.016 w
.17457 .80635 m
.17488 .80639 L
s
1 .944 0 r
.008 w
.17488 .80639 Mdot
.016 w
.17488 .80639 m
.17501 .80631 L
s
.008 w
.17501 .80631 Mdot
.016 w
.17501 .80631 m
.17502 .80618 L
s
.008 w
.17502 .80618 Mdot
.016 w
.17502 .80618 m
.17493 .80602 L
s
.008 w
.17493 .80602 Mdot
.016 w
.17493 .80602 m
.17479 .80589 L
s
.008 w
.17479 .80589 Mdot
.016 w
.17479 .80589 m
.17464 .80584 L
s
1 .943 0 r
.008 w
.17464 .80584 Mdot
.016 w
.17464 .80584 m
.17456 .80599 L
s
.008 w
.17456 .80599 Mdot
.016 w
.17456 .80599 m
.17462 .80637 L
s
.008 w
.17462 .80637 Mdot
.016 w
.17462 .80637 m
.17488 .80704 L
s
.008 w
.17488 .80704 Mdot
.016 w
.17488 .80704 m
.1754 .80799 L
s
.008 w
.1754 .80799 Mdot
.016 w
.1754 .80799 m
.17621 .80924 L
s
1 .942 0 r
.008 w
.17621 .80924 Mdot
.016 w
.17621 .80924 m
.1773 .81081 L
s
.008 w
.1773 .81081 Mdot
.016 w
.1773 .81081 m
.1786 .81246 L
s
.008 w
.1786 .81246 Mdot
.016 w
.1786 .81246 m
.18015 .81441 L
s
.008 w
.18015 .81441 Mdot
.016 w
.18015 .81441 m
.1819 .81654 L
s
.008 w
.1819 .81654 Mdot
.016 w
.1819 .81654 m
.18381 .8187 L
s
1 .941 0 r
.008 w
.18381 .8187 Mdot
.016 w
.18381 .8187 m
.1857 .8208 L
s
.008 w
.1857 .8208 Mdot
.016 w
.1857 .8208 m
.18761 .82283 L
s
.008 w
.18761 .82283 Mdot
.016 w
.18761 .82283 m
.18942 .82448 L
s
.008 w
.18942 .82448 Mdot
.016 w
.18942 .82448 m
.191 .82588 L
s
1 .94 0 r
.008 w
.191 .82588 Mdot
.016 w
.191 .82588 m
.19245 .82699 L
s
.008 w
.19245 .82699 Mdot
.016 w
.19245 .82699 m
.19362 .82778 L
s
.008 w
.19362 .82778 Mdot
.016 w
.19362 .82778 m
.19454 .82824 L
s
.008 w
.19454 .82824 Mdot
.016 w
.19454 .82824 m
.19518 .82838 L
s
.008 w
.19518 .82838 Mdot
.016 w
.19518 .82838 m
.19556 .82829 L
s
1 .939 0 r
.008 w
.19556 .82829 Mdot
.016 w
.19556 .82829 m
.19572 .82806 L
s
.008 w
.19572 .82806 Mdot
.016 w
.19572 .82806 m
.19575 .82775 L
s
.008 w
.19575 .82775 Mdot
.016 w
.19575 .82775 m
.19567 .82741 L
s
.008 w
.19567 .82741 Mdot
.016 w
.19567 .82741 m
.19553 .82709 L
s
.008 w
.19553 .82709 Mdot
.016 w
.19553 .82709 m
.19539 .82684 L
s
1 .938 0 r
.008 w
.19539 .82684 Mdot
.016 w
.19539 .82684 m
.19527 .82668 L
s
.008 w
.19527 .82668 Mdot
.016 w
.19527 .82668 m
.19521 .82661 L
s
.008 w
.19521 .82661 Mdot
.016 w
.19521 .82661 m
.19517 .82661 L
s
.008 w
.19517 .82661 Mdot
.016 w
.19517 .82661 m
.19516 .82665 L
s
.008 w
.19516 .82665 Mdot
.016 w
.19516 .82665 m
.19515 .82671 L
s
1 .937 0 r
.008 w
.19515 .82671 Mdot
.016 w
.19515 .82671 m
.19515 .82678 L
s
.008 w
.19515 .82678 Mdot
.016 w
.19515 .82678 m
.19515 .82683 L
s
.008 w
.19515 .82683 Mdot
.016 w
.19515 .82683 m
.19515 .82684 L
s
.008 w
.19515 .82684 Mdot
.016 w
.19515 .82684 m
.19513 .82679 L
s
1 .936 0 r
.008 w
.19513 .82679 Mdot
.016 w
.19513 .82679 m
.1951 .82669 L
s
.008 w
.1951 .82669 Mdot
.016 w
.1951 .82669 m
.19503 .82655 L
s
.008 w
.19503 .82655 Mdot
.016 w
.19503 .82655 m
.19491 .8264 L
s
.008 w
.19491 .8264 Mdot
.016 w
.19491 .8264 m
.19478 .82629 L
s
.008 w
.19478 .82629 Mdot
.016 w
.19478 .82629 m
.19466 .82625 L
s
1 .935 0 r
.008 w
.19466 .82625 Mdot
.016 w
.19466 .82625 m
.19459 .82632 L
s
.008 w
.19459 .82632 Mdot
.016 w
.19459 .82632 m
.19462 .82652 L
s
.008 w
.19462 .82652 Mdot
.016 w
.19462 .82652 m
.19476 .82689 L
s
.008 w
.19476 .82689 Mdot
.016 w
.19476 .82689 m
.19506 .82744 L
s
.008 w
.19506 .82744 Mdot
.016 w
.19506 .82744 m
.19554 .82818 L
s
1 .934 0 r
.008 w
.19554 .82818 Mdot
.016 w
.19554 .82818 m
.19623 .82909 L
s
.008 w
.19623 .82909 Mdot
.016 w
.19623 .82909 m
.19713 .83015 L
s
.008 w
.19713 .83015 Mdot
.016 w
.19713 .83015 m
.19822 .83144 L
s
.008 w
.19822 .83144 Mdot
.016 w
.19822 .83144 m
.19958 .8329 L
s
.008 w
.19958 .8329 Mdot
.016 w
.19958 .8329 m
.20113 .83468 L
s
1 .933 0 r
.008 w
.20113 .83468 Mdot
.016 w
.20113 .83468 m
.20297 .83655 L
s
.008 w
.20297 .83655 Mdot
.016 w
.20297 .83655 m
.20498 .83873 L
s
.008 w
.20498 .83873 Mdot
.016 w
.20498 .83873 m
.20731 .84114 L
s
.008 w
.20731 .84114 Mdot
.016 w
.20731 .84114 m
.20988 .84376 L
s
.008 w
.20988 .84376 Mdot
.016 w
.20988 .84376 m
.21268 .84655 L
s
1 .932 0 r
.008 w
.21268 .84655 Mdot
.016 w
.21268 .84655 m
.21579 .84964 L
s
.008 w
.21579 .84964 Mdot
.016 w
.21579 .84964 m
.21894 .8525 L
s
.008 w
.21894 .8525 Mdot
.016 w
.21894 .8525 m
.22226 .85566 L
s
.008 w
.22226 .85566 Mdot
.016 w
.22226 .85566 m
.22574 .85909 L
s
1 .931 0 r
.008 w
.22574 .85909 Mdot
.016 w
.22574 .85909 m
.22955 .86238 L
s
.008 w
.22955 .86238 Mdot
.016 w
.22955 .86238 m
.23298 .86576 L
s
.008 w
.23298 .86576 Mdot
.016 w
.23298 .86576 m
.23668 .86916 L
s
.008 w
.23668 .86916 Mdot
.016 w
.23668 .86916 m
.24068 .87215 L
s
.008 w
.24068 .87215 Mdot
.016 w
.24068 .87215 m
.24397 .87511 L
s
1 .93 0 r
.008 w
.24397 .87511 Mdot
.016 w
.24397 .87511 m
.24754 .87787 L
s
.008 w
.24754 .87787 Mdot
.016 w
.24754 .87787 m
.25125 .88056 L
s
.008 w
.25125 .88056 Mdot
.016 w
.25125 .88056 m
.2544 .88292 L
s
.008 w
.2544 .88292 Mdot
.016 w
.2544 .88292 m
.25771 .8852 L
s
.008 w
.25771 .8852 Mdot
.016 w
.25771 .8852 m
.261 .88715 L
s
1 .929 0 r
.008 w
.261 .88715 Mdot
.016 w
.261 .88715 m
.2643 .88903 L
s
.008 w
.2643 .88903 Mdot
.016 w
.2643 .88903 m
.26782 .89082 L
s
.008 w
.26782 .89082 Mdot
.016 w
.26782 .89082 m
.27114 .89262 L
s
.008 w
.27114 .89262 Mdot
.016 w
.27114 .89262 m
.27464 .89415 L
s
.008 w
.27464 .89415 Mdot
.016 w
.27464 .89415 m
.27833 .89581 L
s
1 .928 0 r
.008 w
.27833 .89581 Mdot
.016 w
.27833 .89581 m
.28223 .89734 L
s
.008 w
.28223 .89734 Mdot
.016 w
.28223 .89734 m
.28601 .89888 L
s
.008 w
.28601 .89888 Mdot
.016 w
.28601 .89888 m
.29001 .90035 L
s
.008 w
.29001 .90035 Mdot
.016 w
.29001 .90035 m
.29393 .90179 L
s
1 .927 0 r
.008 w
.29393 .90179 Mdot
.016 w
.29393 .90179 m
.29775 .90305 L
s
.008 w
.29775 .90305 Mdot
.016 w
.29775 .90305 m
.30153 .90426 L
s
.008 w
.30153 .90426 Mdot
.016 w
.30153 .90426 m
.30495 .90535 L
s
.008 w
.30495 .90535 Mdot
.016 w
.30495 .90535 m
.30816 .90625 L
s
.008 w
.30816 .90625 Mdot
.016 w
.30816 .90625 m
.31108 .90703 L
s
1 .926 0 r
.008 w
.31108 .90703 Mdot
.016 w
.31108 .90703 m
.31368 .90768 L
s
.008 w
.31368 .90768 Mdot
.016 w
.31368 .90768 m
.31596 .90819 L
s
.008 w
.31596 .90819 Mdot
.016 w
.31596 .90819 m
.31793 .90859 L
s
.008 w
.31793 .90859 Mdot
.016 w
.31793 .90859 m
.31959 .90887 L
s
.008 w
.31959 .90887 Mdot
.016 w
.31959 .90887 m
.32096 .90905 L
s
1 .925 0 r
.008 w
.32096 .90905 Mdot
.016 w
.32096 .90905 m
.32207 .90913 L
s
.008 w
.32207 .90913 Mdot
.016 w
.32207 .90913 m
.32296 .90914 L
s
.008 w
.32296 .90914 Mdot
.016 w
.32296 .90914 m
.32364 .90911 L
s
.008 w
.32364 .90911 Mdot
.016 w
.32364 .90911 m
.32415 .90908 L
s
.008 w
.32415 .90908 Mdot
.016 w
.32415 .90908 m
.32452 .90905 L
s
1 .924 0 r
.008 w
.32452 .90905 Mdot
.016 w
.32452 .90905 m
.32476 .90904 L
s
.008 w
.32476 .90904 Mdot
.016 w
.32476 .90904 m
.32489 .90903 L
s
.008 w
.32489 .90903 Mdot
.016 w
.32489 .90903 m
.32494 .90902 L
s
.008 w
.32494 .90902 Mdot
.016 w
.32494 .90902 m
.32494 .90899 L
s
1 .923 0 r
.008 w
.32494 .90899 Mdot
.016 w
.32494 .90899 m
.3249 .90897 L
s
.008 w
.3249 .90897 Mdot
.016 w
.3249 .90897 m
.32481 .90894 L
s
.008 w
.32481 .90894 Mdot
.016 w
.32481 .90894 m
.32466 .90891 L
s
.008 w
.32466 .90891 Mdot
.016 w
.32466 .90891 m
.32444 .90885 L
s
.008 w
.32444 .90885 Mdot
.016 w
.32444 .90885 m
.32418 .90876 L
s
1 .922 0 r
.008 w
.32418 .90876 Mdot
.016 w
.32418 .90876 m
.32394 .90864 L
s
.008 w
.32394 .90864 Mdot
.016 w
.32394 .90864 m
.32375 .90855 L
s
.008 w
.32375 .90855 Mdot
.016 w
.32375 .90855 m
.32366 .90852 L
s
.008 w
.32366 .90852 Mdot
.016 w
.32366 .90852 m
.32374 .90857 L
s
.008 w
.32374 .90857 Mdot
.016 w
.32374 .90857 m
.32406 .90874 L
s
1 .921 0 r
.008 w
.32406 .90874 Mdot
.016 w
.32406 .90874 m
.32468 .90902 L
s
.008 w
.32468 .90902 Mdot
.016 w
.32468 .90902 m
.32565 .90944 L
s
.008 w
.32565 .90944 Mdot
.016 w
.32565 .90944 m
.32703 .90998 L
s
.008 w
.32703 .90998 Mdot
.016 w
.32703 .90998 m
.32887 .91066 L
s
.008 w
.32887 .91066 Mdot
.016 w
.32887 .91066 m
.33105 .91152 L
s
1 .92 0 r
.008 w
.33105 .91152 Mdot
.016 w
.33105 .91152 m
.33351 .91243 L
s
.008 w
.33351 .91243 Mdot
.016 w
.33351 .91243 m
.33664 .91369 L
s
.008 w
.33664 .91369 Mdot
.016 w
.33664 .91369 m
.33995 .91492 L
s
.008 w
.33995 .91492 Mdot
.016 w
.33995 .91492 m
.34385 .91632 L
s
.008 w
.34385 .91632 Mdot
.016 w
.34385 .91632 m
.3482 .9179 L
s
1 .919 0 r
.008 w
.3482 .9179 Mdot
.016 w
.3482 .9179 m
.35276 .9196 L
s
.008 w
.35276 .9196 Mdot
.016 w
.35276 .9196 m
.35721 .92143 L
s
.008 w
.35721 .92143 Mdot
.016 w
.35721 .92143 m
.36208 .92305 L
s
.008 w
.36208 .92305 Mdot
.016 w
.36208 .92305 m
.36707 .92482 L
s
1 .918 0 r
.008 w
.36707 .92482 Mdot
.016 w
.36707 .92482 m
.3721 .92648 L
s
.008 w
.3721 .92648 Mdot
.016 w
.3721 .92648 m
.37676 .92815 L
s
.008 w
.37676 .92815 Mdot
.016 w
.37676 .92815 m
.38164 .92986 L
s
.008 w
.38164 .92986 Mdot
.016 w
.38164 .92986 m
.38642 .93142 L
s
.008 w
.38642 .93142 Mdot
.016 w
.38642 .93142 m
.39114 .93306 L
s
1 .917 0 r
.008 w
.39114 .93306 Mdot
.016 w
.39114 .93306 m
.39584 .93463 L
s
.008 w
.39584 .93463 Mdot
.016 w
.39584 .93463 m
.40045 .93618 L
s
.008 w
.40045 .93618 Mdot
.016 w
.40045 .93618 m
.40499 .93762 L
s
.008 w
.40499 .93762 Mdot
.016 w
.40499 .93762 m
.40917 .93904 L
s
.008 w
.40917 .93904 Mdot
.016 w
.40917 .93904 m
.41354 .94033 L
s
1 .916 0 r
.008 w
.41354 .94033 Mdot
.016 w
.41354 .94033 m
.4179 .9416 L
s
.008 w
.4179 .9416 Mdot
.016 w
.4179 .9416 m
.42252 .94288 L
s
.008 w
.42252 .94288 Mdot
.016 w
.42252 .94288 m
.42626 .94409 L
s
.008 w
.42626 .94409 Mdot
.016 w
.42626 .94409 m
.4304 .94532 L
s
.008 w
.4304 .94532 Mdot
.016 w
.4304 .94532 m
.43433 .94648 L
s
1 .915 0 r
.008 w
.43433 .94648 Mdot
.016 w
.43433 .94648 m
.43841 .94762 L
s
.008 w
.43841 .94762 Mdot
.016 w
.43841 .94762 m
.44212 .94867 L
s
.008 w
.44212 .94867 Mdot
.016 w
.44212 .94867 m
.44584 .9496 L
s
.008 w
.44584 .9496 Mdot
.016 w
.44584 .9496 m
.44941 .95044 L
s
1 .914 0 r
.008 w
.44941 .95044 Mdot
.016 w
.44941 .95044 m
.45264 .95117 L
s
.008 w
.45264 .95117 Mdot
.016 w
.45264 .95117 m
.45573 .95174 L
s
.008 w
.45573 .95174 Mdot
.016 w
.45573 .95174 m
.45833 .95218 L
s
.008 w
.45833 .95218 Mdot
.016 w
.45833 .95218 m
.46074 .95251 L
s
.008 w
.46074 .95251 Mdot
.016 w
.46074 .95251 m
.46278 .95276 L
s
1 .913 0 r
.008 w
.46278 .95276 Mdot
.016 w
.46278 .95276 m
.46445 .95291 L
s
.008 w
.46445 .95291 Mdot
.016 w
.46445 .95291 m
.46577 .95299 L
s
.008 w
.46577 .95299 Mdot
.016 w
.46577 .95299 m
.46678 .95302 L
s
.008 w
.46678 .95302 Mdot
.016 w
.46678 .95302 m
.46746 .95299 L
s
.008 w
.46746 .95299 Mdot
.016 w
.46746 .95299 m
.46787 .95293 L
s
1 .912 0 r
.008 w
.46787 .95293 Mdot
.016 w
.46787 .95293 m
.4681 .95286 L
s
.008 w
.4681 .95286 Mdot
.016 w
.4681 .95286 m
.46822 .95279 L
s
.008 w
.46822 .95279 Mdot
.016 w
.46822 .95279 m
.46825 .95272 L
s
.008 w
.46825 .95272 Mdot
.016 w
.46825 .95272 m
.46823 .95266 L
s
.008 w
.46823 .95266 Mdot
.016 w
.46823 .95266 m
.46815 .95263 L
s
1 .911 0 r
.008 w
.46815 .95263 Mdot
.016 w
.46815 .95263 m
.46805 .9526 L
s
.008 w
.46805 .9526 Mdot
.016 w
.46805 .9526 m
.46792 .95258 L
s
.008 w
.46792 .95258 Mdot
.016 w
.46792 .95258 m
.46782 .95255 L
s
.008 w
.46782 .95255 Mdot
.016 w
.46782 .95255 m
.46779 .95253 L
s
.008 w
.46779 .95253 Mdot
.016 w
.46779 .95253 m
.46783 .95251 L
s
1 .91 0 r
.008 w
.46783 .95251 Mdot
.016 w
.46783 .95251 m
.46792 .95249 L
s
.008 w
.46792 .95249 Mdot
.016 w
.46792 .95249 m
.46809 .95248 L
s
.008 w
.46809 .95248 Mdot
.016 w
.46809 .95248 m
.46831 .95248 L
s
.008 w
.46831 .95248 Mdot
.016 w
.46831 .95248 m
.46854 .95249 L
s
1 .909 0 r
.008 w
.46854 .95249 Mdot
.016 w
.46854 .95249 m
.46869 .95248 L
s
.008 w
.46869 .95248 Mdot
.016 w
.46869 .95248 m
.46877 .95244 L
s
.008 w
.46877 .95244 Mdot
.016 w
.46877 .95244 m
.46877 .95236 L
s
.008 w
.46877 .95236 Mdot
.016 w
.46877 .95236 m
.46872 .95222 L
s
.008 w
.46872 .95222 Mdot
.016 w
.46872 .95222 m
.46863 .95202 L
s
1 .908 0 r
.008 w
.46863 .95202 Mdot
.016 w
.46863 .95202 m
.46855 .95177 L
s
.008 w
.46855 .95177 Mdot
.016 w
.46855 .95177 m
.46846 .95146 L
s
.008 w
.46846 .95146 Mdot
.016 w
.46846 .95146 m
.46837 .95108 L
s
.008 w
.46837 .95108 Mdot
.016 w
.46837 .95108 m
.46823 .95068 L
s
.008 w
.46823 .95068 Mdot
.016 w
.46823 .95068 m
.46808 .95025 L
s
1 .907 0 r
.008 w
.46808 .95025 Mdot
.016 w
.46808 .95025 m
.46792 .94982 L
s
.008 w
.46792 .94982 Mdot
.016 w
.46792 .94982 m
.46772 .94936 L
s
.008 w
.46772 .94936 Mdot
.016 w
.46772 .94936 m
.46747 .94891 L
s
.008 w
.46747 .94891 Mdot
.016 w
.46747 .94891 m
.46722 .94852 L
s
.008 w
.46722 .94852 Mdot
.016 w
.46722 .94852 m
.46701 .9482 L
s
1 .906 0 r
.008 w
.46701 .9482 Mdot
.016 w
.46701 .9482 m
.46685 .94796 L
s
.008 w
.46685 .94796 Mdot
.016 w
.46685 .94796 m
.46671 .94776 L
s
.008 w
.46671 .94776 Mdot
.016 w
.46671 .94776 m
.4666 .94761 L
s
.008 w
.4666 .94761 Mdot
.016 w
.4666 .94761 m
.46652 .9475 L
s
1 .905 0 r
.008 w
.46652 .9475 Mdot
.016 w
.46652 .9475 m
.46642 .9474 L
s
.008 w
.46642 .9474 Mdot
.016 w
.46642 .9474 m
.46628 .9473 L
s
.008 w
.46628 .9473 Mdot
.016 w
.46628 .9473 m
.46612 .94721 L
s
.008 w
.46612 .94721 Mdot
.016 w
.46612 .94721 m
.46599 .9471 L
s
.008 w
.46599 .9471 Mdot
.016 w
.46599 .9471 m
.46586 .94696 L
s
1 .904 0 r
.008 w
.46586 .94696 Mdot
.016 w
.46586 .94696 m
.46576 .94678 L
s
.008 w
.46576 .94678 Mdot
.016 w
.46576 .94678 m
.46568 .9466 L
s
.008 w
.46568 .9466 Mdot
.016 w
.46568 .9466 m
.46564 .94642 L
s
.008 w
.46564 .94642 Mdot
.016 w
.46564 .94642 m
.46556 .94625 L
s
.008 w
.46556 .94625 Mdot
.016 w
.46556 .94625 m
.46548 .94612 L
s
1 .903 0 r
.008 w
.46548 .94612 Mdot
.016 w
.46548 .94612 m
.46541 .94604 L
s
.008 w
.46541 .94604 Mdot
.016 w
.46541 .94604 m
.46539 .94604 L
s
.008 w
.46539 .94604 Mdot
.016 w
.46539 .94604 m
.46541 .9461 L
s
.008 w
.46541 .9461 Mdot
.016 w
.46541 .9461 m
.46546 .94622 L
s
.008 w
.46546 .94622 Mdot
.016 w
.46546 .94622 m
.46553 .9464 L
s
1 .902 0 r
.008 w
.46553 .9464 Mdot
.016 w
.46553 .9464 m
.46562 .94664 L
s
.008 w
.46562 .94664 Mdot
.016 w
.46562 .94664 m
.46567 .94688 L
s
.008 w
.46567 .94688 Mdot
.016 w
.46567 .94688 m
.46569 .94709 L
s
.008 w
.46569 .94709 Mdot
.016 w
.46569 .94709 m
.4657 .94731 L
s
1 .901 0 r
.008 w
.4657 .94731 Mdot
.016 w
.4657 .94731 m
.46572 .94752 L
s
.008 w
.46572 .94752 Mdot
.016 w
.46572 .94752 m
.46576 .94772 L
s
.008 w
.46576 .94772 Mdot
.016 w
.46576 .94772 m
.46581 .94793 L
s
.008 w
.46581 .94793 Mdot
.016 w
.46581 .94793 m
.4659 .94813 L
s
.008 w
.4659 .94813 Mdot
.016 w
.4659 .94813 m
.46599 .94836 L
s
1 .9 0 r
.008 w
.46599 .94836 Mdot
.016 w
.46599 .94836 m
.46606 .94861 L
s
.008 w
.46606 .94861 Mdot
.016 w
.46606 .94861 m
.46612 .94881 L
s
.008 w
.46612 .94881 Mdot
.016 w
.46612 .94881 m
.46621 .94901 L
s
.008 w
.46621 .94901 Mdot
.016 w
.46621 .94901 m
.46636 .9492 L
s
.008 w
.46636 .9492 Mdot
.016 w
.46636 .9492 m
.46657 .94936 L
s
1 .899 0 r
.008 w
.46657 .94936 Mdot
.016 w
.46657 .94936 m
.4668 .9495 L
s
.008 w
.4668 .9495 Mdot
.016 w
.4668 .9495 m
.46704 .94959 L
s
.008 w
.46704 .94959 Mdot
.016 w
.46704 .94959 m
.46728 .9496 L
s
.008 w
.46728 .9496 Mdot
.016 w
.46728 .9496 m
.46746 .94953 L
s
.008 w
.46746 .94953 Mdot
.016 w
.46746 .94953 m
.46752 .94936 L
s
1 .898 0 r
.008 w
.46752 .94936 Mdot
.016 w
.46752 .94936 m
.46747 .9491 L
s
.008 w
.46747 .9491 Mdot
.016 w
.46747 .9491 m
.46727 .94879 L
s
.008 w
.46727 .94879 Mdot
.016 w
.46727 .94879 m
.46694 .9484 L
s
.008 w
.46694 .9484 Mdot
.016 w
.46694 .9484 m
.46651 .94801 L
s
.008 w
.46651 .94801 Mdot
.016 w
.46651 .94801 m
.46607 .9477 L
s
1 .897 0 r
.008 w
.46607 .9477 Mdot
.016 w
.46607 .9477 m
.4657 .94754 L
s
.008 w
.4657 .94754 Mdot
.016 w
.4657 .94754 m
.46537 .94753 L
s
.008 w
.46537 .94753 Mdot
.016 w
.46537 .94753 m
.46511 .94766 L
s
.008 w
.46511 .94766 Mdot
.016 w
.46511 .94766 m
.46493 .94789 L
s
1 .896 0 r
.008 w
.46493 .94789 Mdot
.016 w
.46493 .94789 m
.46491 .94813 L
s
.008 w
.46491 .94813 Mdot
.016 w
.46491 .94813 m
.46504 .94855 L
s
.008 w
.46504 .94855 Mdot
.016 w
.46504 .94855 m
.4654 .94911 L
s
.008 w
.4654 .94911 Mdot
.016 w
.4654 .94911 m
.46604 .94979 L
s
.008 w
.46604 .94979 Mdot
.016 w
.46604 .94979 m
.46699 .9505 L
s
1 .895 0 r
.008 w
.46699 .9505 Mdot
.016 w
.46699 .9505 m
.46828 .95116 L
s
.008 w
.46828 .95116 Mdot
.016 w
.46828 .95116 m
.46996 .95174 L
s
.008 w
.46996 .95174 Mdot
.016 w
.46996 .95174 m
.47199 .95219 L
s
.008 w
.47199 .95219 Mdot
.016 w
.47199 .95219 m
.47439 .95247 L
s
.008 w
.47439 .95247 Mdot
.016 w
.47439 .95247 m
.47719 .95255 L
s
1 .894 0 r
.008 w
.47719 .95255 Mdot
.016 w
.47719 .95255 m
.48039 .95242 L
s
.008 w
.48039 .95242 Mdot
.016 w
.48039 .95242 m
.48401 .9521 L
s
.008 w
.48401 .9521 Mdot
.016 w
.48401 .9521 m
.48783 .95166 L
s
.008 w
.48783 .95166 Mdot
.016 w
.48783 .95166 m
.49238 .95113 L
s
.008 w
.49238 .95113 Mdot
.016 w
.49238 .95113 m
.49663 .95056 L
s
1 .893 0 r
.008 w
.49663 .95056 Mdot
.016 w
.49663 .95056 m
.50143 .94996 L
s
.008 w
.50143 .94996 Mdot
.016 w
.50143 .94996 m
.50687 .94934 L
s
.008 w
.50687 .94934 Mdot
.016 w
.50687 .94934 m
.51156 .94871 L
s
.008 w
.51156 .94871 Mdot
.016 w
.51156 .94871 m
.51674 .94809 L
s
1 .892 0 r
.008 w
.51674 .94809 Mdot
.016 w
.51674 .94809 m
.52197 .94749 L
s
.008 w
.52197 .94749 Mdot
.016 w
.52197 .94749 m
.52765 .94692 L
s
.008 w
.52765 .94692 Mdot
.016 w
.52765 .94692 m
.53252 .94636 L
s
.008 w
.53252 .94636 Mdot
.016 w
.53252 .94636 m
.53789 .94581 L
s
.008 w
.53789 .94581 Mdot
.016 w
.53789 .94581 m
.54335 .94524 L
s
1 .891 0 r
.008 w
.54335 .94524 Mdot
.016 w
.54335 .94524 m
.5485 .94463 L
s
.008 w
.5485 .94463 Mdot
.016 w
.5485 .94463 m
.55386 .94394 L
s
.008 w
.55386 .94394 Mdot
.016 w
.55386 .94394 m
.55927 .94317 L
s
.008 w
.55927 .94317 Mdot
.016 w
.55927 .94317 m
.56478 .9423 L
s
.008 w
.56478 .9423 Mdot
.016 w
.56478 .9423 m
.5702 .94135 L
s
1 .89 0 r
.008 w
.5702 .94135 Mdot
.016 w
.5702 .94135 m
.57584 .94033 L
s
.008 w
.57584 .94033 Mdot
.016 w
.57584 .94033 m
.58135 .93928 L
s
.008 w
.58135 .93928 Mdot
.016 w
.58135 .93928 m
.5869 .9382 L
s
.008 w
.5869 .9382 Mdot
.016 w
.5869 .9382 m
.59201 .93713 L
s
.008 w
.59201 .93713 Mdot
.016 w
.59201 .93713 m
.59707 .93608 L
s
1 .889 0 r
.008 w
.59707 .93608 Mdot
.016 w
.59707 .93608 m
.60189 .93507 L
s
.008 w
.60189 .93507 Mdot
.016 w
.60189 .93507 m
.60627 .93417 L
s
.008 w
.60627 .93417 Mdot
.016 w
.60627 .93417 m
.61018 .93343 L
s
.008 w
.61018 .93343 Mdot
.016 w
.61018 .93343 m
.6137 .93284 L
s
1 .888 0 r
.008 w
.6137 .93284 Mdot
.016 w
.6137 .93284 m
.61672 .93239 L
s
.008 w
.61672 .93239 Mdot
.016 w
.61672 .93239 m
.61908 .93208 L
s
.008 w
.61908 .93208 Mdot
.016 w
.61908 .93208 m
.62106 .93188 L
s
.008 w
.62106 .93188 Mdot
.016 w
.62106 .93188 m
.62257 .93178 L
s
.008 w
.62257 .93178 Mdot
.016 w
.62257 .93178 m
.62363 .93172 L
s
1 .887 0 r
.008 w
.62363 .93172 Mdot
.016 w
.62363 .93172 m
.62431 .93169 L
s
.008 w
.62431 .93169 Mdot
.016 w
.62431 .93169 m
.62466 .93169 L
s
.008 w
.62466 .93169 Mdot
.016 w
.62466 .93169 m
.62471 .93171 L
s
.008 w
.62471 .93171 Mdot
.016 w
.62471 .93171 m
.62453 .93172 L
s
.008 w
.62453 .93172 Mdot
.016 w
.62453 .93172 m
.62418 .93174 L
s
1 .886 0 r
.008 w
.62418 .93174 Mdot
.016 w
.62418 .93174 m
.62375 .93175 L
s
.008 w
.62375 .93175 Mdot
.016 w
.62375 .93175 m
.6233 .93174 L
s
.008 w
.6233 .93174 Mdot
.016 w
.6233 .93174 m
.62287 .9317 L
s
.008 w
.62287 .9317 Mdot
.016 w
.62287 .9317 m
.62248 .9316 L
s
.008 w
.62248 .9316 Mdot
.016 w
.62248 .9316 m
.62218 .93145 L
s
1 .885 0 r
.008 w
.62218 .93145 Mdot
.016 w
.62218 .93145 m
.62197 .93124 L
s
.008 w
.62197 .93124 Mdot
.016 w
.62197 .93124 m
.62197 .93098 L
s
.008 w
.62197 .93098 Mdot
.016 w
.62197 .93098 m
.62224 .93066 L
s
.008 w
.62224 .93066 Mdot
.016 w
.62224 .93066 m
.62279 .9303 L
s
.008 w
.62279 .9303 Mdot
.016 w
.62279 .9303 m
.62367 .92988 L
s
1 .884 0 r
.008 w
.62367 .92988 Mdot
.016 w
.62367 .92988 m
.62487 .92941 L
s
.008 w
.62487 .92941 Mdot
.016 w
.62487 .92941 m
.62645 .92893 L
s
.008 w
.62645 .92893 Mdot
.016 w
.62645 .92893 m
.62846 .92844 L
s
.008 w
.62846 .92844 Mdot
.016 w
.62846 .92844 m
.63094 .92789 L
s
1 .883 0 r
.008 w
.63094 .92789 Mdot
.016 w
.63094 .92789 m
.63381 .92732 L
s
.008 w
.63381 .92732 Mdot
.016 w
.63381 .92732 m
.63697 .92672 L
s
.008 w
.63697 .92672 Mdot
.016 w
.63697 .92672 m
.64052 .92608 L
s
.008 w
.64052 .92608 Mdot
.016 w
.64052 .92608 m
.64436 .92541 L
s
.008 w
.64436 .92541 Mdot
.016 w
.64436 .92541 m
.64833 .92474 L
s
1 .882 0 r
.008 w
.64833 .92474 Mdot
.016 w
.64833 .92474 m
.65227 .92406 L
s
.008 w
.65227 .92406 Mdot
.016 w
.65227 .92406 m
.65627 .92339 L
s
.008 w
.65627 .92339 Mdot
.016 w
.65627 .92339 m
.65979 .92275 L
s
.008 w
.65979 .92275 Mdot
.016 w
.65979 .92275 m
.66333 .92216 L
s
.008 w
.66333 .92216 Mdot
.016 w
.66333 .92216 m
.66649 .92163 L
s
1 .881 0 r
.008 w
.66649 .92163 Mdot
.016 w
.66649 .92163 m
.66912 .92114 L
s
.008 w
.66912 .92114 Mdot
.016 w
.66912 .92114 m
.67152 .92068 L
s
.008 w
.67152 .92068 Mdot
.016 w
.67152 .92068 m
.67363 .92025 L
s
.008 w
.67363 .92025 Mdot
.016 w
.67363 .92025 m
.67535 .91989 L
s
.008 w
.67535 .91989 Mdot
.016 w
.67535 .91989 m
.67689 .91961 L
s
1 .88 0 r
.008 w
.67689 .91961 Mdot
.016 w
.67689 .91961 m
.67817 .91944 L
s
.008 w
.67817 .91944 Mdot
.016 w
.67817 .91944 m
.67927 .91936 L
s
.008 w
.67927 .91936 Mdot
.016 w
.67927 .91936 m
.68009 .91934 L
s
.008 w
.68009 .91934 Mdot
.016 w
.68009 .91934 m
.68069 .91935 L
s
1 .879 0 r
.008 w
.68069 .91935 Mdot
.016 w
.68069 .91935 m
.68122 .91936 L
s
.008 w
.68122 .91936 Mdot
.016 w
.68122 .91936 m
.68174 .91932 L
s
.008 w
.68174 .91932 Mdot
.016 w
.68174 .91932 m
.68229 .91917 L
s
.008 w
.68229 .91917 Mdot
.016 w
.68229 .91917 m
.68291 .91887 L
s
.008 w
.68291 .91887 Mdot
.016 w
.68291 .91887 m
.6835 .91843 L
s
1 .878 0 r
.008 w
.6835 .91843 Mdot
.016 w
.6835 .91843 m
.6841 .91786 L
s
.008 w
.6841 .91786 Mdot
.016 w
.6841 .91786 m
.68463 .91719 L
s
.008 w
.68463 .91719 Mdot
.016 w
.68463 .91719 m
.68507 .91644 L
s
.008 w
.68507 .91644 Mdot
.016 w
.68507 .91644 m
.68549 .91561 L
s
.008 w
.68549 .91561 Mdot
.016 w
.68549 .91561 m
.68585 .91473 L
s
1 .877 0 r
.008 w
.68585 .91473 Mdot
.016 w
.68585 .91473 m
.68615 .91384 L
s
.008 w
.68615 .91384 Mdot
.016 w
.68615 .91384 m
.68641 .91299 L
s
.008 w
.68641 .91299 Mdot
.016 w
.68641 .91299 m
.68664 .91222 L
s
.008 w
.68664 .91222 Mdot
.016 w
.68664 .91222 m
.68683 .91165 L
s
.008 w
.68683 .91165 Mdot
.016 w
.68683 .91165 m
.68702 .91119 L
s
1 .876 0 r
.008 w
.68702 .91119 Mdot
.016 w
.68702 .91119 m
.68714 .91096 L
s
.008 w
.68714 .91096 Mdot
.016 w
.68714 .91096 m
.68725 .91081 L
s
.008 w
.68725 .91081 Mdot
.016 w
.68725 .91081 m
.6873 .91076 L
s
.008 w
.6873 .91076 Mdot
.016 w
.6873 .91076 m
.6873 .9108 L
s
1 .875 0 r
.008 w
.6873 .9108 Mdot
.016 w
.6873 .9108 m
.68727 .91095 L
s
.008 w
.68727 .91095 Mdot
.016 w
.68727 .91095 m
.68724 .91112 L
s
.008 w
.68724 .91112 Mdot
.016 w
.68724 .91112 m
.6872 .91127 L
s
.008 w
.6872 .91127 Mdot
.016 w
.6872 .91127 m
.68712 .91143 L
s
.008 w
.68712 .91143 Mdot
.016 w
.68712 .91143 m
.68701 .91162 L
s
1 .874 0 r
.008 w
.68701 .91162 Mdot
.016 w
.68701 .91162 m
.68689 .91183 L
s
.008 w
.68689 .91183 Mdot
.016 w
.68689 .91183 m
.68676 .91202 L
s
.008 w
.68676 .91202 Mdot
.016 w
.68676 .91202 m
.68662 .91214 L
s
.008 w
.68662 .91214 Mdot
.016 w
.68662 .91214 m
.68647 .91225 L
s
.008 w
.68647 .91225 Mdot
.016 w
.68647 .91225 m
.68629 .91238 L
s
1 .873 0 r
.008 w
.68629 .91238 Mdot
.016 w
.68629 .91238 m
.6861 .91253 L
s
.008 w
.6861 .91253 Mdot
.016 w
.6861 .91253 m
.68592 .91271 L
s
.008 w
.68592 .91271 Mdot
.016 w
.68592 .91271 m
.68574 .9129 L
s
.008 w
.68574 .9129 Mdot
.016 w
.68574 .9129 m
.68558 .91308 L
s
.008 w
.68558 .91308 Mdot
.016 w
.68558 .91308 m
.68546 .91319 L
s
1 .872 0 r
.008 w
.68546 .91319 Mdot
.016 w
.68546 .91319 m
.6854 .91326 L
s
.008 w
.6854 .91326 Mdot
.016 w
.6854 .91326 m
.68542 .91326 L
s
.008 w
.68542 .91326 Mdot
.016 w
.68542 .91326 m
.68555 .91314 L
s
.008 w
.68555 .91314 Mdot
.016 w
.68555 .91314 m
.68579 .91286 L
s
.008 w
.68579 .91286 Mdot
.016 w
.68579 .91286 m
.68607 .91246 L
s
1 .871 0 r
.008 w
.68607 .91246 Mdot
.016 w
.68607 .91246 m
.68639 .91198 L
s
.008 w
.68639 .91198 Mdot
.016 w
.68639 .91198 m
.68669 .91153 L
s
.008 w
.68669 .91153 Mdot
.016 w
.68669 .91153 m
.68696 .91111 L
s
.008 w
.68696 .91111 Mdot
.016 w
.68696 .91111 m
.68718 .91079 L
s
1 .87 0 r
.008 w
.68718 .91079 Mdot
.016 w
.68718 .91079 m
.68731 .9105 L
s
.008 w
.68731 .9105 Mdot
.016 w
.68731 .9105 m
.68735 .91018 L
s
.008 w
.68735 .91018 Mdot
.016 w
.68735 .91018 m
.68726 .90985 L
s
.008 w
.68726 .90985 Mdot
.016 w
.68726 .90985 m
.68705 .90954 L
s
.008 w
.68705 .90954 Mdot
.016 w
.68705 .90954 m
.68671 .90924 L
s
1 .869 0 r
.008 w
.68671 .90924 Mdot
.016 w
.68671 .90924 m
.68626 .90887 L
s
.008 w
.68626 .90887 Mdot
.016 w
.68626 .90887 m
.68569 .9084 L
s
.008 w
.68569 .9084 Mdot
.016 w
.68569 .9084 m
.68501 .9078 L
s
.008 w
.68501 .9078 Mdot
.016 w
.68501 .9078 m
.68424 .90695 L
s
.008 w
.68424 .90695 Mdot
.016 w
.68424 .90695 m
.68336 .90603 L
s
1 .868 0 r
.008 w
.68336 .90603 Mdot
.016 w
.68336 .90603 m
.68236 .90479 L
s
.008 w
.68236 .90479 Mdot
.016 w
.68236 .90479 m
.68128 .90344 L
s
.008 w
.68128 .90344 Mdot
.016 w
.68128 .90344 m
.68006 .90219 L
s
.008 w
.68006 .90219 Mdot
.016 w
.68006 .90219 m
.67872 .90059 L
s
.008 w
.67872 .90059 Mdot
.016 w
.67872 .90059 m
.67727 .89898 L
s
1 .867 0 r
.008 w
.67727 .89898 Mdot
.016 w
.67727 .89898 m
.67571 .89731 L
s
.008 w
.67571 .89731 Mdot
.016 w
.67571 .89731 m
.67423 .89568 L
s
.008 w
.67423 .89568 Mdot
.016 w
.67423 .89568 m
.67267 .89418 L
s
.008 w
.67267 .89418 Mdot
.016 w
.67267 .89418 m
.67109 .89275 L
s
1 .866 0 r
.008 w
.67109 .89275 Mdot
.016 w
.67109 .89275 m
.6696 .89141 L
s
.008 w
.6696 .89141 Mdot
.016 w
.6696 .89141 m
.66808 .89016 L
s
.008 w
.66808 .89016 Mdot
.016 w
.66808 .89016 m
.6668 .88896 L
s
.008 w
.6668 .88896 Mdot
.016 w
.6668 .88896 m
.66559 .88788 L
s
.008 w
.66559 .88788 Mdot
.016 w
.66559 .88788 m
.66448 .88696 L
s
1 .865 0 r
.008 w
.66448 .88696 Mdot
.016 w
.66448 .88696 m
.66351 .88612 L
s
.008 w
.66351 .88612 Mdot
.016 w
.66351 .88612 m
.6627 .88533 L
s
.008 w
.6627 .88533 Mdot
.016 w
.6627 .88533 m
.66206 .88459 L
s
.008 w
.66206 .88459 Mdot
.016 w
.66206 .88459 m
.66155 .88386 L
s
.008 w
.66155 .88386 Mdot
.016 w
.66155 .88386 m
.66113 .88316 L
s
1 .864 0 r
.008 w
.66113 .88316 Mdot
.016 w
.66113 .88316 m
.66079 .88249 L
s
.008 w
.66079 .88249 Mdot
.016 w
.66079 .88249 m
.66051 .88184 L
s
.008 w
.66051 .88184 Mdot
.016 w
.66051 .88184 m
.66029 .88126 L
s
.008 w
.66029 .88126 Mdot
.016 w
.66029 .88126 m
.66007 .88071 L
s
.008 w
.66007 .88071 Mdot
.016 w
.66007 .88071 m
.65985 .88022 L
s
1 .863 0 r
.008 w
.65985 .88022 Mdot
.016 w
.65985 .88022 m
.65965 .87979 L
s
.008 w
.65965 .87979 Mdot
.016 w
.65965 .87979 m
.65949 .87943 L
s
.008 w
.65949 .87943 Mdot
.016 w
.65949 .87943 m
.65939 .87913 L
s
.008 w
.65939 .87913 Mdot
.016 w
.65939 .87913 m
.65933 .87888 L
s
.008 w
.65933 .87888 Mdot
.016 w
.65933 .87888 m
.6593 .87865 L
s
1 .862 0 r
.008 w
.6593 .87865 Mdot
.016 w
.6593 .87865 m
.65929 .87845 L
s
.008 w
.65929 .87845 Mdot
.016 w
.65929 .87845 m
.6593 .87826 L
s
.008 w
.6593 .87826 Mdot
.016 w
.6593 .87826 m
.65931 .8781 L
s
.008 w
.65931 .8781 Mdot
.016 w
.65931 .8781 m
.65931 .87794 L
s
1 .861 0 r
.008 w
.65931 .87794 Mdot
.016 w
.65931 .87794 m
.65932 .87776 L
s
.008 w
.65932 .87776 Mdot
.016 w
.65932 .87776 m
.65934 .87757 L
s
.008 w
.65934 .87757 Mdot
.016 w
.65934 .87757 m
.65939 .87736 L
s
.008 w
.65939 .87736 Mdot
.016 w
.65939 .87736 m
.65946 .87718 L
s
.008 w
.65946 .87718 Mdot
.016 w
.65946 .87718 m
.65956 .87702 L
s
1 .86 0 r
.008 w
.65956 .87702 Mdot
.016 w
.65956 .87702 m
.65967 .87691 L
s
.008 w
.65967 .87691 Mdot
.016 w
.65967 .87691 m
.65978 .87684 L
s
.008 w
.65978 .87684 Mdot
.016 w
.65978 .87684 m
.65988 .87681 L
s
.008 w
.65988 .87681 Mdot
.016 w
.65988 .87681 m
.65994 .87682 L
s
.008 w
.65994 .87682 Mdot
.016 w
.65994 .87682 m
.65997 .87685 L
s
1 .859 0 r
.008 w
.65997 .87685 Mdot
.016 w
.65997 .87685 m
.65997 .87689 L
s
.008 w
.65997 .87689 Mdot
.016 w
.65997 .87689 m
.65991 .87692 L
s
.008 w
.65991 .87692 Mdot
.016 w
.65991 .87692 m
.65989 .87694 L
s
.008 w
.65989 .87694 Mdot
.016 w
.65989 .87694 m
.65988 .87694 L
s
.008 w
.65988 .87694 Mdot
.016 w
.65988 .87694 m
.65986 .87695 L
s
1 .858 0 r
.008 w
.65986 .87695 Mdot
.016 w
.65986 .87695 m
.65986 .87698 L
s
.008 w
.65986 .87698 Mdot
.016 w
.65986 .87698 m
.65986 .87703 L
s
.008 w
.65986 .87703 Mdot
.016 w
.65986 .87703 m
.65988 .8771 L
s
.008 w
.65988 .8771 Mdot
.016 w
.65988 .8771 m
.65995 .87716 L
s
1 .857 0 r
.008 w
.65995 .87716 Mdot
.016 w
.65995 .87716 m
.66007 .87718 L
s
.008 w
.66007 .87718 Mdot
.016 w
.66007 .87718 m
.66027 .87714 L
s
.008 w
.66027 .87714 Mdot
.016 w
.66027 .87714 m
.66053 .87702 L
s
.008 w
.66053 .87702 Mdot
.016 w
.66053 .87702 m
.66087 .8768 L
s
.008 w
.66087 .8768 Mdot
.016 w
.66087 .8768 m
.66127 .8765 L
s
1 .856 0 r
.008 w
.66127 .8765 Mdot
.016 w
.66127 .8765 m
.6617 .87612 L
s
.008 w
.6617 .87612 Mdot
.016 w
.6617 .87612 m
.66212 .87567 L
s
.008 w
.66212 .87567 Mdot
.016 w
.66212 .87567 m
.66253 .87518 L
s
.008 w
.66253 .87518 Mdot
.016 w
.66253 .87518 m
.66293 .87467 L
s
.008 w
.66293 .87467 Mdot
.016 w
.66293 .87467 m
.66331 .87416 L
s
1 .855 0 r
.008 w
.66331 .87416 Mdot
.016 w
.66331 .87416 m
.66363 .87367 L
s
.008 w
.66363 .87367 Mdot
.016 w
.66363 .87367 m
.66387 .87324 L
s
.008 w
.66387 .87324 Mdot
.016 w
.66387 .87324 m
.664 .87287 L
s
.008 w
.664 .87287 Mdot
.016 w
.664 .87287 m
.66399 .87261 L
s
.008 w
.66399 .87261 Mdot
.016 w
.66399 .87261 m
.66382 .87243 L
s
1 .854 0 r
.008 w
.66382 .87243 Mdot
.016 w
.66382 .87243 m
.66348 .87233 L
s
.008 w
.66348 .87233 Mdot
.016 w
.66348 .87233 m
.66297 .87228 L
s
.008 w
.66297 .87228 Mdot
.016 w
.66297 .87228 m
.66231 .87224 L
s
.008 w
.66231 .87224 Mdot
.016 w
.66231 .87224 m
.66153 .87217 L
s
1 .853 0 r
.008 w
.66153 .87217 Mdot
.016 w
.66153 .87217 m
.66068 .87208 L
s
.008 w
.66068 .87208 Mdot
.016 w
.66068 .87208 m
.65984 .8719 L
s
.008 w
.65984 .8719 Mdot
.016 w
.65984 .8719 m
.65902 .87169 L
s
.008 w
.65902 .87169 Mdot
.016 w
.65902 .87169 m
.65822 .8714 L
s
.008 w
.65822 .8714 Mdot
.016 w
.65822 .8714 m
.65744 .87109 L
s
1 .852 0 r
.008 w
.65744 .87109 Mdot
.016 w
.65744 .87109 m
.65674 .87077 L
s
.008 w
.65674 .87077 Mdot
.016 w
.65674 .87077 m
.65615 .87045 L
s
.008 w
.65615 .87045 Mdot
.016 w
.65615 .87045 m
.6557 .87011 L
s
.008 w
.6557 .87011 Mdot
.016 w
.6557 .87011 m
.65535 .86976 L
s
.008 w
.65535 .86976 Mdot
.016 w
.65535 .86976 m
.65507 .86935 L
s
1 .851 0 r
.008 w
.65507 .86935 Mdot
.016 w
.65507 .86935 m
.6548 .86887 L
s
.008 w
.6548 .86887 Mdot
.016 w
.6548 .86887 m
.65453 .86831 L
s
.008 w
.65453 .86831 Mdot
.016 w
.65453 .86831 m
.65422 .86767 L
s
.008 w
.65422 .86767 Mdot
.016 w
.65422 .86767 m
.65381 .86696 L
s
.008 w
.65381 .86696 Mdot
.016 w
.65381 .86696 m
.65329 .86618 L
s
1 .85 0 r
.008 w
.65329 .86618 Mdot
.016 w
.65329 .86618 m
.65272 .86533 L
s
.008 w
.65272 .86533 Mdot
.016 w
.65272 .86533 m
.6521 .86442 L
s
.008 w
.6521 .86442 Mdot
.016 w
.6521 .86442 m
.65149 .86352 L
s
.008 w
.65149 .86352 Mdot
.016 w
.65149 .86352 m
.6509 .86259 L
s
.008 w
.6509 .86259 Mdot
.016 w
.6509 .86259 m
.65032 .86163 L
s
1 .849 0 r
.008 w
.65032 .86163 Mdot
.016 w
.65032 .86163 m
.64981 .86077 L
s
.008 w
.64981 .86077 Mdot
.016 w
.64981 .86077 m
.64936 .85997 L
s
.008 w
.64936 .85997 Mdot
.016 w
.64936 .85997 m
.64897 .85919 L
s
.008 w
.64897 .85919 Mdot
.016 w
.64897 .85919 m
.64864 .85844 L
s
1 .848 0 r
.008 w
.64864 .85844 Mdot
.016 w
.64864 .85844 m
.64838 .85769 L
s
.008 w
.64838 .85769 Mdot
.016 w
.64838 .85769 m
.64818 .85695 L
s
.008 w
.64818 .85695 Mdot
.016 w
.64818 .85695 m
.64802 .8562 L
s
.008 w
.64802 .8562 Mdot
.016 w
.64802 .8562 m
.64788 .85543 L
s
.008 w
.64788 .85543 Mdot
.016 w
.64788 .85543 m
.64776 .85462 L
s
1 .847 0 r
.008 w
.64776 .85462 Mdot
.016 w
.64776 .85462 m
.64762 .85373 L
s
.008 w
.64762 .85373 Mdot
.016 w
.64762 .85373 m
.64745 .85279 L
s
.008 w
.64745 .85279 Mdot
.016 w
.64745 .85279 m
.64723 .85174 L
s
.008 w
.64723 .85174 Mdot
.016 w
.64723 .85174 m
.64695 .85056 L
s
.008 w
.64695 .85056 Mdot
.016 w
.64695 .85056 m
.64664 .84942 L
s
1 .846 0 r
.008 w
.64664 .84942 Mdot
.016 w
.64664 .84942 m
.6463 .84829 L
s
.008 w
.6463 .84829 Mdot
.016 w
.6463 .84829 m
.64597 .84722 L
s
.008 w
.64597 .84722 Mdot
.016 w
.64597 .84722 m
.64565 .84626 L
s
.008 w
.64565 .84626 Mdot
.016 w
.64565 .84626 m
.64536 .84545 L
s
.008 w
.64536 .84545 Mdot
.016 w
.64536 .84545 m
.64511 .84481 L
s
1 .845 0 r
.008 w
.64511 .84481 Mdot
.016 w
.64511 .84481 m
.6449 .84434 L
s
.008 w
.6449 .84434 Mdot
.016 w
.6449 .84434 m
.64471 .84397 L
s
.008 w
.64471 .84397 Mdot
.016 w
.64471 .84397 m
.64453 .84366 L
s
.008 w
.64453 .84366 Mdot
.016 w
.64453 .84366 m
.64436 .84338 L
s
1 .844 0 r
.008 w
.64436 .84338 Mdot
.016 w
.64436 .84338 m
.64419 .8431 L
s
.008 w
.64419 .8431 Mdot
.016 w
.64419 .8431 m
.64406 .8428 L
s
.008 w
.64406 .8428 Mdot
.016 w
.64406 .8428 m
.64396 .84252 L
s
.008 w
.64396 .84252 Mdot
.016 w
.64396 .84252 m
.6439 .84226 L
s
.008 w
.6439 .84226 Mdot
.016 w
.6439 .84226 m
.64389 .84203 L
s
1 .843 0 r
.008 w
.64389 .84203 Mdot
.016 w
.64389 .84203 m
.6439 .84184 L
s
.008 w
.6439 .84184 Mdot
.016 w
.6439 .84184 m
.64393 .84168 L
s
.008 w
.64393 .84168 Mdot
.016 w
.64393 .84168 m
.64397 .84152 L
s
.008 w
.64397 .84152 Mdot
.016 w
.64397 .84152 m
.644 .84134 L
s
.008 w
.644 .84134 Mdot
.016 w
.644 .84134 m
.64401 .84114 L
s
1 .842 0 r
.008 w
.64401 .84114 Mdot
.016 w
.64401 .84114 m
.64401 .84093 L
s
.008 w
.64401 .84093 Mdot
.016 w
.64401 .84093 m
.64401 .84075 L
s
.008 w
.64401 .84075 Mdot
.016 w
.64401 .84075 m
.64401 .84061 L
s
.008 w
.64401 .84061 Mdot
.016 w
.64401 .84061 m
.64401 .84051 L
s
.008 w
.64401 .84051 Mdot
.016 w
.64401 .84051 m
.64401 .84046 L
s
1 .841 0 r
.008 w
.64401 .84046 Mdot
.016 w
.64401 .84046 m
.64401 .84044 L
s
.008 w
.64401 .84044 Mdot
.016 w
.64401 .84044 m
.64401 .84045 L
s
.008 w
.64401 .84045 Mdot
.016 w
.64401 .84045 m
.64401 .84049 L
s
.008 w
.64401 .84049 Mdot
.016 w
.64401 .84049 m
.64401 .84053 L
s
1 .84 0 r
.008 w
.64401 .84053 Mdot
.016 w
.64401 .84053 m
.64401 .84059 L
s
.008 w
.64401 .84059 Mdot
.016 w
.64401 .84059 m
.64401 .84065 L
s
.008 w
.64401 .84065 Mdot
.016 w
.64401 .84065 m
.64401 .84073 L
s
.008 w
.64401 .84073 Mdot
.016 w
.64401 .84073 m
.64402 .84079 L
s
.008 w
.64402 .84079 Mdot
.016 w
.64402 .84079 m
.64403 .84082 L
s
1 .839 0 r
.008 w
.64403 .84082 Mdot
.016 w
.64403 .84082 m
.64404 .8408 L
s
.008 w
.64404 .8408 Mdot
.016 w
.64404 .8408 m
.64404 .8407 L
s
.008 w
.64404 .8407 Mdot
.016 w
.64404 .8407 m
.64402 .84053 L
s
.008 w
.64402 .84053 Mdot
.016 w
.64402 .84053 m
.644 .84027 L
s
.008 w
.644 .84027 Mdot
.016 w
.644 .84027 m
.64397 .83993 L
s
1 .838 0 r
.008 w
.64397 .83993 Mdot
.016 w
.64397 .83993 m
.64393 .83954 L
s
.008 w
.64393 .83954 Mdot
.016 w
.64393 .83954 m
.6439 .8391 L
s
.008 w
.6439 .8391 Mdot
.016 w
.6439 .8391 m
.64387 .83864 L
s
.008 w
.64387 .83864 Mdot
.016 w
.64387 .83864 m
.64385 .83818 L
s
.008 w
.64385 .83818 Mdot
.016 w
.64385 .83818 m
.64383 .83772 L
s
1 .837 0 r
.008 w
.64383 .83772 Mdot
.016 w
.64383 .83772 m
.64382 .83728 L
s
.008 w
.64382 .83728 Mdot
.016 w
.64382 .83728 m
.64381 .83686 L
s
.008 w
.64381 .83686 Mdot
.016 w
.64381 .83686 m
.64381 .8365 L
s
.008 w
.64381 .8365 Mdot
.016 w
.64381 .8365 m
.64381 .83621 L
s
.008 w
.64381 .83621 Mdot
.016 w
.64381 .83621 m
.64383 .83601 L
s
1 .836 0 r
.008 w
.64383 .83601 Mdot
.016 w
.64383 .83601 m
.64385 .83589 L
s
.008 w
.64385 .83589 Mdot
.016 w
.64385 .83589 m
.64389 .83588 L
s
.008 w
.64389 .83588 Mdot
.016 w
.64389 .83588 m
.64395 .83596 L
s
.008 w
.64395 .83596 Mdot
.016 w
.64395 .83596 m
.64402 .83609 L
s
1 .835 0 r
.008 w
.64402 .83609 Mdot
.016 w
.64402 .83609 m
.64408 .83622 L
s
.008 w
.64408 .83622 Mdot
.016 w
.64408 .83622 m
.64412 .83631 L
s
.008 w
.64412 .83631 Mdot
.016 w
.64412 .83631 m
.64412 .83631 L
s
.008 w
.64412 .83631 Mdot
.016 w
.64412 .83631 m
.64408 .83622 L
s
.008 w
.64408 .83622 Mdot
.016 w
.64408 .83622 m
.64398 .83604 L
s
1 .834 0 r
.008 w
.64398 .83604 Mdot
.016 w
.64398 .83604 m
.64384 .83577 L
s
.008 w
.64384 .83577 Mdot
.016 w
.64384 .83577 m
.64366 .83539 L
s
.008 w
.64366 .83539 Mdot
.016 w
.64366 .83539 m
.64347 .83493 L
s
.008 w
.64347 .83493 Mdot
.016 w
.64347 .83493 m
.64325 .83444 L
s
.008 w
.64325 .83444 Mdot
.016 w
.64325 .83444 m
.64302 .83396 L
s
1 .833 0 r
.008 w
.64302 .83396 Mdot
.016 w
.64302 .83396 m
.64278 .83354 L
s
.008 w
.64278 .83354 Mdot
.016 w
.64278 .83354 m
.64255 .83319 L
s
.008 w
.64255 .83319 Mdot
.016 w
.64255 .83319 m
.64236 .83293 L
s
.008 w
.64236 .83293 Mdot
.016 w
.64236 .83293 m
.64224 .83278 L
s
.008 w
.64224 .83278 Mdot
.016 w
.64224 .83278 m
.64218 .83277 L
s
1 .832 0 r
.008 w
.64218 .83277 Mdot
.016 w
.64218 .83277 m
.64213 .83288 L
s
.008 w
.64213 .83288 Mdot
.016 w
.64213 .83288 m
.64208 .83313 L
s
.008 w
.64208 .83313 Mdot
.016 w
.64208 .83313 m
.64202 .83348 L
s
.008 w
.64202 .83348 Mdot
.016 w
.64202 .83348 m
.64194 .83393 L
s
1 .831 0 r
.008 w
.64194 .83393 Mdot
.016 w
.64194 .83393 m
.64175 .83443 L
s
.008 w
.64175 .83443 Mdot
.016 w
.64175 .83443 m
.64142 .83498 L
s
.008 w
.64142 .83498 Mdot
.016 w
.64142 .83498 m
.64096 .83552 L
s
.008 w
.64096 .83552 Mdot
.016 w
.64096 .83552 m
.64036 .836 L
s
.008 w
.64036 .836 Mdot
.016 w
.64036 .836 m
.63961 .8364 L
s
1 .83 0 r
.008 w
.63961 .8364 Mdot
.016 w
.63961 .8364 m
.63873 .8367 L
s
.008 w
.63873 .8367 Mdot
.016 w
.63873 .8367 m
.63781 .83691 L
s
.008 w
.63781 .83691 Mdot
.016 w
.63781 .83691 m
.63686 .83705 L
s
.008 w
.63686 .83705 Mdot
.016 w
.63686 .83705 m
.63586 .83713 L
s
.008 w
.63586 .83713 Mdot
.016 w
.63586 .83713 m
.63485 .83717 L
s
1 .829 0 r
.008 w
.63485 .83717 Mdot
.016 w
.63485 .83717 m
.63386 .83719 L
s
.008 w
.63386 .83719 Mdot
.016 w
.63386 .83719 m
.63295 .83721 L
s
.008 w
.63295 .83721 Mdot
.016 w
.63295 .83721 m
.63227 .8372 L
s
.008 w
.63227 .8372 Mdot
.016 w
.63227 .8372 m
.63176 .83715 L
s
.008 w
.63176 .83715 Mdot
.016 w
.63176 .83715 m
.63138 .83703 L
s
1 .828 0 r
.008 w
.63138 .83703 Mdot
.016 w
.63138 .83703 m
.63115 .83689 L
s
.008 w
.63115 .83689 Mdot
.016 w
.63115 .83689 m
.63102 .8368 L
s
.008 w
.63102 .8368 Mdot
.016 w
.63102 .8368 m
.63095 .8368 L
s
.008 w
.63095 .8368 Mdot
.016 w
.63095 .8368 m
.63087 .83694 L
s
1 .827 0 r
.008 w
.63087 .83694 Mdot
.016 w
.63087 .83694 m
.63071 .83723 L
s
.008 w
.63071 .83723 Mdot
.016 w
.63071 .83723 m
.63043 .8377 L
s
.008 w
.63043 .8377 Mdot
.016 w
.63043 .8377 m
.63003 .83837 L
s
.008 w
.63003 .83837 Mdot
.016 w
.63003 .83837 m
.6295 .83925 L
s
.008 w
.6295 .83925 Mdot
.016 w
.6295 .83925 m
.6288 .84034 L
s
1 .826 0 r
.008 w
.6288 .84034 Mdot
.016 w
.6288 .84034 m
.62787 .84166 L
s
.008 w
.62787 .84166 Mdot
.016 w
.62787 .84166 m
.62688 .84304 L
s
.008 w
.62688 .84304 Mdot
.016 w
.62688 .84304 m
.62557 .84481 L
s
.008 w
.62557 .84481 Mdot
.016 w
.62557 .84481 m
.62439 .84649 L
s
.008 w
.62439 .84649 Mdot
.016 w
.62439 .84649 m
.62316 .84828 L
s
1 .825 0 r
.008 w
.62316 .84828 Mdot
.016 w
.62316 .84828 m
.62188 .85014 L
s
.008 w
.62188 .85014 Mdot
.016 w
.62188 .85014 m
.62061 .85196 L
s
.008 w
.62061 .85196 Mdot
.016 w
.62061 .85196 m
.61941 .85364 L
s
.008 w
.61941 .85364 Mdot
.016 w
.61941 .85364 m
.61839 .85503 L
s
.008 w
.61839 .85503 Mdot
.016 w
.61839 .85503 m
.61749 .85621 L
s
1 .824 0 r
.008 w
.61749 .85621 Mdot
.016 w
.61749 .85621 m
.6167 .85721 L
s
.008 w
.6167 .85721 Mdot
.016 w
.6167 .85721 m
.61601 .85799 L
s
.008 w
.61601 .85799 Mdot
.016 w
.61601 .85799 m
.61541 .85859 L
s
.008 w
.61541 .85859 Mdot
.016 w
.61541 .85859 m
.61488 .85902 L
s
.008 w
.61488 .85902 Mdot
.016 w
.61488 .85902 m
.61444 .85928 L
s
1 .823 0 r
.008 w
.61444 .85928 Mdot
.016 w
.61444 .85928 m
.61411 .85935 L
s
.008 w
.61411 .85935 Mdot
.016 w
.61411 .85935 m
.61392 .85926 L
s
.008 w
.61392 .85926 Mdot
.016 w
.61392 .85926 m
.61382 .8591 L
s
.008 w
.61382 .8591 Mdot
.016 w
.61382 .8591 m
.61378 .85894 L
s
1 .822 0 r
.008 w
.61378 .85894 Mdot
.016 w
.61378 .85894 m
.61375 .85885 L
s
.008 w
.61375 .85885 Mdot
.016 w
.61375 .85885 m
.61369 .85892 L
s
.008 w
.61369 .85892 Mdot
.016 w
.61369 .85892 m
.61359 .85918 L
s
.008 w
.61359 .85918 Mdot
.016 w
.61359 .85918 m
.61344 .85965 L
s
.008 w
.61344 .85965 Mdot
.016 w
.61344 .85965 m
.61325 .86035 L
s
1 .821 0 r
.008 w
.61325 .86035 Mdot
.016 w
.61325 .86035 m
.61303 .86132 L
s
.008 w
.61303 .86132 Mdot
.016 w
.61303 .86132 m
.61281 .8626 L
s
.008 w
.61281 .8626 Mdot
.016 w
.61281 .8626 m
.61259 .86426 L
s
.008 w
.61259 .86426 Mdot
.016 w
.61259 .86426 m
.61238 .8663 L
s
.008 w
.61238 .8663 Mdot
.016 w
.61238 .8663 m
.61211 .86848 L
s
1 .82 0 r
.008 w
.61211 .86848 Mdot
.016 w
.61211 .86848 m
.6118 .87104 L
s
.008 w
.6118 .87104 Mdot
.016 w
.6118 .87104 m
.61148 .87407 L
s
.008 w
.61148 .87407 Mdot
.016 w
.61148 .87407 m
.61117 .87706 L
s
.008 w
.61117 .87706 Mdot
.016 w
.61117 .87706 m
.61091 .88052 L
s
.008 w
.61091 .88052 Mdot
.016 w
.61091 .88052 m
.61073 .88383 L
s
1 .819 0 r
.008 w
.61073 .88383 Mdot
.016 w
.61073 .88383 m
.61063 .88732 L
s
.008 w
.61063 .88732 Mdot
.016 w
.61063 .88732 m
.61063 .89095 L
s
.008 w
.61063 .89095 Mdot
.016 w
.61063 .89095 m
.61073 .89401 L
s
.008 w
.61073 .89401 Mdot
.016 w
.61073 .89401 m
.61095 .89717 L
s
1 .818 0 r
.008 w
.61095 .89717 Mdot
.016 w
.61095 .89717 m
.61123 .90023 L
s
.008 w
.61123 .90023 Mdot
.016 w
.61123 .90023 m
.61162 .90287 L
s
.008 w
.61162 .90287 Mdot
.016 w
.61162 .90287 m
.61208 .90534 L
s
.008 w
.61208 .90534 Mdot
.016 w
.61208 .90534 m
.61259 .90756 L
s
.008 w
.61259 .90756 Mdot
.016 w
.61259 .90756 m
.61317 .90953 L
s
1 .817 0 r
.008 w
.61317 .90953 Mdot
.016 w
.61317 .90953 m
.61379 .91136 L
s
.008 w
.61379 .91136 Mdot
.016 w
.61379 .91136 m
.61442 .9131 L
s
.008 w
.61442 .9131 Mdot
.016 w
.61442 .9131 m
.61504 .91489 L
s
.008 w
.61504 .91489 Mdot
.016 w
.61504 .91489 m
.61565 .91624 L
s
.008 w
.61565 .91624 Mdot
.016 w
.61565 .91624 m
.61625 .91772 L
s
1 .816 0 r
.008 w
.61625 .91772 Mdot
.016 w
.61625 .91772 m
.61683 .91905 L
s
.008 w
.61683 .91905 Mdot
.016 w
.61683 .91905 m
.61736 .92032 L
s
.008 w
.61736 .92032 Mdot
.016 w
.61736 .92032 m
.6178 .92147 L
s
.008 w
.6178 .92147 Mdot
.016 w
.6178 .92147 m
.61814 .92258 L
s
.008 w
.61814 .92258 Mdot
.016 w
.61814 .92258 m
.61835 .92357 L
s
1 .815 0 r
.008 w
.61835 .92357 Mdot
.016 w
.61835 .92357 m
.61843 .92442 L
s
.008 w
.61843 .92442 Mdot
.016 w
.61843 .92442 m
.61835 .92514 L
s
.008 w
.61835 .92514 Mdot
.016 w
.61835 .92514 m
.61809 .92576 L
s
.008 w
.61809 .92576 Mdot
.016 w
.61809 .92576 m
.61765 .92623 L
s
.008 w
.61765 .92623 Mdot
.016 w
.61765 .92623 m
.61714 .92656 L
s
1 .814 0 r
.008 w
.61714 .92656 Mdot
.016 w
.61714 .92656 m
.61655 .92684 L
s
.008 w
.61655 .92684 Mdot
.016 w
.61655 .92684 m
.61593 .92709 L
s
.008 w
.61593 .92709 Mdot
.016 w
.61593 .92709 m
.61527 .92731 L
s
.008 w
.61527 .92731 Mdot
.016 w
.61527 .92731 m
.6148 .92758 L
s
1 .813 0 r
.008 w
.6148 .92758 Mdot
.016 w
.6148 .92758 m
.61434 .92794 L
s
.008 w
.61434 .92794 Mdot
.016 w
.61434 .92794 m
.61397 .92834 L
s
.008 w
.61397 .92834 Mdot
.016 w
.61397 .92834 m
.61368 .92872 L
s
.008 w
.61368 .92872 Mdot
.016 w
.61368 .92872 m
.61354 .92912 L
s
.008 w
.61354 .92912 Mdot
.016 w
.61354 .92912 m
.61357 .92954 L
s
1 .812 0 r
.008 w
.61357 .92954 Mdot
.016 w
.61357 .92954 m
.61371 .92994 L
s
.008 w
.61371 .92994 Mdot
.016 w
.61371 .92994 m
.61395 .93027 L
s
.008 w
.61395 .93027 Mdot
.016 w
.61395 .93027 m
.61424 .93054 L
s
.008 w
.61424 .93054 Mdot
.016 w
.61424 .93054 m
.61454 .93072 L
s
.008 w
.61454 .93072 Mdot
.016 w
.61454 .93072 m
.61473 .93081 L
s
1 .811 0 r
.008 w
.61473 .93081 Mdot
.016 w
.61473 .93081 m
.61479 .93079 L
s
.008 w
.61479 .93079 Mdot
.016 w
.61479 .93079 m
.61466 .93073 L
s
.008 w
.61466 .93073 Mdot
.016 w
.61466 .93073 m
.61437 .93064 L
s
.008 w
.61437 .93064 Mdot
.016 w
.61437 .93064 m
.61393 .93047 L
s
.008 w
.61393 .93047 Mdot
.016 w
.61393 .93047 m
.61334 .93025 L
s
1 .81 0 r
.008 w
.61334 .93025 Mdot
.016 w
.61334 .93025 m
.61261 .93005 L
s
.008 w
.61261 .93005 Mdot
.016 w
.61261 .93005 m
.6118 .92988 L
s
.008 w
.6118 .92988 Mdot
.016 w
.6118 .92988 m
.61095 .92968 L
s
.008 w
.61095 .92968 Mdot
.016 w
.61095 .92968 m
.61011 .92949 L
s
1 .809 0 r
.008 w
.61011 .92949 Mdot
.016 w
.61011 .92949 m
.60932 .92931 L
s
.008 w
.60932 .92931 Mdot
.016 w
.60932 .92931 m
.60864 .92919 L
s
.008 w
.60864 .92919 Mdot
.016 w
.60864 .92919 m
.60805 .92904 L
s
.008 w
.60805 .92904 Mdot
.016 w
.60805 .92904 m
.6076 .92891 L
s
.008 w
.6076 .92891 Mdot
.016 w
.6076 .92891 m
.60727 .92882 L
s
1 .808 0 r
.008 w
.60727 .92882 Mdot
.016 w
.60727 .92882 m
.60706 .92877 L
s
.008 w
.60706 .92877 Mdot
.016 w
.60706 .92877 m
.60693 .9287 L
s
.008 w
.60693 .9287 Mdot
.016 w
.60693 .9287 m
.60689 .92864 L
s
.008 w
.60689 .92864 Mdot
.016 w
.60689 .92864 m
.60693 .92859 L
s
.008 w
.60693 .92859 Mdot
.016 w
.60693 .92859 m
.60703 .92854 L
s
1 .807 0 r
.008 w
.60703 .92854 Mdot
.016 w
.60703 .92854 m
.60713 .92846 L
s
.008 w
.60713 .92846 Mdot
.016 w
.60713 .92846 m
.60724 .92837 L
s
.008 w
.60724 .92837 Mdot
.016 w
.60724 .92837 m
.60737 .92829 L
s
.008 w
.60737 .92829 Mdot
.016 w
.60737 .92829 m
.60749 .92825 L
s
.008 w
.60749 .92825 Mdot
.016 w
.60749 .92825 m
.60757 .92822 L
s
1 .806 0 r
.008 w
.60757 .92822 Mdot
.016 w
.60757 .92822 m
.60762 .92821 L
s
.008 w
.60762 .92821 Mdot
.016 w
.60762 .92821 m
.60769 .92824 L
s
.008 w
.60769 .92824 Mdot
.016 w
.60769 .92824 m
.60779 .92831 L
s
.008 w
.60779 .92831 Mdot
.016 w
.60779 .92831 m
.60791 .92837 L
s
1 .805 0 r
.008 w
.60791 .92837 Mdot
.016 w
.60791 .92837 m
.60808 .92839 L
s
.008 w
.60808 .92839 Mdot
.016 w
.60808 .92839 m
.60827 .9284 L
s
.008 w
.60827 .9284 Mdot
.016 w
.60827 .9284 m
.60857 .92842 L
s
.008 w
.60857 .92842 Mdot
.016 w
.60857 .92842 m
.60888 .92844 L
s
.008 w
.60888 .92844 Mdot
.016 w
.60888 .92844 m
.60926 .92846 L
s
1 .804 0 r
.008 w
.60926 .92846 Mdot
.016 w
.60926 .92846 m
.60966 .92852 L
s
.008 w
.60966 .92852 Mdot
.016 w
.60966 .92852 m
.61012 .92864 L
s
.008 w
.61012 .92864 Mdot
.016 w
.61012 .92864 m
.61056 .9288 L
s
.008 w
.61056 .9288 Mdot
.016 w
.61056 .9288 m
.61104 .929 L
s
.008 w
.61104 .929 Mdot
.016 w
.61104 .929 m
.61151 .92917 L
s
1 .803 0 r
.008 w
.61151 .92917 Mdot
.016 w
.61151 .92917 m
.6119 .92931 L
s
.008 w
.6119 .92931 Mdot
.016 w
.6119 .92931 m
.61216 .92941 L
s
.008 w
.61216 .92941 Mdot
.016 w
.61216 .92941 m
.61222 .92942 L
s
.008 w
.61222 .92942 Mdot
.016 w
.61222 .92942 m
.61203 .92943 L
s
.008 w
.61203 .92943 Mdot
.016 w
.61203 .92943 m
.61171 .92941 L
s
1 .802 0 r
.008 w
.61171 .92941 Mdot
.016 w
.61171 .92941 m
.61121 .92937 L
s
.008 w
.61121 .92937 Mdot
.016 w
.61121 .92937 m
.61053 .92925 L
s
.008 w
.61053 .92925 Mdot
.016 w
.61053 .92925 m
.60979 .92914 L
s
.008 w
.60979 .92914 Mdot
.016 w
.60979 .92914 m
.60905 .92904 L
s
.008 w
.60905 .92904 Mdot
.016 w
.60905 .92904 m
.60826 .92889 L
s
1 .801 0 r
.008 w
.60826 .92889 Mdot
.016 w
.60826 .92889 m
.60758 .92871 L
s
.008 w
.60758 .92871 Mdot
.016 w
.60758 .92871 m
.60707 .92852 L
s
.008 w
.60707 .92852 Mdot
.016 w
.60707 .92852 m
.60675 .92834 L
s
.008 w
.60675 .92834 Mdot
.016 w
.60675 .92834 m
.60665 .92821 L
s
1 .8 0 r
.008 w
.60665 .92821 Mdot
.016 w
.60665 .92821 m
.60674 .92813 L
s
.008 w
.60674 .92813 Mdot
.016 w
.60674 .92813 m
.607 .92812 L
s
.008 w
.607 .92812 Mdot
.016 w
.607 .92812 m
.60742 .92815 L
s
.008 w
.60742 .92815 Mdot
.016 w
.60742 .92815 m
.60794 .92819 L
s
.008 w
.60794 .92819 Mdot
.016 w
.60794 .92819 m
.60855 .92826 L
s
1 .799 0 r
.008 w
.60855 .92826 Mdot
.016 w
.60855 .92826 m
.60922 .92835 L
s
.008 w
.60922 .92835 Mdot
.016 w
.60922 .92835 m
.60988 .92845 L
s
.008 w
.60988 .92845 Mdot
.016 w
.60988 .92845 m
.61053 .92849 L
s
.008 w
.61053 .92849 Mdot
.016 w
.61053 .92849 m
.61113 .92847 L
s
.008 w
.61113 .92847 Mdot
.016 w
.61113 .92847 m
.61176 .92843 L
s
1 .798 0 r
.008 w
.61176 .92843 Mdot
.016 w
.61176 .92843 m
.61238 .92841 L
s
.008 w
.61238 .92841 Mdot
.016 w
.61238 .92841 m
.61306 .92841 L
s
.008 w
.61306 .92841 Mdot
.016 w
.61306 .92841 m
.61377 .92843 L
s
.008 w
.61377 .92843 Mdot
.016 w
.61377 .92843 m
.61454 .92849 L
s
.008 w
.61454 .92849 Mdot
.016 w
.61454 .92849 m
.61539 .92863 L
s
1 .797 0 r
.008 w
.61539 .92863 Mdot
.016 w
.61539 .92863 m
.61629 .92884 L
s
.008 w
.61629 .92884 Mdot
.016 w
.61629 .92884 m
.61718 .9291 L
s
.008 w
.61718 .9291 Mdot
.016 w
.61718 .9291 m
.61802 .92942 L
s
.008 w
.61802 .92942 Mdot
.016 w
.61802 .92942 m
.61885 .92975 L
s
1 .796 0 r
.008 w
.61885 .92975 Mdot
.016 w
.61885 .92975 m
.61964 .93006 L
s
.008 w
.61964 .93006 Mdot
.016 w
.61964 .93006 m
.62042 .93032 L
s
.008 w
.62042 .93032 Mdot
.016 w
.62042 .93032 m
.62114 .93053 L
s
.008 w
.62114 .93053 Mdot
.016 w
.62114 .93053 m
.62186 .93066 L
s
.008 w
.62186 .93066 Mdot
.016 w
.62186 .93066 m
.62263 .9307 L
s
1 .795 0 r
.008 w
.62263 .9307 Mdot
.016 w
.62263 .9307 m
.6234 .93061 L
s
.008 w
.6234 .93061 Mdot
.016 w
.6234 .93061 m
.62423 .93038 L
s
.008 w
.62423 .93038 Mdot
.016 w
.62423 .93038 m
.62512 .93007 L
s
.008 w
.62512 .93007 Mdot
.016 w
.62512 .93007 m
.62606 .92972 L
s
.008 w
.62606 .92972 Mdot
.016 w
.62606 .92972 m
.62695 .92929 L
s
1 .794 0 r
.008 w
.62695 .92929 Mdot
.016 w
.62695 .92929 m
.62794 .92886 L
s
.008 w
.62794 .92886 Mdot
.016 w
.62794 .92886 m
.62901 .92843 L
s
.008 w
.62901 .92843 Mdot
.016 w
.62901 .92843 m
.63014 .92805 L
s
.008 w
.63014 .92805 Mdot
.016 w
.63014 .92805 m
.63131 .92775 L
s
.008 w
.63131 .92775 Mdot
.016 w
.63131 .92775 m
.63242 .92752 L
s
1 .793 0 r
.008 w
.63242 .92752 Mdot
.016 w
.63242 .92752 m
.63343 .92734 L
s
.008 w
.63343 .92734 Mdot
.016 w
.63343 .92734 m
.63428 .92718 L
s
.008 w
.63428 .92718 Mdot
.016 w
.63428 .92718 m
.63494 .92704 L
s
.008 w
.63494 .92704 Mdot
.016 w
.63494 .92704 m
.6354 .92692 L
s
1 .792 0 r
.008 w
.6354 .92692 Mdot
.016 w
.6354 .92692 m
.6357 .92681 L
s
.008 w
.6357 .92681 Mdot
.016 w
.6357 .92681 m
.63581 .92663 L
s
.008 w
.63581 .92663 Mdot
.016 w
.63581 .92663 m
.63581 .92635 L
s
.008 w
.63581 .92635 Mdot
.016 w
.63581 .92635 m
.63572 .92596 L
s
.008 w
.63572 .92596 Mdot
.016 w
.63572 .92596 m
.63557 .92543 L
s
1 .791 0 r
.008 w
.63557 .92543 Mdot
.016 w
.63557 .92543 m
.63527 .92475 L
s
.008 w
.63527 .92475 Mdot
.016 w
.63527 .92475 m
.63484 .9239 L
s
.008 w
.63484 .9239 Mdot
.016 w
.63484 .9239 m
.63424 .92289 L
s
.008 w
.63424 .92289 Mdot
.016 w
.63424 .92289 m
.63347 .92171 L
s
.008 w
.63347 .92171 Mdot
.016 w
.63347 .92171 m
.63254 .92043 L
s
1 .79 0 r
.008 w
.63254 .92043 Mdot
.016 w
.63254 .92043 m
.63146 .91906 L
s
.008 w
.63146 .91906 Mdot
.016 w
.63146 .91906 m
.63022 .91743 L
s
.008 w
.63022 .91743 Mdot
.016 w
.63022 .91743 m
.62897 .91609 L
s
.008 w
.62897 .91609 Mdot
.016 w
.62897 .91609 m
.62761 .91451 L
s
.008 w
.62761 .91451 Mdot
.016 w
.62761 .91451 m
.62622 .91291 L
s
1 .789 0 r
.008 w
.62622 .91291 Mdot
.016 w
.62622 .91291 m
.62492 .91136 L
s
.008 w
.62492 .91136 Mdot
.016 w
.62492 .91136 m
.62359 .90982 L
s
.008 w
.62359 .90982 Mdot
.016 w
.62359 .90982 m
.62238 .90844 L
s
.008 w
.62238 .90844 Mdot
.016 w
.62238 .90844 m
.62124 .90717 L
s
.008 w
.62124 .90717 Mdot
.016 w
.62124 .90717 m
.62018 .90601 L
s
1 .788 0 r
.008 w
.62018 .90601 Mdot
.016 w
.62018 .90601 m
.61928 .90512 L
s
.008 w
.61928 .90512 Mdot
.016 w
.61928 .90512 m
.61851 .90438 L
s
.008 w
.61851 .90438 Mdot
.016 w
.61851 .90438 m
.61791 .90387 L
s
.008 w
.61791 .90387 Mdot
.016 w
.61791 .90387 m
.61751 .9036 L
s
1 .787 0 r
.008 w
.61751 .9036 Mdot
.016 w
.61751 .9036 m
.61731 .90356 L
s
.008 w
.61731 .90356 Mdot
.016 w
.61731 .90356 m
.61726 .90367 L
s
.008 w
.61726 .90367 Mdot
.016 w
.61726 .90367 m
.61735 .90384 L
s
.008 w
.61735 .90384 Mdot
.016 w
.61735 .90384 m
.61754 .90402 L
s
.008 w
.61754 .90402 Mdot
.016 w
.61754 .90402 m
.61783 .90419 L
s
1 .786 0 r
.008 w
.61783 .90419 Mdot
.016 w
.61783 .90419 m
.61819 .90434 L
s
.008 w
.61819 .90434 Mdot
.016 w
.61819 .90434 m
.61867 .90447 L
s
.008 w
.61867 .90447 Mdot
.016 w
.61867 .90447 m
.6193 .90461 L
s
.008 w
.6193 .90461 Mdot
.016 w
.6193 .90461 m
.62009 .90482 L
s
.008 w
.62009 .90482 Mdot
.016 w
.62009 .90482 m
.62107 .90506 L
s
1 .785 0 r
.008 w
.62107 .90506 Mdot
.016 w
.62107 .90506 m
.62225 .90536 L
s
.008 w
.62225 .90536 Mdot
.016 w
.62225 .90536 m
.62369 .90574 L
s
.008 w
.62369 .90574 Mdot
.016 w
.62369 .90574 m
.62541 .90624 L
s
.008 w
.62541 .90624 Mdot
.016 w
.62541 .90624 m
.62735 .90687 L
s
.008 w
.62735 .90687 Mdot
.016 w
.62735 .90687 m
.62951 .90762 L
s
1 .784 0 r
.008 w
.62951 .90762 Mdot
.016 w
.62951 .90762 m
.63184 .90839 L
s
.008 w
.63184 .90839 Mdot
.016 w
.63184 .90839 m
.63439 .90921 L
s
.008 w
.63439 .90921 Mdot
.016 w
.63439 .90921 m
.63681 .91005 L
s
.008 w
.63681 .91005 Mdot
.016 w
.63681 .91005 m
.63945 .91094 L
s
1 .783 0 r
.008 w
.63945 .91094 Mdot
.016 w
.63945 .91094 m
.64195 .91167 L
s
.008 w
.64195 .91167 Mdot
.016 w
.64195 .91167 m
.64451 .91231 L
s
.008 w
.64451 .91231 Mdot
.016 w
.64451 .91231 m
.64712 .91292 L
s
.008 w
.64712 .91292 Mdot
.016 w
.64712 .91292 m
.6495 .91341 L
s
.008 w
.6495 .91341 Mdot
.016 w
.6495 .91341 m
.65169 .91379 L
s
1 .782 0 r
.008 w
.65169 .91379 Mdot
.016 w
.65169 .91379 m
.65381 .9141 L
s
.008 w
.65381 .9141 Mdot
.016 w
.65381 .9141 m
.65574 .91429 L
s
.008 w
.65574 .91429 Mdot
.016 w
.65574 .91429 m
.65746 .91445 L
s
.008 w
.65746 .91445 Mdot
.016 w
.65746 .91445 m
.65904 .91462 L
s
.008 w
.65904 .91462 Mdot
.016 w
.65904 .91462 m
.6604 .91479 L
s
1 .781 0 r
.008 w
.6604 .91479 Mdot
.016 w
.6604 .91479 m
.66162 .91499 L
s
.008 w
.66162 .91499 Mdot
.016 w
.66162 .91499 m
.6627 .91521 L
s
.008 w
.6627 .91521 Mdot
.016 w
.6627 .91521 m
.66365 .91548 L
s
.008 w
.66365 .91548 Mdot
.016 w
.66365 .91548 m
.66436 .91579 L
s
.008 w
.66436 .91579 Mdot
.016 w
.66436 .91579 m
.66499 .91609 L
s
1 .78 0 r
.008 w
.66499 .91609 Mdot
.016 w
.66499 .91609 m
.6655 .91637 L
s
.008 w
.6655 .91637 Mdot
.016 w
.6655 .91637 m
.66588 .91662 L
s
.008 w
.66588 .91662 Mdot
.016 w
.66588 .91662 m
.66614 .91683 L
s
.008 w
.66614 .91683 Mdot
.016 w
.66614 .91683 m
.66629 .91694 L
s
.008 w
.66629 .91694 Mdot
.016 w
.66629 .91694 m
.66636 .91696 L
s
1 .779 0 r
.008 w
.66636 .91696 Mdot
.016 w
.66636 .91696 m
.66635 .91693 L
s
.008 w
.66635 .91693 Mdot
.016 w
.66635 .91693 m
.66631 .9169 L
s
.008 w
.66631 .9169 Mdot
.016 w
.66631 .9169 m
.66623 .91689 L
s
.008 w
.66623 .91689 Mdot
.016 w
.66623 .91689 m
.66613 .91694 L
s
1 .778 0 r
.008 w
.66613 .91694 Mdot
.016 w
.66613 .91694 m
.66603 .91707 L
s
.008 w
.66603 .91707 Mdot
.016 w
.66603 .91707 m
.66594 .91729 L
s
.008 w
.66594 .91729 Mdot
.016 w
.66594 .91729 m
.66587 .91756 L
s
.008 w
.66587 .91756 Mdot
.016 w
.66587 .91756 m
.66581 .91782 L
s
.008 w
.66581 .91782 Mdot
.016 w
.66581 .91782 m
.66578 .91806 L
s
1 .777 0 r
.008 w
.66578 .91806 Mdot
.016 w
.66578 .91806 m
.66578 .91827 L
s
.008 w
.66578 .91827 Mdot
.016 w
.66578 .91827 m
.66577 .91841 L
s
.008 w
.66577 .91841 Mdot
.016 w
.66577 .91841 m
.66574 .91845 L
s
.008 w
.66574 .91845 Mdot
.016 w
.66574 .91845 m
.66569 .91844 L
s
.008 w
.66569 .91844 Mdot
.016 w
.66569 .91844 m
.66562 .91841 L
s
1 .776 0 r
.008 w
.66562 .91841 Mdot
.016 w
.66562 .91841 m
.66556 .91835 L
s
.008 w
.66556 .91835 Mdot
.016 w
.66556 .91835 m
.66552 .91822 L
s
.008 w
.66552 .91822 Mdot
.016 w
.66552 .91822 m
.66553 .9181 L
s
.008 w
.66553 .9181 Mdot
.016 w
.66553 .9181 m
.66559 .91797 L
s
.008 w
.66559 .91797 Mdot
.016 w
.66559 .91797 m
.66564 .91787 L
s
1 .775 0 r
.008 w
.66564 .91787 Mdot
.016 w
.66564 .91787 m
.66566 .91781 L
s
.008 w
.66566 .91781 Mdot
.016 w
.66566 .91781 m
.66562 .91784 L
s
.008 w
.66562 .91784 Mdot
.016 w
.66562 .91784 m
.66554 .91796 L
s
.008 w
.66554 .91796 Mdot
.016 w
.66554 .91796 m
.66541 .91817 L
s
1 .774 0 r
.008 w
.66541 .91817 Mdot
.016 w
.66541 .91817 m
.66526 .91845 L
s
.008 w
.66526 .91845 Mdot
.016 w
.66526 .91845 m
.66513 .9188 L
s
.008 w
.66513 .9188 Mdot
.016 w
.66513 .9188 m
.66509 .9192 L
s
.008 w
.66509 .9192 Mdot
.016 w
.66509 .9192 m
.66514 .91957 L
s
.008 w
.66514 .91957 Mdot
.016 w
.66514 .91957 m
.66532 .91987 L
s
1 .773 0 r
.008 w
.66532 .91987 Mdot
.016 w
.66532 .91987 m
.66562 .92011 L
s
.008 w
.66562 .92011 Mdot
.016 w
.66562 .92011 m
.666 .9203 L
s
.008 w
.666 .9203 Mdot
.016 w
.666 .9203 m
.66652 .92038 L
s
.008 w
.66652 .92038 Mdot
.016 w
.66652 .92038 m
.66712 .92032 L
s
.008 w
.66712 .92032 Mdot
.016 w
.66712 .92032 m
.66784 .92009 L
s
1 .772 0 r
.008 w
.66784 .92009 Mdot
.016 w
.66784 .92009 m
.66867 .91967 L
s
.008 w
.66867 .91967 Mdot
.016 w
.66867 .91967 m
.66956 .91905 L
s
.008 w
.66956 .91905 Mdot
.016 w
.66956 .91905 m
.6705 .91824 L
s
.008 w
.6705 .91824 Mdot
.016 w
.6705 .91824 m
.67143 .91727 L
s
.008 w
.67143 .91727 Mdot
.016 w
.67143 .91727 m
.67234 .91623 L
s
1 .771 0 r
.008 w
.67234 .91623 Mdot
.016 w
.67234 .91623 m
.67316 .91511 L
s
.008 w
.67316 .91511 Mdot
.016 w
.67316 .91511 m
.67384 .91398 L
s
.008 w
.67384 .91398 Mdot
.016 w
.67384 .91398 m
.67432 .91291 L
s
.008 w
.67432 .91291 Mdot
.016 w
.67432 .91291 m
.67461 .91197 L
s
1 .77 0 r
.008 w
.67461 .91197 Mdot
.016 w
.67461 .91197 m
.6748 .91116 L
s
.008 w
.6748 .91116 Mdot
.016 w
.6748 .91116 m
.67491 .91049 L
s
.008 w
.67491 .91049 Mdot
.016 w
.67491 .91049 m
.67494 .91 L
s
.008 w
.67494 .91 Mdot
.016 w
.67494 .91 m
.67493 .90969 L
s
.008 w
.67493 .90969 Mdot
.016 w
.67493 .90969 m
.67487 .90954 L
s
1 .769 0 r
.008 w
.67487 .90954 Mdot
.016 w
.67487 .90954 m
.6748 .90954 L
s
.008 w
.6748 .90954 Mdot
.016 w
.6748 .90954 m
.67474 .90965 L
s
.008 w
.67474 .90965 Mdot
.016 w
.67474 .90965 m
.67469 .90982 L
s
.008 w
.67469 .90982 Mdot
.016 w
.67469 .90982 m
.67467 .91005 L
s
.008 w
.67467 .91005 Mdot
.016 w
.67467 .91005 m
.67465 .9103 L
s
1 .768 0 r
.008 w
.67465 .9103 Mdot
.016 w
.67465 .9103 m
.67465 .91055 L
s
.008 w
.67465 .91055 Mdot
.016 w
.67465 .91055 m
.67466 .91075 L
s
.008 w
.67466 .91075 Mdot
.016 w
.67466 .91075 m
.67468 .91085 L
s
.008 w
.67468 .91085 Mdot
.016 w
.67468 .91085 m
.6747 .91087 L
s
.008 w
.6747 .91087 Mdot
.016 w
.6747 .91087 m
.67472 .91085 L
s
1 .767 0 r
.008 w
.67472 .91085 Mdot
.016 w
.67472 .91085 m
.67473 .9108 L
s
.008 w
.67473 .9108 Mdot
.016 w
.67473 .9108 m
.67471 .91075 L
s
.008 w
.67471 .91075 Mdot
.016 w
.67471 .91075 m
.67465 .9107 L
s
.008 w
.67465 .9107 Mdot
.016 w
.67465 .9107 m
.67457 .91071 L
s
.008 w
.67457 .91071 Mdot
.016 w
.67457 .91071 m
.67447 .91077 L
s
1 .766 0 r
.008 w
.67447 .91077 Mdot
.016 w
.67447 .91077 m
.67436 .91086 L
s
.008 w
.67436 .91086 Mdot
.016 w
.67436 .91086 m
.67426 .91093 L
s
.008 w
.67426 .91093 Mdot
.016 w
.67426 .91093 m
.67416 .91098 L
s
.008 w
.67416 .91098 Mdot
.016 w
.67416 .91098 m
.67407 .911 L
s
1 .765 0 r
.008 w
.67407 .911 Mdot
.016 w
.67407 .911 m
.67398 .911 L
s
.008 w
.67398 .911 Mdot
.016 w
.67398 .911 m
.67388 .911 L
s
.008 w
.67388 .911 Mdot
.016 w
.67388 .911 m
.67379 .91104 L
s
.008 w
.67379 .91104 Mdot
.016 w
.67379 .91104 m
.67371 .91111 L
s
.008 w
.67371 .91111 Mdot
.016 w
.67371 .91111 m
.67365 .91122 L
s
1 .764 0 r
.008 w
.67365 .91122 Mdot
.016 w
.67365 .91122 m
.67365 .91135 L
s
.008 w
.67365 .91135 Mdot
.016 w
.67365 .91135 m
.67374 .91149 L
s
.008 w
.67374 .91149 Mdot
.016 w
.67374 .91149 m
.67393 .91161 L
s
.008 w
.67393 .91161 Mdot
.016 w
.67393 .91161 m
.67425 .91167 L
s
.008 w
.67425 .91167 Mdot
.016 w
.67425 .91167 m
.67473 .91168 L
s
1 .763 0 r
.008 w
.67473 .91168 Mdot
.016 w
.67473 .91168 m
.67536 .91168 L
s
.008 w
.67536 .91168 Mdot
.016 w
.67536 .91168 m
.67614 .91171 L
s
.008 w
.67614 .91171 Mdot
.016 w
.67614 .91171 m
.67707 .9117 L
s
.008 w
.67707 .9117 Mdot
.016 w
.67707 .9117 m
.67819 .9117 L
s
.008 w
.67819 .9117 Mdot
.016 w
.67819 .9117 m
.67954 .91162 L
s
1 .762 0 r
.008 w
.67954 .91162 Mdot
.016 w
.67954 .91162 m
.68115 .91143 L
s
.008 w
.68115 .91143 Mdot
.016 w
.68115 .91143 m
.68314 .91106 L
s
.008 w
.68314 .91106 Mdot
.016 w
.68314 .91106 m
.68537 .91049 L
s
.008 w
.68537 .91049 Mdot
.016 w
.68537 .91049 m
.68796 .90971 L
s
1 .761 0 r
.008 w
.68796 .90971 Mdot
.016 w
.68796 .90971 m
.69086 .90873 L
s
.008 w
.69086 .90873 Mdot
.016 w
.69086 .90873 m
.69396 .90755 L
s
.008 w
.69396 .90755 Mdot
.016 w
.69396 .90755 m
.69744 .90619 L
s
.008 w
.69744 .90619 Mdot
.016 w
.69744 .90619 m
.7011 .90463 L
s
.008 w
.7011 .90463 Mdot
.016 w
.7011 .90463 m
.70454 .90295 L
s
1 .76 0 r
.008 w
.70454 .90295 Mdot
.016 w
.70454 .90295 m
.70837 .90099 L
s
.008 w
.70837 .90099 Mdot
.016 w
.70837 .90099 m
.71221 .89875 L
s
.008 w
.71221 .89875 Mdot
.016 w
.71221 .89875 m
.71631 .89625 L
s
.008 w
.71631 .89625 Mdot
.016 w
.71631 .89625 m
.72061 .89367 L
s
.008 w
.72061 .89367 Mdot
.016 w
.72061 .89367 m
.72432 .89092 L
s
1 .759 0 r
.008 w
.72432 .89092 Mdot
.016 w
.72432 .89092 m
.72835 .88811 L
s
.008 w
.72835 .88811 Mdot
.016 w
.72835 .88811 m
.7324 .88524 L
s
.008 w
.7324 .88524 Mdot
.016 w
.7324 .88524 m
.73626 .88237 L
s
.008 w
.73626 .88237 Mdot
.016 w
.73626 .88237 m
.73982 .87955 L
s
.008 w
.73982 .87955 Mdot
.016 w
.73982 .87955 m
.74351 .8766 L
s
1 .758 0 r
.008 w
.74351 .8766 Mdot
.016 w
.74351 .8766 m
.74714 .87363 L
s
.008 w
.74714 .87363 Mdot
.016 w
.74714 .87363 m
.75048 .87081 L
s
.008 w
.75048 .87081 Mdot
.016 w
.75048 .87081 m
.75404 .86789 L
s
.008 w
.75404 .86789 Mdot
.016 w
.75404 .86789 m
.75725 .8651 L
s
1 .757 0 r
.008 w
.75725 .8651 Mdot
.016 w
.75725 .8651 m
.76017 .86246 L
s
.008 w
.76017 .86246 Mdot
.016 w
.76017 .86246 m
.76307 .85996 L
s
.008 w
.76307 .85996 Mdot
.016 w
.76307 .85996 m
.76558 .8577 L
s
.008 w
.76558 .8577 Mdot
.016 w
.76558 .8577 m
.76788 .85563 L
s
.008 w
.76788 .85563 Mdot
.016 w
.76788 .85563 m
.76984 .85372 L
s
1 .756 0 r
.008 w
.76984 .85372 Mdot
.016 w
.76984 .85372 m
.77146 .8521 L
s
.008 w
.77146 .8521 Mdot
.016 w
.77146 .8521 m
.77283 .85065 L
s
.008 w
.77283 .85065 Mdot
.016 w
.77283 .85065 m
.7739 .84939 L
s
.008 w
.7739 .84939 Mdot
.016 w
.7739 .84939 m
.77467 .84832 L
s
.008 w
.77467 .84832 Mdot
.016 w
.77467 .84832 m
.77517 .84744 L
s
1 .755 0 r
.008 w
.77517 .84744 Mdot
.016 w
.77517 .84744 m
.7754 .84673 L
s
.008 w
.7754 .84673 Mdot
.016 w
.7754 .84673 m
.77541 .84619 L
s
.008 w
.77541 .84619 Mdot
.016 w
.77541 .84619 m
.77525 .84573 L
s
.008 w
.77525 .84573 Mdot
.016 w
.77525 .84573 m
.77499 .84533 L
s
.008 w
.77499 .84533 Mdot
.016 w
.77499 .84533 m
.77466 .84499 L
s
1 .754 0 r
.008 w
.77466 .84499 Mdot
.016 w
.77466 .84499 m
.77431 .84467 L
s
.008 w
.77431 .84467 Mdot
.016 w
.77431 .84467 m
.77395 .84435 L
s
.008 w
.77395 .84435 Mdot
.016 w
.77395 .84435 m
.7736 .84405 L
s
.008 w
.7736 .84405 Mdot
.016 w
.7736 .84405 m
.77325 .84375 L
s
.008 w
.77325 .84375 Mdot
.016 w
.77325 .84375 m
.77294 .84347 L
s
1 .753 0 r
.008 w
.77294 .84347 Mdot
.016 w
.77294 .84347 m
.7727 .84321 L
s
.008 w
.7727 .84321 Mdot
.016 w
.7727 .84321 m
.77254 .84295 L
s
.008 w
.77254 .84295 Mdot
.016 w
.77254 .84295 m
.77244 .84268 L
s
.008 w
.77244 .84268 Mdot
.016 w
.77244 .84268 m
.77234 .84235 L
s
1 .752 0 r
.008 w
.77234 .84235 Mdot
.016 w
.77234 .84235 m
.77226 .84191 L
s
.008 w
.77226 .84191 Mdot
.016 w
.77226 .84191 m
.77215 .84137 L
s
.008 w
.77215 .84137 Mdot
.016 w
.77215 .84137 m
.77197 .84075 L
s
.008 w
.77197 .84075 Mdot
.016 w
.77197 .84075 m
.77168 .84003 L
s
.008 w
.77168 .84003 Mdot
.016 w
.77168 .84003 m
.77125 .83924 L
s
1 .751 0 r
.008 w
.77125 .83924 Mdot
.016 w
.77125 .83924 m
.77067 .83836 L
s
.008 w
.77067 .83836 Mdot
.016 w
.77067 .83836 m
.76993 .83741 L
s
.008 w
.76993 .83741 Mdot
.016 w
.76993 .83741 m
.76906 .83641 L
s
.008 w
.76906 .83641 Mdot
.016 w
.76906 .83641 m
.7681 .8354 L
s
.008 w
.7681 .8354 Mdot
.016 w
.7681 .8354 m
.76711 .83452 L
s
1 .75 0 r
.008 w
.76711 .83452 Mdot
.016 w
.76711 .83452 m
.76607 .83369 L
s
.008 w
.76607 .83369 Mdot
.016 w
.76607 .83369 m
.76505 .83304 L
s
.008 w
.76505 .83304 Mdot
.016 w
.76505 .83304 m
.76406 .83245 L
s
.008 w
.76406 .83245 Mdot
.016 w
.76406 .83245 m
.76321 .83205 L
s
.008 w
.76321 .83205 Mdot
.016 w
.76321 .83205 m
.76248 .83168 L
s
1 .749 0 r
.008 w
.76248 .83168 Mdot
.016 w
.76248 .83168 m
.7619 .8314 L
s
.008 w
.7619 .8314 Mdot
.016 w
.7619 .8314 m
.76149 .83124 L
s
.008 w
.76149 .83124 Mdot
.016 w
.76149 .83124 m
.76124 .83119 L
s
.008 w
.76124 .83119 Mdot
.016 w
.76124 .83119 m
.76111 .83123 L
s
1 .748 0 r
.008 w
.76111 .83123 Mdot
.016 w
.76111 .83123 m
.76104 .83132 L
s
.008 w
.76104 .83132 Mdot
.016 w
.76104 .83132 m
.76097 .83141 L
s
.008 w
.76097 .83141 Mdot
.016 w
.76097 .83141 m
.76081 .83156 L
s
.008 w
.76081 .83156 Mdot
.016 w
.76081 .83156 m
.76051 .83173 L
s
.008 w
.76051 .83173 Mdot
.016 w
.76051 .83173 m
.76003 .83191 L
s
1 .747 0 r
.008 w
.76003 .83191 Mdot
.016 w
.76003 .83191 m
.75937 .83205 L
s
.008 w
.75937 .83205 Mdot
.016 w
.75937 .83205 m
.75846 .83226 L
s
.008 w
.75846 .83226 Mdot
.016 w
.75846 .83226 m
.75727 .83262 L
s
.008 w
.75727 .83262 Mdot
.016 w
.75727 .83262 m
.7558 .83315 L
s
.008 w
.7558 .83315 Mdot
.016 w
.7558 .83315 m
.75418 .83395 L
s
1 .746 0 r
.008 w
.75418 .83395 Mdot
.016 w
.75418 .83395 m
.75238 .83493 L
s
.008 w
.75238 .83493 Mdot
.016 w
.75238 .83493 m
.75037 .83591 L
s
.008 w
.75037 .83591 Mdot
.016 w
.75037 .83591 m
.7482 .83724 L
s
.008 w
.7482 .83724 Mdot
.016 w
.7482 .83724 m
.74581 .83822 L
s
.008 w
.74581 .83822 Mdot
.016 w
.74581 .83822 m
.74378 .83941 L
s
1 .745 0 r
.008 w
.74378 .83941 Mdot
.016 w
.74378 .83941 m
.74179 .84058 L
s
.008 w
.74179 .84058 Mdot
.016 w
.74179 .84058 m
.73972 .84161 L
s
.008 w
.73972 .84161 Mdot
.016 w
.73972 .84161 m
.73794 .84256 L
s
.008 w
.73794 .84256 Mdot
.016 w
.73794 .84256 m
.73662 .84344 L
s
1 .744 0 r
.008 w
.73662 .84344 Mdot
.016 w
.73662 .84344 m
.73534 .84417 L
s
.008 w
.73534 .84417 Mdot
.016 w
.73534 .84417 m
.73437 .84478 L
s
.008 w
.73437 .84478 Mdot
.016 w
.73437 .84478 m
.73362 .84522 L
s
.008 w
.73362 .84522 Mdot
.016 w
.73362 .84522 m
.73309 .84547 L
s
.008 w
.73309 .84547 Mdot
.016 w
.73309 .84547 m
.73275 .84554 L
s
1 .743 0 r
.008 w
.73275 .84554 Mdot
.016 w
.73275 .84554 m
.73255 .84545 L
s
.008 w
.73255 .84545 Mdot
.016 w
.73255 .84545 m
.73241 .84526 L
s
.008 w
.73241 .84526 Mdot
.016 w
.73241 .84526 m
.73218 .84494 L
s
.008 w
.73218 .84494 Mdot
.016 w
.73218 .84494 m
.73176 .84455 L
s
.008 w
.73176 .84455 Mdot
.016 w
.73176 .84455 m
.73111 .84408 L
s
1 .742 0 r
.008 w
.73111 .84408 Mdot
.016 w
.73111 .84408 m
.73018 .84355 L
s
.008 w
.73018 .84355 Mdot
.016 w
.73018 .84355 m
.7288 .84294 L
s
.008 w
.7288 .84294 Mdot
.016 w
.7288 .84294 m
.72717 .84219 L
s
.008 w
.72717 .84219 Mdot
.016 w
.72717 .84219 m
.72511 .84129 L
s
.008 w
.72511 .84129 Mdot
.016 w
.72511 .84129 m
.72291 .84029 L
s
1 .741 0 r
.008 w
.72291 .84029 Mdot
.016 w
.72291 .84029 m
.72052 .83916 L
s
.008 w
.72052 .83916 Mdot
.016 w
.72052 .83916 m
.71785 .83793 L
s
.008 w
.71785 .83793 Mdot
.016 w
.71785 .83793 m
.71532 .83669 L
s
.008 w
.71532 .83669 Mdot
.016 w
.71532 .83669 m
.71241 .8354 L
s
.008 w
.71241 .8354 Mdot
.016 w
.71241 .8354 m
.70988 .83409 L
s
1 .74 0 r
.008 w
.70988 .83409 Mdot
.016 w
.70988 .83409 m
.70726 .83275 L
s
.008 w
.70726 .83275 Mdot
.016 w
.70726 .83275 m
.70468 .83141 L
s
.008 w
.70468 .83141 Mdot
.016 w
.70468 .83141 m
.70258 .83022 L
s
.008 w
.70258 .83022 Mdot
.016 w
.70258 .83022 m
.70049 .82907 L
s
1 .739 0 r
.008 w
.70049 .82907 Mdot
.016 w
.70049 .82907 m
.69876 .82811 L
s
.008 w
.69876 .82811 Mdot
.016 w
.69876 .82811 m
.69717 .82729 L
s
.008 w
.69717 .82729 Mdot
.016 w
.69717 .82729 m
.69569 .82661 L
s
.008 w
.69569 .82661 Mdot
.016 w
.69569 .82661 m
.6943 .82606 L
s
.008 w
.6943 .82606 Mdot
.016 w
.6943 .82606 m
.69299 .82561 L
s
1 .738 0 r
.008 w
.69299 .82561 Mdot
.016 w
.69299 .82561 m
.69165 .82525 L
s
.008 w
.69165 .82525 Mdot
.016 w
.69165 .82525 m
.69024 .82498 L
s
.008 w
.69024 .82498 Mdot
.016 w
.69024 .82498 m
.68874 .82479 L
s
.008 w
.68874 .82479 Mdot
.016 w
.68874 .82479 m
.68713 .82465 L
s
.008 w
.68713 .82465 Mdot
.016 w
.68713 .82465 m
.68561 .82456 L
s
1 .737 0 r
.008 w
.68561 .82456 Mdot
.016 w
.68561 .82456 m
.6838 .82448 L
s
.008 w
.6838 .82448 Mdot
.016 w
.6838 .82448 m
.68173 .82436 L
s
.008 w
.68173 .82436 Mdot
.016 w
.68173 .82436 m
.67967 .82417 L
s
.008 w
.67967 .82417 Mdot
.016 w
.67967 .82417 m
.6774 .82391 L
s
.008 w
.6774 .82391 Mdot
.016 w
.6774 .82391 m
.67497 .82358 L
s
1 .736 0 r
.008 w
.67497 .82358 Mdot
.016 w
.67497 .82358 m
.67268 .82321 L
s
.008 w
.67268 .82321 Mdot
.016 w
.67268 .82321 m
.67028 .82282 L
s
.008 w
.67028 .82282 Mdot
.016 w
.67028 .82282 m
.66804 .82241 L
s
.008 w
.66804 .82241 Mdot
.016 w
.66804 .82241 m
.66603 .82203 L
s
1 .735 0 r
.008 w
.66603 .82203 Mdot
.016 w
.66603 .82203 m
.66415 .82168 L
s
.008 w
.66415 .82168 Mdot
.016 w
.66415 .82168 m
.66256 .82137 L
s
.008 w
.66256 .82137 Mdot
.016 w
.66256 .82137 m
.66117 .8211 L
s
.008 w
.66117 .8211 Mdot
.016 w
.66117 .8211 m
.66002 .82085 L
s
.008 w
.66002 .82085 Mdot
.016 w
.66002 .82085 m
.65905 .8206 L
s
1 .734 0 r
.008 w
.65905 .8206 Mdot
.016 w
.65905 .8206 m
.65828 .82034 L
s
.008 w
.65828 .82034 Mdot
.016 w
.65828 .82034 m
.65769 .82006 L
s
.008 w
.65769 .82006 Mdot
.016 w
.65769 .82006 m
.65725 .81983 L
s
.008 w
.65725 .81983 Mdot
.016 w
.65725 .81983 m
.65695 .81968 L
s
.008 w
.65695 .81968 Mdot
.016 w
.65695 .81968 m
.65678 .81959 L
s
1 .733 0 r
.008 w
.65678 .81959 Mdot
.016 w
.65678 .81959 m
.65671 .81959 L
s
.008 w
.65671 .81959 Mdot
.016 w
.65671 .81959 m
.65672 .81965 L
s
.008 w
.65672 .81965 Mdot
.016 w
.65672 .81965 m
.65679 .81975 L
s
.008 w
.65679 .81975 Mdot
.016 w
.65679 .81975 m
.6569 .81986 L
s
.008 w
.6569 .81986 Mdot
.016 w
.6569 .81986 m
.657 .81996 L
s
1 .732 0 r
.008 w
.657 .81996 Mdot
.016 w
.657 .81996 m
.65709 .82007 L
s
.008 w
.65709 .82007 Mdot
.016 w
.65709 .82007 m
.65713 .82017 L
s
.008 w
.65713 .82017 Mdot
.016 w
.65713 .82017 m
.65711 .82024 L
s
.008 w
.65711 .82024 Mdot
.016 w
.65711 .82024 m
.657 .82026 L
s
.008 w
.657 .82026 Mdot
.016 w
.657 .82026 m
.65678 .82019 L
s
1 .731 0 r
.008 w
.65678 .82019 Mdot
.016 w
.65678 .82019 m
.65645 .81995 L
s
.008 w
.65645 .81995 Mdot
.016 w
.65645 .81995 m
.65605 .81949 L
s
.008 w
.65605 .81949 Mdot
.016 w
.65605 .81949 m
.6556 .81881 L
s
.008 w
.6556 .81881 Mdot
.016 w
.6556 .81881 m
.65511 .81792 L
s
1 .73 0 r
.008 w
.65511 .81792 Mdot
.016 w
.65511 .81792 m
.65459 .81689 L
s
.008 w
.65459 .81689 Mdot
.016 w
.65459 .81689 m
.654 .81576 L
s
.008 w
.654 .81576 Mdot
.016 w
.654 .81576 m
.65333 .81461 L
s
.008 w
.65333 .81461 Mdot
.016 w
.65333 .81461 m
.65259 .81357 L
s
.008 w
.65259 .81357 Mdot
.016 w
.65259 .81357 m
.65179 .81248 L
s
1 .729 0 r
.008 w
.65179 .81248 Mdot
.016 w
.65179 .81248 m
.65097 .81155 L
s
.008 w
.65097 .81155 Mdot
.016 w
.65097 .81155 m
.65015 .81071 L
s
.008 w
.65015 .81071 Mdot
.016 w
.65015 .81071 m
.64934 .80999 L
s
.008 w
.64934 .80999 Mdot
.016 w
.64934 .80999 m
.64852 .80939 L
s
.008 w
.64852 .80939 Mdot
.016 w
.64852 .80939 m
.64767 .80891 L
s
1 .728 0 r
.008 w
.64767 .80891 Mdot
.016 w
.64767 .80891 m
.64678 .80855 L
s
.008 w
.64678 .80855 Mdot
.016 w
.64678 .80855 m
.64583 .80831 L
s
.008 w
.64583 .80831 Mdot
.016 w
.64583 .80831 m
.64473 .80815 L
s
.008 w
.64473 .80815 Mdot
.016 w
.64473 .80815 m
.64348 .808 L
s
.008 w
.64348 .808 Mdot
.016 w
.64348 .808 m
.64211 .80782 L
s
1 .727 0 r
.008 w
.64211 .80782 Mdot
.016 w
.64211 .80782 m
.64066 .80754 L
s
.008 w
.64066 .80754 Mdot
.016 w
.64066 .80754 m
.63917 .80711 L
s
.008 w
.63917 .80711 Mdot
.016 w
.63917 .80711 m
.63767 .80653 L
s
.008 w
.63767 .80653 Mdot
.016 w
.63767 .80653 m
.63634 .80582 L
s
1 .726 0 r
.008 w
.63634 .80582 Mdot
.016 w
.63634 .80582 m
.63495 .80507 L
s
.008 w
.63495 .80507 Mdot
.016 w
.63495 .80507 m
.63365 .8043 L
s
.008 w
.63365 .8043 Mdot
.016 w
.63365 .8043 m
.63235 .80354 L
s
.008 w
.63235 .80354 Mdot
.016 w
.63235 .80354 m
.63106 .80282 L
s
.008 w
.63106 .80282 Mdot
.016 w
.63106 .80282 m
.62988 .80216 L
s
1 .725 0 r
.008 w
.62988 .80216 Mdot
.016 w
.62988 .80216 m
.62877 .80156 L
s
.008 w
.62877 .80156 Mdot
.016 w
.62877 .80156 m
.62775 .80101 L
s
.008 w
.62775 .80101 Mdot
.016 w
.62775 .80101 m
.62684 .8005 L
s
.008 w
.62684 .8005 Mdot
.016 w
.62684 .8005 m
.62604 .80004 L
s
.008 w
.62604 .80004 Mdot
.016 w
.62604 .80004 m
.62537 .79963 L
s
1 .724 0 r
.008 w
.62537 .79963 Mdot
.016 w
.62537 .79963 m
.62476 .79929 L
s
.008 w
.62476 .79929 Mdot
.016 w
.62476 .79929 m
.62418 .799 L
s
.008 w
.62418 .799 Mdot
.016 w
.62418 .799 m
.62364 .79877 L
s
.008 w
.62364 .79877 Mdot
.016 w
.62364 .79877 m
.62314 .79856 L
s
.008 w
.62314 .79856 Mdot
.016 w
.62314 .79856 m
.62272 .7984 L
s
1 .723 0 r
.008 w
.62272 .7984 Mdot
.016 w
.62272 .7984 m
.62235 .79826 L
s
.008 w
.62235 .79826 Mdot
.016 w
.62235 .79826 m
.62205 .79814 L
s
.008 w
.62205 .79814 Mdot
.016 w
.62205 .79814 m
.62183 .79801 L
s
.008 w
.62183 .79801 Mdot
.016 w
.62183 .79801 m
.62169 .79787 L
s
1 .722 0 r
.008 w
.62169 .79787 Mdot
.016 w
.62169 .79787 m
.62161 .79774 L
s
.008 w
.62161 .79774 Mdot
.016 w
.62161 .79774 m
.62159 .79764 L
s
.008 w
.62159 .79764 Mdot
.016 w
.62159 .79764 m
.62159 .79759 L
s
.008 w
.62159 .79759 Mdot
.016 w
.62159 .79759 m
.6216 .79757 L
s
.008 w
.6216 .79757 Mdot
.016 w
.6216 .79757 m
.62162 .79759 L
s
1 .721 0 r
.008 w
.62162 .79759 Mdot
.016 w
.62162 .79759 m
.62165 .79762 L
s
.008 w
.62165 .79762 Mdot
.016 w
.62165 .79762 m
.62169 .79765 L
s
.008 w
.62169 .79765 Mdot
.016 w
.62169 .79765 m
.62175 .79768 L
s
.008 w
.62175 .79768 Mdot
.016 w
.62175 .79768 m
.62182 .79768 L
s
.008 w
.62182 .79768 Mdot
.016 w
.62182 .79768 m
.62189 .79769 L
s
1 .72 0 r
.008 w
.62189 .79769 Mdot
.016 w
.62189 .79769 m
.62197 .79771 L
s
.008 w
.62197 .79771 Mdot
.016 w
.62197 .79771 m
.62203 .79776 L
s
.008 w
.62203 .79776 Mdot
.016 w
.62203 .79776 m
.62204 .79783 L
s
.008 w
.62204 .79783 Mdot
.016 w
.62204 .79783 m
.62198 .7979 L
s
.008 w
.62198 .7979 Mdot
.016 w
.62198 .7979 m
.62185 .79797 L
s
1 .719 0 r
.008 w
.62185 .79797 Mdot
.016 w
.62185 .79797 m
.62162 .79801 L
s
.008 w
.62162 .79801 Mdot
.016 w
.62162 .79801 m
.62131 .79801 L
s
.008 w
.62131 .79801 Mdot
.016 w
.62131 .79801 m
.62089 .79792 L
s
.008 w
.62089 .79792 Mdot
.016 w
.62089 .79792 m
.62035 .79772 L
s
.008 w
.62035 .79772 Mdot
.016 w
.62035 .79772 m
.6197 .79741 L
s
1 .718 0 r
.008 w
.6197 .79741 Mdot
.016 w
.6197 .79741 m
.61896 .79698 L
s
.008 w
.61896 .79698 Mdot
.016 w
.61896 .79698 m
.61815 .79643 L
s
.008 w
.61815 .79643 Mdot
.016 w
.61815 .79643 m
.6173 .79578 L
s
.008 w
.6173 .79578 Mdot
.016 w
.6173 .79578 m
.61645 .7951 L
s
1 .717 0 r
.008 w
.61645 .7951 Mdot
.016 w
.61645 .7951 m
.61561 .79435 L
s
.008 w
.61561 .79435 Mdot
.016 w
.61561 .79435 m
.61475 .79358 L
s
.008 w
.61475 .79358 Mdot
.016 w
.61475 .79358 m
.6139 .79282 L
s
.008 w
.6139 .79282 Mdot
.016 w
.6139 .79282 m
.61303 .79209 L
s
.008 w
.61303 .79209 Mdot
.016 w
.61303 .79209 m
.61217 .79144 L
s
1 .716 0 r
.008 w
.61217 .79144 Mdot
.016 w
.61217 .79144 m
.61125 .79084 L
s
.008 w
.61125 .79084 Mdot
.016 w
.61125 .79084 m
.61026 .79029 L
s
.008 w
.61026 .79029 Mdot
.016 w
.61026 .79029 m
.60918 .78978 L
s
.008 w
.60918 .78978 Mdot
.016 w
.60918 .78978 m
.608 .78931 L
s
.008 w
.608 .78931 Mdot
.016 w
.608 .78931 m
.60674 .78887 L
s
1 .715 0 r
.008 w
.60674 .78887 Mdot
.016 w
.60674 .78887 m
.60555 .78842 L
s
.008 w
.60555 .78842 Mdot
.016 w
.60555 .78842 m
.60425 .78797 L
s
.008 w
.60425 .78797 Mdot
.016 w
.60425 .78797 m
.60304 .78748 L
s
.008 w
.60304 .78748 Mdot
.016 w
.60304 .78748 m
.60184 .78698 L
s
.008 w
.60184 .78698 Mdot
.016 w
.60184 .78698 m
.6007 .78648 L
s
1 .714 0 r
.008 w
.6007 .78648 Mdot
.016 w
.6007 .78648 m
.59966 .78598 L
s
.008 w
.59966 .78598 Mdot
.016 w
.59966 .78598 m
.59877 .78548 L
s
.008 w
.59877 .78548 Mdot
.016 w
.59877 .78548 m
.59803 .78499 L
s
.008 w
.59803 .78499 Mdot
.016 w
.59803 .78499 m
.59748 .78456 L
s
1 .713 0 r
.008 w
.59748 .78456 Mdot
.016 w
.59748 .78456 m
.59711 .7842 L
s
.008 w
.59711 .7842 Mdot
.016 w
.59711 .7842 m
.59693 .78391 L
s
.008 w
.59693 .78391 Mdot
.016 w
.59693 .78391 m
.59691 .78369 L
s
.008 w
.59691 .78369 Mdot
.016 w
.59691 .78369 m
.59699 .78353 L
s
.008 w
.59699 .78353 Mdot
.016 w
.59699 .78353 m
.59715 .78344 L
s
1 .712 0 r
.008 w
.59715 .78344 Mdot
.016 w
.59715 .78344 m
.59735 .78343 L
s
.008 w
.59735 .78343 Mdot
.016 w
.59735 .78343 m
.59757 .7835 L
s
.008 w
.59757 .7835 Mdot
.016 w
.59757 .7835 m
.59773 .78366 L
s
.008 w
.59773 .78366 Mdot
.016 w
.59773 .78366 m
.59776 .78389 L
s
.008 w
.59776 .78389 Mdot
.016 w
.59776 .78389 m
.59758 .78418 L
s
1 .711 0 r
.008 w
.59758 .78418 Mdot
.016 w
.59758 .78418 m
.59717 .78454 L
s
.008 w
.59717 .78454 Mdot
.016 w
.59717 .78454 m
.5965 .78496 L
s
.008 w
.5965 .78496 Mdot
.016 w
.5965 .78496 m
.59553 .78546 L
s
.008 w
.59553 .78546 Mdot
.016 w
.59553 .78546 m
.59422 .78602 L
s
.008 w
.59422 .78602 Mdot
.016 w
.59422 .78602 m
.59275 .78663 L
s
1 .71 0 r
.008 w
.59275 .78663 Mdot
.016 w
.59275 .78663 m
.59094 .78729 L
s
.008 w
.59094 .78729 Mdot
.016 w
.59094 .78729 m
.58882 .78799 L
s
.008 w
.58882 .78799 Mdot
.016 w
.58882 .78799 m
.58671 .78872 L
s
.008 w
.58671 .78872 Mdot
.016 w
.58671 .78872 m
.58446 .78945 L
s
1 .709 0 r
.008 w
.58446 .78945 Mdot
.016 w
.58446 .78945 m
.58171 .79015 L
s
.008 w
.58171 .79015 Mdot
.016 w
.58171 .79015 m
.57928 .79079 L
s
.008 w
.57928 .79079 Mdot
.016 w
.57928 .79079 m
.57666 .79137 L
s
.008 w
.57666 .79137 Mdot
.016 w
.57666 .79137 m
.57405 .79185 L
s
.008 w
.57405 .79185 Mdot
.016 w
.57405 .79185 m
.57158 .79226 L
s
1 .708 0 r
.008 w
.57158 .79226 Mdot
.016 w
.57158 .79226 m
.56924 .7926 L
s
.008 w
.56924 .7926 Mdot
.016 w
.56924 .7926 m
.56735 .7929 L
s
.008 w
.56735 .7929 Mdot
.016 w
.56735 .7929 m
.56566 .79316 L
s
.008 w
.56566 .79316 Mdot
.016 w
.56566 .79316 m
.56419 .79339 L
s
.008 w
.56419 .79339 Mdot
.016 w
.56419 .79339 m
.56295 .79357 L
s
1 .707 0 r
.008 w
.56295 .79357 Mdot
.016 w
.56295 .79357 m
.56201 .7937 L
s
.008 w
.56201 .7937 Mdot
.016 w
.56201 .7937 m
.56126 .79378 L
s
.008 w
.56126 .79378 Mdot
.016 w
.56126 .79378 m
.56069 .79381 L
s
.008 w
.56069 .79381 Mdot
.016 w
.56069 .79381 m
.56031 .7938 L
s
.008 w
.56031 .7938 Mdot
.016 w
.56031 .7938 m
.56016 .79378 L
s
1 .706 0 r
.008 w
.56016 .79378 Mdot
.016 w
.56016 .79378 m
.56016 .79375 L
s
.008 w
.56016 .79375 Mdot
.016 w
.56016 .79375 m
.56029 .79372 L
s
.008 w
.56029 .79372 Mdot
.016 w
.56029 .79372 m
.5605 .7937 L
s
.008 w
.5605 .7937 Mdot
.016 w
.5605 .7937 m
.56074 .79367 L
s
.008 w
.56074 .79367 Mdot
.016 w
.56074 .79367 m
.56095 .79365 L
s
1 .705 0 r
.008 w
.56095 .79365 Mdot
.016 w
.56095 .79365 m
.56113 .79364 L
s
.008 w
.56113 .79364 Mdot
.016 w
.56113 .79364 m
.56125 .79363 L
s
.008 w
.56125 .79363 Mdot
.016 w
.56125 .79363 m
.56128 .79363 L
s
.008 w
.56128 .79363 Mdot
.016 w
.56128 .79363 m
.56125 .79363 L
s
1 .704 0 r
.008 w
.56125 .79363 Mdot
.016 w
.56125 .79363 m
.56122 .79363 L
s
.008 w
.56122 .79363 Mdot
.016 w
.56122 .79363 m
.56119 .79364 L
s
.008 w
.56119 .79364 Mdot
.016 w
.56119 .79364 m
.56118 .79364 L
s
.008 w
.56118 .79364 Mdot
.016 w
.56118 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
1 .703 0 r
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
1 .702 0 r
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56117 .79364 L
s
.008 w
.56117 .79364 Mdot
.016 w
.56117 .79364 m
.56118 .79363 L
s
.008 w
.56118 .79363 Mdot
.016 w
.56118 .79363 m
.56122 .7936 L
s
1 .701 0 r
.008 w
.56122 .7936 Mdot
.016 w
.56122 .7936 m
.56131 .79354 L
s
.008 w
.56131 .79354 Mdot
.016 w
.56131 .79354 m
.56143 .79345 L
s
.008 w
.56143 .79345 Mdot
.016 w
.56143 .79345 m
.56156 .79334 L
s
.008 w
.56156 .79334 Mdot
.016 w
.56156 .79334 m
.56168 .79324 L
s
1 .7 0 r
.008 w
.56168 .79324 Mdot
.016 w
.56168 .79324 m
.56174 .79317 L
s
.008 w
.56174 .79317 Mdot
.016 w
.56174 .79317 m
.56173 .79316 L
s
.008 w
.56173 .79316 Mdot
.016 w
.56173 .79316 m
.56161 .7932 L
s
.008 w
.56161 .7932 Mdot
.016 w
.56161 .7932 m
.56133 .79335 L
s
.008 w
.56133 .79335 Mdot
.016 w
.56133 .79335 m
.56084 .79365 L
s
1 .699 0 r
.008 w
.56084 .79365 Mdot
.016 w
.56084 .79365 m
.56011 .79415 L
s
.008 w
.56011 .79415 Mdot
.016 w
.56011 .79415 m
.55912 .79487 L
s
.008 w
.55912 .79487 Mdot
.016 w
.55912 .79487 m
.55783 .79587 L
s
.008 w
.55783 .79587 Mdot
.016 w
.55783 .79587 m
.55637 .79712 L
s
.008 w
.55637 .79712 Mdot
.016 w
.55637 .79712 m
.55465 .79865 L
s
1 .698 0 r
.008 w
.55465 .79865 Mdot
.016 w
.55465 .79865 m
.55263 .80051 L
s
.008 w
.55263 .80051 Mdot
.016 w
.55263 .80051 m
.55038 .80257 L
s
.008 w
.55038 .80257 Mdot
.016 w
.55038 .80257 m
.54806 .80488 L
s
.008 w
.54806 .80488 Mdot
.016 w
.54806 .80488 m
.54542 .80754 L
s
.008 w
.54542 .80754 Mdot
.016 w
.54542 .80754 m
.54274 .80997 L
s
1 .697 0 r
.008 w
.54274 .80997 Mdot
.016 w
.54274 .80997 m
.53982 .81302 L
s
.008 w
.53982 .81302 Mdot
.016 w
.53982 .81302 m
.53712 .81556 L
s
.008 w
.53712 .81556 Mdot
.016 w
.53712 .81556 m
.53413 .81828 L
s
.008 w
.53413 .81828 Mdot
.016 w
.53413 .81828 m
.53118 .82114 L
s
1 .696 0 r
.008 w
.53118 .82114 Mdot
.016 w
.53118 .82114 m
.52823 .82384 L
s
.008 w
.52823 .82384 Mdot
.016 w
.52823 .82384 m
.52506 .82663 L
s
.008 w
.52506 .82663 Mdot
.016 w
.52506 .82663 m
.52235 .82901 L
s
.008 w
.52235 .82901 Mdot
.016 w
.52235 .82901 m
.51927 .83165 L
s
.008 w
.51927 .83165 Mdot
.016 w
.51927 .83165 m
.51665 .83386 L
s
1 .695 0 r
.008 w
.51665 .83386 Mdot
.016 w
.51665 .83386 m
.51394 .83612 L
s
.008 w
.51394 .83612 Mdot
.016 w
.51394 .83612 m
.51143 .83846 L
s
.008 w
.51143 .83846 Mdot
.016 w
.51143 .83846 m
.50876 .84083 L
s
.008 w
.50876 .84083 Mdot
.016 w
.50876 .84083 m
.50657 .84307 L
s
.008 w
.50657 .84307 Mdot
.016 w
.50657 .84307 m
.5044 .84551 L
s
1 .694 0 r
.008 w
.5044 .84551 Mdot
.016 w
.5044 .84551 m
.5023 .84794 L
s
.008 w
.5023 .84794 Mdot
.016 w
.5023 .84794 m
.50028 .85046 L
s
.008 w
.50028 .85046 Mdot
.016 w
.50028 .85046 m
.49828 .85314 L
s
.008 w
.49828 .85314 Mdot
.016 w
.49828 .85314 m
.49645 .85548 L
s
.008 w
.49645 .85548 Mdot
.016 w
.49645 .85548 m
.49458 .85819 L
s
1 .693 0 r
.008 w
.49458 .85819 Mdot
.016 w
.49458 .85819 m
.49262 .86073 L
s
.008 w
.49262 .86073 Mdot
.016 w
.49262 .86073 m
.49058 .86353 L
s
.008 w
.49058 .86353 Mdot
.016 w
.49058 .86353 m
.48864 .86632 L
s
.008 w
.48864 .86632 Mdot
.016 w
.48864 .86632 m
.48679 .8687 L
s
.008 w
.48679 .8687 Mdot
.016 w
.48679 .8687 m
.48482 .87113 L
s
1 .692 0 r
.008 w
.48482 .87113 Mdot
.016 w
.48482 .87113 m
.48273 .87359 L
s
.008 w
.48273 .87359 Mdot
.016 w
.48273 .87359 m
.4807 .87572 L
s
.008 w
.4807 .87572 Mdot
.016 w
.4807 .87572 m
.47878 .87766 L
s
.008 w
.47878 .87766 Mdot
.016 w
.47878 .87766 m
.47692 .87945 L
s
1 .691 0 r
.008 w
.47692 .87945 Mdot
.016 w
.47692 .87945 m
.47523 .881 L
s
.008 w
.47523 .881 Mdot
.016 w
.47523 .881 m
.47372 .88231 L
s
.008 w
.47372 .88231 Mdot
.016 w
.47372 .88231 m
.47232 .88344 L
s
.008 w
.47232 .88344 Mdot
.016 w
.47232 .88344 m
.47103 .88439 L
s
.008 w
.47103 .88439 Mdot
.016 w
.47103 .88439 m
.46984 .88514 L
s
1 .69 0 r
.008 w
.46984 .88514 Mdot
.016 w
.46984 .88514 m
.46877 .88572 L
s
.008 w
.46877 .88572 Mdot
.016 w
.46877 .88572 m
.46769 .88614 L
s
.008 w
.46769 .88614 Mdot
.016 w
.46769 .88614 m
.46655 .88642 L
s
.008 w
.46655 .88642 Mdot
.016 w
.46655 .88642 m
.46536 .88657 L
s
.008 w
.46536 .88657 Mdot
.016 w
.46536 .88657 m
.46409 .88661 L
s
1 .689 0 r
.008 w
.46409 .88661 Mdot
.016 w
.46409 .88661 m
.46274 .88658 L
s
.008 w
.46274 .88658 Mdot
.016 w
.46274 .88658 m
.46133 .88649 L
s
.008 w
.46133 .88649 Mdot
.016 w
.46133 .88649 m
.46008 .88635 L
s
.008 w
.46008 .88635 Mdot
.016 w
.46008 .88635 m
.45876 .88619 L
s
.008 w
.45876 .88619 Mdot
.016 w
.45876 .88619 m
.45746 .88602 L
s
1 .688 0 r
.008 w
.45746 .88602 Mdot
.016 w
.45746 .88602 m
.45624 .88585 L
s
.008 w
.45624 .88585 Mdot
.016 w
.45624 .88585 m
.45504 .88568 L
s
.008 w
.45504 .88568 Mdot
.016 w
.45504 .88568 m
.45399 .88553 L
s
.008 w
.45399 .88553 Mdot
.016 w
.45399 .88553 m
.45307 .8854 L
s
1 .687 0 r
.008 w
.45307 .8854 Mdot
.016 w
.45307 .8854 m
.45234 .88528 L
s
.008 w
.45234 .88528 Mdot
.016 w
.45234 .88528 m
.45181 .88517 L
s
.008 w
.45181 .88517 Mdot
.016 w
.45181 .88517 m
.45152 .88504 L
s
.008 w
.45152 .88504 Mdot
.016 w
.45152 .88504 m
.45145 .8849 L
s
.008 w
.45145 .8849 Mdot
.016 w
.45145 .8849 m
.45157 .88475 L
s
1 .686 0 r
.008 w
.45157 .88475 Mdot
.016 w
.45157 .88475 m
.45178 .88462 L
s
.008 w
.45178 .88462 Mdot
.016 w
.45178 .88462 m
.45201 .88452 L
s
.008 w
.45201 .88452 Mdot
.016 w
.45201 .88452 m
.45218 .88447 L
s
.008 w
.45218 .88447 Mdot
.016 w
.45218 .88447 m
.45223 .8845 L
s
.008 w
.45223 .8845 Mdot
.016 w
.45223 .8845 m
.45211 .88466 L
s
1 .685 0 r
.008 w
.45211 .88466 Mdot
.016 w
.45211 .88466 m
.45177 .88499 L
s
.008 w
.45177 .88499 Mdot
.016 w
.45177 .88499 m
.45121 .88555 L
s
.008 w
.45121 .88555 Mdot
.016 w
.45121 .88555 m
.4504 .88633 L
s
.008 w
.4504 .88633 Mdot
.016 w
.4504 .88633 m
.44939 .88745 L
s
.008 w
.44939 .88745 Mdot
.016 w
.44939 .88745 m
.44815 .88894 L
s
1 .684 0 r
.008 w
.44815 .88894 Mdot
.016 w
.44815 .88894 m
.44682 .89058 L
s
.008 w
.44682 .89058 Mdot
.016 w
.44682 .89058 m
.4453 .89252 L
s
.008 w
.4453 .89252 Mdot
.016 w
.4453 .89252 m
.44354 .89482 L
s
.008 w
.44354 .89482 Mdot
.016 w
.44354 .89482 m
.44161 .89726 L
s
.008 w
.44161 .89726 Mdot
.016 w
.44161 .89726 m
.43955 .90024 L
s
1 .683 0 r
.008 w
.43955 .90024 Mdot
.016 w
.43955 .90024 m
.43747 .90297 L
s
.008 w
.43747 .90297 Mdot
.016 w
.43747 .90297 m
.43522 .90602 L
s
.008 w
.43522 .90602 Mdot
.016 w
.43522 .90602 m
.43301 .90932 L
s
.008 w
.43301 .90932 Mdot
.016 w
.43301 .90932 m
.43097 .91235 L
s
1 .682 0 r
.008 w
.43097 .91235 Mdot
.016 w
.43097 .91235 m
.42892 .91562 L
s
.008 w
.42892 .91562 Mdot
.016 w
.42892 .91562 m
.42692 .91885 L
s
.008 w
.42692 .91885 Mdot
.016 w
.42692 .91885 m
.42523 .92139 L
s
.008 w
.42523 .92139 Mdot
.016 w
.42523 .92139 m
.42371 .92389 L
s
.008 w
.42371 .92389 Mdot
.016 w
.42371 .92389 m
.42238 .92631 L
s
1 .681 0 r
.008 w
.42238 .92631 Mdot
.016 w
.42238 .92631 m
.42123 .92856 L
s
.008 w
.42123 .92856 Mdot
.016 w
.42123 .92856 m
.42039 .93022 L
s
.008 w
.42039 .93022 Mdot
.016 w
.42039 .93022 m
.41974 .93167 L
s
.008 w
.41974 .93167 Mdot
.016 w
.41974 .93167 m
.41922 .93288 L
s
.008 w
.41922 .93288 Mdot
.016 w
.41922 .93288 m
.41879 .93381 L
s
1 .68 0 r
.008 w
.41879 .93381 Mdot
.016 w
.41879 .93381 m
.41837 .93446 L
s
.008 w
.41837 .93446 Mdot
.016 w
.41837 .93446 m
.41783 .93486 L
s
.008 w
.41783 .93486 Mdot
.016 w
.41783 .93486 m
.41708 .93506 L
s
.008 w
.41708 .93506 Mdot
.016 w
.41708 .93506 m
.41605 .93509 L
s
.008 w
.41605 .93509 Mdot
.016 w
.41605 .93509 m
.41466 .93499 L
s
1 .679 0 r
.008 w
.41466 .93499 Mdot
.016 w
.41466 .93499 m
.41289 .93476 L
s
.008 w
.41289 .93476 Mdot
.016 w
.41289 .93476 m
.41121 .93437 L
s
.008 w
.41121 .93437 Mdot
.016 w
.41121 .93437 m
.40913 .93391 L
s
.008 w
.40913 .93391 Mdot
.016 w
.40913 .93391 m
.40647 .93343 L
s
1 .678 0 r
.008 w
.40647 .93343 Mdot
.016 w
.40647 .93343 m
.40414 .93292 L
s
.008 w
.40414 .93292 Mdot
.016 w
.40414 .93292 m
.40147 .9324 L
s
.008 w
.40147 .9324 Mdot
.016 w
.40147 .9324 m
.39836 .93182 L
s
.008 w
.39836 .93182 Mdot
.016 w
.39836 .93182 m
.39579 .9312 L
s
.008 w
.39579 .9312 Mdot
.016 w
.39579 .9312 m
.3931 .93056 L
s
1 .677 0 r
.008 w
.3931 .93056 Mdot
.016 w
.3931 .93056 m
.39065 .9299 L
s
.008 w
.39065 .9299 Mdot
.016 w
.39065 .9299 m
.3884 .92927 L
s
.008 w
.3884 .92927 Mdot
.016 w
.3884 .92927 m
.38634 .92866 L
s
.008 w
.38634 .92866 Mdot
.016 w
.38634 .92866 m
.38467 .92809 L
s
.008 w
.38467 .92809 Mdot
.016 w
.38467 .92809 m
.3833 .92759 L
s
1 .676 0 r
.008 w
.3833 .92759 Mdot
.016 w
.3833 .92759 m
.38214 .92719 L
s
.008 w
.38214 .92719 Mdot
.016 w
.38214 .92719 m
.38117 .9269 L
s
.008 w
.38117 .9269 Mdot
.016 w
.38117 .9269 m
.38043 .92667 L
s
.008 w
.38043 .92667 Mdot
.016 w
.38043 .92667 m
.37992 .92649 L
s
.008 w
.37992 .92649 Mdot
.016 w
.37992 .92649 m
.37961 .92632 L
s
1 .675 0 r
.008 w
.37961 .92632 Mdot
.016 w
.37961 .92632 m
.3795 .92617 L
s
.008 w
.3795 .92617 Mdot
.016 w
.3795 .92617 m
.37954 .92603 L
s
.008 w
.37954 .92603 Mdot
.016 w
.37954 .92603 m
.3797 .92589 L
s
.008 w
.3797 .92589 Mdot
.016 w
.3797 .92589 m
.37994 .92576 L
s
1 .674 0 r
.008 w
.37994 .92576 Mdot
.016 w
.37994 .92576 m
.38021 .92564 L
s
.008 w
.38021 .92564 Mdot
.016 w
.38021 .92564 m
.3805 .92556 L
s
.008 w
.3805 .92556 Mdot
.016 w
.3805 .92556 m
.38078 .92552 L
s
.008 w
.38078 .92552 Mdot
.016 w
.38078 .92552 m
.38104 .92552 L
s
.008 w
.38104 .92552 Mdot
.016 w
.38104 .92552 m
.38128 .92554 L
s
1 .673 0 r
.008 w
.38128 .92554 Mdot
.016 w
.38128 .92554 m
.38148 .92556 L
s
.008 w
.38148 .92556 Mdot
.016 w
.38148 .92556 m
.38163 .92558 L
s
.008 w
.38163 .92558 Mdot
.016 w
.38163 .92558 m
.38171 .92559 L
s
.008 w
.38171 .92559 Mdot
.016 w
.38171 .92559 m
.38173 .92559 L
s
.008 w
.38173 .92559 Mdot
.016 w
.38173 .92559 m
.38171 .92559 L
s
1 .672 0 r
.008 w
.38171 .92559 Mdot
.016 w
.38171 .92559 m
.38168 .92559 L
s
.008 w
.38168 .92559 Mdot
.016 w
.38168 .92559 m
.38163 .9256 L
s
.008 w
.38163 .9256 Mdot
.016 w
.38163 .9256 m
.3816 .9256 L
s
.008 w
.3816 .9256 Mdot
.016 w
.3816 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
1 .671 0 r
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
1 .67 0 r
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38158 .9256 L
s
.008 w
.38158 .9256 Mdot
.016 w
.38158 .9256 m
.38159 .9256 L
s
1 .669 0 r
.008 w
.38159 .9256 Mdot
.016 w
.38159 .9256 m
.38162 .92563 L
s
.008 w
.38162 .92563 Mdot
.016 w
.38162 .92563 m
.38169 .92569 L
s
.008 w
.38169 .92569 Mdot
.016 w
.38169 .92569 m
.3818 .92578 L
s
.008 w
.3818 .92578 Mdot
.016 w
.3818 .92578 m
.38192 .9259 L
s
.008 w
.38192 .9259 Mdot
.016 w
.38192 .9259 m
.38204 .92601 L
s
1 .668 0 r
.008 w
.38204 .92601 Mdot
.016 w
.38204 .92601 m
.38211 .9261 L
s
.008 w
.38211 .9261 Mdot
.016 w
.38211 .9261 m
.3821 .92612 L
s
.008 w
.3821 .92612 Mdot
.016 w
.3821 .92612 m
.38195 .92603 L
s
.008 w
.38195 .92603 Mdot
.016 w
.38195 .92603 m
.38163 .9258 L
s
.008 w
.38163 .9258 Mdot
.016 w
.38163 .9258 m
.38113 .92541 L
s
1 .667 0 r
.008 w
.38113 .92541 Mdot
.016 w
.38113 .92541 m
.38044 .92482 L
s
.008 w
.38044 .92482 Mdot
.016 w
.38044 .92482 m
.37954 .92402 L
s
.008 w
.37954 .92402 Mdot
.016 w
.37954 .92402 m
.37844 .92302 L
s
.008 w
.37844 .92302 Mdot
.016 w
.37844 .92302 m
.37726 .92188 L
s
.008 w
.37726 .92188 Mdot
.016 w
.37726 .92188 m
.37584 .9205 L
s
1 .666 0 r
.008 w
.37584 .9205 Mdot
.016 w
.37584 .9205 m
.37419 .91892 L
s
.008 w
.37419 .91892 Mdot
.016 w
.37419 .91892 m
.37251 .9172 L
s
.008 w
.37251 .9172 Mdot
.016 w
.37251 .9172 m
.37064 .91529 L
s
.008 w
.37064 .91529 Mdot
.016 w
.37064 .91529 m
.36869 .91317 L
s
1 .665 0 r
.008 w
.36869 .91317 Mdot
.016 w
.36869 .91317 m
.36675 .91105 L
s
.008 w
.36675 .91105 Mdot
.016 w
.36675 .91105 m
.3647 .90876 L
s
.008 w
.3647 .90876 Mdot
.016 w
.3647 .90876 m
.36274 .90643 L
s
.008 w
.36274 .90643 Mdot
.016 w
.36274 .90643 m
.36072 .90414 L
s
.008 w
.36072 .90414 Mdot
.016 w
.36072 .90414 m
.35873 .90171 L
s
1 .664 0 r
.008 w
.35873 .90171 Mdot
.016 w
.35873 .90171 m
.35676 .89936 L
s
.008 w
.35676 .89936 Mdot
.016 w
.35676 .89936 m
.35478 .89686 L
s
.008 w
.35478 .89686 Mdot
.016 w
.35478 .89686 m
.35279 .89431 L
s
.008 w
.35279 .89431 Mdot
.016 w
.35279 .89431 m
.3508 .89167 L
s
.008 w
.3508 .89167 Mdot
.016 w
.3508 .89167 m
.34888 .88896 L
s
1 .663 0 r
.008 w
.34888 .88896 Mdot
.016 w
.34888 .88896 m
.34693 .88613 L
s
.008 w
.34693 .88613 Mdot
.016 w
.34693 .88613 m
.3451 .88334 L
s
.008 w
.3451 .88334 Mdot
.016 w
.3451 .88334 m
.34323 .88048 L
s
.008 w
.34323 .88048 Mdot
.016 w
.34323 .88048 m
.34137 .87766 L
s
.008 w
.34137 .87766 Mdot
.016 w
.34137 .87766 m
.33958 .87478 L
s
1 .662 0 r
.008 w
.33958 .87478 Mdot
.016 w
.33958 .87478 m
.33774 .87198 L
s
.008 w
.33774 .87198 Mdot
.016 w
.33774 .87198 m
.33599 .86917 L
s
.008 w
.33599 .86917 Mdot
.016 w
.33599 .86917 m
.3343 .86638 L
s
.008 w
.3343 .86638 Mdot
.016 w
.3343 .86638 m
.33266 .86355 L
s
1 .661 0 r
.008 w
.33266 .86355 Mdot
.016 w
.33266 .86355 m
.33111 .86083 L
s
.008 w
.33111 .86083 Mdot
.016 w
.33111 .86083 m
.32967 .85811 L
s
.008 w
.32967 .85811 Mdot
.016 w
.32967 .85811 m
.3282 .85543 L
s
.008 w
.3282 .85543 Mdot
.016 w
.3282 .85543 m
.32689 .85268 L
s
.008 w
.32689 .85268 Mdot
.016 w
.32689 .85268 m
.32555 .84999 L
s
1 .66 0 r
.008 w
.32555 .84999 Mdot
.016 w
.32555 .84999 m
.32418 .84719 L
s
.008 w
.32418 .84719 Mdot
.016 w
.32418 .84719 m
.32285 .84445 L
s
.008 w
.32285 .84445 Mdot
.016 w
.32285 .84445 m
.32154 .8417 L
s
.008 w
.32154 .8417 Mdot
.016 w
.32154 .8417 m
.32027 .83883 L
s
.008 w
.32027 .83883 Mdot
.016 w
.32027 .83883 m
.31909 .83633 L
s
1 .659 0 r
.008 w
.31909 .83633 Mdot
.016 w
.31909 .83633 m
.31794 .8339 L
s
.008 w
.31794 .8339 Mdot
.016 w
.31794 .8339 m
.31684 .83157 L
s
.008 w
.31684 .83157 Mdot
.016 w
.31684 .83157 m
.3159 .82961 L
s
.008 w
.3159 .82961 Mdot
.016 w
.3159 .82961 m
.31495 .82774 L
s
.008 w
.31495 .82774 Mdot
.016 w
.31495 .82774 m
.31411 .82626 L
s
1 .658 0 r
.008 w
.31411 .82626 Mdot
.016 w
.31411 .82626 m
.31332 .82494 L
s
.008 w
.31332 .82494 Mdot
.016 w
.31332 .82494 m
.31264 .82376 L
s
.008 w
.31264 .82376 Mdot
.016 w
.31264 .82376 m
.31211 .82269 L
s
.008 w
.31211 .82269 Mdot
.016 w
.31211 .82269 m
.31177 .82168 L
s
.008 w
.31177 .82168 Mdot
.016 w
.31177 .82168 m
.31162 .82069 L
s
1 .657 0 r
.008 w
.31162 .82069 Mdot
.016 w
.31162 .82069 m
.31165 .81961 L
s
.008 w
.31165 .81961 Mdot
.016 w
.31165 .81961 m
.3118 .81827 L
s
.008 w
.3118 .81827 Mdot
.016 w
.3118 .81827 m
.31203 .81661 L
s
.008 w
.31203 .81661 Mdot
.016 w
.31203 .81661 m
.31228 .81464 L
s
1 .656 0 r
.008 w
.31228 .81464 Mdot
.016 w
.31228 .81464 m
.31251 .81271 L
s
.008 w
.31251 .81271 Mdot
.016 w
.31251 .81271 m
.3127 .81041 L
s
.008 w
.3127 .81041 Mdot
.016 w
.3127 .81041 m
.31281 .80764 L
s
.008 w
.31281 .80764 Mdot
.016 w
.31281 .80764 m
.31296 .80487 L
s
.008 w
.31296 .80487 Mdot
.016 w
.31296 .80487 m
.31312 .80191 L
s
1 .655 0 r
.008 w
.31312 .80191 Mdot
.016 w
.31312 .80191 m
.31329 .79932 L
s
.008 w
.31329 .79932 Mdot
.016 w
.31329 .79932 m
.31345 .79678 L
s
.008 w
.31345 .79678 Mdot
.016 w
.31345 .79678 m
.31359 .79457 L
s
.008 w
.31359 .79457 Mdot
.016 w
.31359 .79457 m
.31371 .79246 L
s
.008 w
.31371 .79246 Mdot
.016 w
.31371 .79246 m
.31379 .79077 L
s
1 .654 0 r
.008 w
.31379 .79077 Mdot
.016 w
.31379 .79077 m
.31384 .78929 L
s
.008 w
.31384 .78929 Mdot
.016 w
.31384 .78929 m
.31391 .78805 L
s
.008 w
.31391 .78805 Mdot
.016 w
.31391 .78805 m
.31403 .78702 L
s
.008 w
.31403 .78702 Mdot
.016 w
.31403 .78702 m
.31421 .7861 L
s
.008 w
.31421 .7861 Mdot
.016 w
.31421 .7861 m
.31449 .78522 L
s
1 .653 0 r
.008 w
.31449 .78522 Mdot
.016 w
.31449 .78522 m
.31486 .78436 L
s
.008 w
.31486 .78436 Mdot
.016 w
.31486 .78436 m
.31532 .78347 L
s
.008 w
.31532 .78347 Mdot
.016 w
.31532 .78347 m
.31584 .78259 L
s
.008 w
.31584 .78259 Mdot
.016 w
.31584 .78259 m
.31637 .78168 L
s
1 .652 0 r
.008 w
.31637 .78168 Mdot
.016 w
.31637 .78168 m
.31685 .78073 L
s
.008 w
.31685 .78073 Mdot
.016 w
.31685 .78073 m
.31734 .77969 L
s
.008 w
.31734 .77969 Mdot
.016 w
.31734 .77969 m
.31782 .7786 L
s
.008 w
.31782 .7786 Mdot
.016 w
.31782 .7786 m
.31827 .77756 L
s
.008 w
.31827 .77756 Mdot
.016 w
.31827 .77756 m
.31869 .77666 L
s
1 .651 0 r
.008 w
.31869 .77666 Mdot
.016 w
.31869 .77666 m
.31908 .77593 L
s
.008 w
.31908 .77593 Mdot
.016 w
.31908 .77593 m
.3194 .77537 L
s
.008 w
.3194 .77537 Mdot
.016 w
.3194 .77537 m
.31963 .77501 L
s
.008 w
.31963 .77501 Mdot
.016 w
.31963 .77501 m
.31981 .77487 L
s
.008 w
.31981 .77487 Mdot
.016 w
.31981 .77487 m
.31994 .77489 L
s
1 .65 0 r
.008 w
.31994 .77489 Mdot
.016 w
.31994 .77489 m
.32 .77501 L
s
.008 w
.32 .77501 Mdot
.016 w
.32 .77501 m
.32002 .77516 L
s
.008 w
.32002 .77516 Mdot
.016 w
.32002 .77516 m
.32002 .77526 L
s
.008 w
.32002 .77526 Mdot
.016 w
.32002 .77526 m
.32 .77527 L
s
.008 w
.32 .77527 Mdot
.016 w
.32 .77527 m
.31994 .77512 L
s
1 .649 0 r
.008 w
.31994 .77512 Mdot
.016 w
.31994 .77512 m
.31981 .77471 L
s
.008 w
.31981 .77471 Mdot
.016 w
.31981 .77471 m
.31958 .774 L
s
.008 w
.31958 .774 Mdot
.016 w
.31958 .774 m
.3192 .77295 L
s
.008 w
.3192 .77295 Mdot
.016 w
.3192 .77295 m
.31863 .77161 L
s
.008 w
.31863 .77161 Mdot
.016 w
.31863 .77161 m
.31785 .7699 L
s
1 .648 0 r
.008 w
.31785 .7699 Mdot
.016 w
.31785 .7699 m
.31693 .768 L
s
.008 w
.31693 .768 Mdot
.016 w
.31693 .768 m
.31573 .7657 L
s
.008 w
.31573 .7657 Mdot
.016 w
.31573 .7657 m
.31438 .76325 L
s
.008 w
.31438 .76325 Mdot
.016 w
.31438 .76325 m
.31271 .76039 L
s
1 .647 0 r
.008 w
.31271 .76039 Mdot
.016 w
.31271 .76039 m
.31103 .75751 L
s
.008 w
.31103 .75751 Mdot
.016 w
.31103 .75751 m
.30904 .75431 L
s
.008 w
.30904 .75431 Mdot
.016 w
.30904 .75431 m
.30693 .75093 L
s
.008 w
.30693 .75093 Mdot
.016 w
.30693 .75093 m
.30495 .74773 L
s
.008 w
.30495 .74773 Mdot
.016 w
.30495 .74773 m
.30271 .74431 L
s
1 .646 0 r
.008 w
.30271 .74431 Mdot
.016 w
.30271 .74431 m
.30043 .74091 L
s
.008 w
.30043 .74091 Mdot
.016 w
.30043 .74091 m
.29806 .73742 L
s
.008 w
.29806 .73742 Mdot
.016 w
.29806 .73742 m
.29581 .73419 L
s
.008 w
.29581 .73419 Mdot
.016 w
.29581 .73419 m
.29357 .73094 L
s
.008 w
.29357 .73094 Mdot
.016 w
.29357 .73094 m
.29135 .72766 L
s
1 .645 0 r
.008 w
.29135 .72766 Mdot
.016 w
.29135 .72766 m
.28931 .72468 L
s
.008 w
.28931 .72468 Mdot
.016 w
.28931 .72468 m
.28727 .72159 L
s
.008 w
.28727 .72159 Mdot
.016 w
.28727 .72159 m
.28529 .71849 L
s
.008 w
.28529 .71849 Mdot
.016 w
.28529 .71849 m
.28336 .71531 L
s
.008 w
.28336 .71531 Mdot
.016 w
.28336 .71531 m
.28158 .71227 L
s
1 .644 0 r
.008 w
.28158 .71227 Mdot
.016 w
.28158 .71227 m
.27984 .70906 L
s
.008 w
.27984 .70906 Mdot
.016 w
.27984 .70906 m
.27816 .70585 L
s
.008 w
.27816 .70585 Mdot
.016 w
.27816 .70585 m
.2766 .70245 L
s
.008 w
.2766 .70245 Mdot
.016 w
.2766 .70245 m
.2751 .69921 L
s
1 .643 0 r
.008 w
.2751 .69921 Mdot
.016 w
.2751 .69921 m
.27364 .69581 L
s
.008 w
.27364 .69581 Mdot
.016 w
.27364 .69581 m
.27229 .6924 L
s
.008 w
.27229 .6924 Mdot
.016 w
.27229 .6924 m
.27097 .6892 L
s
.008 w
.27097 .6892 Mdot
.016 w
.27097 .6892 m
.2698 .68587 L
s
.008 w
.2698 .68587 Mdot
.016 w
.2698 .68587 m
.26869 .6824 L
s
1 .642 0 r
.008 w
.26869 .6824 Mdot
.016 w
.26869 .6824 m
.26775 .67957 L
s
.008 w
.26775 .67957 Mdot
.016 w
.26775 .67957 m
.26688 .67671 L
s
.008 w
.26688 .67671 Mdot
.016 w
.26688 .67671 m
.2661 .6739 L
s
.008 w
.2661 .6739 Mdot
.016 w
.2661 .6739 m
.26544 .67153 L
s
.008 w
.26544 .67153 Mdot
.016 w
.26544 .67153 m
.26487 .66929 L
s
1 .641 0 r
.008 w
.26487 .66929 Mdot
.016 w
.26487 .66929 m
.26438 .66723 L
s
.008 w
.26438 .66723 Mdot
.016 w
.26438 .66723 m
.26396 .66548 L
s
.008 w
.26396 .66548 Mdot
.016 w
.26396 .66548 m
.26364 .6638 L
s
.008 w
.26364 .6638 Mdot
.016 w
.26364 .6638 m
.26338 .66222 L
s
.008 w
.26338 .66222 Mdot
.016 w
.26338 .66222 m
.26318 .66067 L
s
1 .64 0 r
.008 w
.26318 .66067 Mdot
.016 w
.26318 .66067 m
.26303 .65919 L
s
.008 w
.26303 .65919 Mdot
.016 w
.26303 .65919 m
.26289 .65774 L
s
.008 w
.26289 .65774 Mdot
.016 w
.26289 .65774 m
.26275 .65631 L
s
.008 w
.26275 .65631 Mdot
.016 w
.26275 .65631 m
.26263 .65495 L
s
1 .639 0 r
.008 w
.26263 .65495 Mdot
.016 w
.26263 .65495 m
.26252 .65371 L
s
.008 w
.26252 .65371 Mdot
.016 w
.26252 .65371 m
.26243 .65256 L
s
.008 w
.26243 .65256 Mdot
.016 w
.26243 .65256 m
.26237 .65152 L
s
.008 w
.26237 .65152 Mdot
.016 w
.26237 .65152 m
.26233 .65061 L
s
.008 w
.26233 .65061 Mdot
.016 w
.26233 .65061 m
.26232 .64982 L
s
1 .638 0 r
.008 w
.26232 .64982 Mdot
.016 w
.26232 .64982 m
.26233 .64911 L
s
.008 w
.26233 .64911 Mdot
.016 w
.26233 .64911 m
.26237 .64849 L
s
.008 w
.26237 .64849 Mdot
.016 w
.26237 .64849 m
.26241 .64796 L
s
.008 w
.26241 .64796 Mdot
.016 w
.26241 .64796 m
.26245 .64753 L
s
.008 w
.26245 .64753 Mdot
.016 w
.26245 .64753 m
.26246 .64717 L
s
1 .637 0 r
.008 w
.26246 .64717 Mdot
.016 w
.26246 .64717 m
.26247 .64688 L
s
.008 w
.26247 .64688 Mdot
.016 w
.26247 .64688 m
.26247 .64665 L
s
.008 w
.26247 .64665 Mdot
.016 w
.26247 .64665 m
.26247 .64646 L
s
.008 w
.26247 .64646 Mdot
.016 w
.26247 .64646 m
.26247 .6463 L
s
.008 w
.26247 .6463 Mdot
.016 w
.26247 .6463 m
.26248 .64616 L
s
1 .636 0 r
.008 w
.26248 .64616 Mdot
.016 w
.26248 .64616 m
.26248 .64603 L
s
.008 w
.26248 .64603 Mdot
.016 w
.26248 .64603 m
.26248 .64591 L
s
.008 w
.26248 .64591 Mdot
.016 w
.26248 .64591 m
.26248 .64581 L
s
.008 w
.26248 .64581 Mdot
.016 w
.26248 .64581 m
.26248 .64575 L
s
.008 w
.26248 .64575 Mdot
.016 w
.26248 .64575 m
.26248 .64574 L
s
1 .635 0 r
.008 w
.26248 .64574 Mdot
.016 w
.26248 .64574 m
.26248 .64575 L
s
.008 w
.26248 .64575 Mdot
.016 w
.26248 .64575 m
.26248 .64579 L
s
.008 w
.26248 .64579 Mdot
.016 w
.26248 .64579 m
.26248 .64584 L
s
.008 w
.26248 .64584 Mdot
.016 w
.26248 .64584 m
.26248 .6459 L
s
1 .634 0 r
.008 w
.26248 .6459 Mdot
.016 w
.26248 .6459 m
.26248 .646 L
s
.008 w
.26248 .646 Mdot
.016 w
.26248 .646 m
.26248 .64614 L
s
.008 w
.26248 .64614 Mdot
.016 w
.26248 .64614 m
.26247 .64627 L
s
.008 w
.26247 .64627 Mdot
.016 w
.26247 .64627 m
.26247 .64638 L
s
.008 w
.26247 .64638 Mdot
.016 w
.26247 .64638 m
.26247 .64643 L
s
1 .633 0 r
.008 w
.26247 .64643 Mdot
.016 w
.26247 .64643 m
.26247 .64639 L
s
.008 w
.26247 .64639 Mdot
.016 w
.26247 .64639 m
.26247 .64622 L
s
.008 w
.26247 .64622 Mdot
.016 w
.26247 .64622 m
.26248 .64591 L
s
.008 w
.26248 .64591 Mdot
.016 w
.26248 .64591 m
.26248 .64538 L
s
.008 w
.26248 .64538 Mdot
.016 w
.26248 .64538 m
.26249 .6446 L
s
1 .632 0 r
.008 w
.26249 .6446 Mdot
.016 w
.26249 .6446 m
.2625 .64356 L
s
.008 w
.2625 .64356 Mdot
.016 w
.2625 .64356 m
.26252 .64225 L
s
.008 w
.26252 .64225 Mdot
.016 w
.26252 .64225 m
.26253 .64089 L
s
.008 w
.26253 .64089 Mdot
.016 w
.26253 .64089 m
.26254 .6391 L
s
.008 w
.26254 .6391 Mdot
.016 w
.26254 .6391 m
.26253 .63732 L
s
1 .631 0 r
.008 w
.26253 .63732 Mdot
.016 w
.26253 .63732 m
.2625 .63528 L
s
.008 w
.2625 .63528 Mdot
.016 w
.2625 .63528 m
.26246 .63313 L
s
.008 w
.26246 .63313 Mdot
.016 w
.26246 .63313 m
.26244 .63088 L
s
.008 w
.26244 .63088 Mdot
.016 w
.26244 .63088 m
.26244 .62871 L
s
1 .63 0 r
.008 w
.26244 .62871 Mdot
.016 w
.26244 .62871 m
.26251 .62647 L
s
.008 w
.26251 .62647 Mdot
.016 w
.26251 .62647 m
.26265 .62433 L
s
.008 w
.26265 .62433 Mdot
.016 w
.26265 .62433 m
.26288 .62231 L
s
.008 w
.26288 .62231 Mdot
.016 w
.26288 .62231 m
.2632 .62025 L
s
.008 w
.2632 .62025 Mdot
.016 w
.2632 .62025 m
.26359 .61832 L
s
1 .629 0 r
.008 w
.26359 .61832 Mdot
.016 w
.26359 .61832 m
.26405 .61644 L
s
.008 w
.26405 .61644 Mdot
.016 w
.26405 .61644 m
.26455 .61457 L
s
.008 w
.26455 .61457 Mdot
.016 w
.26455 .61457 m
.26504 .61291 L
s
.008 w
.26504 .61291 Mdot
.016 w
.26504 .61291 m
.26555 .61128 L
s
.008 w
.26555 .61128 Mdot
.016 w
.26555 .61128 m
.26604 .60981 L
s
1 .628 0 r
.008 w
.26604 .60981 Mdot
.016 w
.26604 .60981 m
.26649 .60847 L
s
.008 w
.26649 .60847 Mdot
.016 w
.26649 .60847 m
.2669 .60729 L
s
.008 w
.2669 .60729 Mdot
.016 w
.2669 .60729 m
.26728 .60637 L
s
.008 w
.26728 .60637 Mdot
.016 w
.26728 .60637 m
.26762 .60565 L
s
.008 w
.26762 .60565 Mdot
.016 w
.26762 .60565 m
.26793 .60519 L
s
1 .627 0 r
.008 w
.26793 .60519 Mdot
.016 w
.26793 .60519 m
.26823 .605 L
s
.008 w
.26823 .605 Mdot
.016 w
.26823 .605 m
.26852 .60506 L
s
.008 w
.26852 .60506 Mdot
.016 w
.26852 .60506 m
.26881 .60532 L
s
.008 w
.26881 .60532 Mdot
.016 w
.26881 .60532 m
.26914 .60575 L
s
1 .626 0 r
.008 w
.26914 .60575 Mdot
.016 w
.26914 .60575 m
.2695 .60629 L
s
.008 w
.2695 .60629 Mdot
.016 w
.2695 .60629 m
.26991 .6069 L
s
.008 w
.26991 .6069 Mdot
.016 w
.26991 .6069 m
.2704 .60752 L
s
.008 w
.2704 .60752 Mdot
.016 w
.2704 .60752 m
.27095 .60817 L
s
.008 w
.27095 .60817 Mdot
.016 w
.27095 .60817 m
.27152 .60881 L
s
1 .625 0 r
.008 w
.27152 .60881 Mdot
.016 w
.27152 .60881 m
.27207 .60937 L
s
.008 w
.27207 .60937 Mdot
.016 w
.27207 .60937 m
.27255 .60983 L
s
.008 w
.27255 .60983 Mdot
.016 w
.27255 .60983 m
.27289 .61014 L
s
.008 w
.27289 .61014 Mdot
.016 w
.27289 .61014 m
.27304 .61026 L
s
.008 w
.27304 .61026 Mdot
.016 w
.27304 .61026 m
.27297 .61016 L
s
1 .624 0 r
.008 w
.27297 .61016 Mdot
.016 w
.27297 .61016 m
.27268 .60984 L
s
.008 w
.27268 .60984 Mdot
.016 w
.27268 .60984 m
.27217 .60927 L
s
.008 w
.27217 .60927 Mdot
.016 w
.27217 .60927 m
.2715 .60844 L
s
.008 w
.2715 .60844 Mdot
.016 w
.2715 .60844 m
.27069 .60732 L
s
.008 w
.27069 .60732 Mdot
.016 w
.27069 .60732 m
.2698 .60592 L
s
1 .623 0 r
.008 w
.2698 .60592 Mdot
.016 w
.2698 .60592 m
.26893 .60441 L
s
.008 w
.26893 .60441 Mdot
.016 w
.26893 .60441 m
.26799 .60239 L
s
.008 w
.26799 .60239 Mdot
.016 w
.26799 .60239 m
.26712 .60022 L
s
.008 w
.26712 .60022 Mdot
.016 w
.26712 .60022 m
.2663 .59765 L
s
.008 w
.2663 .59765 Mdot
.016 w
.2663 .59765 m
.26555 .59474 L
s
1 .622 0 r
.008 w
.26555 .59474 Mdot
.016 w
.26555 .59474 m
.26494 .59166 L
s
.008 w
.26494 .59166 Mdot
.016 w
.26494 .59166 m
.26444 .58847 L
s
.008 w
.26444 .58847 Mdot
.016 w
.26444 .58847 m
.26411 .58505 L
s
.008 w
.26411 .58505 Mdot
.016 w
.26411 .58505 m
.26388 .58118 L
s
1 .621 0 r
.008 w
.26388 .58118 Mdot
.016 w
.26388 .58118 m
.26374 .57804 L
s
.008 w
.26374 .57804 Mdot
.016 w
.26374 .57804 m
.26365 .57437 L
s
.008 w
.26365 .57437 Mdot
.016 w
.26365 .57437 m
.26355 .57091 L
s
.008 w
.26355 .57091 Mdot
.016 w
.26355 .57091 m
.26342 .5672 L
s
.008 w
.26342 .5672 Mdot
.016 w
.26342 .5672 m
.26324 .56377 L
s
1 .62 0 r
.008 w
.26324 .56377 Mdot
.016 w
.26324 .56377 m
.26303 .56011 L
s
.008 w
.26303 .56011 Mdot
.016 w
.26303 .56011 m
.26281 .55636 L
s
.008 w
.26281 .55636 Mdot
.016 w
.26281 .55636 m
.26255 .55316 L
s
.008 w
.26255 .55316 Mdot
.016 w
.26255 .55316 m
.26227 .54967 L
s
.008 w
.26227 .54967 Mdot
.016 w
.26227 .54967 m
.26197 .54619 L
s
1 .619 0 r
.008 w
.26197 .54619 Mdot
.016 w
.26197 .54619 m
.26164 .54262 L
s
.008 w
.26164 .54262 Mdot
.016 w
.26164 .54262 m
.26129 .53904 L
s
.008 w
.26129 .53904 Mdot
.016 w
.26129 .53904 m
.26093 .53552 L
s
.008 w
.26093 .53552 Mdot
.016 w
.26093 .53552 m
.26056 .5318 L
s
.008 w
.26056 .5318 Mdot
.016 w
.26056 .5318 m
.26019 .52807 L
s
1 .618 0 r
.008 w
.26019 .52807 Mdot
.016 w
.26019 .52807 m
.25983 .5248 L
s
.008 w
.25983 .5248 Mdot
.016 w
.25983 .5248 m
.25947 .52124 L
s
.008 w
.25947 .52124 Mdot
.016 w
.25947 .52124 m
.25908 .51761 L
s
.008 w
.25908 .51761 Mdot
.016 w
.25908 .51761 m
.25865 .51455 L
s
1 .617 0 r
.008 w
.25865 .51455 Mdot
.016 w
.25865 .51455 m
.25817 .51132 L
s
.008 w
.25817 .51132 Mdot
.016 w
.25817 .51132 m
.25766 .50828 L
s
.008 w
.25766 .50828 Mdot
.016 w
.25766 .50828 m
.25716 .5054 L
s
.008 w
.25716 .5054 Mdot
.016 w
.25716 .5054 m
.25671 .50293 L
s
.008 w
.25671 .50293 Mdot
.016 w
.25671 .50293 m
.25635 .50073 L
s
1 .616 0 r
.008 w
.25635 .50073 Mdot
.016 w
.25635 .50073 m
.2561 .49881 L
s
.008 w
.2561 .49881 Mdot
.016 w
.2561 .49881 m
.25592 .49722 L
s
.008 w
.25592 .49722 Mdot
.016 w
.25592 .49722 m
.25573 .496 L
s
.008 w
.25573 .496 Mdot
.016 w
.25573 .496 m
.25547 .49494 L
s
.008 w
.25547 .49494 Mdot
.016 w
.25547 .49494 m
.25509 .49403 L
s
1 .615 0 r
.008 w
.25509 .49403 Mdot
.016 w
.25509 .49403 m
.25454 .49325 L
s
.008 w
.25454 .49325 Mdot
.016 w
.25454 .49325 m
.25379 .49257 L
s
.008 w
.25379 .49257 Mdot
.016 w
.25379 .49257 m
.25286 .49195 L
s
.008 w
.25286 .49195 Mdot
.016 w
.25286 .49195 m
.25177 .49136 L
s
.008 w
.25177 .49136 Mdot
.016 w
.25177 .49136 m
.25058 .4908 L
s
1 .614 0 r
.008 w
.25058 .4908 Mdot
.016 w
.25058 .4908 m
.24936 .49029 L
s
.008 w
.24936 .49029 Mdot
.016 w
.24936 .49029 m
.24834 .48985 L
s
.008 w
.24834 .48985 Mdot
.016 w
.24834 .48985 m
.24705 .48942 L
s
.008 w
.24705 .48942 Mdot
.016 w
.24705 .48942 m
.246 .48895 L
s
1 .613 0 r
.008 w
.246 .48895 Mdot
.016 w
.246 .48895 m
.24499 .4884 L
s
.008 w
.24499 .4884 Mdot
.016 w
.24499 .4884 m
.24407 .48783 L
s
.008 w
.24407 .48783 Mdot
.016 w
.24407 .48783 m
.24334 .48734 L
s
.008 w
.24334 .48734 Mdot
.016 w
.24334 .48734 m
.24284 .48698 L
s
.008 w
.24284 .48698 Mdot
.016 w
.24284 .48698 m
.24255 .48677 L
s
1 .612 0 r
.008 w
.24255 .48677 Mdot
.016 w
.24255 .48677 m
.2424 .48673 L
s
.008 w
.2424 .48673 Mdot
.016 w
.2424 .48673 m
.24227 .48684 L
s
.008 w
.24227 .48684 Mdot
.016 w
.24227 .48684 m
.24208 .4871 L
s
.008 w
.24208 .4871 Mdot
.016 w
.24208 .4871 m
.2417 .48748 L
s
.008 w
.2417 .48748 Mdot
.016 w
.2417 .48748 m
.24099 .48793 L
s
1 .611 0 r
.008 w
.24099 .48793 Mdot
.016 w
.24099 .48793 m
.23992 .48844 L
s
.008 w
.23992 .48844 Mdot
.016 w
.23992 .48844 m
.23845 .489 L
s
.008 w
.23845 .489 Mdot
.016 w
.23845 .489 m
.23673 .48957 L
s
.008 w
.23673 .48957 Mdot
.016 w
.23673 .48957 m
.23468 .49019 L
s
.008 w
.23468 .49019 Mdot
.016 w
.23468 .49019 m
.23223 .49084 L
s
1 .61 0 r
.008 w
.23223 .49084 Mdot
.016 w
.23223 .49084 m
.22961 .49151 L
s
.008 w
.22961 .49151 Mdot
.016 w
.22961 .49151 m
.22693 .49216 L
s
.008 w
.22693 .49216 Mdot
.016 w
.22693 .49216 m
.22382 .49277 L
s
.008 w
.22382 .49277 Mdot
.016 w
.22382 .49277 m
.22074 .49328 L
s
.008 w
.22074 .49328 Mdot
.016 w
.22074 .49328 m
.21787 .49369 L
s
1 .609 0 r
.008 w
.21787 .49369 Mdot
.016 w
.21787 .49369 m
.21437 .494 L
s
.008 w
.21437 .494 Mdot
.016 w
.21437 .494 m
.21149 .49422 L
s
.008 w
.21149 .49422 Mdot
.016 w
.21149 .49422 m
.20839 .49436 L
s
.008 w
.20839 .49436 Mdot
.016 w
.20839 .49436 m
.20523 .49441 L
s
1 .608 0 r
.008 w
.20523 .49441 Mdot
.016 w
.20523 .49441 m
.202 .4944 L
s
.008 w
.202 .4944 Mdot
.016 w
.202 .4944 m
.19854 .49432 L
s
.008 w
.19854 .49432 Mdot
.016 w
.19854 .49432 m
.19566 .49417 L
s
.008 w
.19566 .49417 Mdot
.016 w
.19566 .49417 m
.19221 .49392 L
s
.008 w
.19221 .49392 Mdot
.016 w
.19221 .49392 m
.18918 .49353 L
s
1 .607 0 r
.008 w
.18918 .49353 Mdot
.016 w
.18918 .49353 m
.18578 .49304 L
s
.008 w
.18578 .49304 Mdot
.016 w
.18578 .49304 m
.18254 .49243 L
s
.008 w
.18254 .49243 Mdot
.016 w
.18254 .49243 m
.17904 .49173 L
s
.008 w
.17904 .49173 Mdot
.016 w
.17904 .49173 m
.17587 .49092 L
s
.008 w
.17587 .49092 Mdot
.016 w
.17587 .49092 m
.17236 .49006 L
s
1 .606 0 r
.008 w
.17236 .49006 Mdot
.016 w
.17236 .49006 m
.16926 .48911 L
s
.008 w
.16926 .48911 Mdot
.016 w
.16926 .48911 m
.16597 .48805 L
s
.008 w
.16597 .48805 Mdot
.016 w
.16597 .48805 m
.163 .4869 L
s
.008 w
.163 .4869 Mdot
.016 w
.163 .4869 m
.15999 .4857 L
s
.008 w
.15999 .4857 Mdot
.016 w
.15999 .4857 m
.15704 .48439 L
s
1 .605 0 r
.008 w
.15704 .48439 Mdot
.016 w
.15704 .48439 m
.15416 .4831 L
s
.008 w
.15416 .4831 Mdot
.016 w
.15416 .4831 m
.15136 .48176 L
s
.008 w
.15136 .48176 Mdot
.016 w
.15136 .48176 m
.14858 .48041 L
s
.008 w
.14858 .48041 Mdot
.016 w
.14858 .48041 m
.14579 .47916 L
s
1 .604 0 r
.008 w
.14579 .47916 Mdot
.016 w
.14579 .47916 m
.14322 .47795 L
s
.008 w
.14322 .47795 Mdot
.016 w
.14322 .47795 m
.14047 .47679 L
s
.008 w
.14047 .47679 Mdot
.016 w
.14047 .47679 m
.13773 .47568 L
s
.008 w
.13773 .47568 Mdot
.016 w
.13773 .47568 m
.13509 .47466 L
s
.008 w
.13509 .47466 Mdot
.016 w
.13509 .47466 m
.13222 .47364 L
s
1 .603 0 r
.008 w
.13222 .47364 Mdot
.016 w
.13222 .47364 m
.12952 .47263 L
s
.008 w
.12952 .47263 Mdot
.016 w
.12952 .47263 m
.12668 .47163 L
s
.008 w
.12668 .47163 Mdot
.016 w
.12668 .47163 m
.12397 .4706 L
s
.008 w
.12397 .4706 Mdot
.016 w
.12397 .4706 m
.12115 .46954 L
s
.008 w
.12115 .46954 Mdot
.016 w
.12115 .46954 m
.1187 .4685 L
s
1 .602 0 r
.008 w
.1187 .4685 Mdot
.016 w
.1187 .4685 m
.11609 .46743 L
s
.008 w
.11609 .46743 Mdot
.016 w
.11609 .46743 m
.11397 .46631 L
s
.008 w
.11397 .46631 Mdot
.016 w
.11397 .46631 m
.11195 .4651 L
s
.008 w
.11195 .4651 Mdot
.016 w
.11195 .4651 m
.11012 .46386 L
s
.008 w
.11012 .46386 Mdot
.016 w
.11012 .46386 m
.10852 .46244 L
s
1 .601 0 r
.008 w
.10852 .46244 Mdot
.016 w
.10852 .46244 m
.10717 .46094 L
s
.008 w
.10717 .46094 Mdot
.016 w
.10717 .46094 m
.10604 .45923 L
s
.008 w
.10604 .45923 Mdot
.016 w
.10604 .45923 m
.10511 .45739 L
s
.008 w
.10511 .45739 Mdot
.016 w
.10511 .45739 m
.10434 .45547 L
s
.008 w
.10434 .45547 Mdot
.016 w
.10434 .45547 m
.10367 .45331 L
s
1 .6 0 r
.008 w
.10367 .45331 Mdot
.016 w
.10367 .45331 m
.1031 .45123 L
s
.008 w
.1031 .45123 Mdot
.016 w
.1031 .45123 m
.10259 .44897 L
s
.008 w
.10259 .44897 Mdot
.016 w
.10259 .44897 m
.10211 .44653 L
s
.008 w
.10211 .44653 Mdot
.016 w
.10211 .44653 m
.10164 .4443 L
s
1 .599 0 r
.008 w
.10164 .4443 Mdot
.016 w
.10164 .4443 m
.10116 .44196 L
s
.008 w
.10116 .44196 Mdot
.016 w
.10116 .44196 m
.10072 .43957 L
s
.008 w
.10072 .43957 Mdot
.016 w
.10072 .43957 m
.10031 .43758 L
s
.008 w
.10031 .43758 Mdot
.016 w
.10031 .43758 m
.0999 .43562 L
s
.008 w
.0999 .43562 Mdot
.016 w
.0999 .43562 m
.09956 .43386 L
s
1 .598 0 r
.008 w
.09956 .43386 Mdot
.016 w
.09956 .43386 m
.09927 .43235 L
s
.008 w
.09927 .43235 Mdot
.016 w
.09927 .43235 m
.09905 .43116 L
s
.008 w
.09905 .43116 Mdot
.016 w
.09905 .43116 m
.09892 .43029 L
s
.008 w
.09892 .43029 Mdot
.016 w
.09892 .43029 m
.0989 .42966 L
s
.008 w
.0989 .42966 Mdot
.016 w
.0989 .42966 m
.09898 .42923 L
s
1 .597 0 r
.008 w
.09898 .42923 Mdot
.016 w
.09898 .42923 m
.09912 .42893 L
s
.008 w
.09912 .42893 Mdot
.016 w
.09912 .42893 m
.09933 .4287 L
s
.008 w
.09933 .4287 Mdot
.016 w
.09933 .4287 m
.09964 .42848 L
s
.008 w
.09964 .42848 Mdot
.016 w
.09964 .42848 m
.10007 .42822 L
s
.008 w
.10007 .42822 Mdot
.016 w
.10007 .42822 m
.10066 .42789 L
s
1 .596 0 r
.008 w
.10066 .42789 Mdot
.016 w
.10066 .42789 m
.1014 .4275 L
s
.008 w
.1014 .4275 Mdot
.016 w
.1014 .4275 m
.10231 .42705 L
s
.008 w
.10231 .42705 Mdot
.016 w
.10231 .42705 m
.10335 .42654 L
s
.008 w
.10335 .42654 Mdot
.016 w
.10335 .42654 m
.10445 .42599 L
s
1 .595 0 r
.008 w
.10445 .42599 Mdot
.016 w
.10445 .42599 m
.10563 .42536 L
s
.008 w
.10563 .42536 Mdot
.016 w
.10563 .42536 m
.10682 .42467 L
s
.008 w
.10682 .42467 Mdot
.016 w
.10682 .42467 m
.10791 .42399 L
s
.008 w
.10791 .42399 Mdot
.016 w
.10791 .42399 m
.109 .42337 L
s
.008 w
.109 .42337 Mdot
.016 w
.109 .42337 m
.10992 .42283 L
s
1 .594 0 r
.008 w
.10992 .42283 Mdot
.016 w
.10992 .42283 m
.11073 .42239 L
s
.008 w
.11073 .42239 Mdot
.016 w
.11073 .42239 m
.11143 .42207 L
s
.008 w
.11143 .42207 Mdot
.016 w
.11143 .42207 m
.11201 .42188 L
s
.008 w
.11201 .42188 Mdot
.016 w
.11201 .42188 m
.11249 .42183 L
s
.008 w
.11249 .42183 Mdot
.016 w
.11249 .42183 m
.1129 .42191 L
s
1 .593 0 r
.008 w
.1129 .42191 Mdot
.016 w
.1129 .42191 m
.11329 .42211 L
s
.008 w
.11329 .42211 Mdot
.016 w
.11329 .42211 m
.11367 .4224 L
s
.008 w
.11367 .4224 Mdot
.016 w
.11367 .4224 m
.11407 .4228 L
s
.008 w
.11407 .4228 Mdot
.016 w
.11407 .4228 m
.11452 .42333 L
s
.008 w
.11452 .42333 Mdot
.016 w
.11452 .42333 m
.11503 .42396 L
s
1 .592 0 r
.008 w
.11503 .42396 Mdot
.016 w
.11503 .42396 m
.11565 .42469 L
s
.008 w
.11565 .42469 Mdot
.016 w
.11565 .42469 m
.11637 .42549 L
s
.008 w
.11637 .42549 Mdot
.016 w
.11637 .42549 m
.11715 .42634 L
s
.008 w
.11715 .42634 Mdot
.016 w
.11715 .42634 m
.11796 .42718 L
s
1 .591 0 r
.008 w
.11796 .42718 Mdot
.016 w
.11796 .42718 m
.11873 .42801 L
s
.008 w
.11873 .42801 Mdot
.016 w
.11873 .42801 m
.11945 .4288 L
s
.008 w
.11945 .4288 Mdot
.016 w
.11945 .4288 m
.12009 .42953 L
s
.008 w
.12009 .42953 Mdot
.016 w
.12009 .42953 m
.12067 .43022 L
s
.008 w
.12067 .43022 Mdot
.016 w
.12067 .43022 m
.12118 .4308 L
s
1 .59 0 r
.008 w
.12118 .4308 Mdot
.016 w
.12118 .4308 m
.12165 .43134 L
s
.008 w
.12165 .43134 Mdot
.016 w
.12165 .43134 m
.12214 .43191 L
s
.008 w
.12214 .43191 Mdot
.016 w
.12214 .43191 m
.12269 .43246 L
s
.008 w
.12269 .43246 Mdot
.016 w
.12269 .43246 m
.12334 .4331 L
s
.008 w
.12334 .4331 Mdot
.016 w
.12334 .4331 m
.12412 .43381 L
s
1 .589 0 r
.008 w
.12412 .43381 Mdot
.016 w
.12412 .43381 m
.12503 .43466 L
s
.008 w
.12503 .43466 Mdot
.016 w
.12503 .43466 m
.12617 .43567 L
s
.008 w
.12617 .43567 Mdot
.016 w
.12617 .43567 m
.12755 .43693 L
s
.008 w
.12755 .43693 Mdot
.016 w
.12755 .43693 m
.12903 .43843 L
s
.008 w
.12903 .43843 Mdot
.016 w
.12903 .43843 m
.13079 .43992 L
s
1 .588 0 r
.008 w
.13079 .43992 Mdot
.016 w
.13079 .43992 m
.13253 .44166 L
s
.008 w
.13253 .44166 Mdot
.016 w
.13253 .44166 m
.13451 .44343 L
s
.008 w
.13451 .44343 Mdot
.016 w
.13451 .44343 m
.13655 .44544 L
s
.008 w
.13655 .44544 Mdot
.016 w
.13655 .44544 m
.13857 .44718 L
s
.008 w
.13857 .44718 Mdot
.016 w
.13857 .44718 m
.14071 .4489 L
s
1 .587 0 r
.008 w
.14071 .4489 Mdot
.016 w
.14071 .4489 m
.14253 .4505 L
s
.008 w
.14253 .4505 Mdot
.016 w
.14253 .4505 m
.14433 .45193 L
s
.008 w
.14433 .45193 Mdot
.016 w
.14433 .45193 m
.14596 .45313 L
s
.008 w
.14596 .45313 Mdot
.016 w
.14596 .45313 m
.14731 .45407 L
s
1 .586 0 r
.008 w
.14731 .45407 Mdot
.016 w
.14731 .45407 m
.14849 .45479 L
s
.008 w
.14849 .45479 Mdot
.016 w
.14849 .45479 m
.14946 .4553 L
s
.008 w
.14946 .4553 Mdot
.016 w
.14946 .4553 m
.1502 .45563 L
s
.008 w
.1502 .45563 Mdot
.016 w
.1502 .45563 m
.15074 .45581 L
s
.008 w
.15074 .45581 Mdot
.016 w
.15074 .45581 m
.15109 .4559 L
s
1 .585 0 r
.008 w
.15109 .4559 Mdot
.016 w
.15109 .4559 m
.15128 .45592 L
s
.008 w
.15128 .45592 Mdot
.016 w
.15128 .45592 m
.15133 .45588 L
s
.008 w
.15133 .45588 Mdot
.016 w
.15133 .45588 m
.1513 .45581 L
s
.008 w
.1513 .45581 Mdot
.016 w
.1513 .45581 m
.15119 .45571 L
s
.008 w
.15119 .45571 Mdot
.016 w
.15119 .45571 m
.15105 .45562 L
s
1 .584 0 r
.008 w
.15105 .45562 Mdot
.016 w
.15105 .45562 m
.1509 .45556 L
s
.008 w
.1509 .45556 Mdot
.016 w
.1509 .45556 m
.15075 .45553 L
s
.008 w
.15075 .45553 Mdot
.016 w
.15075 .45553 m
.15064 .45552 L
s
.008 w
.15064 .45552 Mdot
.016 w
.15064 .45552 m
.15059 .45552 L
s
.008 w
.15059 .45552 Mdot
.016 w
.15059 .45552 m
.15062 .45552 L
s
1 .583 0 r
.008 w
.15062 .45552 Mdot
.016 w
.15062 .45552 m
.15076 .45552 L
s
.008 w
.15076 .45552 Mdot
.016 w
.15076 .45552 m
.15102 .45552 L
s
.008 w
.15102 .45552 Mdot
.016 w
.15102 .45552 m
.15139 .45552 L
s
.008 w
.15139 .45552 Mdot
.016 w
.15139 .45552 m
.1519 .45552 L
s
1 .582 0 r
.008 w
.1519 .45552 Mdot
.016 w
.1519 .45552 m
.15256 .45551 L
s
.008 w
.15256 .45551 Mdot
.016 w
.15256 .45551 m
.15336 .45551 L
s
.008 w
.15336 .45551 Mdot
.016 w
.15336 .45551 m
.15438 .45551 L
s
.008 w
.15438 .45551 Mdot
.016 w
.15438 .45551 m
.15557 .4555 L
s
.008 w
.15557 .4555 Mdot
.016 w
.15557 .4555 m
.15697 .4555 L
s
1 .581 0 r
.008 w
.15697 .4555 Mdot
.016 w
.15697 .4555 m
.15844 .45549 L
s
.008 w
.15844 .45549 Mdot
.016 w
.15844 .45549 m
.16008 .45548 L
s
.008 w
.16008 .45548 Mdot
.016 w
.16008 .45548 m
.16171 .45547 L
s
.008 w
.16171 .45547 Mdot
.016 w
.16171 .45547 m
.16336 .45541 L
s
.008 w
.16336 .45541 Mdot
.016 w
.16336 .45541 m
.16497 .45531 L
s
1 .58 0 r
.008 w
.16497 .45531 Mdot
.016 w
.16497 .45531 m
.16639 .45515 L
s
.008 w
.16639 .45515 Mdot
.016 w
.16639 .45515 m
.16767 .45497 L
s
.008 w
.16767 .45497 Mdot
.016 w
.16767 .45497 m
.16881 .45481 L
s
.008 w
.16881 .45481 Mdot
.016 w
.16881 .45481 m
.1697 .45472 L
s
.008 w
.1697 .45472 Mdot
.016 w
.1697 .45472 m
.17041 .45473 L
s
1 .579 0 r
.008 w
.17041 .45473 Mdot
.016 w
.17041 .45473 m
.17095 .45491 L
s
.008 w
.17095 .45491 Mdot
.016 w
.17095 .45491 m
.17131 .45533 L
s
.008 w
.17131 .45533 Mdot
.016 w
.17131 .45533 m
.17151 .45603 L
s
.008 w
.17151 .45603 Mdot
.016 w
.17151 .45603 m
.17161 .45707 L
s
1 .578 0 r
.008 w
.17161 .45707 Mdot
.016 w
.17161 .45707 m
.17165 .45852 L
s
.008 w
.17165 .45852 Mdot
.016 w
.17165 .45852 m
.17169 .4604 L
s
.008 w
.17169 .4604 Mdot
.016 w
.17169 .4604 m
.17176 .46221 L
s
.008 w
.17176 .46221 Mdot
.016 w
.17176 .46221 m
.17188 .46476 L
s
.008 w
.17188 .46476 Mdot
.016 w
.17188 .46476 m
.17208 .46758 L
s
1 .577 0 r
.008 w
.17208 .46758 Mdot
.016 w
.17208 .46758 m
.17245 .47028 L
s
.008 w
.17245 .47028 Mdot
.016 w
.17245 .47028 m
.17298 .4735 L
s
.008 w
.17298 .4735 Mdot
.016 w
.17298 .4735 m
.17374 .47722 L
s
.008 w
.17374 .47722 Mdot
.016 w
.17374 .47722 m
.17461 .48021 L
s
.008 w
.17461 .48021 Mdot
.016 w
.17461 .48021 m
.17563 .48365 L
s
1 .576 0 r
.008 w
.17563 .48365 Mdot
.016 w
.17563 .48365 m
.17682 .48672 L
s
.008 w
.17682 .48672 Mdot
.016 w
.17682 .48672 m
.17807 .4898 L
s
.008 w
.17807 .4898 Mdot
.016 w
.17807 .4898 m
.17945 .49239 L
s
.008 w
.17945 .49239 Mdot
.016 w
.17945 .49239 m
.18084 .4948 L
s
.008 w
.18084 .4948 Mdot
.016 w
.18084 .4948 m
.18231 .49696 L
s
1 .575 0 r
.008 w
.18231 .49696 Mdot
.016 w
.18231 .49696 m
.18387 .49874 L
s
.008 w
.18387 .49874 Mdot
.016 w
.18387 .49874 m
.18545 .50037 L
s
.008 w
.18545 .50037 Mdot
.016 w
.18545 .50037 m
.18721 .50181 L
s
.008 w
.18721 .50181 Mdot
.016 w
.18721 .50181 m
.18916 .50306 L
s
.008 w
.18916 .50306 Mdot
.016 w
.18916 .50306 m
.19119 .50419 L
s
1 .574 0 r
.008 w
.19119 .50419 Mdot
.016 w
.19119 .50419 m
.19351 .5052 L
s
.008 w
.19351 .5052 Mdot
.016 w
.19351 .5052 m
.19565 .50607 L
s
.008 w
.19565 .50607 Mdot
.016 w
.19565 .50607 m
.198 .50686 L
s
.008 w
.198 .50686 Mdot
.016 w
.198 .50686 m
.2005 .50759 L
s
1 .573 0 r
.008 w
.2005 .50759 Mdot
.016 w
.2005 .50759 m
.2028 .50824 L
s
.008 w
.2028 .50824 Mdot
.016 w
.2028 .50824 m
.20525 .50883 L
s
.008 w
.20525 .50883 Mdot
.016 w
.20525 .50883 m
.20784 .50934 L
s
.008 w
.20784 .50934 Mdot
.016 w
.20784 .50934 m
.21008 .50972 L
s
.008 w
.21008 .50972 Mdot
.016 w
.21008 .50972 m
.21257 .50996 L
s
1 .572 0 r
.008 w
.21257 .50996 Mdot
.016 w
.21257 .50996 m
.21468 .51002 L
s
.008 w
.21468 .51002 Mdot
.016 w
.21468 .51002 m
.21689 .50996 L
s
.008 w
.21689 .50996 Mdot
.016 w
.21689 .50996 m
.21895 .50964 L
s
.008 w
.21895 .50964 Mdot
.016 w
.21895 .50964 m
.22091 .50914 L
s
.008 w
.22091 .50914 Mdot
.016 w
.22091 .50914 m
.22281 .50848 L
s
1 .571 0 r
.008 w
.22281 .50848 Mdot
.016 w
.22281 .50848 m
.22467 .50771 L
s
.008 w
.22467 .50771 Mdot
.016 w
.22467 .50771 m
.22644 .50685 L
s
.008 w
.22644 .50685 Mdot
.016 w
.22644 .50685 m
.22819 .50597 L
s
.008 w
.22819 .50597 Mdot
.016 w
.22819 .50597 m
.2299 .50501 L
s
.008 w
.2299 .50501 Mdot
.016 w
.2299 .50501 m
.23161 .50403 L
s
1 .57 0 r
.008 w
.23161 .50403 Mdot
.016 w
.23161 .50403 m
.2331 .50296 L
s
.008 w
.2331 .50296 Mdot
.016 w
.2331 .50296 m
.23463 .50183 L
s
.008 w
.23463 .50183 Mdot
.016 w
.23463 .50183 m
.2361 .50069 L
s
.008 w
.2361 .50069 Mdot
.016 w
.2361 .50069 m
.23737 .4996 L
s
1 .569 0 r
.008 w
.23737 .4996 Mdot
.016 w
.23737 .4996 m
.23857 .49865 L
s
.008 w
.23857 .49865 Mdot
.016 w
.23857 .49865 m
.23966 .49781 L
s
.008 w
.23966 .49781 Mdot
.016 w
.23966 .49781 m
.24061 .49714 L
s
.008 w
.24061 .49714 Mdot
.016 w
.24061 .49714 m
.24139 .49662 L
s
.008 w
.24139 .49662 Mdot
.016 w
.24139 .49662 m
.24205 .49625 L
s
1 .568 0 r
.008 w
.24205 .49625 Mdot
.016 w
.24205 .49625 m
.24258 .49601 L
s
.008 w
.24258 .49601 Mdot
.016 w
.24258 .49601 m
.24301 .49586 L
s
.008 w
.24301 .49586 Mdot
.016 w
.24301 .49586 m
.24335 .4958 L
s
.008 w
.24335 .4958 Mdot
.016 w
.24335 .4958 m
.24364 .49584 L
s
.008 w
.24364 .49584 Mdot
.016 w
.24364 .49584 m
.24389 .496 L
s
1 .567 0 r
.008 w
.24389 .496 Mdot
.016 w
.24389 .496 m
.24412 .49626 L
s
.008 w
.24412 .49626 Mdot
.016 w
.24412 .49626 m
.24429 .49659 L
s
.008 w
.24429 .49659 Mdot
.016 w
.24429 .49659 m
.2444 .49692 L
s
.008 w
.2444 .49692 Mdot
.016 w
.2444 .49692 m
.24446 .49721 L
s
.008 w
.24446 .49721 Mdot
.016 w
.24446 .49721 m
.24446 .49745 L
s
1 .566 0 r
.008 w
.24446 .49745 Mdot
.016 w
.24446 .49745 m
.24444 .49762 L
s
.008 w
.24444 .49762 Mdot
.016 w
.24444 .49762 m
.2444 .49771 L
s
.008 w
.2444 .49771 Mdot
.016 w
.2444 .49771 m
.24436 .49771 L
s
.008 w
.24436 .49771 Mdot
.016 w
.24436 .49771 m
.24432 .49766 L
s
1 .565 0 r
.008 w
.24432 .49766 Mdot
.016 w
.24432 .49766 m
.24429 .49759 L
s
.008 w
.24429 .49759 Mdot
.016 w
.24429 .49759 m
.24428 .49754 L
s
.008 w
.24428 .49754 Mdot
.016 w
.24428 .49754 m
.24428 .49752 L
s
.008 w
.24428 .49752 Mdot
.016 w
.24428 .49752 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
1 .564 0 r
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
1 .563 0 r
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49751 L
s
1 .562 0 r
.008 w
.24428 .49751 Mdot
.016 w
.24428 .49751 m
.24428 .49752 L
s
.008 w
.24428 .49752 Mdot
.016 w
.24428 .49752 m
.24427 .49754 L
s
.008 w
.24427 .49754 Mdot
.016 w
.24427 .49754 m
.24427 .49759 L
s
.008 w
.24427 .49759 Mdot
.016 w
.24427 .49759 m
.24426 .49766 L
s
.008 w
.24426 .49766 Mdot
.016 w
.24426 .49766 m
.24424 .49774 L
s
1 .561 0 r
.008 w
.24424 .49774 Mdot
.016 w
.24424 .49774 m
.24419 .4978 L
s
.008 w
.24419 .4978 Mdot
.016 w
.24419 .4978 m
.24409 .49784 L
s
.008 w
.24409 .49784 Mdot
.016 w
.24409 .49784 m
.24399 .49784 L
s
.008 w
.24399 .49784 Mdot
.016 w
.24399 .49784 m
.24388 .49779 L
s
1 .56 0 r
.008 w
.24388 .49779 Mdot
.016 w
.24388 .49779 m
.2438 .49768 L
s
.008 w
.2438 .49768 Mdot
.016 w
.2438 .49768 m
.24377 .49748 L
s
.008 w
.24377 .49748 Mdot
.016 w
.24377 .49748 m
.24385 .49715 L
s
.008 w
.24385 .49715 Mdot
.016 w
.24385 .49715 m
.24405 .49667 L
s
.008 w
.24405 .49667 Mdot
.016 w
.24405 .49667 m
.24441 .496 L
s
1 .559 0 r
.008 w
.24441 .496 Mdot
.016 w
.24441 .496 m
.24498 .49515 L
s
.008 w
.24498 .49515 Mdot
.016 w
.24498 .49515 m
.24579 .4941 L
s
.008 w
.24579 .4941 Mdot
.016 w
.24579 .4941 m
.24687 .49283 L
s
.008 w
.24687 .49283 Mdot
.016 w
.24687 .49283 m
.24812 .49136 L
s
.008 w
.24812 .49136 Mdot
.016 w
.24812 .49136 m
.24964 .48964 L
s
1 .558 0 r
.008 w
.24964 .48964 Mdot
.016 w
.24964 .48964 m
.2514 .48774 L
s
.008 w
.2514 .48774 Mdot
.016 w
.2514 .48774 m
.25336 .48557 L
s
.008 w
.25336 .48557 Mdot
.016 w
.25336 .48557 m
.25546 .48327 L
s
.008 w
.25546 .48327 Mdot
.016 w
.25546 .48327 m
.25779 .48061 L
s
.008 w
.25779 .48061 Mdot
.016 w
.25779 .48061 m
.26002 .47812 L
s
1 .557 0 r
.008 w
.26002 .47812 Mdot
.016 w
.26002 .47812 m
.26233 .47535 L
s
.008 w
.26233 .47535 Mdot
.016 w
.26233 .47535 m
.26459 .47261 L
s
.008 w
.26459 .47261 Mdot
.016 w
.26459 .47261 m
.26684 .46974 L
s
.008 w
.26684 .46974 Mdot
.016 w
.26684 .46974 m
.26878 .46691 L
s
1 .556 0 r
.008 w
.26878 .46691 Mdot
.016 w
.26878 .46691 m
.2707 .46403 L
s
.008 w
.2707 .46403 Mdot
.016 w
.2707 .46403 m
.27244 .46091 L
s
.008 w
.27244 .46091 Mdot
.016 w
.27244 .46091 m
.27409 .45778 L
s
.008 w
.27409 .45778 Mdot
.016 w
.27409 .45778 m
.27563 .45496 L
s
.008 w
.27563 .45496 Mdot
.016 w
.27563 .45496 m
.27711 .45187 L
s
1 .555 0 r
.008 w
.27711 .45187 Mdot
.016 w
.27711 .45187 m
.27855 .4485 L
s
.008 w
.27855 .4485 Mdot
.016 w
.27855 .4485 m
.27995 .44499 L
s
.008 w
.27995 .44499 Mdot
.016 w
.27995 .44499 m
.28141 .44217 L
s
.008 w
.28141 .44217 Mdot
.016 w
.28141 .44217 m
.28283 .43891 L
s
.008 w
.28283 .43891 Mdot
.016 w
.28283 .43891 m
.28428 .43545 L
s
1 .554 0 r
.008 w
.28428 .43545 Mdot
.016 w
.28428 .43545 m
.28577 .43238 L
s
.008 w
.28577 .43238 Mdot
.016 w
.28577 .43238 m
.28729 .42911 L
s
.008 w
.28729 .42911 Mdot
.016 w
.28729 .42911 m
.28883 .42562 L
s
.008 w
.28883 .42562 Mdot
.016 w
.28883 .42562 m
.29038 .4227 L
s
.008 w
.29038 .4227 Mdot
.016 w
.29038 .4227 m
.29192 .41952 L
s
1 .553 0 r
.008 w
.29192 .41952 Mdot
.016 w
.29192 .41952 m
.29345 .41658 L
s
.008 w
.29345 .41658 Mdot
.016 w
.29345 .41658 m
.29498 .41359 L
s
.008 w
.29498 .41359 Mdot
.016 w
.29498 .41359 m
.29648 .41097 L
s
.008 w
.29648 .41097 Mdot
.016 w
.29648 .41097 m
.2979 .40829 L
s
.008 w
.2979 .40829 Mdot
.016 w
.2979 .40829 m
.29928 .40581 L
s
1 .552 0 r
.008 w
.29928 .40581 Mdot
.016 w
.29928 .40581 m
.30057 .40335 L
s
.008 w
.30057 .40335 Mdot
.016 w
.30057 .40335 m
.30183 .40091 L
s
.008 w
.30183 .40091 Mdot
.016 w
.30183 .40091 m
.30296 .39872 L
s
.008 w
.30296 .39872 Mdot
.016 w
.30296 .39872 m
.30402 .39656 L
s
1 .551 0 r
.008 w
.30402 .39656 Mdot
.016 w
.30402 .39656 m
.30501 .39468 L
s
.008 w
.30501 .39468 Mdot
.016 w
.30501 .39468 m
.30591 .39294 L
s
.008 w
.30591 .39294 Mdot
.016 w
.30591 .39294 m
.30675 .39145 L
s
.008 w
.30675 .39145 Mdot
.016 w
.30675 .39145 m
.30754 .39014 L
s
.008 w
.30754 .39014 Mdot
.016 w
.30754 .39014 m
.3083 .38911 L
s
1 .55 0 r
.008 w
.3083 .38911 Mdot
.016 w
.3083 .38911 m
.30909 .38826 L
s
.008 w
.30909 .38826 Mdot
.016 w
.30909 .38826 m
.30991 .3876 L
s
.008 w
.30991 .3876 Mdot
.016 w
.30991 .3876 m
.31077 .38714 L
s
.008 w
.31077 .38714 Mdot
.016 w
.31077 .38714 m
.31172 .38684 L
s
.008 w
.31172 .38684 Mdot
.016 w
.31172 .38684 m
.31276 .38666 L
s
1 .549 0 r
.008 w
.31276 .38666 Mdot
.016 w
.31276 .38666 m
.31392 .38658 L
s
.008 w
.31392 .38658 Mdot
.016 w
.31392 .38658 m
.31507 .38657 L
s
.008 w
.31507 .38657 Mdot
.016 w
.31507 .38657 m
.31633 .3866 L
s
.008 w
.31633 .3866 Mdot
.016 w
.31633 .3866 m
.31766 .38666 L
s
.008 w
.31766 .38666 Mdot
.016 w
.31766 .38666 m
.31893 .38673 L
s
1 .548 0 r
.008 w
.31893 .38673 Mdot
.016 w
.31893 .38673 m
.32019 .38676 L
s
.008 w
.32019 .38676 Mdot
.016 w
.32019 .38676 m
.3213 .38676 L
s
.008 w
.3213 .38676 Mdot
.016 w
.3213 .38676 m
.32237 .38663 L
s
.008 w
.32237 .38663 Mdot
.016 w
.32237 .38663 m
.32325 .38659 L
s
1 .547 0 r
.008 w
.32325 .38659 Mdot
.016 w
.32325 .38659 m
.32395 .38658 L
s
.008 w
.32395 .38658 Mdot
.016 w
.32395 .38658 m
.32447 .3866 L
s
.008 w
.32447 .3866 Mdot
.016 w
.32447 .3866 m
.32479 .38664 L
s
.008 w
.32479 .38664 Mdot
.016 w
.32479 .38664 m
.32491 .38671 L
s
.008 w
.32491 .38671 Mdot
.016 w
.32491 .38671 m
.32486 .3868 L
s
1 .546 0 r
.008 w
.32486 .3868 Mdot
.016 w
.32486 .3868 m
.32468 .3869 L
s
.008 w
.32468 .3869 Mdot
.016 w
.32468 .3869 m
.32442 .38699 L
s
.008 w
.32442 .38699 Mdot
.016 w
.32442 .38699 m
.32418 .38705 L
s
.008 w
.32418 .38705 Mdot
.016 w
.32418 .38705 m
.32403 .38707 L
s
.008 w
.32403 .38707 Mdot
.016 w
.32403 .38707 m
.32409 .38704 L
s
1 .545 0 r
.008 w
.32409 .38704 Mdot
.016 w
.32409 .38704 m
.32441 .38694 L
s
.008 w
.32441 .38694 Mdot
.016 w
.32441 .38694 m
.32504 .38676 L
s
.008 w
.32504 .38676 Mdot
.016 w
.32504 .38676 m
.326 .3865 L
s
.008 w
.326 .3865 Mdot
.016 w
.326 .3865 m
.32728 .38614 L
s
.008 w
.32728 .38614 Mdot
.016 w
.32728 .38614 m
.32883 .38571 L
s
1 .544 0 r
.008 w
.32883 .38571 Mdot
.016 w
.32883 .38571 m
.33065 .38521 L
s
.008 w
.33065 .38521 Mdot
.016 w
.33065 .38521 m
.33266 .38467 L
s
.008 w
.33266 .38467 Mdot
.016 w
.33266 .38467 m
.33488 .3841 L
s
.008 w
.33488 .3841 Mdot
.016 w
.33488 .3841 m
.33728 .38348 L
s
1 .543 0 r
.008 w
.33728 .38348 Mdot
.016 w
.33728 .38348 m
.33979 .38284 L
s
.008 w
.33979 .38284 Mdot
.016 w
.33979 .38284 m
.34241 .38216 L
s
.008 w
.34241 .38216 Mdot
.016 w
.34241 .38216 m
.34501 .38143 L
s
.008 w
.34501 .38143 Mdot
.016 w
.34501 .38143 m
.34762 .38065 L
s
.008 w
.34762 .38065 Mdot
.016 w
.34762 .38065 m
.3502 .37981 L
s
1 .542 0 r
.008 w
.3502 .37981 Mdot
.016 w
.3502 .37981 m
.35276 .37892 L
s
.008 w
.35276 .37892 Mdot
.016 w
.35276 .37892 m
.35528 .37797 L
s
.008 w
.35528 .37797 Mdot
.016 w
.35528 .37797 m
.35784 .37698 L
s
.008 w
.35784 .37698 Mdot
.016 w
.35784 .37698 m
.36043 .37596 L
s
.008 w
.36043 .37596 Mdot
.016 w
.36043 .37596 m
.36307 .37494 L
s
1 .541 0 r
.008 w
.36307 .37494 Mdot
.016 w
.36307 .37494 m
.36576 .37389 L
s
.008 w
.36576 .37389 Mdot
.016 w
.36576 .37389 m
.36845 .37284 L
s
.008 w
.36845 .37284 Mdot
.016 w
.36845 .37284 m
.37105 .37184 L
s
.008 w
.37105 .37184 Mdot
.016 w
.37105 .37184 m
.3735 .37094 L
s
.008 w
.3735 .37094 Mdot
.016 w
.3735 .37094 m
.37574 .37013 L
s
1 .54 0 r
.008 w
.37574 .37013 Mdot
.016 w
.37574 .37013 m
.37773 .36942 L
s
.008 w
.37773 .36942 Mdot
.016 w
.37773 .36942 m
.37939 .36885 L
s
.008 w
.37939 .36885 Mdot
.016 w
.37939 .36885 m
.38074 .36845 L
s
.008 w
.38074 .36845 Mdot
.016 w
.38074 .36845 m
.38177 .36823 L
s
.008 w
.38177 .36823 Mdot
.016 w
.38177 .36823 m
.38247 .36821 L
s
1 .539 0 r
.008 w
.38247 .36821 Mdot
.016 w
.38247 .36821 m
.38287 .36836 L
s
.008 w
.38287 .36836 Mdot
.016 w
.38287 .36836 m
.38297 .36863 L
s
.008 w
.38297 .36863 Mdot
.016 w
.38297 .36863 m
.38285 .36896 L
s
.008 w
.38285 .36896 Mdot
.016 w
.38285 .36896 m
.38255 .36927 L
s
1 .538 0 r
.008 w
.38255 .36927 Mdot
.016 w
.38255 .36927 m
.38214 .36955 L
s
.008 w
.38214 .36955 Mdot
.016 w
.38214 .36955 m
.38167 .36977 L
s
.008 w
.38167 .36977 Mdot
.016 w
.38167 .36977 m
.38119 .36996 L
s
.008 w
.38119 .36996 Mdot
.016 w
.38119 .36996 m
.38074 .37015 L
s
.008 w
.38074 .37015 Mdot
.016 w
.38074 .37015 m
.38033 .37033 L
s
1 .537 0 r
.008 w
.38033 .37033 Mdot
.016 w
.38033 .37033 m
.37997 .3705 L
s
.008 w
.37997 .3705 Mdot
.016 w
.37997 .3705 m
.37969 .37067 L
s
.008 w
.37969 .37067 Mdot
.016 w
.37969 .37067 m
.37956 .37083 L
s
.008 w
.37956 .37083 Mdot
.016 w
.37956 .37083 m
.37962 .37101 L
s
.008 w
.37962 .37101 Mdot
.016 w
.37962 .37101 m
.37992 .37121 L
s
1 .536 0 r
.008 w
.37992 .37121 Mdot
.016 w
.37992 .37121 m
.38049 .37147 L
s
.008 w
.38049 .37147 Mdot
.016 w
.38049 .37147 m
.38132 .37178 L
s
.008 w
.38132 .37178 Mdot
.016 w
.38132 .37178 m
.38237 .37222 L
s
.008 w
.38237 .37222 Mdot
.016 w
.38237 .37222 m
.38359 .37279 L
s
.008 w
.38359 .37279 Mdot
.016 w
.38359 .37279 m
.38493 .37349 L
s
1 .535 0 r
.008 w
.38493 .37349 Mdot
.016 w
.38493 .37349 m
.38629 .37429 L
s
.008 w
.38629 .37429 Mdot
.016 w
.38629 .37429 m
.38762 .37516 L
s
.008 w
.38762 .37516 Mdot
.016 w
.38762 .37516 m
.38883 .37603 L
s
.008 w
.38883 .37603 Mdot
.016 w
.38883 .37603 m
.38993 .37687 L
s
1 .534 0 r
.008 w
.38993 .37687 Mdot
.016 w
.38993 .37687 m
.3909 .37762 L
s
.008 w
.3909 .37762 Mdot
.016 w
.3909 .37762 m
.39172 .37823 L
s
.008 w
.39172 .37823 Mdot
.016 w
.39172 .37823 m
.39244 .37866 L
s
.008 w
.39244 .37866 Mdot
.016 w
.39244 .37866 m
.3931 .3789 L
s
.008 w
.3931 .3789 Mdot
.016 w
.3931 .3789 m
.39379 .3789 L
s
1 .533 0 r
.008 w
.39379 .3789 Mdot
.016 w
.39379 .3789 m
.39455 .37863 L
s
.008 w
.39455 .37863 Mdot
.016 w
.39455 .37863 m
.39547 .37805 L
s
.008 w
.39547 .37805 Mdot
.016 w
.39547 .37805 m
.39662 .37713 L
s
.008 w
.39662 .37713 Mdot
.016 w
.39662 .37713 m
.39804 .37589 L
s
.008 w
.39804 .37589 Mdot
.016 w
.39804 .37589 m
.3997 .3744 L
s
1 .532 0 r
.008 w
.3997 .3744 Mdot
.016 w
.3997 .3744 m
.40161 .37271 L
s
.008 w
.40161 .37271 Mdot
.016 w
.40161 .37271 m
.40373 .37098 L
s
.008 w
.40373 .37098 Mdot
.016 w
.40373 .37098 m
.40596 .3692 L
s
.008 w
.40596 .3692 Mdot
.016 w
.40596 .3692 m
.4082 .36735 L
s
.008 w
.4082 .36735 Mdot
.016 w
.4082 .36735 m
.41035 .36547 L
s
1 .531 0 r
.008 w
.41035 .36547 Mdot
.016 w
.41035 .36547 m
.41234 .36357 L
s
.008 w
.41234 .36357 Mdot
.016 w
.41234 .36357 m
.41415 .36174 L
s
.008 w
.41415 .36174 Mdot
.016 w
.41415 .36174 m
.41572 .35987 L
s
.008 w
.41572 .35987 Mdot
.016 w
.41572 .35987 m
.41703 .35814 L
s
1 .53 0 r
.008 w
.41703 .35814 Mdot
.016 w
.41703 .35814 m
.41818 .35646 L
s
.008 w
.41818 .35646 Mdot
.016 w
.41818 .35646 m
.41932 .3547 L
s
.008 w
.41932 .3547 Mdot
.016 w
.41932 .3547 m
.42062 .35277 L
s
.008 w
.42062 .35277 Mdot
.016 w
.42062 .35277 m
.4222 .35066 L
s
.008 w
.4222 .35066 Mdot
.016 w
.4222 .35066 m
.42415 .34827 L
s
1 .529 0 r
.008 w
.42415 .34827 Mdot
.016 w
.42415 .34827 m
.42652 .34547 L
s
.008 w
.42652 .34547 Mdot
.016 w
.42652 .34547 m
.42922 .34206 L
s
.008 w
.42922 .34206 Mdot
.016 w
.42922 .34206 m
.43226 .33818 L
s
.008 w
.43226 .33818 Mdot
.016 w
.43226 .33818 m
.43556 .33362 L
s
.008 w
.43556 .33362 Mdot
.016 w
.43556 .33362 m
.43889 .32978 L
s
1 .528 0 r
.008 w
.43889 .32978 Mdot
.016 w
.43889 .32978 m
.44227 .32531 L
s
.008 w
.44227 .32531 Mdot
.016 w
.44227 .32531 m
.4456 .32149 L
s
.008 w
.4456 .32149 Mdot
.016 w
.4456 .32149 m
.44862 .31792 L
s
.008 w
.44862 .31792 Mdot
.016 w
.44862 .31792 m
.4514 .31478 L
s
.008 w
.4514 .31478 Mdot
.016 w
.4514 .31478 m
.45383 .31181 L
s
1 .527 0 r
.008 w
.45383 .31181 Mdot
.016 w
.45383 .31181 m
.45584 .309 L
s
.008 w
.45584 .309 Mdot
.016 w
.45584 .309 m
.45737 .30675 L
s
.008 w
.45737 .30675 Mdot
.016 w
.45737 .30675 m
.4584 .3053 L
s
.008 w
.4584 .3053 Mdot
.016 w
.4584 .3053 m
.45898 .30454 L
s
.008 w
.45898 .30454 Mdot
.016 w
.45898 .30454 m
.45918 .30424 L
s
1 .526 0 r
.008 w
.45918 .30424 Mdot
.016 w
.45918 .30424 m
.45909 .30425 L
s
.008 w
.45909 .30425 Mdot
.016 w
.45909 .30425 m
.45881 .30455 L
s
.008 w
.45881 .30455 Mdot
.016 w
.45881 .30455 m
.4585 .30503 L
s
.008 w
.4585 .30503 Mdot
.016 w
.4585 .30503 m
.45829 .30541 L
s
1 .525 0 r
.008 w
.45829 .30541 Mdot
.016 w
.45829 .30541 m
.45823 .30553 L
s
.008 w
.45823 .30553 Mdot
.016 w
.45823 .30553 m
.45826 .30561 L
s
.008 w
.45826 .30561 Mdot
.016 w
.45826 .30561 m
.45832 .30573 L
s
.008 w
.45832 .30573 Mdot
.016 w
.45832 .30573 m
.45847 .30586 L
s
.008 w
.45847 .30586 Mdot
.016 w
.45847 .30586 m
.45876 .30596 L
s
1 .524 0 r
.008 w
.45876 .30596 Mdot
.016 w
.45876 .30596 m
.45925 .30598 L
s
.008 w
.45925 .30598 Mdot
.016 w
.45925 .30598 m
.46007 .30588 L
s
.008 w
.46007 .30588 Mdot
.016 w
.46007 .30588 m
.46138 .30561 L
s
.008 w
.46138 .30561 Mdot
.016 w
.46138 .30561 m
.46327 .30515 L
s
.008 w
.46327 .30515 Mdot
.016 w
.46327 .30515 m
.4657 .30451 L
s
1 .523 0 r
.008 w
.4657 .30451 Mdot
.016 w
.4657 .30451 m
.46873 .30369 L
s
.008 w
.46873 .30369 Mdot
.016 w
.46873 .30369 m
.47231 .30272 L
s
.008 w
.47231 .30272 Mdot
.016 w
.47231 .30272 m
.47639 .30164 L
s
.008 w
.47639 .30164 Mdot
.016 w
.47639 .30164 m
.48054 .30059 L
s
.008 w
.48054 .30059 Mdot
.016 w
.48054 .30059 m
.48486 .29952 L
s
1 .522 0 r
.008 w
.48486 .29952 Mdot
.016 w
.48486 .29952 m
.48901 .29855 L
s
.008 w
.48901 .29855 Mdot
.016 w
.48901 .29855 m
.49324 .29759 L
s
.008 w
.49324 .29759 Mdot
.016 w
.49324 .29759 m
.49796 .2966 L
s
.008 w
.49796 .2966 Mdot
.016 w
.49796 .2966 m
.50243 .29562 L
s
1 .521 0 r
.008 w
.50243 .29562 Mdot
.016 w
.50243 .29562 m
.50716 .29463 L
s
.008 w
.50716 .29463 Mdot
.016 w
.50716 .29463 m
.51214 .29364 L
s
.008 w
.51214 .29364 Mdot
.016 w
.51214 .29364 m
.51732 .29263 L
s
.008 w
.51732 .29263 Mdot
.016 w
.51732 .29263 m
.52261 .2916 L
s
.008 w
.52261 .2916 Mdot
.016 w
.52261 .2916 m
.52746 .29056 L
s
1 .52 0 r
.008 w
.52746 .29056 Mdot
.016 w
.52746 .29056 m
.53224 .28953 L
s
.008 w
.53224 .28953 Mdot
.016 w
.53224 .28953 m
.53677 .28849 L
s
.008 w
.53677 .28849 Mdot
.016 w
.53677 .28849 m
.54087 .28751 L
s
.008 w
.54087 .28751 Mdot
.016 w
.54087 .28751 m
.54437 .28655 L
s
.008 w
.54437 .28655 Mdot
.016 w
.54437 .28655 m
.54769 .28558 L
s
1 .519 0 r
.008 w
.54769 .28558 Mdot
.016 w
.54769 .28558 m
.55093 .28465 L
s
.008 w
.55093 .28465 Mdot
.016 w
.55093 .28465 m
.55391 .28381 L
s
.008 w
.55391 .28381 Mdot
.016 w
.55391 .28381 m
.55634 .28311 L
s
.008 w
.55634 .28311 Mdot
.016 w
.55634 .28311 m
.55817 .2826 L
s
.008 w
.55817 .2826 Mdot
.016 w
.55817 .2826 m
.55948 .28224 L
s
1 .518 0 r
.008 w
.55948 .28224 Mdot
.016 w
.55948 .28224 m
.56042 .282 L
s
.008 w
.56042 .282 Mdot
.016 w
.56042 .282 m
.56123 .28184 L
s
.008 w
.56123 .28184 Mdot
.016 w
.56123 .28184 m
.56222 .28172 L
s
.008 w
.56222 .28172 Mdot
.016 w
.56222 .28172 m
.56353 .28154 L
s
.008 w
.56353 .28154 Mdot
.016 w
.56353 .28154 m
.56528 .28119 L
s
1 .517 0 r
.008 w
.56528 .28119 Mdot
.016 w
.56528 .28119 m
.56791 .28062 L
s
.008 w
.56791 .28062 Mdot
.016 w
.56791 .28062 m
.57124 .2798 L
s
.008 w
.57124 .2798 Mdot
.016 w
.57124 .2798 m
.57537 .27874 L
s
.008 w
.57537 .27874 Mdot
.016 w
.57537 .27874 m
.58055 .27745 L
s
1 .516 0 r
.008 w
.58055 .27745 Mdot
.016 w
.58055 .27745 m
.58704 .27593 L
s
.008 w
.58704 .27593 Mdot
.016 w
.58704 .27593 m
.59455 .27429 L
s
.008 w
.59455 .27429 Mdot
.016 w
.59455 .27429 m
.60315 .27255 L
s
.008 w
.60315 .27255 Mdot
.016 w
.60315 .27255 m
.61209 .27077 L
s
.008 w
.61209 .27077 Mdot
.016 w
.61209 .27077 m
.61954 .26903 L
s
1 .515 0 r
.008 w
.61954 .26903 Mdot
.016 w
.61954 .26903 m
.62673 .26743 L
s
.008 w
.62673 .26743 Mdot
.016 w
.62673 .26743 m
.63349 .26599 L
s
.008 w
.63349 .26599 Mdot
.016 w
.63349 .26599 m
.63972 .26464 L
s
.008 w
.63972 .26464 Mdot
.016 w
.63972 .26464 m
.64615 .26339 L
s
.008 w
.64615 .26339 Mdot
.016 w
.64615 .26339 m
.6525 .26231 L
s
1 .514 0 r
.008 w
.6525 .26231 Mdot
.016 w
.6525 .26231 m
.65733 .26148 L
s
.008 w
.65733 .26148 Mdot
.016 w
.65733 .26148 m
.66003 .26094 L
s
.008 w
.66003 .26094 Mdot
.016 w
.66003 .26094 m
.66113 .26067 L
s
.008 w
.66113 .26067 Mdot
.016 w
.66113 .26067 m
.66138 .26061 L
s
.008 w
.66138 .26061 Mdot
.016 w
.66138 .26061 m
.66118 .26069 L
s
1 .513 0 r
.008 w
.66118 .26069 Mdot
.016 w
.66118 .26069 m
.66051 .26083 L
s
.008 w
.66051 .26083 Mdot
.016 w
.66051 .26083 m
.65976 .26097 L
s
.008 w
.65976 .26097 Mdot
.016 w
.65976 .26097 m
.65982 .26104 L
s
.008 w
.65982 .26104 Mdot
.016 w
.65982 .26104 m
.66052 .26102 L
s
1 .512 0 r
.008 w
.66052 .26102 Mdot
.016 w
.66052 .26102 m
.66167 .26098 L
s
.008 w
.66167 .26098 Mdot
.016 w
.66167 .26098 m
.66321 .26101 L
s
.008 w
.66321 .26101 Mdot
.016 w
.66321 .26101 m
.66517 .26115 L
s
.008 w
.66517 .26115 Mdot
.016 w
.66517 .26115 m
.66753 .26141 L
s
.008 w
.66753 .26141 Mdot
.016 w
.66753 .26141 m
.67029 .26179 L
s
1 .511 0 r
.008 w
.67029 .26179 Mdot
.016 w
.67029 .26179 m
.67346 .26228 L
s
.008 w
.67346 .26228 Mdot
.016 w
.67346 .26228 m
.67697 .26285 L
s
.008 w
.67697 .26285 Mdot
.016 w
.67697 .26285 m
.6807 .26348 L
s
.008 w
.6807 .26348 Mdot
.016 w
.6807 .26348 m
.68442 .26414 L
s
.008 w
.68442 .26414 Mdot
.016 w
.68442 .26414 m
.68807 .2648 L
s
1 .51 0 r
.008 w
.68807 .2648 Mdot
.016 w
.68807 .2648 m
.69147 .26547 L
s
.008 w
.69147 .26547 Mdot
.016 w
.69147 .26547 m
.69461 .26614 L
s
.008 w
.69461 .26614 Mdot
.016 w
.69461 .26614 m
.6974 .26678 L
s
.008 w
.6974 .26678 Mdot
.016 w
.6974 .26678 m
.69979 .2674 L
s
.008 w
.69979 .2674 Mdot
.016 w
.69979 .2674 m
.70176 .26794 L
s
1 .509 0 r
.008 w
.70176 .26794 Mdot
.016 w
.70176 .26794 m
.70339 .26838 L
s
.008 w
.70339 .26838 Mdot
.016 w
.70339 .26838 m
.70475 .26867 L
s
.008 w
.70475 .26867 Mdot
.016 w
.70475 .26867 m
.7059 .26875 L
s
.008 w
.7059 .26875 Mdot
.016 w
.7059 .26875 m
.70692 .26861 L
s
1 .508 0 r
.008 w
.70692 .26861 Mdot
.016 w
.70692 .26861 m
.70788 .26825 L
s
.008 w
.70788 .26825 Mdot
.016 w
.70788 .26825 m
.70894 .26767 L
s
.008 w
.70894 .26767 Mdot
.016 w
.70894 .26767 m
.71023 .2669 L
s
.008 w
.71023 .2669 Mdot
.016 w
.71023 .2669 m
.71182 .26592 L
s
.008 w
.71182 .26592 Mdot
.016 w
.71182 .26592 m
.71368 .26474 L
s
1 .507 0 r
.008 w
.71368 .26474 Mdot
.016 w
.71368 .26474 m
.71579 .26341 L
s
.008 w
.71579 .26341 Mdot
.016 w
.71579 .26341 m
.71821 .26185 L
s
.008 w
.71821 .26185 Mdot
.016 w
.71821 .26185 m
.72093 .26012 L
s
.008 w
.72093 .26012 Mdot
.016 w
.72093 .26012 m
.72382 .25828 L
s
.008 w
.72382 .25828 Mdot
.016 w
.72382 .25828 m
.7268 .25631 L
s
1 .506 0 r
.008 w
.7268 .25631 Mdot
.016 w
.7268 .25631 m
.7298 .25435 L
s
.008 w
.7298 .25435 Mdot
.016 w
.7298 .25435 m
.73286 .2523 L
s
.008 w
.73286 .2523 Mdot
.016 w
.73286 .2523 m
.73593 .25022 L
s
.008 w
.73593 .25022 Mdot
.016 w
.73593 .25022 m
.73905 .2482 L
s
.008 w
.73905 .2482 Mdot
.016 w
.73905 .2482 m
.74221 .24618 L
s
1 .505 0 r
.008 w
.74221 .24618 Mdot
.016 w
.74221 .24618 m
.74545 .24423 L
s
.008 w
.74545 .24423 Mdot
.016 w
.74545 .24423 m
.74878 .24227 L
s
.008 w
.74878 .24227 Mdot
.016 w
.74878 .24227 m
.75219 .24031 L
s
.008 w
.75219 .24031 Mdot
.016 w
.75219 .24031 m
.75568 .23833 L
s
.008 w
.75568 .23833 Mdot
.016 w
.75568 .23833 m
.75921 .23634 L
s
1 .504 0 r
.008 w
.75921 .23634 Mdot
.016 w
.75921 .23634 m
.76263 .23431 L
s
.008 w
.76263 .23431 Mdot
.016 w
.76263 .23431 m
.76594 .2323 L
s
.008 w
.76594 .2323 Mdot
.016 w
.76594 .2323 m
.76897 .23041 L
s
.008 w
.76897 .23041 Mdot
.016 w
.76897 .23041 m
.7718 .2285 L
s
1 .503 0 r
.008 w
.7718 .2285 Mdot
.016 w
.7718 .2285 m
.77439 .22659 L
s
.008 w
.77439 .22659 Mdot
.016 w
.77439 .22659 m
.77675 .22468 L
s
.008 w
.77675 .22468 Mdot
.016 w
.77675 .22468 m
.77885 .22283 L
s
.008 w
.77885 .22283 Mdot
.016 w
.77885 .22283 m
.78073 .22101 L
s
.008 w
.78073 .22101 Mdot
.016 w
.78073 .22101 m
.78239 .21912 L
s
1 .502 0 r
.008 w
.78239 .21912 Mdot
.016 w
.78239 .21912 m
.78387 .2171 L
s
.008 w
.78387 .2171 Mdot
.016 w
.78387 .2171 m
.78521 .21501 L
s
.008 w
.78521 .21501 Mdot
.016 w
.78521 .21501 m
.78647 .21286 L
s
.008 w
.78647 .21286 Mdot
.016 w
.78647 .21286 m
.78771 .21057 L
s
.008 w
.78771 .21057 Mdot
.016 w
.78771 .21057 m
.78901 .20822 L
s
1 .501 0 r
.008 w
.78901 .20822 Mdot
.016 w
.78901 .20822 m
.79035 .20582 L
s
.008 w
.79035 .20582 Mdot
.016 w
.79035 .20582 m
.79169 .20352 L
s
.008 w
.79169 .20352 Mdot
.016 w
.79169 .20352 m
.79295 .20133 L
s
.008 w
.79295 .20133 Mdot
.016 w
.79295 .20133 m
.7941 .19937 L
s
.008 w
.7941 .19937 Mdot
.016 w
.7941 .19937 m
.79513 .19756 L
s
1 .5 0 r
.008 w
.79513 .19756 Mdot
.016 w
.79513 .19756 m
.79603 .19607 L
s
.008 w
.79603 .19607 Mdot
.016 w
.79603 .19607 m
.79677 .19485 L
s
.008 w
.79677 .19485 Mdot
.016 w
.79677 .19485 m
.79734 .1939 L
s
.008 w
.79734 .1939 Mdot
.016 w
.79734 .1939 m
.79778 .19323 L
s
1 .499 0 r
.008 w
.79778 .19323 Mdot
.016 w
.79778 .19323 m
.79819 .1928 L
s
.008 w
.79819 .1928 Mdot
.016 w
.79819 .1928 m
.79864 .19256 L
s
.008 w
.79864 .19256 Mdot
.016 w
.79864 .19256 m
.79922 .19249 L
s
.008 w
.79922 .19249 Mdot
.016 w
.79922 .19249 m
.79998 .19252 L
s
.008 w
.79998 .19252 Mdot
.016 w
.79998 .19252 m
.80098 .1926 L
s
1 .498 0 r
.008 w
.80098 .1926 Mdot
.016 w
.80098 .1926 m
.80223 .19265 L
s
.008 w
.80223 .19265 Mdot
.016 w
.80223 .19265 m
.80372 .19262 L
s
.008 w
.80372 .19262 Mdot
.016 w
.80372 .19262 m
.80539 .19247 L
s
.008 w
.80539 .19247 Mdot
.016 w
.80539 .19247 m
.80721 .19219 L
s
.008 w
.80721 .19219 Mdot
.016 w
.80721 .19219 m
.8091 .19182 L
s
1 .497 0 r
.008 w
.8091 .19182 Mdot
.016 w
.8091 .19182 m
.811 .19143 L
s
.008 w
.811 .19143 Mdot
.016 w
.811 .19143 m
.81286 .19104 L
s
.008 w
.81286 .19104 Mdot
.016 w
.81286 .19104 m
.81462 .19071 L
s
.008 w
.81462 .19071 Mdot
.016 w
.81462 .19071 m
.81622 .19046 L
s
.008 w
.81622 .19046 Mdot
.016 w
.81622 .19046 m
.81762 .19031 L
s
1 .496 0 r
.008 w
.81762 .19031 Mdot
.016 w
.81762 .19031 m
.81881 .19029 L
s
.008 w
.81881 .19029 Mdot
.016 w
.81881 .19029 m
.8198 .19044 L
s
.008 w
.8198 .19044 Mdot
.016 w
.8198 .19044 m
.8206 .19075 L
s
.008 w
.8206 .19075 Mdot
.016 w
.8206 .19075 m
.82123 .19119 L
s
1 .495 0 r
.008 w
.82123 .19119 Mdot
.016 w
.82123 .19119 m
.82172 .19171 L
s
.008 w
.82172 .19171 Mdot
.016 w
.82172 .19171 m
.8221 .19226 L
s
.008 w
.8221 .19226 Mdot
.016 w
.8221 .19226 m
.82243 .19284 L
s
.008 w
.82243 .19284 Mdot
.016 w
.82243 .19284 m
.82275 .19341 L
s
.008 w
.82275 .19341 Mdot
.016 w
.82275 .19341 m
.8231 .19397 L
s
1 .494 0 r
.008 w
.8231 .19397 Mdot
.016 w
.8231 .19397 m
.82346 .19448 L
s
.008 w
.82346 .19448 Mdot
.016 w
.82346 .19448 m
.82372 .19469 L
s
.008 w
.82372 .19469 Mdot
.016 w
.82372 .19469 m
.82402 .19494 L
s
.008 w
.82402 .19494 Mdot
.016 w
.82402 .19494 m
.82426 .19508 L
s
.008 w
.82426 .19508 Mdot
.016 w
.82426 .19508 m
.82443 .19512 L
s
1 .493 0 r
.008 w
.82443 .19512 Mdot
.016 w
.82443 .19512 m
.82454 .19505 L
s
.008 w
.82454 .19505 Mdot
.016 w
.82454 .19505 m
.82458 .19489 L
s
.008 w
.82458 .19489 Mdot
.016 w
.82458 .19489 m
.82454 .19467 L
s
.008 w
.82454 .19467 Mdot
.016 w
.82454 .19467 m
.82446 .19442 L
s
.008 w
.82446 .19442 Mdot
.016 w
.82446 .19442 m
.82438 .19425 L
s
1 .492 0 r
.008 w
.82438 .19425 Mdot
.016 w
.82438 .19425 m
.82429 .19409 L
s
.008 w
.82429 .19409 Mdot
.016 w
.82429 .19409 m
.8242 .19397 L
s
.008 w
.8242 .19397 Mdot
.016 w
.8242 .19397 m
.82414 .19389 L
s
.008 w
.82414 .19389 Mdot
.016 w
.82414 .19389 m
.82412 .19389 L
s
.008 w
.82412 .19389 Mdot
.016 w
.82412 .19389 m
.82415 .19395 L
s
1 .491 0 r
.008 w
.82415 .19395 Mdot
.016 w
.82415 .19395 m
.82419 .19405 L
s
.008 w
.82419 .19405 Mdot
.016 w
.82419 .19405 m
.82424 .19415 L
s
.008 w
.82424 .19415 Mdot
.016 w
.82424 .19415 m
.82426 .19421 L
s
.008 w
.82426 .19421 Mdot
.016 w
.82426 .19421 m
.82425 .19424 L
s
1 .49 0 r
.008 w
.82425 .19424 Mdot
.016 w
.82425 .19424 m
.82423 .19424 L
s
.008 w
.82423 .19424 Mdot
.016 w
.82423 .19424 m
.82419 .19421 L
s
.008 w
.82419 .19421 Mdot
.016 w
.82419 .19421 m
.8241 .19412 L
s
.008 w
.8241 .19412 Mdot
.016 w
.8241 .19412 m
.82395 .19391 L
s
.008 w
.82395 .19391 Mdot
.016 w
.82395 .19391 m
.82374 .19355 L
s
1 .489 0 r
.008 w
.82374 .19355 Mdot
.016 w
.82374 .19355 m
.82348 .19303 L
s
.008 w
.82348 .19303 Mdot
.016 w
.82348 .19303 m
.82319 .19231 L
s
.008 w
.82319 .19231 Mdot
.016 w
.82319 .19231 m
.82285 .19139 L
s
.008 w
.82285 .19139 Mdot
.016 w
.82285 .19139 m
.82252 .1903 L
s
.008 w
.82252 .1903 Mdot
.016 w
.82252 .1903 m
.82212 .18901 L
s
1 .488 0 r
.008 w
.82212 .18901 Mdot
.016 w
.82212 .18901 m
.82168 .18753 L
s
.008 w
.82168 .18753 Mdot
.016 w
.82168 .18753 m
.82119 .186 L
s
.008 w
.82119 .186 Mdot
.016 w
.82119 .186 m
.82069 .1844 L
s
.008 w
.82069 .1844 Mdot
.016 w
.82069 .1844 m
.82016 .18273 L
s
.008 w
.82016 .18273 Mdot
.016 w
.82016 .18273 m
.81962 .18109 L
s
1 .487 0 r
.008 w
.81962 .18109 Mdot
.016 w
.81962 .18109 m
.81907 .17953 L
s
.008 w
.81907 .17953 Mdot
.016 w
.81907 .17953 m
.81855 .17814 L
s
.008 w
.81855 .17814 Mdot
.016 w
.81855 .17814 m
.81804 .17686 L
s
.008 w
.81804 .17686 Mdot
.016 w
.81804 .17686 m
.81758 .17574 L
s
1 .486 0 r
.008 w
.81758 .17574 Mdot
.016 w
.81758 .17574 m
.81716 .17485 L
s
.008 w
.81716 .17485 Mdot
.016 w
.81716 .17485 m
.81675 .17415 L
s
.008 w
.81675 .17415 Mdot
.016 w
.81675 .17415 m
.81633 .17364 L
s
.008 w
.81633 .17364 Mdot
.016 w
.81633 .17364 m
.81587 .17331 L
s
.008 w
.81587 .17331 Mdot
.016 w
.81587 .17331 m
.81537 .17314 L
s
1 .485 0 r
.008 w
.81537 .17314 Mdot
.016 w
.81537 .17314 m
.81481 .17307 L
s
.008 w
.81481 .17307 Mdot
.016 w
.81481 .17307 m
.81414 .17307 L
s
.008 w
.81414 .17307 Mdot
.016 w
.81414 .17307 m
.81353 .1731 L
s
.008 w
.81353 .1731 Mdot
.016 w
.81353 .1731 m
.81285 .17315 L
s
.008 w
.81285 .17315 Mdot
.016 w
.81285 .17315 m
.81215 .17319 L
s
1 .484 0 r
.008 w
.81215 .17319 Mdot
.016 w
.81215 .17319 m
.81146 .17319 L
s
.008 w
.81146 .17319 Mdot
.016 w
.81146 .17319 m
.81076 .17316 L
s
.008 w
.81076 .17316 Mdot
.016 w
.81076 .17316 m
.8101 .17309 L
s
.008 w
.8101 .17309 Mdot
.016 w
.8101 .17309 m
.80944 .17301 L
s
.008 w
.80944 .17301 Mdot
.016 w
.80944 .17301 m
.80883 .17298 L
s
1 .483 0 r
.008 w
.80883 .17298 Mdot
.016 w
.80883 .17298 m
.80832 .17302 L
s
.008 w
.80832 .17302 Mdot
.016 w
.80832 .17302 m
.80793 .17311 L
s
.008 w
.80793 .17311 Mdot
.016 w
.80793 .17311 m
.80768 .17327 L
s
.008 w
.80768 .17327 Mdot
.016 w
.80768 .17327 m
.80757 .17347 L
s
1 .482 0 r
.008 w
.80757 .17347 Mdot
.016 w
.80757 .17347 m
.80758 .17376 L
s
.008 w
.80758 .17376 Mdot
.016 w
.80758 .17376 m
.80763 .17413 L
s
.008 w
.80763 .17413 Mdot
.016 w
.80763 .17413 m
.80769 .17459 L
s
.008 w
.80769 .17459 Mdot
.016 w
.80769 .17459 m
.80774 .17517 L
s
.008 w
.80774 .17517 Mdot
.016 w
.80774 .17517 m
.80774 .17584 L
s
1 .481 0 r
.008 w
.80774 .17584 Mdot
.016 w
.80774 .17584 m
.80767 .1766 L
s
.008 w
.80767 .1766 Mdot
.016 w
.80767 .1766 m
.80757 .17742 L
s
.008 w
.80757 .17742 Mdot
.016 w
.80757 .17742 m
.80746 .17829 L
s
.008 w
.80746 .17829 Mdot
.016 w
.80746 .17829 m
.80738 .17915 L
s
.008 w
.80738 .17915 Mdot
.016 w
.80738 .17915 m
.80731 .17998 L
s
1 .48 0 r
.008 w
.80731 .17998 Mdot
.016 w
.80731 .17998 m
.80725 .18071 L
s
.008 w
.80725 .18071 Mdot
.016 w
.80725 .18071 m
.80722 .18132 L
s
.008 w
.80722 .18132 Mdot
.016 w
.80722 .18132 m
.80721 .18183 L
s
.008 w
.80721 .18183 Mdot
.016 w
.80721 .18183 m
.80722 .18222 L
s
.008 w
.80722 .18222 Mdot
.016 w
.80722 .18222 m
.80725 .18253 L
s
1 .479 0 r
.008 w
.80725 .18253 Mdot
.016 w
.80725 .18253 m
.80732 .18274 L
s
.008 w
.80732 .18274 Mdot
.016 w
.80732 .18274 m
.80743 .18289 L
s
.008 w
.80743 .18289 Mdot
.016 w
.80743 .18289 m
.80759 .18302 L
s
.008 w
.80759 .18302 Mdot
.016 w
.80759 .18302 m
.80777 .18319 L
s
.008 w
.80777 .18319 Mdot
.016 w
.80777 .18319 m
.80796 .18346 L
s
1 .478 0 r
.008 w
.80796 .18346 Mdot
.016 w
.80796 .18346 m
.80818 .18387 L
s
.008 w
.80818 .18387 Mdot
.016 w
.80818 .18387 m
.80846 .18448 L
s
.008 w
.80846 .18448 Mdot
.016 w
.80846 .18448 m
.80881 .18534 L
s
.008 w
.80881 .18534 Mdot
.016 w
.80881 .18534 m
.80925 .1865 L
s
1 .477 0 r
.008 w
.80925 .1865 Mdot
.016 w
.80925 .1865 m
.80987 .18776 L
s
.008 w
.80987 .18776 Mdot
.016 w
.80987 .18776 m
.81071 .18932 L
s
.008 w
.81071 .18932 Mdot
.016 w
.81071 .18932 m
.81185 .19117 L
s
.008 w
.81185 .19117 Mdot
.016 w
.81185 .19117 m
.81323 .19307 L
s
.008 w
.81323 .19307 Mdot
.016 w
.81323 .19307 m
.81485 .19531 L
s
1 .476 0 r
.008 w
.81485 .19531 Mdot
.016 w
.81485 .19531 m
.81679 .19755 L
s
.008 w
.81679 .19755 Mdot
.016 w
.81679 .19755 m
.81904 .20004 L
s
.008 w
.81904 .20004 Mdot
.016 w
.81904 .20004 m
.82094 .20239 L
s
.008 w
.82094 .20239 Mdot
.016 w
.82094 .20239 m
.82327 .20476 L
s
.008 w
.82327 .20476 Mdot
.016 w
.82327 .20476 m
.82554 .20701 L
s
1 .475 0 r
.008 w
.82554 .20701 Mdot
.016 w
.82554 .20701 m
.82784 .20913 L
s
.008 w
.82784 .20913 Mdot
.016 w
.82784 .20913 m
.83001 .21103 L
s
.008 w
.83001 .21103 Mdot
.016 w
.83001 .21103 m
.83212 .21274 L
s
.008 w
.83212 .21274 Mdot
.016 w
.83212 .21274 m
.83372 .21436 L
s
.008 w
.83372 .21436 Mdot
.016 w
.83372 .21436 m
.83516 .21563 L
s
1 .474 0 r
.008 w
.83516 .21563 Mdot
.016 w
.83516 .21563 m
.83644 .21675 L
s
.008 w
.83644 .21675 Mdot
.016 w
.83644 .21675 m
.83744 .21765 L
s
.008 w
.83744 .21765 Mdot
.016 w
.83744 .21765 m
.83818 .2183 L
s
.008 w
.83818 .2183 Mdot
.016 w
.83818 .2183 m
.83863 .21866 L
s
1 .473 0 r
.008 w
.83863 .21866 Mdot
.016 w
.83863 .21866 m
.83885 .2188 L
s
.008 w
.83885 .2188 Mdot
.016 w
.83885 .2188 m
.83896 .21876 L
s
.008 w
.83896 .21876 Mdot
.016 w
.83896 .21876 m
.83901 .21864 L
s
.008 w
.83901 .21864 Mdot
.016 w
.83901 .21864 m
.839 .21851 L
s
.008 w
.839 .21851 Mdot
.016 w
.839 .21851 m
.83897 .21845 L
s
1 .472 0 r
.008 w
.83897 .21845 Mdot
.016 w
.83897 .21845 m
.839 .21852 L
s
.008 w
.839 .21852 Mdot
.016 w
.839 .21852 m
.83911 .21877 L
s
.008 w
.83911 .21877 Mdot
.016 w
.83911 .21877 m
.83929 .21921 L
s
.008 w
.83929 .21921 Mdot
.016 w
.83929 .21921 m
.8395 .21981 L
s
.008 w
.8395 .21981 Mdot
.016 w
.8395 .21981 m
.83977 .22057 L
s
1 .471 0 r
.008 w
.83977 .22057 Mdot
.016 w
.83977 .22057 m
.84007 .22147 L
s
.008 w
.84007 .22147 Mdot
.016 w
.84007 .22147 m
.84039 .22244 L
s
.008 w
.84039 .22244 Mdot
.016 w
.84039 .22244 m
.84072 .22354 L
s
.008 w
.84072 .22354 Mdot
.016 w
.84072 .22354 m
.84106 .22479 L
s
.008 w
.84106 .22479 Mdot
.016 w
.84106 .22479 m
.84139 .22618 L
s
1 .47 0 r
.008 w
.84139 .22618 Mdot
.016 w
.84139 .22618 m
.84169 .22752 L
s
.008 w
.84169 .22752 Mdot
.016 w
.84169 .22752 m
.84195 .22887 L
s
.008 w
.84195 .22887 Mdot
.016 w
.84195 .22887 m
.84218 .23015 L
s
.008 w
.84218 .23015 Mdot
.016 w
.84218 .23015 m
.84236 .23127 L
s
.008 w
.84236 .23127 Mdot
.016 w
.84236 .23127 m
.84249 .23216 L
s
1 .469 0 r
.008 w
.84249 .23216 Mdot
.016 w
.84249 .23216 m
.8426 .23289 L
s
.008 w
.8426 .23289 Mdot
.016 w
.8426 .23289 m
.84269 .23346 L
s
.008 w
.84269 .23346 Mdot
.016 w
.84269 .23346 m
.84276 .23388 L
s
.008 w
.84276 .23388 Mdot
.016 w
.84276 .23388 m
.84279 .23415 L
s
1 .468 0 r
.008 w
.84279 .23415 Mdot
.016 w
.84279 .23415 m
.84278 .23428 L
s
.008 w
.84278 .23428 Mdot
.016 w
.84278 .23428 m
.84274 .23427 L
s
.008 w
.84274 .23427 Mdot
.016 w
.84274 .23427 m
.84266 .23411 L
s
.008 w
.84266 .23411 Mdot
.016 w
.84266 .23411 m
.84257 .2338 L
s
.008 w
.84257 .2338 Mdot
.016 w
.84257 .2338 m
.84247 .23334 L
s
1 .467 0 r
.008 w
.84247 .23334 Mdot
.016 w
.84247 .23334 m
.84237 .23276 L
s
.008 w
.84237 .23276 Mdot
.016 w
.84237 .23276 m
.84226 .23209 L
s
.008 w
.84226 .23209 Mdot
.016 w
.84226 .23209 m
.84211 .2314 L
s
.008 w
.84211 .2314 Mdot
.016 w
.84211 .2314 m
.84194 .23073 L
s
.008 w
.84194 .23073 Mdot
.016 w
.84194 .23073 m
.84174 .23009 L
s
1 .466 0 r
.008 w
.84174 .23009 Mdot
.016 w
.84174 .23009 m
.84148 .22941 L
s
.008 w
.84148 .22941 Mdot
.016 w
.84148 .22941 m
.84116 .22868 L
s
.008 w
.84116 .22868 Mdot
.016 w
.84116 .22868 m
.84076 .22788 L
s
.008 w
.84076 .22788 Mdot
.016 w
.84076 .22788 m
.84032 .22696 L
s
.008 w
.84032 .22696 Mdot
.016 w
.84032 .22696 m
.83987 .226 L
s
1 .465 0 r
.008 w
.83987 .226 Mdot
.016 w
.83987 .226 m
.83936 .22489 L
s
.008 w
.83936 .22489 Mdot
.016 w
.83936 .22489 m
.83878 .22361 L
s
.008 w
.83878 .22361 Mdot
.016 w
.83878 .22361 m
.83826 .2222 L
s
.008 w
.83826 .2222 Mdot
.016 w
.83826 .2222 m
.83768 .22069 L
s
1 .464 0 r
.008 w
.83768 .22069 Mdot
.016 w
.83768 .22069 m
.83704 .21925 L
s
.008 w
.83704 .21925 Mdot
.016 w
.83704 .21925 m
.83642 .21777 L
s
.008 w
.83642 .21777 Mdot
.016 w
.83642 .21777 m
.83575 .21617 L
s
.008 w
.83575 .21617 Mdot
.016 w
.83575 .21617 m
.83512 .21475 L
s
.008 w
.83512 .21475 Mdot
.016 w
.83512 .21475 m
.8345 .2133 L
s
1 .463 0 r
.008 w
.8345 .2133 Mdot
.016 w
.8345 .2133 m
.83395 .21201 L
s
.008 w
.83395 .21201 Mdot
.016 w
.83395 .21201 m
.8335 .21081 L
s
.008 w
.8335 .21081 Mdot
.016 w
.8335 .21081 m
.83312 .20987 L
s
.008 w
.83312 .20987 Mdot
.016 w
.83312 .20987 m
.83281 .20901 L
s
.008 w
.83281 .20901 Mdot
.016 w
.83281 .20901 m
.83256 .20845 L
s
1 .462 0 r
.008 w
.83256 .20845 Mdot
.016 w
.83256 .20845 m
.83238 .208 L
s
.008 w
.83238 .208 Mdot
.016 w
.83238 .208 m
.83224 .20775 L
s
.008 w
.83224 .20775 Mdot
.016 w
.83224 .20775 m
.83212 .20768 L
s
.008 w
.83212 .20768 Mdot
.016 w
.83212 .20768 m
.83201 .20769 L
s
.008 w
.83201 .20769 Mdot
.016 w
.83201 .20769 m
.8319 .20775 L
s
1 .461 0 r
.008 w
.8319 .20775 Mdot
.016 w
.8319 .20775 m
.8318 .20782 L
s
.008 w
.8318 .20782 Mdot
.016 w
.8318 .20782 m
.83172 .2079 L
s
.008 w
.83172 .2079 Mdot
.016 w
.83172 .2079 m
.83165 .20797 L
s
.008 w
.83165 .20797 Mdot
.016 w
.83165 .20797 m
.83158 .20802 L
s
1 .46 0 r
.008 w
.83158 .20802 Mdot
.016 w
.83158 .20802 m
.83152 .20805 L
s
.008 w
.83152 .20805 Mdot
.016 w
.83152 .20805 m
.83147 .20805 L
s
.008 w
.83147 .20805 Mdot
.016 w
.83147 .20805 m
.83144 .20805 L
s
.008 w
.83144 .20805 Mdot
.016 w
.83144 .20805 m
.83144 .20805 L
s
.008 w
.83144 .20805 Mdot
.016 w
.83144 .20805 m
.83146 .20806 L
s
1 .459 0 r
.008 w
.83146 .20806 Mdot
.016 w
.83146 .20806 m
.8315 .20806 L
s
.008 w
.8315 .20806 Mdot
.016 w
.8315 .20806 m
.83158 .20808 L
s
.008 w
.83158 .20808 Mdot
.016 w
.83158 .20808 m
.83169 .20809 L
s
.008 w
.83169 .20809 Mdot
.016 w
.83169 .20809 m
.83184 .20812 L
s
.008 w
.83184 .20812 Mdot
.016 w
.83184 .20812 m
.83199 .20814 L
s
1 .458 0 r
.008 w
.83199 .20814 Mdot
.016 w
.83199 .20814 m
.83213 .20815 L
s
.008 w
.83213 .20815 Mdot
.016 w
.83213 .20815 m
.83222 .20814 L
s
.008 w
.83222 .20814 Mdot
.016 w
.83222 .20814 m
.83226 .20812 L
s
.008 w
.83226 .20812 Mdot
.016 w
.83226 .20812 m
.83225 .20808 L
s
.008 w
.83225 .20808 Mdot
.016 w
.83225 .20808 m
.83219 .20804 L
s
1 .457 0 r
.008 w
.83219 .20804 Mdot
.016 w
.83219 .20804 m
.8321 .208 L
s
.008 w
.8321 .208 Mdot
.016 w
.8321 .208 m
.832 .20796 L
s
.008 w
.832 .20796 Mdot
.016 w
.832 .20796 m
.83192 .20793 L
s
.008 w
.83192 .20793 Mdot
.016 w
.83192 .20793 m
.83184 .20791 L
s
.008 w
.83184 .20791 Mdot
.016 w
.83184 .20791 m
.83179 .20789 L
s
1 .456 0 r
.008 w
.83179 .20789 Mdot
.016 w
.83179 .20789 m
.83175 .20789 L
s
.008 w
.83175 .20789 Mdot
.016 w
.83175 .20789 m
.83173 .20789 L
s
.008 w
.83173 .20789 Mdot
.016 w
.83173 .20789 m
.83175 .20789 L
s
.008 w
.83175 .20789 Mdot
.016 w
.83175 .20789 m
.83181 .2079 L
s
1 .455 0 r
.008 w
.83181 .2079 Mdot
.016 w
.83181 .2079 m
.83192 .20792 L
s
.008 w
.83192 .20792 Mdot
.016 w
.83192 .20792 m
.83208 .20795 L
s
.008 w
.83208 .20795 Mdot
.016 w
.83208 .20795 m
.83228 .20799 L
s
.008 w
.83228 .20799 Mdot
.016 w
.83228 .20799 m
.83252 .20804 L
s
.008 w
.83252 .20804 Mdot
.016 w
.83252 .20804 m
.83278 .20809 L
s
1 .454 0 r
.008 w
.83278 .20809 Mdot
.016 w
.83278 .20809 m
.83304 .20813 L
s
.008 w
.83304 .20813 Mdot
.016 w
.83304 .20813 m
.83328 .20816 L
s
.008 w
.83328 .20816 Mdot
.016 w
.83328 .20816 m
.8335 .20818 L
s
.008 w
.8335 .20818 Mdot
.016 w
.8335 .20818 m
.83369 .20818 L
s
.008 w
.83369 .20818 Mdot
.016 w
.83369 .20818 m
.83385 .20817 L
s
1 .453 0 r
.008 w
.83385 .20817 Mdot
.016 w
.83385 .20817 m
.83398 .20816 L
s
.008 w
.83398 .20816 Mdot
.016 w
.83398 .20816 m
.83409 .20815 L
s
.008 w
.83409 .20815 Mdot
.016 w
.83409 .20815 m
.83418 .20815 L
s
.008 w
.83418 .20815 Mdot
.016 w
.83418 .20815 m
.83423 .20815 L
s
.008 w
.83423 .20815 Mdot
.016 w
.83423 .20815 m
.83424 .20815 L
s
1 .452 0 r
.008 w
.83424 .20815 Mdot
.016 w
.83424 .20815 m
.83423 .20816 L
s
.008 w
.83423 .20816 Mdot
.016 w
.83423 .20816 m
.83421 .20818 L
s
.008 w
.83421 .20818 Mdot
.016 w
.83421 .20818 m
.8342 .20823 L
s
.008 w
.8342 .20823 Mdot
.016 w
.8342 .20823 m
.83421 .20829 L
s
1 .451 0 r
.008 w
.83421 .20829 Mdot
.016 w
.83421 .20829 m
.83423 .20835 L
s
.008 w
.83423 .20835 Mdot
.016 w
.83423 .20835 m
.83424 .20837 L
s
.008 w
.83424 .20837 Mdot
.016 w
.83424 .20837 m
.83423 .20836 L
s
.008 w
.83423 .20836 Mdot
.016 w
.83423 .20836 m
.83419 .20828 L
s
.008 w
.83419 .20828 Mdot
.016 w
.83419 .20828 m
.83411 .20813 L
s
1 .45 0 r
.008 w
.83411 .20813 Mdot
.016 w
.83411 .20813 m
.83398 .20788 L
s
.008 w
.83398 .20788 Mdot
.016 w
.83398 .20788 m
.83383 .20755 L
s
.008 w
.83383 .20755 Mdot
.016 w
.83383 .20755 m
.83364 .20717 L
s
.008 w
.83364 .20717 Mdot
.016 w
.83364 .20717 m
.83344 .20675 L
s
.008 w
.83344 .20675 Mdot
.016 w
.83344 .20675 m
.83322 .20631 L
s
1 .449 0 r
.008 w
.83322 .20631 Mdot
.016 w
.83322 .20631 m
.83301 .20588 L
s
.008 w
.83301 .20588 Mdot
.016 w
.83301 .20588 m
.83279 .20545 L
s
.008 w
.83279 .20545 Mdot
.016 w
.83279 .20545 m
.83258 .20504 L
s
.008 w
.83258 .20504 Mdot
.016 w
.83258 .20504 m
.83238 .20466 L
s
.008 w
.83238 .20466 Mdot
.016 w
.83238 .20466 m
.83221 .20433 L
s
1 .448 0 r
.008 w
.83221 .20433 Mdot
.016 w
.83221 .20433 m
.83205 .20407 L
s
.008 w
.83205 .20407 Mdot
.016 w
.83205 .20407 m
.83193 .20388 L
s
.008 w
.83193 .20388 Mdot
.016 w
.83193 .20388 m
.83184 .20378 L
s
.008 w
.83184 .20378 Mdot
.016 w
.83184 .20378 m
.83182 .20375 L
s
1 .447 0 r
.008 w
.83182 .20375 Mdot
.016 w
.83182 .20375 m
.83184 .20378 L
s
.008 w
.83184 .20378 Mdot
.016 w
.83184 .20378 m
.83192 .20386 L
s
.008 w
.83192 .20386 Mdot
.016 w
.83192 .20386 m
.83203 .20395 L
s
.008 w
.83203 .20395 Mdot
.016 w
.83203 .20395 m
.83217 .20402 L
s
.008 w
.83217 .20402 Mdot
.016 w
.83217 .20402 m
.83234 .20408 L
s
1 .446 0 r
.008 w
.83234 .20408 Mdot
.016 w
.83234 .20408 m
.83255 .20414 L
s
.008 w
.83255 .20414 Mdot
.016 w
.83255 .20414 m
.83281 .20422 L
s
.008 w
.83281 .20422 Mdot
.016 w
.83281 .20422 m
.83308 .20429 L
s
.008 w
.83308 .20429 Mdot
.016 w
.83308 .20429 m
.83332 .20432 L
s
.008 w
.83332 .20432 Mdot
.016 w
.83332 .20432 m
.83352 .2043 L
s
1 .445 0 r
.008 w
.83352 .2043 Mdot
.016 w
.83352 .2043 m
.83367 .20422 L
s
.008 w
.83367 .20422 Mdot
.016 w
.83367 .20422 m
.83373 .20406 L
s
.008 w
.83373 .20406 Mdot
.016 w
.83373 .20406 m
.83367 .20382 L
s
.008 w
.83367 .20382 Mdot
.016 w
.83367 .20382 m
.83349 .20351 L
s
.008 w
.83349 .20351 Mdot
.016 w
.83349 .20351 m
.83321 .20314 L
s
1 .444 0 r
.008 w
.83321 .20314 Mdot
.016 w
.83321 .20314 m
.83287 .20274 L
s
.008 w
.83287 .20274 Mdot
.016 w
.83287 .20274 m
.83248 .20232 L
s
.008 w
.83248 .20232 Mdot
.016 w
.83248 .20232 m
.83205 .20191 L
s
.008 w
.83205 .20191 Mdot
.016 w
.83205 .20191 m
.83164 .20152 L
s
.008 w
.83164 .20152 Mdot
.016 w
.83164 .20152 m
.83126 .20115 L
s
1 .443 0 r
.008 w
.83126 .20115 Mdot
.016 w
.83126 .20115 m
.83084 .20081 L
s
.008 w
.83084 .20081 Mdot
.016 w
.83084 .20081 m
.83048 .20054 L
s
.008 w
.83048 .20054 Mdot
.016 w
.83048 .20054 m
.8302 .20034 L
s
.008 w
.8302 .20034 Mdot
.016 w
.8302 .20034 m
.83 .20021 L
s
1 .442 0 r
.008 w
.83 .20021 Mdot
.016 w
.83 .20021 m
.8299 .20013 L
s
.008 w
.8299 .20013 Mdot
.016 w
.8299 .20013 m
.82985 .20005 L
s
.008 w
.82985 .20005 Mdot
.016 w
.82985 .20005 m
.82985 .19993 L
s
.008 w
.82985 .19993 Mdot
.016 w
.82985 .19993 m
.82987 .19973 L
s
.008 w
.82987 .19973 Mdot
.016 w
.82987 .19973 m
.82988 .19939 L
s
1 .441 0 r
.008 w
.82988 .19939 Mdot
.016 w
.82988 .19939 m
.82983 .19888 L
s
.008 w
.82983 .19888 Mdot
.016 w
.82983 .19888 m
.8297 .19821 L
s
.008 w
.8297 .19821 Mdot
.016 w
.8297 .19821 m
.82947 .19734 L
s
.008 w
.82947 .19734 Mdot
.016 w
.82947 .19734 m
.82914 .19626 L
s
.008 w
.82914 .19626 Mdot
.016 w
.82914 .19626 m
.8287 .19507 L
s
1 .44 0 r
.008 w
.8287 .19507 Mdot
.016 w
.8287 .19507 m
.82813 .19368 L
s
.008 w
.82813 .19368 Mdot
.016 w
.82813 .19368 m
.82741 .19201 L
s
.008 w
.82741 .19201 Mdot
.016 w
.82741 .19201 m
.82653 .19034 L
s
.008 w
.82653 .19034 Mdot
.016 w
.82653 .19034 m
.82555 .18844 L
s
.008 w
.82555 .18844 Mdot
.016 w
.82555 .18844 m
.82438 .18635 L
s
1 .439 0 r
.008 w
.82438 .18635 Mdot
.016 w
.82438 .18635 m
.82309 .18423 L
s
.008 w
.82309 .18423 Mdot
.016 w
.82309 .18423 m
.82171 .18189 L
s
.008 w
.82171 .18189 Mdot
.016 w
.82171 .18189 m
.82014 .17964 L
s
.008 w
.82014 .17964 Mdot
.016 w
.82014 .17964 m
.81856 .17726 L
s
1 .438 0 r
.008 w
.81856 .17726 Mdot
.016 w
.81856 .17726 m
.81688 .17482 L
s
.008 w
.81688 .17482 Mdot
.016 w
.81688 .17482 m
.81522 .17247 L
s
.008 w
.81522 .17247 Mdot
.016 w
.81522 .17247 m
.8136 .17021 L
s
.008 w
.8136 .17021 Mdot
.016 w
.8136 .17021 m
.81205 .16805 L
s
.008 w
.81205 .16805 Mdot
.016 w
.81205 .16805 m
.81061 .166 L
s
1 .437 0 r
.008 w
.81061 .166 Mdot
.016 w
.81061 .166 m
.80937 .16426 L
s
.008 w
.80937 .16426 Mdot
.016 w
.80937 .16426 m
.80821 .16261 L
s
.008 w
.80821 .16261 Mdot
.016 w
.80821 .16261 m
.80733 .16143 L
s
.008 w
.80733 .16143 Mdot
.016 w
.80733 .16143 m
.80658 .16042 L
s
.008 w
.80658 .16042 Mdot
.016 w
.80658 .16042 m
.80598 .15962 L
s
1 .436 0 r
.008 w
.80598 .15962 Mdot
.016 w
.80598 .15962 m
.80553 .15905 L
s
.008 w
.80553 .15905 Mdot
.016 w
.80553 .15905 m
.80523 .1587 L
s
.008 w
.80523 .1587 Mdot
.016 w
.80523 .1587 m
.80506 .15852 L
s
.008 w
.80506 .15852 Mdot
.016 w
.80506 .15852 m
.805 .15847 L
s
.008 w
.805 .15847 Mdot
.016 w
.805 .15847 m
.80502 .1585 L
s
1 .435 0 r
.008 w
.80502 .1585 Mdot
.016 w
.80502 .1585 m
.8051 .1586 L
s
.008 w
.8051 .1586 Mdot
.016 w
.8051 .1586 m
.8052 .15872 L
s
.008 w
.8052 .15872 Mdot
.016 w
.8052 .15872 m
.8053 .15886 L
s
.008 w
.8053 .15886 Mdot
.016 w
.8053 .15886 m
.80539 .15897 L
s
.008 w
.80539 .15897 Mdot
.016 w
.80539 .15897 m
.80544 .15903 L
s
1 .434 0 r
.008 w
.80544 .15903 Mdot
.016 w
.80544 .15903 m
.80548 .15907 L
s
.008 w
.80548 .15907 Mdot
.016 w
.80548 .15907 m
.80552 .1591 L
s
.008 w
.80552 .1591 Mdot
.016 w
.80552 .1591 m
.8056 .15915 L
s
.008 w
.8056 .15915 Mdot
.016 w
.8056 .15915 m
.80573 .15923 L
s
1 .433 0 r
.008 w
.80573 .15923 Mdot
.016 w
.80573 .15923 m
.80584 .15934 L
s
.008 w
.80584 .15934 Mdot
.016 w
.80584 .15934 m
.8059 .15942 L
s
.008 w
.8059 .15942 Mdot
.016 w
.8059 .15942 m
.80588 .15945 L
s
.008 w
.80588 .15945 Mdot
.016 w
.80588 .15945 m
.80575 .15938 L
s
.008 w
.80575 .15938 Mdot
.016 w
.80575 .15938 m
.80545 .15917 L
s
1 .432 0 r
.008 w
.80545 .15917 Mdot
.016 w
.80545 .15917 m
.80492 .15877 L
s
.008 w
.80492 .15877 Mdot
.016 w
.80492 .15877 m
.80414 .15813 L
s
.008 w
.80414 .15813 Mdot
.016 w
.80414 .15813 m
.80311 .15717 L
s
.008 w
.80311 .15717 Mdot
.016 w
.80311 .15717 m
.8018 .15588 L
s
.008 w
.8018 .15588 Mdot
.016 w
.8018 .15588 m
.80015 .15423 L
s
1 .431 0 r
.008 w
.80015 .15423 Mdot
.016 w
.80015 .15423 m
.79828 .15228 L
s
.008 w
.79828 .15228 Mdot
.016 w
.79828 .15228 m
.7966 .1505 L
s
.008 w
.7966 .1505 Mdot
.016 w
.7966 .1505 m
.79452 .14827 L
s
.008 w
.79452 .14827 Mdot
.016 w
.79452 .14827 m
.79236 .14608 L
s
.008 w
.79236 .14608 Mdot
.016 w
.79236 .14608 m
.79012 .14356 L
s
1 .43 0 r
.008 w
.79012 .14356 Mdot
.016 w
.79012 .14356 m
.78751 .14084 L
s
.008 w
.78751 .14084 Mdot
.016 w
.78751 .14084 m
.78551 .13843 L
s
.008 w
.78551 .13843 Mdot
.016 w
.78551 .13843 m
.78354 .13616 L
s
.008 w
.78354 .13616 Mdot
.016 w
.78354 .13616 m
.78149 .13368 L
s
1 .429 0 r
.008 w
.78149 .13368 Mdot
.016 w
.78149 .13368 m
.77975 .13155 L
s
.008 w
.77975 .13155 Mdot
.016 w
.77975 .13155 m
.7783 .12988 L
s
.008 w
.7783 .12988 Mdot
.016 w
.7783 .12988 m
.77701 .12833 L
s
.008 w
.77701 .12833 Mdot
.016 w
.77701 .12833 m
.77594 .12698 L
s
.008 w
.77594 .12698 Mdot
.016 w
.77594 .12698 m
.77512 .12594 L
s
1 .428 0 r
.008 w
.77512 .12594 Mdot
.016 w
.77512 .12594 m
.77448 .12518 L
s
.008 w
.77448 .12518 Mdot
.016 w
.77448 .12518 m
.77395 .12453 L
s
.008 w
.77395 .12453 Mdot
.016 w
.77395 .12453 m
.77354 .1241 L
s
.008 w
.77354 .1241 Mdot
.016 w
.77354 .1241 m
.77318 .12372 L
s
.008 w
.77318 .12372 Mdot
.016 w
.77318 .12372 m
.77282 .12344 L
s
1 .427 0 r
.008 w
.77282 .12344 Mdot
.016 w
.77282 .12344 m
.77245 .12322 L
s
.008 w
.77245 .12322 Mdot
.016 w
.77245 .12322 m
.77202 .12305 L
s
.008 w
.77202 .12305 Mdot
.016 w
.77202 .12305 m
.77149 .12288 L
s
.008 w
.77149 .12288 Mdot
.016 w
.77149 .12288 m
.77083 .1227 L
s
.008 w
.77083 .1227 Mdot
.016 w
.77083 .1227 m
.77004 .12251 L
s
1 .426 0 r
.008 w
.77004 .12251 Mdot
.016 w
.77004 .12251 m
.76931 .12234 L
s
.008 w
.76931 .12234 Mdot
.016 w
.76931 .12234 m
.76847 .12217 L
s
.008 w
.76847 .12217 Mdot
.016 w
.76847 .12217 m
.7676 .12199 L
s
.008 w
.7676 .12199 Mdot
.016 w
.7676 .12199 m
.76677 .1218 L
s
1 .425 0 r
.008 w
.76677 .1218 Mdot
.016 w
.76677 .1218 m
.76608 .12164 L
s
.008 w
.76608 .12164 Mdot
.016 w
.76608 .12164 m
.76554 .12152 L
s
.008 w
.76554 .12152 Mdot
.016 w
.76554 .12152 m
.76513 .12141 L
s
.008 w
.76513 .12141 Mdot
.016 w
.76513 .12141 m
.76484 .12136 L
s
.008 w
.76484 .12136 Mdot
.016 w
.76484 .12136 m
.76472 .12127 L
s
1 .424 0 r
.008 w
.76472 .12127 Mdot
.016 w
.76472 .12127 m
.76471 .12128 L
s
.008 w
.76471 .12128 Mdot
.016 w
.76471 .12128 m
.76483 .12131 L
s
.008 w
.76483 .12131 Mdot
.016 w
.76483 .12131 m
.76511 .12134 L
s
.008 w
.76511 .12134 Mdot
.016 w
.76511 .12134 m
.76544 .12136 L
s
.008 w
.76544 .12136 Mdot
.016 w
.76544 .12136 m
.7658 .12137 L
s
1 .423 0 r
.008 w
.7658 .12137 Mdot
.016 w
.7658 .12137 m
.76619 .12137 L
s
.008 w
.76619 .12137 Mdot
.016 w
.76619 .12137 m
.76656 .12137 L
s
.008 w
.76656 .12137 Mdot
.016 w
.76656 .12137 m
.76684 .12138 L
s
.008 w
.76684 .12138 Mdot
.016 w
.76684 .12138 m
.767 .12138 L
s
.008 w
.767 .12138 Mdot
.016 w
.767 .12138 m
.76707 .12139 L
s
1 .422 0 r
.008 w
.76707 .12139 Mdot
.016 w
.76707 .12139 m
.76708 .12139 L
s
.008 w
.76708 .12139 Mdot
.016 w
.76708 .12139 m
.76706 .1214 L
s
.008 w
.76706 .1214 Mdot
.016 w
.76706 .1214 m
.767 .1214 L
s
.008 w
.767 .1214 Mdot
.016 w
.767 .1214 m
.76695 .12139 L
s
.008 w
.76695 .12139 Mdot
.016 w
.76695 .12139 m
.76691 .12139 L
s
1 .421 0 r
.008 w
.76691 .12139 Mdot
.016 w
.76691 .12139 m
.7669 .12139 L
s
.008 w
.7669 .12139 Mdot
.016 w
.7669 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76688 .12139 L
s
1 .42 0 r
.008 w
.76688 .12139 Mdot
.016 w
.76688 .12139 m
.76687 .12139 L
s
.008 w
.76687 .12139 Mdot
.016 w
.76687 .12139 m
.76687 .12139 L
s
.008 w
.76687 .12139 Mdot
.016 w
.76687 .12139 m
.76687 .12139 L
s
.008 w
.76687 .12139 Mdot
.016 w
.76687 .12139 m
.76689 .12138 L
s
.008 w
.76689 .12138 Mdot
.016 w
.76689 .12138 m
.76692 .12138 L
s
1 .419 0 r
.008 w
.76692 .12138 Mdot
.016 w
.76692 .12138 m
.76695 .12138 L
s
.008 w
.76695 .12138 Mdot
.016 w
.76695 .12138 m
.76698 .12139 L
s
.008 w
.76698 .12139 Mdot
.016 w
.76698 .12139 m
.767 .12139 L
s
.008 w
.767 .12139 Mdot
.016 w
.767 .12139 m
.76702 .1214 L
s
.008 w
.76702 .1214 Mdot
.016 w
.76702 .1214 m
.76702 .12142 L
s
1 .418 0 r
.008 w
.76702 .12142 Mdot
.016 w
.76702 .12142 m
.76702 .12143 L
s
.008 w
.76702 .12143 Mdot
.016 w
.76702 .12143 m
.76702 .12144 L
s
.008 w
.76702 .12144 Mdot
.016 w
.76702 .12144 m
.767 .12145 L
s
.008 w
.767 .12145 Mdot
.016 w
.767 .12145 m
.767 .12146 L
s
.008 w
.767 .12146 Mdot
.016 w
.767 .12146 m
.76699 .12146 L
s
1 .417 0 r
.008 w
.76699 .12146 Mdot
.016 w
.76699 .12146 m
.76696 .12146 L
s
.008 w
.76696 .12146 Mdot
.016 w
.76696 .12146 m
.76695 .12146 L
s
.008 w
.76695 .12146 Mdot
.016 w
.76695 .12146 m
.76692 .12146 L
s
.008 w
.76692 .12146 Mdot
.016 w
.76692 .12146 m
.76689 .12145 L
s
1 .416 0 r
.008 w
.76689 .12145 Mdot
.016 w
.76689 .12145 m
.76687 .12145 L
s
.008 w
.76687 .12145 Mdot
.016 w
.76687 .12145 m
.76685 .12144 L
s
.008 w
.76685 .12144 Mdot
.016 w
.76685 .12144 m
.76684 .12142 L
s
.008 w
.76684 .12142 Mdot
.016 w
.76684 .12142 m
.76684 .12141 L
s
.008 w
.76684 .12141 Mdot
.016 w
.76684 .12141 m
.76685 .1214 L
s
1 .415 0 r
.008 w
.76685 .1214 Mdot
.016 w
.76685 .1214 m
.76687 .12139 L
s
.008 w
.76687 .12139 Mdot
.016 w
.76687 .12139 m
.76689 .12138 L
s
.008 w
.76689 .12138 Mdot
.016 w
.76689 .12138 m
.7669 .12138 L
s
.008 w
.7669 .12138 Mdot
.016 w
.7669 .12138 m
.7669 .12138 L
s
.008 w
.7669 .12138 Mdot
.016 w
.7669 .12138 m
.76691 .12139 L
s
1 .414 0 r
.008 w
.76691 .12139 Mdot
.016 w
.76691 .12139 m
.7669 .12139 L
s
.008 w
.7669 .12139 Mdot
.016 w
.7669 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .413 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .412 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .411 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .41 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .409 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .408 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .407 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .406 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .405 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .404 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .403 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .402 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .401 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .4 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .399 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .398 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .397 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .396 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76688 .12139 L
s
.008 w
.76688 .12139 Mdot
.016 w
.76688 .12139 m
.76686 .12139 L
s
.008 w
.76686 .12139 Mdot
.016 w
.76686 .12139 m
.76684 .12139 L
s
1 .395 0 r
.008 w
.76684 .12139 Mdot
.016 w
.76684 .12139 m
.76681 .12139 L
s
.008 w
.76681 .12139 Mdot
.016 w
.76681 .12139 m
.76681 .12139 L
s
.008 w
.76681 .12139 Mdot
.016 w
.76681 .12139 m
.76684 .12139 L
s
.008 w
.76684 .12139 Mdot
.016 w
.76684 .12139 m
.76691 .1214 L
s
1 .394 0 r
.008 w
.76691 .1214 Mdot
.016 w
.76691 .1214 m
.76699 .1214 L
s
.008 w
.76699 .1214 Mdot
.016 w
.76699 .1214 m
.76708 .1214 L
s
.008 w
.76708 .1214 Mdot
.016 w
.76708 .1214 m
.76718 .1214 L
s
.008 w
.76718 .1214 Mdot
.016 w
.76718 .1214 m
.76726 .1214 L
s
.008 w
.76726 .1214 Mdot
.016 w
.76726 .1214 m
.76732 .1214 L
s
1 .393 0 r
.008 w
.76732 .1214 Mdot
.016 w
.76732 .1214 m
.76735 .1214 L
s
.008 w
.76735 .1214 Mdot
.016 w
.76735 .1214 m
.76734 .1214 L
s
.008 w
.76734 .1214 Mdot
.016 w
.76734 .1214 m
.76731 .1214 L
s
.008 w
.76731 .1214 Mdot
.016 w
.76731 .1214 m
.76727 .1214 L
s
.008 w
.76727 .1214 Mdot
.016 w
.76727 .1214 m
.76724 .12139 L
s
1 .392 0 r
.008 w
.76724 .12139 Mdot
.016 w
.76724 .12139 m
.76724 .12139 L
s
.008 w
.76724 .12139 Mdot
.016 w
.76724 .12139 m
.76723 .12139 L
s
.008 w
.76723 .12139 Mdot
.016 w
.76723 .12139 m
.76723 .12139 L
s
.008 w
.76723 .12139 Mdot
.016 w
.76723 .12139 m
.76725 .12139 L
s
.008 w
.76725 .12139 Mdot
.016 w
.76725 .12139 m
.7673 .1214 L
s
1 .391 0 r
.008 w
.7673 .1214 Mdot
.016 w
.7673 .1214 m
.76739 .1214 L
s
.008 w
.76739 .1214 Mdot
.016 w
.76739 .1214 m
.76752 .12141 L
s
.008 w
.76752 .12141 Mdot
.016 w
.76752 .12141 m
.76769 .12142 L
s
.008 w
.76769 .12142 Mdot
.016 w
.76769 .12142 m
.76788 .12143 L
s
1 .39 0 r
.008 w
.76788 .12143 Mdot
.016 w
.76788 .12143 m
.7681 .12143 L
s
.008 w
.7681 .12143 Mdot
.016 w
.7681 .12143 m
.76833 .12144 L
s
.008 w
.76833 .12144 Mdot
.016 w
.76833 .12144 m
.76855 .12145 L
s
.008 w
.76855 .12145 Mdot
.016 w
.76855 .12145 m
.76872 .12145 L
s
.008 w
.76872 .12145 Mdot
.016 w
.76872 .12145 m
.76884 .12146 L
s
1 .389 0 r
.008 w
.76884 .12146 Mdot
.016 w
.76884 .12146 m
.76893 .12146 L
s
.008 w
.76893 .12146 Mdot
.016 w
.76893 .12146 m
.76898 .12146 L
s
.008 w
.76898 .12146 Mdot
.016 w
.76898 .12146 m
.769 .12146 L
s
.008 w
.769 .12146 Mdot
.016 w
.769 .12146 m
.76899 .12146 L
s
.008 w
.76899 .12146 Mdot
.016 w
.76899 .12146 m
.76896 .12146 L
s
1 .388 0 r
.008 w
.76896 .12146 Mdot
.016 w
.76896 .12146 m
.76892 .12146 L
s
.008 w
.76892 .12146 Mdot
.016 w
.76892 .12146 m
.7689 .12146 L
s
.008 w
.7689 .12146 Mdot
.016 w
.7689 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .387 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .386 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .385 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .384 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .383 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .382 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .381 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .38 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .379 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .378 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .377 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .376 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .375 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .374 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .373 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .372 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .371 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .37 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .369 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .368 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .367 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
1 .366 0 r
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12146 L
s
.008 w
.76888 .12146 Mdot
.016 w
.76888 .12146 m
.76888 .12145 L
s
.008 w
.76888 .12145 Mdot
.016 w
.76888 .12145 m
.76888 .12144 L
s
1 .365 0 r
.008 w
.76888 .12144 Mdot
.016 w
.76888 .12144 m
.7689 .12142 L
s
.008 w
.7689 .12142 Mdot
.016 w
.7689 .12142 m
.76895 .12141 L
s
.008 w
.76895 .12141 Mdot
.016 w
.76895 .12141 m
.76899 .12141 L
s
.008 w
.76899 .12141 Mdot
.016 w
.76899 .12141 m
.76901 .12142 L
s
1 .364 0 r
.008 w
.76901 .12142 Mdot
.016 w
.76901 .12142 m
.76899 .12144 L
s
.008 w
.76899 .12144 Mdot
.016 w
.76899 .12144 m
.76894 .12149 L
s
.008 w
.76894 .12149 Mdot
.016 w
.76894 .12149 m
.76883 .12156 L
s
.008 w
.76883 .12156 Mdot
.016 w
.76883 .12156 m
.76868 .12165 L
s
.008 w
.76868 .12165 Mdot
.016 w
.76868 .12165 m
.76849 .12174 L
s
1 .363 0 r
.008 w
.76849 .12174 Mdot
.016 w
.76849 .12174 m
.76828 .12183 L
s
.008 w
.76828 .12183 Mdot
.016 w
.76828 .12183 m
.76803 .1219 L
s
.008 w
.76803 .1219 Mdot
.016 w
.76803 .1219 m
.76785 .12196 L
s
.008 w
.76785 .12196 Mdot
.016 w
.76785 .12196 m
.76764 .122 L
s
.008 w
.76764 .122 Mdot
.016 w
.76764 .122 m
.76745 .12202 L
s
1 .362 0 r
.008 w
.76745 .12202 Mdot
.016 w
.76745 .12202 m
.76725 .12202 L
s
.008 w
.76725 .12202 Mdot
.016 w
.76725 .12202 m
.76706 .12199 L
s
.008 w
.76706 .12199 Mdot
.016 w
.76706 .12199 m
.7669 .12195 L
s
.008 w
.7669 .12195 Mdot
.016 w
.7669 .12195 m
.76679 .1219 L
s
.008 w
.76679 .1219 Mdot
.016 w
.76679 .1219 m
.76672 .12182 L
s
1 .361 0 r
.008 w
.76672 .12182 Mdot
.016 w
.76672 .12182 m
.76671 .12173 L
s
.008 w
.76671 .12173 Mdot
.016 w
.76671 .12173 m
.76672 .12163 L
s
.008 w
.76672 .12163 Mdot
.016 w
.76672 .12163 m
.76677 .12153 L
s
.008 w
.76677 .12153 Mdot
.016 w
.76677 .12153 m
.76683 .12145 L
s
.008 w
.76683 .12145 Mdot
.016 w
.76683 .12145 m
.76688 .12139 L
s
1 .36 0 r
.008 w
.76688 .12139 Mdot
.016 w
.76688 .12139 m
.76692 .12135 L
s
.008 w
.76692 .12135 Mdot
.016 w
.76692 .12135 m
.76693 .12134 L
s
.008 w
.76693 .12134 Mdot
.016 w
.76693 .12134 m
.76692 .12134 L
s
.008 w
.76692 .12134 Mdot
.016 w
.76692 .12134 m
.7669 .12134 L
s
1 .359 0 r
.008 w
.7669 .12134 Mdot
.016 w
.7669 .12134 m
.76689 .12136 L
s
.008 w
.76689 .12136 Mdot
.016 w
.76689 .12136 m
.76689 .12138 L
s
.008 w
.76689 .12138 Mdot
.016 w
.76689 .12138 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .358 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76688 .12138 L
s
.008 w
.76688 .12138 Mdot
.016 w
.76688 .12138 m
.76686 .12136 L
s
.008 w
.76686 .12136 Mdot
.016 w
.76686 .12136 m
.76684 .12133 L
s
.008 w
.76684 .12133 Mdot
.016 w
.76684 .12133 m
.76682 .1213 L
s
1 .357 0 r
.008 w
.76682 .1213 Mdot
.016 w
.76682 .1213 m
.76683 .1213 L
s
.008 w
.76683 .1213 Mdot
.016 w
.76683 .1213 m
.76687 .12131 L
s
.008 w
.76687 .12131 Mdot
.016 w
.76687 .12131 m
.76693 .12135 L
s
.008 w
.76693 .12135 Mdot
.016 w
.76693 .12135 m
.767 .12142 L
s
.008 w
.767 .12142 Mdot
.016 w
.767 .12142 m
.76708 .12152 L
s
1 .356 0 r
.008 w
.76708 .12152 Mdot
.016 w
.76708 .12152 m
.76714 .12165 L
s
.008 w
.76714 .12165 Mdot
.016 w
.76714 .12165 m
.76718 .12181 L
s
.008 w
.76718 .12181 Mdot
.016 w
.76718 .12181 m
.76722 .12198 L
s
.008 w
.76722 .12198 Mdot
.016 w
.76722 .12198 m
.76725 .12217 L
s
1 .355 0 r
.008 w
.76725 .12217 Mdot
.016 w
.76725 .12217 m
.76728 .12234 L
s
.008 w
.76728 .12234 Mdot
.016 w
.76728 .12234 m
.7673 .12249 L
s
.008 w
.7673 .12249 Mdot
.016 w
.7673 .12249 m
.76734 .12263 L
s
.008 w
.76734 .12263 Mdot
.016 w
.76734 .12263 m
.7674 .12276 L
s
.008 w
.7674 .12276 Mdot
.016 w
.7674 .12276 m
.76747 .12287 L
s
1 .354 0 r
.008 w
.76747 .12287 Mdot
.016 w
.76747 .12287 m
.76754 .12295 L
s
.008 w
.76754 .12295 Mdot
.016 w
.76754 .12295 m
.76761 .12303 L
s
.008 w
.76761 .12303 Mdot
.016 w
.76761 .12303 m
.76768 .12309 L
s
.008 w
.76768 .12309 Mdot
.016 w
.76768 .12309 m
.76772 .12314 L
s
.008 w
.76772 .12314 Mdot
.016 w
.76772 .12314 m
.76774 .12317 L
s
1 .353 0 r
.008 w
.76774 .12317 Mdot
.016 w
.76774 .12317 m
.76774 .1232 L
s
.008 w
.76774 .1232 Mdot
.016 w
.76774 .1232 m
.76771 .1232 L
s
.008 w
.76771 .1232 Mdot
.016 w
.76771 .1232 m
.76767 .12318 L
s
.008 w
.76767 .12318 Mdot
.016 w
.76767 .12318 m
.76762 .12317 L
s
.008 w
.76762 .12317 Mdot
.016 w
.76762 .12317 m
.76754 .12314 L
s
1 .352 0 r
.008 w
.76754 .12314 Mdot
.016 w
.76754 .12314 m
.76742 .12308 L
s
.008 w
.76742 .12308 Mdot
.016 w
.76742 .12308 m
.76726 .12299 L
s
.008 w
.76726 .12299 Mdot
.016 w
.76726 .12299 m
.7671 .12286 L
s
.008 w
.7671 .12286 Mdot
.016 w
.7671 .12286 m
.76694 .12271 L
s
1 .351 0 r
.008 w
.76694 .12271 Mdot
.016 w
.76694 .12271 m
.7668 .12255 L
s
.008 w
.7668 .12255 Mdot
.016 w
.7668 .12255 m
.7667 .12236 L
s
.008 w
.7667 .12236 Mdot
.016 w
.7667 .12236 m
.76662 .12216 L
s
.008 w
.76662 .12216 Mdot
.016 w
.76662 .12216 m
.76659 .12197 L
s
.008 w
.76659 .12197 Mdot
.016 w
.76659 .12197 m
.76658 .12177 L
s
1 .35 0 r
.008 w
.76658 .12177 Mdot
.016 w
.76658 .12177 m
.7666 .1216 L
s
.008 w
.7666 .1216 Mdot
.016 w
.7666 .1216 m
.76667 .12148 L
s
.008 w
.76667 .12148 Mdot
.016 w
.76667 .12148 m
.76676 .12139 L
s
.008 w
.76676 .12139 Mdot
.016 w
.76676 .12139 m
.76683 .12135 L
s
.008 w
.76683 .12135 Mdot
.016 w
.76683 .12135 m
.7669 .12133 L
s
1 .349 0 r
.008 w
.7669 .12133 Mdot
.016 w
.7669 .12133 m
.76696 .12133 L
s
.008 w
.76696 .12133 Mdot
.016 w
.76696 .12133 m
.767 .12134 L
s
.008 w
.767 .12134 Mdot
.016 w
.767 .12134 m
.76702 .12135 L
s
.008 w
.76702 .12135 Mdot
.016 w
.76702 .12135 m
.76701 .12135 L
s
.008 w
.76701 .12135 Mdot
.016 w
.76701 .12135 m
.76698 .12135 L
s
1 .348 0 r
.008 w
.76698 .12135 Mdot
.016 w
.76698 .12135 m
.76692 .12135 L
s
.008 w
.76692 .12135 Mdot
.016 w
.76692 .12135 m
.76683 .12135 L
s
.008 w
.76683 .12135 Mdot
.016 w
.76683 .12135 m
.76672 .12134 L
s
.008 w
.76672 .12134 Mdot
.016 w
.76672 .12134 m
.7666 .12135 L
s
.008 w
.7666 .12135 Mdot
.016 w
.7666 .12135 m
.76647 .12138 L
s
1 .347 0 r
.008 w
.76647 .12138 Mdot
.016 w
.76647 .12138 m
.76634 .12143 L
s
.008 w
.76634 .12143 Mdot
.016 w
.76634 .12143 m
.76618 .12148 L
s
.008 w
.76618 .12148 Mdot
.016 w
.76618 .12148 m
.76603 .12154 L
s
.008 w
.76603 .12154 Mdot
.016 w
.76603 .12154 m
.7659 .12161 L
s
1 .346 0 r
.008 w
.7659 .12161 Mdot
.016 w
.7659 .12161 m
.76578 .12169 L
s
.008 w
.76578 .12169 Mdot
.016 w
.76578 .12169 m
.76568 .12178 L
s
.008 w
.76568 .12178 Mdot
.016 w
.76568 .12178 m
.76562 .12186 L
s
.008 w
.76562 .12186 Mdot
.016 w
.76562 .12186 m
.7656 .12194 L
s
.008 w
.7656 .12194 Mdot
.016 w
.7656 .12194 m
.76564 .122 L
s
1 .345 0 r
.008 w
.76564 .122 Mdot
.016 w
.76564 .122 m
.76571 .12204 L
s
.008 w
.76571 .12204 Mdot
.016 w
.76571 .12204 m
.76583 .12206 L
s
.008 w
.76583 .12206 Mdot
.016 w
.76583 .12206 m
.76596 .12205 L
s
.008 w
.76596 .12205 Mdot
.016 w
.76596 .12205 m
.76611 .12202 L
s
.008 w
.76611 .12202 Mdot
.016 w
.76611 .12202 m
.76626 .12195 L
s
1 .344 0 r
.008 w
.76626 .12195 Mdot
.016 w
.76626 .12195 m
.76639 .12188 L
s
.008 w
.76639 .12188 Mdot
.016 w
.76639 .12188 m
.76651 .1218 L
s
.008 w
.76651 .1218 Mdot
.016 w
.76651 .1218 m
.7666 .12172 L
s
.008 w
.7666 .12172 Mdot
.016 w
.7666 .12172 m
.76669 .12163 L
s
.008 w
.76669 .12163 Mdot
.016 w
.76669 .12163 m
.76678 .12155 L
s
1 .343 0 r
.008 w
.76678 .12155 Mdot
.016 w
.76678 .12155 m
.76685 .12149 L
s
.008 w
.76685 .12149 Mdot
.016 w
.76685 .12149 m
.7669 .12144 L
s
.008 w
.7669 .12144 Mdot
.016 w
.7669 .12144 m
.76693 .1214 L
s
.008 w
.76693 .1214 Mdot
.016 w
.76693 .1214 m
.76694 .12137 L
s
1 .342 0 r
.008 w
.76694 .12137 Mdot
.016 w
.76694 .12137 m
.76694 .12135 L
s
.008 w
.76694 .12135 Mdot
.016 w
.76694 .12135 m
.76692 .12134 L
s
.008 w
.76692 .12134 Mdot
.016 w
.76692 .12134 m
.76692 .12135 L
s
.008 w
.76692 .12135 Mdot
.016 w
.76692 .12135 m
.76697 .12137 L
s
.008 w
.76697 .12137 Mdot
.016 w
.76697 .12137 m
.76703 .12139 L
s
1 .341 0 r
.008 w
.76703 .12139 Mdot
.016 w
.76703 .12139 m
.76709 .12139 L
s
.008 w
.76709 .12139 Mdot
.016 w
.76709 .12139 m
.76711 .12138 L
s
.008 w
.76711 .12138 Mdot
.016 w
.76711 .12138 m
.7671 .12136 L
s
.008 w
.7671 .12136 Mdot
.016 w
.7671 .12136 m
.76704 .12136 L
s
.008 w
.76704 .12136 Mdot
.016 w
.76704 .12136 m
.76691 .12137 L
s
1 .34 0 r
.008 w
.76691 .12137 Mdot
.016 w
.76691 .12137 m
.7667 .12138 L
s
.008 w
.7667 .12138 Mdot
.016 w
.7667 .12138 m
.76641 .12141 L
s
.008 w
.76641 .12141 Mdot
.016 w
.76641 .12141 m
.76604 .12143 L
s
.008 w
.76604 .12143 Mdot
.016 w
.76604 .12143 m
.76558 .12146 L
s
.008 w
.76558 .12146 Mdot
.016 w
.76558 .12146 m
.76506 .12147 L
s
1 .339 0 r
.008 w
.76506 .12147 Mdot
.016 w
.76506 .12147 m
.7645 .12148 L
s
.008 w
.7645 .12148 Mdot
.016 w
.7645 .12148 m
.76393 .12148 L
s
.008 w
.76393 .12148 Mdot
.016 w
.76393 .12148 m
.76334 .12148 L
s
.008 w
.76334 .12148 Mdot
.016 w
.76334 .12148 m
.76276 .12146 L
s
.008 w
.76276 .12146 Mdot
.016 w
.76276 .12146 m
.76225 .12144 L
s
1 .338 0 r
.008 w
.76225 .12144 Mdot
.016 w
.76225 .12144 m
.76184 .12144 L
s
.008 w
.76184 .12144 Mdot
.016 w
.76184 .12144 m
.76157 .12145 L
s
.008 w
.76157 .12145 Mdot
.016 w
.76157 .12145 m
.76145 .12148 L
s
.008 w
.76145 .12148 Mdot
.016 w
.76145 .12148 m
.76145 .12153 L
s
1 .337 0 r
.008 w
.76145 .12153 Mdot
.016 w
.76145 .12153 m
.76157 .12158 L
s
.008 w
.76157 .12158 Mdot
.016 w
.76157 .12158 m
.7618 .12164 L
s
.008 w
.7618 .12164 Mdot
.016 w
.7618 .12164 m
.7621 .1217 L
s
.008 w
.7621 .1217 Mdot
.016 w
.7621 .1217 m
.76245 .12174 L
s
.008 w
.76245 .12174 Mdot
.016 w
.76245 .12174 m
.76282 .12177 L
s
1 .336 0 r
.008 w
.76282 .12177 Mdot
.016 w
.76282 .12177 m
.7632 .12179 L
s
.008 w
.7632 .12179 Mdot
.016 w
.7632 .12179 m
.76356 .12178 L
s
.008 w
.76356 .12178 Mdot
.016 w
.76356 .12178 m
.76388 .12176 L
s
.008 w
.76388 .12176 Mdot
.016 w
.76388 .12176 m
.76417 .12172 L
s
.008 w
.76417 .12172 Mdot
.016 w
.76417 .12172 m
.76443 .12168 L
s
1 .335 0 r
.008 w
.76443 .12168 Mdot
.016 w
.76443 .12168 m
.76464 .12163 L
s
.008 w
.76464 .12163 Mdot
.016 w
.76464 .12163 m
.76483 .1216 L
s
.008 w
.76483 .1216 Mdot
.016 w
.76483 .1216 m
.76499 .12159 L
s
.008 w
.76499 .12159 Mdot
.016 w
.76499 .12159 m
.76512 .12163 L
s
.008 w
.76512 .12163 Mdot
.016 w
.76512 .12163 m
.76523 .12173 L
s
1 .334 0 r
.008 w
.76523 .12173 Mdot
.016 w
.76523 .12173 m
.76531 .12186 L
s
.008 w
.76531 .12186 Mdot
.016 w
.76531 .12186 m
.76537 .12202 L
s
.008 w
.76537 .12202 Mdot
.016 w
.76537 .12202 m
.76541 .12219 L
s
.008 w
.76541 .12219 Mdot
.016 w
.76541 .12219 m
.76545 .12238 L
s
1 .333 0 r
.008 w
.76545 .12238 Mdot
.016 w
.76545 .12238 m
.76549 .12258 L
s
.008 w
.76549 .12258 Mdot
.016 w
.76549 .12258 m
.76554 .12277 L
s
.008 w
.76554 .12277 Mdot
.016 w
.76554 .12277 m
.76558 .12292 L
s
.008 w
.76558 .12292 Mdot
.016 w
.76558 .12292 m
.76559 .12301 L
s
.008 w
.76559 .12301 Mdot
.016 w
.76559 .12301 m
.76558 .12303 L
s
1 .332 0 r
.008 w
.76558 .12303 Mdot
.016 w
.76558 .12303 m
.76556 .123 L
s
.008 w
.76556 .123 Mdot
.016 w
.76556 .123 m
.76552 .1229 L
s
.008 w
.76552 .1229 Mdot
.016 w
.76552 .1229 m
.76547 .12277 L
s
.008 w
.76547 .12277 Mdot
.016 w
.76547 .12277 m
.76542 .12261 L
s
.008 w
.76542 .12261 Mdot
.016 w
.76542 .12261 m
.76538 .12242 L
s
1 .331 0 r
.008 w
.76538 .12242 Mdot
.016 w
.76538 .12242 m
.76535 .12224 L
s
.008 w
.76535 .12224 Mdot
.016 w
.76535 .12224 m
.76534 .12209 L
s
.008 w
.76534 .12209 Mdot
.016 w
.76534 .12209 m
.76534 .12196 L
s
.008 w
.76534 .12196 Mdot
.016 w
.76534 .12196 m
.76534 .12186 L
s
.008 w
.76534 .12186 Mdot
.016 w
.76534 .12186 m
.76532 .12178 L
s
1 .33 0 r
.008 w
.76532 .12178 Mdot
.016 w
.76532 .12178 m
.76527 .1217 L
s
.008 w
.76527 .1217 Mdot
.016 w
.76527 .1217 m
.76518 .12162 L
s
.008 w
.76518 .12162 Mdot
.016 w
.76518 .12162 m
.76511 .12157 L
s
.008 w
.76511 .12157 Mdot
.016 w
.76511 .12157 m
.76504 .1215 L
s
1 .329 0 r
.008 w
.76504 .1215 Mdot
.016 w
.76504 .1215 m
.76499 .12145 L
s
.008 w
.76499 .12145 Mdot
.016 w
.76499 .12145 m
.76496 .1214 L
s
.008 w
.76496 .1214 Mdot
.016 w
.76496 .1214 m
.76494 .12137 L
s
.008 w
.76494 .12137 Mdot
.016 w
.76494 .12137 m
.76493 .12135 L
s
.008 w
.76493 .12135 Mdot
.016 w
.76493 .12135 m
.76492 .12133 L
s
1 .328 0 r
.008 w
.76492 .12133 Mdot
.016 w
.76492 .12133 m
.7649 .12131 L
s
.008 w
.7649 .12131 Mdot
.016 w
.7649 .12131 m
.76489 .1213 L
s
.008 w
.76489 .1213 Mdot
.016 w
.76489 .1213 m
.76488 .1213 L
s
.008 w
.76488 .1213 Mdot
.016 w
.76488 .1213 m
.76488 .1213 L
s
.008 w
.76488 .1213 Mdot
.016 w
.76488 .1213 m
.76489 .1213 L
s
1 .327 0 r
.008 w
.76489 .1213 Mdot
.016 w
.76489 .1213 m
.76489 .12131 L
s
.008 w
.76489 .12131 Mdot
.016 w
.76489 .12131 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .326 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .325 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .324 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .323 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .322 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .321 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .32 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
1 .319 0 r
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .12132 L
s
.008 w
.7649 .12132 Mdot
.016 w
.7649 .12132 m
.7649 .1213 L
s
1 .318 0 r
.008 w
.7649 .1213 Mdot
.016 w
.7649 .1213 m
.76492 .1213 L
s
.008 w
.76492 .1213 Mdot
.016 w
.76492 .1213 m
.76494 .1213 L
s
.008 w
.76494 .1213 Mdot
.016 w
.76494 .1213 m
.76497 .1213 L
s
.008 w
.76497 .1213 Mdot
.016 w
.76497 .1213 m
.76497 .1213 L
s
.008 w
.76497 .1213 Mdot
.016 w
.76497 .1213 m
.76495 .12131 L
s
1 .317 0 r
.008 w
.76495 .12131 Mdot
.016 w
.76495 .12131 m
.76491 .12134 L
s
.008 w
.76491 .12134 Mdot
.016 w
.76491 .12134 m
.76486 .12138 L
s
.008 w
.76486 .12138 Mdot
.016 w
.76486 .12138 m
.7648 .12144 L
s
.008 w
.7648 .12144 Mdot
.016 w
.7648 .12144 m
.76473 .12152 L
s
1 .316 0 r
.008 w
.76473 .12152 Mdot
.016 w
.76473 .12152 m
.76466 .12159 L
s
.008 w
.76466 .12159 Mdot
.016 w
.76466 .12159 m
.76458 .12167 L
s
.008 w
.76458 .12167 Mdot
.016 w
.76458 .12167 m
.7645 .12173 L
s
.008 w
.7645 .12173 Mdot
.016 w
.7645 .12173 m
.76444 .12177 L
s
.008 w
.76444 .12177 Mdot
.016 w
.76444 .12177 m
.76442 .1218 L
s
1 .315 0 r
.008 w
.76442 .1218 Mdot
.016 w
.76442 .1218 m
.76443 .12182 L
s
.008 w
.76443 .12182 Mdot
.016 w
.76443 .12182 m
.76448 .12181 L
s
.008 w
.76448 .12181 Mdot
.016 w
.76448 .12181 m
.76457 .12178 L
s
.008 w
.76457 .12178 Mdot
.016 w
.76457 .12178 m
.76473 .12176 L
s
.008 w
.76473 .12176 Mdot
.016 w
.76473 .12176 m
.76489 .12171 L
s
1 .314 0 r
.008 w
.76489 .12171 Mdot
.016 w
.76489 .12171 m
.76513 .12165 L
s
.008 w
.76513 .12165 Mdot
.016 w
.76513 .12165 m
.7654 .12158 L
s
.008 w
.7654 .12158 Mdot
.016 w
.7654 .12158 m
.76568 .12152 L
s
.008 w
.76568 .12152 Mdot
.016 w
.76568 .12152 m
.76595 .12145 L
s
.008 w
.76595 .12145 Mdot
.016 w
.76595 .12145 m
.76621 .1214 L
s
1 .313 0 r
.008 w
.76621 .1214 Mdot
.016 w
.76621 .1214 m
.76643 .12136 L
s
.008 w
.76643 .12136 Mdot
.016 w
.76643 .12136 m
.76661 .12134 L
s
.008 w
.76661 .12134 Mdot
.016 w
.76661 .12134 m
.76676 .12133 L
s
.008 w
.76676 .12133 Mdot
.016 w
.76676 .12133 m
.76688 .12134 L
s
.008 w
.76688 .12134 Mdot
.016 w
.76688 .12134 m
.76697 .12136 L
s
1 .312 0 r
.008 w
.76697 .12136 Mdot
.016 w
.76697 .12136 m
.76702 .12138 L
s
.008 w
.76702 .12138 Mdot
.016 w
.76702 .12138 m
.76702 .12139 L
s
.008 w
.76702 .12139 Mdot
.016 w
.76702 .12139 m
.767 .1214 L
s
.008 w
.767 .1214 Mdot
.016 w
.767 .1214 m
.76697 .12139 L
s
1 .311 0 r
.008 w
.76697 .12139 Mdot
.016 w
.76697 .12139 m
.76693 .12139 L
s
.008 w
.76693 .12139 Mdot
.016 w
.76693 .12139 m
.76691 .12139 L
s
.008 w
.76691 .12139 Mdot
.016 w
.76691 .12139 m
.7669 .12139 L
s
.008 w
.7669 .12139 Mdot
.016 w
.7669 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .31 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .309 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .308 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .307 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .306 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .305 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .304 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .303 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .302 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .301 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .3 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
1 .299 0 r
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76689 .12139 L
s
.008 w
.76689 .12139 Mdot
.016 w
.76689 .12139 m
.76688 .12138 L
s
1 .298 0 r
.008 w
.76688 .12138 Mdot
.016 w
.76688 .12138 m
.76685 .12135 L
s
.008 w
.76685 .12135 Mdot
.016 w
.76685 .12135 m
.76682 .12132 L
s
.008 w
.76682 .12132 Mdot
.016 w
.76682 .12132 m
.76679 .12129 L
s
.008 w
.76679 .12129 Mdot
.016 w
.76679 .12129 m
.76678 .12127 L
s
.008 w
.76678 .12127 Mdot
.016 w
.76678 .12127 m
.76679 .12128 L
s
1 .297 0 r
.008 w
.76679 .12128 Mdot
.016 w
.76679 .12128 m
.76683 .12133 L
s
.008 w
.76683 .12133 Mdot
.016 w
.76683 .12133 m
.76692 .12141 L
s
.008 w
.76692 .12141 Mdot
.016 w
.76692 .12141 m
.76704 .12154 L
s
.008 w
.76704 .12154 Mdot
.016 w
.76704 .12154 m
.76719 .12169 L
s
.008 w
.76719 .12169 Mdot
.016 w
.76719 .12169 m
.76738 .12188 L
s
1 .296 0 r
.008 w
.76738 .12188 Mdot
.016 w
.76738 .12188 m
.76759 .12209 L
s
.008 w
.76759 .12209 Mdot
.016 w
.76759 .12209 m
.76782 .1223 L
s
.008 w
.76782 .1223 Mdot
.016 w
.76782 .1223 m
.76806 .12252 L
s
.008 w
.76806 .12252 Mdot
.016 w
.76806 .12252 m
.76829 .12275 L
s
.008 w
.76829 .12275 Mdot
.016 w
.76829 .12275 m
.7685 .12299 L
s
1 .295 0 r
.008 w
.7685 .12299 Mdot
.016 w
.7685 .12299 m
.76869 .12321 L
s
.008 w
.76869 .12321 Mdot
.016 w
.76869 .12321 m
.76882 .12339 L
s
.008 w
.76882 .12339 Mdot
.016 w
.76882 .12339 m
.76888 .12352 L
s
.008 w
.76888 .12352 Mdot
.016 w
.76888 .12352 m
.76886 .12357 L
s
1 .294 0 r
.008 w
.76886 .12357 Mdot
.016 w
.76886 .12357 m
.76877 .12355 L
s
.008 w
.76877 .12355 Mdot
.016 w
.76877 .12355 m
.76863 .12348 L
s
.008 w
.76863 .12348 Mdot
.016 w
.76863 .12348 m
.76849 .12337 L
s
.008 w
.76849 .12337 Mdot
.016 w
.76849 .12337 m
.76837 .12326 L
s
.008 w
.76837 .12326 Mdot
.016 w
.76837 .12326 m
.7683 .12317 L
s
1 .293 0 r
.008 w
.7683 .12317 Mdot
.016 w
.7683 .12317 m
.76824 .12309 L
s
.008 w
.76824 .12309 Mdot
.016 w
.76824 .12309 m
.76819 .12303 L
s
.008 w
.76819 .12303 Mdot
.016 w
.76819 .12303 m
.76814 .12298 L
s
.008 w
.76814 .12298 Mdot
.016 w
.76814 .12298 m
.76807 .12291 L
s
.008 w
.76807 .12291 Mdot
.016 w
.76807 .12291 m
.76795 .12283 L
s
1 .292 0 r
.008 w
.76795 .12283 Mdot
.016 w
.76795 .12283 m
.76778 .12274 L
s
.008 w
.76778 .12274 Mdot
.016 w
.76778 .12274 m
.76759 .12266 L
s
.008 w
.76759 .12266 Mdot
.016 w
.76759 .12266 m
.76739 .12257 L
s
.008 w
.76739 .12257 Mdot
.016 w
.76739 .12257 m
.76715 .12249 L
s
.008 w
.76715 .12249 Mdot
.016 w
.76715 .12249 m
.76688 .1224 L
s
1 .291 0 r
.008 w
.76688 .1224 Mdot
.016 w
.76688 .1224 m
.76662 .12232 L
s
.008 w
.76662 .12232 Mdot
.016 w
.76662 .12232 m
.76635 .12224 L
s
.008 w
.76635 .12224 Mdot
.016 w
.76635 .12224 m
.76609 .12218 L
s
.008 w
.76609 .12218 Mdot
.016 w
.76609 .12218 m
.76584 .12212 L
s
.008 w
.76584 .12212 Mdot
.016 w
.76584 .12212 m
.76563 .12208 L
s
1 .29 0 r
.008 w
.76563 .12208 Mdot
.016 w
.76563 .12208 m
.76548 .12205 L
s
.008 w
.76548 .12205 Mdot
.016 w
.76548 .12205 m
.76536 .12204 L
s
.008 w
.76536 .12204 Mdot
.016 w
.76536 .12204 m
.76534 .12206 L
s
.008 w
.76534 .12206 Mdot
.016 w
.76534 .12206 m
.76538 .12211 L
s
1 .289 0 r
.008 w
.76538 .12211 Mdot
.016 w
.76538 .12211 m
.76546 .12215 L
s
.008 w
.76546 .12215 Mdot
.016 w
.76546 .12215 m
.76552 .12216 L
s
.008 w
.76552 .12216 Mdot
.016 w
.76552 .12216 m
.76556 .12214 L
s
.008 w
.76556 .12214 Mdot
.016 w
.76556 .12214 m
.76555 .12209 L
s
.008 w
.76555 .12209 Mdot
.016 w
.76555 .12209 m
.76551 .12203 L
s
1 .288 0 r
.008 w
.76551 .12203 Mdot
.016 w
.76551 .12203 m
.76543 .12196 L
s
.008 w
.76543 .12196 Mdot
.016 w
.76543 .12196 m
.76539 .12191 L
s
.008 w
.76539 .12191 Mdot
.016 w
.76539 .12191 m
.76535 .12187 L
s
.008 w
.76535 .12187 Mdot
.016 w
.76535 .12187 m
.76533 .12185 L
s
.008 w
.76533 .12185 Mdot
.016 w
.76533 .12185 m
.76536 .12184 L
s
1 .287 0 r
.008 w
.76536 .12184 Mdot
.016 w
.76536 .12184 m
.76547 .12187 L
s
.008 w
.76547 .12187 Mdot
.016 w
.76547 .12187 m
.76565 .12194 L
s
.008 w
.76565 .12194 Mdot
.016 w
.76565 .12194 m
.7659 .12205 L
s
.008 w
.7659 .12205 Mdot
.016 w
.7659 .12205 m
.76621 .12221 L
s
.008 w
.76621 .12221 Mdot
.016 w
.76621 .12221 m
.76658 .1224 L
s
1 .286 0 r
.008 w
.76658 .1224 Mdot
.016 w
.76658 .1224 m
.767 .12263 L
s
.008 w
.767 .12263 Mdot
.016 w
.767 .12263 m
.76742 .12286 L
s
.008 w
.76742 .12286 Mdot
.016 w
.76742 .12286 m
.76782 .12305 L
s
.008 w
.76782 .12305 Mdot
.016 w
.76782 .12305 m
.76818 .12323 L
s
1 .285 0 r
.008 w
.76818 .12323 Mdot
.016 w
.76818 .12323 m
.76849 .12337 L
s
.008 w
.76849 .12337 Mdot
.016 w
.76849 .12337 m
.76873 .12347 L
s
.008 w
.76873 .12347 Mdot
.016 w
.76873 .12347 m
.76891 .12352 L
s
.008 w
.76891 .12352 Mdot
.016 w
.76891 .12352 m
.76902 .12354 L
s
.008 w
.76902 .12354 Mdot
.016 w
.76902 .12354 m
.76908 .12355 L
s
1 .284 0 r
.008 w
.76908 .12355 Mdot
.016 w
.76908 .12355 m
.76909 .12354 L
s
.008 w
.76909 .12354 Mdot
.016 w
.76909 .12354 m
.76905 .12351 L
s
.008 w
.76905 .12351 Mdot
.016 w
.76905 .12351 m
.76897 .12348 L
s
.008 w
.76897 .12348 Mdot
.016 w
.76897 .12348 m
.76887 .12343 L
s
.008 w
.76887 .12343 Mdot
.016 w
.76887 .12343 m
.76876 .12335 L
s
1 .283 0 r
.008 w
.76876 .12335 Mdot
.016 w
.76876 .12335 m
.76864 .12325 L
s
.008 w
.76864 .12325 Mdot
.016 w
.76864 .12325 m
.76854 .12314 L
s
.008 w
.76854 .12314 Mdot
.016 w
.76854 .12314 m
.76847 .12302 L
s
.008 w
.76847 .12302 Mdot
.016 w
.76847 .12302 m
.76843 .1229 L
s
.008 w
.76843 .1229 Mdot
.016 w
.76843 .1229 m
.76842 .12277 L
s
1 .282 0 r
.008 w
.76842 .12277 Mdot
.016 w
.76842 .12277 m
.76844 .12264 L
s
.008 w
.76844 .12264 Mdot
.016 w
.76844 .12264 m
.76851 .12252 L
s
.008 w
.76851 .12252 Mdot
.016 w
.76851 .12252 m
.76862 .12243 L
s
.008 w
.76862 .12243 Mdot
.016 w
.76862 .12243 m
.76876 .12239 L
s
1 .281 0 r
.008 w
.76876 .12239 Mdot
.016 w
.76876 .12239 m
.76897 .12244 L
s
.008 w
.76897 .12244 Mdot
.016 w
.76897 .12244 m
.76922 .12257 L
s
.008 w
.76922 .12257 Mdot
.016 w
.76922 .12257 m
.76952 .12277 L
s
.008 w
.76952 .12277 Mdot
.016 w
.76952 .12277 m
.76984 .12304 L
s
.008 w
.76984 .12304 Mdot
.016 w
.76984 .12304 m
.7702 .12337 L
s
1 .28 0 r
.008 w
.7702 .12337 Mdot
.016 w
.7702 .12337 m
.77061 .12377 L
s
.008 w
.77061 .12377 Mdot
.016 w
.77061 .12377 m
.77109 .12423 L
s
.008 w
.77109 .12423 Mdot
.016 w
.77109 .12423 m
.77165 .12475 L
s
.008 w
.77165 .12475 Mdot
.016 w
.77165 .12475 m
.7723 .12536 L
s
.008 w
.7723 .12536 Mdot
.016 w
.7723 .12536 m
.77305 .12602 L
s
1 .279 0 r
.008 w
.77305 .12602 Mdot
.016 w
.77305 .12602 m
.77391 .12675 L
s
.008 w
.77391 .12675 Mdot
.016 w
.77391 .12675 m
.77486 .12757 L
s
.008 w
.77486 .12757 Mdot
.016 w
.77486 .12757 m
.77592 .12845 L
s
.008 w
.77592 .12845 Mdot
.016 w
.77592 .12845 m
.77706 .12937 L
s
.008 w
.77706 .12937 Mdot
.016 w
.77706 .12937 m
.77811 .13028 L
s
1 .278 0 r
.008 w
.77811 .13028 Mdot
.016 w
.77811 .13028 m
.77922 .1311 L
s
.008 w
.77922 .1311 Mdot
.016 w
.77922 .1311 m
.78034 .13195 L
s
.008 w
.78034 .13195 Mdot
.016 w
.78034 .13195 m
.78131 .13278 L
s
.008 w
.78131 .13278 Mdot
.016 w
.78131 .13278 m
.78225 .13359 L
s
.008 w
.78225 .13359 Mdot
.016 w
.78225 .13359 m
.78313 .13429 L
s
1 .277 0 r
.008 w
.78313 .13429 Mdot
.016 w
.78313 .13429 m
.78391 .13495 L
s
.008 w
.78391 .13495 Mdot
.016 w
.78391 .13495 m
.78456 .13554 L
s
.008 w
.78456 .13554 Mdot
.016 w
.78456 .13554 m
.78513 .13604 L
s
.008 w
.78513 .13604 Mdot
.016 w
.78513 .13604 m
.78561 .13644 L
s
1 .276 0 r
.008 w
.78561 .13644 Mdot
.016 w
.78561 .13644 m
.78603 .13677 L
s
.008 w
.78603 .13677 Mdot
.016 w
.78603 .13677 m
.78643 .13705 L
s
.008 w
.78643 .13705 Mdot
.016 w
.78643 .13705 m
.78686 .13736 L
s
.008 w
.78686 .13736 Mdot
.016 w
.78686 .13736 m
.78737 .13776 L
s
.008 w
.78737 .13776 Mdot
.016 w
.78737 .13776 m
.78801 .13835 L
s
1 .275 0 r
.008 w
.78801 .13835 Mdot
.016 w
.78801 .13835 m
.78877 .13916 L
s
.008 w
.78877 .13916 Mdot
.016 w
.78877 .13916 m
.78972 .14026 L
s
.008 w
.78972 .14026 Mdot
.016 w
.78972 .14026 m
.79078 .14155 L
s
.008 w
.79078 .14155 Mdot
.016 w
.79078 .14155 m
.79206 .14315 L
s
.008 w
.79206 .14315 Mdot
.016 w
.79206 .14315 m
.79355 .1451 L
s
1 .274 0 r
.008 w
.79355 .1451 Mdot
.016 w
.79355 .1451 m
.79526 .14729 L
s
.008 w
.79526 .14729 Mdot
.016 w
.79526 .14729 m
.79724 .14984 L
s
.008 w
.79724 .14984 Mdot
.016 w
.79724 .14984 m
.79924 .15267 L
s
.008 w
.79924 .15267 Mdot
.016 w
.79924 .15267 m
.80149 .15581 L
s
.008 w
.80149 .15581 Mdot
.016 w
.80149 .15581 m
.80398 .15937 L
s
1 .273 0 r
.008 w
.80398 .15937 Mdot
.016 w
.80398 .15937 m
.8065 .16268 L
s
.008 w
.8065 .16268 Mdot
.016 w
.8065 .16268 m
.80909 .16647 L
s
.008 w
.80909 .16647 Mdot
.016 w
.80909 .16647 m
.81184 .16987 L
s
.008 w
.81184 .16987 Mdot
.016 w
.81184 .16987 m
.81451 .17367 L
s
1 .272 0 r
.008 w
.81451 .17367 Mdot
.016 w
.81451 .17367 m
.81737 .17704 L
s
.008 w
.81737 .17704 Mdot
.016 w
.81737 .17704 m
.82028 .18073 L
s
.008 w
.82028 .18073 Mdot
.016 w
.82028 .18073 m
.8229 .18429 L
s
.008 w
.8229 .18429 Mdot
.016 w
.8229 .18429 m
.82536 .18756 L
s
.008 w
.82536 .18756 Mdot
.016 w
.82536 .18756 m
.82799 .191 L
s
1 .271 0 r
.008 w
.82799 .191 Mdot
.016 w
.82799 .191 m
.83057 .19449 L
s
.008 w
.83057 .19449 Mdot
.016 w
.83057 .19449 m
.8331 .19775 L
s
.008 w
.8331 .19775 Mdot
.016 w
.8331 .19775 m
.83582 .20145 L
s
.008 w
.83582 .20145 Mdot
.016 w
.83582 .20145 m
.83826 .20478 L
s
.008 w
.83826 .20478 Mdot
.016 w
.83826 .20478 m
.84112 .20892 L
s
1 .27 0 r
.008 w
.84112 .20892 Mdot
.016 w
.84112 .20892 m
.84373 .21241 L
s
.008 w
.84373 .21241 Mdot
.016 w
.84373 .21241 m
.84634 .21662 L
s
.008 w
.84634 .21662 Mdot
.016 w
.84634 .21662 m
.8492 .22087 L
s
.008 w
.8492 .22087 Mdot
.016 w
.8492 .22087 m
.85201 .22546 L
s
.008 w
.85201 .22546 Mdot
.016 w
.85201 .22546 m
.85528 .23074 L
s
1 .269 0 r
.008 w
.85528 .23074 Mdot
.016 w
.85528 .23074 m
.85798 .23486 L
s
.008 w
.85798 .23486 Mdot
.016 w
.85798 .23486 m
.86098 .2395 L
s
.008 w
.86098 .2395 Mdot
.016 w
.86098 .2395 m
.86398 .24437 L
s
.008 w
.86398 .24437 Mdot
.016 w
.86398 .24437 m
.86659 .24809 L
s
1 .268 0 r
.008 w
.86659 .24809 Mdot
.016 w
.86659 .24809 m
.86919 .25196 L
s
.008 w
.86919 .25196 Mdot
.016 w
.86919 .25196 m
.87164 .25563 L
s
.008 w
.87164 .25563 Mdot
.016 w
.87164 .25563 m
.87372 .25877 L
s
.008 w
.87372 .25877 Mdot
.016 w
.87372 .25877 m
.87545 .26123 L
s
.008 w
.87545 .26123 Mdot
.016 w
.87545 .26123 m
.87698 .2634 L
s
1 .267 0 r
.008 w
.87698 .2634 Mdot
.016 w
.87698 .2634 m
.87821 .26513 L
s
.008 w
.87821 .26513 Mdot
.016 w
.87821 .26513 m
.87912 .26647 L
s
.008 w
.87912 .26647 Mdot
.016 w
.87912 .26647 m
.87976 .26742 L
s
.008 w
.87976 .26742 Mdot
.016 w
.87976 .26742 m
.88015 .26801 L
s
.008 w
.88015 .26801 Mdot
.016 w
.88015 .26801 m
.88034 .26833 L
s
1 .266 0 r
.008 w
.88034 .26833 Mdot
.016 w
.88034 .26833 m
.8804 .26852 L
s
.008 w
.8804 .26852 Mdot
.016 w
.8804 .26852 m
.88038 .26862 L
s
.008 w
.88038 .26862 Mdot
.016 w
.88038 .26862 m
.8803 .26866 L
s
.008 w
.8803 .26866 Mdot
.016 w
.8803 .26866 m
.88024 .26871 L
s
.008 w
.88024 .26871 Mdot
.016 w
.88024 .26871 m
.88024 .26878 L
s
1 .265 0 r
.008 w
.88024 .26878 Mdot
.016 w
.88024 .26878 m
.88031 .26888 L
s
.008 w
.88031 .26888 Mdot
.016 w
.88031 .26888 m
.88042 .26899 L
s
.008 w
.88042 .26899 Mdot
.016 w
.88042 .26899 m
.88057 .26906 L
s
.008 w
.88057 .26906 Mdot
.016 w
.88057 .26906 m
.88076 .26909 L
s
.008 w
.88076 .26909 Mdot
.016 w
.88076 .26909 m
.88095 .26912 L
s
1 .264 0 r
.008 w
.88095 .26912 Mdot
.016 w
.88095 .26912 m
.88113 .26913 L
s
.008 w
.88113 .26913 Mdot
.016 w
.88113 .26913 m
.88128 .26911 L
s
.008 w
.88128 .26911 Mdot
.016 w
.88128 .26911 m
.8814 .26906 L
s
.008 w
.8814 .26906 Mdot
.016 w
.8814 .26906 m
.88149 .26901 L
s
1 .263 0 r
.008 w
.88149 .26901 Mdot
.016 w
.88149 .26901 m
.88154 .26896 L
s
.008 w
.88154 .26896 Mdot
.016 w
.88154 .26896 m
.88157 .26894 L
s
.008 w
.88157 .26894 Mdot
.016 w
.88157 .26894 m
.88159 .269 L
s
.008 w
.88159 .269 Mdot
.016 w
.88159 .269 m
.88164 .26919 L
s
.008 w
.88164 .26919 Mdot
.016 w
.88164 .26919 m
.88177 .26953 L
s
1 .262 0 r
.008 w
.88177 .26953 Mdot
.016 w
.88177 .26953 m
.88203 .27009 L
s
.008 w
.88203 .27009 Mdot
.016 w
.88203 .27009 m
.88247 .27092 L
s
.008 w
.88247 .27092 Mdot
.016 w
.88247 .27092 m
.88312 .27208 L
s
.008 w
.88312 .27208 Mdot
.016 w
.88312 .27208 m
.88401 .27358 L
s
.008 w
.88401 .27358 Mdot
.016 w
.88401 .27358 m
.88504 .27519 L
s
1 .261 0 r
.008 w
.88504 .27519 Mdot
.016 w
.88504 .27519 m
.88624 .27717 L
s
.008 w
.88624 .27717 Mdot
.016 w
.88624 .27717 m
.8876 .27923 L
s
.008 w
.8876 .27923 Mdot
.016 w
.8876 .27923 m
.88907 .28155 L
s
.008 w
.88907 .28155 Mdot
.016 w
.88907 .28155 m
.89051 .28383 L
s
.008 w
.89051 .28383 Mdot
.016 w
.89051 .28383 m
.89198 .28624 L
s
1 .26 0 r
.008 w
.89198 .28624 Mdot
.016 w
.89198 .28624 m
.89336 .2883 L
s
.008 w
.89336 .2883 Mdot
.016 w
.89336 .2883 m
.89455 .29026 L
s
.008 w
.89455 .29026 Mdot
.016 w
.89455 .29026 m
.89567 .292 L
s
.008 w
.89567 .292 Mdot
.016 w
.89567 .292 m
.89658 .29345 L
s
1 .259 0 r
.008 w
.89658 .29345 Mdot
.016 w
.89658 .29345 m
.8973 .29459 L
s
.008 w
.8973 .29459 Mdot
.016 w
.8973 .29459 m
.89781 .29546 L
s
.008 w
.89781 .29546 Mdot
.016 w
.89781 .29546 m
.89811 .29606 L
s
.008 w
.89811 .29606 Mdot
.016 w
.89811 .29606 m
.89824 .29643 L
s
.008 w
.89824 .29643 Mdot
.016 w
.89824 .29643 m
.89827 .29661 L
s
1 .258 0 r
.008 w
.89827 .29661 Mdot
.016 w
.89827 .29661 m
.89822 .29662 L
s
.008 w
.89822 .29662 Mdot
.016 w
.89822 .29662 m
.89811 .29651 L
s
.008 w
.89811 .29651 Mdot
.016 w
.89811 .29651 m
.898 .29632 L
s
.008 w
.898 .29632 Mdot
.016 w
.898 .29632 m
.89791 .29608 L
s
.008 w
.89791 .29608 Mdot
.016 w
.89791 .29608 m
.89785 .29582 L
s
1 .257 0 r
.008 w
.89785 .29582 Mdot
.016 w
.89785 .29582 m
.89782 .29556 L
s
.008 w
.89782 .29556 Mdot
.016 w
.89782 .29556 m
.8978 .29533 L
s
.008 w
.8978 .29533 Mdot
.016 w
.8978 .29533 m
.89779 .29514 L
s
.008 w
.89779 .29514 Mdot
.016 w
.89779 .29514 m
.89778 .295 L
s
.008 w
.89778 .295 Mdot
.016 w
.89778 .295 m
.89778 .29489 L
s
1 .256 0 r
.008 w
.89778 .29489 Mdot
.016 w
.89778 .29489 m
.89778 .29482 L
s
.008 w
.89778 .29482 Mdot
.016 w
.89778 .29482 m
.89778 .29478 L
s
.008 w
.89778 .29478 Mdot
.016 w
.89778 .29478 m
.89778 .2948 L
s
.008 w
.89778 .2948 Mdot
.016 w
.89778 .2948 m
.89778 .29486 L
s
.008 w
.89778 .29486 Mdot
.016 w
.89778 .29486 m
.89778 .29496 L
s
1 .255 0 r
.008 w
.89778 .29496 Mdot
.016 w
.89778 .29496 m
.89779 .29509 L
s
.008 w
.89779 .29509 Mdot
.016 w
.89779 .29509 m
.89779 .29526 L
s
.008 w
.89779 .29526 Mdot
.016 w
.89779 .29526 m
.8978 .29544 L
s
.008 w
.8978 .29544 Mdot
.016 w
.8978 .29544 m
.89781 .29562 L
s
1 .254 0 r
.008 w
.89781 .29562 Mdot
.016 w
.89781 .29562 m
.89781 .29578 L
s
.008 w
.89781 .29578 Mdot
.016 w
.89781 .29578 m
.89782 .29592 L
s
.008 w
.89782 .29592 Mdot
.016 w
.89782 .29592 m
.89782 .29601 L
s
.008 w
.89782 .29601 Mdot
.016 w
.89782 .29601 m
.89782 .29607 L
s
.008 w
.89782 .29607 Mdot
.016 w
.89782 .29607 m
.89783 .29609 L
s
1 .253 0 r
.008 w
.89783 .29609 Mdot
.016 w
.89783 .29609 m
.89782 .29607 L
s
.008 w
.89782 .29607 Mdot
.016 w
.89782 .29607 m
.89782 .29601 L
s
.008 w
.89782 .29601 Mdot
.016 w
.89782 .29601 m
.89782 .29589 L
s
.008 w
.89782 .29589 Mdot
.016 w
.89782 .29589 m
.8978 .29577 L
s
.008 w
.8978 .29577 Mdot
.016 w
.8978 .29577 m
.89777 .29566 L
s
1 .252 0 r
.008 w
.89777 .29566 Mdot
.016 w
.89777 .29566 m
.89774 .29557 L
s
.008 w
.89774 .29557 Mdot
.016 w
.89774 .29557 m
.89771 .29552 L
s
.008 w
.89771 .29552 Mdot
.016 w
.89771 .29552 m
.89768 .29553 L
s
.008 w
.89768 .29553 Mdot
.016 w
.89768 .29553 m
.89767 .29562 L
s
.008 w
.89767 .29562 Mdot
.016 w
.89767 .29562 m
.89769 .29584 L
s
1 .251 0 r
.008 w
.89769 .29584 Mdot
.016 w
.89769 .29584 m
.89775 .29616 L
s
.008 w
.89775 .29616 Mdot
.016 w
.89775 .29616 m
.89786 .29661 L
s
.008 w
.89786 .29661 Mdot
.016 w
.89786 .29661 m
.89804 .29719 L
s
.008 w
.89804 .29719 Mdot
.016 w
.89804 .29719 m
.89827 .29787 L
s
1 .25 0 r
.008 w
.89827 .29787 Mdot
.016 w
.89827 .29787 m
.89855 .29861 L
s
.008 w
.89855 .29861 Mdot
.016 w
.89855 .29861 m
.89889 .29942 L
s
.008 w
.89889 .29942 Mdot
.016 w
.89889 .29942 m
.89925 .30025 L
s
.008 w
.89925 .30025 Mdot
.016 w
.89925 .30025 m
.89964 .30108 L
s
.008 w
.89964 .30108 Mdot
.016 w
.89964 .30108 m
.90004 .30186 L
s
1 .249 0 r
.008 w
.90004 .30186 Mdot
.016 w
.90004 .30186 m
.90043 .30255 L
s
.008 w
.90043 .30255 Mdot
.016 w
.90043 .30255 m
.9008 .30315 L
s
.008 w
.9008 .30315 Mdot
.016 w
.9008 .30315 m
.90113 .30362 L
s
.008 w
.90113 .30362 Mdot
.016 w
.90113 .30362 m
.90141 .30397 L
s
.008 w
.90141 .30397 Mdot
.016 w
.90141 .30397 m
.90164 .3042 L
s
1 .248 0 r
.008 w
.90164 .3042 Mdot
.016 w
.90164 .3042 m
.90181 .30432 L
s
.008 w
.90181 .30432 Mdot
.016 w
.90181 .30432 m
.90191 .30436 L
s
.008 w
.90191 .30436 Mdot
.016 w
.90191 .30436 m
.90197 .30435 L
s
.008 w
.90197 .30435 Mdot
.016 w
.90197 .30435 m
.90198 .3043 L
s
.008 w
.90198 .3043 Mdot
.016 w
.90198 .3043 m
.90197 .30423 L
s
1 .247 0 r
.008 w
.90197 .30423 Mdot
.016 w
.90197 .30423 m
.90194 .30416 L
s
.008 w
.90194 .30416 Mdot
.016 w
.90194 .30416 m
.9019 .30409 L
s
.008 w
.9019 .30409 Mdot
.016 w
.9019 .30409 m
.90184 .30404 L
s
.008 w
.90184 .30404 Mdot
.016 w
.90184 .30404 m
.90178 .304 L
s
1 .246 0 r
.008 w
.90178 .304 Mdot
.016 w
.90178 .304 m
.90174 .30397 L
s
.008 w
.90174 .30397 Mdot
.016 w
.90174 .30397 m
.90173 .30396 L
s
.008 w
.90173 .30396 Mdot
.016 w
.90173 .30396 m
.90174 .30397 L
s
.008 w
.90174 .30397 Mdot
.016 w
.90174 .30397 m
.90178 .304 L
s
.008 w
.90178 .304 Mdot
.016 w
.90178 .304 m
.90185 .30406 L
s
1 .245 0 r
.008 w
.90185 .30406 Mdot
.016 w
.90185 .30406 m
.90195 .30414 L
s
.008 w
.90195 .30414 Mdot
.016 w
.90195 .30414 m
.90208 .30423 L
s
.008 w
.90208 .30423 Mdot
.016 w
.90208 .30423 m
.90223 .30436 L
s
.008 w
.90223 .30436 Mdot
.016 w
.90223 .30436 m
.90241 .30455 L
s
.008 w
.90241 .30455 Mdot
.016 w
.90241 .30455 m
.90263 .30479 L
s
1 .244 0 r
.008 w
.90263 .30479 Mdot
.016 w
.90263 .30479 m
.90287 .30509 L
s
.008 w
.90287 .30509 Mdot
.016 w
.90287 .30509 m
.90313 .30544 L
s
.008 w
.90313 .30544 Mdot
.016 w
.90313 .30544 m
.9034 .30584 L
s
.008 w
.9034 .30584 Mdot
.016 w
.9034 .30584 m
.90365 .30627 L
s
.008 w
.90365 .30627 Mdot
.016 w
.90365 .30627 m
.90388 .30673 L
s
1 .243 0 r
.008 w
.90388 .30673 Mdot
.016 w
.90388 .30673 m
.90406 .3072 L
s
.008 w
.90406 .3072 Mdot
.016 w
.90406 .3072 m
.9042 .30767 L
s
.008 w
.9042 .30767 Mdot
.016 w
.9042 .30767 m
.90429 .30811 L
s
.008 w
.90429 .30811 Mdot
.016 w
.90429 .30811 m
.90434 .30854 L
s
.008 w
.90434 .30854 Mdot
.016 w
.90434 .30854 m
.90434 .30896 L
s
1 .242 0 r
.008 w
.90434 .30896 Mdot
.016 w
.90434 .30896 m
.90432 .30938 L
s
.008 w
.90432 .30938 Mdot
.016 w
.90432 .30938 m
.90428 .30972 L
s
.008 w
.90428 .30972 Mdot
.016 w
.90428 .30972 m
.90423 .31 L
s
.008 w
.90423 .31 Mdot
.016 w
.90423 .31 m
.90418 .31018 L
s
1 .241 0 r
.008 w
.90418 .31018 Mdot
.016 w
.90418 .31018 m
.90411 .31024 L
s
.008 w
.90411 .31024 Mdot
.016 w
.90411 .31024 m
.90404 .31017 L
s
.008 w
.90404 .31017 Mdot
.016 w
.90404 .31017 m
.90397 .30996 L
s
.008 w
.90397 .30996 Mdot
.016 w
.90397 .30996 m
.9039 .30965 L
s
.008 w
.9039 .30965 Mdot
.016 w
.9039 .30965 m
.90385 .30928 L
s
1 .24 0 r
.008 w
.90385 .30928 Mdot
.016 w
.90385 .30928 m
.90382 .30888 L
s
.008 w
.90382 .30888 Mdot
.016 w
.90382 .30888 m
.90382 .30846 L
s
.008 w
.90382 .30846 Mdot
.016 w
.90382 .30846 m
.90386 .30805 L
s
.008 w
.90386 .30805 Mdot
.016 w
.90386 .30805 m
.9039 .30763 L
s
.008 w
.9039 .30763 Mdot
.016 w
.9039 .30763 m
.90393 .30722 L
s
1 .239 0 r
.008 w
.90393 .30722 Mdot
.016 w
.90393 .30722 m
.90395 .30686 L
s
.008 w
.90395 .30686 Mdot
.016 w
.90395 .30686 m
.90394 .30659 L
s
.008 w
.90394 .30659 Mdot
.016 w
.90394 .30659 m
.9039 .3064 L
s
.008 w
.9039 .3064 Mdot
.016 w
.9039 .3064 m
.90383 .30629 L
s
.008 w
.90383 .30629 Mdot
.016 w
.90383 .30629 m
.90373 .30627 L
s
1 .238 0 r
.008 w
.90373 .30627 Mdot
.016 w
.90373 .30627 m
.90361 .30632 L
s
.008 w
.90361 .30632 Mdot
.016 w
.90361 .30632 m
.90345 .30636 L
s
.008 w
.90345 .30636 Mdot
.016 w
.90345 .30636 m
.90325 .30633 L
s
.008 w
.90325 .30633 Mdot
.016 w
.90325 .30633 m
.90302 .30616 L
s
1 .237 0 r
.008 w
.90302 .30616 Mdot
.016 w
.90302 .30616 m
.90272 .30577 L
s
.008 w
.90272 .30577 Mdot
.016 w
.90272 .30577 m
.90233 .30514 L
s
.008 w
.90233 .30514 Mdot
.016 w
.90233 .30514 m
.90184 .30422 L
s
.008 w
.90184 .30422 Mdot
.016 w
.90184 .30422 m
.90121 .30303 L
s
.008 w
.90121 .30303 Mdot
.016 w
.90121 .30303 m
.90043 .30145 L
s
1 .236 0 r
.008 w
.90043 .30145 Mdot
.016 w
.90043 .30145 m
.89944 .29949 L
s
.008 w
.89944 .29949 Mdot
.016 w
.89944 .29949 m
.89822 .29703 L
s
.008 w
.89822 .29703 Mdot
.016 w
.89822 .29703 m
.89678 .29438 L
s
.008 w
.89678 .29438 Mdot
.016 w
.89678 .29438 m
.89506 .29084 L
s
.008 w
.89506 .29084 Mdot
.016 w
.89506 .29084 m
.89308 .28757 L
s
1 .235 0 r
.008 w
.89308 .28757 Mdot
.016 w
.89308 .28757 m
.89076 .28352 L
s
.008 w
.89076 .28352 Mdot
.016 w
.89076 .28352 m
.88831 .27941 L
s
.008 w
.88831 .27941 Mdot
.016 w
.88831 .27941 m
.88551 .27494 L
s
.008 w
.88551 .27494 Mdot
.016 w
.88551 .27494 m
.88254 .26988 L
s
.008 w
.88254 .26988 Mdot
.016 w
.88254 .26988 m
.87943 .26548 L
s
1 .234 0 r
.008 w
.87943 .26548 Mdot
.016 w
.87943 .26548 m
.87615 .26023 L
s
.008 w
.87615 .26023 Mdot
.016 w
.87615 .26023 m
.87282 .25515 L
s
.008 w
.87282 .25515 Mdot
.016 w
.87282 .25515 m
.86959 .25078 L
s
.008 w
.86959 .25078 Mdot
.016 w
.86959 .25078 m
.86627 .24581 L
s
1 .233 0 r
.008 w
.86627 .24581 Mdot
.016 w
.86627 .24581 m
.86288 .24037 L
s
.008 w
.86288 .24037 Mdot
.016 w
.86288 .24037 m
.8597 .23595 L
s
.008 w
.8597 .23595 Mdot
.016 w
.8597 .23595 m
.85648 .23099 L
s
.008 w
.85648 .23099 Mdot
.016 w
.85648 .23099 m
.85327 .22638 L
s
.008 w
.85327 .22638 Mdot
.016 w
.85327 .22638 m
.85011 .22174 L
s
1 .232 0 r
.008 w
.85011 .22174 Mdot
.016 w
.85011 .22174 m
.84679 .21684 L
s
.008 w
.84679 .21684 Mdot
.016 w
.84679 .21684 m
.84358 .21238 L
s
.008 w
.84358 .21238 Mdot
.016 w
.84358 .21238 m
.84027 .20778 L
s
.008 w
.84027 .20778 Mdot
.016 w
.84027 .20778 m
.83683 .20287 L
s
.008 w
.83683 .20287 Mdot
.016 w
.83683 .20287 m
.83326 .19817 L
s
1 .231 0 r
.008 w
.83326 .19817 Mdot
.016 w
.83326 .19817 m
.82969 .19314 L
s
.008 w
.82969 .19314 Mdot
.016 w
.82969 .19314 m
.82609 .1885 L
s
.008 w
.82609 .1885 Mdot
.016 w
.82609 .1885 m
.82224 .18318 L
s
.008 w
.82224 .18318 Mdot
.016 w
.82224 .18318 m
.81864 .17858 L
s
.008 w
.81864 .17858 Mdot
.016 w
.81864 .17858 m
.81487 .17356 L
s
1 .23 0 r
.008 w
.81487 .17356 Mdot
.016 w
.81487 .17356 m
.81097 .16795 L
s
.008 w
.81097 .16795 Mdot
.016 w
.81097 .16795 m
.80736 .16346 L
s
.008 w
.80736 .16346 Mdot
.016 w
.80736 .16346 m
.80369 .15844 L
s
.008 w
.80369 .15844 Mdot
.016 w
.80369 .15844 m
.80006 .15325 L
s
.008 w
.80006 .15325 Mdot
.016 w
.80006 .15325 m
.79648 .14881 L
s
1 .229 0 r
.008 w
.79648 .14881 Mdot
.016 w
.79648 .14881 m
.79314 .14438 L
s
.008 w
.79314 .14438 Mdot
.016 w
.79314 .14438 m
.78981 .14043 L
s
.008 w
.78981 .14043 Mdot
.016 w
.78981 .14043 m
.7865 .13651 L
s
.008 w
.7865 .13651 Mdot
.016 w
.7865 .13651 m
.78342 .13348 L
s
1 .228 0 r
.008 w
.78342 .13348 Mdot
.016 w
.78342 .13348 m
.78026 .13044 L
s
.008 w
.78026 .13044 Mdot
.016 w
.78026 .13044 m
.77714 .12768 L
s
.008 w
.77714 .12768 Mdot
.016 w
.77714 .12768 m
.77414 .12546 L
s
.008 w
.77414 .12546 Mdot
.016 w
.77414 .12546 m
.7711 .12343 L
s
.008 w
.7711 .12343 Mdot
.016 w
.7711 .12343 m
.76854 .12167 L
s
1 .227 0 r
.008 w
.76854 .12167 Mdot
.016 w
.76854 .12167 m
.76605 .12026 L
s
.008 w
.76605 .12026 Mdot
.016 w
.76605 .12026 m
.76387 .11904 L
s
.008 w
.76387 .11904 Mdot
.016 w
.76387 .11904 m
.76175 .11801 L
s
.008 w
.76175 .11801 Mdot
.016 w
.76175 .11801 m
.75967 .11718 L
s
.008 w
.75967 .11718 Mdot
.016 w
.75967 .11718 m
.75778 .11628 L
s
1 .226 0 r
.008 w
.75778 .11628 Mdot
.016 w
.75778 .11628 m
.756 .11543 L
s
.008 w
.756 .11543 Mdot
.016 w
.756 .11543 m
.75416 .11451 L
s
.008 w
.75416 .11451 Mdot
.016 w
.75416 .11451 m
.75219 .11349 L
s
.008 w
.75219 .11349 Mdot
.016 w
.75219 .11349 m
.75001 .1124 L
s
.008 w
.75001 .1124 Mdot
.016 w
.75001 .1124 m
.74757 .11123 L
s
1 .225 0 r
.008 w
.74757 .11123 Mdot
.016 w
.74757 .11123 m
.74483 .11 L
s
.008 w
.74483 .11 Mdot
.016 w
.74483 .11 m
.74232 .1088 L
s
.008 w
.74232 .1088 Mdot
.016 w
.74232 .1088 m
.73909 .10753 L
s
.008 w
.73909 .10753 Mdot
.016 w
.73909 .10753 m
.73564 .10617 L
s
1 .224 0 r
.008 w
.73564 .10617 Mdot
.016 w
.73564 .10617 m
.73169 .10463 L
s
.008 w
.73169 .10463 Mdot
.016 w
.73169 .10463 m
.72676 .10288 L
s
.008 w
.72676 .10288 Mdot
.016 w
.72676 .10288 m
.72253 .1011 L
s
.008 w
.72253 .1011 Mdot
.016 w
.72253 .1011 m
.71737 .0991 L
s
.008 w
.71737 .0991 Mdot
.016 w
.71737 .0991 m
.71217 .09694 L
s
1 .223 0 r
.008 w
.71217 .09694 Mdot
.016 w
.71217 .09694 m
.70663 .09475 L
s
.008 w
.70663 .09475 Mdot
.016 w
.70663 .09475 m
.70094 .0924 L
s
.008 w
.70094 .0924 Mdot
.016 w
.70094 .0924 m
.69503 .09014 L
s
.008 w
.69503 .09014 Mdot
.016 w
.69503 .09014 m
.68954 .0878 L
s
.008 w
.68954 .0878 Mdot
.016 w
.68954 .0878 m
.68362 .08543 L
s
1 .222 0 r
.008 w
.68362 .08543 Mdot
.016 w
.68362 .08543 m
.67764 .08308 L
s
.008 w
.67764 .08308 Mdot
.016 w
.67764 .08308 m
.672 .08073 L
s
.008 w
.672 .08073 Mdot
.016 w
.672 .08073 m
.66569 .0784 L
s
.008 w
.66569 .0784 Mdot
.016 w
.66569 .0784 m
.66051 .07609 L
s
.008 w
.66051 .07609 Mdot
.016 w
.66051 .07609 m
.65482 .07382 L
s
1 .221 0 r
.008 w
.65482 .07382 Mdot
.016 w
.65482 .07382 m
.64916 .07151 L
s
.008 w
.64916 .07151 Mdot
.016 w
.64916 .07151 m
.64373 .06945 L
s
.008 w
.64373 .06945 Mdot
.016 w
.64373 .06945 m
.63887 .06741 L
s
.008 w
.63887 .06741 Mdot
.016 w
.63887 .06741 m
.63392 .06547 L
s
1 .22 0 r
.008 w
.63392 .06547 Mdot
.016 w
.63392 .06547 m
.6292 .06357 L
s
.008 w
.6292 .06357 Mdot
.016 w
.6292 .06357 m
.62475 .06184 L
s
.008 w
.62475 .06184 Mdot
.016 w
.62475 .06184 m
.62023 .06013 L
s
.008 w
.62023 .06013 Mdot
.016 w
.62023 .06013 m
.6162 .05852 L
s
.008 w
.6162 .05852 Mdot
.016 w
.6162 .05852 m
.61205 .05697 L
s
1 .219 0 r
.008 w
.61205 .05697 Mdot
.016 w
.61205 .05697 m
.60851 .05555 L
s
.008 w
.60851 .05555 Mdot
.016 w
.60851 .05555 m
.60486 .05417 L
s
.008 w
.60486 .05417 Mdot
.016 w
.60486 .05417 m
.60153 .05286 L
s
.008 w
.60153 .05286 Mdot
.016 w
.60153 .05286 m
.59841 .05167 L
s
.008 w
.59841 .05167 Mdot
.016 w
.59841 .05167 m
.59547 .05058 L
s
1 .218 0 r
.008 w
.59547 .05058 Mdot
.016 w
.59547 .05058 m
.59297 .04961 L
s
.008 w
.59297 .04961 Mdot
.016 w
.59297 .04961 m
.59064 .04875 L
s
.008 w
.59064 .04875 Mdot
.016 w
.59064 .04875 m
.58867 .04804 L
s
.008 w
.58867 .04804 Mdot
.016 w
.58867 .04804 m
.58688 .04742 L
s
.008 w
.58688 .04742 Mdot
.016 w
.58688 .04742 m
.58529 .04692 L
s
1 .217 0 r
.008 w
.58529 .04692 Mdot
.016 w
.58529 .04692 m
.58391 .04647 L
s
.008 w
.58391 .04647 Mdot
.016 w
.58391 .04647 m
.58271 .04609 L
s
.008 w
.58271 .04609 Mdot
.016 w
.58271 .04609 m
.5817 .04579 L
s
.008 w
.5817 .04579 Mdot
.016 w
.5817 .04579 m
.58091 .04557 L
s
.008 w
.58091 .04557 Mdot
.016 w
.58091 .04557 m
.58033 .04543 L
s
1 .216 0 r
.008 w
.58033 .04543 Mdot
.016 w
.58033 .04543 m
.57987 .04534 L
s
.008 w
.57987 .04534 Mdot
.016 w
.57987 .04534 m
.57952 .04529 L
s
.008 w
.57952 .04529 Mdot
.016 w
.57952 .04529 m
.57925 .04527 L
s
.008 w
.57925 .04527 Mdot
.016 w
.57925 .04527 m
.57903 .04528 L
s
1 .215 0 r
.008 w
.57903 .04528 Mdot
.016 w
.57903 .04528 m
.57887 .04532 L
s
.008 w
.57887 .04532 Mdot
.016 w
.57887 .04532 m
.57876 .04537 L
s
.008 w
.57876 .04537 Mdot
.016 w
.57876 .04537 m
.57871 .04541 L
s
.008 w
.57871 .04541 Mdot
.016 w
.57871 .04541 m
.57872 .04544 L
s
.008 w
.57872 .04544 Mdot
.016 w
.57872 .04544 m
.57875 .04544 L
s
1 .214 0 r
.008 w
.57875 .04544 Mdot
.016 w
.57875 .04544 m
.57882 .04544 L
s
.008 w
.57882 .04544 Mdot
.016 w
.57882 .04544 m
.57889 .04545 L
s
.008 w
.57889 .04545 Mdot
.016 w
.57889 .04545 m
.57895 .04545 L
s
.008 w
.57895 .04545 Mdot
.016 w
.57895 .04545 m
.57897 .04545 L
s
.008 w
.57897 .04545 Mdot
.016 w
.57897 .04545 m
.57898 .04545 L
s
1 .213 0 r
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
1 .212 0 r
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
1 .211 0 r
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
1 .21 0 r
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
1 .209 0 r
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57898 .04545 L
s
.008 w
.57898 .04545 Mdot
.016 w
.57898 .04545 m
.57901 .04545 L
s
1 .208 0 r
.008 w
.57901 .04545 Mdot
.016 w
.57901 .04545 m
.57909 .04545 L
s
.008 w
.57909 .04545 Mdot
.016 w
.57909 .04545 m
.57919 .04546 L
s
.008 w
.57919 .04546 Mdot
.016 w
.57919 .04546 m
.57929 .04546 L
s
.008 w
.57929 .04546 Mdot
.016 w
.57929 .04546 m
.57933 .04546 L
s
.008 w
.57933 .04546 Mdot
.016 w
.57933 .04546 m
.5793 .04546 L
s
1 .207 0 r
.008 w
.5793 .04546 Mdot
.016 w
.5793 .04546 m
.57916 .04545 L
s
.008 w
.57916 .04545 Mdot
.016 w
.57916 .04545 m
.57891 .04544 L
s
.008 w
.57891 .04544 Mdot
.016 w
.57891 .04544 m
.57852 .04543 L
s
.008 w
.57852 .04543 Mdot
.016 w
.57852 .04543 m
.57803 .04541 L
s
1 .206 0 r
.008 w
.57803 .04541 Mdot
.016 w
.57803 .04541 m
.57745 .04539 L
s
.008 w
.57745 .04539 Mdot
.016 w
.57745 .04539 m
.57681 .04537 L
s
.008 w
.57681 .04537 Mdot
.016 w
.57681 .04537 m
.57618 .04535 L
s
.008 w
.57618 .04535 Mdot
.016 w
.57618 .04535 m
.57556 .04533 L
s
.008 w
.57556 .04533 Mdot
.016 w
.57556 .04533 m
.57501 .04531 L
s
1 .205 0 r
.008 w
.57501 .04531 Mdot
.016 w
.57501 .04531 m
.57444 .04529 L
s
.008 w
.57444 .04529 Mdot
.016 w
.57444 .04529 m
.57392 .04527 L
s
.008 w
.57392 .04527 Mdot
.016 w
.57392 .04527 m
.57346 .04526 L
s
.008 w
.57346 .04526 Mdot
.016 w
.57346 .04526 m
.57304 .04525 L
s
.008 w
.57304 .04525 Mdot
.016 w
.57304 .04525 m
.57263 .04524 L
s
1 .204 0 r
.008 w
.57263 .04524 Mdot
.016 w
.57263 .04524 m
.57221 .04522 L
s
.008 w
.57221 .04522 Mdot
.016 w
.57221 .04522 m
.57172 .04521 L
s
.008 w
.57172 .04521 Mdot
.016 w
.57172 .04521 m
.57117 .04519 L
s
.008 w
.57117 .04519 Mdot
.016 w
.57117 .04519 m
.57055 .04517 L
s
.008 w
.57055 .04517 Mdot
.016 w
.57055 .04517 m
.56981 .04514 L
s
1 .203 0 r
.008 w
.56981 .04514 Mdot
.016 w
.56981 .04514 m
.56898 .04511 L
s
.008 w
.56898 .04511 Mdot
.016 w
.56898 .04511 m
.56796 .04508 L
s
.008 w
.56796 .04508 Mdot
.016 w
.56796 .04508 m
.56683 .04504 L
s
.008 w
.56683 .04504 Mdot
.016 w
.56683 .04504 m
.56565 .045 L
s
1 .202 0 r
.008 w
.56565 .045 Mdot
.016 w
.56565 .045 m
.56449 .04496 L
s
.008 w
.56449 .04496 Mdot
.016 w
.56449 .04496 m
.56332 .04493 L
s
.008 w
.56332 .04493 Mdot
.016 w
.56332 .04493 m
.56219 .04489 L
s
.008 w
.56219 .04489 Mdot
.016 w
.56219 .04489 m
.56115 .04486 L
s
.008 w
.56115 .04486 Mdot
.016 w
.56115 .04486 m
.56023 .04483 L
s
1 .201 0 r
.008 w
.56023 .04483 Mdot
.016 w
.56023 .04483 m
.55947 .0448 L
s
.008 w
.55947 .0448 Mdot
.016 w
.55947 .0448 m
.55889 .04479 L
s
.008 w
.55889 .04479 Mdot
.016 w
.55889 .04479 m
.55843 .04477 L
s
.008 w
.55843 .04477 Mdot
.016 w
.55843 .04477 m
.55807 .04476 L
s
.008 w
.55807 .04476 Mdot
.016 w
.55807 .04476 m
.55778 .04475 L
s
1 .2 0 r
.008 w
.55778 .04475 Mdot
.016 w
.55778 .04475 m
.55755 .04474 L
s
.008 w
.55755 .04474 Mdot
.016 w
.55755 .04474 m
.55737 .04474 L
s
.008 w
.55737 .04474 Mdot
.016 w
.55737 .04474 m
.55723 .04473 L
s
.008 w
.55723 .04473 Mdot
.016 w
.55723 .04473 m
.55715 .04473 L
s
.008 w
.55715 .04473 Mdot
.016 w
.55715 .04473 m
.55713 .04473 L
s
1 .199 0 r
.008 w
.55713 .04473 Mdot
.016 w
.55713 .04473 m
.55717 .04473 L
s
.008 w
.55717 .04473 Mdot
.016 w
.55717 .04473 m
.5573 .04473 L
s
.008 w
.5573 .04473 Mdot
.016 w
.5573 .04473 m
.55748 .04474 L
s
.008 w
.55748 .04474 Mdot
.016 w
.55748 .04474 m
.55768 .04475 L
s
1 .198 0 r
.008 w
.55768 .04475 Mdot
.016 w
.55768 .04475 m
.55786 .04475 L
s
.008 w
.55786 .04475 Mdot
.016 w
.55786 .04475 m
.55798 .04476 L
s
.008 w
.55798 .04476 Mdot
.016 w
.55798 .04476 m
.55801 .04476 L
s
.008 w
.55801 .04476 Mdot
.016 w
.55801 .04476 m
.55793 .04476 L
s
.008 w
.55793 .04476 Mdot
.016 w
.55793 .04476 m
.5577 .04475 L
s
1 .197 0 r
.008 w
.5577 .04475 Mdot
.016 w
.5577 .04475 m
.55723 .04474 L
s
.008 w
.55723 .04474 Mdot
.016 w
.55723 .04474 m
.55649 .04472 L
s
.008 w
.55649 .04472 Mdot
.016 w
.55649 .04472 m
.55546 .04469 L
s
.008 w
.55546 .04469 Mdot
.016 w
.55546 .04469 m
.55415 .04465 L
s
.008 w
.55415 .04465 Mdot
.016 w
.55415 .04465 m
.55255 .04459 L
s
1 .196 0 r
.008 w
.55255 .04459 Mdot
.016 w
.55255 .04459 m
.55088 .04454 L
s
.008 w
.55088 .04454 Mdot
.016 w
.55088 .04454 m
.54897 .04447 L
s
.008 w
.54897 .04447 Mdot
.016 w
.54897 .04447 m
.54684 .0444 L
s
.008 w
.54684 .0444 Mdot
.016 w
.54684 .0444 m
.54468 .04433 L
s
.008 w
.54468 .04433 Mdot
.016 w
.54468 .04433 m
.54261 .04425 L
s
1 .195 0 r
.008 w
.54261 .04425 Mdot
.016 w
.54261 .04425 m
.54054 .04419 L
s
.008 w
.54054 .04419 Mdot
.016 w
.54054 .04419 m
.5386 .04413 L
s
.008 w
.5386 .04413 Mdot
.016 w
.5386 .04413 m
.53706 .04407 L
s
.008 w
.53706 .04407 Mdot
.016 w
.53706 .04407 m
.53572 .04403 L
s
.008 w
.53572 .04403 Mdot
.016 w
.53572 .04403 m
.53461 .044 L
s
1 .194 0 r
.008 w
.53461 .044 Mdot
.016 w
.53461 .044 m
.53377 .04397 L
s
.008 w
.53377 .04397 Mdot
.016 w
.53377 .04397 m
.53322 .04395 L
s
.008 w
.53322 .04395 Mdot
.016 w
.53322 .04395 m
.53293 .04392 L
s
.008 w
.53293 .04392 Mdot
.016 w
.53293 .04392 m
.53281 .04386 L
s
1 .193 0 r
.008 w
.53281 .04386 Mdot
.016 w
.53281 .04386 m
.53281 .04379 L
s
.008 w
.53281 .04379 Mdot
.016 w
.53281 .04379 m
.53291 .04372 L
s
.008 w
.53291 .04372 Mdot
.016 w
.53291 .04372 m
.53305 .04366 L
s
.008 w
.53305 .04366 Mdot
.016 w
.53305 .04366 m
.53321 .04364 L
s
.008 w
.53321 .04364 Mdot
.016 w
.53321 .04364 m
.53335 .04369 L
s
1 .192 0 r
.008 w
.53335 .04369 Mdot
.016 w
.53335 .04369 m
.53341 .04385 L
s
.008 w
.53341 .04385 Mdot
.016 w
.53341 .04385 m
.53343 .04412 L
s
.008 w
.53343 .04412 Mdot
.016 w
.53343 .04412 m
.53343 .04453 L
s
.008 w
.53343 .04453 Mdot
.016 w
.53343 .04453 m
.53344 .04505 L
s
.008 w
.53344 .04505 Mdot
.016 w
.53344 .04505 m
.53344 .0457 L
s
1 .191 0 r
.008 w
.53344 .0457 Mdot
.016 w
.53344 .0457 m
.53345 .04645 L
s
.008 w
.53345 .04645 Mdot
.016 w
.53345 .04645 m
.53346 .0472 L
s
.008 w
.53346 .0472 Mdot
.016 w
.53346 .0472 m
.5335 .04799 L
s
.008 w
.5335 .04799 Mdot
.016 w
.5335 .04799 m
.5336 .04877 L
s
.008 w
.5336 .04877 Mdot
.016 w
.5336 .04877 m
.53374 .04952 L
s
1 .19 0 r
.008 w
.53374 .04952 Mdot
.016 w
.53374 .04952 m
.53387 .05016 L
s
.008 w
.53387 .05016 Mdot
.016 w
.53387 .05016 m
.53393 .05077 L
s
.008 w
.53393 .05077 Mdot
.016 w
.53393 .05077 m
.53389 .05133 L
s
.008 w
.53389 .05133 Mdot
.016 w
.53389 .05133 m
.53372 .05182 L
s
1 .189 0 r
.008 w
.53372 .05182 Mdot
.016 w
.53372 .05182 m
.53338 .05227 L
s
.008 w
.53338 .05227 Mdot
.016 w
.53338 .05227 m
.53286 .05275 L
s
.008 w
.53286 .05275 Mdot
.016 w
.53286 .05275 m
.53219 .05327 L
s
.008 w
.53219 .05327 Mdot
.016 w
.53219 .05327 m
.5314 .05382 L
s
.008 w
.5314 .05382 Mdot
.016 w
.5314 .05382 m
.53053 .05441 L
s
1 .188 0 r
.008 w
.53053 .05441 Mdot
.016 w
.53053 .05441 m
.5296 .05503 L
s
.008 w
.5296 .05503 Mdot
.016 w
.5296 .05503 m
.52869 .0556 L
s
.008 w
.52869 .0556 Mdot
.016 w
.52869 .0556 m
.52781 .05622 L
s
.008 w
.52781 .05622 Mdot
.016 w
.52781 .05622 m
.52692 .05685 L
s
.008 w
.52692 .05685 Mdot
.016 w
.52692 .05685 m
.52608 .0575 L
s
1 .187 0 r
.008 w
.52608 .0575 Mdot
.016 w
.52608 .0575 m
.52534 .0581 L
s
.008 w
.52534 .0581 Mdot
.016 w
.52534 .0581 m
.52479 .05864 L
s
.008 w
.52479 .05864 Mdot
.016 w
.52479 .05864 m
.52446 .05899 L
s
.008 w
.52446 .05899 Mdot
.016 w
.52446 .05899 m
.52434 .0592 L
s
.008 w
.52434 .0592 Mdot
.016 w
.52434 .0592 m
.5244 .05923 L
s
1 .186 0 r
.008 w
.5244 .05923 Mdot
.016 w
.5244 .05923 m
.52464 .05906 L
s
.008 w
.52464 .05906 Mdot
.016 w
.52464 .05906 m
.52502 .05873 L
s
.008 w
.52502 .05873 Mdot
.016 w
.52502 .05873 m
.52553 .05828 L
s
.008 w
.52553 .05828 Mdot
.016 w
.52553 .05828 m
.52616 .05777 L
s
1 .185 0 r
.008 w
.52616 .05777 Mdot
.016 w
.52616 .05777 m
.52692 .05724 L
s
.008 w
.52692 .05724 Mdot
.016 w
.52692 .05724 m
.52789 .05673 L
s
.008 w
.52789 .05673 Mdot
.016 w
.52789 .05673 m
.52918 .05624 L
s
.008 w
.52918 .05624 Mdot
.016 w
.52918 .05624 m
.53087 .05582 L
s
.008 w
.53087 .05582 Mdot
.016 w
.53087 .05582 m
.53298 .05546 L
s
1 .184 0 r
.008 w
.53298 .05546 Mdot
.016 w
.53298 .05546 m
.53546 .05518 L
s
.008 w
.53546 .05518 Mdot
.016 w
.53546 .05518 m
.53836 .05502 L
s
.008 w
.53836 .05502 Mdot
.016 w
.53836 .05502 m
.54147 .055 L
s
.008 w
.54147 .055 Mdot
.016 w
.54147 .055 m
.54516 .05513 L
s
.008 w
.54516 .05513 Mdot
.016 w
.54516 .05513 m
.54884 .05541 L
s
1 .183 0 r
.008 w
.54884 .05541 Mdot
.016 w
.54884 .05541 m
.55322 .05591 L
s
.008 w
.55322 .05591 Mdot
.016 w
.55322 .05591 m
.55718 .0566 L
s
.008 w
.55718 .0566 Mdot
.016 w
.55718 .0566 m
.56155 .05746 L
s
.008 w
.56155 .05746 Mdot
.016 w
.56155 .05746 m
.5662 .05835 L
s
.008 w
.5662 .05835 Mdot
.016 w
.5662 .05835 m
.57052 .05936 L
s
1 .182 0 r
.008 w
.57052 .05936 Mdot
.016 w
.57052 .05936 m
.57444 .06042 L
s
.008 w
.57444 .06042 Mdot
.016 w
.57444 .06042 m
.57843 .06149 L
s
.008 w
.57843 .06149 Mdot
.016 w
.57843 .06149 m
.58219 .06252 L
s
.008 w
.58219 .06252 Mdot
.016 w
.58219 .06252 m
.58575 .06349 L
s
.008 w
.58575 .06349 Mdot
.016 w
.58575 .06349 m
.58911 .06441 L
s
1 .181 0 r
.008 w
.58911 .06441 Mdot
.016 w
.58911 .06441 m
.59238 .06521 L
s
.008 w
.59238 .06521 Mdot
.016 w
.59238 .06521 m
.59568 .06582 L
s
.008 w
.59568 .06582 Mdot
.016 w
.59568 .06582 m
.59885 .06627 L
s
.008 w
.59885 .06627 Mdot
.016 w
.59885 .06627 m
.60227 .0666 L
s
1 .18 0 r
.008 w
.60227 .0666 Mdot
.016 w
.60227 .0666 m
.60576 .06681 L
s
.008 w
.60576 .06681 Mdot
.016 w
.60576 .06681 m
.60948 .06697 L
s
.008 w
.60948 .06697 Mdot
.016 w
.60948 .06697 m
.61351 .06714 L
s
.008 w
.61351 .06714 Mdot
.016 w
.61351 .06714 m
.61768 .06737 L
s
.008 w
.61768 .06737 Mdot
.016 w
.61768 .06737 m
.6219 .06771 L
s
1 .179 0 r
.008 w
.6219 .06771 Mdot
.016 w
.6219 .06771 m
.62692 .06819 L
s
.008 w
.62692 .06819 Mdot
.016 w
.62692 .06819 m
.63115 .06885 L
s
.008 w
.63115 .06885 Mdot
.016 w
.63115 .06885 m
.63605 .06974 L
s
.008 w
.63605 .06974 Mdot
.016 w
.63605 .06974 m
.64119 .0709 L
s
.008 w
.64119 .0709 Mdot
.016 w
.64119 .0709 m
.6471 .07218 L
s
1 .178 0 r
.008 w
.6471 .07218 Mdot
.016 w
.6471 .07218 m
.65185 .07377 L
s
.008 w
.65185 .07377 Mdot
.016 w
.65185 .07377 m
.65755 .07558 L
s
.008 w
.65755 .07558 Mdot
.016 w
.65755 .07558 m
.66309 .07756 L
s
.008 w
.66309 .07756 Mdot
.016 w
.66309 .07756 m
.66875 .07958 L
s
.008 w
.66875 .07958 Mdot
.016 w
.66875 .07958 m
.6741 .08186 L
s
1 .177 0 r
.008 w
.6741 .08186 Mdot
.016 w
.6741 .08186 m
.67954 .08396 L
s
.008 w
.67954 .08396 Mdot
.016 w
.67954 .08396 m
.68474 .08623 L
s
.008 w
.68474 .08623 Mdot
.016 w
.68474 .08623 m
.68914 .08826 L
s
.008 w
.68914 .08826 Mdot
.016 w
.68914 .08826 m
.6936 .09023 L
s
1 .176 0 r
.008 w
.6936 .09023 Mdot
.016 w
.6936 .09023 m
.69779 .09213 L
s
.008 w
.69779 .09213 Mdot
.016 w
.69779 .09213 m
.70126 .0937 L
s
.008 w
.70126 .0937 Mdot
.016 w
.70126 .0937 m
.70411 .0951 L
s
.008 w
.70411 .0951 Mdot
.016 w
.70411 .0951 m
.70675 .09633 L
s
.008 w
.70675 .09633 Mdot
.016 w
.70675 .09633 m
.7087 .09733 L
s
1 .175 0 r
.008 w
.7087 .09733 Mdot
.016 w
.7087 .09733 m
.71025 .0981 L
s
.008 w
.71025 .0981 Mdot
.016 w
.71025 .0981 m
.71133 .09868 L
s
.008 w
.71133 .09868 Mdot
.016 w
.71133 .09868 m
.71195 .09907 L
s
.008 w
.71195 .09907 Mdot
.016 w
.71195 .09907 m
.71226 .09931 L
s
.008 w
.71226 .09931 Mdot
.016 w
.71226 .09931 m
.71236 .09945 L
s
1 .174 0 r
.008 w
.71236 .09945 Mdot
.016 w
.71236 .09945 m
.71235 .09951 L
s
.008 w
.71235 .09951 Mdot
.016 w
.71235 .09951 m
.7123 .09951 L
s
.008 w
.7123 .09951 Mdot
.016 w
.7123 .09951 m
.71223 .09947 L
s
.008 w
.71223 .09947 Mdot
.016 w
.71223 .09947 m
.71221 .09942 L
s
.008 w
.71221 .09942 Mdot
.016 w
.71221 .09942 m
.71226 .09935 L
s
1 .173 0 r
.008 w
.71226 .09935 Mdot
.016 w
.71226 .09935 m
.71234 .09929 L
s
.008 w
.71234 .09929 Mdot
.016 w
.71234 .09929 m
.71245 .09925 L
s
.008 w
.71245 .09925 Mdot
.016 w
.71245 .09925 m
.71258 .09924 L
s
.008 w
.71258 .09924 Mdot
.016 w
.71258 .09924 m
.71275 .09923 L
s
.008 w
.71275 .09923 Mdot
.016 w
.71275 .09923 m
.71295 .09922 L
s
1 .172 0 r
.008 w
.71295 .09922 Mdot
.016 w
.71295 .09922 m
.7132 .0992 L
s
.008 w
.7132 .0992 Mdot
.016 w
.7132 .0992 m
.71349 .0992 L
s
.008 w
.71349 .0992 Mdot
.016 w
.71349 .0992 m
.71382 .0992 L
s
.008 w
.71382 .0992 Mdot
.016 w
.71382 .0992 m
.71414 .09922 L
s
1 .171 0 r
.008 w
.71414 .09922 Mdot
.016 w
.71414 .09922 m
.71446 .09923 L
s
.008 w
.71446 .09923 Mdot
.016 w
.71446 .09923 m
.71477 .09924 L
s
.008 w
.71477 .09924 Mdot
.016 w
.71477 .09924 m
.71507 .09929 L
s
.008 w
.71507 .09929 Mdot
.016 w
.71507 .09929 m
.71538 .09939 L
s
.008 w
.71538 .09939 Mdot
.016 w
.71538 .09939 m
.7157 .09956 L
s
1 .17 0 r
.008 w
.7157 .09956 Mdot
.016 w
.7157 .09956 m
.71609 .09982 L
s
.008 w
.71609 .09982 Mdot
.016 w
.71609 .09982 m
.71658 .10021 L
s
.008 w
.71658 .10021 Mdot
.016 w
.71658 .10021 m
.71722 .10074 L
s
.008 w
.71722 .10074 Mdot
.016 w
.71722 .10074 m
.71806 .10144 L
s
.008 w
.71806 .10144 Mdot
.016 w
.71806 .10144 m
.71915 .10235 L
s
1 .169 0 r
.008 w
.71915 .10235 Mdot
.016 w
.71915 .10235 m
.72049 .10346 L
s
.008 w
.72049 .10346 Mdot
.016 w
.72049 .10346 m
.72217 .10476 L
s
.008 w
.72217 .10476 Mdot
.016 w
.72217 .10476 m
.72409 .10605 L
s
.008 w
.72409 .10605 Mdot
.016 w
.72409 .10605 m
.72638 .10762 L
s
.008 w
.72638 .10762 Mdot
.016 w
.72638 .10762 m
.7291 .10916 L
s
1 .168 0 r
.008 w
.7291 .10916 Mdot
.016 w
.7291 .10916 m
.73196 .11086 L
s
.008 w
.73196 .11086 Mdot
.016 w
.73196 .11086 m
.7352 .1126 L
s
.008 w
.7352 .1126 Mdot
.016 w
.7352 .1126 m
.73878 .11444 L
s
.008 w
.73878 .11444 Mdot
.016 w
.73878 .11444 m
.7425 .11621 L
s
1 .167 0 r
.008 w
.7425 .11621 Mdot
.016 w
.7425 .11621 m
.7465 .11812 L
s
.008 w
.7465 .11812 Mdot
.016 w
.7465 .11812 m
.75035 .11984 L
s
.008 w
.75035 .11984 Mdot
.016 w
.75035 .11984 m
.75433 .12156 L
s
.008 w
.75433 .12156 Mdot
.016 w
.75433 .12156 m
.75843 .12324 L
s
.008 w
.75843 .12324 Mdot
.016 w
.75843 .12324 m
.76188 .1247 L
s
1 .166 0 r
.008 w
.76188 .1247 Mdot
.016 w
.76188 .1247 m
.76527 .12607 L
s
.008 w
.76527 .12607 Mdot
.016 w
.76527 .12607 m
.76827 .1273 L
s
.008 w
.76827 .1273 Mdot
.016 w
.76827 .1273 m
.77091 .12838 L
s
.008 w
.77091 .12838 Mdot
.016 w
.77091 .12838 m
.77326 .1293 L
s
.008 w
.77326 .1293 Mdot
.016 w
.77326 .1293 m
.77515 .13004 L
s
1 .165 0 r
.008 w
.77515 .13004 Mdot
.016 w
.77515 .13004 m
.77668 .13069 L
s
.008 w
.77668 .13069 Mdot
.016 w
.77668 .13069 m
.77796 .13127 L
s
.008 w
.77796 .13127 Mdot
.016 w
.77796 .13127 m
.77897 .13177 L
s
.008 w
.77897 .13177 Mdot
.016 w
.77897 .13177 m
.77972 .13221 L
s
.008 w
.77972 .13221 Mdot
.016 w
.77972 .13221 m
.78028 .13259 L
s
1 .164 0 r
.008 w
.78028 .13259 Mdot
.016 w
.78028 .13259 m
.7807 .13294 L
s
.008 w
.7807 .13294 Mdot
.016 w
.7807 .13294 m
.781 .13327 L
s
.008 w
.781 .13327 Mdot
.016 w
.781 .13327 m
.78125 .1336 L
s
.008 w
.78125 .1336 Mdot
.016 w
.78125 .1336 m
.78145 .13395 L
s
1 .163 0 r
.008 w
.78145 .13395 Mdot
.016 w
.78145 .13395 m
.78165 .13428 L
s
.008 w
.78165 .13428 Mdot
.016 w
.78165 .13428 m
.78189 .13463 L
s
.008 w
.78189 .13463 Mdot
.016 w
.78189 .13463 m
.7822 .13499 L
s
.008 w
.7822 .13499 Mdot
.016 w
.7822 .13499 m
.78254 .13533 L
s
.008 w
.78254 .13533 Mdot
.016 w
.78254 .13533 m
.78286 .13563 L
s
1 .162 0 r
.008 w
.78286 .13563 Mdot
.016 w
.78286 .13563 m
.78315 .13586 L
s
.008 w
.78315 .13586 Mdot
.016 w
.78315 .13586 m
.78341 .13601 L
s
.008 w
.78341 .13601 Mdot
.016 w
.78341 .13601 m
.78364 .1361 L
s
.008 w
.78364 .1361 Mdot
.016 w
.78364 .1361 m
.78386 .13616 L
s
.008 w
.78386 .13616 Mdot
.016 w
.78386 .13616 m
.78409 .13623 L
s
1 .161 0 r
.008 w
.78409 .13623 Mdot
.016 w
.78409 .13623 m
.78437 .13634 L
s
.008 w
.78437 .13634 Mdot
.016 w
.78437 .13634 m
.78474 .13655 L
s
.008 w
.78474 .13655 Mdot
.016 w
.78474 .13655 m
.78519 .13686 L
s
.008 w
.78519 .13686 Mdot
.016 w
.78519 .13686 m
.78575 .1373 L
s
.008 w
.78575 .1373 Mdot
.016 w
.78575 .1373 m
.78637 .13783 L
s
1 .16 0 r
.008 w
.78637 .13783 Mdot
.016 w
.78637 .13783 m
.78705 .13841 L
s
.008 w
.78705 .13841 Mdot
.016 w
.78705 .13841 m
.78777 .13903 L
s
.008 w
.78777 .13903 Mdot
.016 w
.78777 .13903 m
.7885 .13966 L
s
.008 w
.7885 .13966 Mdot
.016 w
.7885 .13966 m
.78921 .14027 L
s
.008 w
.78921 .14027 Mdot
.016 w
.78921 .14027 m
.7899 .14083 L
s
1 .159 0 r
.008 w
.7899 .14083 Mdot
.016 w
.7899 .14083 m
.79055 .14134 L
s
.008 w
.79055 .14134 Mdot
.016 w
.79055 .14134 m
.79115 .14179 L
s
.008 w
.79115 .14179 Mdot
.016 w
.79115 .14179 m
.7917 .14216 L
s
.008 w
.7917 .14216 Mdot
.016 w
.7917 .14216 m
.79216 .14243 L
s
1 .158 0 r
.008 w
.79216 .14243 Mdot
.016 w
.79216 .14243 m
.79256 .1426 L
s
.008 w
.79256 .1426 Mdot
.016 w
.79256 .1426 m
.79286 .14266 L
s
.008 w
.79286 .14266 Mdot
.016 w
.79286 .14266 m
.79308 .14263 L
s
.008 w
.79308 .14263 Mdot
.016 w
.79308 .14263 m
.79322 .14253 L
s
.008 w
.79322 .14253 Mdot
.016 w
.79322 .14253 m
.79327 .14239 L
s
1 .157 0 r
.008 w
.79327 .14239 Mdot
.016 w
.79327 .14239 m
.79323 .14225 L
s
.008 w
.79323 .14225 Mdot
.016 w
.79323 .14225 m
.79312 .14212 L
s
.008 w
.79312 .14212 Mdot
.016 w
.79312 .14212 m
.79299 .14205 L
s
.008 w
.79299 .14205 Mdot
.016 w
.79299 .14205 m
.79286 .14204 L
s
.008 w
.79286 .14204 Mdot
.016 w
.79286 .14204 m
.79277 .14211 L
s
1 .156 0 r
.008 w
.79277 .14211 Mdot
.016 w
.79277 .14211 m
.79275 .14229 L
s
.008 w
.79275 .14229 Mdot
.016 w
.79275 .14229 m
.79284 .14261 L
s
.008 w
.79284 .14261 Mdot
.016 w
.79284 .14261 m
.79305 .14311 L
s
.008 w
.79305 .14311 Mdot
.016 w
.79305 .14311 m
.79343 .14387 L
s
.008 w
.79343 .14387 Mdot
.016 w
.79343 .14387 m
.79399 .14497 L
s
1 .155 0 r
.008 w
.79399 .14497 Mdot
.016 w
.79399 .14497 m
.79474 .14638 L
s
.008 w
.79474 .14638 Mdot
.016 w
.79474 .14638 m
.79574 .14818 L
s
.008 w
.79574 .14818 Mdot
.016 w
.79574 .14818 m
.79692 .15023 L
s
.008 w
.79692 .15023 Mdot
.016 w
.79692 .15023 m
.79841 .15253 L
s
1 .154 0 r
.008 w
.79841 .15253 Mdot
.016 w
.79841 .15253 m
.80012 .1553 L
s
.008 w
.80012 .1553 Mdot
.016 w
.80012 .1553 m
.80205 .15802 L
s
.008 w
.80205 .15802 Mdot
.016 w
.80205 .15802 m
.8041 .16095 L
s
.008 w
.8041 .16095 Mdot
.016 w
.8041 .16095 m
.80634 .16385 L
s
.008 w
.80634 .16385 Mdot
.016 w
.80634 .16385 m
.8084 .16661 L
s
1 .153 0 r
.008 w
.8084 .16661 Mdot
.016 w
.8084 .16661 m
.81056 .16949 L
s
.008 w
.81056 .16949 Mdot
.016 w
.81056 .16949 m
.81241 .17199 L
s
.008 w
.81241 .17199 Mdot
.016 w
.81241 .17199 m
.81417 .17396 L
s
.008 w
.81417 .17396 Mdot
.016 w
.81417 .17396 m
.81574 .17579 L
s
.008 w
.81574 .17579 Mdot
.016 w
.81574 .17579 m
.81708 .17743 L
s
1 .152 0 r
.008 w
.81708 .17743 Mdot
.016 w
.81708 .17743 m
.81814 .17871 L
s
.008 w
.81814 .17871 Mdot
.016 w
.81814 .17871 m
.81898 .17963 L
s
.008 w
.81898 .17963 Mdot
.016 w
.81898 .17963 m
.8196 .18021 L
s
.008 w
.8196 .18021 Mdot
.016 w
.8196 .18021 m
.81999 .18051 L
s
.008 w
.81999 .18051 Mdot
.016 w
.81999 .18051 m
.82019 .18059 L
s
1 .151 0 r
.008 w
.82019 .18059 Mdot
.016 w
.82019 .18059 m
.82024 .18056 L
s
.008 w
.82024 .18056 Mdot
.016 w
.82024 .18056 m
.8202 .18046 L
s
.008 w
.8202 .18046 Mdot
.016 w
.8202 .18046 m
.82011 .1803 L
s
.008 w
.82011 .1803 Mdot
.016 w
.82011 .1803 m
.82001 .18019 L
s
1 .15 0 r
.008 w
.82001 .18019 Mdot
.016 w
.82001 .18019 m
.81989 .18017 L
s
.008 w
.81989 .18017 Mdot
.016 w
.81989 .18017 m
.81977 .18017 L
s
.008 w
.81977 .18017 Mdot
.016 w
.81977 .18017 m
.81967 .18016 L
s
.008 w
.81967 .18016 Mdot
.016 w
.81967 .18016 m
.8196 .18014 L
s
.008 w
.8196 .18014 Mdot
.016 w
.8196 .18014 m
.81956 .18011 L
s
1 .149 0 r
.008 w
.81956 .18011 Mdot
.016 w
.81956 .18011 m
.81952 .18006 L
s
.008 w
.81952 .18006 Mdot
.016 w
.81952 .18006 m
.8195 .18002 L
s
.008 w
.8195 .18002 Mdot
.016 w
.8195 .18002 m
.81952 .17995 L
s
.008 w
.81952 .17995 Mdot
.016 w
.81952 .17995 m
.81948 .17992 L
s
.008 w
.81948 .17992 Mdot
.016 w
.81948 .17992 m
.81942 .17991 L
s
1 .148 0 r
.008 w
.81942 .17991 Mdot
.016 w
.81942 .17991 m
.81934 .17992 L
s
.008 w
.81934 .17992 Mdot
.016 w
.81934 .17992 m
.81923 .17994 L
s
.008 w
.81923 .17994 Mdot
.016 w
.81923 .17994 m
.8191 .17992 L
s
.008 w
.8191 .17992 Mdot
.016 w
.8191 .17992 m
.81895 .17988 L
s
.008 w
.81895 .17988 Mdot
.016 w
.81895 .17988 m
.8188 .17981 L
s
1 .147 0 r
.008 w
.8188 .17981 Mdot
.016 w
.8188 .17981 m
.81864 .17972 L
s
.008 w
.81864 .17972 Mdot
.016 w
.81864 .17972 m
.8185 .17966 L
s
.008 w
.8185 .17966 Mdot
.016 w
.8185 .17966 m
.81834 .1796 L
s
.008 w
.81834 .1796 Mdot
.016 w
.81834 .1796 m
.81817 .17956 L
s
.008 w
.81817 .17956 Mdot
.016 w
.81817 .17956 m
.818 .17954 L
s
1 .146 0 r
.008 w
.818 .17954 Mdot
.016 w
.818 .17954 m
.81783 .17954 L
s
.008 w
.81783 .17954 Mdot
.016 w
.81783 .17954 m
.81769 .17953 L
s
.008 w
.81769 .17953 Mdot
.016 w
.81769 .17953 m
.81759 .1795 L
s
.008 w
.81759 .1795 Mdot
.016 w
.81759 .1795 m
.81756 .17943 L
s
1 .145 0 r
.008 w
.81756 .17943 Mdot
.016 w
.81756 .17943 m
.81761 .17935 L
s
.008 w
.81761 .17935 Mdot
.016 w
.81761 .17935 m
.81772 .17928 L
s
.008 w
.81772 .17928 Mdot
.016 w
.81772 .17928 m
.81787 .17924 L
s
.008 w
.81787 .17924 Mdot
.016 w
.81787 .17924 m
.81804 .17923 L
s
.008 w
.81804 .17923 Mdot
.016 w
.81804 .17923 m
.81821 .17926 L
s
1 .144 0 r
.008 w
.81821 .17926 Mdot
.016 w
.81821 .17926 m
.81838 .17931 L
s
.008 w
.81838 .17931 Mdot
.016 w
.81838 .17931 m
.81854 .17942 L
s
.008 w
.81854 .17942 Mdot
.016 w
.81854 .17942 m
.81874 .17962 L
s
.008 w
.81874 .17962 Mdot
.016 w
.81874 .17962 m
.81898 .17992 L
s
.008 w
.81898 .17992 Mdot
.016 w
.81898 .17992 m
.81927 .18036 L
s
1 .143 0 r
.008 w
.81927 .18036 Mdot
.016 w
.81927 .18036 m
.81963 .18099 L
s
.008 w
.81963 .18099 Mdot
.016 w
.81963 .18099 m
.82004 .18181 L
s
.008 w
.82004 .18181 Mdot
.016 w
.82004 .18181 m
.82051 .1828 L
s
.008 w
.82051 .1828 Mdot
.016 w
.82051 .1828 m
.82106 .18398 L
s
.008 w
.82106 .18398 Mdot
.016 w
.82106 .18398 m
.82163 .18535 L
s
1 .142 0 r
.008 w
.82163 .18535 Mdot
.016 w
.82163 .18535 m
.82228 .18688 L
s
.008 w
.82228 .18688 Mdot
.016 w
.82228 .18688 m
.82297 .18828 L
s
.008 w
.82297 .18828 Mdot
.016 w
.82297 .18828 m
.82366 .18981 L
s
.008 w
.82366 .18981 Mdot
.016 w
.82366 .18981 m
.8244 .19137 L
s
1 .141 0 r
.008 w
.8244 .19137 Mdot
.016 w
.8244 .19137 m
.82511 .19274 L
s
.008 w
.82511 .19274 Mdot
.016 w
.82511 .19274 m
.82581 .19406 L
s
.008 w
.82581 .19406 Mdot
.016 w
.82581 .19406 m
.82646 .1953 L
s
.008 w
.82646 .1953 Mdot
.016 w
.82646 .1953 m
.82702 .19632 L
s
.008 w
.82702 .19632 Mdot
.016 w
.82702 .19632 m
.82749 .19718 L
s
1 .14 0 r
.008 w
.82749 .19718 Mdot
.016 w
.82749 .19718 m
.82784 .19785 L
s
.008 w
.82784 .19785 Mdot
.016 w
.82784 .19785 m
.82808 .19831 L
s
.008 w
.82808 .19831 Mdot
.016 w
.82808 .19831 m
.82822 .19853 L
s
.008 w
.82822 .19853 Mdot
.016 w
.82822 .19853 m
.82824 .19853 L
s
.008 w
.82824 .19853 Mdot
.016 w
.82824 .19853 m
.82817 .19834 L
s
1 .139 0 r
.008 w
.82817 .19834 Mdot
.016 w
.82817 .19834 m
.82801 .19801 L
s
.008 w
.82801 .19801 Mdot
.016 w
.82801 .19801 m
.82779 .19757 L
s
.008 w
.82779 .19757 Mdot
.016 w
.82779 .19757 m
.82754 .19703 L
s
.008 w
.82754 .19703 Mdot
.016 w
.82754 .19703 m
.82725 .1964 L
s
.008 w
.82725 .1964 Mdot
.016 w
.82725 .1964 m
.82694 .19569 L
s
1 .138 0 r
.008 w
.82694 .19569 Mdot
.016 w
.82694 .19569 m
.82661 .19492 L
s
.008 w
.82661 .19492 Mdot
.016 w
.82661 .19492 m
.82625 .19407 L
s
.008 w
.82625 .19407 Mdot
.016 w
.82625 .19407 m
.82585 .19311 L
s
.008 w
.82585 .19311 Mdot
.016 w
.82585 .19311 m
.82534 .192 L
s
1 .137 0 r
.008 w
.82534 .192 Mdot
.016 w
.82534 .192 m
.82477 .19081 L
s
.008 w
.82477 .19081 Mdot
.016 w
.82477 .19081 m
.82407 .18946 L
s
.008 w
.82407 .18946 Mdot
.016 w
.82407 .18946 m
.82322 .18793 L
s
.008 w
.82322 .18793 Mdot
.016 w
.82322 .18793 m
.82219 .18619 L
s
.008 w
.82219 .18619 Mdot
.016 w
.82219 .18619 m
.82109 .18432 L
s
1 .136 0 r
.008 w
.82109 .18432 Mdot
.016 w
.82109 .18432 m
.81975 .18221 L
s
.008 w
.81975 .18221 Mdot
.016 w
.81975 .18221 m
.81838 .17995 L
s
.008 w
.81838 .17995 Mdot
.016 w
.81838 .17995 m
.81677 .17734 L
s
.008 w
.81677 .17734 Mdot
.016 w
.81677 .17734 m
.81505 .17459 L
s
.008 w
.81505 .17459 Mdot
.016 w
.81505 .17459 m
.81316 .17179 L
s
1 .135 0 r
.008 w
.81316 .17179 Mdot
.016 w
.81316 .17179 m
.81124 .169 L
s
.008 w
.81124 .169 Mdot
.016 w
.81124 .169 m
.80938 .16615 L
s
.008 w
.80938 .16615 Mdot
.016 w
.80938 .16615 m
.80751 .16336 L
s
.008 w
.80751 .16336 Mdot
.016 w
.80751 .16336 m
.80566 .16044 L
s
.008 w
.80566 .16044 Mdot
.016 w
.80566 .16044 m
.80411 .15814 L
s
1 .134 0 r
.008 w
.80411 .15814 Mdot
.016 w
.80411 .15814 m
.80259 .15584 L
s
.008 w
.80259 .15584 Mdot
.016 w
.80259 .15584 m
.80125 .15387 L
s
.008 w
.80125 .15387 Mdot
.016 w
.80125 .15387 m
.79994 .15204 L
s
.008 w
.79994 .15204 Mdot
.016 w
.79994 .15204 m
.7989 .15065 L
s
.008 w
.7989 .15065 Mdot
.016 w
.7989 .15065 m
.79794 .1495 L
s
1 .133 0 r
.008 w
.79794 .1495 Mdot
.016 w
.79794 .1495 m
.79707 .14861 L
s
.008 w
.79707 .14861 Mdot
.016 w
.79707 .14861 m
.79629 .14799 L
s
.008 w
.79629 .14799 Mdot
.016 w
.79629 .14799 m
.79562 .1476 L
s
.008 w
.79562 .1476 Mdot
.016 w
.79562 .1476 m
.79505 .14741 L
s
1 .132 0 r
.008 w
.79505 .14741 Mdot
.016 w
.79505 .14741 m
.79461 .14736 L
s
.008 w
.79461 .14736 Mdot
.016 w
.79461 .14736 m
.79423 .14741 L
s
.008 w
.79423 .14741 Mdot
.016 w
.79423 .14741 m
.79392 .14751 L
s
.008 w
.79392 .14751 Mdot
.016 w
.79392 .14751 m
.79366 .14763 L
s
.008 w
.79366 .14763 Mdot
.016 w
.79366 .14763 m
.79346 .14777 L
s
1 .131 0 r
.008 w
.79346 .14777 Mdot
.016 w
.79346 .14777 m
.7933 .1479 L
s
.008 w
.7933 .1479 Mdot
.016 w
.7933 .1479 m
.79318 .148 L
s
.008 w
.79318 .148 Mdot
.016 w
.79318 .148 m
.79312 .1481 L
s
.008 w
.79312 .1481 Mdot
.016 w
.79312 .1481 m
.79311 .1482 L
s
.008 w
.79311 .1482 Mdot
.016 w
.79311 .1482 m
.79315 .14829 L
s
1 .13 0 r
.008 w
.79315 .14829 Mdot
.016 w
.79315 .14829 m
.79321 .14838 L
s
.008 w
.79321 .14838 Mdot
.016 w
.79321 .14838 m
.79328 .14843 L
s
.008 w
.79328 .14843 Mdot
.016 w
.79328 .14843 m
.79332 .14844 L
s
.008 w
.79332 .14844 Mdot
.016 w
.79332 .14844 m
.79337 .14841 L
s
.008 w
.79337 .14841 Mdot
.016 w
.79337 .14841 m
.79344 .14835 L
s
1 .129 0 r
.008 w
.79344 .14835 Mdot
.016 w
.79344 .14835 m
.79354 .14828 L
s
.008 w
.79354 .14828 Mdot
.016 w
.79354 .14828 m
.79363 .14823 L
s
.008 w
.79363 .14823 Mdot
.016 w
.79363 .14823 m
.79367 .14819 L
s
.008 w
.79367 .14819 Mdot
.016 w
.79367 .14819 m
.79366 .14819 L
s
1 .128 0 r
.008 w
.79366 .14819 Mdot
.016 w
.79366 .14819 m
.79357 .14825 L
s
.008 w
.79357 .14825 Mdot
.016 w
.79357 .14825 m
.79336 .1484 L
s
.008 w
.79336 .1484 Mdot
.016 w
.79336 .1484 m
.793 .14867 L
s
.008 w
.793 .14867 Mdot
.016 w
.793 .14867 m
.7925 .14904 L
s
.008 w
.7925 .14904 Mdot
.016 w
.7925 .14904 m
.79187 .14954 L
s
1 .127 0 r
.008 w
.79187 .14954 Mdot
.016 w
.79187 .14954 m
.79115 .15017 L
s
.008 w
.79115 .15017 Mdot
.016 w
.79115 .15017 m
.79034 .15093 L
s
.008 w
.79034 .15093 Mdot
.016 w
.79034 .15093 m
.78954 .15171 L
s
.008 w
.78954 .15171 Mdot
.016 w
.78954 .15171 m
.78872 .15254 L
s
.008 w
.78872 .15254 Mdot
.016 w
.78872 .15254 m
.78785 .15339 L
s
1 .126 0 r
.008 w
.78785 .15339 Mdot
.016 w
.78785 .15339 m
.78695 .15421 L
s
.008 w
.78695 .15421 Mdot
.016 w
.78695 .15421 m
.78613 .15491 L
s
.008 w
.78613 .15491 Mdot
.016 w
.78613 .15491 m
.78542 .1555 L
s
.008 w
.78542 .1555 Mdot
.016 w
.78542 .1555 m
.78485 .15592 L
s
.008 w
.78485 .15592 Mdot
.016 w
.78485 .15592 m
.78449 .15614 L
s
1 .125 0 r
.008 w
.78449 .15614 Mdot
.016 w
.78449 .15614 m
.78422 .15612 L
s
.008 w
.78422 .15612 Mdot
.016 w
.78422 .15612 m
.78404 .15586 L
s
.008 w
.78404 .15586 Mdot
.016 w
.78404 .15586 m
.78392 .15533 L
s
.008 w
.78392 .15533 Mdot
.016 w
.78392 .15533 m
.78383 .15452 L
s
.008 w
.78383 .15452 Mdot
.016 w
.78383 .15452 m
.78367 .15352 L
s
1 .124 0 r
.008 w
.78367 .15352 Mdot
.016 w
.78367 .15352 m
.78338 .15229 L
s
.008 w
.78338 .15229 Mdot
.016 w
.78338 .15229 m
.78293 .15078 L
s
.008 w
.78293 .15078 Mdot
.016 w
.78293 .15078 m
.78234 .14909 L
s
.008 w
.78234 .14909 Mdot
.016 w
.78234 .14909 m
.7816 .14717 L
s
1 .123 0 r
.008 w
.7816 .14717 Mdot
.016 w
.7816 .14717 m
.78072 .14509 L
s
.008 w
.78072 .14509 Mdot
.016 w
.78072 .14509 m
.77985 .14288 L
s
.008 w
.77985 .14288 Mdot
.016 w
.77985 .14288 m
.77877 .14051 L
s
.008 w
.77877 .14051 Mdot
.016 w
.77877 .14051 m
.7776 .13817 L
s
.008 w
.7776 .13817 Mdot
.016 w
.7776 .13817 m
.7764 .13579 L
s
1 .122 0 r
.008 w
.7764 .13579 Mdot
.016 w
.7764 .13579 m
.77517 .13342 L
s
.008 w
.77517 .13342 Mdot
.016 w
.77517 .13342 m
.774 .13123 L
s
.008 w
.774 .13123 Mdot
.016 w
.774 .13123 m
.7728 .12915 L
s
.008 w
.7728 .12915 Mdot
.016 w
.7728 .12915 m
.77168 .12717 L
s
.008 w
.77168 .12717 Mdot
.016 w
.77168 .12717 m
.77059 .12563 L
s
1 .121 0 r
.008 w
.77059 .12563 Mdot
.016 w
.77059 .12563 m
.76956 .12427 L
s
.008 w
.76956 .12427 Mdot
.016 w
.76956 .12427 m
.7686 .12314 L
s
.008 w
.7686 .12314 Mdot
.016 w
.7686 .12314 m
.76778 .12228 L
s
.008 w
.76778 .12228 Mdot
.016 w
.76778 .12228 m
.76698 .12167 L
s
.008 w
.76698 .12167 Mdot
.016 w
.76698 .12167 m
.76622 .12127 L
s
1 .12 0 r
.008 w
.76622 .12127 Mdot
.016 w
.76622 .12127 m
.76552 .12104 L
s
.008 w
.76552 .12104 Mdot
.016 w
.76552 .12104 m
.76488 .12094 L
s
.008 w
.76488 .12094 Mdot
.016 w
.76488 .12094 m
.7643 .12093 L
s
.008 w
.7643 .12093 Mdot
.016 w
.7643 .12093 m
.76378 .12096 L
s
1 .119 0 r
.008 w
.76378 .12096 Mdot
.016 w
.76378 .12096 m
.76335 .12103 L
s
.008 w
.76335 .12103 Mdot
.016 w
.76335 .12103 m
.76302 .12109 L
s
.008 w
.76302 .12109 Mdot
.016 w
.76302 .12109 m
.7628 .12114 L
s
.008 w
.7628 .12114 Mdot
.016 w
.7628 .12114 m
.76268 .12117 L
s
.008 w
.76268 .12117 Mdot
.016 w
.76268 .12117 m
.76263 .12121 L
s
1 .118 0 r
.008 w
.76263 .12121 Mdot
.016 w
.76263 .12121 m
.76265 .12123 L
s
.008 w
.76265 .12123 Mdot
.016 w
.76265 .12123 m
.7627 .12125 L
s
.008 w
.7627 .12125 Mdot
.016 w
.7627 .12125 m
.76276 .12125 L
s
.008 w
.76276 .12125 Mdot
.016 w
.76276 .12125 m
.76283 .12126 L
s
.008 w
.76283 .12126 Mdot
.016 w
.76283 .12126 m
.76288 .12126 L
s
1 .117 0 r
.008 w
.76288 .12126 Mdot
.016 w
.76288 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .116 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .115 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .114 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .113 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .112 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
1 .111 0 r
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76291 .12126 L
s
.008 w
.76291 .12126 Mdot
.016 w
.76291 .12126 m
.76292 .12126 L
s
1 .11 0 r
.008 w
.76292 .12126 Mdot
.016 w
.76292 .12126 m
.76295 .12126 L
s
.008 w
.76295 .12126 Mdot
.016 w
.76295 .12126 m
.76302 .12126 L
s
.008 w
.76302 .12126 Mdot
.016 w
.76302 .12126 m
.76312 .12127 L
s
.008 w
.76312 .12127 Mdot
.016 w
.76312 .12127 m
.76321 .12129 L
s
.008 w
.76321 .12129 Mdot
.016 w
.76321 .12129 m
.76328 .12133 L
s
1 .109 0 r
.008 w
.76328 .12133 Mdot
.016 w
.76328 .12133 m
.76327 .12139 L
s
.008 w
.76327 .12139 Mdot
.016 w
.76327 .12139 m
.76317 .12144 L
s
.008 w
.76317 .12144 Mdot
.016 w
.76317 .12144 m
.76297 .12145 L
s
.008 w
.76297 .12145 Mdot
.016 w
.76297 .12145 m
.76264 .12138 L
s
.008 w
.76264 .12138 Mdot
.016 w
.76264 .12138 m
.76219 .12123 L
s
1 .108 0 r
.008 w
.76219 .12123 Mdot
.016 w
.76219 .12123 m
.76161 .12102 L
s
.008 w
.76161 .12102 Mdot
.016 w
.76161 .12102 m
.7609 .12077 L
s
.008 w
.7609 .12077 Mdot
.016 w
.7609 .12077 m
.76008 .1205 L
s
.008 w
.76008 .1205 Mdot
.016 w
.76008 .1205 m
.7592 .12025 L
s
.008 w
.7592 .12025 Mdot
.016 w
.7592 .12025 m
.75826 .12003 L
s
1 .107 0 r
.008 w
.75826 .12003 Mdot
.016 w
.75826 .12003 m
.75724 .11987 L
s
.008 w
.75724 .11987 Mdot
.016 w
.75724 .11987 m
.75618 .11975 L
s
.008 w
.75618 .11975 Mdot
.016 w
.75618 .11975 m
.75515 .11967 L
s
.008 w
.75515 .11967 Mdot
.016 w
.75515 .11967 m
.75418 .11964 L
s
1 .106 0 r
.008 w
.75418 .11964 Mdot
.016 w
.75418 .11964 m
.75331 .11963 L
s
.008 w
.75331 .11963 Mdot
.016 w
.75331 .11963 m
.7526 .11966 L
s
.008 w
.7526 .11966 Mdot
.016 w
.7526 .11966 m
.75201 .11975 L
s
.008 w
.75201 .11975 Mdot
.016 w
.75201 .11975 m
.75156 .11992 L
s
.008 w
.75156 .11992 Mdot
.016 w
.75156 .11992 m
.75123 .12014 L
s
1 .105 0 r
.008 w
.75123 .12014 Mdot
.016 w
.75123 .12014 m
.751 .1204 L
s
.008 w
.751 .1204 Mdot
.016 w
.751 .1204 m
.75086 .12069 L
s
.008 w
.75086 .12069 Mdot
.016 w
.75086 .12069 m
.75079 .12095 L
s
.008 w
.75079 .12095 Mdot
.016 w
.75079 .12095 m
.75077 .12116 L
s
.008 w
.75077 .12116 Mdot
.016 w
.75077 .12116 m
.75079 .12126 L
s
1 .104 0 r
.008 w
.75079 .12126 Mdot
.016 w
.75079 .12126 m
.75082 .12124 L
s
.008 w
.75082 .12124 Mdot
.016 w
.75082 .12124 m
.75084 .1211 L
s
.008 w
.75084 .1211 Mdot
.016 w
.75084 .1211 m
.75082 .12089 L
s
.008 w
.75082 .12089 Mdot
.016 w
.75082 .12089 m
.75075 .1206 L
s
.008 w
.75075 .1206 Mdot
.016 w
.75075 .1206 m
.75061 .12027 L
s
1 .103 0 r
.008 w
.75061 .12027 Mdot
.016 w
.75061 .12027 m
.75043 .1199 L
s
.008 w
.75043 .1199 Mdot
.016 w
.75043 .1199 m
.75022 .11949 L
s
.008 w
.75022 .11949 Mdot
.016 w
.75022 .11949 m
.75 .11907 L
s
.008 w
.75 .11907 Mdot
.016 w
.75 .11907 m
.74978 .11864 L
s
1 .102 0 r
.008 w
.74978 .11864 Mdot
.016 w
.74978 .11864 m
.74956 .11822 L
s
.008 w
.74956 .11822 Mdot
.016 w
.74956 .11822 m
.74935 .11781 L
s
.008 w
.74935 .11781 Mdot
.016 w
.74935 .11781 m
.74915 .11743 L
s
.008 w
.74915 .11743 Mdot
.016 w
.74915 .11743 m
.74897 .11709 L
s
.008 w
.74897 .11709 Mdot
.016 w
.74897 .11709 m
.74881 .11683 L
s
1 .101 0 r
.008 w
.74881 .11683 Mdot
.016 w
.74881 .11683 m
.74868 .11664 L
s
.008 w
.74868 .11664 Mdot
.016 w
.74868 .11664 m
.7486 .11653 L
s
.008 w
.7486 .11653 Mdot
.016 w
.7486 .11653 m
.74856 .1165 L
s
.008 w
.74856 .1165 Mdot
.016 w
.74856 .1165 m
.74859 .11652 L
s
.008 w
.74859 .11652 Mdot
.016 w
.74859 .11652 m
.74866 .11658 L
s
1 .1 0 r
.008 w
.74866 .11658 Mdot
.016 w
.74866 .11658 m
.74878 .11666 L
s
.008 w
.74878 .11666 Mdot
.016 w
.74878 .11666 m
.74893 .11671 L
s
.008 w
.74893 .11671 Mdot
.016 w
.74893 .11671 m
.74909 .11674 L
s
.008 w
.74909 .11674 Mdot
.016 w
.74909 .11674 m
.74927 .11675 L
s
.008 w
.74927 .11675 Mdot
.016 w
.74927 .11675 m
.74947 .11676 L
s
1 .099 0 r
.008 w
.74947 .11676 Mdot
.016 w
.74947 .11676 m
.74968 .11676 L
s
.008 w
.74968 .11676 Mdot
.016 w
.74968 .11676 m
.74987 .11675 L
s
.008 w
.74987 .11675 Mdot
.016 w
.74987 .11675 m
.75006 .11671 L
s
.008 w
.75006 .11671 Mdot
.016 w
.75006 .11671 m
.75022 .11665 L
s
.008 w
.75022 .11665 Mdot
.016 w
.75022 .11665 m
.75037 .11659 L
s
1 .098 0 r
.008 w
.75037 .11659 Mdot
.016 w
.75037 .11659 m
.75049 .11654 L
s
.008 w
.75049 .11654 Mdot
.016 w
.75049 .11654 m
.75055 .11652 L
s
.008 w
.75055 .11652 Mdot
.016 w
.75055 .11652 m
.75059 .11652 L
s
.008 w
.75059 .11652 Mdot
.016 w
.75059 .11652 m
.75062 .11657 L
s
1 .097 0 r
.008 w
.75062 .11657 Mdot
.016 w
.75062 .11657 m
.75067 .1167 L
s
.008 w
.75067 .1167 Mdot
.016 w
.75067 .1167 m
.75076 .1169 L
s
.008 w
.75076 .1169 Mdot
.016 w
.75076 .1169 m
.75093 .11721 L
s
.008 w
.75093 .11721 Mdot
.016 w
.75093 .11721 m
.75121 .11763 L
s
.008 w
.75121 .11763 Mdot
.016 w
.75121 .11763 m
.75163 .1182 L
s
1 .096 0 r
.008 w
.75163 .1182 Mdot
.016 w
.75163 .1182 m
.75223 .11893 L
s
.008 w
.75223 .11893 Mdot
.016 w
.75223 .11893 m
.75304 .11981 L
s
.008 w
.75304 .11981 Mdot
.016 w
.75304 .11981 m
.75406 .12088 L
s
.008 w
.75406 .12088 Mdot
.016 w
.75406 .12088 m
.7553 .12217 L
s
.008 w
.7553 .12217 Mdot
.016 w
.7553 .12217 m
.7567 .12363 L
s
1 .095 0 r
.008 w
.7567 .12363 Mdot
.016 w
.7567 .12363 m
.75823 .12538 L
s
.008 w
.75823 .12538 Mdot
.016 w
.75823 .12538 m
.75998 .12727 L
s
.008 w
.75998 .12727 Mdot
.016 w
.75998 .12727 m
.76186 .12948 L
s
.008 w
.76186 .12948 Mdot
.016 w
.76186 .12948 m
.76385 .13167 L
s
.008 w
.76385 .13167 Mdot
.016 w
.76385 .13167 m
.76592 .13409 L
s
1 .094 0 r
.008 w
.76592 .13409 Mdot
.016 w
.76592 .13409 m
.76799 .13657 L
s
.008 w
.76799 .13657 Mdot
.016 w
.76799 .13657 m
.77004 .13906 L
s
.008 w
.77004 .13906 Mdot
.016 w
.77004 .13906 m
.77201 .14169 L
s
.008 w
.77201 .14169 Mdot
.016 w
.77201 .14169 m
.77382 .14385 L
s
1 .093 0 r
.008 w
.77382 .14385 Mdot
.016 w
.77382 .14385 m
.77549 .14618 L
s
.008 w
.77549 .14618 Mdot
.016 w
.77549 .14618 m
.77699 .14861 L
s
.008 w
.77699 .14861 Mdot
.016 w
.77699 .14861 m
.77829 .15101 L
s
.008 w
.77829 .15101 Mdot
.016 w
.77829 .15101 m
.77932 .153 L
s
.008 w
.77932 .153 Mdot
.016 w
.77932 .153 m
.78014 .15499 L
s
1 .092 0 r
.008 w
.78014 .15499 Mdot
.016 w
.78014 .15499 m
.78076 .15713 L
s
.008 w
.78076 .15713 Mdot
.016 w
.78076 .15713 m
.78124 .15941 L
s
.008 w
.78124 .15941 Mdot
.016 w
.78124 .15941 m
.78163 .16174 L
s
.008 w
.78163 .16174 Mdot
.016 w
.78163 .16174 m
.782 .1637 L
s
.008 w
.782 .1637 Mdot
.016 w
.782 .1637 m
.7824 .16623 L
s
1 .091 0 r
.008 w
.7824 .16623 Mdot
.016 w
.7824 .16623 m
.78291 .16864 L
s
.008 w
.78291 .16864 Mdot
.016 w
.78291 .16864 m
.78359 .1716 L
s
.008 w
.78359 .1716 Mdot
.016 w
.78359 .1716 m
.78449 .1745 L
s
.008 w
.78449 .1745 Mdot
.016 w
.78449 .1745 m
.78566 .17742 L
s
.008 w
.78566 .17742 Mdot
.016 w
.78566 .17742 m
.78712 .18064 L
s
1 .09 0 r
.008 w
.78712 .18064 Mdot
.016 w
.78712 .18064 m
.7888 .18378 L
s
.008 w
.7888 .18378 Mdot
.016 w
.7888 .18378 m
.79081 .18699 L
s
.008 w
.79081 .18699 Mdot
.016 w
.79081 .18699 m
.79316 .19015 L
s
.008 w
.79316 .19015 Mdot
.016 w
.79316 .19015 m
.79582 .1929 L
s
1 .089 0 r
.008 w
.79582 .1929 Mdot
.016 w
.79582 .1929 m
.79875 .19569 L
s
.008 w
.79875 .19569 Mdot
.016 w
.79875 .19569 m
.80213 .19823 L
s
.008 w
.80213 .19823 Mdot
.016 w
.80213 .19823 m
.80535 .20057 L
s
.008 w
.80535 .20057 Mdot
.016 w
.80535 .20057 m
.80901 .20264 L
s
.008 w
.80901 .20264 Mdot
.016 w
.80901 .20264 m
.81252 .20448 L
s
1 .088 0 r
.008 w
.81252 .20448 Mdot
.016 w
.81252 .20448 m
.81597 .20605 L
s
.008 w
.81597 .20605 Mdot
.016 w
.81597 .20605 m
.81916 .20733 L
s
.008 w
.81916 .20733 Mdot
.016 w
.81916 .20733 m
.82209 .20841 L
s
.008 w
.82209 .20841 Mdot
.016 w
.82209 .20841 m
.82516 .20923 L
s
.008 w
.82516 .20923 Mdot
.016 w
.82516 .20923 m
.82751 .20985 L
s
1 .087 0 r
.008 w
.82751 .20985 Mdot
.016 w
.82751 .20985 m
.82944 .21026 L
s
.008 w
.82944 .21026 Mdot
.016 w
.82944 .21026 m
.83122 .21048 L
s
.008 w
.83122 .21048 Mdot
.016 w
.83122 .21048 m
.83251 .21049 L
s
.008 w
.83251 .21049 Mdot
.016 w
.83251 .21049 m
.83347 .21033 L
s
.008 w
.83347 .21033 Mdot
.016 w
.83347 .21033 m
.83413 .21002 L
s
1 .086 0 r
.008 w
.83413 .21002 Mdot
.016 w
.83413 .21002 m
.83455 .20958 L
s
.008 w
.83455 .20958 Mdot
.016 w
.83455 .20958 m
.83475 .209 L
s
.008 w
.83475 .209 Mdot
.016 w
.83475 .209 m
.8348 .2083 L
s
.008 w
.8348 .2083 Mdot
.016 w
.8348 .2083 m
.83471 .20742 L
s
.008 w
.83471 .20742 Mdot
.016 w
.83471 .20742 m
.83417 .20636 L
s
1 .085 0 r
.008 w
.83417 .20636 Mdot
.016 w
.83417 .20636 m
.83392 .20515 L
s
.008 w
.83392 .20515 Mdot
.016 w
.83392 .20515 m
.83368 .20374 L
s
.008 w
.83368 .20374 Mdot
.016 w
.83368 .20374 m
.83342 .20212 L
s
.008 w
.83342 .20212 Mdot
.016 w
.83342 .20212 m
.83304 .20039 L
s
1 .084 0 r
.008 w
.83304 .20039 Mdot
.016 w
.83304 .20039 m
.83253 .19848 L
s
.008 w
.83253 .19848 Mdot
.016 w
.83253 .19848 m
.83192 .19642 L
s
.008 w
.83192 .19642 Mdot
.016 w
.83192 .19642 m
.83126 .19455 L
s
.008 w
.83126 .19455 Mdot
.016 w
.83126 .19455 m
.83042 .19249 L
s
.008 w
.83042 .19249 Mdot
.016 w
.83042 .19249 m
.82945 .19058 L
s
1 .083 0 r
.008 w
.82945 .19058 Mdot
.016 w
.82945 .19058 m
.82828 .18864 L
s
.008 w
.82828 .18864 Mdot
.016 w
.82828 .18864 m
.82702 .18669 L
s
.008 w
.82702 .18669 Mdot
.016 w
.82702 .18669 m
.82568 .18496 L
s
.008 w
.82568 .18496 Mdot
.016 w
.82568 .18496 m
.82432 .18328 L
s
.008 w
.82432 .18328 Mdot
.016 w
.82432 .18328 m
.82296 .18168 L
s
1 .082 0 r
.008 w
.82296 .18168 Mdot
.016 w
.82296 .18168 m
.82161 .18019 L
s
.008 w
.82161 .18019 Mdot
.016 w
.82161 .18019 m
.82028 .17874 L
s
.008 w
.82028 .17874 Mdot
.016 w
.82028 .17874 m
.819 .1773 L
s
.008 w
.819 .1773 Mdot
.016 w
.819 .1773 m
.81778 .17591 L
s
.008 w
.81778 .17591 Mdot
.016 w
.81778 .17591 m
.81655 .1745 L
s
1 .081 0 r
.008 w
.81655 .1745 Mdot
.016 w
.81655 .1745 m
.81533 .17301 L
s
.008 w
.81533 .17301 Mdot
.016 w
.81533 .17301 m
.81408 .17144 L
s
.008 w
.81408 .17144 Mdot
.016 w
.81408 .17144 m
.81284 .1699 L
s
.008 w
.81284 .1699 Mdot
.016 w
.81284 .1699 m
.81166 .16832 L
s
1 .08 0 r
.008 w
.81166 .16832 Mdot
.016 w
.81166 .16832 m
.81058 .16677 L
s
.008 w
.81058 .16677 Mdot
.016 w
.81058 .16677 m
.8096 .16526 L
s
.008 w
.8096 .16526 Mdot
.016 w
.8096 .16526 m
.80873 .16392 L
s
.008 w
.80873 .16392 Mdot
.016 w
.80873 .16392 m
.80798 .16269 L
s
.008 w
.80798 .16269 Mdot
.016 w
.80798 .16269 m
.80736 .16163 L
s
1 .079 0 r
.008 w
.80736 .16163 Mdot
.016 w
.80736 .16163 m
.80687 .16077 L
s
.008 w
.80687 .16077 Mdot
.016 w
.80687 .16077 m
.80646 .16008 L
s
.008 w
.80646 .16008 Mdot
.016 w
.80646 .16008 m
.80611 .15956 L
s
.008 w
.80611 .15956 Mdot
.016 w
.80611 .15956 m
.80582 .15919 L
s
.008 w
.80582 .15919 Mdot
.016 w
.80582 .15919 m
.80559 .15895 L
s
1 .078 0 r
.008 w
.80559 .15895 Mdot
.016 w
.80559 .15895 m
.80545 .15883 L
s
.008 w
.80545 .15883 Mdot
.016 w
.80545 .15883 m
.80541 .15883 L
s
.008 w
.80541 .15883 Mdot
.016 w
.80541 .15883 m
.80549 .15895 L
s
.008 w
.80549 .15895 Mdot
.016 w
.80549 .15895 m
.80566 .15918 L
s
.008 w
.80566 .15918 Mdot
.016 w
.80566 .15918 m
.80588 .15943 L
s
1 .077 0 r
.008 w
.80588 .15943 Mdot
.016 w
.80588 .15943 m
.80606 .15964 L
s
.008 w
.80606 .15964 Mdot
.016 w
.80606 .15964 m
.80612 .15973 L
s
.008 w
.80612 .15973 Mdot
.016 w
.80612 .15973 m
.80597 .15961 L
s
.008 w
.80597 .15961 Mdot
.016 w
.80597 .15961 m
.80553 .15916 L
s
.008 w
.80553 .15916 Mdot
.016 w
.80553 .15916 m
.80477 .15836 L
s
1 .076 0 r
.008 w
.80477 .15836 Mdot
.016 w
.80477 .15836 m
.8037 .15715 L
s
.008 w
.8037 .15715 Mdot
.016 w
.8037 .15715 m
.80235 .15556 L
s
.008 w
.80235 .15556 Mdot
.016 w
.80235 .15556 m
.80065 .15349 L
s
.008 w
.80065 .15349 Mdot
.016 w
.80065 .15349 m
.79855 .1509 L
s
1 .075 0 r
.008 w
.79855 .1509 Mdot
.016 w
.79855 .1509 m
.79633 .14832 L
s
.008 w
.79633 .14832 Mdot
.016 w
.79633 .14832 m
.79344 .14546 L
s
.008 w
.79344 .14546 Mdot
.016 w
.79344 .14546 m
.79056 .14248 L
s
.008 w
.79056 .14248 Mdot
.016 w
.79056 .14248 m
.78718 .13909 L
s
.008 w
.78718 .13909 Mdot
.016 w
.78718 .13909 m
.78356 .13506 L
s
1 .074 0 r
.008 w
.78356 .13506 Mdot
.016 w
.78356 .13506 m
.7799 .13191 L
s
.008 w
.7799 .13191 Mdot
.016 w
.7799 .13191 m
.77585 .1288 L
s
.008 w
.77585 .1288 Mdot
.016 w
.77585 .1288 m
.77234 .12571 L
s
.008 w
.77234 .12571 Mdot
.016 w
.77234 .12571 m
.76835 .12293 L
s
.008 w
.76835 .12293 Mdot
.016 w
.76835 .12293 m
.76456 .12033 L
s
1 .073 0 r
.008 w
.76456 .12033 Mdot
.016 w
.76456 .12033 m
.76036 .11802 L
s
.008 w
.76036 .11802 Mdot
.016 w
.76036 .11802 m
.75598 .11581 L
s
.008 w
.75598 .11581 Mdot
.016 w
.75598 .11581 m
.75199 .11385 L
s
.008 w
.75199 .11385 Mdot
.016 w
.75199 .11385 m
.74722 .11182 L
s
.008 w
.74722 .11182 Mdot
.016 w
.74722 .11182 m
.74262 .10972 L
s
1 .072 0 r
.008 w
.74262 .10972 Mdot
.016 w
.74262 .10972 m
.73764 .10753 L
s
.008 w
.73764 .10753 Mdot
.016 w
.73764 .10753 m
.73205 .10523 L
s
.008 w
.73205 .10523 Mdot
.016 w
.73205 .10523 m
.72738 .10316 L
s
.008 w
.72738 .10316 Mdot
.016 w
.72738 .10316 m
.72249 .10101 L
s
1 .071 0 r
.008 w
.72249 .10101 Mdot
.016 w
.72249 .10101 m
.71694 .0987 L
s
.008 w
.71694 .0987 Mdot
.016 w
.71694 .0987 m
.71264 .09679 L
s
.008 w
.71264 .09679 Mdot
.016 w
.71264 .09679 m
.70794 .09489 L
s
.008 w
.70794 .09489 Mdot
.016 w
.70794 .09489 m
.70359 .0931 L
s
.008 w
.70359 .0931 Mdot
.016 w
.70359 .0931 m
.69942 .09152 L
s
1 .07 0 r
.008 w
.69942 .09152 Mdot
.016 w
.69942 .09152 m
.696 .09021 L
s
.008 w
.696 .09021 Mdot
.016 w
.696 .09021 m
.6929 .0891 L
s
.008 w
.6929 .0891 Mdot
.016 w
.6929 .0891 m
.6904 .08822 L
s
.008 w
.6904 .08822 Mdot
.016 w
.6904 .08822 m
.68824 .08758 L
s
.008 w
.68824 .08758 Mdot
.016 w
.68824 .08758 m
.68649 .08716 L
s
1 .069 0 r
.008 w
.68649 .08716 Mdot
.016 w
.68649 .08716 m
.68509 .08693 L
s
.008 w
.68509 .08693 Mdot
.016 w
.68509 .08693 m
.68398 .08681 L
s
.008 w
.68398 .08681 Mdot
.016 w
.68398 .08681 m
.6831 .08677 L
s
.008 w
.6831 .08677 Mdot
.016 w
.6831 .08677 m
.68243 .08679 L
s
.008 w
.68243 .08679 Mdot
.016 w
.68243 .08679 m
.68191 .08683 L
s
1 .068 0 r
.008 w
.68191 .08683 Mdot
.016 w
.68191 .08683 m
.68153 .08692 L
s
.008 w
.68153 .08692 Mdot
.016 w
.68153 .08692 m
.68124 .08699 L
s
.008 w
.68124 .08699 Mdot
.016 w
.68124 .08699 m
.68099 .08705 L
s
.008 w
.68099 .08705 Mdot
.016 w
.68099 .08705 m
.68079 .08714 L
s
1 .067 0 r
.008 w
.68079 .08714 Mdot
.016 w
.68079 .08714 m
.68066 .08727 L
s
.008 w
.68066 .08727 Mdot
.016 w
.68066 .08727 m
.68058 .08743 L
s
.008 w
.68058 .08743 Mdot
.016 w
.68058 .08743 m
.68055 .08761 L
s
.008 w
.68055 .08761 Mdot
.016 w
.68055 .08761 m
.68058 .08779 L
s
.008 w
.68058 .08779 Mdot
.016 w
.68058 .08779 m
.68064 .08795 L
s
1 .066 0 r
.008 w
.68064 .08795 Mdot
.016 w
.68064 .08795 m
.68073 .08807 L
s
.008 w
.68073 .08807 Mdot
.016 w
.68073 .08807 m
.68082 .08813 L
s
.008 w
.68082 .08813 Mdot
.016 w
.68082 .08813 m
.68089 .08814 L
s
.008 w
.68089 .08814 Mdot
.016 w
.68089 .08814 m
.68094 .08811 L
s
.008 w
.68094 .08811 Mdot
.016 w
.68094 .08811 m
.68095 .08807 L
s
1 .065 0 r
.008 w
.68095 .08807 Mdot
.016 w
.68095 .08807 m
.68095 .08803 L
s
.008 w
.68095 .08803 Mdot
.016 w
.68095 .08803 m
.68096 .088 L
s
.008 w
.68096 .088 Mdot
.016 w
.68096 .088 m
.681 .08797 L
s
.008 w
.681 .08797 Mdot
.016 w
.681 .08797 m
.68107 .08794 L
s
.008 w
.68107 .08794 Mdot
.016 w
.68107 .08794 m
.68113 .08791 L
s
1 .064 0 r
.008 w
.68113 .08791 Mdot
.016 w
.68113 .08791 m
.68116 .0879 L
s
.008 w
.68116 .0879 Mdot
.016 w
.68116 .0879 m
.68114 .08791 L
s
.008 w
.68114 .08791 Mdot
.016 w
.68114 .08791 m
.68105 .08795 L
s
.008 w
.68105 .08795 Mdot
.016 w
.68105 .08795 m
.68088 .08803 L
s
.008 w
.68088 .08803 Mdot
.016 w
.68088 .08803 m
.68064 .08814 L
s
1 .063 0 r
.008 w
.68064 .08814 Mdot
.016 w
.68064 .08814 m
.68033 .08829 L
s
.008 w
.68033 .08829 Mdot
.016 w
.68033 .08829 m
.67996 .08846 L
s
.008 w
.67996 .08846 Mdot
.016 w
.67996 .08846 m
.67956 .08864 L
s
.008 w
.67956 .08864 Mdot
.016 w
.67956 .08864 m
.67914 .08884 L
s
1 .062 0 r
.008 w
.67914 .08884 Mdot
.016 w
.67914 .08884 m
.67871 .08904 L
s
.008 w
.67871 .08904 Mdot
.016 w
.67871 .08904 m
.67829 .08924 L
s
.008 w
.67829 .08924 Mdot
.016 w
.67829 .08924 m
.67787 .08944 L
s
.008 w
.67787 .08944 Mdot
.016 w
.67787 .08944 m
.67749 .08963 L
s
.008 w
.67749 .08963 Mdot
.016 w
.67749 .08963 m
.67716 .08981 L
s
1 .061 0 r
.008 w
.67716 .08981 Mdot
.016 w
.67716 .08981 m
.6769 .08996 L
s
.008 w
.6769 .08996 Mdot
.016 w
.6769 .08996 m
.67672 .09008 L
s
.008 w
.67672 .09008 Mdot
.016 w
.67672 .09008 m
.67661 .09014 L
s
.008 w
.67661 .09014 Mdot
.016 w
.67661 .09014 m
.67658 .09015 L
s
.008 w
.67658 .09015 Mdot
.016 w
.67658 .09015 m
.67661 .09009 L
s
1 .06 0 r
.008 w
.67661 .09009 Mdot
.016 w
.67661 .09009 m
.67667 .08998 L
s
.008 w
.67667 .08998 Mdot
.016 w
.67667 .08998 m
.67673 .08982 L
s
.008 w
.67673 .08982 Mdot
.016 w
.67673 .08982 m
.67678 .08964 L
s
.008 w
.67678 .08964 Mdot
.016 w
.67678 .08964 m
.67681 .08945 L
s
.008 w
.67681 .08945 Mdot
.016 w
.67681 .08945 m
.67681 .08925 L
s
1 .059 0 r
.008 w
.67681 .08925 Mdot
.016 w
.67681 .08925 m
.6768 .08903 L
s
.008 w
.6768 .08903 Mdot
.016 w
.6768 .08903 m
.6768 .08882 L
s
.008 w
.6768 .08882 Mdot
.016 w
.6768 .08882 m
.67679 .0886 L
s
.008 w
.67679 .0886 Mdot
.016 w
.67679 .0886 m
.67679 .0884 L
s
1 .058 0 r
.008 w
.67679 .0884 Mdot
.016 w
.67679 .0884 m
.67679 .08821 L
s
.008 w
.67679 .08821 Mdot
.016 w
.67679 .08821 m
.67682 .08807 L
s
.008 w
.67682 .08807 Mdot
.016 w
.67682 .08807 m
.6769 .08799 L
s
.008 w
.6769 .08799 Mdot
.016 w
.6769 .08799 m
.67704 .08797 L
s
.008 w
.67704 .08797 Mdot
.016 w
.67704 .08797 m
.67721 .088 L
s
1 .057 0 r
.008 w
.67721 .088 Mdot
.016 w
.67721 .088 m
.67738 .08806 L
s
.008 w
.67738 .08806 Mdot
.016 w
.67738 .08806 m
.67752 .08816 L
s
.008 w
.67752 .08816 Mdot
.016 w
.67752 .08816 m
.67756 .08824 L
s
.008 w
.67756 .08824 Mdot
.016 w
.67756 .08824 m
.67745 .08825 L
s
.008 w
.67745 .08825 Mdot
.016 w
.67745 .08825 m
.67716 .08815 L
s
1 .056 0 r
.008 w
.67716 .08815 Mdot
.016 w
.67716 .08815 m
.67665 .08788 L
s
.008 w
.67665 .08788 Mdot
.016 w
.67665 .08788 m
.67587 .08742 L
s
.008 w
.67587 .08742 Mdot
.016 w
.67587 .08742 m
.67476 .08673 L
s
.008 w
.67476 .08673 Mdot
.016 w
.67476 .08673 m
.67327 .0858 L
s
.008 w
.67327 .0858 Mdot
.016 w
.67327 .0858 m
.67151 .08465 L
s
1 .055 0 r
.008 w
.67151 .08465 Mdot
.016 w
.67151 .08465 m
.66925 .08327 L
s
.008 w
.66925 .08327 Mdot
.016 w
.66925 .08327 m
.66675 .08166 L
s
.008 w
.66675 .08166 Mdot
.016 w
.66675 .08166 m
.66375 .07983 L
s
.008 w
.66375 .07983 Mdot
.016 w
.66375 .07983 m
.66048 .07806 L
s
1 .054 0 r
.008 w
.66048 .07806 Mdot
.016 w
.66048 .07806 m
.65695 .07588 L
s
.008 w
.65695 .07588 Mdot
.016 w
.65695 .07588 m
.65314 .07403 L
s
.008 w
.65314 .07403 Mdot
.016 w
.65314 .07403 m
.64935 .07199 L
s
.008 w
.64935 .07199 Mdot
.016 w
.64935 .07199 m
.64546 .06993 L
s
.008 w
.64546 .06993 Mdot
.016 w
.64546 .06993 m
.64141 .06795 L
s
1 .053 0 r
.008 w
.64141 .06795 Mdot
.016 w
.64141 .06795 m
.63773 .06616 L
s
.008 w
.63773 .06616 Mdot
.016 w
.63773 .06616 m
.63389 .0644 L
s
.008 w
.63389 .0644 Mdot
.016 w
.63389 .0644 m
.63007 .06285 L
s
.008 w
.63007 .06285 Mdot
.016 w
.63007 .06285 m
.62628 .06145 L
s
.008 w
.62628 .06145 Mdot
.016 w
.62628 .06145 m
.62263 .06018 L
s
1 .052 0 r
.008 w
.62263 .06018 Mdot
.016 w
.62263 .06018 m
.61899 .05907 L
s
.008 w
.61899 .05907 Mdot
.016 w
.61899 .05907 m
.61563 .05813 L
s
.008 w
.61563 .05813 Mdot
.016 w
.61563 .05813 m
.6122 .05729 L
s
.008 w
.6122 .05729 Mdot
.016 w
.6122 .05729 m
.60896 .05652 L
s
.008 w
.60896 .05652 Mdot
.016 w
.60896 .05652 m
.60561 .05581 L
s
1 .051 0 r
.008 w
.60561 .05581 Mdot
.016 w
.60561 .05581 m
.60204 .05512 L
s
.008 w
.60204 .05512 Mdot
.016 w
.60204 .05512 m
.59853 .0544 L
s
.008 w
.59853 .0544 Mdot
.016 w
.59853 .0544 m
.59462 .05365 L
s
.008 w
.59462 .05365 Mdot
.016 w
.59462 .05365 m
.59069 .05284 L
s
.008 w
.59069 .05284 Mdot
.016 w
.59069 .05284 m
.58637 .05198 L
s
1 .05 0 r
.008 w
.58637 .05198 Mdot
.016 w
.58637 .05198 m
.58241 .05108 L
s
.008 w
.58241 .05108 Mdot
.016 w
.58241 .05108 m
.57818 .05026 L
s
.008 w
.57818 .05026 Mdot
.016 w
.57818 .05026 m
.57428 .04937 L
s
.008 w
.57428 .04937 Mdot
.016 w
.57428 .04937 m
.5706 .04846 L
s
1 .049 0 r
.008 w
.5706 .04846 Mdot
.016 w
.5706 .04846 m
.56706 .04755 L
s
.008 w
.56706 .04755 Mdot
.016 w
.56706 .04755 m
.56365 .04676 L
s
.008 w
.56365 .04676 Mdot
.016 w
.56365 .04676 m
.561 .04605 L
s
.008 w
.561 .04605 Mdot
.016 w
.561 .04605 m
.55861 .04542 L
s
.008 w
.55861 .04542 Mdot
.016 w
.55861 .04542 m
.55652 .0449 L
s
1 .048 0 r
.008 w
.55652 .0449 Mdot
.016 w
.55652 .0449 m
.555 .04453 L
s
.008 w
.555 .04453 Mdot
.016 w
.555 .04453 m
.55381 .04431 L
s
.008 w
.55381 .04431 Mdot
.016 w
.55381 .04431 m
.55299 .04423 L
s
.008 w
.55299 .04423 Mdot
.016 w
.55299 .04423 m
.55245 .04427 L
s
.008 w
.55245 .04427 Mdot
.016 w
.55245 .04427 m
.55202 .04436 L
s
1 .047 0 r
.008 w
.55202 .04436 Mdot
.016 w
.55202 .04436 m
.55156 .04448 L
s
.008 w
.55156 .04448 Mdot
.016 w
.55156 .04448 m
.5509 .04458 L
s
.008 w
.5509 .04458 Mdot
.016 w
.5509 .04458 m
.54993 .04466 L
s
.008 w
.54993 .04466 Mdot
.016 w
.54993 .04466 m
.54862 .04468 L
s
.008 w
.54862 .04468 Mdot
.016 w
.54862 .04468 m
.54684 .04465 L
s
1 .046 0 r
.008 w
.54684 .04465 Mdot
.016 w
.54684 .04465 m
.54449 .04459 L
s
.008 w
.54449 .04459 Mdot
.016 w
.54449 .04459 m
.54169 .0445 L
s
.008 w
.54169 .0445 Mdot
.016 w
.54169 .0445 m
.53845 .04439 L
s
.008 w
.53845 .04439 Mdot
.016 w
.53845 .04439 m
.53467 .04428 L
s
1 .045 0 r
.008 w
.53467 .04428 Mdot
.016 w
.53467 .04428 m
.53106 .04415 L
s
.008 w
.53106 .04415 Mdot
.016 w
.53106 .04415 m
.52725 .04401 L
s
.008 w
.52725 .04401 Mdot
.016 w
.52725 .04401 m
.52351 .04385 L
s
.008 w
.52351 .04385 Mdot
.016 w
.52351 .04385 m
.51997 .04368 L
s
.008 w
.51997 .04368 Mdot
.016 w
.51997 .04368 m
.51643 .04352 L
s
1 .044 0 r
.008 w
.51643 .04352 Mdot
.016 w
.51643 .04352 m
.51372 .04338 L
s
.008 w
.51372 .04338 Mdot
.016 w
.51372 .04338 m
.51129 .04326 L
s
.008 w
.51129 .04326 Mdot
.016 w
.51129 .04326 m
.50915 .04316 L
s
.008 w
.50915 .04316 Mdot
.016 w
.50915 .04316 m
.50767 .0431 L
s
.008 w
.50767 .0431 Mdot
.016 w
.50767 .0431 m
.50661 .04307 L
s
1 .043 0 r
.008 w
.50661 .04307 Mdot
.016 w
.50661 .04307 m
.50604 .04308 L
s
.008 w
.50604 .04308 Mdot
.016 w
.50604 .04308 m
.50595 .0431 L
s
.008 w
.50595 .0431 Mdot
.016 w
.50595 .0431 m
.50622 .04312 L
s
.008 w
.50622 .04312 Mdot
.016 w
.50622 .04312 m
.50671 .04314 L
s
.008 w
.50671 .04314 Mdot
.016 w
.50671 .04314 m
.50728 .04316 L
s
1 .042 0 r
.008 w
.50728 .04316 Mdot
.016 w
.50728 .04316 m
.50788 .04318 L
s
.008 w
.50788 .04318 Mdot
.016 w
.50788 .04318 m
.50845 .0432 L
s
.008 w
.50845 .0432 Mdot
.016 w
.50845 .0432 m
.50889 .04321 L
s
.008 w
.50889 .04321 Mdot
.016 w
.50889 .04321 m
.50921 .04322 L
s
.008 w
.50921 .04322 Mdot
.016 w
.50921 .04322 m
.50947 .04322 L
s
1 .041 0 r
.008 w
.50947 .04322 Mdot
.016 w
.50947 .04322 m
.5097 .04321 L
s
.008 w
.5097 .04321 Mdot
.016 w
.5097 .04321 m
.5099 .04317 L
s
.008 w
.5099 .04317 Mdot
.016 w
.5099 .04317 m
.51008 .04311 L
s
.008 w
.51008 .04311 Mdot
.016 w
.51008 .04311 m
.51018 .04305 L
s
1 .04 0 r
.008 w
.51018 .04305 Mdot
.016 w
.51018 .04305 m
.51018 .04302 L
s
.008 w
.51018 .04302 Mdot
.016 w
.51018 .04302 m
.51004 .04304 L
s
.008 w
.51004 .04304 Mdot
.016 w
.51004 .04304 m
.5097 .04312 L
s
.008 w
.5097 .04312 Mdot
.016 w
.5097 .04312 m
.50907 .04326 L
s
.008 w
.50907 .04326 Mdot
.016 w
.50907 .04326 m
.50807 .04348 L
s
1 .039 0 r
.008 w
.50807 .04348 Mdot
.016 w
.50807 .04348 m
.50665 .04376 L
s
.008 w
.50665 .04376 Mdot
.016 w
.50665 .04376 m
.50481 .04408 L
s
.008 w
.50481 .04408 Mdot
.016 w
.50481 .04408 m
.50273 .04442 L
s
.008 w
.50273 .04442 Mdot
.016 w
.50273 .04442 m
.50016 .04478 L
s
.008 w
.50016 .04478 Mdot
.016 w
.50016 .04478 m
.49735 .04512 L
s
1 .038 0 r
.008 w
.49735 .04512 Mdot
.016 w
.49735 .04512 m
.49426 .04545 L
s
.008 w
.49426 .04545 Mdot
.016 w
.49426 .04545 m
.49122 .04578 L
s
.008 w
.49122 .04578 Mdot
.016 w
.49122 .04578 m
.48815 .04608 L
s
.008 w
.48815 .04608 Mdot
.016 w
.48815 .04608 m
.4855 .04634 L
s
.008 w
.4855 .04634 Mdot
.016 w
.4855 .04634 m
.48299 .04654 L
s
1 .037 0 r
.008 w
.48299 .04654 Mdot
.016 w
.48299 .04654 m
.48115 .04668 L
s
.008 w
.48115 .04668 Mdot
.016 w
.48115 .04668 m
.47966 .04675 L
s
.008 w
.47966 .04675 Mdot
.016 w
.47966 .04675 m
.4786 .04675 L
s
.008 w
.4786 .04675 Mdot
.016 w
.4786 .04675 m
.47798 .04672 L
s
1 .036 0 r
.008 w
.47798 .04672 Mdot
.016 w
.47798 .04672 m
.47776 .04665 L
s
.008 w
.47776 .04665 Mdot
.016 w
.47776 .04665 m
.47778 .04658 L
s
.008 w
.47778 .04658 Mdot
.016 w
.47778 .04658 m
.47791 .04652 L
s
.008 w
.47791 .04652 Mdot
.016 w
.47791 .04652 m
.47801 .04645 L
s
.008 w
.47801 .04645 Mdot
.016 w
.47801 .04645 m
.47801 .04638 L
s
1 .035 0 r
.008 w
.47801 .04638 Mdot
.016 w
.47801 .04638 m
.47786 .04631 L
s
.008 w
.47786 .04631 Mdot
.016 w
.47786 .04631 m
.47752 .04626 L
s
.008 w
.47752 .04626 Mdot
.016 w
.47752 .04626 m
.47689 .04624 L
s
.008 w
.47689 .04624 Mdot
.016 w
.47689 .04624 m
.47601 .04625 L
s
.008 w
.47601 .04625 Mdot
.016 w
.47601 .04625 m
.47486 .0463 L
s
1 .034 0 r
.008 w
.47486 .0463 Mdot
.016 w
.47486 .0463 m
.47359 .04642 L
s
.008 w
.47359 .04642 Mdot
.016 w
.47359 .04642 m
.47234 .04663 L
s
.008 w
.47234 .04663 Mdot
.016 w
.47234 .04663 m
.47109 .04694 L
s
.008 w
.47109 .04694 Mdot
.016 w
.47109 .04694 m
.46992 .04737 L
s
.008 w
.46992 .04737 Mdot
.016 w
.46992 .04737 m
.46888 .04794 L
s
1 .033 0 r
.008 w
.46888 .04794 Mdot
.016 w
.46888 .04794 m
.46804 .04864 L
s
.008 w
.46804 .04864 Mdot
.016 w
.46804 .04864 m
.46736 .04943 L
s
.008 w
.46736 .04943 Mdot
.016 w
.46736 .04943 m
.46685 .05034 L
s
.008 w
.46685 .05034 Mdot
.016 w
.46685 .05034 m
.46647 .05134 L
s
1 .032 0 r
.008 w
.46647 .05134 Mdot
.016 w
.46647 .05134 m
.46618 .0524 L
s
.008 w
.46618 .0524 Mdot
.016 w
.46618 .0524 m
.46595 .05343 L
s
.008 w
.46595 .05343 Mdot
.016 w
.46595 .05343 m
.46575 .0543 L
s
.008 w
.46575 .0543 Mdot
.016 w
.46575 .0543 m
.46558 .055 L
s
.008 w
.46558 .055 Mdot
.016 w
.46558 .055 m
.46548 .05555 L
s
1 .031 0 r
.008 w
.46548 .05555 Mdot
.016 w
.46548 .05555 m
.46546 .05593 L
s
.008 w
.46546 .05593 Mdot
.016 w
.46546 .05593 m
.46549 .05615 L
s
.008 w
.46549 .05615 Mdot
.016 w
.46549 .05615 m
.46559 .05619 L
s
.008 w
.46559 .05619 Mdot
.016 w
.46559 .05619 m
.46567 .05609 L
s
.008 w
.46567 .05609 Mdot
.016 w
.46567 .05609 m
.46562 .05589 L
s
1 .03 0 r
.008 w
.46562 .05589 Mdot
.016 w
.46562 .05589 m
.46538 .05569 L
s
.008 w
.46538 .05569 Mdot
.016 w
.46538 .05569 m
.4649 .0555 L
s
.008 w
.4649 .0555 Mdot
.016 w
.4649 .0555 m
.46414 .05538 L
s
.008 w
.46414 .05538 Mdot
.016 w
.46414 .05538 m
.46306 .05527 L
s
.008 w
.46306 .05527 Mdot
.016 w
.46306 .05527 m
.46161 .05521 L
s
1 .029 0 r
.008 w
.46161 .05521 Mdot
.016 w
.46161 .05521 m
.45984 .05525 L
s
.008 w
.45984 .05525 Mdot
.016 w
.45984 .05525 m
.45805 .05504 L
s
.008 w
.45805 .05504 Mdot
.016 w
.45805 .05504 m
.45586 .05516 L
s
.008 w
.45586 .05516 Mdot
.016 w
.45586 .05516 m
.45351 .05525 L
s
.008 w
.45351 .05525 Mdot
.016 w
.45351 .05525 m
.4506 .05526 L
s
1 .028 0 r
.008 w
.4506 .05526 Mdot
.016 w
.4506 .05526 m
.44804 .05517 L
s
.008 w
.44804 .05517 Mdot
.016 w
.44804 .05517 m
.44516 .05495 L
s
.008 w
.44516 .05495 Mdot
.016 w
.44516 .05495 m
.44205 .05458 L
s
.008 w
.44205 .05458 Mdot
.016 w
.44205 .05458 m
.43886 .05405 L
s
1 .027 0 r
.008 w
.43886 .05405 Mdot
.016 w
.43886 .05405 m
.43602 .0534 L
s
.008 w
.43602 .0534 Mdot
.016 w
.43602 .0534 m
.43322 .05265 L
s
.008 w
.43322 .05265 Mdot
.016 w
.43322 .05265 m
.43069 .05186 L
s
.008 w
.43069 .05186 Mdot
.016 w
.43069 .05186 m
.42868 .05111 L
s
.008 w
.42868 .05111 Mdot
.016 w
.42868 .05111 m
.42687 .05044 L
s
1 .026 0 r
.008 w
.42687 .05044 Mdot
.016 w
.42687 .05044 m
.42527 .04988 L
s
.008 w
.42527 .04988 Mdot
.016 w
.42527 .04988 m
.42401 .04946 L
s
.008 w
.42401 .04946 Mdot
.016 w
.42401 .04946 m
.42298 .04915 L
s
.008 w
.42298 .04915 Mdot
.016 w
.42298 .04915 m
.42227 .04896 L
s
.008 w
.42227 .04896 Mdot
.016 w
.42227 .04896 m
.42196 .04888 L
s
1 .025 0 r
.008 w
.42196 .04888 Mdot
.016 w
.42196 .04888 m
.422 .04889 L
s
.008 w
.422 .04889 Mdot
.016 w
.422 .04889 m
.42236 .04895 L
s
.008 w
.42236 .04895 Mdot
.016 w
.42236 .04895 m
.42297 .04904 L
s
.008 w
.42297 .04904 Mdot
.016 w
.42297 .04904 m
.4237 .04912 L
s
.008 w
.4237 .04912 Mdot
.016 w
.4237 .04912 m
.42439 .04919 L
s
1 .024 0 r
.008 w
.42439 .04919 Mdot
.016 w
.42439 .04919 m
.42493 .04923 L
s
.008 w
.42493 .04923 Mdot
.016 w
.42493 .04923 m
.42521 .04925 L
s
.008 w
.42521 .04925 Mdot
.016 w
.42521 .04925 m
.42511 .04925 L
s
.008 w
.42511 .04925 Mdot
.016 w
.42511 .04925 m
.42455 .04924 L
s
1 .023 0 r
.008 w
.42455 .04924 Mdot
.016 w
.42455 .04924 m
.4235 .04921 L
s
.008 w
.4235 .04921 Mdot
.016 w
.4235 .04921 m
.42196 .04916 L
s
.008 w
.42196 .04916 Mdot
.016 w
.42196 .04916 m
.4199 .0491 L
s
.008 w
.4199 .0491 Mdot
.016 w
.4199 .0491 m
.41757 .04898 L
s
.008 w
.41757 .04898 Mdot
.016 w
.41757 .04898 m
.41467 .04878 L
s
1 .022 0 r
.008 w
.41467 .04878 Mdot
.016 w
.41467 .04878 m
.41131 .04853 L
s
.008 w
.41131 .04853 Mdot
.016 w
.41131 .04853 m
.40785 .04826 L
s
.008 w
.40785 .04826 Mdot
.016 w
.40785 .04826 m
.40379 .048 L
s
.008 w
.40379 .048 Mdot
.016 w
.40379 .048 m
.39961 .04778 L
s
.008 w
.39961 .04778 Mdot
.016 w
.39961 .04778 m
.39508 .04768 L
s
1 .021 0 r
.008 w
.39508 .04768 Mdot
.016 w
.39508 .04768 m
.39006 .04774 L
s
.008 w
.39006 .04774 Mdot
.016 w
.39006 .04774 m
.38562 .04802 L
s
.008 w
.38562 .04802 Mdot
.016 w
.38562 .04802 m
.38071 .04853 L
s
.008 w
.38071 .04853 Mdot
.016 w
.38071 .04853 m
.37584 .04931 L
s
.008 w
.37584 .04931 Mdot
.016 w
.37584 .04931 m
.37115 .05038 L
s
1 .02 0 r
.008 w
.37115 .05038 Mdot
.016 w
.37115 .05038 m
.36602 .05177 L
s
.008 w
.36602 .05177 Mdot
.016 w
.36602 .05177 m
.36154 .05332 L
s
.008 w
.36154 .05332 Mdot
.016 w
.36154 .05332 m
.35644 .05523 L
s
.008 w
.35644 .05523 Mdot
.016 w
.35644 .05523 m
.35191 .05731 L
s
1 .019 0 r
.008 w
.35191 .05731 Mdot
.016 w
.35191 .05731 m
.3469 .05965 L
s
.008 w
.3469 .05965 Mdot
.016 w
.3469 .05965 m
.34209 .06213 L
s
.008 w
.34209 .06213 Mdot
.016 w
.34209 .06213 m
.33733 .06481 L
s
.008 w
.33733 .06481 Mdot
.016 w
.33733 .06481 m
.33274 .06746 L
s
.008 w
.33274 .06746 Mdot
.016 w
.33274 .06746 m
.32764 .07029 L
s
1 .018 0 r
.008 w
.32764 .07029 Mdot
.016 w
.32764 .07029 m
.32308 .07313 L
s
.008 w
.32308 .07313 Mdot
.016 w
.32308 .07313 m
.31791 .07607 L
s
.008 w
.31791 .07607 Mdot
.016 w
.31791 .07607 m
.31342 .07895 L
s
.008 w
.31342 .07895 Mdot
.016 w
.31342 .07895 m
.30843 .08199 L
s
.008 w
.30843 .08199 Mdot
.016 w
.30843 .08199 m
.30366 .08487 L
s
1 .017 0 r
.008 w
.30366 .08487 Mdot
.016 w
.30366 .08487 m
.29869 .08791 L
s
.008 w
.29869 .08791 Mdot
.016 w
.29869 .08791 m
.29345 .09101 L
s
.008 w
.29345 .09101 Mdot
.016 w
.29345 .09101 m
.28862 .09409 L
s
.008 w
.28862 .09409 Mdot
.016 w
.28862 .09409 m
.2831 .0974 L
s
.008 w
.2831 .0974 Mdot
.016 w
.2831 .0974 m
.27837 .10049 L
s
1 .016 0 r
.008 w
.27837 .10049 Mdot
.016 w
.27837 .10049 m
.27307 .1038 L
s
.008 w
.27307 .1038 Mdot
.016 w
.27307 .1038 m
.26773 .10712 L
s
.008 w
.26773 .10712 Mdot
.016 w
.26773 .10712 m
.26285 .11032 L
s
.008 w
.26285 .11032 Mdot
.016 w
.26285 .11032 m
.25741 .11366 L
s
.008 w
.25741 .11366 Mdot
.016 w
.25741 .11366 m
.25247 .11673 L
s
1 .015 0 r
.008 w
.25247 .11673 Mdot
.016 w
.25247 .11673 m
.24743 .11982 L
s
.008 w
.24743 .11982 Mdot
.016 w
.24743 .11982 m
.24245 .12288 L
s
.008 w
.24245 .12288 Mdot
.016 w
.24245 .12288 m
.23751 .12586 L
s
.008 w
.23751 .12586 Mdot
.016 w
.23751 .12586 m
.23277 .12899 L
s
1 .014 0 r
.008 w
.23277 .12899 Mdot
.016 w
.23277 .12899 m
.22788 .13226 L
s
.008 w
.22788 .13226 Mdot
.016 w
.22788 .13226 m
.22333 .13551 L
s
.008 w
.22333 .13551 Mdot
.016 w
.22333 .13551 m
.21868 .13901 L
s
.008 w
.21868 .13901 Mdot
.016 w
.21868 .13901 m
.21421 .14262 L
s
.008 w
.21421 .14262 Mdot
.016 w
.21421 .14262 m
.20985 .14637 L
s
1 .013 0 r
.008 w
.20985 .14637 Mdot
.016 w
.20985 .14637 m
.20554 .15045 L
s
.008 w
.20554 .15045 Mdot
.016 w
.20554 .15045 m
.20165 .15436 L
s
.008 w
.20165 .15436 Mdot
.016 w
.20165 .15436 m
.19784 .15857 L
s
.008 w
.19784 .15857 Mdot
.016 w
.19784 .15857 m
.19409 .16322 L
s
.008 w
.19409 .16322 Mdot
.016 w
.19409 .16322 m
.19072 .1675 L
s
1 .012 0 r
.008 w
.19072 .1675 Mdot
.016 w
.19072 .1675 m
.18736 .17228 L
s
.008 w
.18736 .17228 Mdot
.016 w
.18736 .17228 m
.18417 .17727 L
s
.008 w
.18417 .17727 Mdot
.016 w
.18417 .17727 m
.18105 .18196 L
s
.008 w
.18105 .18196 Mdot
.016 w
.18105 .18196 m
.17805 .18687 L
s
.008 w
.17805 .18687 Mdot
.016 w
.17805 .18687 m
.17511 .19174 L
s
1 .011 0 r
.008 w
.17511 .19174 Mdot
.016 w
.17511 .19174 m
.17221 .19676 L
s
.008 w
.17221 .19676 Mdot
.016 w
.17221 .19676 m
.16936 .20125 L
s
.008 w
.16936 .20125 Mdot
.016 w
.16936 .20125 m
.16645 .20623 L
s
.008 w
.16645 .20623 Mdot
.016 w
.16645 .20623 m
.16364 .21072 L
s
1 .01 0 r
.008 w
.16364 .21072 Mdot
.016 w
.16364 .21072 m
.16079 .21529 L
s
.008 w
.16079 .21529 Mdot
.016 w
.16079 .21529 m
.1578 .21973 L
s
.008 w
.1578 .21973 Mdot
.016 w
.1578 .21973 m
.15487 .22433 L
s
.008 w
.15487 .22433 Mdot
.016 w
.15487 .22433 m
.15181 .22923 L
s
.008 w
.15181 .22923 Mdot
.016 w
.15181 .22923 m
.14885 .23357 L
s
1 .009 0 r
.008 w
.14885 .23357 Mdot
.016 w
.14885 .23357 m
.14576 .2385 L
s
.008 w
.14576 .2385 Mdot
.016 w
.14576 .2385 m
.14264 .24344 L
s
.008 w
.14264 .24344 Mdot
.016 w
.14264 .24344 m
.13961 .24785 L
s
.008 w
.13961 .24785 Mdot
.016 w
.13961 .24785 m
.13642 .25298 L
s
.008 w
.13642 .25298 Mdot
.016 w
.13642 .25298 m
.13326 .25794 L
s
1 .008 0 r
.008 w
.13326 .25794 Mdot
.016 w
.13326 .25794 m
.13034 .2632 L
s
.008 w
.13034 .2632 Mdot
.016 w
.13034 .2632 m
.1271 .26851 L
s
.008 w
.1271 .26851 Mdot
.016 w
.1271 .26851 m
.12363 .27383 L
s
.008 w
.12363 .27383 Mdot
.016 w
.12363 .27383 m
.1205 .27911 L
s
.008 w
.1205 .27911 Mdot
.016 w
.1205 .27911 m
.11703 .28463 L
s
1 .007 0 r
.008 w
.11703 .28463 Mdot
.016 w
.11703 .28463 m
.11422 .28931 L
s
.008 w
.11422 .28931 Mdot
.016 w
.11422 .28931 m
.11118 .29399 L
s
.008 w
.11118 .29399 Mdot
.016 w
.11118 .29399 m
.10853 .29831 L
s
.008 w
.10853 .29831 Mdot
.016 w
.10853 .29831 m
.10615 .30233 L
s
1 .006 0 r
.008 w
.10615 .30233 Mdot
.016 w
.10615 .30233 m
.1042 .30553 L
s
.008 w
.1042 .30553 Mdot
.016 w
.1042 .30553 m
.10246 .30853 L
s
.008 w
.10246 .30853 Mdot
.016 w
.10246 .30853 m
.10102 .31129 L
s
.008 w
.10102 .31129 Mdot
.016 w
.10102 .31129 m
.09993 .31355 L
s
.008 w
.09993 .31355 Mdot
.016 w
.09993 .31355 m
.09901 .31574 L
s
1 .005 0 r
.008 w
.09901 .31574 Mdot
.016 w
.09901 .31574 m
.09821 .31795 L
s
.008 w
.09821 .31795 Mdot
.016 w
.09821 .31795 m
.09749 .3203 L
s
.008 w
.09749 .3203 Mdot
.016 w
.09749 .3203 m
.09679 .32291 L
s
.008 w
.09679 .32291 Mdot
.016 w
.09679 .32291 m
.09605 .3256 L
s
.008 w
.09605 .3256 Mdot
.016 w
.09605 .3256 m
.09527 .32892 L
s
1 .004 0 r
.008 w
.09527 .32892 Mdot
.016 w
.09527 .32892 m
.09449 .3322 L
s
.008 w
.09449 .3322 Mdot
.016 w
.09449 .3322 m
.09357 .33606 L
s
.008 w
.09357 .33606 Mdot
.016 w
.09357 .33606 m
.09263 .34037 L
s
.008 w
.09263 .34037 Mdot
.016 w
.09263 .34037 m
.0916 .34502 L
s
.008 w
.0916 .34502 Mdot
.016 w
.0916 .34502 m
.0905 .35027 L
s
1 .003 0 r
.008 w
.0905 .35027 Mdot
.016 w
.0905 .35027 m
.08946 .35519 L
s
.008 w
.08946 .35519 Mdot
.016 w
.08946 .35519 m
.08843 .36081 L
s
.008 w
.08843 .36081 Mdot
.016 w
.08843 .36081 m
.08748 .3657 L
s
.008 w
.08748 .3657 Mdot
.016 w
.08748 .3657 m
.08664 .37118 L
s
.008 w
.08664 .37118 Mdot
.016 w
.08664 .37118 m
.08596 .3757 L
s
1 .002 0 r
.008 w
.08596 .3757 Mdot
.016 w
.08596 .3757 m
.08545 .38037 L
s
.008 w
.08545 .38037 Mdot
.016 w
.08545 .38037 m
.08508 .38458 L
s
.008 w
.08508 .38458 Mdot
.016 w
.08508 .38458 m
.08482 .38822 L
s
.008 w
.08482 .38822 Mdot
.016 w
.08482 .38822 m
.08463 .39154 L
s
1 .001 0 r
.008 w
.08463 .39154 Mdot
.016 w
.08463 .39154 m
.08449 .39435 L
s
.008 w
.08449 .39435 Mdot
.016 w
.08449 .39435 m
.08437 .39672 L
s
.008 w
.08437 .39672 Mdot
.016 w
.08437 .39672 m
.08425 .39855 L
s
.008 w
.08425 .39855 Mdot
.016 w
.08425 .39855 m
.08415 .39997 L
s
.008 w
.08415 .39997 Mdot
.016 w
.08415 .39997 m
.08409 .40095 L
s
1 0 0 r
.008 w
.08409 .40095 Mdot
.016 w
.08409 .40095 m
.08405 .40158 L
s
.008 w
.08405 .40158 Mdot
.016 w
.08405 .40158 m
.08404 .40191 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0159247 0.0155241 scale
6.25569 46.2713 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133236 0.0129884 scale
14.6672 63.6592 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0118101 0.011513 scale
27.5172 78.9658 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0238871 0.0232861 scale
19.5985 40.9214 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0151075 0.0147274 scale
45.5019 61.856 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0128389 0.0125159 scale
51.3984 70.0812 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0238871 0.0232861 scale
26.9635 36.1026 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.018157 0.0177002 scale
33.4346 52.4729 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0170774 0.0166477 scale
39.0154 55.0808 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0178044 0.0173564 scale
37.9098 52.4145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106826 0.0104139 scale
61.5018 78.7219 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0128389 0.0125159 scale
48.4169 63.7381 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0198261 0.0193273 scale
28.2653 41.0755 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
51.7798 104.102 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0178044 0.0173564 scale
21.4285 53.3289 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133236 0.0129884 scale
19.7207 49.7599 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106826 0.0104139 scale
14.1716 43.7906 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0188424 0.0183683 scale
12.9846 27.0928 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
37.2791 45.5081 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00942119 0.00918417 scale
48.7444 33.132 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0106826 0.0104139 scale
77.1777 18.6501 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0348893 0.0340116 scale
23.8598 6.1141 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133236 0.0129884 scale
60.4365 12.2171 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0928562 0.0905202 scale
8.23919 1.34302 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0137912 0.0134442 scale
63.8494 19.9937 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0204557 0.019941 scale
43.9155 14.8769 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0244121 0.023798 scale
36.9439 12.7906 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0222377 0.0216782 scale
26.0387 2.09842 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0118101 0.011513 scale
47.1953 3.88692 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
61.111 5.17706 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
81.7018 11.7278 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
90.9597 16.7814 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0191759 0.0186935 scale
42.7803 9.66862 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0128389 0.0125159 scale
61.7848 11.8305 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0244121 0.023798 scale
31.2492 5.09287 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0207633 0.0202409 scale
36.1662 5.9933 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00872232 0.00850289 scale
92.3515 18.6889 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0244121 0.023798 scale
27.8902 3.70494 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0133236 0.0129884 scale
37.9823 3.31835 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00942119 0.00918417 scale
44.8054 5.33853 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002SOol4001iOol00:9oo`03
001oogoo009oo`8007Moo`00KGoo00<mkgooOol087oo0`003Goo0P001goo00<007ooOol0:7oo2P00
@Woo001/Ool2?Nl;Ool2?Nl5Ool2?NlB00000g`P0000000:0009Ool00`00Oomoo`0ROol5000:Ool3
000oOol006]oo`Hmk`Aoo`@mk`<0018mk`03001l87`P009l8004001l87`P0003O<002000Oomoo`00
O<0007`P0002?Nl200000gc0Oomoo`02Ool00`00Oomoo`0NOol3000BOol2000mOol006Yoo`8mk`9l
00Xmk`05000mkcg_?Nl00008?Nl8O2000`00O21l8004O2000`00O2000003O2000`00O2000002O200
1000O21l80000W`P0gc000@007cP000001moo`03001oogoo01Eoo`8003]oo`00Igoo00<mkg`0O000
3W`000D007`0O01l0000008mk`03O00mkcg_008mk`Ul8003001l87`P00Al8003001l800000=l8003
001l8000009l8004001l87`P0005O202O<000g`P001lh002000KOol00`00Oomoo`0HOol3000hOol0
06Eooa9l0003001l07`0009l0003001l07`0009l00<mk`Yl8003001l87`P009l8003001l87`P0080
0005O2000000O2000002O2001000O21l800027`P00D007cPO>1lh7`P00@001Aoo`8001ioo`03001o
ogoo03Eoo`00Hgoo00<mkg`0O0004W`000D007`0O01l000000]l00Il8080009l808000Al8004001l
87`PO202000017`P0000000027`P00<007`PO20017`P00=lh7`POol00`0047oo00<007ooOol07goo
00<007ooOol0=7oo001QOolGO004000<O0000g`P?Nlmk`05?Nl20002?Nl:O:030009O2000`00O21l
8008O202Ool3000<Ool00`00Oomoo`0QOol00`00Oomoo`0cOol0061oo`al00dmk`ml00`mk`alX080
009lX0El8003001l87`P00]l80=oo`<000Qoo`03001oogoo02=oo`03001oogoo039oo`00Ggoo2g`0
4Sg_0Woo2W`00cg_2Goo3WbP0P0017bP00<007`PO2003W`P17oo1P0000=oo`00Ool09Goo00<007oo
Ool0<Woo001LOol:O009?Nl4Ool9?NlHOol4O:07Ool5O:040006O:0=O2000gcPOomoo`0400000goo
0000000WOol00`00Oomoo`0aOol005]oo`]l008mkcMoo`Dmk`elX0]l808000Aoo`800003Ool007oo
02Ioo`03001oogoo031oo`00F7oo00<007`0O00027`00Sg_@Woo37bP2G`P00<007`PO:000WbP00=o
o`00Ool00`009goo00<007ooOol0;goo001FOol2000:O002?Nm=Ool013g_O:1lX7bP1W`P00@007`P
O21l80=lX003001oogoo009oo`8002Eoo`03001oogoo02moo`00E7oo00<007`0O0002G`00Sg_DGoo
13g_17`P00<007`PO2000g`P00P007a0O41lX7a0Ool007oo0P0097oo00<007ooOol0;Woo001BOol0
0`00?Nml0009O002?NmFOol3?Nl00g`P001l8005O2000`00O41l@003O4001000Oomoogoo0P008Woo
00<007ooOol0;Woo001@Ool20009O005?NmJOol00`00?Nml8003O2000`00O21l@004O4000`00O41l
@003Ool2000POol00`00Oomoo`0^Ool004moo`03001oog`000Ql00Dmke]oo`03001oog`P00=l8003
001l87a000Al@0D00004O41oogoo000POol00`00Oomoo`0]Ool004eoo`800003Ooml07`000Ql00@m
keaoo`03001oogoo009l8003001l87`P00El@08000=l@004001l@7ooO4020005Ool3000FOol00`00
Oomoo`0]Ool004]oo`800003Ooml07`000Ml00Dmkemoo`05001oogooOol00003Ool00gbPO41l@002
0004O4000`00O41l@002O4000goo000000030003Ool00`00Oomoo`0DOol00`00Oomoo`0/Ool004Uo
o`800003Oolmkg`000Il00Hmkf9oo`04001oogoo0005Ool01000O41l@0000ga000<007a0O4000Wa0
1`000goo00<007ooOol04goo00<007ooOol0;7oo0018Ool00`00Oolmk`09O006?NmSOol00`00Ool0
0004Ool00`00Oomoo`02O:030004O4000`00O4000003O4000`00Ool00003Ool00`00Oomoo`0BOol0
0`00Oomoo`0/Ool004Ioo`800003Oolmkg`000Ql00LmkfAoo`H000Eoo`9lX0Al@003001l@00000El
@003O>00000000=oo`03001oogoo015oo`03001oogoo02aoo`00AGoo00<007ooO0002G`023g_IGoo
00<007ooOol02Woo17bP00<007a000001ga000<007ooOol00Woo00<007ooOol047oo00<007ooOol0
;7oo0014Ool00`00?Nml0009O006?NmXOol00`00Oomoo`0<Ool017bP001lX0002Ga000D007fPOomo
o`00019oo`03001oogoo02aoo`00@Woo00<003g_?Nl027`023g_JGoo00<007ooOol03Goo00@007bP
001lH0Ql@005001l@7cP?Nl0000BOol00`00Oomoo`0/Ool0041oo`800003?Nml07`000Ql00Hmkf]o
o`03001oogoo00ioo`03001oo`0000=lH0El@005001l@7a0O>00000BOol00`00Oomoo`0/Ool003mo
o`03001oocg_00Ml00Xmkf]oo`03001oogoo00ioo`03001oo`0000AlH0=l@008001l@7a0O40007cP
?Nl0011oo`03001oogoo02aoo`00?Woo00<003g_?Nl027`00cg_Lgoo00<007ooOol03Woo00<003g_
00000Sg_17aP00H007a0O41l@000O403000?Ool00`00Oomoo`0/Ool003aoo`04000mkcg_?Nl8O003
?NmdOol00`00Oomoo`0<Ool2?Nl30002?Nl2O60200001GaPO41l@000O4001@003Woo00<007ooOol0
;7oo000kOol00`00?Nlmk`07O005?NmeOol00`00Oomoo`0;Ool5?Nl50002O602O4001000O4000000
0ga00P003Goo00<007ooOol0;7oo000jOol00`00?Nlmk`07O004?NmgOol00`00Oomoo`0;Ool7?Nl7
0002O4000`00O41l@002O404000;Ool00`00Oomoo`0/Ool003Uoo`03000mkcg_00Ql00@mkgQoo`03
001oogoo00Yoo`Dmk`Eoo`03O61l@7a0009l@004001l@000O40500000goo001oo`08Ool00`00Oomo
o`0]Ool003Qoo`03000mkcg_00Ql00@mkgUoo`03001oogoo00Uoo`Hmk`Ioo`03O61l@7a0009l@003
001l@00000P000Qoo`03001oogoo02eoo`00=goo00<007oo?Nl01W`01Sg_NWoo00<007ooOol02Goo
1Sg_1goo17a000@007a0001l@080009l@0<000Moo`03001oogoo02ioo`00=Woo00<007oo?Nl01W`0
0cg_Ogoo00<007ooOol027oo1Sg_1goo1Ga01@000Wa00P0000=oo`00Ool01Goo00<007ooOol0;Woo
000eOol00`00Oomoo`06O004?NmoOol00`00Oomoo`09Ool6?Nl7Ool5O4030002O4060005Ool00`00
Oomoo`0^Ool003Aoo`04001oogoo?Nl5O004?Nn1Ool00`00Oomoo`08Ool7?Nl6Ool6O40600000ga0
Oomoo`020003Ool00`00Oomoo`0_Ool0039oo`80009oo`03?Nml07`000=l00Dmkh5oo`03001oogoo
00Yoo`Dmk`Ioo`El@003OomlP00000@0009l@0=oo`800003Ool007oo031oo`00<Goo00<007ooOol0
0Woo1W`01Cg_PWoo00<007ooOol02Goo1Sg_1Woo17a00Woo00=mh000000017a01P00<Woo000`Ool0
0`00Oomoo`02Ool6O006?Nn2Ool00`00Oomoo`09Ool6?Nl6Ool5O4000gooON000003O4020002O402
Ool4000`Ool002moo`03001oogoo009oo`03?Nml07`000Al00DmkhAoo`03001oogoo00Yoo`Dmk`Eo
o`Il@005ON0007a0O4000004O4000gcP00000002Ool2000_Ool002ioo`03001oogoo00=oo`03?Nml
07`0009l00HmkhIoo`03001oogoo00Uoo`Dmk`Eoo`Il@004ON0007gP0002O40300000ga000000003
Ool2000^Ool002ioo`03001oogoo009oo`03?Nml07`000Al00<mkhUoo`03001oogoo00Uoo`Dmk`Eo
o`Il@0800003O81l@000009l@0800003O40007oo009oo`03001oo`0002eoo`00;Goo00<007ooOol0
0Woo0Sg_1G`00cg_Rgoo0P002Goo1Sg_17oo1ga000H007gPO80007a00002O4020004Ool00`00Ool0
000/Ool002aoo`03001oogoo00=oo`03?Nml07`000Al00<mkheoo`8000Qoo`Hmk`Aoo`El@0@00004
O80007a0O40200000gcPOomoo`03Ool2000/Ool002]oo`03001oogoo00=oo`03?Nml07`000Al00@m
khmoo`03001oogoo00Ioo`Dmk`Aoo`Al@004001l@7a0O405000017a0001l@7cP1Goo00<007ooOol0
:Woo000ZOol00`00Oomoo`04Ool6O002?NnCOol00`00Oomoo`06Ool5?Nl3Ool017h0ON1mh7a01000
00Al@000001l@080009l@003O@0mkgoo00Aoo`03001oogoo02Uoo`00:Woo00<007ooOol00goo00<m
kg`0O00017`0UWoo1@000goo1Cg_0Woo0Wh00WgP0P001Wa000<007a0O4000Wa000=lh7d0Ool017oo
00<007ooOol0:Goo000YOol00`00Oomoo`04Ool00cg_O01l0002O02MOol20002Ool5?Nl500000gh0
001l@00:O402O>000gd0Oomoo`02Ool2000ZOol002Qoo`03001oogoo00Aoo`03?Nml07`000=l09mo
o`L000In0003001ooga000Ul@0Alh0=oo`03001oo`0002Uoo`009goo00<007ooOol017oo00<mkg`0
O00017`0XWoo0cg_1Wh000=oo`00Ool00Woo27a017cP00Am07ooOol0009oo`03001oogoo02Ioo`00
9Woo00<007ooOol01Goo1W`00Sg_XGoo0Sg_1gh000=oo`00Ool01Goo00Amh7g0OL1m00Ilh003Ool0
07oo00=oo`03001oogoo02Eoo`009Woo00<007ooOol017oo1g`00Sg_XGoo27h00goo00<007ooOol0
17oo17g01GcP00<007ooOol00goo00<007ooOol09Goo000UOol00`00Oomoo`04Ool00cg_O01l0003
O003?NnPOol:OP04Ool00`00Oomoo`04Ool4OL04O>000`00Oomoo`04Ool00`00Oomoo`0TOol002Ao
o`03001oogoo00Eoo`03?Nml07`0009l00<mkimoo`]n00<mk`9oo`03001oogoo00Aoo`Am`09lh080
00=lh0Eoo`03001oogoo02=oo`008goo00<007ooOol01Goo00<mkg`0O00017`00Sg_WWoo2Gh01cg_
0Woo0P0017oo1Gg000<007cPO>000gcP1Woo00<007ooOol08Woo000ROol00`00Oomoo`05Ool00cg_
O01l0004O002?NnNOol:OP09?Nl2Ool20003Ool2OL0200000gd0O>1lh004O>06Ool00`00Oomoo`0Q
Ool0029oo`03001oogoo00Eoo`03?Nml07`000Al008mkiaoo`Yn00Aoo`Pmk`=oo`D0009m`09m00El
h0Ioo`03001oogoo025oo`008Goo00<007ooOol01Goo00<mkg`0O0000g`00cg_Vgoo2Wh01Woo2Cg_
27oo0cg_00=m07cPO>000WcP00<mkgooOol017oo00<007ooOol087oo000POol00`00Oomoo`06Ool6
O0000cg_Oomoo`2JOol8OP0<Ool7?Nl9Ool00cg_O@1lh004O>000cg_Oomoo`04Ool00`00Oomoo`0O
Ool0021oo`03001oogoo00Eoo`Il0003?Nmoogoo08Qoo`9n00=oo`03OP1oogoo00Uoo`Un00eoo`Tm
k`Qoo`03?Nmlh7cP00=lh003?Nmoogoo00Aoo`03001oogoo01moo`007goo00<007ooOol01Woo1W`0
QWoo0Wh00Woo27h02Goo2Wh047oo23g_1goo1GcP0`001Goo00<007ooOol07Woo000OOol00`00Oomo
o`05Ool00cg_O01l0002O002?Nn2Ool2OP000gooOP1n000AOP02Ool9OP0COol9?Nl5Ool00gd0O>1l
h0020002O>000goo001oo`04Ool00`00Oomoo`0MOol001ioo`03001oogoo00Eoo`03?Nml07`000Al
0003?Nmoogoo07]oobAn01Ioo`Xmk`Eoo`03O>0007cP00=lh003001oogoo00=oo`03001oogoo01eo
o`007Goo00<007ooOol01Woo00<mkg`0O0000g`00Sg_NGoo9gh06Goo3Cg_00<007cPO>000gcP00=o
o`00Ool017oo00<007ooOol077oo000MOol00`00Oomoo`05Ool00cg_O01l0004O002?NmdOolIOP02
Ool>OP0NOol;?Nl00`00O@1lh004O>000`00Oomoo`03Ool00`00Oomoo`0LOol001aoo`03001oogoo
00Eoo`03?Nml07`000Al008mkg1oo`9n009ooaEn00aoo`Un021oo`Xmk`03001lh7cP009lh003001l
h000008000=oo`03001oogoo01]oo`0077oo00<007ooOol01Goo00<mkg`0O0000g`00cg_K7oo0Wh0
00=oogh0OP004Wh0?Goo23g_0P000WcP0`0000=lh7ooOol00P0000=oo`00Ool077oo000KOol00`00
Oomoo`05Ool00cg_O01l0004O003?NmZOolDOP17Ool4?Nl00gd00000000900000goo001oo`0KOol0
01]oo`03001oogoo00Eoo`Il00<mkfAoo`9n009ooa=n04moo`04?Nmm00000004O>03Ool3000LOol0
01Yoo`03001oogoo00Eoo`Il00@mkemoo`9n009ooaEn05=oo`8000Elh0Aoo`03001oo`0001]oo`00
6Woo00<007ooOol017oo00<mkg`0O00017`00cg_GWoo5Wh0F7oo00<003g_O>001GcP0goo0`006goo
000IOol00`00Oomoo`05Ool00cg_O01l0002O004?NmHOol5000DOP1LOol00`00?Nmlh005O>03Ool0
1000Ool000006Woo000IOol00`00Oomoo`04Ool6O002?NmJOol01@00OP1n07h0000047h0H7oo00<0
07ooOol01WcP00@mkgoo001oo`8001Yoo`0067oo00<007ooOol017oo00<mkg`0O00017`00Sg_FGoo
00<007h0OP000Wh000<007h0OP002Gh0IGoo00<007ooOol01WcP0Woo00D007oo001oo`0001Uoo`00
67oo00<007ooOol017oo1W`00Sg_FGoo0Wh000D007h0OP1n000000In06Yoo`80008mk`Elh007?Nl0
07ooOol007oo00006Goo000HOol00`00Oomoo`04Ool6O0000cg_Oomoo`1HOol2OP0200000gh00000
0002OP1^Ool300000cg_O>1lh002O>020003Ool00`00Ool0000IOol001Moo`03001oogoo00Aoo`Il
008mkeUoo`En0003001n07oo071oo`03001oogoo00D00003O>0mkcg_009oo`04001oogoo000HOol0
01Ioo`03001oogoo00Eoo`El00<mkeQoo`In07Aoo`04001oocg_?Nl4O>03?Nl01@00Oomoogoo0000
67oo000FOol00`00Oomoo`04Ool00cg_O01l0003O003?NmGOol7OP1dOol200000goo?Nlmk`04?Nl2
00000cg_Oomoo`02Ool00`00Oomoo`0EOol001Eoo`03001oogoo00Eoo`03?Nml07`000=l008mkeMo
o`In07Qoo`<0008mk`80008mk`Ioo`03001oogoo01Aoo`005Goo00<007ooOol01Goo00<mkg`0O000
0W`00Sg_Egoo1Wh0Ngoo00<mk`0000000cg_1goo00<007ooOol057oo000DOol00`00Oomoo`06Ool6
O0000cg_Oomoo`1DOol6OP1lOol6?Nl8Ool00`00Oomoo`0COol001Aoo`03001oogoo00Ioo`El0003
?Nmoogoo05Eoo`En07ioo`Dmk`Qoo`03001oogoo01=oo`0057oo00<007ooOol01Goo00<mkg`0O000
0g`000<mkgooOol0E7oo1Wh0OWoo1Cg_27oo00<007ooOol04goo000COol00`00Oomoo`06Ool00cg_
O01l0002O0000cg_Oomoo`1DOol6OP1oOol6?Nl8Ool00`00Oomoo`0BOol001=oo`03001oogoo00Io
o`03?Nml07`0009l0003?Nmoogoo05=oo`Mn07ioo`Lmk`Qoo`03001oogoo019oo`004goo00<007oo
Ool01Woo1W`0EGoo1Gh0P7oo1cg_27oo00<007ooOol04Woo000BOol00`00Oomoo`07Ool5O0000cg_
Oomoo`1BOol6OP20Ool7?Nl8Ool00`00Oomoo`0BOol0019oo`03001oogoo00Moo`El05Aoo`Mn081o
o`Lmk`Uoo`03001oogoo015oo`004Woo00<007ooOol01Woo00<mkg`0O0000W`000<mkgooOol0DGoo
1gh0PGoo1cg_2Goo00<007ooOol04Goo000BOol00`00Oomoo`06Ool00cg_O01l0003O019Ool7OR02
Ool00ghPOP1n0003OP26Ool4?Nl9Ool00`00Oomoo`0AOol0015oo`03001oogoo00Moo`03?Nml07`0
009l0003?Nmoogoo04Aoo`in80=n08Moo`Dmk`Uoo`03001oogoo011oo`004Goo00<007ooOol01goo
1G`0@goo4ghP00=n07ooOol0QWoo1Cg_2Goo00<007ooOol047oo000AOol00`00Oomoo`07Ool5O000
0cg_Oomoo`0kOol300000gooOR1n800BOR29Ool5?Nl9Ool00`00Oomoo`0@Ool0015oo`03001oogoo
00Moo`Al008mkcaoo`05001n87hPOR00000DOR29Ool5?Nl:Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo00Qoo`Al0003?Nmoogoo03Ioo`En8005001n87hPOR000009OR03Ool7OR2;Ool4?Nl:Ool00`00
Oomoo`0?Ool0011oo`03001oogoo00Qoo`Al0003?Nmoogoo03Ioo`En8005001n87hPOR000007OR07
Ool4OR2<Ool4?Nl:Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`Al0003?Nmoogoo03Eoo`In
80800003OR00000000=n89]oo`@mk`Yoo`03001oogoo00moo`0047oo00<007ooOol027oo17`000<m
kgooOol0=Goo27hP00<007hPOR00WWoo13g_2Woo00<007ooOol03goo000?Ool00`00Oomoo`09Ool4
O0000cg_Oomoo`0dOol6OR2TOol4?Nl;Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Al0003
On1oogoo03Aoo`En8:Eoo`@mk`]oo`03001oogoo00ioo`003goo00<007ooOol02Goo17`000=oh7oo
Ool0<goo1WhPYGoo13g_2goo00<007ooOol03Woo000?Ool00`00Oomoo`09Ool4O002On0dOol6OR2U
Ool5?Nl:Ool00`00Oomoo`0>Ool000moo`03001oogoo00Uoo`Ioh003?Nmoogoo031oo`In8:Ioo`Dm
k`]oo`03001oogoo00eoo`003Woo00<007ooOol02Woo00<mkgoPOn0017oP00=nH7i0OT000Wi0;Goo
1WhPYWoo1Cg_2goo00<007ooOol03Goo000>Ool00`00Oomoo`0:Ool00cg_On1oh002On03OV05OT0[
Ool6OR2WOol5?Nl;Ool00`00Oomoo`0=Ool000ioo`03001oogoo00aoo`9oh0AnH0In@2Yoo`En8:Uo
o`@mk`]oo`03001oogoo00eoo`003Woo00<007ooOol037oo0WoP17iP1gi0:7oo1WhPZGoo13g_2goo
00<007ooOol03Goo000>Ool00`00Oomoo`0=Ool00goPOV1nH002OV08OT0WOol5OR2ZOol4?Nl<Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00ioo`03On1nH7iP00=nH0Qn@2Eoo`In8:Yoo`@mk`aoo`03
001oogoo00aoo`003Goo00<007ooOol03Woo00=oh7iPOV000giP00=oogi0OT001Wi097oo1GhPZgoo
1Cg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0>Ool00goPOV1nH003OV02Ool8OT0SOol5OR2[
Ool5?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`9oh0EnH09oo`03?Nmn@7i000In@0<0
01ioo`In8:Yoo`Hmk`]oo`03001oogoo00aoo`003Goo00<007ooOol03Goo0WoP1GiP13g_1Gi00P00
0gi000<007i0OT000Wi067oo1WhPZgoo1Sg_2goo00<007ooOol037oo000=Ool00`00Oomoo`0=Ool3
On05OV04?Nl4OT000`00OT1n@002OT000`00OT1n@002OT0HOol6OR2[Ool6?Nl;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00]oo`03?Nmoh7oP009oh0InH0@mk`9n@003001n@7i000=n@003001n@7i0
009n@1Qoo`En8:aoo`Hmk`]oo`03001oogoo00aoo`003Goo00<007ooOol02Goo0cg_17oP1WiP00<m
kgiP?Nl00Sg_0Wi000<007i0OT000Wi000<007i0OT000Wi05goo1WhP[7oo1Sg_2goo00<007ooOol0
37oo000=Ool00`00Oomoo`08Ool3?Nl5On0:OV03?Nl200000gi000000005OT0FOol6OR2/Ool7?Nl;
Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`<mk`Eoh003?NmnH7iP00QnH005?NmnH3g_?Nl0
0003?Nl4OT0EOol7OR2/Ool7?Nl;Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qoo`8mk`Ioh09o
o`anH0Dmk`An@1Eoo`In8:eoo`Lmk`aoo`03001oogoo00]oo`0037oo00<007ooOol02Goo0Sg_1WoP
0goo3giP00<mkgi0OT000gi04Woo27hP[Goo23g_2goo00<007ooOol02goo000<Ool00`00Oomoo`08
Ool2?Nl6On07?Nl=OV05OT0>Ool50005OR2`Ool7?Nl;Ool00`00Oomoo`0;Ool000aoo`03001oogoo
00Qoo`03?Nmoh7oP00Aoh0Xmk`]nH0En@0aoo`03OV0007iP009nH09n808000=n8;1oo`Lmk`]oo`03
001oogoo00]oo`0037oo00<007ooOol027oo00<mkgoPOn0017oP3Cg_27iP1Wi02Woo0WiP00<007iP
OV001GhP00<007hPOol0/7oo1cg_2goo00<007ooOol02goo000<Ool00`00Oomoo`08Ool00cg_On1o
h002On0A?Nl7OV06OT0:OV000`00OV1nH007OR000`00Oomoo`2_Ool7?Nl;Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo00Qoo`03?Nmoh7oP009oh004?NmoogooOol??Nl2Ool3OV06OT0:OV000`00OT1n
@005OR02OV000`00Oomoo`2_Ool7?Nl;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Qoo`Ioh0Qo
o`/mk`03OomnH7iP009nH0Mn@0QnH003001n@7i000En809nH003001oogoo0:moo`Lmk`]oo`03001o
ogoo00]oo`0037oo00<007ooOol027oo1GoP00<mkgooOol027oo1Sg_27oo27i00WiP00=n@7iPOT00
0Wi000<007i0OT001GhP0WiP00<007ooOol0/7oo1Sg_2goo00<007ooOol02goo000<Ool00`00Oomo
o`07Ool00cg_On1oh003On000cg_Oomoo`09Ool5?Nl:Ool=OT000`00OT1n@004OR03OV000`00Oomo
o`2`Ool6?Nl;Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Moo`03?Nmoh7oP009oh003?Nmoogoo
00Uoo`Lmk`Yoo`en@005001n@7i0OT1oo`04OV000`00Oomoo`2`Ool6?Nl;Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo00Moo`Ioh0]oo`Tmk`Qoo`en@0800003OT1oogoo009nH080009nH;9oo`Dmk`]o
o`03001oogoo00]oo`0037oo00<007ooOol01goo1GoP37oo2Sg_2Goo37i000=oo`0000000`000giP
/goo1Cg_2goo00<007ooOol02goo000<Ool00`00Oomoo`07Ool5On0<Ool:?Nl=Ool5OT08Ool4OV2c
Ool6?Nl:Ool00`00Oomoo`0;Ool000eoo`03001oogoo00Ioo`Aoh003?Nmoogoo00Yoo`/mkaUoo`An
H;=oo`Hmk`Yoo`03001oogoo00]oo`003Goo00<007ooOol01Woo17oP00<mkgooOol03Woo1cg_6Goo
17iP]7oo1Cg_2Goo00<007ooOol037oo000=Ool00`00Oomoo`06Ool4On000cg_Oomoo`0>Ool8?NlH
Ool4OV2dOol5?Nl9Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Ioo`Eoh11oo`PmkaQoo`AnH;Ao
o`Dmk`Uoo`03001oogoo00aoo`003Goo00<007ooOol01Woo1WoP3goo23g_67oo1GiP/goo1Cg_2Goo
00<007ooOol037oo000=Ool00`00Oomoo`06Ool5On02?Nl?Ool8?NlGOol5OV2cOol5?Nl9Ool00`00
Oomoo`0<Ool000eoo`03001oogoo00Moo`Aoh08mk`moo`PmkaMoo`EnH;=oo`Dmk`Uoo`03001oogoo
00aoo`003Goo00<007ooOol01goo17oP00<mkgooOol03Woo23g_5goo1GiP/goo1Cg_2Goo00<007oo
Ool037oo000=Ool00`00Oomoo`07Ool4On02?Nl?Ool:?NlFOol4OV2cOol5?Nl9Ool00`00Oomoo`0<
Ool000eoo`03001oogoo00Moo`Eoh003?Nmoogoo00eoo`XmkaIoo`AnH;=oo`Dmk`Uoo`03001oogoo
00aoo`003Goo00<007ooOol01goo1GoP4Goo2Cg_5Woo17iP/Woo1cg_27oo00<007ooOol037oo000>
Ool00`00Oomoo`06Ool5On000cg_Oomoo`0@Ool7?NlFOol4OV2bOol6?Nl9Ool00`00Oomoo`0<Ool0
00ioo`03001oogoo00Ioo`Eoh003?Nmoogoo011oo`DmkaQoo`AnH;9oo`Dmk`Uoo`03001oogoo00eo
o`003Woo00<007ooOol01goo17oP00<mkgooOol047oo1Cg_67oo17iP/Woo1Cg_2Goo00<007ooOol0
3Goo000>Ool00`00Oomoo`07Ool4On000cg_Oomoo`0]Ool4OV2aOol6?Nl9Ool00`00Oomoo`0=Ool0
00ioo`03001oogoo00Moo`Eoh003?Nmoogoo02aoo`AnH;5oo`Dmk`Yoo`03001oogoo00eoo`003goo
00<007ooOol01Woo1GoP00<mkgooOol0;7oo17iP/Goo1Cg_2Woo00<007ooOol03Goo000?Ool00`00
Oomoo`06Ool5On02?Nl]Ool4OV2aOol5?Nl9Ool00`00Oomoo`0>Ool000moo`03001oogoo00Ioo`Eo
h08mkbeoo`AnH;1oo`Hmk`Uoo`03001oogoo00ioo`003goo00<007ooOol01goo1GoP00<mkgooOol0
:goo1GiP[goo1Cg_2Woo00<007ooOol03Woo000?Ool00`00Oomoo`07Ool5On000cg_Oomoo`0[Ool6
OV2^Ool5?Nl:Ool00`00Oomoo`0>Ool0011oo`03001oogoo00Ioo`Eoh003?Nmoogoo02]oo`InH:io
o`Dmk`Uoo`03001oogoo00moo`0047oo00<007ooOol01Woo1GoP;goo1GiP[Woo13g_2Woo00<007oo
Ool03goo000@Ool00`00Oomoo`06Ool00cg_On1oh002On0_Ool6OV2/Ool5?Nl:Ool00`00Oomoo`0?
Ool0011oo`03001oogoo00Ioo`03?Nmoh7oP009oh2ioo`03OX1nH7iP00AnH:aoo`Dmk`Yoo`03001o
ogoo00moo`004Goo00<007ooOol01Goo00<mkgoPOn000WoP00<mkgooOol0:goo0Wj01GiP[7oo13g_
2goo00<007ooOol03goo000AOol00`00Oomoo`05Ool00cg_On1oh003On000cg_Oomoo`0ZOol2OX05
OV2[Ool5?Nl:Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Eoo`03?Nmoh7oP00Aoh2aoo`AnP:eo
o`Hmk`Yoo`03001oogoo011oo`004Goo00<007ooOol01Woo1GoP;Goo17j0[7oo1cg_2Woo00<007oo
Ool047oo000AOol00`00Oomoo`06Ool00cg_On1oh002On0]Ool4OX2/Ool7?Nl9Ool00`00Oomoo`0A
Ool0019oo`03001oogoo00Eoo`03?Nmoh7oP009oh2eoo`04OX000000OX2[Ool7?Nl:Ool00`00Oomo
o`0AOol0019oo`03001oogoo00Eoo`03?Nmoh7oP009oh2aoo`80009nP0800:Yoo`Lmk`Yoo`03001o
ogoo015oo`004goo00<007ooOol01Goo17oP;7oo00<007j0OX000Wj000=oo`00Ool0Z7oo1cg_2Woo
00<007ooOol04Goo000COol00`00Oomoo`05Ool4On000cg_Oomoo`0XOol00`00OomnP003OX02Ool0
0`00Oomoo`2VOol6?Nl:Ool00`00Oomoo`0BOol001=oo`03001oogoo00Eoo`Aoh003?Nmoogoo02Qo
o`03001oogj000=nP09oo`03001oogoo0:Eoo`Lmk`Yoo`03001oogoo019oo`004goo00<007ooOol0
1Goo17oP00<mkgooOol0:Goo00<007j0OX000Wj000=oo`00Ool0Ygoo1cg_2Woo00<007ooOol04Woo
000DOol00`00Oomoo`04Ool4On02?NlZOol00`00OX1nP002OX000goo001oo`2WOol6?Nl:Ool00`00
Oomoo`0COol001Aoo`03001oogoo00Aoo`Eoh003?Nmoogoo02Uoo`800003OX0000000:Uoo`Hmk`Yo
o`03001oogoo01=oo`0057oo00<007ooOol017oo1GoP00<mkgooOol0:Goo0Wj000<007j0Ool0XWoo
3Cg_2Woo00<007ooOol04goo000EOol00`00Oomoo`03Ool00cg_On1oh003On0[Ool4OX2TOol;?Nl:
Ool00`00Oomoo`0DOol001Eoo`03001oogoo00Aoo`Aoh003?Nmoogoo02Uoo`EnP:Aoo`Xmk`Yoo`03
001oogoo01Aoo`005Woo00<007ooOol00goo17oP00<mkgooOol0:Goo1Wj0Y7oo2Cg_2Goo00<007oo
Ool05Goo000FOol00`00Oomoo`03Ool5On0[Ool5OX2UOol9?Nl9Ool00`00Oomoo`0EOol001Moo`03
001oogoo009oo`Ioh2]oo`AnP:Eoo`Pmk`Uoo`03001oogoo01Ioo`0067oo00@007ooOomoo`Eoh003
?Nmoogoo02Uoo`EnP:Aoo`Pmk`Uoo`03001oogoo01Ioo`0067oo00D007ooOomoocg_00Aoh003?Nmo
ogoo02Uoo`InP:=oo`Pmk`Qoo`03001oogoo01Moo`0067oo00D007ooOomoocg_00Aoh003?Nmoogoo
02Uoo`EnP:9oo`Xmk`Qoo`03001oogoo01Moo`006Goo00@007ooOomoo`Eoh003?Nmoogoo02Uoo`En
P:1oo`/mk`Moo`03001oogoo01Qoo`006Goo00@007ooOomoo`Ioh003?Nmoogoo02Qoo`InP9ioo`/m
k`Qoo`03001oogoo01Qoo`006Woo00<007ooOol017oP0P000Sg_:Goo1gj0W7oo33g_1goo00<007oo
Ool06Goo000JOol01@00Oomoocg_On000P0000Aoh3g_000mkb]oo`EnP9Qooa0mk`Moo`03001oogoo
01Uoo`006goo00@007ooOol000Aoh004?Nl003g_?NlYOol6OX2GOol??Nl7Ool00`00Oomoo`0JOol0
01]oo`04001oogoo0005On0013g_000mkcg_:7oo1Wj0UWoo23g_00=oocg_?Nl01Cg_1goo00<007oo
Ool06Woo000LOol20006On0013g_000mkcg_0Woo0Wo09Goo1Wj0UGoo1cg_0Woo1cg_1Woo00<007oo
Ool06goo000LOol200000cg_On1o`003Ol000cg_000mk`02?Nl4Ol0TOol6OX2EOol5?Nl4Ool7?Nl6
Ool00`00Oomoo`0KOol001eoo`03001oogoP00Eo`003001o`7o000Io`2Aoo`InP9=oo`Dmk`Ioo`Hm
k`Eoo`03001oogoo01aoo`007Goo0P0000=oh7o0Ol000go000<007o0Ol001Go09Goo1gj0TWoo1Cg_
1Woo1Cg_1Woo00<007ooOol077oo000NOol00`00?Nmo`003Ol000`00Ol1o`006Ol0WOol5OX2BOol4
?Nl6Ool6?Nl5Ool00`00Oomoo`0MOol001moo`D000Yo`2Ioo`InP95oo`Dmk`Eoo`Dmk`Ioo`03001o
ogoo01eoo`007goo00<mkgo0Ol003Go09Goo1gj0Sgoo1Sg_17oo1Sg_1Goo00<007ooOol07Woo000P
Ool3?Nl5Ol000cg_Ol1o`004Ol0WOol5OX2?Ool5?Nl4Ool7?Nl4Ool00`00Oomoo`0OOol0021oo`Xm
k`Io`2Ioo`InP8ioo`Dmk`Aoo`Hmk`Eoo`03001oogoo01moo`008Goo00<003g_?Nl01Sg_1Wo09Woo
1Wj0SGoo1Sg_17oo1Sg_17oo00<007ooOol087oo000ROol9?Nl5Ol0WOol6OX2<Ool5?Nl4Ool7?Nl3
Ool00`00Oomoo`0QOol0029oo`03000mkcg_00Hmk`Eo`2Moo`MnP8Yoo`Dmk`Eoo`Lmk`=oo`03001o
ogoo025oo`008goo2Cg_1Go0:7oo1Wj0RGoo1Cg_1Goo1Sg_0goo00<007ooOol08Woo000TOol00`00
?Nlmk`05?Nl6Ol0XOol5OX29Ool5?Nl4Ool6?Nl3Ool00`00Oomoo`0SOol002Eoo`03000mkcg_00@m
k`Eo`2Uoo`EnP8Qoo`Hmk`Aoo`Hmk`9oo`03001oogoo02Aoo`009Woo00<003g_?Nl013g_17o0:Goo
1Wj0QWoo1Sg_17oo1cg_00=oo`00Ool09Woo000VOol00`00?Nlmk`04?Nl5Ol000cg_Oomoo`0UOol6
OX0mOol50014Ool6?Nl3Ool7?Nl2Ool00`00Oomoo`0UOol002Moo`03000mkcg_00<mk`Io`003?Nmo
ogoo02Aoo`InP3aoo`03001oogoo00=oo`80049oo`Hmk`9oo`Pmk`03Ool007oo02Moo`00:7oo00<0
07oo?Nl00Sg_1Wo000<mkgooOol097oo1Wj0?7oo00<007ooOol01Goo00<007ooO/001gk0=goo1Sg_
0Woo23g_00=oo`00Ool0:7oo000YOol00`00?Nlmk`02?Nl6Ol000cg_Oomoo`0SOol5OX0lOol00`00
Oomoo`05Ool2O/000`00O/1n`007O/0017oo00000000<Woo1Cg_00=oocg_?Nl023g_00<007ooOol0
:7oo000ZOol01000Oomoocg_1Go00Sg_9Goo1Gj0?7oo00<007ooOol01gk000<007k0O/001Wk00P00
00An`7ooOol0035oo`@mk`9oo`Xmkb]oo`00:Woo00<007ooOol00Sg_1Go00Sg_97oo17j0?7oo00<0
07ooO/0027k000<007k0O/001Wk000H007k0O/1n`7oo000`Ool5?Nl2Ool9?Nl00`00Oomoo`0YOol0
02]oo`04001oocg_?Nl6Ol02?NlSOol4OX0lOol00`00O/1n`008O/000`00O/1n`005O/000`00O/1n
`002O/02O^000`00Oomoo`0]Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0ZOol002aoo`03001oogoo
00Qo`2=oo`AnP3aoo`03001n`7k000Qn`003001n`7oo00Aoo`03O/0007k000=n`09nh004001nh7oo
O^0[Ool5?Nl00goo?Nlmk`07?Nl00`00Oomoo`0[Ool002eoo`03001oocg_00Qo`29oo`AnP3]oo`9n
`003001n`7k000An`09oo`8000Moo`03O/0007k0009n`09nh003001nh7kP009nh2Yoo`hmk`03001o
ogoo02aoo`00;Woo00<007ooOl001go00Sg_87oo17j0>Woo17k000@007k0O/1n`0=oo`03001oogoo
00Qoo`80009nh08000Inh2Uoo`dmk`03001oogoo02eoo`00;Woo00<007ooOol027o00Sg_7Woo1Gj0
>Goo1Wk00P000Woo0P003Goo0P001WkP10009goo33g_00=oo`00Ool0;Woo000_Ool00`00Oomoo`08
Ol0013g_000000006goo1Gj0>7oo1gk00Woo0P004Goo1WkP00D007kPO^1nh00002Eoo`/mk`9oo`03
001oogoo02ioo`00<7oo00@007ooOolmk`Eo`08000<mk`03001oogoo01Qoo`EnP3Moo`Qn`1Moo`D0
00Anh003001nh7kP029oo`Tmk`=oo`03001oogoo02moo`00<Goo00D007ooOomoocg_00=o`006001o
X7nPOj0mk`000Sg_67oo1Gj0=Woo27k05goo00H007ooOomoo`00O^0300000gkP001nh008O^0JOol9
?Nl3Ool00`00Oomoo`0`Ool0039oo`80009oo`03?Nmo`00000EoX003?Nl003g_008mkaIoo`InX3Ao
o`Mn`1Qoo`03001oogoo009oo`03O^0007kP009nh08000]nh0]oo`Anh0Moo`Xmk`9oo`8003=oo`00
=7oo00D007ooOolmk`0000IoX004000mkcg_?NlFOol6OZ0cOol8O/0HOol00`00Oomo@003Od06000=
O^07Ool8O^03Ool:?Nl3Ool00`00Oomoo`0cOol003Eoo`05001oocg_?Nl00005Oj000`00?Nlmk`02
?NlFOol6OZ0aOol8O/0HOol00`00Od1o@005Od03Ool00gkP001nh00=O^05Ool9O^000gl0?Nlmk`09
?Nl3Ool00`00Oomoo`0dOol003Ioo`03001oogoo0080009oX080009oX0@mkaEoo`InX2moo`Mn`1Yo
o`03Od0007m000Io@0Aoo`03001oogoo00=ooaMnh09o00Xmk`9oo`03001oogoo03Eoo`00=goo00@0
07ooOomoX08000AoX0@mkaIoo`InX2ioo`In`1Yoo`03Od0007m000Mo@0Aoo`03001oogoo00EooaEn
h09o00Lmk`Aoo`03001oogoo03Ioo`00=goo00@007ooOomoo`MoX0<mkaIoo`InX2eoo`In`1]oo`03
Od0007m000Mo@0Aoo`03001oogoo00Mooa=nh0=o00Hmk`Aoo`03001oogoo03Ioo`00>7oo00@007oo
Oomoo`QoX08mkaIoo`InX2]oo`Mn`1Yoo`9o@003001o@7m000Io@0Aoo`03001oogoo00Uoo`]nh0=o
o`Io00@mk`Eoo`03001oogoo03Moo`00>Goo0P000Woo27nP0Sg_5Goo1WjP:Woo1gk06goo0Wm000D0
07m0Od1o@7oo00Ao@005Of1oogooOol0000=Ool8O^04Ool6O`04?Nl3Ool2000jOol003]oo`04001o
ogooOol7Oj02?NlEOol5OZ0ZOol5O/0KOol5Od001000Od1oogoo1GmP0Woo00<007ooOol03Woo17kP
1Goo1gl00cg_0goo00<007ooOol0>Woo000lOol01000Oomoogoo1gnP00<mkgooOol04goo1WjP:7oo
1Wk06goo1Wm00P0000=oogmPOf000gmP0P0067oo27l000<mkgooOol00goo00<007ooOol0>goo000m
Ool00`00Oomoo`08Oj02?NlCOol7OZ0VOol7O/0KOol6Od02Ool20002Of0200000gmPOomoo`0FOol0
0cg_O`1o0004O`02?Nl5Ool00`00Oomoo`0lOol003ioo`80009oo`03?NmoX7nP00AoX0<mka9oo`In
X2Eoo`Mn`1aoo`Eo@0Eoo`80009oH0<001Aoo`03?Nmo07l000Eo008mk`Aoo`8003moo`00@7oo0P00
00=oocg_Oj001GnP0cg_4Woo1GjP97oo1Wk07Woo17m01Woo0gmP00@007mPOf1oH080015oo`03?Nmo
07l000Io008mk`=oo`03001oogoo03moo`00@Woo00<003g_?Nl01gnP0cg_47oo1WjP8Woo1Wk07goo
17m01goo00=oH000Of0017mP00<007ooOol03Goo0Sg_27l000@mkgooOomoo`80049oo`00A7oo0Sg_
1gnP0cg_47oo1WjP6goo0`000Woo1gk07Woo1Wm01Woo00<007mPOf0017mP00<007ooOol027oo1Sg_
1gl000@mkgooOomoo`8004Aoo`00AGoo00<003g_Oj001WnP0cg_27oo00<mkgooOol017oo1gjP6Goo
00D007jPOZ1nX00000Qn`1ioo`Eo@0Moo`03001oH7mP00AoH003001oogoo00Qoo`@mk`Uo00=oo`03
001oogoo04Aoo`00AWoo00<003g_Oj001gnP0cg_1Goo0Sg_27oo1GjP67oo00<007jPOZ000WjP00<0
07k0O/001Gk07goo1Gm027oo00<007mPOf000WmP00<007ooOol027oo13g_1gl000@mkgooOomoo`80
04Moo`00B7oo2GnP00@mkgnP?Nlmk`9oo`<mk`Qoo`InX1Ioo`9nX005001nX7jPOZ000006O/0POol4
Od09Ool20002Of020002Of07Ool4?Nl7O`001Cg_Oomoogoo0000BGoo0019Ool00`00Oj1oX009Oj05
?Nl8Ool7OZ0EOol2OZ0200000gjP001n`005O/0QOol4Od0:Ool00gmP00000005Of02Ool00cg_Oolm
k`02?Nl9O`000cg_Oomoo`02001:Ool004Yoo`ioX0<mk`Uoo`InX1=oo`EnX003001nX7k000An`29o
o`Ao@0aoo`9oH0H000<mk`]o0003Ool0000004aoo`00C7oo3gnP0Sg_00Aoo`00000000Aoo`EnX19o
o`MnX2Qoo`Ao@09o8003Oomo87oo00Moo`03Of0007mP00=oH0@000Yo0003Ool0000004ioo`00CWoo
3WnP00Hmk`00?Nlmkgoo0003Ool6OZ0@Ool7OZ0YOol2Od07Ob07Ool60003O`030007O`000goo001o
o`1?Ool0051oo`03001oX7nP00YoX003001oX7nP009oX003001oogoo00MnX0moo`EnX2]oo`9o@0Yo
809oo`<00003Oomo07l0008000=o0003001o000000Eo0003Ool00000055oo`00DWoo00<007nPOj00
1gnP00<007nPOj000gnP00@007nPOj0mk`InX0H000Qoo`InX2aoo`03Od1o87lP00Uo8003001o8000
009oo`05O`0007l0O`000002O`001000O`1o00000Wl000=oo`000000Dgoo001DOol200000cg_Oj1o
X004Oj000`00Oj1oX002Oj001000Oj1oX7nP0Sg_0gjP00<007jPOZ000Woo0Sg_00<003g_?Nl017oo
1WjP:goo1P0027lP00<007l000000gl000@007l0O`00009o0004001o07l00002?Nl00`00Oomoo`1C
Ool005Ioo`800003OomoX7nP009oX0800003Oj00000000IoX0=nX004001nX7jPOZ03?Nl00`00?Nlm
k`03Ool7OZ0ZOol00`00Oomoo`02Od02Ob000`00Ob1o8005Ob000`00O`000004O`000`00O`000002
O`000`00O`000004?NmEOol005Qoo`<000=oo`03Oj0007nP00MoX09nX003001nX7jP00=nX0<mk`03
000mkgoo009oo`EnX2]oo`04001oogooOol3Od02Ob000`00Ob1o8004Ob001000O`1o00000gl000D0
07l0001o0000008mk`03001oogoo05Moo`00Fgoo0`000goo27nP00=nX000OZ001WjP00<mk`00?Nl0
0Woo1WjP:goo00<007ooOb001WlP00<007lPOb000glP00AoP000O`1o008000=o00<00003Oh000000
05Yoo`00GWoo00<007ooOol00Woo1gnP00<007jPOZ001WjP00@007jP?Nlmk`InX2Yoo`03001oogoo
00Mo8003001o87lP009o80=oP080009o00L005aoo`00Ggoo0P001Goo00DmkgnPOj1oX00000QnX003
001nX7jP00InX003?Nmoogoo00Aoo`L001Qoo`8mk`9oP08mk`03001oP7lP00Io8003001o87lP009o
80EoP080009oP08005moo`00HGoo10000Woo0cg_00=oX000OZ001WjP00<007jPOZ001WjP0Sg_17oo
00<007ooOol01Goo00@007ooOomoo`8mk`eoo`03?NmoP7n000<mk`EoP003001oP7lP00Io8003001o
87lP009o80=oP0@mk`80065oo`00IGoo0`000goo00<003g_Oj000gjP0P0027jP00=oX3g_Oj000cg_
00<003g_?Nl01cg_00<003g_?Nl01Sg_0Woo00<mkgn0Oh0013g_37n000<007lPOb001GlP00<007lP
Ob000cg_0`00IWoo001XOol900000gnPOZ1nX007OZ04Oj0013g_001oX3g_1Gn013g_00<007n0Oh00
1Cg_5Gn000<007n0Oh000gn00P000Sg_1000JGoo001/Ool30003Ool>Oj000`00Oj1oX005Oh04?Nl0
0gn0001oP00KOh05000017oo00000000KGoo001_Ool40002Ool;Oj000`00Oj1oX00:Oh000`00Oh1o
P00FOh000cg_Oomoo`02Ool5001`Ool007=oo`D00003?NmoX7nP00EoX003001oX7nP00YoP003001o
P7n0011oP0Moo`@007Eoo`00N7oo100017nP00<007nPOj002Wn000<007n0Oh001gn00cg_1Goo2000
NGoo001oOol00cg_001oX002Oj08Oh000`00Oh1oP00@0021Ool0085oo`03001oogoo00Qoo`03001o
ogoo095oo`00PGoo00<007ooOol027oo00<007ooOol0TGoo0022Ool20006Ool2002DOol008Aoo`80
009oo`8009Ioo`00QWoo0P00V7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:
Ool500000goo00000003002;Ool008aoo`03001oogoo00=oo`03001oogoo08]oo`00S7oo00<007oo
Ool00goo00<007ooOol0Rgoo002<Ool00`00Oomoo`03Ool00`00Oomoo`2;Ool008aoo`03001oogoo
00=oo`03001oogoo08]oo`00Rgoo0P0017oo0P00SGoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-186.584, -182.088, 1.30024, \
1.33379}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.520903 0.00267816 0.495364 0.00277206 [
[.5 1.0125 -6 0 ]
[.5 1.0125 6 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(12)] .5 1.0125 0 -1 Mshowa
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.455287 0.471249 scale
1.14411 1.05116 1 0 365.73 arc
setmatrix s
.5 g
.015 w
.12353 .3918 m
.12362 .39168 L
.12377 .39148 L
.12394 .39122 L
.12413 .39088 L
.12433 .39044 L
.12452 .38991 L
.12471 .3893 L
.12489 .38862 L
.12509 .38787 L
.12533 .38703 L
.12559 .38612 L
.1259 .3852 L
.12619 .38424 L
.12645 .38328 L
.12672 .38237 L
.12699 .38151 L
.12726 .38066 L
.12755 .3798 L
.12786 .37889 L
.12817 .37795 L
.12843 .37701 L
.12864 .37603 L
.12878 .37497 L
.12884 .37386 L
.1288 .37277 L
.12872 .37156 L
.12862 .37038 L
.12854 .36916 L
.12848 .36788 L
.12844 .36656 L
.12842 .36535 L
.12842 .36415 L
.12841 .36304 L
.12842 .36206 L
.12844 .36119 L
.1285 .36044 L
.1286 .35978 L
.12874 .35919 L
.1289 .35859 L
.12908 .35793 L
.12926 .35719 L
.12943 .35634 L
.1296 .35533 L
.12982 .35416 L
.13011 .35306 L
.13047 .35175 L
.13091 .35038 L
.13142 .34875 L
.13198 .34723 L
Mistroke
.13256 .34548 L
.13312 .34356 L
.13368 .34177 L
.1342 .33992 L
.13469 .33812 L
.13519 .33634 L
.1357 .3349 L
.13622 .33345 L
.13673 .33213 L
.13719 .33103 L
.13758 .33 L
.1379 .32918 L
.13814 .32851 L
.13834 .32801 L
.13851 .32768 L
.1387 .32752 L
.13889 .32752 L
.13906 .32763 L
.13919 .3278 L
.13926 .32798 L
.13926 .3281 L
.13919 .32811 L
.13905 .32797 L
.13887 .32768 L
.13866 .32723 L
.13843 .32663 L
.13819 .32591 L
.13794 .32508 L
.13769 .32426 L
.13744 .32335 L
.1372 .32239 L
.13697 .32139 L
.13677 .32055 L
.13662 .31979 L
.13649 .31918 L
.1364 .31878 L
.13635 .31864 L
.13632 .31876 L
.13634 .31912 L
.13637 .31963 L
.13643 .32021 L
.1365 .32079 L
.1366 .32131 L
.13677 .32173 L
.13698 .32202 L
.13725 .32214 L
.13757 .32208 L
.13793 .32185 L
.13834 .32142 L
.13881 .32084 L
Mistroke
.13933 .32014 L
.13987 .31933 L
.14039 .31842 L
.14089 .31749 L
.14138 .31663 L
.14183 .31593 L
.14226 .31532 L
.14266 .3148 L
.14304 .31434 L
.14342 .31392 L
.14382 .31352 L
.14424 .31309 L
.14469 .31258 L
.14519 .31197 L
.1457 .31122 L
.14627 .31032 L
.14687 .30922 L
.1475 .30806 L
.1481 .30663 L
.1487 .30503 L
.14928 .30347 L
.14983 .30175 L
.1503 .30003 L
.15068 .29832 L
.15098 .29678 L
.1512 .29534 L
.15135 .29406 L
.15142 .29302 L
.15145 .29213 L
.15143 .29138 L
.15138 .29079 L
.15133 .29033 L
.15127 .29004 L
.15121 .28988 L
.15115 .28985 L
.1511 .28993 L
.15104 .29008 L
.151 .29026 L
.15098 .29043 L
.15098 .29055 L
.15104 .29061 L
.15119 .29059 L
.15147 .29046 L
.15189 .2902 L
.15245 .28981 L
.15315 .2893 L
.154 .28865 L
.15501 .28787 L
.15608 .28698 L
.15727 .28603 L
Mistroke
.15842 .285 L
.15961 .28394 L
.1608 .28292 L
.16183 .28204 L
.16282 .28129 L
.16374 .28066 L
.16454 .28017 L
.1652 .27977 L
.16574 .27945 L
.16619 .27913 L
.16654 .27877 L
.16684 .27835 L
.16711 .27783 L
.1674 .27721 L
.16773 .27647 L
.1681 .27561 L
.16851 .27473 L
.16895 .27376 L
.16942 .27275 L
.16988 .27172 L
.17036 .27076 L
.17081 .26986 L
.17124 .26909 L
.17164 .26849 L
.17199 .26806 L
.1723 .26774 L
.17253 .26748 L
.17271 .26725 L
.17283 .26698 L
.17291 .26659 L
.17298 .26606 L
.17306 .26538 L
.17318 .26458 L
.17333 .26371 L
.1735 .26293 L
.17369 .26188 L
.17389 .26089 L
.1741 .25982 L
.17429 .25867 L
.17445 .25744 L
.17458 .25622 L
.17469 .25496 L
.1748 .25363 L
.17493 .25225 L
.17508 .251 L
.17524 .24955 L
.17543 .24808 L
.17567 .24654 L
.17597 .24493 L
.17636 .24319 L
Mistroke
.17684 .24169 L
.17743 .24021 L
.17814 .23876 L
.17889 .23742 L
.1797 .23619 L
.18055 .23502 L
.18143 .23386 L
.18226 .23274 L
.18312 .23159 L
.18397 .23047 L
.1849 .22939 L
.18581 .22829 L
.1868 .22714 L
.1879 .22599 L
.18903 .22483 L
.19021 .2236 L
.19143 .2224 L
.19252 .22117 L
.19359 .21996 L
.19461 .21879 L
.19556 .21782 L
.19647 .21683 L
.19722 .21593 L
.19788 .21522 L
.19841 .21461 L
.1988 .21408 L
.19907 .21363 L
.19918 .21325 L
.19919 .21291 L
.19914 .21259 L
.19907 .21225 L
.19901 .21185 L
.19897 .21134 L
.19895 .21076 L
.19894 .2102 L
.19893 .20975 L
.19887 .20937 L
.19878 .20914 L
.19864 .20913 L
.19845 .20934 L
.19823 .2098 L
.19797 .21046 L
.19769 .2113 L
.19741 .21217 L
.19713 .21328 L
.19688 .21429 L
.19667 .2153 L
.19652 .21622 L
.19645 .21698 L
.19651 .21754 L
Mistroke
.1967 .21788 L
.19702 .21804 L
.19748 .21807 L
.19804 .21802 L
.19872 .21791 L
.19946 .21781 L
.20024 .21774 L
.20093 .21772 L
.20157 .21773 L
.20211 .21774 L
.20249 .21775 L
.20272 .21775 L
.20278 .21775 L
.20268 .21772 L
.2025 .21765 L
.20225 .21757 L
.20188 .21746 L
.20143 .21734 L
.20087 .21725 L
.2002 .21723 L
.19946 .2173 L
.19866 .21749 L
.1978 .21784 L
.19688 .21835 L
.19591 .21906 L
.19489 .22 L
.19393 .22109 L
.19289 .22241 L
.1917 .22393 L
.19022 .22558 L
.18888 .22719 L
.18748 .22892 L
.18604 .23072 L
.18467 .23245 L
.18328 .23404 L
.18191 .23559 L
.18067 .23713 L
.17953 .23852 L
.17837 .23993 L
.17719 .24138 L
.176 .2429 L
.17489 .24441 L
.17384 .24601 L
.17281 .24779 L
.17181 .24971 L
.1709 .25155 L
.17003 .25362 L
.16922 .25562 L
.16845 .25767 L
.16777 .25957 L
Mistroke
.1672 .26122 L
.16675 .26271 L
.16641 .26399 L
.16616 .26495 L
.16597 .26571 L
.1658 .26632 L
.16563 .26678 L
.16541 .26714 L
.16512 .26747 L
.16473 .26781 L
.16425 .26817 L
.16369 .26856 L
.16306 .26901 L
.16245 .26951 L
.16168 .27018 L
.16093 .27092 L
.16011 .2718 L
.15923 .27279 L
.15833 .27386 L
.15746 .27503 L
.15663 .27628 L
.15589 .27749 L
.15515 .27879 L
.15443 .28013 L
.15374 .28149 L
.15307 .28282 L
.15239 .28426 L
.15177 .28581 L
.15128 .28736 L
.15091 .28884 L
.1506 .29027 L
.15031 .2917 L
.15002 .29288 L
.14967 .29411 L
.14921 .29524 L
.14862 .29644 L
.14798 .29772 L
.14714 .29895 L
.14618 .30021 L
.14515 .3015 L
.14417 .3028 L
.14312 .30412 L
.14199 .30535 L
.14078 .3066 L
.13959 .30789 L
.13854 .30926 L
.13761 .31054 L
.13681 .31188 L
.13615 .31329 L
.1356 .31471 L
Mistroke
.13517 .31607 L
.13482 .31739 L
.13455 .31875 L
.13434 .32017 L
.13418 .32162 L
.13404 .32311 L
.13391 .32466 L
.13376 .32621 L
.13358 .32762 L
.13339 .32889 L
.13321 .33002 L
.13304 .33101 L
.13285 .33188 L
.13262 .3326 L
.13236 .33324 L
.13208 .33382 L
.1318 .33436 L
.13152 .33489 L
.13126 .33546 L
.13101 .33611 L
.13076 .33691 L
.13051 .33788 L
.13026 .33899 L
.12995 .34027 L
.12959 .34177 L
.12917 .34357 L
.12871 .34542 L
.12826 .34749 L
.12783 .34974 L
.12745 .35173 L
.12709 .35403 L
.12675 .35609 L
.12643 .35833 L
.12611 .36075 L
.12578 .3632 L
.12547 .36537 L
.12517 .36761 L
.12491 .36999 L
.12468 .37241 L
.12451 .37447 L
.12435 .37665 L
.12419 .37875 L
.12404 .38078 L
.1239 .38272 L
.12378 .38444 L
.12365 .386 L
.12359 .38732 L
.12355 .38844 L
.12355 .38935 L
.12357 .39007 L
Mistroke
.12359 .39064 L
.12361 .39108 L
.12361 .39148 L
.12361 .39189 L
.1236 .39236 L
.12359 .39291 L
.12358 .39358 L
.12357 .39438 L
.12356 .39522 L
.12354 .39615 L
.12352 .39717 L
.12351 .39826 L
.12349 .39934 L
.12347 .40027 L
.12346 .40114 L
.12345 .40191 L
.12344 .40254 L
.12343 .40301 L
.12343 .4033 L
Mfstroke
.12346 .40302 m
.12346 .40285 L
.12346 .40262 L
.12345 .40235 L
.12341 .40198 L
.12338 .40171 L
.12336 .40129 L
.12337 .40085 L
.12342 .40035 L
.12351 .39967 L
.12365 .399 L
.12386 .39846 L
.12411 .39771 L
.12437 .39698 L
.12463 .39619 L
.12487 .39532 L
.1251 .39428 L
.12534 .3934 L
.12559 .39249 L
.12584 .39143 L
.12603 .39023 L
.12616 .38903 L
.12624 .38805 L
.12628 .38698 L
.12628 .38587 L
.12627 .3849 L
.12624 .38395 L
.12623 .38307 L
.12623 .38231 L
.12624 .3817 L
.12625 .38117 L
.12625 .38073 L
.12626 .38038 L
.12626 .38015 L
.12626 .38001 L
.12626 .37995 L
.12626 .37993 L
.12626 .37996 L
.12626 .38003 L
.12626 .38011 L
.12626 .38017 L
.12626 .38019 L
.12626 .3802 L
.12626 .3802 L
.12626 .38021 L
.12626 .38026 L
.12626 .38033 L
.12625 .38039 L
.12622 .38041 L
.12619 .38039 L
Mistroke
.12615 .3803 L
.12615 .38013 L
.12617 .37986 L
.12622 .37951 L
.12633 .37909 L
.12648 .37863 L
.12668 .37815 L
.12693 .37767 L
.12723 .3772 L
.12755 .37673 L
.12783 .37627 L
.12807 .37586 L
.1283 .37557 L
.12852 .37543 L
.12869 .37547 L
.12873 .37568 L
.12863 .37601 L
.12844 .37644 L
.12819 .37695 L
.12791 .37746 L
.12761 .37784 L
.12732 .37812 L
.12704 .37844 L
.1268 .37882 L
.12661 .37924 L
.12645 .37964 L
.12634 .38001 L
.12626 .3804 L
.1262 .38091 L
.12611 .38163 L
.12597 .38256 L
.12579 .38369 L
.12554 .38495 L
.12532 .38622 L
.12503 .38792 L
.12477 .39012 L
.12452 .39179 L
.12426 .39413 L
.124 .396 L
.12375 .39802 L
.12355 .40017 L
.12342 .40167 L
.12334 .40326 L
.1233 .40475 L
.12329 .40575 L
.12331 .40655 L
.12333 .4072 L
.12334 .40766 L
.12334 .40792 L
Mfstroke
.15204 .46464 m
.15222 .46474 L
.15244 .46487 L
.15271 .46504 L
.15302 .46524 L
.15339 .46548 L
.15379 .46577 L
.15429 .46617 L
.15479 .46664 L
.15534 .46721 L
.15596 .46792 L
.15662 .4687 L
.15721 .46943 L
.15784 .47027 L
.15842 .47111 L
.15897 .47195 L
.15949 .47276 L
.15998 .47353 L
.16043 .47418 L
.16085 .47475 L
.16122 .47525 L
.16151 .47565 L
.1617 .4759 L
.16179 .47605 L
.16177 .47615 L
.16169 .47631 L
.16159 .47656 L
.1615 .47689 L
.16145 .47732 L
.16149 .47783 L
.16165 .47845 L
.16194 .4791 L
.16237 .47979 L
.16291 .48046 L
.16355 .48111 L
.16424 .48168 L
.16489 .48217 L
.16555 .48255 L
.16621 .4828 L
.1669 .48294 L
.16751 .48298 L
.16807 .48298 L
.16856 .48299 L
.16897 .48307 L
.1693 .48323 L
.16958 .4835 L
.16982 .48386 L
.17004 .48424 L
.17027 .48466 L
.17048 .48509 L
Mistroke
.17067 .48549 L
.17082 .48589 L
.17093 .48627 L
.17097 .48661 L
.17092 .48688 L
.1708 .48705 L
.1706 .48711 L
.17033 .4871 L
.17002 .48705 L
.16971 .48696 L
.16941 .48692 L
.16915 .48701 L
.16895 .48729 L
.16884 .48777 L
.1688 .48844 L
.16885 .48927 L
.16897 .49024 L
.16915 .49132 L
.16937 .49229 L
.16959 .4933 L
.1698 .49431 L
.16999 .4953 L
.17015 .49626 L
.17031 .49695 L
.17047 .49762 L
.17061 .49816 L
.17073 .49861 L
.17086 .49903 L
.17101 .4995 L
.17121 .5001 L
.17149 .50089 L
.17185 .50188 L
.17229 .50292 L
.1728 .50414 L
.17338 .50553 L
.174 .50707 L
.17462 .50856 L
.17515 .50992 L
.17566 .51124 L
.1761 .51232 L
.17653 .51326 L
.17695 .51406 L
.17737 .51467 L
.17778 .51511 L
.17822 .51541 L
.17867 .51562 L
.17913 .51577 L
.17958 .51589 L
.18001 .51599 L
.18044 .51612 L
Mistroke
.18089 .5163 L
.18138 .51652 L
.18185 .51675 L
.18227 .51694 L
.18256 .51706 L
.18273 .51711 L
.18275 .51703 L
.18265 .51682 L
.18244 .51651 L
.18217 .51616 L
.18185 .5158 L
.18152 .51546 L
.1812 .51522 L
.18089 .5151 L
.18061 .51514 L
.18038 .5154 L
.18022 .51596 L
.18013 .51684 L
.18013 .51806 L
.18019 .5195 L
.18031 .52116 L
.18045 .52313 L
.18063 .5254 L
.18083 .52747 L
.18104 .5299 L
.18127 .53203 L
.18153 .53425 L
.18177 .53645 L
.18204 .53822 L
.18229 .53982 L
.18253 .54121 L
.18275 .54235 L
.18294 .54319 L
.18312 .54383 L
.18329 .54427 L
.18346 .54456 L
.18363 .54475 L
.18377 .54486 L
.18385 .54491 L
.18388 .54488 L
.18386 .5448 L
.18381 .54468 L
.18375 .54455 L
.18372 .54446 L
.18372 .54444 L
.18377 .54453 L
.18388 .54471 L
.18407 .54499 L
.18436 .54536 L
.18475 .54583 L
Mistroke
.18524 .54638 L
.18583 .54699 L
.18652 .54765 L
.1873 .5484 L
.1881 .54922 L
.18896 .55006 L
.18986 .55089 L
.19076 .55167 L
.19157 .5524 L
.19234 .55311 L
.19307 .55379 L
.19372 .55446 L
.19428 .55512 L
.19472 .55579 L
.19508 .55651 L
.19535 .55727 L
.19553 .55801 L
.19564 .55866 L
.19567 .55919 L
.19564 .55963 L
.19553 .55996 L
.19535 .56015 L
.19508 .56017 L
.19475 .56002 L
.19441 .55974 L
.19408 .55935 L
.19379 .55888 L
.19356 .55837 L
.19341 .55783 L
.19341 .55729 L
.1936 .55683 L
.19401 .55647 L
.19464 .55622 L
.19546 .55605 L
.19653 .55597 L
.19777 .55593 L
.19923 .55594 L
.20072 .55595 L
.20228 .55595 L
.20362 .55592 L
.20491 .55588 L
.2059 .55584 L
.20667 .55583 L
.20713 .55584 L
.20723 .55588 L
.20701 .55593 L
.20651 .55597 L
.20581 .55601 L
.20493 .55605 L
.20405 .55609 L
Mistroke
.2031 .55615 L
.20209 .5562 L
.20112 .55619 L
.20028 .55608 L
.19962 .55582 L
.19911 .55536 L
.1987 .55468 L
.19838 .55376 L
.19809 .55255 L
.19779 .55102 L
.19744 .54916 L
.19697 .54732 L
.19638 .54513 L
.19567 .54256 L
.19485 .54008 L
.19401 .53739 L
.19303 .53453 L
.19199 .53181 L
.19095 .52924 L
.1899 .5268 L
.18888 .52442 L
.18798 .52264 L
.1872 .52098 L
.18656 .51959 L
.18606 .51859 L
.18571 .51777 L
.18548 .51716 L
.18529 .51674 L
.18509 .51646 L
.18483 .5163 L
.18445 .5162 L
.18389 .51615 L
.18311 .5161 L
.18211 .51602 L
.18099 .51588 L
.17964 .51567 L
.17809 .51538 L
.17638 .51503 L
.17481 .51465 L
.17323 .51426 L
.17169 .51391 L
.17029 .51361 L
.16913 .51334 L
.16822 .51311 L
.16752 .51287 L
.16704 .51257 L
.16676 .51215 L
.16667 .51167 L
.16674 .51119 L
.16691 .51059 L
Mistroke
.16718 .50989 L
.16748 .50906 L
.16778 .50804 L
.16804 .50693 L
.1682 .50562 L
.16819 .50407 L
.16804 .50231 L
.16779 .50049 L
.16747 .49872 L
.1671 .49683 L
.16673 .49529 L
.16634 .49382 L
.16599 .49268 L
.16569 .49174 L
.16545 .491 L
.16527 .49059 L
.16516 .49033 L
.16513 .49022 L
.16516 .49024 L
.16526 .49042 L
.16541 .49072 L
.1656 .49111 L
.16579 .49152 L
.16596 .49188 L
.1661 .49215 L
.1662 .49231 L
.16625 .49233 L
.16626 .49218 L
.16623 .49187 L
.16621 .49147 L
.16619 .49101 L
.16619 .49053 L
.16621 .49005 L
.16623 .48958 L
.16624 .48912 L
.16627 .48867 L
.16632 .48823 L
.16646 .48785 L
.16666 .48756 L
.16687 .48741 L
.16703 .48736 L
.16708 .48739 L
.16702 .48746 L
.16676 .48752 L
.1662 .48754 L
.16528 .48745 L
.16401 .48723 L
.1624 .48689 L
.16045 .48645 L
.15855 .48594 L
Mistroke
.15618 .48536 L
.15366 .48478 L
.15109 .4842 L
.14841 .48364 L
.14583 .48311 L
.143 .48261 L
.14074 .48218 L
.1386 .48177 L
.13641 .48141 L
.13446 .48106 L
.13259 .48072 L
.1308 .48038 L
.12916 .48003 L
.12777 .47969 L
.1268 .47934 L
.12561 .47899 L
.1247 .47863 L
.12381 .47821 L
.12292 .47774 L
.12209 .47725 L
.12132 .47675 L
.12061 .47625 L
.11995 .47572 L
.11936 .47514 L
.11882 .47451 L
.1183 .47386 L
.11768 .47313 L
.11701 .47228 L
.11634 .47131 L
.1157 .47033 L
.11514 .46936 L
.11468 .46845 L
.11435 .46763 L
.11415 .46695 L
.1141 .46638 L
.11417 .46594 L
.11434 .46562 L
.11458 .4654 L
.11485 .46527 L
.11514 .46517 L
.11544 .46508 L
.1157 .46494 L
.11595 .46475 L
.11618 .46447 L
.1164 .46412 L
.11663 .46369 L
.11686 .46321 L
.1171 .46274 L
.11732 .46228 L
.11755 .46183 L
Mistroke
.11777 .46139 L
.11799 .461 L
.11822 .4607 L
.11845 .46048 L
.1187 .46036 L
.11895 .46032 L
.11919 .46034 L
.11939 .4604 L
.11954 .46047 L
Mfstroke
.12344 .39878 m
.12345 .39866 L
.12347 .39844 L
.12351 .39808 L
.12356 .39757 L
.12363 .39688 L
.12373 .39598 L
.12386 .39483 L
.12402 .39343 L
.12422 .39182 L
.12439 .38984 L
.12457 .38772 L
.12478 .38527 L
.12503 .38262 L
.1253 .38009 L
.12554 .37701 L
.12582 .37441 L
.1261 .37132 L
.12641 .36849 L
.12673 .36546 L
.12709 .36205 L
.12749 .3594 L
.12789 .35658 L
.1283 .35375 L
.1287 .35089 L
.12911 .34794 L
.12953 .34568 L
.12996 .34306 L
.1304 .34066 L
.13083 .33844 L
.13126 .33626 L
.13167 .33441 L
.13206 .33267 L
.13244 .33128 L
.13278 .33008 L
.13309 .32917 L
.13337 .32844 L
.1336 .32791 L
.13379 .32757 L
.13395 .32738 L
.13407 .32729 L
.13416 .3273 L
.13421 .32737 L
.13422 .32748 L
.1342 .3276 L
.13417 .3277 L
.13413 .32775 L
.1341 .32777 L
.13408 .32778 L
.13408 .32778 L
Mistroke
.13408 .32778 L
.13408 .32778 L
.13408 .32778 L
.13408 .32778 L
.13408 .32778 L
.13408 .32778 L
.13408 .32778 L
.1341 .3278 L
.13413 .32786 L
.13416 .32793 L
.1342 .328 L
.13421 .32803 L
.1342 .328 L
.13414 .3279 L
.13404 .32771 L
.13389 .32743 L
.13369 .32706 L
.13344 .32659 L
.13315 .32605 L
.13285 .32549 L
.13259 .32501 L
.13235 .32461 L
.13216 .32428 L
.13202 .32404 L
.13195 .32389 L
.13198 .32385 L
.1321 .32391 L
.13228 .32405 L
.13252 .32423 L
.13279 .32444 L
.13307 .32461 L
.13336 .32473 L
.13363 .32476 L
.13385 .32466 L
.13402 .32439 L
.13414 .32396 L
.13421 .32339 L
.13424 .32272 L
.13423 .322 L
.1342 .32128 L
.13416 .32064 L
.13413 .32006 L
.13411 .31959 L
.13411 .31922 L
.13411 .31892 L
.13411 .31868 L
.13411 .31851 L
.13411 .31841 L
.13411 .31838 L
.13411 .31841 L
Mistroke
.13411 .31847 L
.13411 .31855 L
.13411 .31861 L
.13411 .31863 L
.13411 .31864 L
.1341 .31864 L
.13407 .31866 L
.13403 .31872 L
.134 .31879 L
.13398 .31885 L
.13399 .31888 L
.13404 .31886 L
.13414 .31877 L
.13428 .31859 L
.13447 .31832 L
.13469 .31798 L
.13493 .31758 L
.13519 .31714 L
.13544 .31667 L
.13568 .31621 L
.13593 .31576 L
.13616 .31532 L
.13636 .3149 L
.13652 .31452 L
.13663 .31423 L
.1367 .31402 L
.13672 .31391 L
.1367 .31387 L
.13667 .3139 L
.13663 .31396 L
.1366 .31404 L
.13658 .31409 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31412 L
.13658 .31414 L
.13658 .31417 L
.13656 .31423 L
.13653 .31431 L
.13649 .3144 L
.13644 .31445 L
Mistroke
.1364 .31446 L
.13638 .31441 L
.13639 .31425 L
.13647 .31397 L
.13662 .31354 L
.13682 .31297 L
.1371 .31226 L
.13746 .31146 L
.13788 .31052 L
.13836 .3095 L
.1389 .30844 L
.1395 .30734 L
.14014 .30621 L
.14076 .30512 L
.14137 .30415 L
.14195 .30327 L
.14246 .30251 L
.1429 .3019 L
.14325 .30143 L
.14353 .30108 L
.14374 .30082 L
.14389 .30064 L
.14399 .30051 L
.14406 .30045 L
.14409 .30042 L
.14409 .30043 L
.14407 .30044 L
.14403 .30046 L
.14399 .3005 L
.14395 .30054 L
.14394 .30057 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
Mistroke
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14394 .30058 L
.14393 .30058 L
.14392 .30058 L
.14389 .30058 L
.14385 .30058 L
.1438 .30058 L
.14377 .30058 L
.14376 .3006 L
.14382 .30063 L
.14392 .30067 L
.14407 .30069 L
.14427 .30071 L
.14452 .30072 L
.14482 .30071 L
.14514 .30068 L
.14544 .30062 L
.14573 .30054 L
.14601 .30042 L
.1463 .30025 L
.14654 .29999 L
.14676 .29961 L
.147 .29917 L
.14726 .29863 L
.14758 .29798 L
.14805 .29727 L
.14866 .2964 L
.14935 .29538 L
.15028 .29422 L
.15131 .29299 L
.15259 .29166 L
.15389 .29024 L
.15533 .28882 L
.15675 .28744 L
.15813 .28626 L
.1592 .2852 L
.16038 .28417 L
.16131 .28332 L
.1621 .28251 L
.16276 .28169 L
.16331 .28085 L
Mistroke
.16382 .27994 L
.1643 .2789 L
.16481 .27768 L
.16534 .27627 L
.16588 .27482 L
.16634 .27331 L
.16689 .27144 L
.16748 .26962 L
.16813 .26763 L
.1687 .2655 L
.16923 .26369 L
.16972 .26187 L
.17017 .26011 L
.17061 .25844 L
.17106 .25696 L
.17155 .25554 L
.17214 .25413 L
.1728 .25267 L
.17364 .25115 L
.1746 .24981 L
.17573 .24826 L
.17699 .24666 L
.1784 .24509 L
.17982 .2434 L
.18146 .24171 L
.18279 .24006 L
.18413 .23839 L
.18547 .23684 L
.18666 .23532 L
.18779 .23396 L
.1888 .23267 L
.18979 .23143 L
.19063 .23031 L
.19141 .22922 L
.19213 .22814 L
.19281 .22699 L
.19345 .22588 L
.194 .22467 L
.19454 .22331 L
.19504 .22188 L
.19548 .22028 L
.1959 .21853 L
.19632 .2169 L
.19676 .21499 L
.19723 .21309 L
.19774 .21088 L
.19829 .20867 L
.19892 .20651 L
.19964 .20415 L
.20049 .20174 L
Mistroke
.20137 .19968 L
.20236 .19766 L
.20339 .19564 L
.2045 .19368 L
.2057 .19194 L
.20686 .19016 L
.20811 .18834 L
.20947 .18662 L
.21086 .1849 L
.21234 .18327 L
.21373 .18168 L
.21513 .18027 L
.21654 .1789 L
.21786 .1776 L
.21914 .17647 L
.22037 .17543 L
.22145 .17456 L
.22246 .17382 L
.22326 .17323 L
.22391 .17283 L
.22439 .17263 L
.22468 .17259 L
.22479 .1727 L
.22473 .17288 L
.22457 .17309 L
.22438 .17326 L
.22421 .17331 L
.22414 .17318 L
.22422 .17282 L
.22447 .17221 L
.22493 .17133 L
.22556 .17017 L
.22635 .16884 L
.22726 .16718 L
.22827 .16521 L
.22927 .16328 L
.23036 .16106 L
.23166 .15843 L
.23293 .15622 L
.23431 .15397 L
.23557 .1517 L
.23676 .14958 L
.23785 .14766 L
.23879 .14619 L
.23968 .14484 L
.2405 .1438 L
.24131 .14295 L
.24208 .14225 L
.24282 .14169 L
.24351 .14124 L
Mistroke
.24413 .1409 L
.2447 .14064 L
.24526 .14046 L
.24585 .14034 L
.24652 .14026 L
.2473 .14018 L
.24822 .14006 L
.24928 .13992 L
.25047 .13978 L
.25158 .13968 L
.2528 .13961 L
.25381 .13959 L
.2549 .13962 L
.25594 .1397 L
.25679 .13984 L
.25755 .14003 L
.25817 .14022 L
.25861 .14036 L
.25888 .14043 L
.25904 .1404 L
.25914 .14023 L
.25929 .13989 L
.25957 .13938 L
.26006 .13867 L
.2608 .13773 L
.26182 .13654 L
.26301 .13526 L
.26451 .13359 L
.26614 .13183 L
.26813 .12979 L
.26994 .12756 L
.272 .12528 L
.2742 .12292 L
.276 .12069 L
.27788 .11851 L
.27962 .1165 L
.28108 .1148 L
.28241 .11325 L
.28352 .11188 L
.28444 .11079 L
.28522 .1099 L
.28589 .10925 L
.28649 .10884 L
.28704 .10863 L
.28758 .10857 L
.28814 .10862 L
.28873 .10874 L
.28935 .10887 L
.28999 .109 L
.29058 .10912 L
Mistroke
.29114 .10923 L
.29166 .1093 L
.29213 .10933 L
.29256 .10932 L
.29295 .10928 L
.29327 .10922 L
.29354 .10915 L
.29376 .10908 L
.29395 .10902 L
.29413 .109 L
.2943 .109 L
.29448 .10902 L
.29465 .10923 L
.29486 .10918 L
.29507 .10907 L
.29528 .10893 L
.29546 .10879 L
.2956 .10865 L
.29569 .1085 L
.29572 .10834 L
.2957 .10813 L
.29565 .10792 L
.29558 .10765 L
.29553 .10738 L
.29551 .10708 L
.29555 .10673 L
.29566 .10642 L
.29583 .10613 L
.29605 .10589 L
.29631 .10563 L
.2966 .10535 L
.29693 .10505 L
.29731 .10475 L
.29774 .10446 L
.29824 .10417 L
.29879 .10388 L
.29942 .10358 L
.30012 .10327 L
.3009 .10295 L
.30175 .10259 L
.30263 .10216 L
.30359 .1017 L
.30459 .10122 L
.30565 .10077 L
.30673 .10036 L
.30782 .09996 L
.30887 .09959 L
.30988 .09927 L
.31076 .09901 L
.31152 .09883 L
Mistroke
.31213 .09874 L
.31259 .09871 L
.31295 .09869 L
.31325 .09863 L
.31353 .0985 L
.31381 .09826 L
.31411 .09789 L
.31444 .09738 L
.3148 .09677 L
.31519 .09611 L
.3156 .09548 L
.31598 .09482 L
.31635 .09417 L
.31669 .09361 L
.317 .09312 L
.31729 .09271 L
.31757 .0924 L
.31785 .09219 L
.31818 .09204 L
.31857 .0919 L
.31905 .09173 L
.31964 .09148 L
.32038 .09112 L
.32126 .09062 L
.32236 .09 L
.32359 .0893 L
.32498 .0885 L
.32656 .08766 L
.32805 .0868 L
.32958 .08596 L
.33111 .0852 L
.33259 .08449 L
.33399 .08384 L
.33535 .08324 L
.3367 .08267 L
.33801 .0821 L
.33935 .0815 L
.34069 .08083 L
.34206 .08002 L
.34346 .07905 L
.34474 .07802 L
.34605 .07682 L
.34726 .07541 L
.34845 .07397 L
.34963 .07243 L
.35075 .07095 L
.35189 .06939 L
.35302 .06791 L
.35413 .06652 L
.3553 .06509 L
Mistroke
.35654 .06388 L
.35794 .06271 L
.35946 .06157 L
.36125 .06044 L
.36312 .05937 L
.36508 .05828 L
.36724 .05722 L
.36956 .05617 L
.37177 .05511 L
.37392 .05406 L
.37593 .0531 L
.37761 .0522 L
.37938 .05141 L
.38104 .05078 L
.38261 .05033 L
.38418 .05007 L
.38575 .04998 L
.38739 .05002 L
.38905 .05018 L
.39061 .05041 L
.39189 .0507 L
.39315 .05103 L
.39424 .05136 L
.39533 .05167 L
.39642 .05192 L
.3974 .05213 L
.39816 .05227 L
.39865 .05234 L
.3989 .05238 L
.39898 .0524 L
.39889 .05239 L
.39867 .05238 L
.3984 .05237 L
.39818 .05237 L
.39804 .05237 L
.39799 .05237 L
.39806 .05235 L
.39828 .05227 L
.39866 .05211 L
.39922 .05184 L
.39995 .05143 L
.40083 .05088 L
.40184 .05021 L
.40286 .04941 L
.40395 .04853 L
.40515 .04758 L
.40645 .04669 L
.40768 .04573 L
.40895 .04472 L
.41021 .04383 L
Mistroke
.41142 .04298 L
.41261 .04221 L
.41377 .04154 L
.41499 .04098 L
.41633 .04054 L
.41779 .04024 L
.41936 .04004 L
.42111 .03992 L
.42304 .03985 L
.42495 .0398 L
.4269 .03978 L
.4289 .03976 L
.43076 .03977 L
.43255 .03982 L
.4342 .03988 L
.43565 .03997 L
.43698 .04006 L
.43814 .04014 L
.43905 .04021 L
.43966 .04026 L
.43996 .04029 L
.43997 .04032 L
.43972 .04033 L
.43928 .04033 L
.43869 .04031 L
.43802 .04028 L
.43733 .04025 L
.43664 .04022 L
.43596 .0402 L
.43527 .04018 L
.43462 .04016 L
.43405 .04014 L
.43359 .04013 L
.43329 .04012 L
.43311 .04011 L
.43306 .04011 L
.43309 .04011 L
.43318 .04012 L
.43329 .04012 L
.43335 .0401 L
.43335 .04005 L
.4333 .03997 L
.43323 .03987 L
.43319 .03979 L
.43318 .03975 L
.43324 .03977 L
.43338 .03989 L
.43359 .04015 L
.43389 .04056 L
.43424 .04114 L
Mistroke
.43465 .04186 L
.43509 .04274 L
.43553 .04367 L
.436 .04473 L
.43645 .04579 L
.4369 .04688 L
.43731 .0479 L
.43765 .04877 L
.43791 .04936 L
.43806 .04972 L
.43808 .04983 L
.438 .04968 L
.43784 .04929 L
.43763 .04867 L
.43744 .04795 L
.43727 .04711 L
.43712 .04623 L
.43699 .04535 L
.43684 .04456 L
.43664 .04381 L
.43638 .04315 L
.43603 .04261 L
.43555 .0422 L
.43494 .04192 L
.43418 .04178 L
.4332 .04175 L
.43204 .04177 L
.43062 .04179 L
.42898 .04179 L
.42706 .04174 L
.42499 .04163 L
.42289 .04146 L
.42064 .04126 L
.41848 .04105 L
.41648 .04084 L
.41451 .04062 L
.41259 .04041 L
.41103 .04019 L
.40958 .03995 L
.40823 .0397 L
.40698 .03944 L
.40579 .03919 L
.40462 .03898 L
.40349 .03882 L
.40234 .03873 L
.40108 .03872 L
.39971 .03881 L
.39834 .03904 L
.39687 .03938 L
.39524 .03982 L
Mistroke
.3935 .04034 L
.3918 .04093 L
.39029 .04163 L
.38884 .04241 L
.38746 .04321 L
.38621 .04394 L
.38511 .04465 L
.38419 .04546 L
.38342 .04619 L
.38273 .04693 L
.38208 .0477 L
.38149 .04841 L
.38091 .04918 L
.38033 .04997 L
.37974 .05079 L
.37916 .05163 L
.37863 .05247 L
.37819 .05324 L
.37777 .05396 L
.37736 .05464 L
.37698 .05524 L
.37664 .05573 L
.37639 .05608 L
.37623 .05629 L
.37613 .05641 L
.3761 .05645 L
.37613 .0564 L
.3762 .05628 L
.37626 .05615 L
.37631 .05605 L
.37632 .05599 L
.37633 .05594 L
.37635 .0559 L
.37637 .05585 L
.3764 .05578 L
.37644 .05568 L
.37648 .05554 L
.37652 .05538 L
.37658 .05522 L
.37663 .05506 L
.37671 .05491 L
.37679 .05479 L
.37688 .0547 L
.37692 .05464 L
.37689 .05461 L
.37675 .05458 L
.37648 .05456 L
.37608 .05458 L
.37554 .05466 L
.37486 .05483 L
Mistroke
.37407 .05503 L
.37317 .05533 L
.37218 .0557 L
.3711 .0561 L
.37003 .05651 L
.36886 .05691 L
.3676 .05732 L
.36628 .05772 L
.36494 .05816 L
.36356 .05866 L
.36218 .05923 L
.36077 .05988 L
.3593 .06059 L
.35777 .06137 L
.35632 .06221 L
.35485 .06313 L
.35327 .06411 L
.35168 .06508 L
.3502 .06608 L
.34876 .06707 L
.34741 .06804 L
.34623 .06888 L
.34513 .06963 L
.34413 .07024 L
.34323 .07069 L
.3425 .07097 L
.34187 .07113 L
.34132 .07122 L
.34083 .07132 L
.34038 .07147 L
.33996 .07171 L
.33952 .07211 L
.33916 .07255 L
.33872 .0732 L
.33824 .07404 L
.33771 .07505 L
.3371 .07612 L
.33639 .07738 L
.33563 .07877 L
.3348 .0801 L
.33397 .08141 L
.33316 .08263 L
.33237 .08376 L
.33165 .08475 L
.33102 .0856 L
.33047 .08637 L
.33002 .08706 L
.32968 .08768 L
.32945 .08826 L
.32932 .08881 L
Mistroke
.32926 .08934 L
.32925 .08982 L
.32929 .09024 L
.32939 .09057 L
.32952 .09083 L
.32965 .09108 L
.32977 .09135 L
.32986 .09162 L
.3299 .09188 L
.32988 .09217 L
.32978 .09254 L
.32955 .09301 L
.32916 .0936 L
.3286 .09431 L
.32786 .09515 L
.32693 .09611 L
.32592 .09706 L
.32478 .0981 L
.32361 .09917 L
.32248 .10024 L
.32142 .10116 L
.32037 .10198 L
.3193 .10264 L
.31838 .10313 L
.31753 .10345 L
.31678 .1036 L
.31613 .10361 L
.3156 .10355 L
.3152 .10346 L
.3149 .10337 L
.31468 .10329 L
.31448 .10321 L
.31425 .10316 L
.31397 .10312 L
.31365 .10306 L
.31332 .103 L
.31301 .10292 L
.31277 .10285 L
.31263 .10278 L
.31258 .10273 L
.3126 .10269 L
.31263 .10267 L
.31265 .10266 L
.31266 .10267 L
.3127 .1027 L
.3128 .10273 L
.31298 .10279 L
.31322 .10288 L
.31347 .10297 L
.31371 .10307 L
Mistroke
.31389 .10314 L
.31397 .1032 L
.31392 .10322 L
.31373 .1032 L
.31343 .10313 L
.31303 .10301 L
.31255 .10282 L
.31199 .10255 L
.31133 .10222 L
.3107 .10185 L
.30996 .10153 L
.30917 .10122 L
.30837 .10098 L
.30762 .10081 L
.30693 .10072 L
.30632 .10068 L
.30581 .1007 L
.30544 .10081 L
.30514 .10097 L
.30496 .10117 L
.30486 .10143 L
.30482 .1017 L
.30481 .10194 L
.30479 .10211 L
.30473 .10225 L
.30458 .10231 L
.30429 .10235 L
.30385 .10238 L
.30328 .10249 L
.30258 .10277 L
.30174 .10325 L
.30083 .10393 L
.2999 .10479 L
.29892 .10574 L
.29788 .10671 L
.29683 .10754 L
.29585 .10835 L
.29493 .10909 L
.29415 .10979 L
.29347 .11029 L
.2929 .11066 L
.29244 .11089 L
.29207 .11097 L
.29178 .11085 L
.29159 .11057 L
.29149 .11017 L
.29145 .10974 L
.29144 .10936 L
.29144 .10909 L
.2914 .10893 L
Mistroke
.29127 .10888 L
.29096 .10898 L
.29045 .10921 L
.28975 .10955 L
.28885 .10997 L
.2877 .11047 L
.28652 .11105 L
.28508 .11169 L
.28353 .11234 L
.28198 .11303 L
.28032 .11373 L
.27866 .11444 L
.27705 .11515 L
.27558 .11585 L
.2741 .11661 L
.27263 .1174 L
.27121 .11825 L
.26988 .11913 L
.26875 .12003 L
.26757 .12101 L
.26642 .12207 L
.26537 .12315 L
.26439 .12434 L
.26342 .1257 L
.26252 .12703 L
.2617 .12842 L
.26098 .12981 L
.26038 .13107 L
.25991 .13214 L
.25956 .13292 L
.25932 .1335 L
.25913 .13383 L
.25899 .13393 L
.25889 .13382 L
.25882 .13354 L
.25877 .13318 L
.25875 .13281 L
.25876 .13246 L
.2588 .13219 L
.25886 .13207 L
.25893 .13217 L
.25899 .13255 L
.25903 .1332 L
.25908 .13404 L
.25914 .13491 L
.2592 .13602 L
.25927 .13699 L
.25932 .1379 L
.25934 .13869 L
.25935 .13928 L
Mistroke
.25934 .13964 L
.25929 .13977 L
.25918 .13973 L
.25897 .13957 L
.25866 .13935 L
.25824 .1391 L
.25768 .13885 L
.25697 .13866 L
.25609 .13851 L
.25505 .13841 L
.25385 .13837 L
.25246 .13842 L
.25091 .13858 L
.24944 .13889 L
.24782 .13934 L
.24597 .13994 L
.24395 .14069 L
.24201 .14158 L
.24019 .14263 L
.23825 .14386 L
.23633 .14517 L
.23442 .14672 L
.23271 .14846 L
.23091 .15032 L
.22942 .15221 L
.22792 .15429 L
.22636 .15637 L
.22489 .15865 L
.22342 .16074 L
.22194 .16294 L
.22048 .1652 L
.2193 .16713 L
.21808 .16918 L
.21701 .17114 L
.21606 .17297 L
.21512 .17484 L
.21431 .17633 L
.21361 .17777 L
.21307 .1792 L
.21268 .18057 L
.21245 .18186 L
.21237 .18296 L
.2124 .18399 L
.21249 .1849 L
.2126 .18565 L
.2127 .18621 L
.21277 .18661 L
.21281 .18687 L
.21281 .18702 L
.21278 .18704 L
Mistroke
.21274 .18696 L
.21268 .1867 L
.21262 .18631 L
.21256 .18582 L
.21254 .18533 L
.2126 .18484 L
.21275 .18438 L
.213 .184 L
.21336 .18374 L
.21382 .18365 L
.21437 .18368 L
.21496 .18375 L
.21563 .18383 L
.21636 .18391 L
.21714 .18397 L
.21789 .18403 L
.21864 .18406 L
.21936 .18409 L
.22002 .18411 L
.2206 .18412 L
.22106 .18414 L
.22141 .18415 L
.22167 .18415 L
.22186 .18416 L
.22199 .18416 L
.2221 .18416 L
.22218 .18417 L
.22225 .18417 L
.2223 .18417 L
.22231 .18417 L
.22229 .18417 L
.22226 .18417 L
.22222 .18417 L
.22219 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
Mistroke
.22217 .18417 L
.22217 .18417 L
.22217 .18417 L
.22215 .18417 L
.22212 .18417 L
.22209 .18416 L
.22205 .18416 L
.22203 .18416 L
.22205 .18416 L
.2221 .18416 L
.22219 .18417 L
.22233 .18417 L
.22251 .18418 L
.22271 .18418 L
.22294 .18419 L
.22318 .1842 L
.22343 .18421 L
.22367 .18424 L
.22389 .1843 L
.22407 .18439 L
.22421 .18448 L
.2243 .18457 L
.22435 .18462 L
.22437 .1846 L
.22437 .18448 L
.22438 .18426 L
.22444 .18392 L
.22458 .18346 L
.22484 .18286 L
.22524 .18212 L
.22579 .18125 L
.22645 .18021 L
.22726 .17897 L
.22823 .17751 L
.22931 .17597 L
.23053 .17429 L
.23178 .17257 L
.23309 .17081 L
.23441 .16923 L
.23561 .16771 L
.23675 .16633 L
.23769 .16522 L
.23855 .16416 L
.23926 .1633 L
.2399 .16253 L
.24034 .16204 L
.24068 .16168 L
.24089 .1615 L
.24099 .16146 L
.24102 .16153 L
Mistroke
.241 .16165 L
.24095 .16177 L
.24087 .16187 L
.24078 .16194 L
.24072 .16197 L
.24069 .16199 L
.24069 .162 L
.24069 .16202 L
.2407 .16208 L
.2407 .16216 L
.24068 .16226 L
.24065 .16235 L
.2406 .16243 L
.24054 .16247 L
.2405 .16239 L
.24048 .16216 L
.24051 .16176 L
.24062 .16116 L
.24081 .16033 L
.24107 .15926 L
.24141 .15807 L
.2418 .15664 L
.24224 .15498 L
.24269 .15337 L
.24315 .15161 L
.24361 .14974 L
.244 .14818 L
.24434 .14669 L
.24463 .14532 L
.24486 .14416 L
.24502 .14325 L
.24515 .14258 L
.24527 .14211 L
.24544 .14178 L
.24567 .14152 L
.24601 .1413 L
.24648 .14107 L
.2471 .1408 L
.2478 .14048 L
.24868 .1401 L
.24963 .13963 L
.25071 .13906 L
.2519 .13835 L
.25301 .13751 L
.25419 .13663 L
.25544 .13571 L
.25666 .13479 L
.25792 .13389 L
.25914 .13303 L
.26039 .13224 L
Mistroke
.26159 .13145 L
.26282 .13065 L
.26402 .1299 L
.26523 .12915 L
.26638 .12842 L
.26743 .12773 L
.26845 .12708 L
.26939 .12651 L
.2702 .12605 L
.27091 .12565 L
.27151 .12531 L
.27198 .125 L
.27234 .12472 L
.2726 .12448 L
.27279 .12431 L
.27291 .12422 L
.27298 .1242 L
.27302 .12424 L
.27302 .12431 L
.273 .12441 L
.27295 .12452 L
.27287 .12463 L
.27274 .12472 L
.27261 .12478 L
.27251 .1248 L
.27247 .12476 L
.27253 .12462 L
.2727 .12435 L
.273 .12395 L
.27346 .12339 L
.27409 .12269 L
.27486 .12186 L
.27576 .12098 L
.27663 .12 L
.27767 .11896 L
.27864 .11793 L
.27968 .11692 L
.28052 .11598 L
.28135 .11519 L
.28215 .11451 L
.28286 .11397 L
.28347 .11359 L
.28403 .11336 L
.28458 .11329 L
.28518 .11334 L
.28586 .11344 L
.28662 .11353 L
.28746 .11357 L
.28834 .11354 L
.28924 .11344 L
Mistroke
.29024 .11326 L
.29136 .11305 L
.29256 .11284 L
.29379 .1127 L
.29504 .11262 L
.29629 .11258 L
.29751 .11257 L
.2987 .11258 L
.29985 .11262 L
.30088 .11268 L
.30185 .1128 L
.30274 .11294 L
.30348 .1131 L
.30406 .11323 L
.30449 .1133 L
.3048 .11329 L
.305 .11318 L
.30514 .11294 L
.30524 .1125 L
.30533 .11192 L
.30544 .1113 L
.30559 .11062 L
.30581 .10991 L
.30609 .1092 L
.3064 .1085 L
.30676 .10782 L
.30718 .1072 L
.30765 .10664 L
.30812 .10616 L
.30858 .10579 L
.30899 .10555 L
.30934 .10543 L
.30963 .10541 L
.30988 .10545 L
.31011 .10551 L
.31035 .10554 L
.31063 .10548 L
.31096 .1053 L
.31134 .10492 L
.31177 .10431 L
.31228 .10344 L
.31289 .10237 L
.31357 .101 L
.31441 .09951 L
.31533 .09778 L
.31641 .0959 L
.31766 .09396 L
.31905 .09207 L
.32067 .0901 L
.32223 .08836 L
Mistroke
.32401 .08655 L
.32564 .08504 L
.3275 .08357 L
.32936 .0823 L
.33136 .08111 L
.33349 .07999 L
.3355 .07894 L
.33757 .078 L
.33962 .07704 L
.34161 .07604 L
.34362 .07495 L
.34563 .07383 L
.34761 .07256 L
.34977 .0711 L
.3518 .06959 L
.35395 .06796 L
.35621 .0663 L
.35834 .06451 L
.36058 .0628 L
.36294 .06101 L
.36515 .05917 L
.36747 .05762 L
.36986 .05609 L
.37206 .0546 L
.37426 .05326 L
.37633 .05208 L
.37829 .05099 L
.3799 .05004 L
.38135 .04919 L
.38256 .04843 L
.38356 .04777 L
.38432 .0472 L
.38489 .04674 L
.38527 .04632 L
.38549 .04597 L
.38557 .04567 L
.38553 .04544 L
.38542 .04526 L
.38526 .04513 L
.3851 .04506 L
.38495 .04505 L
.38483 .04509 L
.38476 .04515 L
.38477 .04523 L
.38486 .04529 L
.38508 .04531 L
.38545 .04532 L
.38601 .04532 L
.38675 .04533 L
.38768 .04534 L
Mistroke
.38881 .04537 L
.39012 .04545 L
.39138 .04554 L
.39275 .04564 L
.39404 .04571 L
.39537 .04573 L
.39647 .04569 L
.39749 .04555 L
.39843 .04532 L
.3992 .04501 L
.39987 .04464 L
.40047 .04423 L
.40102 .04379 L
.40155 .04336 L
.40204 .04292 L
.4025 .0425 L
.40298 .04211 L
.40352 .04176 L
.40411 .04148 L
.40472 .04127 L
.40533 .04114 L
.40586 .04108 L
.40634 .0411 L
.40675 .04118 L
.40708 .04133 L
.40734 .04152 L
.40752 .04177 L
.40768 .04206 L
.40787 .04238 L
.4081 .04267 L
.40837 .04288 L
.40866 .04303 L
.40899 .04311 L
.40932 .04317 L
.40967 .04325 L
.41002 .04335 L
.41038 .04346 L
.41076 .04358 L
.4112 .04368 L
.4117 .04376 L
.4123 .04383 L
.41306 .04393 L
.4138 .04408 L
.41476 .04437 L
.41588 .0448 L
.41706 .04536 L
.41846 .04601 L
.41993 .0467 L
.42167 .0474 L
.42363 .04805 L
Mistroke
.42544 .04863 L
.42744 .04911 L
.42946 .04956 L
.43149 .04998 L
.43361 .0504 L
.43558 .05079 L
.4375 .05116 L
.43937 .05146 L
.44104 .05168 L
.4427 .05179 L
.44414 .05179 L
.44539 .05169 L
.44634 .05149 L
.44706 .05123 L
.44757 .05093 L
.44793 .05063 L
.44818 .05031 L
.44839 .04998 L
.44861 .04959 L
.44895 .04917 L
.44945 .04866 L
.45013 .04808 L
.45101 .04743 L
.45201 .04667 L
.45321 .04604 L
.4546 .04535 L
.45615 .04469 L
.45772 .04411 L
.45929 .04354 L
.46087 .04298 L
.46212 .04245 L
.46324 .04194 L
.46409 .04149 L
.46478 .04114 L
.46528 .0409 L
.46559 .04078 L
.46581 .04077 L
.46605 .04082 L
.46638 .0409 L
.46687 .04099 L
.46754 .04106 L
.46844 .04111 L
.46959 .04114 L
.4708 .04119 L
.47242 .04126 L
.47411 .04136 L
.47605 .0415 L
.47824 .04168 L
.48029 .0419 L
.48254 .04214 L
Mistroke
.48465 .04241 L
.48673 .04268 L
.48871 .04295 L
.49048 .04319 L
.49209 .04339 L
.49355 .04355 L
.49477 .04368 L
.49585 .04382 L
.49675 .04397 L
.49744 .04415 L
.49793 .04437 L
.49824 .04465 L
.49839 .04497 L
.49844 .04535 L
.49841 .04577 L
.49834 .04622 L
.49824 .04667 L
.49816 .04714 L
.49808 .04759 L
.49798 .048 L
.49785 .04833 L
.49771 .04852 L
.49758 .04855 L
.49751 .04843 L
.49753 .04817 L
.49769 .04781 L
.498 .04737 L
.49851 .04694 L
.49924 .04649 L
.50021 .04609 L
.50135 .0457 L
.5028 .04534 L
.50422 .04502 L
.50601 .04475 L
.50785 .04454 L
.50968 .04434 L
.51177 .04412 L
.51392 .04387 L
.51611 .04359 L
.51829 .04326 L
.52039 .04286 L
.52238 .04244 L
.52433 .04195 L
.52596 .04145 L
.52742 .04095 L
.52884 .04049 L
.52999 .04005 L
.53099 .03962 L
.53173 .03921 L
.53229 .03892 L
Mistroke
.53264 .03869 L
.53281 .03859 L
.53281 .0386 L
.53267 .03874 L
.53242 .03897 L
.53213 .03926 L
.53185 .0396 L
.53163 .03997 L
.53147 .04036 L
.53135 .04077 L
.53127 .04119 L
.53123 .04161 L
.53123 .04206 L
.53127 .0424 L
.53137 .04271 L
.53151 .04296 L
.53171 .04312 L
.53196 .04322 L
.53226 .04326 L
.53259 .04329 L
.53295 .04332 L
.5333 .04336 L
.53362 .04341 L
.53387 .04344 L
.53404 .04342 L
.53411 .04333 L
.53411 .04315 L
.53407 .0429 L
.53399 .04257 L
.53385 .0422 L
.53364 .0418 L
.53335 .04138 L
.53301 .04098 L
.53262 .04056 L
.53219 .04011 L
.53174 .03964 L
.53127 .03919 L
.5308 .03878 L
.53033 .03845 L
.52987 .03818 L
.52946 .03797 L
.52909 .03778 L
.52867 .03759 L
.52825 .03735 L
.52778 .03707 L
.52725 .03675 L
.52663 .03637 L
.52588 .036 L
.5249 .03564 L
.52363 .03534 L
Mistroke
.52205 .03505 L
.52008 .03478 L
.51798 .03453 L
.51546 .03429 L
.51274 .03406 L
.50997 .03384 L
.50682 .03364 L
.5042 .03348 L
.50093 .03338 L
.49831 .03333 L
.49504 .0333 L
.49243 .03325 L
.48972 .03318 L
.48686 .0331 L
.48438 .03301 L
.48169 .03293 L
.47879 .03282 L
.47635 .03269 L
.47318 .03253 L
.47061 .03237 L
.4677 .03225 L
.46427 .03217 L
.46128 .03216 L
.45793 .03223 L
.4547 .03238 L
.45119 .03262 L
.44836 .03292 L
.44542 .03329 L
.44272 .0337 L
.44013 .03412 L
.43791 .03454 L
.43599 .03491 L
.4343 .0352 L
.43302 .03538 L
.43201 .03544 L
.43126 .03538 L
.43075 .03521 L
.43045 .03498 L
.43034 .03472 L
.43037 .03445 L
.43048 .03424 L
.43064 .03408 L
.43082 .03401 L
.43096 .034 L
.43106 .03405 L
.43113 .03416 L
.43118 .03434 L
.43122 .0346 L
.43125 .03484 L
.43126 .03512 L
Mistroke
.43127 .03537 L
.43126 .03558 L
.43125 .0357 L
.43127 .03576 L
.43134 .03578 L
.43144 .03577 L
.43154 .03575 L
.43158 .03573 L
.43155 .03569 L
.43141 .03562 L
.43116 .03555 L
.43077 .0355 L
.43028 .03549 L
.42969 .03552 L
.42905 .03562 L
.42838 .03578 L
.42774 .03601 L
.42717 .03631 L
.42657 .03667 L
.42596 .03706 L
.42538 .03748 L
.42492 .03789 L
.42462 .03832 L
.42447 .0387 L
.42442 .03908 L
.42444 .03942 L
.42452 .03969 L
.42463 .03988 L
.42468 .03998 L
.42469 .04002 L
.42467 .04001 L
.42463 .03998 L
.4246 .03993 L
.42458 .0399 L
.42459 .03988 L
.42464 .03987 L
.42472 .03986 L
.42485 .03986 L
.42502 .03987 L
.42521 .03987 L
.42543 .03988 L
.42565 .03989 L
.42588 .03989 L
.4261 .0399 L
.42632 .03993 L
.42652 .03997 L
.4267 .04003 L
.42685 .04007 L
.42695 .0401 L
.42701 .0401 L
Mistroke
.42703 .04005 L
.427 .03993 L
.42696 .03971 L
.4269 .03939 L
.42684 .03901 L
.4268 .03861 L
.42678 .03823 L
.42678 .03788 L
.42677 .03763 L
.42677 .03749 L
.42678 .03746 L
.4268 .03747 L
.42682 .03753 L
.42683 .03766 L
.42685 .03787 L
.42687 .03816 L
.42689 .03849 L
.42693 .03884 L
.42699 .03919 L
.42707 .0395 L
.4272 .03976 L
.42737 .0399 L
.42759 .03997 L
.42786 .03998 L
.42818 .03995 L
.42852 .0399 L
.42889 .0399 L
.42929 .03993 L
.42968 .03998 L
.43006 .04003 L
.4304 .04006 L
.4307 .04009 L
.43096 .04009 L
.43116 .04008 L
.43129 .04007 L
.43137 .04006 L
.43139 .04006 L
.43138 .04006 L
.43136 .04006 L
.43132 .04006 L
.43129 .04006 L
.43126 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
Mistroke
.43124 .04006 L
.43124 .04006 L
.43124 .04006 L
.43123 .04006 L
.4312 .04006 L
.43117 .04006 L
.43113 .04006 L
.43112 .04005 L
.43113 .04005 L
.43117 .04006 L
.43125 .04007 L
.43138 .04009 L
.43153 .04011 L
.43169 .04012 L
.43187 .04011 L
.43206 .04009 L
.43228 .04006 L
.43252 .04003 L
.43279 .03999 L
.4331 .03997 L
.43343 .03996 L
.43375 .03995 L
.43404 .03992 L
.43427 .03988 L
.43445 .03984 L
.43458 .0398 L
.43469 .03977 L
.43478 .03975 L
.43488 .03975 L
.43498 .03977 L
.43507 .03981 L
.43515 .03986 L
.4352 .03991 L
.43523 .03995 L
.43523 .03998 L
.43525 .04002 L
.43531 .04007 L
.43542 .04017 L
.43556 .04029 L
.43568 .04038 L
.43575 .04041 L
.43573 .04036 L
.43559 .0402 L
.43532 .03995 L
.43493 .03959 L
.43446 .03916 L
.43398 .0387 L
.43353 .03823 L
.43316 .03777 L
.43282 .03733 L
Mistroke
.43252 .03689 L
.43227 .03647 L
.4321 .03611 L
.43203 .03582 L
.43206 .03563 L
.43218 .03552 L
.43238 .03549 L
.43262 .03552 L
.4329 .03559 L
.43316 .03567 L
.43335 .03573 L
.43347 .03576 L
.43352 .03576 L
.43354 .03576 L
.43352 .03576 L
.43349 .03576 L
.43345 .03577 L
.43343 .03577 L
.43341 .03578 L
.43341 .03579 L
.43341 .0358 L
.43341 .0358 L
.43341 .03581 L
.43341 .03581 L
.43341 .03581 L
.43341 .03581 L
.43341 .03581 L
.43341 .03581 L
.43341 .0358 L
.43341 .03579 L
.43341 .03578 L
.43341 .03577 L
.43341 .03577 L
.43341 .03576 L
.43341 .03575 L
.43341 .03575 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
Mistroke
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03576 L
.43341 .03577 L
.43342 .03577 L
.43344 .03577 L
.43345 .03577 L
.43346 .03577 L
.43344 .03576 L
.43341 .03575 L
.43337 .03574 L
.43332 .03573 L
.43326 .03572 L
.43321 .03571 L
.43317 .0357 L
.43314 .0357 L
.43312 .0357 L
.43312 .0357 L
.43313 .0357 L
.43315 .03571 L
.43319 .03572 L
.43324 .03573 L
.43327 .03574 L
.43329 .03574 L
.43328 .03574 L
.43325 .03574 L
.4332 .03574 L
.43314 .03573 L
.43307 .03572 L
.43301 .03571 L
Mistroke
.43294 .03571 L
.4329 .03571 L
.43288 .03571 L
.43287 .03571 L
.43286 .03571 L
.43286 .03571 L
.43289 .03572 L
.43296 .03573 L
.43306 .03574 L
.43321 .03575 L
.43339 .03576 L
.43359 .03577 L
.43379 .03578 L
.434 .03579 L
.43419 .03579 L
.43439 .03579 L
.43459 .0358 L
.43481 .03581 L
.43503 .03581 L
.43523 .03582 L
.4354 .03583 L
.43554 .03583 L
.43564 .03583 L
.43569 .03583 L
.43571 .03584 L
.4357 .03583 L
.43566 .03583 L
.43563 .03583 L
.4356 .03583 L
.43559 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43559 .03583 L
.4356 .03583 L
.43565 .03583 L
.43571 .03584 L
Mistroke
.43578 .03584 L
.4358 .03584 L
.43578 .03584 L
.4357 .03584 L
.43553 .03583 L
.43528 .03582 L
.43494 .03581 L
.43455 .0358 L
.43412 .03579 L
.43368 .03577 L
.43325 .03576 L
.43283 .03574 L
.4324 .03573 L
.43199 .03572 L
.4316 .0357 L
.43128 .03569 L
.43105 .03569 L
.43092 .03568 L
.4309 .03568 L
.43096 .03568 L
.4311 .03569 L
.4313 .0357 L
.43151 .0357 L
.43172 .03571 L
.43195 .03572 L
.43218 .03572 L
.4324 .03573 L
.43263 .03574 L
.43285 .03575 L
.43305 .03575 L
.43322 .03576 L
.43337 .03577 L
.43346 .03577 L
.43352 .03577 L
.43354 .03577 L
.43353 .03576 L
.43351 .03576 L
.43349 .03575 L
.43347 .03574 L
.43345 .03574 L
.43341 .03573 L
.43337 .03573 L
.43332 .03573 L
.43326 .03574 L
.43321 .03575 L
.43317 .03576 L
.43314 .03574 L
.43312 .03572 L
.43311 .0357 L
.4331 .03566 L
Mistroke
.43307 .03563 L
.43305 .03559 L
.43305 .03557 L
.43308 .03555 L
.43314 .03554 L
.43324 .03554 L
.43338 .03554 L
.43356 .03554 L
.43376 .03556 L
.43397 .03558 L
.43417 .03562 L
.43438 .03567 L
.43459 .03572 L
.43481 .03577 L
.43502 .03581 L
.43523 .03585 L
.4354 .03587 L
.43554 .03587 L
.43564 .03586 L
.43569 .03584 L
.43571 .03584 L
.4357 .03583 L
.43566 .03583 L
.43563 .03583 L
.4356 .03583 L
.43559 .03583 L
.43558 .03583 L
.43558 .03583 L
.43558 .03583 L
.43559 .03581 L
.43561 .03576 L
.43563 .03569 L
.43563 .03563 L
.43562 .0356 L
.43559 .03562 L
.43554 .03571 L
.43549 .03588 L
.43544 .03613 L
.43539 .03646 L
.43535 .03685 L
.43532 .03728 L
.4353 .03773 L
.43529 .03817 L
.4353 .0386 L
.4353 .03903 L
.43531 .03944 L
.43534 .0398 L
.43538 .04008 L
.43543 .04028 L
.43549 .0404 L
Mistroke
.43555 .04043 L
.43561 .04039 L
.43569 .04031 L
.43577 .0402 L
.43582 .0401 L
.43583 .04001 L
.4358 .03995 L
.4357 .03993 L
.43554 .03998 L
.43529 .04012 L
.43495 .04036 L
.43456 .04071 L
.43414 .04116 L
.43369 .0417 L
.43326 .04228 L
.43284 .04294 L
.43242 .04365 L
.43203 .04437 L
.43167 .04502 L
.43137 .04562 L
.43117 .04611 L
.43108 .04645 L
.43111 .0466 L
.43122 .04656 L
.43134 .04633 L
.43145 .04595 L
.4315 .0455 L
.43146 .045 L
.43127 .0445 L
.431 .04402 L
.43055 .04356 L
.42987 .04311 L
.42897 .04268 L
.42791 .04227 L
.42681 .04189 L
.42567 .04156 L
.42431 .04128 L
.42266 .04103 L
.42121 .04083 L
.41961 .04068 L
.41819 .04052 L
.41672 .04034 L
.41539 .04014 L
.41431 .0399 L
.41335 .03964 L
.41249 .03934 L
.41178 .03901 L
.41126 .03864 L
.41091 .03826 L
.41073 .03785 L
Mistroke
.41069 .03743 L
.41074 .03702 L
.41082 .03661 L
.41092 .03618 L
.411 .03578 L
.41103 .03542 L
.41099 .03514 L
.41092 .03496 L
.41083 .03485 L
.41072 .03482 L
.41059 .03483 L
.41044 .03489 L
.41026 .03496 L
.41005 .03501 L
.40982 .03504 L
.40961 .03503 L
.40943 .03502 L
.40931 .03501 L
.40923 .03501 L
.40919 .03501 L
.40921 .03501 L
.40928 .03503 L
.40937 .03506 L
.40948 .03509 L
.40957 .03512 L
.40964 .03515 L
.40969 .03519 L
.40972 .03523 L
.40976 .03526 L
.40981 .03529 L
.40988 .03531 L
.41 .03532 L
.41015 .03532 L
.41033 .03531 L
.4105 .03528 L
.41066 .03522 L
.41078 .0353 L
.41087 .03526 L
.41094 .03523 L
.41098 .03523 L
.41098 .03526 L
.41094 .03533 L
.41083 .03545 L
.41064 .03562 L
.41036 .03587 L
.40999 .03614 L
.40956 .03647 L
.40911 .03683 L
.40867 .03719 L
.40827 .03759 L
Mistroke
.40793 .03796 L
.40765 .03826 L
.40743 .03856 L
.40727 .03881 L
.40716 .03902 L
.4071 .03918 L
.40708 .0393 L
.40711 .03938 L
.40719 .03942 L
.40733 .03944 L
.40745 .03944 L
.40753 .03942 L
.40751 .03938 L
.40738 .03934 L
.40712 .03931 L
.40674 .0393 L
.40624 .03928 L
.40565 .03926 L
.405 .03924 L
.40433 .03922 L
.40367 .0392 L
.40303 .03918 L
.40239 .03915 L
.40178 .03914 L
.40123 .03912 L
.40079 .03911 L
.40049 .0391 L
.40033 .03909 L
.40027 .03909 L
.4003 .03909 L
.40039 .03909 L
.4005 .0391 L
.40058 .0391 L
.40061 .0391 L
.40062 .03908 L
.40063 .03905 L
.40066 .03902 L
.4007 .03901 L
.40073 .03902 L
.40074 .03905 L
.40072 .03912 L
.40065 .03923 L
.40052 .03939 L
.40036 .03959 L
.40018 .03978 L
.4 .03995 L
.39984 .04011 L
.3997 .04021 L
.39961 .04027 L
.39954 .04033 L
Mistroke
.39952 .04034 L
.39953 .0403 L
.39958 .0402 L
.39966 .04006 L
.39979 .03988 L
.39995 .03969 L
.40014 .03949 L
.40032 .03929 L
.4005 .03914 L
.40063 .03904 L
.40072 .03901 L
.40075 .03899 L
.40073 .039 L
.4007 .03902 L
.40066 .03906 L
.40064 .03908 L
.40062 .0391 L
.40062 .0391 L
.40062 .0391 L
.40062 .0391 L
.40062 .0391 L
.40062 .0391 L
.40064 .0391 L
.40069 .0391 L
.40076 .03911 L
.40082 .03911 L
.40086 .03911 L
.40084 .03911 L
.40076 .03911 L
.4006 .0391 L
.40037 .03909 L
.40008 .03904 L
.39976 .03895 L
.39942 .03883 L
.39907 .03872 L
.3987 .03865 L
.39833 .03863 L
.3979 .03871 L
.39739 .03892 L
.39681 .03928 L
.39614 .0398 L
.39536 .04048 L
.39444 .0413 L
.39336 .04222 L
.39223 .04315 L
.3909 .04412 L
.38938 .04512 L
.38786 .04612 L
.38605 .04706 L
.38442 .04785 L
Mistroke
.38278 .04851 L
.38121 .04903 L
.37982 .04939 L
.3787 .04961 L
.37775 .0497 L
.37702 .0497 L
.3765 .04965 L
.37617 .04958 L
.37598 .04951 L
.37592 .04943 L
.37593 .04937 L
.376 .04934 L
.3761 .04934 L
.37621 .04934 L
.37631 .04934 L
.37635 .04934 L
.37636 .04934 L
.37638 .04931 L
.37644 .04924 L
.37655 .04914 L
.37665 .04905 L
.37671 .04901 L
.37671 .04905 L
.37662 .04918 L
.37638 .04943 L
.37596 .04981 L
.37537 .0503 L
.37465 .05088 L
.37387 .05152 L
.37307 .05219 L
.37227 .05283 L
.37162 .05344 L
.3709 .05405 L
.37021 .05463 L
.36962 .05514 L
.3692 .05554 L
.36899 .05578 L
.36898 .05586 L
.3691 .05583 L
.3693 .05572 L
.36952 .05559 L
.36971 .05549 L
.36978 .05546 L
.36966 .05553 L
.36934 .0557 L
.3688 .05595 L
.36803 .05628 L
.36701 .05668 L
.36591 .05717 L
.36449 .05776 L
Mistroke
.36318 .05844 L
.36177 .05923 L
.36015 .06013 L
.35858 .06113 L
.35696 .06221 L
.35525 .06331 L
.35354 .06437 L
.3519 .06536 L
.35024 .06632 L
.34861 .06722 L
.34727 .06803 L
.34588 .06873 L
.34459 .06934 L
.34356 .06986 L
.34266 .07028 L
.34188 .07062 L
.34124 .07087 L
.34075 .07106 L
.34042 .07124 L
.34026 .0714 L
.34024 .07156 L
.34031 .07171 L
.34044 .07188 L
.34057 .07208 L
.34067 .07228 L
.34073 .07246 L
.34074 .0726 L
.34074 .0727 L
.34074 .07275 L
.34074 .07277 L
.34074 .07276 L
.34074 .07272 L
.34074 .07268 L
.34074 .07266 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34074 .07264 L
.34076 .07261 L
.34082 .07257 L
.34092 .0725 L
.34102 .07244 L
.34108 .0724 L
.34105 .07242 L
Mistroke
.34094 .0725 L
.34071 .07266 L
.34035 .0729 L
.33988 .07318 L
.33935 .0735 L
.33878 .07385 L
.33817 .07422 L
.3375 .07464 L
.33681 .07511 L
.33605 .07564 L
.33524 .07621 L
.33442 .07682 L
.33363 .07743 L
.33292 .07801 L
.33236 .07855 L
.33191 .07904 L
.33155 .07947 L
.3312 .07987 L
.33081 .08025 L
.33033 .08062 L
.32975 .08096 L
.32908 .08125 L
.32837 .08145 L
.32764 .08155 L
.32694 .08157 L
.32631 .08152 L
.32575 .0814 L
.32521 .08128 L
.32463 .08117 L
.32402 .08111 L
.32343 .08109 L
.32291 .08112 L
.32249 .08119 L
.32215 .0813 L
.32189 .08145 L
.3217 .08162 L
.32156 .08183 L
.32144 .08208 L
.32127 .08228 L
.32106 .08254 L
.32083 .08278 L
.32062 .08299 L
.32044 .08316 L
.32033 .08327 L
.32028 .0833 L
.32032 .08327 L
.32042 .08322 L
.32059 .08318 L
.3208 .08319 L
.32103 .08324 L
Mistroke
.32126 .08339 L
.3215 .08362 L
.32174 .0839 L
.32198 .08419 L
.32224 .08443 L
.3225 .08459 L
.32276 .08467 L
.32299 .0847 L
.3232 .08471 L
.32335 .08472 L
.3234 .08482 L
.32332 .08484 L
.32309 .08489 L
.3227 .08497 L
.32211 .08512 L
.32129 .08539 L
.32019 .08581 L
.31897 .08638 L
.31744 .08717 L
.3156 .08817 L
.31355 .08937 L
.31163 .09061 L
.30949 .09194 L
.30712 .09332 L
.30497 .09463 L
.30275 .0959 L
.30087 .09702 L
.29918 .09805 L
.29777 .09898 L
.29662 .09981 L
.2956 .10051 L
.29476 .10109 L
.29406 .10158 L
.29347 .10197 L
.29293 .10229 L
.29238 .10258 L
.29178 .10287 L
.29107 .1032 L
.2902 .10364 L
.28918 .10418 L
.28802 .10487 L
.28662 .1057 L
.28494 .10671 L
.28319 .10783 L
.28135 .10907 L
.27945 .11038 L
.27777 .11166 L
.27615 .11287 L
.27481 .11401 L
.27351 .11505 L
Mistroke
.27244 .11591 L
.27154 .11663 L
.27085 .11719 L
.27037 .1176 L
.2701 .11785 L
.27 .11797 L
.27003 .118 L
.27014 .11797 L
.27029 .11789 L
.27043 .1178 L
.27052 .11772 L
.27058 .11764 L
.27066 .11756 L
.27077 .11747 L
.27087 .11737 L
.27092 .11728 L
.2709 .11724 L
.27078 .11725 L
.27055 .11737 L
.27017 .11761 L
.26966 .118 L
.26902 .11855 L
.26828 .11926 L
.26746 .1201 L
.26663 .12101 L
.2658 .12203 L
.26494 .12306 L
.26409 .12411 L
.26329 .12515 L
.2626 .12612 L
.26206 .12695 L
.26166 .12765 L
.26139 .1282 L
.26125 .1286 L
.26119 .12884 L
.2612 .12895 L
.26122 .12897 L
.26125 .12893 L
.26127 .12888 L
.26131 .12881 L
.26135 .12873 L
.26141 .12865 L
.26149 .1286 L
.26157 .12855 L
.26167 .1285 L
.26179 .12842 L
.26189 .12835 L
.26193 .12829 L
.26186 .12828 L
.26165 .12836 L
Mistroke
.26126 .12858 L
.26064 .12893 L
.25977 .12943 L
.25863 .13007 L
.25736 .13081 L
.25583 .13164 L
.25402 .13255 L
.25215 .13351 L
.2502 .13458 L
.24795 .13584 L
.24588 .13708 L
.24366 .13841 L
.24152 .13981 L
.23969 .14123 L
.23795 .14262 L
.23637 .14394 L
.23508 .14502 L
.23399 .1461 L
.2331 .14711 L
.23245 .14789 L
.23199 .1486 L
.23168 .14921 L
.23149 .14969 L
.23136 .15004 L
.23123 .15035 L
.23105 .15072 L
.23078 .15119 L
.23041 .15182 L
.22994 .15266 L
.22937 .15368 L
.22872 .15485 L
.22807 .15596 L
.2274 .15722 L
.22675 .1585 L
.22618 .15958 L
.22565 .16065 L
.22521 .16156 L
.22488 .16233 L
.22466 .16296 L
.22448 .1635 L
.22428 .16403 L
.22402 .16461 L
.22364 .16532 L
.22305 .16627 L
.22221 .16751 L
.2212 .16883 L
.21996 .17056 L
.21847 .17249 L
.21675 .17481 L
.21494 .17725 L
Mistroke
.21325 .18002 L
.21145 .18259 L
.20953 .18545 L
.20767 .18834 L
.20589 .19117 L
.20411 .19418 L
.20249 .19675 L
.20088 .19951 L
.1994 .20207 L
.19794 .20461 L
.19652 .20702 L
.19525 .20946 L
.19396 .21159 L
.19271 .21373 L
.19153 .21578 L
.19046 .21766 L
.18944 .21947 L
.18849 .22115 L
.18764 .22254 L
.18689 .22386 L
.18624 .22506 L
.18573 .22611 L
.18533 .22697 L
.18505 .22769 L
.18487 .22821 L
.18478 .22855 L
.18475 .22874 L
.18474 .22882 L
.18472 .22881 L
.18469 .22877 L
.18462 .22874 L
.1845 .22875 L
.18429 .22882 L
.18399 .22898 L
.18359 .22927 L
.18307 .22973 L
.18242 .23043 L
.18168 .23131 L
.18082 .23242 L
.17983 .23379 L
.17872 .23545 L
.17751 .2374 L
.17632 .23929 L
.17508 .24158 L
.17381 .24404 L
.17252 .24651 L
.17116 .24926 L
.16969 .25224 L
.1682 .25503 L
.1666 .25822 L
Mistroke
.16499 .26123 L
.16343 .2644 L
.16182 .26735 L
.16017 .2705 L
.15869 .2732 L
.1569 .27615 L
.15529 .279 L
.15347 .282 L
.15173 .28507 L
.14987 .28775 L
.14794 .29065 L
.14606 .29369 L
.14464 .29618 L
.1431 .29887 L
.14171 .30119 L
.14031 .3035 L
.13927 .30538 L
.13834 .30713 L
.13753 .30871 L
.1369 .30998 L
.13647 .31102 L
.13621 .31177 L
.13611 .31223 L
.13613 .31245 L
.13622 .31248 L
.13633 .31238 L
.13645 .31221 L
.13655 .31203 L
.13659 .31189 L
.13659 .31178 L
.13659 .31171 L
.13659 .31169 L
.13657 .31173 L
.13653 .31182 L
.13645 .31198 L
.13635 .31224 L
.13623 .31263 L
.1361 .31317 L
.13598 .31384 L
.13589 .31466 L
.13582 .31558 L
.13578 .31659 L
.13578 .31758 L
.1358 .31859 L
.13584 .31958 L
.13589 .32052 L
.13598 .32134 L
.13609 .322 L
.13622 .32242 L
.13638 .32267 L
Mistroke
.13654 .3228 L
.13669 .32284 L
.1368 .32285 L
.13684 .32289 L
.13679 .32308 L
.13665 .32357 L
.13641 .32444 L
.13612 .32571 L
.13577 .32738 L
.13537 .32948 L
.13491 .33163 L
.13435 .33404 L
.13369 .33695 L
.13293 .33999 L
.1321 .34337 L
.13119 .34667 L
.13023 .35019 L
.12931 .35364 L
.12839 .35674 L
.12751 .36013 L
.12673 .36322 L
.12598 .36639 L
.12535 .36934 L
.12478 .37245 L
.1243 .3751 L
.12391 .37789 L
.12363 .3805 L
.12346 .38318 L
.12338 .38576 L
.12337 .38787 L
.1234 .38987 L
.12346 .39175 L
.12351 .39345 L
.12354 .39491 L
.12354 .39604 L
.12353 .39699 L
.12352 .39772 L
.12351 .39826 L
.12351 .39862 L
.12351 .39881 L
Mfstroke
.11135 .48136 m
.11132 .4816 L
.11129 .48197 L
.11127 .48243 L
.11126 .48294 L
.11125 .48349 L
.11123 .48406 L
.11119 .48469 L
.11114 .48538 L
.11108 .48616 L
.11102 .487 L
.11098 .48787 L
.11096 .48879 L
.11094 .48977 L
.11091 .49081 L
.11084 .49195 L
.11073 .49319 L
.11057 .49461 L
.11036 .4963 L
.11011 .49834 L
.1098 .50057 L
.10946 .50316 L
.10911 .50599 L
.10878 .50856 L
.10844 .51112 L
.10813 .51387 L
.10786 .51648 L
.10764 .51928 L
.10749 .52165 L
.10745 .52404 L
.10754 .52637 L
.10775 .52847 L
.10805 .53046 L
.10844 .5322 L
.10887 .53375 L
.10932 .53512 L
.10976 .53633 L
.11016 .53735 L
.11051 .53819 L
.11082 .53889 L
.1111 .53947 L
.11136 .53995 L
.11159 .54032 L
.11181 .54062 L
.11202 .54084 L
.11224 .54102 L
.11249 .54115 L
.11275 .54125 L
.11302 .54131 L
.11326 .54134 L
Mistroke
.11351 .54141 L
.11373 .54154 L
.1139 .54175 L
.11396 .54204 L
.11392 .54244 L
.11375 .54297 L
.11349 .54364 L
.11317 .5445 L
.11283 .54559 L
.11252 .54683 L
.11227 .54834 L
.1121 .55009 L
.11203 .55198 L
.11208 .55411 L
.11224 .55639 L
.1125 .55864 L
.11286 .56106 L
.11332 .56345 L
.11388 .56593 L
.11446 .5682 L
.11505 .57048 L
.11562 .57271 L
.11612 .57459 L
.11655 .57641 L
.11688 .57806 L
.11715 .57944 L
.11734 .58064 L
.11749 .58168 L
.11759 .58237 L
.11767 .58292 L
.11773 .58326 L
.11776 .58342 L
.11775 .58342 L
.11772 .58335 L
.11768 .58328 L
.11766 .58329 L
.11766 .58337 L
.11769 .58352 L
.11774 .58372 L
.1178 .58397 L
.11784 .58425 L
.11788 .58453 L
.11791 .58484 L
.11792 .58515 L
.11791 .58553 L
.11788 .58604 L
.11783 .58673 L
.11774 .5875 L
.11763 .58846 L
.11751 .58958 L
Mistroke
.11739 .59088 L
.11728 .59227 L
.11721 .59396 L
.1172 .59587 L
.11725 .59804 L
.11736 .60055 L
.11756 .60305 L
.11784 .60584 L
.11819 .60879 L
.11863 .61197 L
.11914 .61493 L
.11973 .61795 L
.12037 .62109 L
.12104 .62405 L
.12171 .62716 L
.12235 .63006 L
.12293 .63298 L
.12349 .63556 L
.12403 .63803 L
.12453 .64012 L
.12499 .64198 L
.12542 .64361 L
.12581 .64505 L
.12614 .64636 L
.12644 .64759 L
.12671 .64878 L
.12698 .64993 L
.12726 .65103 L
.12756 .6521 L
.12789 .65304 L
.12824 .65395 L
.12859 .65476 L
.12891 .65553 L
.12918 .65615 L
.12941 .65671 L
.12963 .65721 L
.12983 .65761 L
.13002 .65798 L
.13022 .65841 L
.13042 .65892 L
.13061 .65953 L
.13079 .66042 L
.13094 .66157 L
.1311 .66296 L
.13124 .66445 L
.1314 .6661 L
.13155 .66786 L
.1317 .66956 L
.13181 .6714 L
.13191 .67309 L
Mistroke
.132 .67481 L
.13208 .67653 L
.13214 .67827 L
.13221 .68005 L
.13228 .68186 L
.13239 .68352 L
.13255 .68532 L
.13279 .68721 L
.13315 .68906 L
.13359 .69101 L
.13413 .69298 L
.13479 .69476 L
.13554 .69645 L
.13645 .69797 L
.13713 .69902 L
.13792 .70002 L
.13874 .70081 L
.1394 .70141 L
.14002 .70188 L
.14059 .70225 L
.14108 .70254 L
.14148 .70279 L
.14174 .70303 L
.14188 .70334 L
.14192 .70376 L
.14189 .70432 L
.1418 .70507 L
.14172 .70601 L
.14164 .70709 L
.14158 .70827 L
.14153 .70955 L
.14147 .71087 L
.14138 .7123 L
.14129 .71384 L
.14119 .71566 L
.14109 .71731 L
.141 .71916 L
.14093 .72108 L
.14087 .72291 L
.14083 .7246 L
.1408 .72613 L
.14078 .72737 L
.14078 .72845 L
.1408 .72936 L
.14084 .73013 L
.1409 .73076 L
.14096 .73122 L
.14103 .7315 L
.14108 .73161 L
.14113 .73161 L
Mistroke
.14115 .73153 L
.14115 .73141 L
.14113 .73129 L
.14111 .7312 L
.14109 .73115 L
.14109 .73112 L
.14109 .73108 L
.1411 .73101 L
.1411 .73092 L
.1411 .73081 L
.1411 .73068 L
.1411 .73056 L
.14109 .73047 L
.14106 .73044 L
.14102 .73044 L
.14098 .73044 L
.14096 .73043 L
.14096 .73044 L
.14097 .73046 L
.14101 .73053 L
.14106 .73065 L
.14115 .73086 L
.14131 .73119 L
.14156 .73167 L
.14191 .73228 L
.14238 .73304 L
.14296 .73394 L
.14367 .73501 L
.14449 .73613 L
.14537 .73737 L
.14623 .73869 L
.1471 .74005 L
.14795 .74145 L
.14872 .74276 L
.14947 .74405 L
.15018 .74527 L
.15087 .7464 L
.15158 .74746 L
.15233 .74849 L
.15319 .74962 L
.15407 .75074 L
.15507 .75206 L
.1562 .75354 L
.15737 .75506 L
.15874 .75671 L
.16026 .7585 L
.16191 .76036 L
.16361 .76203 L
.16531 .76378 L
.16684 .76521 L
Mistroke
.1683 .76647 L
.16945 .76754 L
.17038 .76833 L
.17099 .76882 L
.17127 .76905 L
.17127 .76906 L
.17109 .76893 L
.17085 .76871 L
.17059 .76847 L
.17036 .76829 L
.1702 .76825 L
.1701 .76842 L
.17009 .7688 L
.17022 .76934 L
.1706 .77003 L
.17138 .77086 L
.17223 .77169 L
.17351 .77263 L
.17497 .77362 L
.17667 .77465 L
.17845 .7757 L
.18038 .77669 L
.18225 .77764 L
.18413 .77851 L
.18605 .77927 L
.18787 .77991 L
.18957 .78044 L
.19112 .78087 L
.19241 .78124 L
.19347 .78154 L
.19436 .78184 L
.19494 .78208 L
.19541 .78238 L
.19576 .78274 L
.19603 .78317 L
.19623 .78371 L
.19644 .78437 L
.19665 .78523 L
.1969 .78619 L
.19719 .78743 L
.19761 .78892 L
.19819 .79058 L
.19897 .79241 L
.19995 .79448 L
.20113 .79679 L
.20242 .79915 L
.20383 .80154 L
.20539 .8041 L
.207 .80661 L
.20875 .80919 L
Mistroke
.21067 .81178 L
.2127 .8143 L
.21488 .81675 L
.21702 .81908 L
.21918 .82124 L
.22114 .82318 L
.2229 .82476 L
.22445 .82613 L
.22574 .82721 L
.22683 .82807 L
.2277 .82877 L
.22845 .82934 L
.22913 .82988 L
.2298 .83046 L
.2305 .83113 L
.23125 .83191 L
.23209 .83283 L
.23304 .83389 L
.2342 .83514 L
.23562 .83661 L
.23723 .83833 L
.23907 .84016 L
.24094 .84207 L
.24292 .84394 L
.24491 .84589 L
.24662 .84739 L
.2483 .84889 L
.24974 .85022 L
.25099 .85131 L
.25199 .85221 L
.25278 .85294 L
.25334 .85349 L
.25372 .85389 L
.25394 .85418 L
.25404 .8544 L
.25409 .8546 L
.25412 .85481 L
.25422 .85506 L
.25442 .85537 L
.25473 .85574 L
.25519 .85618 L
.25578 .85666 L
.25648 .85716 L
.25719 .85768 L
.25793 .8581 L
.25867 .85853 L
.25935 .85889 L
.25993 .85916 L
.26039 .85933 L
.26073 .85942 L
Mistroke
.26095 .85946 L
.26106 .85945 L
.26111 .85945 L
.26116 .85951 L
.2613 .85967 L
.26161 .85997 L
.26212 .86045 L
.26288 .8611 L
.26388 .86192 L
.26507 .86295 L
.26655 .86413 L
.26829 .86551 L
.27012 .86701 L
.27209 .86857 L
.27408 .87016 L
.27602 .87162 L
.2778 .87291 L
.27951 .87425 L
.2811 .87557 L
.28245 .87682 L
.28367 .87803 L
.28467 .87909 L
.2856 .88008 L
.28622 .88097 L
.28678 .88176 L
.28729 .8824 L
.28766 .8831 L
.28803 .88382 L
.28844 .88461 L
.28892 .88546 L
.28946 .88626 L
.29015 .88711 L
.29098 .88795 L
.29205 .88875 L
.29303 .88953 L
.29429 .89032 L
.2957 .89116 L
.2973 .8921 L
.29915 .89314 L
.30125 .89426 L
.3035 .89542 L
.30575 .89651 L
.30799 .89756 L
.31021 .89854 L
.31218 .89946 L
.31398 .90026 L
.31536 .90095 L
.31649 .90156 L
.3174 .90207 L
.31812 .90243 L
Mistroke
.31863 .90261 L
.31899 .90261 L
.31923 .90246 L
.31944 .90219 L
.31972 .90186 L
.32017 .90154 L
.32078 .90126 L
.32159 .90102 L
.32253 .90082 L
.32363 .90066 L
.32482 .90048 L
.32604 .90026 L
.32717 .90003 L
.32813 .89976 L
.32886 .89946 L
.32934 .89913 L
.32962 .89883 L
.32976 .89863 L
.32975 .89852 L
.32963 .8985 L
.32955 .89858 L
.32958 .89881 L
.32981 .89916 L
.3303 .89968 L
.33114 .90048 L
.33236 .90153 L
.33403 .9028 L
.33603 .90421 L
.33849 .90573 L
.34115 .90738 L
.34421 .90913 L
.34726 .91088 L
.35056 .91259 L
.35377 .91425 L
.35706 .91579 L
.36031 .91714 L
.36357 .91842 L
.36654 .91954 L
.36954 .92055 L
.37247 .92148 L
.37532 .92232 L
.37808 .92311 L
.38075 .92384 L
.38333 .92454 L
.38592 .92524 L
.38848 .92593 L
.3909 .92665 L
.39332 .9274 L
.3957 .92821 L
.3979 .92904 L
Mistroke
.39994 .92987 L
.40173 .93063 L
.40322 .93132 L
.40443 .9319 L
.40538 .93235 L
.4061 .93263 L
.40664 .93276 L
.40706 .93274 L
.40743 .93254 L
.40786 .93216 L
.40841 .93162 L
.40914 .93096 L
.41 .93017 L
.41108 .92928 L
.41228 .92832 L
.41358 .92733 L
.41496 .92637 L
.41637 .9254 L
.41772 .92477 L
.41892 .9241 L
.41985 .92363 L
.42052 .92335 L
.42093 .9233 L
.42107 .92348 L
.42097 .92382 L
.42069 .9243 L
.42036 .92494 L
.42007 .92568 L
.41988 .92641 L
.41986 .92705 L
.42006 .92759 L
.42049 .92809 L
.42113 .92854 L
.42194 .92891 L
.42276 .92927 L
.4236 .92967 L
.42434 .93008 L
.42495 .93048 L
.42535 .93088 L
.42554 .93128 L
.42554 .93154 L
.42539 .9317 L
.42512 .93168 L
.42477 .93151 L
.4242 .93114 L
.42374 .93046 L
.4232 .92961 L
.42269 .92874 L
.42225 .92753 L
.42196 .92624 L
Mistroke
.4218 .92477 L
.42177 .92345 L
.42179 .92221 L
.42184 .9212 L
.42188 .92045 L
.42184 .91997 L
.42169 .91972 L
.42141 .91972 L
.42106 .92001 L
.42069 .92054 L
.42032 .92122 L
.42 .92203 L
.41977 .92299 L
.41966 .92403 L
.41968 .9252 L
.41985 .92644 L
.4202 .92773 L
.42074 .92912 L
.42148 .93058 L
.42241 .9321 L
.42356 .93362 L
.42492 .93514 L
.42647 .93668 L
.42825 .9382 L
.43016 .93969 L
.43231 .94118 L
.43472 .94258 L
.43715 .94383 L
.43978 .94498 L
.44255 .94608 L
.44536 .94714 L
.44818 .94815 L
.45087 .94911 L
.45357 .95003 L
.4561 .95087 L
.45851 .95163 L
.46055 .9523 L
.4624 .95282 L
.46403 .9532 L
.46545 .95349 L
.46672 .95376 L
.46788 .95405 L
.46903 .95434 L
.47004 .9546 L
.47117 .95484 L
.47239 .95502 L
.47365 .95507 L
.475 .955 L
.47645 .95484 L
.4779 .95464 L
Mistroke
.47936 .95449 L
.48081 .95446 L
.48225 .95454 L
.48365 .9547 L
.48508 .95479 L
.48655 .95488 L
.48809 .95497 L
.48971 .95509 L
.4914 .95523 L
.49316 .95538 L
.4951 .95558 L
.49714 .95584 L
.4993 .95611 L
.50152 .95631 L
.50382 .95641 L
.50615 .95636 L
.50854 .95619 L
.51124 .95597 L
.51348 .95578 L
.51581 .9556 L
.51802 .95545 L
.51997 .95536 L
.52155 .95532 L
.52273 .95532 L
.52346 .95533 L
.52393 .95533 L
.52416 .9553 L
.52419 .95531 L
.5241 .95537 L
.52384 .95542 L
.52347 .95545 L
.5231 .95543 L
.52276 .95532 L
.52246 .95511 L
.52226 .95477 L
.52213 .95432 L
.52214 .9538 L
.52233 .95324 L
.52268 .95267 L
.52313 .9521 L
.5234 .95148 L
.52355 .95079 L
.5236 .95007 L
.52355 .94939 L
.52351 .94872 L
.52346 .94816 L
.5234 .94768 L
.5234 .94737 L
.5234 .94716 L
.52338 .94709 L
Mistroke
.52329 .94715 L
.52309 .94731 L
.52276 .94743 L
.52226 .94746 L
.52155 .94745 L
.52061 .94744 L
.51941 .94742 L
.51799 .94743 L
.51637 .94752 L
.51463 .9477 L
.51262 .9479 L
.51028 .94808 L
.50812 .94822 L
.50573 .9484 L
.50324 .94856 L
.50067 .94868 L
.49806 .94889 L
.49537 .94916 L
.49275 .94951 L
.49009 .94982 L
.48742 .95024 L
.48482 .9505 L
.48212 .95067 L
.47944 .95072 L
.4768 .95075 L
.47419 .95078 L
.47158 .95082 L
.46911 .95088 L
.46661 .95095 L
.46438 .951 L
.46212 .95094 L
.45979 .95073 L
.45782 .95038 L
.45583 .94989 L
.45389 .94931 L
.4519 .94865 L
.44992 .94794 L
.44796 .94723 L
.44596 .94649 L
.44389 .94573 L
.44173 .94495 L
.43957 .94413 L
.43724 .94324 L
.4347 .94229 L
.43208 .94132 L
.42934 .94037 L
.42654 .93941 L
.42356 .93846 L
.42056 .93751 L
.41759 .93653 L
Mistroke
.4145 .93551 L
.41152 .93444 L
.40848 .93335 L
.40551 .9322 L
.40257 .93105 L
.39951 .92992 L
.39657 .92882 L
.39363 .92783 L
.39073 .92689 L
.3878 .92599 L
.38499 .92509 L
.38222 .92417 L
.3793 .92319 L
.37632 .92216 L
.37346 .92109 L
.37048 .91998 L
.3674 .91889 L
.36457 .91785 L
.36183 .91684 L
.35903 .91588 L
.35662 .91497 L
.35406 .91412 L
.35206 .91339 L
.35027 .91277 L
.34864 .9123 L
.34725 .91199 L
.34615 .91182 L
.34533 .91175 L
.3447 .91173 L
.34414 .91165 L
.34356 .91144 L
.34288 .91107 L
.34207 .91053 L
.34107 .9098 L
.3398 .90893 L
.33848 .908 L
.33706 .907 L
.33566 .90599 L
.33434 .905 L
.33306 .90407 L
.33181 .90329 L
.33078 .90264 L
.32993 .90216 L
.32928 .90187 L
.32884 .90173 L
.32861 .90168 L
.32856 .90168 L
.32865 .90164 L
.3288 .90148 L
.32896 .90115 L
Mistroke
.32909 .90069 L
.32915 .90014 L
.32914 .89951 L
.32911 .89889 L
.3291 .89839 L
.32929 .89802 L
.32945 .89781 L
.32965 .89775 L
.32981 .89787 L
.32992 .89817 L
.32992 .89859 L
.32972 .89907 L
.32928 .89955 L
.32856 .90009 L
.32755 .90056 L
.32622 .90086 L
.32468 .90093 L
.32279 .90072 L
.32072 .90021 L
.31846 .89952 L
.31587 .89862 L
.31315 .8976 L
.31037 .89661 L
.30793 .89562 L
.30541 .89471 L
.30316 .89398 L
.30114 .89331 L
.29944 .89275 L
.298 .89225 L
.29677 .89178 L
.29582 .89132 L
.29499 .89088 L
.29427 .89044 L
.29377 .89004 L
.29334 .88962 L
.293 .88919 L
.29275 .88881 L
.29259 .88845 L
.29245 .88809 L
.29231 .88774 L
.29211 .88743 L
.2919 .88717 L
.29157 .88695 L
.29115 .88676 L
.29061 .88654 L
.28993 .88623 L
.28906 .88579 L
.28804 .88519 L
.28686 .88438 L
.28559 .8834 L
Mistroke
.28415 .88222 L
.28254 .88086 L
.28078 .8794 L
.27902 .87788 L
.27725 .87632 L
.27558 .87477 L
.27409 .87328 L
.27282 .87201 L
.27176 .87095 L
.2709 .87011 L
.27015 .86939 L
.26953 .86884 L
.26895 .86831 L
.26831 .86772 L
.2677 .86714 L
.26712 .8666 L
.26642 .86591 L
.26561 .86511 L
.26463 .86414 L
.26343 .86302 L
.26204 .86171 L
.26052 .8603 L
.25881 .85873 L
.25695 .85702 L
.25497 .85516 L
.25294 .85326 L
.25084 .85127 L
.24881 .8493 L
.24678 .84732 L
.24472 .84535 L
.24277 .84358 L
.24084 .84182 L
.23897 .84002 L
.23721 .83834 L
.23552 .8366 L
.23394 .83479 L
.23247 .83305 L
.23106 .83128 L
.22973 .82953 L
.22851 .82791 L
.22736 .82635 L
.22629 .82506 L
.22531 .82379 L
.22438 .82271 L
.22347 .82166 L
.22254 .82062 L
.22159 .81966 L
.22058 .81877 L
.21948 .81792 L
.2183 .8171 L
Mistroke
.21703 .81625 L
.21569 .81535 L
.21437 .81433 L
.21293 .81327 L
.21143 .81191 L
.20988 .81047 L
.20821 .80882 L
.20656 .80707 L
.20484 .80517 L
.20309 .80315 L
.20141 .80114 L
.1998 .7992 L
.19824 .7972 L
.19673 .79517 L
.1952 .79313 L
.1938 .79114 L
.19236 .78912 L
.19093 .78715 L
.18953 .78529 L
.18825 .78358 L
.18708 .78203 L
.18604 .78063 L
.18502 .77935 L
.184 .77817 L
.18287 .77705 L
.1819 .77599 L
.18071 .77491 L
.17929 .77378 L
.17777 .77249 L
.17601 .77122 L
.17427 .76982 L
.17228 .76825 L
.17029 .76655 L
.16851 .76468 L
.16664 .76271 L
.16459 .76061 L
.16256 .75846 L
.16052 .75625 L
.1586 .75404 L
.15665 .75186 L
.15485 .74985 L
.15315 .74794 L
.15152 .74621 L
.15006 .74462 L
.1487 .7432 L
.1474 .74192 L
.14624 .74077 L
.14529 .73974 L
.14449 .73879 L
.14386 .73797 L
Mistroke
.14343 .73732 L
.14319 .73685 L
.14313 .73652 L
.14319 .73628 L
.14333 .73608 L
.1435 .73592 L
.14367 .73577 L
.14384 .73563 L
.14398 .73547 L
.14408 .73529 L
.14412 .73515 L
.14412 .73506 L
.14405 .73501 L
.14393 .73492 L
.14373 .73476 L
.14349 .7345 L
.1432 .7341 L
.1429 .73354 L
.1426 .73277 L
.14236 .73204 L
.14213 .73115 L
.1419 .73021 L
.14169 .72919 L
.14147 .72802 L
.14125 .72659 L
.14104 .72489 L
.14084 .72298 L
.14064 .72105 L
.14043 .71915 L
.14019 .71732 L
.13993 .71567 L
.13962 .71419 L
.13927 .71295 L
.13894 .71193 L
.13864 .71112 L
.1384 .71049 L
.13822 .70999 L
.1381 .70963 L
.13804 .70944 L
.13805 .70939 L
.13812 .70943 L
.13829 .70945 L
.13854 .70941 L
.13883 .70933 L
.13913 .70922 L
.13941 .70907 L
.13963 .70891 L
.13977 .70881 L
.13981 .70884 L
.13974 .70896 L
Mistroke
.13957 .70913 L
.13932 .70923 L
.13902 .70917 L
.13868 .70885 L
.13828 .70834 L
.1378 .70773 L
.13724 .70684 L
.13663 .70569 L
.136 .70424 L
.13538 .70254 L
.13482 .7006 L
.13426 .69864 L
.1337 .69634 L
.13311 .69361 L
.13248 .69072 L
.13178 .68746 L
.131 .68396 L
.13022 .67996 L
.12945 .6759 L
.12872 .67148 L
.12805 .66771 L
.12745 .66379 L
.12693 .6605 L
.12647 .65756 L
.12609 .65472 L
.12579 .65209 L
.12558 .65004 L
.12546 .64877 L
.12543 .64811 L
.12545 .6477 L
.12545 .64731 L
.1254 .64685 L
.12526 .64624 L
.12503 .64514 L
.12469 .64329 L
.1243 .64098 L
.12387 .63834 L
.12341 .63554 L
.12294 .63262 L
.12248 .62971 L
.12204 .62685 L
.12167 .6243 L
.12137 .62199 L
.12115 .62008 L
.12104 .61861 L
.12105 .61755 L
.1212 .61691 L
.12145 .61664 L
.12177 .61665 L
.12212 .61684 L
Mistroke
.12248 .61716 L
.12281 .61756 L
.12312 .61798 L
.12336 .61837 L
.12356 .6187 L
.12372 .61896 L
.12386 .61913 L
.12397 .61924 L
.12403 .6193 L
.12405 .61932 L
.12403 .6193 L
.124 .61927 L
.12395 .61923 L
.12392 .6192 L
.12391 .61918 L
.12391 .61918 L
.12393 .61919 L
.12399 .61922 L
.12406 .61926 L
.12413 .61933 L
.12417 .61945 L
.12415 .61961 L
.12407 .61979 L
.12391 .61994 L
.12365 .61999 L
.12329 .61988 L
.12284 .61951 L
.12231 .61882 L
.12174 .61778 L
.12116 .61638 L
.12058 .61457 L
.11999 .61235 L
.1194 .60997 L
.11884 .60724 L
.11834 .6041 L
.11791 .60103 L
.11753 .59768 L
.11721 .59432 L
.11692 .59088 L
.11665 .58758 L
.11638 .58431 L
.11607 .5811 L
.1157 .57788 L
.11527 .57466 L
.1148 .57138 L
.1143 .56796 L
.11377 .56426 L
.11318 .56074 L
.11256 .55703 L
.11195 .55331 L
Mistroke
.11133 .54961 L
.11071 .54604 L
.11011 .54264 L
.10954 .53925 L
.109 .53611 L
.10854 .533 L
.10817 .53005 L
.1079 .52719 L
.10772 .52443 L
.10764 .5216 L
.10767 .51874 L
.10781 .51562 L
.10806 .51254 L
.1084 .50922 L
.10885 .50581 L
.10936 .50226 L
.10994 .49887 L
.1105 .49561 L
.11108 .49268 L
.11163 .49006 L
.11212 .48775 L
.11256 .48584 L
.11294 .48426 L
.11327 .48292 L
.11354 .48178 L
.11376 .48081 L
.1139 .47997 L
.11399 .47923 L
.11402 .47854 L
.11403 .47783 L
.11404 .47712 L
.11408 .4763 L
.11416 .4754 L
.1143 .47444 L
.11451 .47348 L
.11477 .47261 L
.11507 .47189 L
.11536 .4713 L
.11564 .47084 L
.11591 .47047 L
.11615 .47016 L
.11634 .46986 L
.11648 .46952 L
.11657 .46913 L
.11663 .46868 L
.11669 .46823 L
.11677 .46778 L
.11687 .46737 L
.11698 .46696 L
.11707 .46656 L
Mistroke
.11719 .46614 L
.11735 .46572 L
.11756 .46529 L
.11783 .46488 L
.11814 .46449 L
.1185 .46412 L
.1189 .46376 L
.11932 .4634 L
.11976 .46303 L
.12015 .46263 L
.12049 .46218 L
.12076 .46177 L
.12103 .46137 L
.12129 .46103 L
.12155 .46075 L
.12179 .46056 L
.122 .46044 L
.12216 .46038 L
Mfstroke
.11625 .49272 m
.1162 .49285 L
.11611 .49311 L
.11596 .49351 L
.11572 .49408 L
.11536 .49487 L
.11489 .49587 L
.11427 .49703 L
.11371 .49828 L
.11301 .49977 L
.11224 .50153 L
.11144 .5036 L
.11073 .50557 L
.10994 .50806 L
.10926 .51021 L
.10862 .51259 L
.10806 .51527 L
.1076 .518 L
.10728 .52013 L
.10709 .52262 L
.10705 .52519 L
.10712 .52723 L
.10728 .52922 L
.1075 .53097 L
.10776 .53255 L
.10802 .53374 L
.10826 .53481 L
.1085 .53551 L
.10874 .53594 L
.10897 .53611 L
.10917 .53609 L
.10934 .53595 L
.10944 .53575 L
.10948 .53554 L
.10946 .53539 L
.1094 .53536 L
.10932 .53549 L
.10925 .53585 L
.10922 .53644 L
.10927 .53725 L
.10939 .53828 L
.10959 .5395 L
.10987 .54079 L
.11021 .54222 L
.1106 .54375 L
.111 .5453 L
.11143 .54678 L
.11188 .54817 L
.11233 .54941 L
.11273 .55042 L
Mistroke
.11311 .55124 L
.11343 .55185 L
.11368 .55226 L
.11386 .55249 L
.11396 .55259 L
.114 .5526 L
.11398 .55255 L
.11394 .55245 L
.1139 .55231 L
.11386 .55214 L
.11383 .55197 L
.11382 .55183 L
.11382 .55174 L
.11382 .55172 L
.11382 .55181 L
.11381 .55202 L
.11378 .55238 L
.11373 .5529 L
.11367 .55357 L
.1136 .55442 L
.11354 .55542 L
.11351 .55654 L
.11351 .55778 L
.11356 .55913 L
.11365 .56057 L
.11378 .56199 L
.11394 .56333 L
.11412 .56456 L
.1143 .56564 L
.1145 .56653 L
.11472 .56725 L
.11498 .5678 L
.11527 .56823 L
.11557 .56857 L
.11583 .56889 L
.11605 .56921 L
.1162 .56955 L
.11629 .56991 L
.11633 .57031 L
.11635 .57076 L
.11637 .57128 L
.11644 .57189 L
.11658 .57261 L
.11678 .57341 L
.11701 .57425 L
.11726 .57512 L
.11753 .57598 L
.11778 .57681 L
.11809 .57757 L
.11841 .57825 L
Mistroke
.11877 .57882 L
.11913 .57932 L
.1195 .57975 L
.11984 .5801 L
.12012 .58039 L
.12031 .58063 L
.12041 .5808 L
.12044 .58091 L
.12043 .58094 L
.12039 .58091 L
.12035 .58083 L
.12031 .58075 L
.12026 .58065 L
.12022 .58053 L
.12019 .58041 L
.12015 .58031 L
.12013 .58025 L
.12014 .58025 L
.12019 .58033 L
.12029 .58054 L
.12042 .58091 L
.12058 .58145 L
.12075 .58215 L
.12093 .58301 L
.12111 .58403 L
.12129 .58516 L
.12147 .58636 L
.12164 .58759 L
.1218 .58877 L
.12195 .58983 L
.1221 .59071 L
.1222 .59132 L
.12226 .59171 L
.1223 .59186 L
.12231 .59177 L
.12232 .59149 L
.12232 .59104 L
.12235 .59051 L
.1224 .58994 L
.12245 .58936 L
.12249 .58879 L
.12252 .58827 L
.12253 .58787 L
.12252 .58763 L
.12251 .58753 L
.12251 .58751 L
.12251 .58754 L
.12252 .58757 L
.12255 .58757 L
.12259 .58752 L
Mistroke
.12263 .58745 L
.12265 .5874 L
.12264 .58743 L
.1226 .58755 L
.12251 .58781 L
.12239 .58822 L
.12222 .58876 L
.12198 .58939 L
.12167 .59012 L
.1213 .59094 L
.12088 .59182 L
.12045 .5927 L
.12004 .59356 L
.11965 .59439 L
.1193 .59515 L
.119 .5958 L
.11872 .59633 L
.1185 .59674 L
.11831 .59706 L
.11816 .59729 L
.11805 .59744 L
.11799 .59758 L
.11798 .59771 L
.11801 .59787 L
.11808 .59805 L
.11819 .59823 L
.11832 .59842 L
.11845 .59864 L
.11856 .59883 L
.11867 .59904 L
.1188 .59927 L
.11891 .59943 L
.11907 .59959 L
.11924 .59971 L
.11941 .59978 L
.11954 .59983 L
.11961 .59989 L
.11963 .59995 L
.11963 .60001 L
.11962 .60004 L
.1196 .60004 L
.11959 .60003 L
.11958 .60001 L
.11957 .59999 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
Mistroke
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59997 L
.11956 .59996 L
.11956 .59992 L
.11956 .59983 L
.11957 .5997 L
.11957 .59958 L
.11957 .59951 L
.11957 .59952 L
.11957 .59964 L
.11956 .5999 L
.11955 .60033 L
.11953 .60092 L
.1195 .60168 L
.11947 .6026 L
.11943 .60366 L
.11939 .60473 L
.11935 .60584 L
.11931 .60696 L
.11927 .60811 L
.11924 .60911 L
.11921 .60995 L
.11917 .61059 L
.11913 .611 L
.11908 .61123 L
.11904 .61132 L
.11901 .61133 L
.11899 .61135 L
.119 .61145 L
.11905 .61172 L
.11913 .61222 L
.11927 .61298 L
.11947 .61407 L
.11975 .61557 L
Mistroke
.12009 .61733 L
.12049 .61946 L
.12094 .622 L
.12145 .62479 L
.12201 .62813 L
.12259 .63162 L
.12318 .63496 L
.12376 .63887 L
.12432 .64314 L
.12483 .64676 L
.12531 .65087 L
.12577 .65528 L
.12621 .65878 L
.12662 .66267 L
.12701 .6662 L
.12739 .66962 L
.12774 .67249 L
.12806 .67511 L
.12834 .6773 L
.12858 .6789 L
.12879 .68022 L
.129 .68125 L
.1292 .68201 L
.12941 .68254 L
.12961 .68295 L
.12981 .68335 L
.13001 .68382 L
.1302 .68437 L
.13037 .68501 L
.13055 .68579 L
.13076 .68672 L
.131 .68783 L
.13128 .68907 L
.13158 .69032 L
.13189 .69159 L
.13218 .69287 L
.13246 .69408 L
.13272 .69527 L
.133 .69655 L
.13328 .69799 L
.13358 .69961 L
.13397 .70152 L
.13435 .70324 L
.13478 .70543 L
.13524 .70787 L
.13568 .71017 L
.13613 .71271 L
.13658 .7154 L
.13704 .71804 L
.1375 .72093 L
Mistroke
.13796 .72304 L
.1384 .72523 L
.13879 .72715 L
.1391 .72872 L
.13931 .72994 L
.13946 .7308 L
.13957 .73135 L
.13966 .73159 L
.13976 .73168 L
.13986 .73167 L
.13996 .73157 L
.14006 .7315 L
.14016 .73145 L
.14024 .73147 L
.1403 .73153 L
.14037 .73162 L
.14045 .73174 L
.14055 .73186 L
.14067 .73197 L
.14081 .73208 L
.14095 .73225 L
.14109 .73245 L
.1412 .73269 L
.14127 .73294 L
.14129 .73317 L
.14126 .73333 L
.14117 .73338 L
.14104 .73333 L
.14088 .73323 L
.14068 .73307 L
.14046 .73289 L
.14023 .73272 L
.14003 .73265 L
.13986 .73263 L
.13974 .73263 L
.13969 .73263 L
.13973 .73267 L
.13984 .73279 L
.14004 .73299 L
.14035 .73331 L
.14074 .73374 L
.14118 .73423 L
.14163 .73479 L
.14208 .73525 L
.14251 .73573 L
.1429 .7361 L
.14325 .73632 L
.14356 .73645 L
.14387 .73652 L
.14419 .73654 L
Mistroke
.14456 .7365 L
.14496 .73642 L
.1454 .73632 L
.14583 .73623 L
.14631 .73614 L
.14676 .73614 L
.14721 .73617 L
.1476 .73622 L
.14793 .73632 L
.14815 .73648 L
.14823 .73668 L
.14819 .73685 L
.14801 .73696 L
.14771 .73708 L
.14731 .7372 L
.14684 .73731 L
.14635 .73738 L
.14585 .73738 L
.1454 .73736 L
.14502 .73733 L
.14475 .73735 L
.14458 .73742 L
.14454 .73755 L
.14463 .73772 L
.14484 .73802 L
.14513 .73843 L
.14549 .73892 L
.14591 .73948 L
.14636 .74006 L
.1469 .74069 L
.14733 .74121 L
.14781 .74182 L
.14825 .74245 L
.14863 .74306 L
.14894 .74361 L
.14915 .74406 L
.14926 .74438 L
.14929 .7446 L
.1493 .74473 L
.1493 .7448 L
.14944 .74473 L
.14945 .74474 L
.1495 .74478 L
.14957 .74483 L
.14966 .7449 L
.14976 .74495 L
.14986 .74499 L
.14996 .74499 L
.15006 .74499 L
.15016 .74495 L
Mistroke
.15025 .74491 L
.15035 .7449 L
.15042 .74492 L
.15044 .74493 L
.15039 .74494 L
.15028 .74491 L
.1501 .74482 L
.14988 .74465 L
.14966 .74444 L
.14945 .74423 L
.14926 .74405 L
.14912 .74394 L
.14903 .7439 L
.14896 .74392 L
.14891 .744 L
.14885 .74413 L
.14877 .74427 L
.14866 .7444 L
.14854 .74452 L
.14842 .74461 L
.14836 .7447 L
.14836 .74483 L
.14845 .745 L
.1486 .74519 L
.14879 .74534 L
.149 .74543 L
.14923 .74547 L
.14951 .74548 L
.14975 .74547 L
.15003 .74545 L
.15029 .74542 L
.15053 .74539 L
.15069 .74535 L
.15075 .74526 L
.15069 .7451 L
.15055 .7449 L
.15033 .74468 L
.15006 .74444 L
.14976 .74418 L
.14946 .74393 L
.14919 .74374 L
.14898 .74367 L
.14887 .74377 L
.14888 .74406 L
.14901 .74457 L
.14931 .74527 L
.14975 .74621 L
.15035 .74715 L
.15106 .74822 L
.15185 .74935 L
Mistroke
.15275 .75049 L
.15376 .75162 L
.15485 .75276 L
.15599 .7539 L
.15713 .75498 L
.15824 .75595 L
.15928 .75681 L
.16022 .75752 L
.16102 .75812 L
.16166 .75859 L
.16217 .75892 L
.16251 .75917 L
.16273 .7594 L
.16281 .75965 L
.16277 .75987 L
.16263 .76008 L
.16244 .76024 L
.16218 .76035 L
.16193 .76045 L
.1617 .76056 L
.16146 .76067 L
.16127 .76079 L
.16119 .76098 L
.16121 .7612 L
.16134 .76143 L
.16152 .76162 L
.16178 .76176 L
.1621 .76186 L
.16249 .76192 L
.16292 .76194 L
.16334 .76194 L
.16377 .76193 L
.16415 .7619 L
.16449 .76187 L
.16482 .76189 L
.16513 .76194 L
.16541 .76201 L
.16564 .76206 L
.1658 .76205 L
.16585 .76199 L
.1658 .76192 L
.16567 .76184 L
.16549 .76177 L
.16532 .7617 L
.16517 .76163 L
.16505 .76158 L
.16497 .76158 L
.16492 .76168 L
.1649 .76188 L
.1649 .76216 L
Mistroke
.16491 .76251 L
.16496 .76293 L
.16504 .76341 L
.16513 .76396 L
.16523 .76453 L
.16534 .76507 L
.16545 .76562 L
.16556 .76611 L
.16568 .76657 L
.16583 .76697 L
.16604 .76733 L
.16635 .76762 L
.16676 .76784 L
.16731 .76804 L
.16799 .76818 L
.16874 .76825 L
.16956 .76828 L
.17041 .76832 L
.17124 .76837 L
.17201 .76844 L
.1727 .76851 L
.17325 .76857 L
.17356 .76863 L
.17385 .76867 L
.17404 .76871 L
.17411 .76873 L
.17405 .76873 L
.1739 .76869 L
.17364 .76864 L
.17335 .7686 L
.17303 .76855 L
.17269 .76848 L
.17233 .76837 L
.17195 .76823 L
.17157 .76808 L
.17121 .76795 L
.17092 .76791 L
.17074 .768 L
.17069 .76824 L
.17079 .76865 L
.17102 .76923 L
.17138 .76997 L
.17189 .77084 L
.17247 .7718 L
.173 .77276 L
.17372 .77375 L
.17455 .7748 L
.17545 .77583 L
.17644 .77689 L
.17749 .77795 L
Mistroke
.17859 .77904 L
.17975 .78015 L
.18098 .7813 L
.1822 .78247 L
.18346 .78368 L
.18489 .78506 L
.18606 .78624 L
.18739 .78761 L
.18865 .78895 L
.18983 .79028 L
.19087 .79154 L
.1917 .79264 L
.19232 .79354 L
.19275 .79424 L
.19301 .79473 L
.19308 .79504 L
.19301 .79519 L
.19281 .79521 L
.19253 .79509 L
.1922 .79488 L
.19186 .79463 L
.19156 .7944 L
.19138 .79427 L
.19139 .79431 L
.19161 .7946 L
.1921 .7951 L
.19287 .79591 L
.1939 .79699 L
.19524 .79837 L
.1969 .80006 L
.19886 .80205 L
.20104 .80408 L
.20345 .80633 L
.20612 .80899 L
.20874 .81147 L
.21152 .81414 L
.21433 .81688 L
.21718 .81962 L
.21995 .82242 L
.22276 .82517 L
.22561 .82801 L
.22853 .8309 L
.23151 .8339 L
.23465 .83728 L
.23757 .84017 L
.24072 .84355 L
.24395 .84699 L
.24715 .85029 L
.25031 .85359 L
.25342 .85685 L
Mistroke
.25631 .85989 L
.25908 .86275 L
.26155 .86529 L
.2638 .86757 L
.26573 .86938 L
.26737 .87085 L
.2687 .87194 L
.26984 .87268 L
.27058 .87311 L
.27118 .87335 L
.27159 .87343 L
.27182 .87341 L
.27197 .87336 L
.27203 .87325 L
.27205 .87317 L
.27208 .87314 L
.27218 .87324 L
.27235 .87346 L
.27263 .87382 L
.27304 .87431 L
.27362 .87497 L
.27437 .87572 L
.27524 .87649 L
.27624 .87725 L
.27743 .87802 L
.27875 .87877 L
.2802 .87955 L
.28173 .88033 L
.28326 .8811 L
.28474 .88183 L
.28609 .88246 L
.28721 .88289 L
.28812 .88319 L
.28885 .88342 L
.28941 .8836 L
.28982 .88371 L
.2901 .88374 L
.29025 .88373 L
.29025 .88371 L
.29015 .88369 L
.28995 .88367 L
.28968 .88364 L
.28936 .8836 L
.28907 .88359 L
.2888 .88359 L
.28855 .88368 L
.28831 .88383 L
.28806 .88405 L
.28792 .88427 L
.28772 .88445 L
Mistroke
.28755 .88467 L
.28746 .88496 L
.28757 .8854 L
.28785 .88592 L
.28841 .88662 L
.28926 .88747 L
.29039 .88844 L
.2918 .88947 L
.29341 .89048 L
.29529 .89158 L
.29737 .89273 L
.29974 .89398 L
.3022 .89529 L
.30472 .89658 L
.30736 .89787 L
.30994 .89914 L
.31268 .90035 L
.31517 .90154 L
.31774 .90271 L
.32029 .90383 L
.32281 .90494 L
.32531 .90601 L
.32784 .90705 L
.33042 .90804 L
.3331 .90901 L
.33596 .90994 L
.33886 .91086 L
.34194 .91177 L
.34523 .91269 L
.34834 .91362 L
.35151 .91459 L
.35473 .91557 L
.35802 .91653 L
.36094 .91751 L
.36384 .91846 L
.36653 .91934 L
.36894 .92013 L
.37108 .92085 L
.37294 .9215 L
.37446 .92205 L
.3758 .92252 L
.37696 .92293 L
.37807 .9233 L
.3792 .92368 L
.38039 .92408 L
.3817 .92456 L
.38314 .92512 L
.38478 .92576 L
.38668 .92649 L
.38873 .92734 L
Mistroke
.39109 .92829 L
.39378 .9293 L
.39667 .93033 L
.3999 .93141 L
.40307 .9325 L
.40656 .93363 L
.40987 .93484 L
.41324 .93603 L
.41674 .93732 L
.42018 .93871 L
.4237 .94002 L
.42731 .94141 L
.43099 .94278 L
.43466 .94423 L
.43838 .94562 L
.44226 .9472 L
.44605 .9486 L
.45003 .95 L
.45392 .9514 L
.4579 .95272 L
.46171 .95392 L
.4656 .95495 L
.46921 .95577 L
.47273 .95645 L
.47602 .95706 L
.47908 .95759 L
.48205 .95802 L
.48452 .95835 L
.48682 .95856 L
.48889 .95864 L
.49072 .9586 L
.49225 .95847 L
.49364 .95826 L
.49463 .95805 L
.49546 .95787 L
.49611 .95776 L
.49663 .95768 L
.49702 .95758 L
.49732 .95746 L
.49756 .95733 L
.49774 .9572 L
.49783 .95708 L
.49786 .95698 L
.49782 .95691 L
.49772 .95689 L
.49756 .95691 L
.49738 .95695 L
.49721 .95699 L
.49701 .95704 L
.49677 .95707 L
Mistroke
.49649 .95709 L
.49618 .95711 L
.49589 .95712 L
.49556 .95714 L
.49522 .95716 L
.49492 .95717 L
.49468 .95717 L
.49446 .95716 L
.49426 .95716 L
.49414 .95717 L
.49407 .95719 L
.49404 .95722 L
.49409 .95694 L
.4942 .95699 L
.49437 .95705 L
.4946 .95711 L
.49492 .95714 L
.49528 .95717 L
.49563 .9572 L
.49592 .95723 L
.49621 .95726 L
.49647 .9573 L
.49667 .95736 L
.49685 .95743 L
.49705 .95751 L
.49727 .9576 L
.49753 .95769 L
.49785 .95777 L
.49826 .95781 L
.49878 .95781 L
.49942 .95779 L
.50019 .95774 L
.50114 .95764 L
.50227 .95748 L
.50356 .95727 L
.50499 .957 L
.50649 .95671 L
.50808 .95643 L
.50977 .95615 L
.51162 .9559 L
.51354 .95568 L
.51576 .95548 L
.51771 .9553 L
.52001 .95512 L
.52236 .95492 L
.52492 .95469 L
.52764 .95442 L
.5306 .95411 L
.53357 .95376 L
.53652 .95337 L
Mistroke
.53942 .95296 L
.54246 .95254 L
.54531 .9521 L
.54815 .95166 L
.55097 .95124 L
.55349 .95085 L
.55604 .95048 L
.55853 .95013 L
.56099 .9498 L
.56342 .94941 L
.56581 .94893 L
.56815 .94833 L
.57049 .94762 L
.57273 .94679 L
.57485 .94599 L
.57694 .94516 L
.57885 .94443 L
.58069 .94384 L
.58239 .94333 L
.58379 .9429 L
.585 .94259 L
.58601 .94238 L
.58691 .9423 L
.58778 .9424 L
.58875 .94264 L
.58997 .94298 L
.59125 .94338 L
.5929 .94373 L
.59481 .944 L
.59699 .94412 L
.59953 .94406 L
.60224 .94384 L
.60523 .94355 L
.6085 .9431 L
.6117 .94257 L
.61547 .94217 L
.61888 .94158 L
.62233 .94096 L
.62572 .94031 L
.62892 .93959 L
.632 .93888 L
.63499 .93809 L
.63788 .93723 L
.64072 .93637 L
.6435 .93552 L
.64613 .93471 L
.64861 .93394 L
.65087 .93326 L
.6529 .93258 L
.65471 .93192 L
Mistroke
.65628 .93133 L
.65771 .93085 L
.65901 .93044 L
.66023 .93008 L
.66136 .92971 L
.66243 .92936 L
.66337 .9291 L
.66414 .92896 L
.66482 .92884 L
.66539 .92879 L
.66588 .92875 L
.66633 .92864 L
.66673 .9285 L
.66705 .92835 L
.66721 .92827 L
.66717 .9283 L
.66694 .92839 L
.66656 .92861 L
.66605 .92894 L
.66549 .92931 L
.66498 .92961 L
.66455 .92992 L
.66422 .93023 L
.66395 .93055 L
.6637 .93082 L
.6635 .93109 L
.66328 .93135 L
.66306 .93156 L
.66289 .93168 L
.66283 .93166 L
.6628 .93158 L
.66289 .93126 L
.66308 .93076 L
.66333 .93014 L
.66353 .92959 L
.66368 .92905 L
.66377 .9285 L
.6639 .9279 L
.66401 .92746 L
.66419 .927 L
.66439 .92662 L
.6646 .9264 L
.66474 .92637 L
.66483 .92646 L
.66487 .92666 L
.66481 .92689 L
.66468 .92726 L
.66455 .92759 L
.66447 .92783 L
.66453 .92801 L
Mistroke
.6647 .92813 L
.66497 .92818 L
.66539 .92805 L
.66584 .92791 L
.66622 .92777 L
.66652 .9276 L
.66673 .92736 L
.66683 .92726 L
.66676 .92732 L
.66654 .92754 L
.66617 .92785 L
.66566 .92832 L
.6651 .92887 L
.66456 .92936 L
.66415 .92965 L
.66385 .9298 L
.6636 .92989 L
.66342 .92993 L
.66342 .92988 L
.66354 .92979 L
.66373 .92972 L
.66403 .92959 L
.66437 .92943 L
.66469 .9293 L
.66492 .92927 L
.66504 .92929 L
.66501 .92943 L
.66488 .92966 L
.66473 .92992 L
.66454 .9302 L
.66439 .93043 L
.66428 .93054 L
.66423 .93057 L
.66433 .93038 L
.66454 .93007 L
.66484 .92969 L
.6651 .92937 L
.66539 .92903 L
.66568 .92873 L
.66601 .92845 L
.66626 .92828 L
.66651 .92813 L
.66671 .92805 L
.66688 .92804 L
.66705 .92813 L
.66726 .92824 L
.66753 .92832 L
.66783 .92839 L
.66805 .92852 L
.66816 .9287 L
Mistroke
.66817 .92891 L
.66806 .92915 L
.66788 .9294 L
.66769 .92959 L
.66753 .92967 L
.66742 .92967 L
.66734 .9296 L
.66725 .92949 L
.6672 .9293 L
.66717 .92911 L
.66712 .92896 L
.66709 .92884 L
.66712 .9287 L
.66728 .92854 L
.66758 .92835 L
.66794 .92818 L
.66835 .92801 L
.66873 .92789 L
.66901 .92786 L
.66914 .92793 L
.66915 .92809 L
.66908 .92831 L
.66893 .92856 L
.66877 .92879 L
.66862 .92896 L
.66843 .92894 L
.66826 .92904 L
.66808 .92912 L
.66796 .92915 L
.66791 .92909 L
.66791 .92902 L
.66799 .92886 L
.66813 .92863 L
.66832 .92836 L
.66844 .92817 L
.66857 .92796 L
.66867 .92778 L
.66872 .92767 L
.66866 .92768 L
.66854 .92772 L
.66839 .92778 L
.66818 .9279 L
.66787 .92814 L
.66754 .92844 L
.66728 .92875 L
.66706 .92909 L
.66685 .92951 L
.66668 .92996 L
.66658 .93036 L
.66649 .9308 L
Mistroke
.66644 .93125 L
.66645 .93172 L
.66649 .93216 L
.66653 .93255 L
.66653 .93288 L
.66654 .93311 L
.66663 .93319 L
.66681 .93314 L
.66708 .93298 L
.66752 .93262 L
.66807 .93209 L
.66867 .9315 L
.66922 .93096 L
.66975 .93036 L
.67022 .92982 L
.6706 .92938 L
.67093 .92904 L
.6712 .92878 L
.6714 .92862 L
.67152 .9286 L
.6716 .92866 L
.67169 .92872 L
.67175 .92876 L
.67177 .9288 L
.67177 .92882 L
.67186 .92874 L
.67204 .9286 L
.67236 .92842 L
.67279 .92822 L
.67335 .928 L
.67396 .92775 L
.6746 .9275 L
.67523 .92724 L
.67583 .92697 L
.67639 .92669 L
.67692 .92646 L
.67738 .92631 L
.6777 .92629 L
.67781 .92638 L
.67773 .92658 L
.67749 .92685 L
.67717 .92714 L
.67683 .92737 L
.67654 .92748 L
.67622 .92755 L
.67582 .92768 L
.67531 .92795 L
.67475 .92833 L
.67412 .92881 L
.67337 .92953 L
Mistroke
.67256 .93014 L
.67183 .93067 L
.67132 .93105 L
.67101 .93127 L
.67085 .93135 L
.67077 .93134 L
.67068 .93129 L
.67042 .93134 L
.67028 .93128 L
.67019 .93116 L
.67028 .9309 L
.67068 .93046 L
.6713 .92993 L
.67203 .92938 L
.67275 .92886 L
.67339 .92841 L
.67376 .92814 L
.67377 .9281 L
.67352 .92818 L
.67302 .92828 L
.67239 .92838 L
.67165 .92848 L
.67096 .92854 L
.67039 .92851 L
.67 .92835 L
.66974 .92814 L
.6695 .92796 L
.66925 .92787 L
.66905 .92789 L
.66892 .92803 L
.66892 .92826 L
.66906 .92851 L
.6693 .92875 L
.66958 .92896 L
.66977 .92914 L
.66983 .92934 L
.66969 .92957 L
.66945 .92981 L
.66913 .93007 L
.66882 .93028 L
.66857 .93036 L
.66848 .93033 L
.66846 .93022 L
.66851 .9301 L
.66862 .92996 L
.66873 .92988 L
.66882 .92984 L
.66888 .92979 L
.66892 .92978 L
.66901 .92977 L
Mistroke
.66923 .92974 L
.66955 .92969 L
.67 .9296 L
.67042 .92955 L
.67075 .92959 L
.67098 .92968 L
.67111 .92986 L
.67118 .93006 L
.67126 .93021 L
.67138 .9302 L
.67155 .93009 L
.67166 .92992 L
.67164 .92972 L
.6714 .92959 L
.67096 .92947 L
.67039 .92931 L
.66984 .92917 L
.66942 .92889 L
.66933 .92828 L
.66929 .92797 L
.66941 .92772 L
.66968 .92755 L
.67009 .92747 L
.67046 .92749 L
.67081 .92759 L
.67109 .9277 L
.67129 .92782 L
.67141 .92796 L
.67142 .92816 L
.67131 .92844 L
.67105 .92878 L
.67064 .92918 L
.67005 .92965 L
.66935 .93013 L
.66849 .93059 L
.66774 .9309 L
.66699 .93117 L
.66629 .93139 L
.66575 .93154 L
.66534 .93166 L
.66509 .93175 L
.66503 .93171 L
.66511 .93158 L
.66538 .93133 L
.66581 .93099 L
.66638 .93055 L
.66706 .93 L
.66779 .92949 L
.66849 .9291 L
.66923 .92875 L
Mistroke
.66996 .92849 L
.67064 .92835 L
.67127 .92826 L
.67184 .92815 L
.67235 .92807 L
.67271 .92803 L
.67292 .92805 L
.67293 .92813 L
.67279 .92831 L
.67253 .92853 L
.67226 .92872 L
.67209 .92881 L
.67211 .92877 L
.67237 .9286 L
.67275 .9284 L
.67328 .92812 L
.67391 .92782 L
.67474 .92747 L
.67549 .92717 L
.67639 .92683 L
.67727 .92651 L
.67808 .92624 L
.67875 .92602 L
.6793 .92582 L
.6797 .92564 L
.67989 .92555 L
.67981 .9256 L
.67949 .92577 L
.67899 .926 L
.67839 .9263 L
.67769 .92662 L
.67699 .92694 L
.67639 .92722 L
.67602 .92741 L
.67587 .92755 L
.67595 .92763 L
.67628 .92763 L
.67678 .92763 L
.67737 .92761 L
.67823 .92748 L
.67948 .927 L
.68073 .92674 L
.68214 .92637 L
.68367 .92588 L
.6853 .92528 L
.68699 .92458 L
.68874 .92381 L
.6905 .92296 L
.69223 .92203 L
.69383 .92103 L
Mistroke
.69539 .91994 L
.69685 .91885 L
.69819 .91768 L
.69936 .91657 L
.70031 .91561 L
.70105 .91478 L
.70157 .9141 L
.70184 .91363 L
.70187 .91338 L
.70168 .91335 L
.70129 .9135 L
.70074 .9138 L
.70013 .9142 L
.69948 .91474 L
.69881 .91541 L
.69828 .91598 L
.69783 .91657 L
.69755 .91697 L
.69749 .91711 L
.69765 .91703 L
.69792 .91677 L
.6982 .91642 L
.69849 .91605 L
.69875 .91568 L
.69901 .91535 L
.69923 .91507 L
.69941 .91478 L
.69957 .91454 L
.6997 .91438 L
.69981 .91431 L
.69989 .91434 L
.69989 .91451 L
.69981 .91479 L
.6997 .91518 L
.69964 .91559 L
.6997 .91595 L
.69989 .9162 L
.70016 .91635 L
.70046 .91637 L
.70075 .91638 L
.701 .91645 L
.70114 .91662 L
.70125 .91683 L
.70137 .91703 L
.7016 .91715 L
.70201 .91713 L
.70263 .91693 L
.70349 .91656 L
.70432 .91615 L
.70529 .91565 L
Mistroke
.70626 .91509 L
.70714 .9145 L
.70807 .91392 L
.7089 .91333 L
.70963 .91273 L
.71021 .91217 L
.71057 .91172 L
.71072 .91137 L
.71062 .91117 L
.71022 .91115 L
.70955 .91133 L
.70873 .91163 L
.70793 .91195 L
.70715 .91224 L
.70667 .91237 L
.70605 .91262 L
.70545 .91284 L
.7049 .91311 L
.70438 .91344 L
.7039 .91388 L
.70343 .9144 L
.70294 .91495 L
.70245 .91547 L
.70199 .9159 L
.70152 .91628 L
.70115 .91653 L
.70077 .91675 L
.70044 .91687 L
.70017 .91693 L
.7 .91695 L
.69991 .91696 L
.69985 .91697 L
.69981 .91694 L
.69979 .91693 L
.69975 .91692 L
.69968 .91692 L
.69952 .91703 L
.69928 .9173 L
.69898 .91767 L
.69863 .91805 L
.69824 .9184 L
.69779 .9187 L
.69727 .91893 L
.69669 .91908 L
.69608 .91913 L
.69547 .91911 L
.69493 .9191 L
.69437 .91914 L
.69386 .91926 L
.69344 .91945 L
Mistroke
.69306 .91971 L
.69272 .92004 L
.6924 .92042 L
.69217 .92084 L
.69199 .92128 L
.69184 .92174 L
.69168 .92218 L
.6915 .92263 L
.69128 .92305 L
.69102 .92343 L
.69073 .92374 L
.69045 .92399 L
.6902 .92416 L
.69 .92426 L
.68983 .9243 L
.68975 .92429 L
.68969 .92425 L
.68968 .92419 L
.68969 .92414 L
.68973 .92413 L
.68977 .92417 L
.6898 .92424 L
.68981 .9243 L
.68982 .92432 L
.68984 .92426 L
.68983 .92412 L
.68981 .92391 L
.68977 .92368 L
.68966 .92345 L
.68952 .92323 L
.68939 .92298 L
.68932 .92269 L
.68933 .92235 L
.68941 .922 L
.68952 .92166 L
.68962 .92138 L
.68969 .92118 L
.6897 .92111 L
.68965 .92118 L
.68957 .92141 L
.68947 .92174 L
.68936 .92212 L
.68928 .92245 L
.68925 .92268 L
.68929 .92282 L
.68925 .9229 L
.68917 .92297 L
.68904 .92306 L
.68887 .92318 L
.68867 .92332 L
Mistroke
.6885 .92344 L
.68842 .9235 L
.68842 .92349 L
.68848 .92345 L
.68855 .92342 L
.68857 .9235 L
.68857 .92365 L
.68856 .92382 L
.68857 .92398 L
.6886 .9241 L
.68865 .92414 L
.68869 .92412 L
.68869 .92403 L
.68869 .92387 L
.68867 .92368 L
.68861 .92352 L
.6885 .92345 L
.68837 .92349 L
.68826 .9236 L
.6882 .92374 L
.68816 .92391 L
.68816 .92408 L
.68818 .92422 L
.6882 .92429 L
.68819 .92427 L
.68812 .92415 L
.68794 .92392 L
.68766 .92367 L
.68729 .92334 L
.68688 .92293 L
.68647 .92248 L
.686 .92202 L
.68549 .9216 L
.68504 .92123 L
.68471 .9209 L
.68447 .9206 L
.68432 .92035 L
.68421 .92018 L
.68409 .92015 L
.6839 .92025 L
.68365 .92041 L
.68333 .92061 L
.68297 .9208 L
.68254 .92094 L
.68208 .92105 L
.68167 .92113 L
.68137 .92121 L
.68111 .92127 L
.68093 .92131 L
.68082 .92136 L
Mistroke
.68077 .92143 L
.68083 .92147 L
.68097 .92148 L
.68112 .92154 L
.68117 .92172 L
.68111 .92201 L
.68089 .9224 L
.68053 .92282 L
.68006 .92326 L
.67951 .92371 L
.6788 .92415 L
.67825 .92447 L
.67769 .9247 L
.67714 .92487 L
.67657 .92495 L
.67609 .92495 L
.67568 .92492 L
.67529 .92481 L
.67508 .925 L
.67486 .92477 L
.67472 .92445 L
.67457 .92413 L
.67424 .92378 L
.67385 .9235 L
.67345 .9233 L
.673 .9231 L
.6726 .92296 L
.67228 .92282 L
.67219 .92279 L
.6723 .92281 L
.67263 .9229 L
.67316 .92306 L
.67378 .92327 L
.67442 .92347 L
.67507 .92364 L
.67573 .92376 L
.67647 .92382 L
.67725 .9238 L
.67801 .92376 L
.67874 .92371 L
.67939 .92359 L
.67994 .92335 L
.68042 .923 L
.68085 .92257 L
.68123 .92214 L
.68159 .92174 L
.68201 .92141 L
.68257 .9212 L
.68329 .92111 L
.68412 .9211 L
Mistroke
.685 .92111 L
.68605 .92109 L
.68725 .92099 L
.68858 .92079 L
.69002 .92048 L
.69155 .92011 L
.69314 .91965 L
.69478 .91913 L
.69643 .91857 L
.6981 .91796 L
.69978 .9173 L
.70131 .91655 L
.70295 .91571 L
.7046 .91478 L
.70632 .91376 L
.70808 .91264 L
.70986 .91139 L
.71169 .91001 L
.71354 .90846 L
.71543 .90676 L
.71734 .90495 L
.71925 .90304 L
.72116 .90107 L
.72306 .89907 L
.72495 .89708 L
.72701 .89483 L
.72863 .89312 L
.73023 .89129 L
.73162 .8897 L
.73279 .88837 L
.73372 .88735 L
.73445 .88665 L
.73497 .88623 L
.73531 .88604 L
.73549 .886 L
.73553 .88607 L
.73546 .88621 L
.73529 .88636 L
.73504 .88648 L
.73476 .88649 L
.73446 .88637 L
.73416 .88613 L
.73387 .88577 L
.73361 .88528 L
.73337 .88466 L
.73314 .88396 L
.7329 .88329 L
.73264 .88273 L
.73233 .88229 L
.73199 .88203 L
Mistroke
.73165 .88198 L
.73133 .88218 L
.73107 .88258 L
.73085 .88297 L
.73068 .88372 L
.73051 .88454 L
.73031 .88562 L
.73004 .88664 L
.72968 .88766 L
.72918 .8889 L
.72858 .88999 L
.72784 .89114 L
.72695 .89233 L
.72595 .89339 L
.7248 .89446 L
.72351 .89546 L
.72217 .89638 L
.7207 .89724 L
.71923 .89812 L
.7177 .899 L
.71623 .89988 L
.7148 .90081 L
.7134 .90183 L
.712 .90299 L
.71054 .90425 L
.70904 .90559 L
.70746 .90701 L
.70576 .9084 L
.70409 .90992 L
.70227 .91151 L
.70031 .91318 L
.6983 .91485 L
.69629 .9164 L
.69428 .91783 L
.69233 .91909 L
.69057 .92016 L
.68891 .92103 L
.68744 .92167 L
.68617 .92211 L
.6852 .92246 L
.68429 .92279 L
.68349 .92309 L
.68273 .92337 L
.68188 .9237 L
.68094 .92412 L
.6799 .92461 L
.67861 .92511 L
.67699 .92569 L
.67503 .92638 L
.67287 .92716 L
Mistroke
.67003 .92809 L
.66724 .92904 L
.66382 .93008 L
.66035 .9311 L
.65648 .93206 L
.65293 .93302 L
.64917 .93398 L
.64562 .93488 L
.64185 .9357 L
.63851 .93646 L
.63502 .93719 L
.63173 .93781 L
.62875 .93837 L
.62562 .93879 L
.6226 .93907 L
.61962 .9392 L
.61662 .9393 L
.61382 .9394 L
.61082 .93951 L
.60801 .9396 L
.60495 .93973 L
.60183 .93994 L
.59832 .94029 L
.59498 .94071 L
.59136 .94121 L
.5873 .94178 L
.58378 .9424 L
.57982 .94316 L
.57616 .94401 L
.57227 .94491 L
.56869 .94574 L
.56503 .94647 L
.56138 .94709 L
.55806 .94756 L
.5548 .94794 L
.55168 .94821 L
.54882 .94843 L
.54619 .94866 L
.54389 .94896 L
.54204 .94934 L
.54018 .94977 L
.53864 .95022 L
.5372 .95066 L
.53592 .95108 L
.53485 .95144 L
.53399 .95174 L
.53334 .95193 L
.53288 .95199 L
.53258 .95194 L
.53243 .95179 L
Mistroke
.53238 .95156 L
.53233 .95123 L
.53223 .95078 L
.53209 .95027 L
.53189 .94972 L
.53164 .94921 L
.53136 .94881 L
.53107 .94858 L
.53078 .94851 L
.53048 .9486 L
.53019 .9488 L
.52988 .94906 L
.52959 .94933 L
.52927 .94957 L
.52896 .94976 L
.52868 .94992 L
.5284 .95006 L
.5281 .95017 L
.5278 .95022 L
.52748 .95022 L
.52707 .95018 L
.52653 .9501 L
.52584 .94997 L
.52508 .94978 L
.52415 .94956 L
.52309 .94929 L
.52197 .949 L
.52081 .94867 L
.51969 .94833 L
.51862 .94798 L
.5176 .9476 L
.51678 .94728 L
.51602 .94696 L
.5154 .94662 L
.51497 .94629 L
.51477 .94603 L
.51481 .94588 L
.51505 .94584 L
.51544 .94587 L
.51593 .94597 L
.51644 .94611 L
.51687 .94628 L
.51716 .94643 L
.51732 .94649 L
.51735 .94653 L
.51731 .9466 L
.5172 .94671 L
.51705 .94684 L
.51687 .94698 L
.51663 .94714 L
Mistroke
.51639 .94727 L
.51622 .94738 L
.51616 .94745 L
.51622 .9475 L
.51641 .94749 L
.51674 .94745 L
.51717 .94738 L
.51756 .94736 L
.51799 .94731 L
.51837 .94711 L
.51866 .94691 L
.5188 .9466 L
.51883 .94627 L
.51881 .94599 L
.51882 .94578 L
.5188 .94568 L
.51879 .9457 L
.5188 .94584 L
.51881 .94602 L
.51876 .94624 L
.51866 .94646 L
.51856 .94666 L
.51852 .94691 L
.51851 .94717 L
.51853 .94746 L
.51857 .94779 L
.51858 .94811 L
.51852 .94835 L
.51835 .94845 L
.51812 .94846 L
.51794 .94841 L
.51785 .94834 L
.51787 .94825 L
.51803 .94816 L
.51834 .94816 L
.51875 .94823 L
.51915 .9483 L
.51947 .94843 L
.5195 .94864 L
.51916 .94891 L
.51845 .94924 L
.51746 .9497 L
.51614 .95025 L
.51463 .95088 L
.51283 .95142 L
.51087 .95197 L
.50887 .95253 L
.5066 .95307 L
.50401 .95347 L
.50167 .95382 L
Mistroke
.49941 .95414 L
.49727 .95444 L
.49542 .95477 L
.49393 .95512 L
.49283 .95552 L
.49195 .95585 L
.49122 .95613 L
.49058 .9563 L
.48999 .95636 L
.48935 .95627 L
.48866 .95605 L
.48786 .9557 L
.4871 .95524 L
.48623 .95468 L
.48531 .95404 L
.48429 .95335 L
.4832 .95265 L
.48196 .95197 L
.48059 .9513 L
.47909 .95059 L
.47763 .95002 L
.47612 .94944 L
.4747 .94898 L
.47341 .94868 L
.47228 .94855 L
.47124 .94854 L
.47026 .94858 L
.46921 .94858 L
.4681 .94849 L
.46684 .94834 L
.4653 .94811 L
.4638 .94785 L
.46204 .94752 L
.46 .94716 L
.45775 .94665 L
.45551 .94606 L
.45309 .94537 L
.4504 .94456 L
.44718 .94375 L
.44429 .94285 L
.44094 .94183 L
.43764 .94089 L
.43409 .9399 L
.43032 .93892 L
.42696 .93792 L
.42318 .93695 L
.41958 .93589 L
.41565 .93473 L
.41166 .93346 L
.40807 .93217 L
Mistroke
.40424 .93079 L
.40048 .92935 L
.3966 .92794 L
.39317 .92652 L
.38959 .92509 L
.38605 .92371 L
.38261 .92232 L
.37922 .92096 L
.37568 .91959 L
.37225 .91824 L
.369 .91692 L
.36555 .91561 L
.36215 .91435 L
.35852 .91314 L
.35526 .91199 L
.35182 .91089 L
.34828 .90983 L
.34509 .90884 L
.34198 .90787 L
.33875 .90691 L
.33564 .90592 L
.33245 .90493 L
.32939 .9039 L
.32623 .90279 L
.3231 .9016 L
.32033 .90033 L
.31736 .89898 L
.31456 .89767 L
.31171 .8963 L
.309 .89493 L
.30642 .89361 L
.3038 .89229 L
.30137 .891 L
.29893 .88971 L
.29674 .88844 L
.29463 .88724 L
.2927 .88608 L
.291 .88497 L
.28952 .88393 L
.2883 .88301 L
.28732 .88212 L
.28655 .88133 L
.28603 .88063 L
.28571 .88009 L
.28554 .87964 L
.28545 .87924 L
.28538 .87892 L
.28523 .8786 L
.28494 .87829 L
.28444 .87794 L
Mistroke
.28373 .87754 L
.28272 .8769 L
.28136 .87598 L
.27961 .87476 L
.27754 .87328 L
.27518 .87151 L
.27245 .86936 L
.26949 .86703 L
.26635 .86449 L
.26302 .86169 L
.25979 .85896 L
.25647 .85605 L
.25327 .85309 L
.25013 .85047 L
.24705 .84766 L
.24416 .84487 L
.24132 .84214 L
.2386 .83941 L
.23595 .83685 L
.23337 .83426 L
.23083 .83177 L
.22832 .82924 L
.22576 .82661 L
.22326 .82402 L
.22082 .82153 L
.21847 .81896 L
.21625 .81645 L
.21412 .81414 L
.21223 .8119 L
.21039 .8098 L
.20895 .80795 L
.2077 .80622 L
.20663 .80462 L
.20578 .80326 L
.20506 .80201 L
.20442 .80087 L
.20377 .7998 L
.20301 .79877 L
.2021 .7977 L
.20095 .79654 L
.19959 .79524 L
.19789 .79372 L
.19584 .79194 L
.19392 .79006 L
.19165 .78791 L
.18904 .78569 L
.18679 .78341 L
.18426 .78097 L
.18159 .77841 L
.17929 .77607 L
Mistroke
.17677 .77355 L
.17418 .77092 L
.17198 .76831 L
.1697 .76576 L
.16739 .76317 L
.16546 .76086 L
.16345 .75853 L
.16144 .75626 L
.15956 .75404 L
.15769 .75189 L
.15589 .74975 L
.1543 .74793 L
.15277 .74623 L
.15137 .74468 L
.15014 .7433 L
.1492 .74216 L
.14832 .74114 L
.14759 .74022 L
.14692 .73925 L
.14628 .73817 L
.14566 .73698 L
.14506 .73567 L
.14448 .73423 L
.14395 .73281 L
.14352 .73127 L
.14314 .72977 L
.14283 .72839 L
.14254 .72711 L
.14225 .72575 L
.14197 .72451 L
.1417 .7233 L
.14143 .72211 L
.14114 .72091 L
.14081 .71965 L
.14044 .71829 L
.14001 .71672 L
.13949 .71488 L
.13889 .71278 L
.13824 .71076 L
.13752 .70834 L
.13674 .70571 L
.13593 .70285 L
.13516 .69979 L
.13444 .69682 L
.1338 .69392 L
.13328 .69093 L
.1329 .68823 L
.13264 .68577 L
.13247 .68338 L
.13234 .68113 L
Mistroke
.13221 .67903 L
.13206 .67704 L
.13186 .67507 L
.13164 .67322 L
.13138 .67135 L
.13109 .66948 L
.13076 .66755 L
.13041 .66566 L
.12998 .66355 L
.12946 .6613 L
.12889 .65871 L
.12824 .65611 L
.12751 .65312 L
.12672 .64992 L
.12592 .64655 L
.12512 .64315 L
.12437 .63931 L
.12371 .63589 L
.12312 .6323 L
.12257 .62862 L
.12209 .62557 L
.12165 .62254 L
.12127 .61981 L
.12096 .6175 L
.12069 .61548 L
.12049 .61397 L
.12034 .61283 L
.12025 .61202 L
.12021 .61148 L
.12025 .6112 L
.12028 .61109 L
.12033 .61111 L
.12036 .61122 L
.1204 .61133 L
.12042 .61141 L
.12045 .61141 L
.1205 .61127 L
.12055 .61094 L
.1206 .61043 L
.12062 .60971 L
.12056 .60875 L
.12044 .60761 L
.12022 .60612 L
.11988 .60433 L
.11956 .60216 L
.11915 .59972 L
.1187 .59682 L
.11825 .59383 L
.11778 .59039 L
.1173 .5868 L
Mistroke
.11681 .58296 L
.11629 .57889 L
.11575 .57477 L
.11518 .57093 L
.1146 .56692 L
.11405 .56308 L
.11353 .55986 L
.11305 .55691 L
.11262 .55441 L
.11225 .55226 L
.11194 .55073 L
.1117 .54958 L
.11154 .54879 L
.11144 .54829 L
.1114 .54801 L
.11139 .54783 L
.1114 .54755 L
.11139 .54712 L
.11132 .54649 L
.1112 .54572 L
.11101 .54457 L
.11074 .54306 L
.11039 .541 L
.11 .53854 L
.1096 .53592 L
.1092 .53285 L
.10884 .52987 L
.10855 .52614 L
.10832 .52299 L
.10818 .51961 L
.10813 .51597 L
.10818 .51228 L
.10833 .50824 L
.1086 .50461 L
.10897 .50082 L
.10941 .4971 L
.1099 .49355 L
.11047 .49029 L
.11099 .4872 L
.11153 .4846 L
.11203 .48226 L
.11247 .48029 L
.11284 .4788 L
.11317 .47765 L
.11345 .47686 L
.11369 .47638 L
.1139 .47616 L
.11406 .47611 L
Mfstroke
.11112 .48792 m
.11097 .48807 L
.11077 .48845 L
.11052 .48915 L
.11024 .49025 L
.10992 .4918 L
.10958 .49372 L
.10921 .49599 L
.10882 .49884 L
.10843 .50224 L
.10805 .50521 L
.10773 .50915 L
.10749 .51286 L
.10734 .51701 L
.1073 .52115 L
.10736 .52528 L
.10751 .52904 L
.10775 .53293 L
.10808 .53668 L
.10845 .54006 L
.10891 .54332 L
.10943 .5465 L
.11003 .54964 L
.11065 .55255 L
.1113 .5557 L
.11198 .55861 L
.11261 .56185 L
.11324 .56502 L
.11385 .56865 L
.11444 .5721 L
.11499 .57541 L
.11551 .57948 L
.116 .58315 L
.11644 .58769 L
.11686 .59136 L
.11726 .59586 L
.11767 .60026 L
.11809 .60433 L
.11853 .60865 L
.11902 .61299 L
.11957 .61739 L
.12019 .6218 L
.12087 .62616 L
.1215 .6305 L
.12222 .63495 L
.12291 .63966 L
.12361 .64386 L
.12431 .64868 L
.12495 .65256 L
.12557 .65714 L
Mistroke
.12617 .66105 L
.12669 .66499 L
.12716 .66836 L
.12756 .67145 L
.12789 .67446 L
.12818 .67706 L
.12844 .67942 L
.12868 .68151 L
.12893 .68316 L
.12919 .68463 L
.12946 .68587 L
.12976 .68689 L
.13007 .68775 L
.13036 .68838 L
.13065 .68899 L
.1309 .68948 L
.1311 .68983 L
.13129 .69 L
.13145 .69 L
.13161 .68987 L
.13176 .68968 L
.13187 .68949 L
.13193 .68932 L
.13195 .68924 L
.13193 .68931 L
.13188 .68957 L
.13182 .69004 L
.13177 .69073 L
.13175 .69161 L
.13179 .69272 L
.13188 .69404 L
.13205 .69562 L
.13233 .69756 L
.13274 .6999 L
.13326 .70256 L
.13387 .70531 L
.13456 .7084 L
.13534 .71163 L
.13614 .71479 L
.13695 .7181 L
.13775 .7209 L
.13846 .72365 L
.13915 .72632 L
.13971 .72839 L
.14025 .73028 L
.14061 .7319 L
.14093 .73318 L
.14114 .73405 L
.14126 .73455 L
.14128 .73476 L
Mistroke
.14125 .73477 L
.1412 .73463 L
.14114 .73441 L
.14109 .73425 L
.14106 .73418 L
.14107 .73425 L
.14109 .73448 L
.14111 .73472 L
.14111 .73494 L
.14106 .73511 L
.14098 .73518 L
.14088 .73518 L
.14076 .73512 L
.14065 .73504 L
.14055 .735 L
.14047 .735 L
.14041 .73507 L
.14038 .73519 L
.14036 .73535 L
.14036 .73555 L
.14038 .73579 L
.14042 .73606 L
.14049 .73635 L
.14059 .7367 L
.1407 .73707 L
.14082 .73746 L
.14093 .73786 L
.14101 .73821 L
.14106 .73844 L
.14107 .73854 L
.14105 .73854 L
.14102 .7385 L
.14099 .73842 L
.14098 .73831 L
.14098 .73816 L
.14098 .73799 L
.14099 .7378 L
.14099 .73759 L
.14099 .73738 L
.141 .73719 L
.141 .73704 L
.141 .73693 L
.141 .73688 L
.141 .73687 L
.141 .73689 L
.141 .73696 L
.141 .73706 L
.14099 .73725 L
.14099 .73747 L
.14098 .73772 L
Mistroke
.14098 .73797 L
.14098 .7382 L
.14097 .7384 L
.14095 .73856 L
.14091 .73865 L
.14084 .73862 L
.14073 .73846 L
.1406 .73821 L
.1405 .73795 L
.14044 .73775 L
.14045 .73765 L
.14058 .7377 L
.1409 .73798 L
.14142 .73853 L
.14216 .73939 L
.14315 .74057 L
.1443 .74208 L
.14578 .74389 L
.14733 .74574 L
.1492 .74801 L
.15117 .75042 L
.15333 .75305 L
.15577 .75575 L
.15812 .75857 L
.16044 .76115 L
.1628 .76382 L
.16513 .76641 L
.16746 .76885 L
.16983 .77136 L
.17218 .77375 L
.17474 .77628 L
.17718 .77879 L
.17985 .78148 L
.18255 .78409 L
.18529 .78695 L
.18803 .78965 L
.19088 .7926 L
.19374 .79551 L
.19671 .79857 L
.19945 .80146 L
.20231 .80458 L
.20523 .80752 L
.20808 .81055 L
.21099 .81352 L
.21401 .8167 L
.21685 .8196 L
.22001 .82281 L
.22311 .82622 L
.22638 .82944 L
.22979 .83295 L
Mistroke
.23353 .83675 L
.23701 .84011 L
.24059 .84371 L
.24434 .84754 L
.24793 .85098 L
.25163 .85454 L
.25513 .85851 L
.25866 .86173 L
.26196 .86509 L
.2651 .86845 L
.26806 .87146 L
.27086 .87438 L
.27327 .87674 L
.27553 .8789 L
.27739 .88058 L
.27904 .88196 L
.2804 .88303 L
.2815 .88381 L
.28235 .8843 L
.28296 .88453 L
.28337 .88453 L
.28361 .88433 L
.28372 .88398 L
.28372 .88355 L
.28366 .88311 L
.28356 .88274 L
.28347 .88246 L
.28339 .88228 L
.28331 .88218 L
.28326 .88214 L
.28324 .88218 L
.28324 .88225 L
.28324 .8823 L
.28321 .88232 L
.28317 .8823 L
.28312 .88228 L
.28307 .88225 L
.28302 .88223 L
.283 .8822 L
.28301 .8822 L
.28309 .88224 L
.28327 .88233 L
.28355 .8825 L
.28393 .88274 L
.28444 .88306 L
.28506 .88343 L
.28573 .88383 L
.28641 .88423 L
.28711 .88463 L
.28778 .88501 L
Mistroke
.28844 .88538 L
.28902 .88571 L
.28954 .886 L
.28996 .88624 L
.2903 .88642 L
.29054 .88654 L
.2907 .88661 L
.29077 .88662 L
.29076 .88661 L
.29072 .88659 L
.29066 .88656 L
.29062 .88655 L
.29059 .88657 L
.2906 .88661 L
.29062 .88665 L
.29062 .88669 L
.29061 .88674 L
.29059 .8868 L
.29056 .88686 L
.29052 .88692 L
.29051 .88696 L
.29052 .88694 L
.29055 .88684 L
.29061 .88666 L
.29067 .8864 L
.29074 .88607 L
.29081 .88566 L
.29088 .88521 L
.29095 .88472 L
.29099 .88421 L
.29102 .88373 L
.29106 .88324 L
.29111 .88269 L
.29119 .8823 L
.29128 .88193 L
.29137 .88166 L
.29141 .88152 L
.29139 .88149 L
.29132 .88156 L
.29112 .88172 L
.29098 .88188 L
.29084 .88209 L
.29069 .88236 L
.29054 .88268 L
.29044 .88311 L
.29039 .88362 L
.29044 .88423 L
.29063 .88493 L
.29098 .88572 L
.2916 .88664 L
Mistroke
.2925 .88771 L
.29377 .8889 L
.29545 .89023 L
.29762 .89172 L
.30016 .89334 L
.30313 .89508 L
.30647 .89684 L
.31018 .89867 L
.31415 .90049 L
.3183 .90232 L
.32293 .90415 L
.32755 .90601 L
.33242 .90783 L
.33757 .90968 L
.34248 .91149 L
.34761 .91334 L
.35265 .91515 L
.35772 .91694 L
.36256 .91876 L
.36701 .92056 L
.37132 .92233 L
.37513 .924 L
.37863 .92557 L
.3821 .9269 L
.38494 .92812 L
.38745 .92911 L
.38982 .92996 L
.39206 .93069 L
.39418 .93133 L
.3962 .93189 L
.39801 .93238 L
.39991 .93286 L
.40197 .93335 L
.40409 .93385 L
.40625 .93438 L
.40844 .93495 L
.41066 .93558 L
.41278 .93626 L
.41462 .93697 L
.41622 .93757 L
.41755 .93816 L
.41861 .93867 L
.41947 .93907 L
.42004 .93937 L
.42043 .93954 L
.42061 .93957 L
.42062 .9395 L
.42055 .93938 L
.42044 .93923 L
.42029 .93901 L
Mistroke
.42022 .93876 L
.42028 .93852 L
.42047 .93829 L
.42072 .93803 L
.42105 .93774 L
.42144 .93743 L
.42183 .93706 L
.42221 .93673 L
.42257 .93637 L
.42291 .93603 L
.42321 .93567 L
.42341 .93536 L
.42351 .93508 L
.42351 .93495 L
.42333 .93473 L
.423 .93452 L
.42254 .93431 L
.42208 .9342 L
.4216 .93422 L
.42114 .93433 L
.42072 .93454 L
.42039 .93485 L
.42008 .93511 L
.41982 .93539 L
.41959 .93564 L
.41938 .93582 L
.41916 .93592 L
.4189 .93598 L
.41866 .93606 L
.41849 .93616 L
.41841 .93628 L
.41843 .9364 L
.41864 .93658 L
.41911 .93688 L
.41987 .93734 L
.42099 .93797 L
.4225 .93879 L
.42451 .93978 L
.42707 .94094 L
.42978 .94224 L
.4332 .94367 L
.43697 .9452 L
.44126 .94671 L
.44596 .94831 L
.45038 .94982 L
.45502 .95128 L
.4599 .95266 L
.46419 .95389 L
.4685 .95498 L
.47224 .95592 L
Mistroke
.47574 .9567 L
.47903 .95732 L
.48148 .9578 L
.48363 .95817 L
.4855 .95844 L
.48705 .95863 L
.48831 .95875 L
.48942 .95878 L
.49028 .95872 L
.49104 .95858 L
.49178 .95842 L
.49251 .95824 L
.49319 .95808 L
.49385 .95793 L
.49449 .95779 L
.49514 .95764 L
.49575 .9575 L
.49634 .95735 L
.49692 .95725 L
.49752 .95719 L
.49818 .95717 L
.49895 .95715 L
.49988 .95709 L
.50105 .957 L
.50241 .95681 L
.50384 .95647 L
.50559 .95599 L
.50759 .95539 L
.50978 .95471 L
.51206 .95398 L
.51431 .95324 L
.51647 .95249 L
.51847 .95184 L
.52015 .95124 L
.52151 .9507 L
.5225 .95017 L
.5232 .94973 L
.52362 .94934 L
.52384 .94912 L
.52401 .94899 L
.5242 .94896 L
.52445 .94901 L
.52486 .94914 L
.52549 .94936 L
.52647 .94966 L
.52771 .94998 L
.5294 .95038 L
.53126 .95078 L
.53354 .95117 L
.5364 .95165 L
Mistroke
.53921 .95203 L
.54235 .95232 L
.54565 .95246 L
.54903 .95245 L
.55258 .95232 L
.55605 .95208 L
.55969 .95165 L
.56335 .95106 L
.5671 .95033 L
.571 .94952 L
.5751 .94865 L
.57928 .94778 L
.58354 .94696 L
.58787 .94625 L
.59212 .94564 L
.59627 .94511 L
.60036 .94465 L
.60439 .94424 L
.60838 .94386 L
.61214 .94348 L
.61597 .9431 L
.61952 .94272 L
.62301 .9423 L
.62652 .94182 L
.62996 .94126 L
.63335 .94059 L
.63678 .93979 L
.64004 .93885 L
.6432 .93782 L
.64624 .93672 L
.6491 .93561 L
.65185 .93448 L
.65436 .93344 L
.6566 .9325 L
.65852 .93172 L
.66006 .93108 L
.6612 .93062 L
.66204 .93036 L
.66261 .93028 L
.66295 .93034 L
.66321 .9304 L
.66346 .9305 L
.66374 .93058 L
.66407 .93058 L
.66445 .93049 L
.66481 .93039 L
.66528 .93014 L
.6657 .92982 L
.66625 .92928 L
.66685 .92862 L
Mistroke
.66748 .92786 L
.66814 .92705 L
.6688 .92623 L
.66946 .92541 L
.67011 .92462 L
.67067 .9239 L
.67109 .92323 L
.67132 .92279 L
.67153 .92241 L
.67172 .92216 L
.67196 .92197 L
.67222 .92197 L
.67255 .92208 L
.67291 .9223 L
.67331 .92261 L
.67376 .92294 L
.6742 .92327 L
.67466 .92356 L
.6752 .92383 L
.67585 .92413 L
.67666 .92439 L
.67756 .92458 L
.67853 .92467 L
.67949 .92471 L
.68043 .92468 L
.68132 .9246 L
.68214 .92448 L
.68284 .92437 L
.68344 .92432 L
.68388 .92433 L
.68431 .9244 L
.68472 .92452 L
.68507 .92464 L
.68532 .92472 L
.68551 .92477 L
.68565 .92478 L
.68575 .92477 L
.6858 .92475 L
.68583 .92475 L
.68585 .92477 L
.68586 .92479 L
.68581 .92481 L
.68577 .9248 L
.68578 .92477 L
.68574 .92472 L
.68573 .92468 L
.68581 .92466 L
.68601 .92467 L
.68626 .92469 L
.68658 .92471 L
Mistroke
.68694 .92469 L
.68739 .92463 L
.68791 .9245 L
.68848 .92429 L
.68911 .92402 L
.68985 .92369 L
.69068 .9233 L
.6916 .92284 L
.69263 .92229 L
.69375 .92164 L
.69496 .92088 L
.69624 .92 L
.69773 .91898 L
.69937 .91784 L
.70122 .91658 L
.70325 .91521 L
.70552 .91379 L
.7079 .91222 L
.71044 .91062 L
.7131 .90896 L
.7156 .90728 L
.71817 .90556 L
.72077 .90379 L
.72346 .90198 L
.72607 .90025 L
.72863 .89853 L
.73117 .89682 L
.73369 .89508 L
.73612 .89342 L
.73838 .89182 L
.74016 .89053 L
.74197 .88919 L
.74364 .88802 L
.74512 .88694 L
.74646 .88597 L
.74761 .88511 L
.74858 .88436 L
.74938 .88372 L
.75004 .88315 L
.75058 .88264 L
.75106 .88216 L
.75154 .88167 L
.75206 .8811 L
.75264 .88044 L
.75326 .87969 L
.75392 .87887 L
.75458 .87802 L
.75519 .87719 L
.75575 .87639 L
.75624 .87568 L
Mistroke
.75663 .87505 L
.7569 .87453 L
.75702 .87413 L
.75703 .87384 L
.75694 .87364 L
.75678 .87353 L
.75657 .8735 L
.75642 .87353 L
.75632 .87361 L
.7563 .87372 L
.75643 .87383 L
.75676 .87388 L
.75729 .87385 L
.75798 .87374 L
.7589 .87354 L
.76002 .87322 L
.76133 .87274 L
.76283 .87208 L
.76452 .87125 L
.76636 .87026 L
.76833 .86915 L
.77036 .86792 L
.77249 .86658 L
.7747 .86512 L
.77699 .86354 L
.77925 .86185 L
.78155 .86006 L
.78386 .85824 L
.78617 .85639 L
.78836 .85456 L
.79045 .8528 L
.79235 .85125 L
.79399 .84981 L
.79535 .84858 L
.7964 .84756 L
.79718 .84674 L
.79768 .84613 L
.79798 .8457 L
.79813 .84541 L
.7982 .8452 L
.79818 .84505 L
.79811 .84485 L
.79808 .84451 L
.79813 .84398 L
.79828 .8432 L
.79857 .84215 L
.79902 .84085 L
.7996 .83942 L
.80028 .83784 L
.80095 .83626 L
Mistroke
.80152 .83476 L
.80194 .83348 L
.80218 .83254 L
.80225 .83198 L
.80219 .83185 L
.80209 .8321 L
.80201 .83261 L
.80206 .83325 L
.80234 .83397 L
.8028 .83447 L
.8035 .83498 L
.80446 .83534 L
.80562 .83547 L
.80709 .83534 L
.80886 .83489 L
.81087 .83401 L
.8132 .83271 L
.81566 .83112 L
.81828 .82918 L
.82094 .82703 L
.82362 .82463 L
.82635 .82217 L
.82902 .81976 L
.83178 .81725 L
.83453 .81476 L
.83733 .8123 L
.84009 .80993 L
.84276 .80759 L
.84533 .8054 L
.84775 .80335 L
.85004 .80147 L
.85219 .79971 L
.85409 .79813 L
.85593 .7966 L
.85769 .79503 L
.85951 .79333 L
.86119 .79148 L
.86253 .78971 L
.86399 .78766 L
.86526 .78563 L
.86665 .78332 L
.86775 .78124 L
.86895 .77902 L
.87013 .77671 L
.87125 .77436 L
.87229 .77195 L
.87319 .76957 L
.87396 .76719 L
.8746 .76462 L
.87502 .76243 L
Mistroke
.8754 .76015 L
.87571 .75818 L
.87597 .7563 L
.87614 .75459 L
.87626 .75315 L
.87632 .75194 L
.87634 .75092 L
.87633 .75011 L
.87631 .74945 L
.87632 .74894 L
.87634 .74865 L
.87646 .74852 L
.8767 .7484 L
.87709 .74813 L
.87762 .74756 L
.8783 .74663 L
.87911 .74531 L
.88008 .74359 L
.88117 .7415 L
.88237 .73908 L
.88364 .73633 L
.88494 .73342 L
.88624 .73025 L
.88751 .72697 L
.88876 .72348 L
.88994 .71994 L
.89106 .71633 L
.89208 .71272 L
.89301 .7092 L
.89385 .70591 L
.89458 .70281 L
.89519 .7001 L
.89565 .6977 L
.89599 .69566 L
.89625 .69393 L
.89645 .69251 L
.89662 .69134 L
.89681 .69045 L
.89701 .68971 L
.89723 .68915 L
.8975 .68859 L
.89784 .68797 L
.89829 .68716 L
.89877 .68635 L
.89932 .68521 L
.90003 .68367 L
.90059 .68212 L
.90114 .68039 L
.90163 .67844 L
.90205 .6763 L
Mistroke
.90237 .67403 L
.90259 .67176 L
.90268 .66966 L
.90268 .66771 L
.90258 .66604 L
.90241 .66473 L
.90224 .66376 L
.90211 .66306 L
.90205 .66262 L
.90204 .66247 L
.90208 .66251 L
.90215 .66271 L
.90219 .66307 L
.90218 .66358 L
.90211 .66427 L
.90193 .66506 L
.90164 .6659 L
.90123 .66666 L
.90071 .66725 L
.90014 .66766 L
.89946 .66791 L
.89863 .66809 L
.89764 .66822 L
.89653 .66835 L
.89525 .66852 L
.89389 .66865 L
.89252 .66865 L
.89117 .66851 L
.88989 .66824 L
.88883 .6679 L
.88786 .66752 L
.88696 .66719 L
.88612 .66691 L
.88544 .66669 L
.88498 .66648 L
.88465 .66632 L
.88445 .66622 L
.88441 .66622 L
.88448 .66636 L
.88464 .66671 L
.88484 .66736 L
.88503 .6684 L
.88518 .66985 L
.88531 .67173 L
.88542 .67405 L
.88548 .6766 L
.88548 .67956 L
.88543 .68265 L
.88538 .68601 L
.88535 .68906 L
Mistroke
.88532 .69208 L
.88531 .695 L
.8853 .69759 L
.88528 .69979 L
.88527 .70168 L
.88525 .70322 L
.88524 .70437 L
.88523 .7052 L
.88521 .70579 L
.88519 .70616 L
.88517 .70637 L
.88516 .70645 L
.88515 .70647 L
.88517 .70643 L
.8852 .70638 L
.88525 .70636 L
.88529 .7064 L
.88531 .70648 L
.88529 .70663 L
.88524 .7068 L
.88516 .70699 L
.88505 .7072 L
.88491 .70748 L
.88475 .70789 L
.88458 .70843 L
.88443 .7091 L
.88429 .70993 L
.88419 .71093 L
.88413 .71214 L
.88414 .71355 L
.88422 .71513 L
.88437 .71687 L
.88458 .71864 L
.8848 .72057 L
.885 .72266 L
.88516 .72493 L
.88522 .7274 L
.88516 .73 L
.88496 .73253 L
.88463 .7351 L
.8842 .7376 L
.88372 .73988 L
.88323 .74172 L
.88273 .74334 L
.88225 .74471 L
.88183 .74574 L
.88149 .74653 L
.88125 .74716 L
.88112 .74746 L
.88111 .74751 L
Mistroke
.88122 .74734 L
.88145 .74698 L
.88176 .74649 L
.88208 .74598 L
.88237 .74555 L
.88258 .7453 L
.88266 .74531 L
.88258 .7456 L
.88232 .74614 L
.88187 .74694 L
.88124 .74798 L
.88044 .74929 L
.87949 .75083 L
.87849 .75246 L
.87742 .75412 L
.8763 .75573 L
.87518 .75725 L
.87408 .75872 L
.8731 .75997 L
.87224 .76104 L
.87157 .76183 L
.8711 .76232 L
.87084 .76254 L
.87078 .76247 L
.87089 .76217 L
.87112 .76173 L
.87142 .76121 L
.87171 .76084 L
.872 .76054 L
.87224 .76042 L
.8724 .76058 L
.87249 .76094 L
.87252 .76148 L
.8725 .76216 L
.87243 .76298 L
.87234 .76389 L
.87223 .76487 L
.87211 .76594 L
.87196 .76702 L
.87181 .76822 L
.87169 .76937 L
.87163 .77037 L
.8716 .77119 L
.87157 .77188 L
.87149 .77247 L
.87137 .77296 L
.87122 .77335 L
.87105 .7736 L
.8709 .77367 L
.87078 .77357 L
Mistroke
.87073 .77332 L
.8707 .77299 L
.87068 .77261 L
.87071 .77217 L
.87076 .77176 L
.87083 .77143 L
.87093 .77109 L
.87104 .77074 L
.87116 .77036 L
.87126 .76997 L
.87132 .76964 L
.87136 .76939 L
.87137 .76927 L
.87132 .7693 L
.87117 .76954 L
.87092 .77002 L
.87057 .77076 L
.87013 .7717 L
.86961 .77286 L
.86901 .77424 L
.86829 .77573 L
.86742 .7775 L
.86643 .77943 L
.86536 .78149 L
.86422 .78358 L
.86318 .78551 L
.86217 .78728 L
.86124 .78884 L
.86044 .7901 L
.85978 .79103 L
.85927 .79165 L
.85888 .79206 L
.85862 .79231 L
.85847 .79244 L
.85843 .79247 L
.85844 .79244 L
.85843 .79241 L
.8584 .79242 L
.85837 .79243 L
.85838 .79241 L
.85837 .79238 L
.85831 .79239 L
.85817 .79246 L
.858 .79256 L
.85783 .79265 L
.85767 .79273 L
.85753 .79277 L
.8574 .79273 L
.85726 .79271 L
.85697 .7927 L
Mistroke
.85654 .79276 L
.85599 .79277 L
.85532 .7929 L
.85451 .79308 L
.85353 .79319 L
.85253 .79321 L
.85155 .79315 L
.85068 .79306 L
.8498 .79296 L
.84897 .79285 L
.84838 .79274 L
.84797 .79265 L
.84764 .79256 L
.84743 .79253 L
.8474 .79254 L
.8475 .79261 L
.84781 .79263 L
.84828 .79258 L
.84886 .79246 L
.84948 .79233 L
.85016 .79214 L
.85085 .7919 L
.85163 .79149 L
.85236 .79107 L
.85314 .7905 L
.85383 .78993 L
.85449 .78935 L
.85505 .78879 L
.85554 .78827 L
.85598 .78778 L
.85634 .78736 L
.85667 .78701 L
.85699 .78669 L
.85728 .78637 L
.85753 .78607 L
.85768 .78589 L
.85772 .78586 L
.85772 .78588 L
.85776 .78592 L
.85782 .78596 L
.85787 .78602 L
.85791 .78612 L
.85792 .78624 L
.85793 .78637 L
.85792 .7865 L
.85788 .7866 L
.85782 .78674 L
.85772 .78689 L
.85763 .78701 L
.85763 .787 L
Mistroke
.85772 .78687 L
.85792 .78663 L
.8581 .78641 L
.85835 .78613 L
.85858 .78586 L
.85878 .78564 L
.85892 .78549 L
.85898 .78544 L
.85898 .78548 L
.85895 .78556 L
.85893 .78563 L
.8589 .78567 L
.85887 .7857 L
.85882 .78573 L
.85877 .78576 L
.85874 .78576 L
.85874 .78571 L
.85873 .78567 L
.85874 .78559 L
.85875 .7855 L
.85878 .7854 L
.85882 .78532 L
.85886 .78525 L
.8589 .78522 L
.85895 .78521 L
.85898 .78522 L
.859 .78523 L
.85901 .78523 L
.859 .78523 L
.85898 .78524 L
.85897 .78525 L
.85896 .78525 L
.85896 .78522 L
.85897 .78519 L
.859 .78512 L
.85906 .78503 L
.85913 .78494 L
.85918 .78492 L
.8592 .78497 L
.85917 .78511 L
.85907 .78537 L
.85888 .7858 L
.85857 .78637 L
.85816 .78702 L
.85769 .7877 L
.85721 .78833 L
.85676 .78892 L
.85634 .78942 L
.856 .78978 L
.85571 .79003 L
Mistroke
.85547 .7902 L
.85534 .79018 L
.85531 .79001 L
.8554 .78973 L
.85568 .78919 L
.85614 .78849 L
.85677 .78763 L
.85757 .78674 L
.85852 .78577 L
.85962 .78474 L
.86086 .7836 L
.86224 .78229 L
.86375 .78071 L
.86539 .77887 L
.86709 .77676 L
.86879 .77451 L
.87055 .77196 L
.87223 .76929 L
.87377 .76691 L
.87513 .76447 L
.87626 .76234 L
.87723 .76029 L
.87799 .75854 L
.87857 .75712 L
.87898 .75596 L
.87927 .7551 L
.87947 .75455 L
.8796 .75429 L
.87971 .75422 L
.8798 .75429 L
.8799 .75442 L
.88002 .75457 L
.88016 .75469 L
.8803 .75478 L
.88044 .75483 L
.88055 .75484 L
.88063 .75483 L
.88068 .75483 L
.88069 .75486 L
.88068 .75491 L
.88065 .75498 L
.88062 .75505 L
.8806 .75511 L
.88059 .75514 L
.88058 .75511 L
.88057 .755 L
.88054 .75479 L
.88051 .75447 L
.88048 .75403 L
.88045 .75346 L
Mistroke
.88045 .75277 L
.88048 .75199 L
.88054 .75111 L
.88063 .75016 L
.88075 .74917 L
.8809 .7482 L
.88106 .74727 L
.88124 .74641 L
.88142 .74566 L
.8816 .74504 L
.88177 .74454 L
.88194 .74417 L
.88208 .74392 L
.88219 .74376 L
.88228 .74367 L
.88233 .74363 L
.88239 .74364 L
.88244 .74368 L
.88248 .74372 L
.88247 .74376 L
.88242 .7438 L
.88232 .74385 L
.88216 .74388 L
.88193 .74391 L
.88163 .74394 L
.88129 .74398 L
.88092 .74402 L
.88054 .74406 L
.88014 .7441 L
.87975 .74414 L
.87938 .74418 L
.87902 .74421 L
.8787 .74424 L
.87845 .74426 L
.87832 .74427 L
.87829 .7443 L
.87837 .74436 L
.87854 .74445 L
.87878 .74455 L
.87907 .7446 L
.8794 .74457 L
.87974 .74442 L
.88013 .74412 L
.88056 .74366 L
.88101 .74304 L
.88147 .74229 L
.88191 .74144 L
.88232 .74054 L
.88268 .73968 L
.88299 .73872 L
Mistroke
.88325 .73785 L
.88348 .73703 L
.88368 .73631 L
.88386 .73575 L
.88401 .73538 L
.88415 .73521 L
.88428 .73518 L
.88442 .73522 L
.88458 .73526 L
.88477 .73519 L
.88501 .7349 L
.88532 .7343 L
.88571 .73334 L
.88617 .73203 L
.88671 .73045 L
.88729 .72861 L
.88794 .72645 L
.88863 .72416 L
.88935 .72167 L
.89009 .71927 L
.8908 .7169 L
.89154 .71463 L
.89216 .71252 L
.89276 .71078 L
.89327 .70924 L
.89368 .70793 L
.89399 .70686 L
.8942 .70598 L
.89434 .70522 L
.8944 .70449 L
.89441 .70373 L
.89437 .70289 L
.89431 .7019 L
.89424 .70074 L
.89418 .69933 L
.89412 .6978 L
.89406 .69613 L
.89401 .69449 L
.89398 .69293 L
.89395 .69162 L
.89393 .69045 L
.89391 .68958 L
.8939 .68894 L
.89389 .68852 L
.89392 .68833 L
.89398 .68834 L
.89407 .68854 L
.89415 .68891 L
.89421 .68938 L
.89421 .68992 L
Mistroke
.89416 .69046 L
.89401 .69093 L
.89376 .69126 L
.89338 .69142 L
.89289 .69146 L
.89231 .69143 L
.89167 .6914 L
.89099 .69142 L
.89026 .69151 L
.88948 .69171 L
.88864 .69199 L
.88775 .69234 L
.88684 .69272 L
.88597 .69312 L
.88509 .69354 L
.88421 .69397 L
.88333 .69444 L
.88246 .69497 L
.88162 .69557 L
.88073 .69621 L
.87974 .69688 L
.87867 .69757 L
.87755 .69829 L
.87642 .69903 L
.87523 .69984 L
.87403 .70072 L
.87296 .70168 L
.87191 .70269 L
.87093 .70376 L
.87004 .70483 L
.86928 .70583 L
.86857 .70671 L
.86791 .70745 L
.86731 .70803 L
.86678 .70848 L
.86631 .70879 L
.86589 .70901 L
.86547 .70917 L
.86499 .70929 L
.8644 .70938 L
.86369 .70948 L
.86281 .70958 L
.8619 .70971 L
.86078 .70989 L
.85958 .71013 L
.85848 .7104 L
.85734 .71071 L
.85625 .71102 L
.85523 .71133 L
.85436 .7116 L
Mistroke
.85359 .71179 L
.85294 .71189 L
.85244 .71191 L
.85213 .71184 L
.85203 .7117 L
.85213 .71154 L
.85236 .71142 L
.85264 .71142 L
.85291 .7116 L
.85311 .71199 L
.85323 .7126 L
.8532 .7135 L
.85306 .71469 L
.8528 .71608 L
.85247 .71775 L
.85204 .71966 L
.85157 .7216 L
.85099 .72377 L
.85037 .72582 L
.84972 .72786 L
.84906 .72978 L
.84845 .73147 L
.84796 .73295 L
.8476 .73419 L
.84738 .73513 L
.84728 .73588 L
.84729 .73646 L
.84737 .7369 L
.8475 .73722 L
.84765 .73748 L
.84782 .73768 L
.84801 .73783 L
.84822 .73794 L
.84844 .73804 L
.84864 .73813 L
.84882 .73824 L
.84895 .73834 L
.84904 .73843 L
.84909 .73848 L
.84911 .73849 L
.8491 .73847 L
.84909 .73839 L
.8491 .73824 L
.84914 .73806 L
.8492 .73788 L
.84926 .73774 L
.8493 .7377 L
.84927 .73778 L
.84917 .73802 L
.84899 .73846 L
Mistroke
.84869 .73915 L
.84828 .7401 L
.84774 .7413 L
.84708 .7428 L
.84634 .74449 L
.84551 .74644 L
.8446 .74868 L
.84362 .75116 L
.84265 .75361 L
.84167 .75619 L
.8407 .75876 L
.8398 .76105 L
.83901 .76306 L
.83833 .76489 L
.83777 .76648 L
.83736 .76778 L
.83709 .76872 L
.83696 .76944 L
.83696 .76997 L
.83706 .77034 L
.83719 .77057 L
.83731 .77072 L
.83742 .77082 L
.83749 .77091 L
.83751 .77097 L
.83746 .77099 L
.83735 .77103 L
.83719 .77113 L
.83693 .77136 L
.83652 .77172 L
.836 .77222 L
.83537 .77285 L
.83468 .77364 L
.83391 .7746 L
.83313 .77575 L
.83234 .77711 L
.83152 .77858 L
.83085 .78032 L
.83013 .78235 L
.8294 .78462 L
.82859 .78715 L
.82778 .78978 L
.82691 .79248 L
.826 .79484 L
.82522 .79735 L
.8245 .79926 L
.82393 .80116 L
.82344 .80281 L
.82301 .80419 L
.82266 .80534 L
Mistroke
.82237 .80622 L
.82215 .80682 L
.82205 .80717 L
.82206 .8073 L
.82216 .80726 L
.8223 .80712 L
.82247 .80697 L
.8226 .80685 L
.82269 .80676 L
.82271 .80668 L
.8227 .80664 L
.82264 .80665 L
.82253 .80666 L
.82238 .80668 L
.82224 .80669 L
.82214 .8067 L
.82205 .80671 L
.82197 .80671 L
.82191 .80671 L
.82185 .80672 L
.82178 .80672 L
.82171 .80673 L
.82166 .80673 L
.82164 .80673 L
.82163 .80673 L
.82162 .80671 L
.82158 .80669 L
.82154 .80667 L
.82146 .80666 L
.82136 .80666 L
.82126 .80666 L
.82117 .80665 L
.82109 .80664 L
.82103 .80661 L
.82097 .80661 L
.82092 .80669 L
.82084 .80691 L
.82076 .80731 L
.82061 .80797 L
.82045 .80879 L
.82024 .80984 L
.82002 .81119 L
.8198 .81227 L
.81958 .81382 L
.81934 .81531 L
.81909 .81658 L
.81881 .81821 L
.8185 .8197 L
.81816 .82118 L
.81782 .82256 L
Mistroke
.81749 .82377 L
.81719 .82476 L
.81691 .82551 L
.81669 .82608 L
.81649 .8265 L
.81633 .8268 L
.81621 .82701 L
.81613 .82717 L
.81609 .82729 L
.8161 .82735 L
.81615 .82736 L
.81623 .82731 L
.81632 .82723 L
.81639 .82714 L
.81642 .82709 L
.81639 .82706 L
.81632 .82707 L
.81622 .82708 L
.81609 .82709 L
.81593 .82711 L
.81573 .82713 L
.81552 .82715 L
.81531 .82717 L
.8151 .82719 L
.81489 .82721 L
.81476 .82723 L
.81466 .82724 L
.81463 .82724 L
.81466 .82724 L
.81477 .82723 L
.81492 .82721 L
.81513 .82719 L
.81534 .82717 L
.81556 .82715 L
.81575 .82713 L
.81591 .82711 L
.81606 .8271 L
.8162 .82708 L
.81632 .82707 L
.81641 .82705 L
.81646 .82705 L
.8165 .82704 L
.81652 .82701 L
.81651 .82695 L
.81648 .82687 L
.81643 .82681 L
.81632 .82678 L
.81613 .82682 L
.81582 .82693 L
.81537 .82712 L
Mistroke
.81469 .82742 L
.81392 .82786 L
.8129 .82845 L
.81167 .82919 L
.81034 .83007 L
.80881 .83107 L
.80709 .83214 L
.8053 .83333 L
.80344 .8345 L
.80163 .83572 L
.79982 .8369 L
.7981 .83797 L
.7966 .8389 L
.79523 .83971 L
.79407 .84037 L
.79312 .84089 L
.79244 .84128 L
.79191 .84152 L
.79156 .84161 L
.79138 .84157 L
.79131 .84144 L
.79128 .8413 L
.79123 .84123 L
.79116 .84126 L
.79102 .84142 L
.79081 .84169 L
.79051 .84206 L
.79017 .84253 L
.78971 .84311 L
.78919 .84378 L
.78859 .8445 L
.78797 .84531 L
.78734 .84616 L
.78669 .84706 L
.78597 .84804 L
.7852 .84908 L
.78438 .85015 L
.78344 .85124 L
.78251 .85241 L
.78144 .85369 L
.78019 .85509 L
.77876 .85664 L
.77731 .85824 L
.77568 .85994 L
.77388 .86168 L
.77214 .86334 L
.77049 .86485 L
.76893 .86622 L
.76744 .86743 L
.76613 .86847 L
Mistroke
.76485 .86941 L
.76368 .87027 L
.76257 .87103 L
.76153 .87171 L
.76054 .87234 L
.75956 .87291 L
.75862 .87354 L
.75761 .87422 L
.75655 .87496 L
.75541 .87578 L
.75427 .87662 L
.75304 .87754 L
.75174 .87851 L
.75041 .8795 L
.74911 .88046 L
.74782 .88137 L
.74668 .88214 L
.74563 .88279 L
.74465 .88335 L
.74372 .8839 L
.74282 .88447 L
.74195 .88506 L
.7411 .88568 L
.7402 .88637 L
.73919 .88717 L
.73804 .88814 L
.73673 .88929 L
.7352 .89066 L
.73346 .89225 L
.73179 .89385 L
.72985 .89555 L
.72773 .89745 L
.72568 .89952 L
.72326 .90164 L
.72114 .90352 L
.71897 .90541 L
.71681 .9072 L
.71485 .90874 L
.71303 .91014 L
.71147 .91137 L
.71008 .91241 L
.70881 .91335 L
.70764 .91419 L
.7066 .91498 L
.70556 .91568 L
.7045 .91637 L
.70344 .91699 L
.70246 .91763 L
.70149 .91824 L
.7006 .9188 L
Mistroke
.69981 .91928 L
.69917 .91965 L
.69865 .91987 L
.69824 .91999 L
.6979 .92005 L
.69769 .92001 L
.69755 .91989 L
.69747 .91972 L
.69745 .91949 L
.69745 .91927 L
.69747 .91912 L
.69747 .91904 L
.69743 .91909 L
.69728 .91928 L
.69701 .91962 L
.69664 .92002 L
.69618 .9205 L
.69562 .92103 L
.6949 .92162 L
.69429 .92213 L
.69362 .92265 L
.69303 .92311 L
.69256 .92349 L
.69217 .92379 L
.69186 .924 L
.6916 .92414 L
.6914 .9242 L
.69119 .92421 L
.69096 .92418 L
.69074 .92412 L
.69052 .92408 L
.69029 .92407 L
.69001 .9241 L
.68971 .92412 L
.6894 .92416 L
.68907 .92419 L
.68875 .92423 L
.68848 .92425 L
.68832 .92427 L
.68829 .92428 L
.68836 .92427 L
.68849 .92426 L
.68868 .92425 L
.68892 .92423 L
.68918 .92421 L
.68945 .92419 L
.68972 .92416 L
.69001 .92414 L
.69028 .92411 L
.69055 .92408 L
Mistroke
.69075 .92406 L
.69088 .92405 L
.69091 .92404 L
.69086 .92404 L
.69077 .92405 L
.69065 .92405 L
.69056 .92405 L
.6905 .92405 L
.69048 .92404 L
.69047 .92403 L
.69046 .92403 L
.69043 .92404 L
.69044 .92404 L
.6905 .92403 L
.69066 .92402 L
.69085 .924 L
.69105 .92397 L
.69125 .92394 L
.69138 .92393 L
.69141 .92392 L
.69133 .92393 L
.69113 .92395 L
.69084 .92398 L
.69046 .92402 L
.69008 .92407 L
.68963 .92413 L
.68916 .92419 L
.68872 .92424 L
.68834 .92429 L
.68804 .92433 L
.68782 .92435 L
.6877 .92437 L
.68765 .92438 L
.68767 .92438 L
.68773 .92437 L
.6878 .92436 L
.68786 .92435 L
.68789 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
Mistroke
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92435 L
.6879 .92434 L
.68793 .92434 L
.68798 .92434 L
.68804 .92433 L
.6881 .92432 L
.68814 .92432 L
.68811 .92432 L
.68801 .92433 L
.68782 .92435 L
.68754 .92439 L
.6872 .92443 L
.68681 .92447 L
.68642 .92452 L
.68604 .92457 L
.68568 .92461 L
.68535 .92465 L
.68506 .92469 L
.68486 .92473 L
.68476 .92479 L
.68478 .92484 L
.6849 .92486 L
.6851 .92482 L
.68534 .92471 L
.6856 .92455 L
.68583 .92436 L
Mistroke
.686 .92416 L
.6861 .92396 L
.68612 .9238 L
.68608 .92369 L
.68602 .92364 L
.68597 .92366 L
.68591 .92374 L
.68584 .92382 L
.68577 .92389 L
.6857 .92394 L
.6856 .92397 L
.68549 .92393 L
.68535 .9238 L
.68522 .92359 L
.6851 .92333 L
.68501 .92305 L
.68495 .92279 L
.68491 .92254 L
.68484 .9223 L
.68475 .92213 L
.68467 .92208 L
.68462 .92213 L
.68461 .92229 L
.68463 .92253 L
.68467 .92287 L
.68471 .92328 L
.68474 .92375 L
.68472 .92422 L
.68466 .92463 L
.68456 .92494 L
.68444 .92512 L
.68432 .92519 L
.68428 .92518 L
.68437 .92512 L
.68458 .92502 L
.68482 .92494 L
.68515 .92486 L
.68552 .92479 L
.68586 .92472 L
.68616 .92465 L
.68636 .9246 L
.68649 .92455 L
.68656 .92451 L
.68662 .92449 L
.68667 .92447 L
.68673 .92446 L
.6867 .92448 L
.68661 .9245 L
.68651 .92453 L
.68649 .92454 L
Mistroke
.68649 .92454 L
.68659 .92452 L
.68676 .9245 L
.68698 .92447 L
.68724 .92444 L
.68751 .9244 L
.68778 .92436 L
.68803 .92432 L
.68822 .9243 L
.68831 .92429 L
.68827 .92429 L
.6881 .92432 L
.6878 .92437 L
.68738 .92443 L
.68689 .9245 L
.68638 .92457 L
.68587 .92463 L
.68539 .9247 L
.68494 .92475 L
.6846 .9248 L
.68432 .92485 L
.68411 .9249 L
.68402 .92492 L
.68411 .92491 L
.68436 .92484 L
.68472 .92475 L
.68515 .92462 L
.68561 .92448 L
.68608 .92434 L
.68649 .92422 L
.68681 .92413 L
.68701 .92406 L
.68714 .92402 L
.68724 .924 L
.68734 .92399 L
.68746 .92396 L
.68757 .92395 L
.68765 .92396 L
.68769 .92401 L
.6877 .9241 L
.68769 .92422 L
.68765 .92435 L
.68756 .9245 L
.68742 .92463 L
.68724 .92475 L
.68708 .92483 L
.68694 .92488 L
.68658 .92499 L
.68633 .92505 L
.686 .92514 L
Mistroke
.68554 .92523 L
.6849 .92535 L
.68406 .92548 L
.68294 .92562 L
.68166 .92582 L
.68004 .92606 L
.67815 .92636 L
.67614 .92671 L
.67386 .92711 L
.67136 .92756 L
.66871 .92807 L
.66594 .92866 L
.66356 .9292 L
.66132 .92982 L
.65947 .93046 L
.65792 .93104 L
.65683 .93157 L
.65609 .932 L
.65568 .93231 L
.65559 .93251 L
.65567 .93259 L
.65594 .9326 L
.65632 .93253 L
.6568 .93234 L
.65731 .93209 L
.65777 .9318 L
.65812 .93148 L
.65832 .93113 L
.65839 .93079 L
.65836 .93047 L
.65827 .93018 L
.65812 .92995 L
.65789 .92978 L
.65761 .92961 L
.65728 .92938 L
.65695 .92911 L
.65663 .92878 L
.65634 .92838 L
.65608 .92788 L
.65587 .92728 L
.65571 .92666 L
.65563 .92608 L
.65558 .92554 L
.65556 .92505 L
.65554 .92463 L
.65554 .92437 L
.65554 .92426 L
.65556 .9243 L
.6556 .92449 L
.65566 .92477 L
Mistroke
.65574 .92507 L
.65582 .92533 L
.65589 .92549 L
.65595 .92562 L
.65599 .92566 L
.65604 .92558 L
.65613 .92544 L
.65626 .92524 L
.65645 .92502 L
.65668 .92479 L
.65693 .92458 L
.65714 .92444 L
.65724 .92437 L
.65721 .92439 L
.65705 .92454 L
.65673 .92485 L
.6562 .92527 L
.65546 .92583 L
.65451 .92649 L
.65335 .92723 L
.65203 .92806 L
.65031 .92878 L
.64852 .92957 L
.64647 .93038 L
.644 .93121 L
.64122 .93207 L
.63807 .93289 L
.63493 .93374 L
.63185 .93461 L
.62847 .93546 L
.62481 .93637 L
.62153 .9373 L
.61768 .93809 L
.61399 .93885 L
.60988 .93957 L
.60593 .94029 L
.60225 .94091 L
.59835 .94152 L
.5944 .9421 L
.59122 .94263 L
.58769 .9431 L
.58447 .94354 L
.58108 .94395 L
.57792 .94436 L
.57456 .94477 L
.57118 .94518 L
.56807 .94557 L
.56479 .94601 L
.56141 .94649 L
.55842 .94701 L
Mistroke
.55559 .94753 L
.55231 .94804 L
.54956 .94851 L
.54672 .94891 L
.5438 .94924 L
.5409 .94949 L
.53837 .94961 L
.53584 .94958 L
.53348 .94938 L
.53121 .94905 L
.52917 .94861 L
.52722 .94809 L
.52537 .94751 L
.52387 .94694 L
.52255 .94648 L
.52141 .94605 L
.52048 .94572 L
.51975 .94551 L
.51914 .94537 L
.51859 .94528 L
.518 .94522 L
.5173 .94521 L
.51643 .94525 L
.51527 .94531 L
.51378 .94539 L
.51208 .94553 L
.51 .94566 L
.50754 .94576 L
.50466 .94584 L
.50158 .94595 L
.49831 .9461 L
.4946 .94631 L
.4908 .94655 L
.4872 .94678 L
.48338 .94699 L
.47954 .94716 L
.47576 .94722 L
.47216 .94718 L
.46851 .94703 L
.46533 .94685 L
.46237 .94668 L
.4597 .94654 L
.45747 .94642 L
.45553 .94631 L
.45391 .94622 L
.4527 .94615 L
.45179 .9461 L
.45116 .94605 L
.45081 .94601 L
.45069 .94598 L
Mistroke
.45074 .94597 L
.45088 .94592 L
.45104 .94586 L
.45118 .94571 L
.4513 .94547 L
.45137 .94524 L
.45139 .945 L
.45134 .94476 L
.45126 .9445 L
.45117 .94423 L
.45107 .94397 L
.45098 .94377 L
.45087 .94355 L
.45074 .94327 L
.4506 .94295 L
.45046 .94259 L
.45031 .94224 L
.45017 .94185 L
.45004 .9415 L
.44993 .94116 L
.44982 .94084 L
.44969 .94055 L
.44956 .94033 L
.44943 .94021 L
.44932 .94018 L
.44926 .94028 L
.44927 .94055 L
.44935 .94095 L
.44948 .94142 L
.44963 .94193 L
.44978 .94242 L
.44994 .94287 L
.4501 .94323 L
.45023 .94352 L
.45037 .9437 L
.45052 .94377 L
.45068 .94372 L
.45084 .9435 L
.451 .94313 L
.45117 .9427 L
.45131 .94224 L
.45144 .94178 L
.45152 .94135 L
.45157 .94102 L
.45159 .94083 L
.4516 .94078 L
.4516 .94083 L
.45157 .94092 L
.4515 .94104 L
.45138 .94119 L
Mistroke
.45121 .94129 L
.45098 .94139 L
.45072 .94145 L
.45045 .94144 L
.45018 .94136 L
.44995 .94124 L
.44977 .94108 L
.44962 .94091 L
.44951 .94074 L
.44945 .94059 L
.44944 .94048 L
.44944 .94043 L
.44946 .94044 L
.44949 .94049 L
.44953 .94054 L
.44956 .94058 L
.44959 .94062 L
.44962 .94066 L
.44965 .9407 L
.44968 .94072 L
.4497 .9407 L
.44971 .94064 L
.44972 .94056 L
.44972 .94051 L
.44973 .94052 L
.44975 .94064 L
.44979 .94089 L
.44983 .94125 L
.44987 .9417 L
.44993 .94223 L
.44999 .94281 L
.45007 .94337 L
.45015 .94391 L
.45027 .94434 L
.4504 .94479 L
.45054 .94521 L
.45069 .94553 L
.45084 .94575 L
.45098 .94581 L
.45108 .94573 L
.45116 .94556 L
.45123 .94532 L
.45128 .94505 L
.45131 .94479 L
.45133 .94454 L
.45134 .94433 L
.45137 .94414 L
.4514 .94394 L
.45143 .94375 L
.45145 .94353 L
Mistroke
.45145 .94328 L
.4514 .94299 L
.45133 .94268 L
.45125 .94238 L
.45113 .94206 L
.451 .94174 L
.45087 .94144 L
.45073 .94117 L
.4506 .94096 L
.45046 .9408 L
.45039 .9407 L
.45041 .94066 L
.45048 .94066 L
.45054 .94067 L
.45058 .94067 L
.45059 .94065 L
.4505 .94062 L
.45023 .94059 L
.44967 .9406 L
.44875 .94065 L
.44739 .94068 L
.44553 .94066 L
.44319 .94055 L
.44084 .94034 L
.4381 .94001 L
.43468 .93957 L
.43137 .939 L
.42707 .93828 L
.42361 .93743 L
.41923 .93652 L
.41536 .93543 L
.41133 .93428 L
.40684 .93301 L
.40332 .93162 L
.39924 .93018 L
.39555 .92869 L
.39177 .9272 L
.38809 .92569 L
.38406 .92425 L
.38064 .92285 L
.37674 .92152 L
.37315 .92021 L
.36942 .91893 L
.3657 .91767 L
.36217 .91641 L
.35829 .91515 L
.35504 .91391 L
.35152 .91265 L
.34814 .9114 L
.34488 .91016 L
Mistroke
.34161 .90895 L
.3386 .90786 L
.33554 .90678 L
.33281 .90575 L
.33046 .90483 L
.32834 .90397 L
.32646 .90322 L
.32503 .90263 L
.32384 .90222 L
.32294 .90201 L
.32228 .90194 L
.32179 .90196 L
.32139 .90201 L
.32099 .902 L
.3205 .90185 L
.31981 .90151 L
.31881 .90095 L
.31768 .90024 L
.31613 .89934 L
.3142 .89827 L
.31201 .89717 L
.30954 .8958 L
.30686 .89442 L
.30389 .89289 L
.30104 .89128 L
.29823 .8896 L
.29552 .88807 L
.29282 .88657 L
.29031 .88509 L
.28788 .88371 L
.28563 .88234 L
.2834 .88087 L
.28125 .87931 L
.27917 .87761 L
.27704 .87574 L
.27484 .87368 L
.27276 .87156 L
.27058 .86921 L
.26839 .86681 L
.26625 .86422 L
.26416 .86143 L
.26212 .85864 L
.26015 .8556 L
.25844 .85277 L
.2569 .84971 L
.25554 .847 L
.25439 .84437 L
.25341 .84196 L
.25255 .83977 L
.25172 .83781 L
Mistroke
.25084 .83592 L
.24983 .83441 L
.24864 .83303 L
.24723 .83178 L
.24552 .83066 L
.24347 .82965 L
.24145 .82869 L
.23901 .82776 L
.23617 .82667 L
.23344 .8254 L
.23031 .82389 L
.22684 .8221 L
.22359 .82008 L
.22001 .81763 L
.21656 .81502 L
.21302 .81224 L
.20973 .80954 L
.20631 .8065 L
.20323 .80356 L
.20005 .8004 L
.19709 .79747 L
.1942 .79443 L
.19149 .7915 L
.18894 .78858 L
.18657 .78595 L
.18442 .78328 L
.18248 .78062 L
.18076 .77811 L
.17921 .77546 L
.17785 .77303 L
.1766 .77049 L
.1754 .76799 L
.17418 .76546 L
.17295 .76293 L
.17172 .76023 L
.17046 .75776 L
.16924 .75512 L
.16799 .75241 L
.16686 .74987 L
.16576 .74727 L
.16473 .74487 L
.16376 .74265 L
.16293 .7404 L
.16263 .73836 L
.16188 .73631 L
.16125 .73454 L
.16078 .73288 L
.16051 .73142 L
.1604 .73019 L
.1604 .72919 L
Mistroke
.16046 .72839 L
.16052 .72776 L
.16051 .7272 L
.1604 .72664 L
.16012 .726 L
.15961 .72522 L
.15884 .72424 L
.15786 .72304 L
.15668 .72164 L
.15552 .72019 L
.15401 .7185 L
.15224 .71662 L
.15033 .71463 L
.14825 .71234 L
.14616 .71009 L
.1439 .70764 L
.14178 .70503 L
.13985 .70253 L
.13794 .69978 L
.13627 .69701 L
.13478 .69404 L
.13345 .69085 L
.13232 .68729 L
.13132 .6836 L
.13046 .67956 L
.12968 .67517 L
.12895 .67075 L
.12827 .66589 L
.12762 .66126 L
.12698 .65714 L
.12634 .6525 L
.12572 .64777 L
.12506 .64351 L
.12434 .63908 L
.1236 .63476 L
.12281 .63067 L
.12203 .6264 L
.12126 .62233 L
.12051 .61828 L
.11985 .61415 L
.11927 .61003 L
.11877 .60601 L
.11837 .60197 L
.11804 .59796 L
.11779 .59421 L
.11759 .59045 L
.11741 .58679 L
.11724 .58352 L
.11704 .58002 L
.1168 .57685 L
Mistroke
.11652 .57348 L
.11615 .57016 L
.11568 .56663 L
.11512 .56288 L
.1145 .55945 L
.11382 .5554 L
.11313 .55132 L
.11247 .54748 L
.11182 .54369 L
.11123 .53975 L
.11074 .53527 L
.11037 .53124 L
.11013 .52696 L
.11002 .52264 L
.11006 .5183 L
.11024 .51394 L
.11055 .50952 L
.11098 .50532 L
.11149 .50129 L
.11206 .49707 L
.11264 .49344 L
.11325 .48988 L
.11385 .48666 L
.11442 .48402 L
.11493 .48182 L
.11536 .48012 L
.11572 .47885 L
.11598 .47788 L
.11615 .4772 L
.11626 .47672 L
.11634 .47633 L
.11642 .47592 L
.11655 .47542 L
.11673 .47481 L
.11698 .47409 L
.11731 .47325 L
.11771 .47238 L
.11817 .47136 L
.1187 .47028 L
.11923 .46915 L
.1198 .46807 L
.12033 .46715 L
.12083 .46635 L
.12129 .4657 L
.12167 .46523 L
.12196 .46492 L
.12215 .46478 L
Mfstroke
.12984 .45825 m
.12997 .45822 L
.13023 .45814 L
.13066 .45799 L
.13126 .45776 L
.13207 .45744 L
.13311 .45706 L
.13433 .45665 L
.13574 .45624 L
.13722 .45581 L
.1389 .45534 L
.14057 .45482 L
.14255 .45427 L
.14425 .4537 L
.14599 .45314 L
.14788 .4526 L
.14968 .45211 L
.15151 .45165 L
.15326 .45124 L
.15468 .45086 L
.15612 .45049 L
.15743 .45014 L
.15868 .44978 L
.15984 .44942 L
.16103 .44917 L
.16218 .44895 L
.16338 .44878 L
.16456 .44865 L
.16574 .44854 L
.16692 .44842 L
.16801 .44827 L
.16913 .44807 L
.17022 .44783 L
.1713 .44754 L
.17232 .44723 L
.1732 .44689 L
.17398 .44658 L
.1746 .44632 L
.17503 .44615 L
.17521 .4461 L
.17513 .4462 L
.17482 .44645 L
.17432 .44686 L
.17373 .44741 L
.17313 .44808 L
.17256 .44883 L
.17209 .44965 L
.17172 .45051 L
.17148 .45145 L
.17137 .45249 L
Mistroke
.17141 .45361 L
.17161 .45481 L
.17197 .45603 L
.17255 .4573 L
.17327 .45862 L
.17414 .45999 L
.17511 .46132 L
.17609 .46268 L
.17702 .46401 L
.17784 .46534 L
.17853 .46657 L
.17912 .46764 L
.17963 .46862 L
.18007 .4695 L
.18047 .47027 L
.18088 .47096 L
.1813 .47158 L
.18176 .47213 L
.18229 .47261 L
.18296 .47306 L
.18379 .47348 L
.18476 .47386 L
.18593 .47423 L
.18727 .47459 L
.18881 .47494 L
.19037 .47525 L
.19207 .47549 L
.19383 .47565 L
.19558 .47574 L
.19725 .47574 L
.1987 .47569 L
.19998 .4756 L
.20097 .47551 L
.20169 .47547 L
.20213 .47549 L
.20231 .47556 L
.20228 .47562 L
.20206 .47566 L
.20173 .47566 L
.20131 .47558 L
.20088 .47545 L
.20041 .47522 L
.19993 .47489 L
.19949 .47448 L
.19912 .47398 L
.19888 .4734 L
.1988 .47278 L
.19891 .47213 L
.19916 .47145 L
.19948 .47079 L
Mistroke
.19982 .47019 L
.20013 .46973 L
.20039 .46944 L
.20057 .46933 L
.20067 .46937 L
.20067 .4695 L
.20053 .46968 L
.2002 .46987 L
.1996 .47 L
.19886 .47001 L
.19792 .46987 L
.19669 .46959 L
.19505 .46914 L
.193 .4685 L
.1913 .46776 L
.18882 .46676 L
.18661 .46574 L
.18354 .46461 L
.18102 .46339 L
.17772 .46219 L
.17532 .46116 L
.17169 .46022 L
.16891 .45943 L
.16534 .4588 L
.16286 .45829 L
.15927 .45789 L
.1566 .45758 L
.15321 .45738 L
.15079 .45728 L
.14761 .45731 L
.14454 .45751 L
.14203 .45787 L
.13853 .4584 L
.13607 .45908 L
.13313 .45993 L
.12994 .46093 L
.12744 .46187 L
.12498 .46294 L
.12308 .46394 L
.12081 .46503 L
.11877 .46633 L
.11731 .46744 L
.11612 .46853 L
.11511 .46959 L
.11434 .4706 L
.11377 .47156 L
.11338 .47243 L
.11311 .47321 L
.11292 .47386 L
.11274 .47444 L
Mistroke
.11262 .47498 L
.11257 .47558 L
.11255 .47602 L
.1125 .47647 L
.11248 .4768 L
.11252 .477 L
Mfstroke
.12323 .39853 m
.12336 .39827 L
.12349 .39785 L
.12364 .39719 L
.12381 .39626 L
.12401 .39501 L
.12424 .39336 L
.12449 .39161 L
.12477 .38924 L
.12508 .3867 L
.12543 .38393 L
.12582 .38074 L
.12625 .37714 L
.12669 .37331 L
.12713 .36908 L
.12759 .36546 L
.12805 .36075 L
.12855 .35697 L
.1291 .35255 L
.12971 .34791 L
.1304 .34344 L
.13109 .33889 L
.13181 .33498 L
.13254 .33072 L
.13327 .32726 L
.1339 .32389 L
.13462 .32072 L
.13523 .3178 L
.13583 .31564 L
.13641 .31359 L
.13696 .31195 L
.13745 .31054 L
.13786 .30943 L
.13819 .30879 L
.13845 .30828 L
.13865 .30794 L
.1388 .30773 L
.13893 .30765 L
.13903 .30759 L
.1391 .30752 L
.13913 .30743 L
.1391 .30731 L
.13905 .30716 L
.13899 .30696 L
.13896 .30672 L
.13898 .3064 L
.13907 .30603 L
.1392 .30563 L
.13938 .30521 L
.13959 .30481 L
Mistroke
.1398 .30445 L
.13997 .30417 L
.14011 .30399 L
.14025 .30383 L
.14042 .3037 L
.14063 .30358 L
.1409 .3034 L
.14124 .3031 L
.14164 .30262 L
.14216 .30188 L
.1428 .30079 L
.14361 .29932 L
.14461 .29759 L
.14565 .29548 L
.14699 .29331 L
.1484 .29075 L
.15002 .28774 L
.15169 .28468 L
.15351 .28173 L
.15522 .27849 L
.15702 .27518 L
.15882 .27185 L
.16052 .26872 L
.16227 .26556 L
.164 .26251 L
.16574 .25941 L
.16762 .25631 L
.16944 .25313 L
.17139 .24982 L
.17335 .24663 L
.17537 .24302 L
.17744 .23968 L
.17956 .23614 L
.18179 .23246 L
.18388 .22905 L
.18604 .2255 L
.1884 .22174 L
.19044 .21843 L
.19268 .2148 L
.19493 .2111 L
.19741 .20751 L
.19956 .20376 L
.20188 .20016 L
.20423 .19659 L
.20647 .19299 L
.2087 .18956 L
.21092 .1861 L
.21302 .18263 L
.21494 .17939 L
.21689 .17603 L
Mistroke
.21875 .17255 L
.22053 .16961 L
.22217 .16662 L
.22379 .16372 L
.22526 .16142 L
.22673 .15912 L
.22799 .15719 L
.22914 .15539 L
.23029 .15387 L
.2312 .15263 L
.23203 .15161 L
.23273 .15085 L
.23328 .15034 L
.23366 .15008 L
.23386 .15004 L
.2339 .15015 L
.23383 .15031 L
.23372 .15043 L
.23366 .15041 L
.23369 .15021 L
.23387 .14979 L
.23422 .14914 L
.23477 .14826 L
.2355 .14721 L
.23643 .14597 L
.23762 .14455 L
.239 .14299 L
.24056 .1413 L
.24243 .13948 L
.24455 .13749 L
.24662 .1355 L
.24908 .13341 L
.25164 .13137 L
.25418 .12935 L
.25696 .12741 L
.25954 .12554 L
.26215 .12394 L
.26462 .1224 L
.26687 .12114 L
.2689 .11999 L
.27067 .11907 L
.27218 .11833 L
.27332 .11778 L
.27423 .11744 L
.27492 .11727 L
.2754 .11723 L
.27571 .11729 L
.27591 .11742 L
.27602 .11758 L
.27608 .11776 L
Mistroke
.27611 .11792 L
.27611 .11806 L
.27611 .11818 L
.27616 .11824 L
.27625 .11824 L
.27638 .11813 L
.27659 .11789 L
.27691 .11747 L
.27741 .11688 L
.27813 .1161 L
.27911 .11515 L
.28038 .11414 L
.28185 .11293 L
.28359 .1115 L
.28575 .11004 L
.2881 .10837 L
.29079 .10653 L
.29402 .1046 L
.2968 .10267 L
.29998 .10058 L
.30346 .09862 L
.30644 .09651 L
.30966 .09452 L
.31278 .09244 L
.31596 .0902 L
.31892 .08812 L
.322 .08581 L
.32529 .08365 L
.32849 .08135 L
.33205 .07893 L
.33548 .07667 L
.33916 .07426 L
.34306 .07187 L
.34689 .06939 L
.3508 .06689 L
.35522 .06421 L
.35896 .06163 L
.36319 .05892 L
.36718 .05627 L
.37141 .0536 L
.37518 .0512 L
.37881 .0489 L
.38222 .0467 L
.38541 .04481 L
.38816 .04328 L
.39063 .04192 L
.39285 .04076 L
.39453 .03986 L
.39603 .0392 L
.39715 .03878 L
Mistroke
.39801 .03855 L
.39861 .03847 L
.39895 .03849 L
.39909 .0386 L
.39909 .03875 L
.39901 .03888 L
.39887 .03896 L
.39871 .039 L
.39856 .03902 L
.39847 .03903 L
.39844 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39842 .03903 L
.39841 .03903 L
.39838 .03903 L
.39833 .03903 L
.39826 .03903 L
.3982 .03902 L
.39813 .03902 L
.39808 .03902 L
.39807 .03902 L
.39814 .03903 L
.39831 .03906 L
.39859 .03911 L
.39901 .0392 L
.3996 .03928 L
.40035 .03934 L
.40131 .03934 L
.40244 .03929 L
.40378 .03916 L
.40527 .03895 L
.40702 .03867 L
.40878 .03834 L
.41079 .03797 L
Mistroke
.41286 .03759 L
.41508 .03721 L
.41709 .03683 L
.41922 .03646 L
.42124 .03612 L
.42316 .03582 L
.42489 .03559 L
.42646 .03544 L
.42783 .03537 L
.429 .03537 L
.42991 .03543 L
.43062 .03552 L
.43115 .03561 L
.43149 .03567 L
.43166 .0357 L
.43172 .03571 L
.43168 .03571 L
.43159 .03571 L
.43149 .0357 L
.43139 .0357 L
.4313 .0357 L
.43124 .03569 L
.4312 .03569 L
.43116 .03569 L
.43113 .03569 L
.43111 .03569 L
.43112 .03569 L
.43117 .03569 L
.43125 .03569 L
.43138 .03569 L
.43155 .03569 L
.43174 .0357 L
.43195 .03571 L
.43218 .03573 L
.43241 .03574 L
.43263 .03576 L
.43285 .03575 L
.43305 .03571 L
.43323 .03565 L
.43337 .03559 L
.43347 .03556 L
.43352 .0356 L
.43354 .03572 L
.43352 .03595 L
.43349 .03628 L
.43346 .03666 L
.43343 .03706 L
.4334 .03745 L
.43337 .03778 L
.43333 .03802 L
Mistroke
.43328 .03818 L
.43322 .03825 L
.43314 .03822 L
.43307 .03808 L
.43303 .03784 L
.43305 .03754 L
.43314 .03722 L
.43335 .0369 L
.43369 .03664 L
.43422 .03651 L
.43496 .03657 L
.43592 .03683 L
.43716 .03723 L
.43861 .0377 L
.4404 .03819 L
.44235 .03867 L
.44461 .03908 L
.4471 .03938 L
.44997 .03953 L
.45256 .03956 L
.45554 .03948 L
.45876 .03929 L
.46165 .03904 L
.46474 .03875 L
.46783 .03844 L
.4712 .03818 L
.47396 .03795 L
.47706 .03779 L
.48034 .03766 L
.48331 .03757 L
.48642 .03742 L
.48951 .03721 L
.49276 .03691 L
.49626 .03655 L
.49943 .03616 L
.50279 .03578 L
.50631 .03547 L
.50952 .03522 L
.51306 .03508 L
.51634 .03504 L
.51982 .03514 L
.52328 .03543 L
.52651 .03589 L
.52992 .0365 L
.53311 .03722 L
.53628 .03808 L
.53949 .03902 L
.54278 .03999 L
.54594 .04091 L
.54909 .04172 L
Mistroke
.55225 .04246 L
.55543 .04314 L
.55855 .04381 L
.56166 .0445 L
.56469 .04523 L
.56773 .04602 L
.57054 .04689 L
.57324 .04782 L
.57579 .04879 L
.57803 .04977 L
.58006 .0506 L
.58181 .05149 L
.58328 .05243 L
.58438 .05323 L
.5852 .05395 L
.58575 .05459 L
.58607 .0551 L
.5862 .05547 L
.58622 .0557 L
.58626 .0558 L
.58641 .0558 L
.58672 .05576 L
.58727 .05574 L
.5881 .05575 L
.58929 .05578 L
.59078 .05582 L
.59273 .05585 L
.59508 .05583 L
.5977 .05574 L
.60064 .05558 L
.60379 .05532 L
.60684 .05498 L
.60993 .05457 L
.61275 .05414 L
.61552 .05374 L
.61787 .05336 L
.62017 .05304 L
.62233 .05284 L
.62416 .05277 L
.62597 .0529 L
.62778 .05325 L
.62965 .05381 L
.63161 .05461 L
.63356 .05556 L
.63564 .0567 L
.63769 .05802 L
.63995 .0594 L
.6424 .06087 L
.6452 .06231 L
.64766 .0637 L
Mistroke
.6503 .06502 L
.65289 .0662 L
.65562 .06719 L
.65805 .06807 L
.66056 .06883 L
.66306 .06946 L
.66559 .07002 L
.66834 .07055 L
.67107 .07107 L
.67398 .0716 L
.67715 .0722 L
.68027 .07288 L
.68355 .07363 L
.68699 .07442 L
.69023 .07534 L
.6936 .07642 L
.69678 .07767 L
.70009 .07895 L
.70303 .08034 L
.70608 .08183 L
.70914 .08332 L
.71191 .08479 L
.71494 .08627 L
.71754 .08754 L
.72001 .08885 L
.72233 .08999 L
.72441 .09104 L
.72638 .09196 L
.7278 .0927 L
.72902 .09324 L
.73 .09355 L
.73069 .09365 L
.7311 .09356 L
.73123 .09331 L
.73114 .09296 L
.73091 .0926 L
.73063 .09232 L
.73035 .09212 L
.7301 .09202 L
.72992 .09204 L
.7299 .09218 L
.73001 .09245 L
.73018 .09282 L
.73038 .09323 L
.73061 .09366 L
.73085 .09408 L
.73108 .09447 L
.73125 .09475 L
.73133 .09492 L
.73131 .09497 L
Mistroke
.73122 .0949 L
.73109 .09476 L
.73095 .09456 L
.73087 .09432 L
.73093 .09412 L
.73117 .09401 L
.73165 .09405 L
.73239 .09426 L
.73341 .09467 L
.73474 .09528 L
.73626 .09606 L
.73796 .09694 L
.73991 .09792 L
.74206 .09901 L
.74441 .10012 L
.74668 .10115 L
.74884 .1021 L
.75093 .10296 L
.75284 .10368 L
.75444 .10426 L
.75582 .10468 L
.75693 .10496 L
.75777 .10513 L
.75842 .1052 L
.75893 .10523 L
.75931 .10522 L
.75959 .10519 L
.75979 .10515 L
.75995 .10512 L
.76005 .10509 L
.76015 .10506 L
.76025 .10504 L
.76036 .105 L
.76047 .10497 L
.76057 .10495 L
.76066 .10495 L
.7607 .10496 L
.7607 .105 L
.76066 .10505 L
.76057 .10512 L
.76044 .10522 L
.7603 .10535 L
.76017 .10552 L
.7601 .10577 L
.76011 .10611 L
.76024 .10651 L
.76051 .10699 L
.76097 .10754 L
.76165 .10813 L
.76255 .10884 L
Mistroke
.76365 .10964 L
.76507 .11058 L
.76667 .11166 L
.76849 .11287 L
.77055 .11423 L
.77279 .1157 L
.77508 .11728 L
.77737 .11892 L
.77959 .12041 L
.78164 .12189 L
.78341 .12315 L
.78502 .12431 L
.78648 .12542 L
.78761 .12637 L
.78857 .12722 L
.78935 .12799 L
.79001 .12881 L
.79057 .12972 L
.79103 .13066 L
.79144 .13166 L
.7918 .13268 L
.79217 .13382 L
.79248 .13485 L
.79271 .13598 L
.79292 .137 L
.79314 .13802 L
.79339 .13914 L
.79369 .14004 L
.79409 .14092 L
.79463 .14178 L
.7954 .14267 L
.79645 .14356 L
.79779 .14452 L
.79928 .14552 L
.80101 .14689 L
.8029 .14846 L
.80489 .15025 L
.80715 .15221 L
.8097 .15438 L
.81192 .15662 L
.8142 .159 L
.81639 .16138 L
.81835 .16383 L
.8201 .16611 L
.82173 .16848 L
.82316 .17071 L
.82447 .17298 L
.82573 .17528 L
.82695 .17749 L
.82815 .17947 L
Mistroke
.82937 .18143 L
.83056 .1833 L
.83177 .18511 L
.83301 .18678 L
.83423 .18843 L
.83551 .19001 L
.83679 .19158 L
.83804 .1931 L
.83936 .19471 L
.84071 .19648 L
.84208 .19829 L
.84359 .2004 L
.84523 .20255 L
.84675 .20501 L
.84842 .20737 L
.85009 .21 L
.8518 .21258 L
.85355 .21519 L
.8551 .21764 L
.8566 .21994 L
.85791 .22202 L
.85902 .22357 L
.85985 .22483 L
.86048 .22579 L
.86086 .22643 L
.86099 .22673 L
.8609 .2267 L
.86064 .22641 L
.86025 .22594 L
.85977 .22536 L
.85927 .22475 L
.85877 .22414 L
.85831 .2236 L
.85792 .22318 L
.85764 .2229 L
.85745 .2227 L
.85735 .22259 L
.8573 .22252 L
.85727 .22248 L
.85726 .22245 L
.85726 .22242 L
.85724 .22239 L
.85719 .22236 L
.85714 .22235 L
.85714 .22243 L
.85726 .22263 L
.8575 .22297 L
.8579 .22348 L
.85846 .22417 L
.85918 .22504 L
Mistroke
.86 .22607 L
.861 .22734 L
.86216 .22879 L
.86342 .2305 L
.86488 .23241 L
.86658 .23465 L
.86811 .23695 L
.86975 .23959 L
.87161 .24227 L
.87362 .24519 L
.87534 .24814 L
.8772 .25129 L
.87906 .25456 L
.88084 .25757 L
.8826 .26072 L
.88436 .26401 L
.88603 .26692 L
.88757 .26971 L
.88912 .27267 L
.89061 .27545 L
.892 .278 L
.89338 .28056 L
.89464 .28311 L
.89585 .28541 L
.89705 .28775 L
.89814 .28978 L
.89916 .29182 L
.90013 .29352 L
.90098 .2951 L
.90176 .29652 L
.9024 .29764 L
.90291 .29853 L
.90329 .29918 L
.90353 .29961 L
.90365 .29983 L
.90367 .29988 L
.90363 .29981 L
.90357 .29969 L
.90349 .29956 L
.90342 .29945 L
.90337 .29937 L
.90334 .29932 L
.90333 .29929 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
Mistroke
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90333 .29928 L
.90332 .29927 L
.90329 .29924 L
.90326 .29921 L
.90324 .29918 L
.90322 .29916 L
.90323 .29917 L
.90327 .29922 L
.90335 .2993 L
.90346 .29942 L
.9036 .29958 L
.90376 .29976 L
.90394 .29997 L
.90413 .30018 L
.90432 .3004 L
.90452 .30061 L
.9047 .30082 L
.90487 .30101 L
.90502 .30118 L
.90514 .30131 L
.90522 .3014 L
.90527 .30145 L
.90528 .30147 L
.90527 .30146 L
.90524 .30143 L
.90521 .30139 L
.90519 .30136 L
.90518 .30135 L
.90517 .30135 L
.90517 .30135 L
.90517 .30135 L
.90517 .30135 L
.90518 .30134 L
.90519 .30133 L
.90521 .30132 L
.90523 .30131 L
.90526 .30131 L
.90528 .30133 L
.90527 .30136 L
.90523 .3014 L
.90516 .30145 L
.90506 .30152 L
.90493 .30159 L
.90478 .30165 L
.9046 .30169 L
.90442 .30168 L
.90424 .30163 L
Mistroke
.90405 .30156 L
.90386 .30143 L
.90369 .30126 L
.90354 .30105 L
.90342 .30081 L
.90333 .30055 L
.90327 .30029 L
.90325 .30003 L
.90325 .29978 L
.90327 .29953 L
.90329 .29927 L
.90329 .29903 L
.90326 .29881 L
.90319 .29866 L
.90311 .2986 L
.90305 .29868 L
.90303 .2989 L
.90307 .2993 L
.90321 .29989 L
.90345 .30068 L
.90382 .30165 L
.9043 .30281 L
.90488 .30404 L
.90555 .3055 L
.90622 .30721 L
.90699 .30906 L
.90773 .31101 L
.90847 .31316 L
.90918 .31527 L
.90983 .31778 L
.91037 .31971 L
.91082 .32204 L
.91119 .32444 L
.91148 .32656 L
.91172 .3287 L
.91193 .33099 L
.91213 .33324 L
.91234 .33538 L
.91255 .33738 L
.91272 .33922 L
.91283 .34075 L
.91291 .34197 L
.91295 .34301 L
.91298 .34388 L
.91298 .34456 L
.91298 .34505 L
.91296 .3454 L
.91294 .34562 L
.91292 .34578 L
.91292 .34587 L
Mistroke
.91294 .34591 L
.91301 .34593 L
.91311 .34599 L
.91325 .34614 L
.91341 .34632 L
.91356 .34647 L
.91366 .34657 L
.9137 .34659 L
.91366 .3465 L
.91355 .3463 L
.91338 .34595 L
.91318 .34544 L
.91298 .3448 L
.91278 .34407 L
.9126 .34331 L
.91242 .34258 L
.91224 .34197 L
.91205 .34151 L
.91185 .34125 L
.91164 .34123 L
.9114 .34147 L
.91114 .34197 L
.91084 .34274 L
.91053 .34373 L
.91021 .34475 L
.90988 .34584 L
.90956 .34694 L
.90928 .34798 L
.90907 .34879 L
.90895 .34936 L
.90894 .34965 L
.90905 .3497 L
.90928 .34954 L
.9096 .34918 L
.90995 .34866 L
.91033 .34801 L
.91068 .34727 L
.91098 .34648 L
.91119 .34573 L
.91134 .34501 L
.91143 .34435 L
.91145 .34374 L
.91142 .34317 L
.91134 .34261 L
.91124 .34208 L
.91114 .34155 L
.91106 .34099 L
.91101 .34038 L
.91103 .33973 L
.9111 .33905 L
Mistroke
.91126 .33831 L
.91149 .33753 L
.91176 .33666 L
.91206 .33572 L
.91235 .33469 L
.91263 .33364 L
.91287 .33249 L
.91305 .33134 L
.91318 .33017 L
.91325 .32901 L
.91325 .32788 L
.9132 .32675 L
.91309 .32568 L
.91293 .3246 L
.91272 .32354 L
.91249 .32255 L
.91224 .32165 L
.91201 .32089 L
.9118 .32015 L
.91161 .31944 L
.91145 .31873 L
.91131 .31799 L
.91119 .31725 L
.91107 .31646 L
.91096 .31564 L
.91084 .31483 L
.91073 .31405 L
.91059 .31333 L
.91044 .3127 L
.91027 .31208 L
.91008 .3115 L
.90988 .31097 L
.90968 .31051 L
.90949 .31011 L
.90931 .30977 L
.90916 .30953 L
.90904 .30938 L
.90894 .30932 L
.90888 .30932 L
.90884 .30937 L
.90882 .30944 L
.90884 .30949 L
.90888 .30953 L
.90894 .30956 L
.90902 .30957 L
.90913 .30957 L
.90926 .30957 L
.90942 .30958 L
.90959 .30958 L
.90978 .30958 L
Mistroke
.90996 .30958 L
.91014 .30958 L
.91032 .30958 L
.91048 .30958 L
.91063 .30958 L
.91074 .30958 L
.91082 .30958 L
.91087 .30958 L
.91088 .30958 L
.91087 .30958 L
.91084 .30958 L
.91081 .30958 L
.91079 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91078 .30958 L
.91079 .30957 L
.9108 .30954 L
.91083 .3095 L
.91086 .30946 L
.91087 .30945 L
.91086 .30948 L
.91083 .30954 L
Mistroke
.91077 .30964 L
.91067 .30979 L
.91055 .30997 L
.9104 .31018 L
.91024 .3104 L
.91006 .31061 L
.90989 .31084 L
.90971 .31104 L
.90954 .31123 L
.90939 .31142 L
.90925 .31158 L
.90913 .3117 L
.90905 .31177 L
.909 .31179 L
.90899 .31177 L
.90899 .31173 L
.90902 .31168 L
.90904 .31162 L
.90906 .3116 L
.90908 .31161 L
.90908 .31165 L
.90908 .31169 L
.90909 .31172 L
.90909 .31174 L
.90909 .31173 L
.90908 .31169 L
.90908 .31161 L
.90908 .31149 L
.90907 .31134 L
.90907 .31118 L
.90906 .31103 L
.90905 .31089 L
.90905 .31073 L
.90905 .31055 L
.90907 .31035 L
.90911 .31011 L
.90916 .30985 L
.9092 .30955 L
.90923 .3092 L
.90923 .30879 L
.90916 .30833 L
.909 .30776 L
.90874 .30708 L
.90836 .30631 L
.90788 .30546 L
.90732 .30456 L
.90669 .30365 L
.90611 .3028 L
.90547 .30201 L
.90479 .3013 L
Mistroke
.90404 .30068 L
.90344 .30017 L
.9029 .29977 L
.90243 .29947 L
.90207 .29929 L
.90188 .29922 L
.90189 .29926 L
.90202 .29948 L
.90223 .29972 L
.90248 .29995 L
.90269 .30015 L
.9028 .30032 L
.9028 .30051 L
.90267 .30072 L
.90242 .30097 L
.90199 .30129 L
.90138 .30168 L
.90064 .30213 L
.89988 .30263 L
.89908 .30314 L
.89822 .30363 L
.89734 .30404 L
.89657 .3044 L
.89617 .30464 L
.89592 .30474 L
.89589 .30467 L
.89607 .30448 L
.89639 .30417 L
.89677 .3038 L
.8973 .30342 L
.89798 .30311 L
.8986 .30293 L
.89924 .30298 L
.89993 .30331 L
.90053 .30396 L
.90108 .30495 L
.90162 .30622 L
.90221 .30778 L
.90285 .30974 L
.90354 .31202 L
.90427 .31451 L
.90515 .31722 L
.90615 .3199 L
.90712 .32281 L
.90828 .32583 L
.90953 .32903 L
.91071 .33242 L
.91197 .3358 L
.91319 .33942 L
.91434 .34332 L
Mistroke
.91536 .34691 L
.91629 .35066 L
.91711 .35486 L
.91785 .35824 L
.91854 .36225 L
.91915 .36574 L
.91973 .36953 L
.92027 .37338 L
.92075 .377 L
.92116 .38071 L
.92152 .38457 L
.92183 .38827 L
.92211 .39189 L
.92235 .39571 L
.92258 .39939 L
.92278 .40326 L
.92297 .40685 L
.92314 .41047 L
.92331 .41387 L
.92347 .41718 L
.92363 .42041 L
.92382 .42341 L
.92402 .42649 L
.92425 .42924 L
.92451 .43193 L
.92479 .43466 L
.92505 .43705 L
.92532 .43942 L
.92557 .44152 L
.92579 .4433 L
.92598 .44482 L
.92613 .44591 L
.92624 .44667 L
.9263 .44706 L
.92631 .4471 L
.92629 .44682 L
.92624 .44629 L
.92619 .44561 L
.92614 .44484 L
.9261 .44403 L
.92607 .44328 L
.92605 .44261 L
.92603 .44207 L
.92602 .44167 L
.92603 .44143 L
.92607 .4413 L
.92612 .44127 L
.92617 .44131 L
.9262 .44139 L
.92618 .44148 L
Mistroke
.92611 .44154 L
.92596 .44158 L
.92573 .4416 L
.92542 .44161 L
.92508 .44161 L
.92472 .44162 L
.92437 .44163 L
.92406 .44164 L
.92378 .44164 L
.92355 .4416 L
.92338 .44152 L
.92328 .44142 L
.92326 .44128 L
.92333 .44113 L
.92347 .44102 L
.92364 .44097 L
.9238 .44105 L
.92391 .44134 L
.92395 .4419 L
.92386 .44274 L
.92363 .44391 L
.9233 .44542 L
.9229 .44708 L
.92243 .44907 L
.9219 .45134 L
.92136 .45369 L
.92086 .456 L
.9204 .45856 L
.92001 .46157 L
.91972 .46412 L
.91954 .46673 L
.91951 .46946 L
.91962 .47227 L
.91988 .47481 L
.92026 .4776 L
.9207 .48035 L
.92123 .48323 L
.92179 .48634 L
.92237 .48927 L
.92299 .49234 L
.9236 .4951 L
.92421 .49776 L
.92485 .50013 L
.92544 .50212 L
.92603 .5038 L
.9266 .50527 L
.92715 .50657 L
.92769 .50768 L
.92821 .50878 L
.92876 .5099 L
Mistroke
.92931 .51103 L
.92987 .51238 L
.93046 .51397 L
.93106 .51573 L
.93167 .51792 L
.93226 .52036 L
.9328 .52324 L
.93327 .52617 L
.93364 .52954 L
.9339 .5325 L
.93405 .53564 L
.93408 .53877 L
.93402 .54166 L
.93388 .54448 L
.93367 .54691 L
.93343 .54916 L
.93317 .55106 L
.93292 .55274 L
.93269 .55413 L
.93251 .55519 L
.93238 .55597 L
.93231 .55649 L
.93231 .55675 L
.93237 .5568 L
.93249 .55667 L
.93268 .55639 L
.9329 .55604 L
.93312 .55568 L
.93331 .55537 L
.93343 .55516 L
.93346 .55508 L
.93337 .55517 L
.93319 .55548 L
.93292 .55601 L
.93258 .55682 L
.93218 .55792 L
.9317 .55933 L
.93116 .56094 L
.93055 .56281 L
.92986 .56495 L
.92909 .5672 L
.92827 .56978 L
.92748 .57228 L
.92665 .57504 L
.92593 .57785 L
.92521 .58087 L
.92459 .58372 L
.92401 .58677 L
.92343 .58973 L
.92287 .59276 L
Mistroke
.92231 .59569 L
.92173 .59859 L
.92114 .6014 L
.92058 .60397 L
.92004 .60632 L
.91954 .60842 L
.9191 .61022 L
.91872 .6118 L
.91838 .61299 L
.91811 .6139 L
.91792 .61455 L
.91782 .61492 L
.91784 .61505 L
.91795 .61498 L
.91813 .61478 L
.91837 .61454 L
.91862 .61433 L
.91884 .61422 L
.919 .61424 L
.91906 .61443 L
.91899 .61478 L
.91875 .61532 L
.91833 .61604 L
.91772 .61697 L
.91694 .61809 L
.91604 .6194 L
.91497 .62089 L
.91367 .62252 L
.91247 .62417 L
.91111 .62584 L
.90972 .62755 L
.90866 .6292 L
.90741 .63109 L
.90645 .6328 L
.90558 .63458 L
.9048 .63648 L
.90415 .63851 L
.90368 .64067 L
.90339 .64273 L
.90321 .645 L
.90307 .64755 L
.90294 .65005 L
.90281 .65283 L
.90263 .65582 L
.90234 .65886 L
.90194 .66218 L
.90148 .66515 L
.90104 .66801 L
.90061 .67063 L
.90021 .67294 L
Mistroke
.89985 .675 L
.89955 .67666 L
.89931 .67808 L
.89914 .67922 L
.89902 .68003 L
.89896 .68054 L
.89895 .68076 L
.89897 .68076 L
.89903 .6806 L
.89912 .68035 L
.89922 .68008 L
.8993 .67985 L
.89933 .6797 L
.89929 .67968 L
.89917 .67977 L
.89897 .67996 L
.8987 .68021 L
.8984 .68051 L
.8981 .68083 L
.89781 .68116 L
.89756 .68146 L
.89733 .68176 L
.89712 .68208 L
.89693 .68246 L
.89675 .68292 L
.89661 .6835 L
.89651 .68422 L
.89646 .68514 L
.89642 .68634 L
.89633 .68794 L
.89618 .68984 L
.89591 .69218 L
.89548 .69505 L
.89486 .69821 L
.89404 .70167 L
.89305 .70577 L
.89197 .70975 L
.89079 .71392 L
.88957 .71845 L
.88834 .72244 L
.88704 .72703 L
.88573 .731 L
.88437 .7353 L
.88302 .73938 L
.88165 .74357 L
.88031 .74758 L
.87899 .75174 L
.87777 .75522 L
.87659 .75878 L
.87548 .76224 L
Mistroke
.87441 .76526 L
.8734 .76834 L
.87245 .77092 L
.87153 .77339 L
.87064 .77572 L
.86984 .77767 L
.86908 .77947 L
.86839 .78098 L
.86783 .78217 L
.86741 .78301 L
.86705 .78374 L
.86672 .78436 L
.86638 .78498 L
.86611 .78548 L
.86581 .78598 L
.86554 .78644 L
.86535 .78682 L
.86522 .78712 L
.86511 .78734 L
.86503 .78748 L
.86491 .78758 L
.86474 .78774 L
.86444 .78799 L
.86404 .78832 L
.86358 .78871 L
.86309 .78913 L
.86262 .7895 L
.8622 .78979 L
.86187 .78997 L
.86162 .79007 L
.86145 .79013 L
.86131 .79017 L
.86121 .79022 L
.86116 .79028 L
.86115 .79035 L
.86126 .79037 L
.86145 .79035 L
.86171 .79026 L
.86198 .79014 L
.86222 .78998 L
.86241 .78981 L
.86255 .7896 L
.86262 .78945 L
.86267 .78931 L
.86268 .78924 L
.86265 .78922 L
.86259 .78925 L
.86252 .78928 L
.86241 .78936 L
.86226 .7895 L
Mistroke
.86206 .7897 L
.86182 .78995 L
.86154 .79024 L
.86124 .79056 L
.86091 .7909 L
.86058 .7912 L
.86031 .7914 L
.86016 .79147 L
.86005 .79149 L
.85991 .79155 L
.85972 .79166 L
.85946 .79187 L
.8591 .79219 L
.85864 .79263 L
.85805 .79321 L
.85732 .79393 L
.85648 .79477 L
.85557 .79572 L
.85458 .79676 L
.85363 .79778 L
.85258 .79865 L
.8514 .79987 L
.85017 .80115 L
.84894 .80236 L
.84778 .8034 L
.84674 .80424 L
.84585 .8049 L
.84507 .80543 L
.84437 .80586 L
.84373 .80623 L
.84314 .80655 L
.84254 .80687 L
.84203 .80713 L
.84163 .80731 L
.84139 .80735 L
.84128 .80726 L
.84131 .80707 L
.8414 .80684 L
.84151 .80664 L
.84163 .80649 L
.84175 .80635 L
.84186 .80626 L
.84196 .80619 L
.842 .80616 L
.84201 .80624 L
.84199 .80638 L
.84193 .80661 L
.84182 .80693 L
.84162 .80739 L
.84132 .80794 L
Mistroke
.84095 .80854 L
.84058 .80897 L
.8402 .80931 L
.83979 .80958 L
.83931 .80983 L
.83889 .81004 L
.83842 .81025 L
.83796 .81047 L
.83749 .81067 L
.83702 .8109 L
.83656 .81114 L
.8361 .81141 L
.83563 .81172 L
.83504 .81211 L
.83445 .81262 L
.83384 .81323 L
.83308 .81402 L
.83227 .81496 L
.83141 .81595 L
.83063 .81686 L
.82977 .81774 L
.82893 .81852 L
.82815 .81921 L
.82738 .81985 L
.82681 .82044 L
.82629 .82098 L
.8259 .82143 L
.82569 .82174 L
.82563 .82191 L
.8257 .82196 L
.82587 .82193 L
.82605 .82186 L
.82622 .82177 L
.82636 .82165 L
.82647 .82151 L
.82653 .82135 L
.8265 .82114 L
.8264 .82087 L
.82622 .82056 L
.82596 .82022 L
.82565 .81985 L
.82529 .81948 L
.82496 .81912 L
.82468 .81875 L
.82452 .81839 L
.82449 .81806 L
.8246 .81776 L
.82482 .81751 L
.82512 .81732 L
.82548 .81719 L
Mistroke
.82592 .81714 L
.8264 .81714 L
.8269 .81718 L
.82742 .81719 L
.82796 .81715 L
.8285 .81701 L
.82906 .81675 L
.82964 .81639 L
.83022 .8159 L
.83083 .81526 L
.83156 .81445 L
.83248 .81345 L
.8336 .81229 L
.835 .81101 L
.83664 .80957 L
.8385 .80801 L
.84064 .80636 L
.84286 .80466 L
.84527 .8029 L
.84781 .80112 L
.85027 .7993 L
.8527 .79755 L
.85521 .79577 L
.85737 .794 L
.85954 .79237 L
.86149 .79073 L
.86325 .78915 L
.8648 .78756 L
.86619 .78603 L
.86728 .78456 L
.86823 .78312 L
.86903 .78177 L
.86967 .78053 L
.87019 .77936 L
.8706 .77826 L
.87089 .77727 L
.87107 .77627 L
.87116 .77535 L
.87117 .77437 L
.87109 .77349 L
.87096 .77262 L
.8708 .77179 L
.87063 .77101 L
.87047 .77036 L
.87032 .76979 L
.87019 .76932 L
.8701 .76894 L
.87006 .76865 L
.87006 .76848 L
.87011 .76843 L
Mistroke
.87022 .76852 L
.87039 .76869 L
.87063 .76894 L
.87095 .76918 L
.87138 .76934 L
.87179 .76936 L
.8723 .76916 L
.87288 .76865 L
.87354 .76779 L
.8743 .76654 L
.87514 .76493 L
.87609 .76288 L
.8771 .76042 L
.87821 .75735 L
.87931 .75451 L
.8805 .75083 L
.88164 .74763 L
.88283 .74372 L
.88406 .73968 L
.88523 .736 L
.88643 .73226 L
.88757 .72851 L
.88867 .72487 L
.8897 .72137 L
.89066 .71809 L
.89146 .71507 L
.89218 .71241 L
.89281 .70987 L
.89334 .70785 L
.89377 .70603 L
.89409 .70448 L
.89433 .70332 L
.89449 .70247 L
.89459 .7019 L
.89463 .70158 L
.89462 .70144 L
.89454 .70142 L
.89441 .70145 L
.89422 .70144 L
.89396 .70134 L
.89361 .70111 L
.89319 .70074 L
.8927 .70028 L
.89214 .69972 L
.89159 .69911 L
.891 .69848 L
.89042 .6979 L
.88987 .69737 L
.88941 .69692 L
.88906 .69656 L
Mistroke
.88885 .6963 L
.8888 .69613 L
.88889 .69605 L
.88911 .69604 L
.88944 .69608 L
.88983 .69613 L
.89027 .69617 L
.89071 .69616 L
.89113 .6961 L
.89151 .69601 L
.89183 .69591 L
.89208 .69581 L
.89223 .69573 L
.89229 .69569 L
.89227 .69571 L
.89218 .69578 L
.89204 .69593 L
.89187 .69615 L
.89167 .6964 L
.89146 .69669 L
.89124 .69692 L
.891 .69717 L
.89074 .69743 L
.89046 .69771 L
.89014 .69802 L
.88981 .69836 L
.88947 .69872 L
.88915 .69912 L
.88882 .69952 L
.8885 .69995 L
.88819 .70039 L
.88789 .70082 L
.88758 .70128 L
.88729 .70171 L
.88701 .70206 L
.88678 .70232 L
.8866 .70247 L
.8865 .70251 L
.88648 .70245 L
.88654 .70227 L
.88668 .70196 L
.8869 .70148 L
.88716 .70088 L
.88751 .70012 L
.88793 .69919 L
.88841 .69808 L
.88901 .69671 L
.88967 .69509 L
.89042 .69319 L
.89129 .69112 L
Mistroke
.89222 .68872 L
.89325 .68612 L
.89426 .6833 L
.8953 .68016 L
.89635 .67717 L
.89734 .67387 L
.89836 .6706 L
.89931 .66719 L
.90032 .66384 L
.90124 .66039 L
.90231 .6569 L
.90331 .65346 L
.90442 .64988 L
.90567 .6463 L
.90685 .64268 L
.90809 .63893 L
.90952 .63523 L
.91066 .63149 L
.91212 .62765 L
.91351 .62379 L
.9148 .61998 L
.91625 .61606 L
.91766 .61212 L
.91894 .6082 L
.92014 .60436 L
.92126 .6006 L
.92222 .59683 L
.92316 .59309 L
.92404 .58944 L
.92487 .58576 L
.92577 .58195 L
.92666 .57851 L
.9276 .57485 L
.92849 .57121 L
.92937 .56733 L
.93015 .56383 L
.93088 .5601 L
.93149 .55617 L
.93198 .55253 L
.93238 .5486 L
.93269 .54465 L
.93291 .54036 L
.93301 .53651 L
.93302 .53228 L
.93293 .52791 L
.93275 .52362 L
.93253 .51929 L
.9323 .51494 L
.93205 .51042 L
.93182 .50629 L
Mistroke
.93162 .50184 L
.93143 .49739 L
.93122 .49306 L
.93098 .48888 L
.93071 .48443 L
.9304 .48001 L
.93007 .47549 L
.92972 .47124 L
.92939 .46728 L
.92906 .46351 L
.92876 .45972 L
.92846 .45642 L
.92818 .45327 L
.92788 .44992 L
.92758 .44734 L
.92728 .44494 L
.92697 .44263 L
.92665 .4404 L
.92633 .43828 L
.92601 .43635 L
.92567 .43437 L
.92531 .43221 L
.92495 .4299 L
.9246 .42742 L
.92426 .42471 L
.92394 .4218 L
.92366 .4187 L
.92341 .41539 L
.92321 .41193 L
.92304 .40858 L
.92286 .40493 L
.92265 .40119 L
.92239 .39742 L
.92206 .39335 L
.92166 .38926 L
.9212 .38503 L
.92066 .38037 L
.92007 .37619 L
.91942 .3717 L
.91875 .36712 L
.91807 .36258 L
.91739 .35804 L
.91673 .35367 L
.9161 .34954 L
.9155 .34558 L
.91492 .34186 L
.91439 .33843 L
.91388 .33536 L
.91342 .33263 L
.913 .33031 L
Mistroke
.91263 .32831 L
.91231 .32668 L
.91203 .32535 L
.9118 .32431 L
.9116 .32351 L
.91145 .32289 L
.91134 .32239 L
.91127 .32192 L
.91123 .32145 L
.9112 .32097 L
.91119 .32046 L
.91118 .31982 L
.91118 .31904 L
.91115 .31809 L
.91107 .31701 L
.91092 .31576 L
.91069 .31431 L
.91036 .31273 L
.90992 .31095 L
.90939 .30903 L
.90875 .30697 L
.908 .30489 L
.90716 .30266 L
.90618 .30031 L
.90509 .2978 L
.90375 .29505 L
.90241 .2923 L
.90087 .28927 L
.89918 .28605 L
.89737 .28266 L
.89534 .27919 L
.89342 .27559 L
.89134 .27205 L
.88904 .26837 L
.88704 .26491 L
.88481 .26123 L
.88244 .25743 L
.88021 .25382 L
.8779 .25014 L
.87563 .2465 L
.87322 .243 L
.87111 .23976 L
.86894 .23641 L
.86686 .23321 L
.86463 .2299 L
.86258 .22684 L
.86045 .22364 L
.85836 .22042 L
.8563 .21723 L
.85431 .21415 L
Mistroke
.85238 .21102 L
.8504 .20782 L
.84853 .20497 L
.84656 .20177 L
.84452 .19851 L
.84255 .19549 L
.84045 .19254 L
.83822 .1892 L
.83618 .18609 L
.83395 .18294 L
.83176 .17976 L
.82952 .17668 L
.82723 .17348 L
.82508 .1705 L
.8229 .16744 L
.82078 .16441 L
.81872 .16153 L
.81679 .15867 L
.81491 .15598 L
.81304 .1532 L
.81123 .15071 L
.80935 .14807 L
.80747 .14553 L
.8056 .14293 L
.80369 .14041 L
.80185 .13794 L
.80003 .13546 L
.79834 .13338 L
.79675 .13146 L
.7953 .12968 L
.79403 .12807 L
.793 .12681 L
.79218 .12577 L
.79161 .12498 L
.79128 .12446 L
.79118 .12415 L
.79124 .12403 L
.79143 .12405 L
.79171 .12417 L
.79203 .12431 L
.79235 .12443 L
.79264 .12454 L
.79288 .12464 L
.79308 .12471 L
.79323 .12476 L
.79336 .1248 L
.79344 .12484 L
.7935 .12488 L
.79351 .1249 L
.7935 .12492 L
Mistroke
.79347 .12493 L
.79344 .12493 L
.79342 .12493 L
.7934 .12492 L
.7934 .12489 L
.7934 .12482 L
.79339 .12475 L
.79339 .12469 L
.79339 .12465 L
.79339 .12464 L
.7934 .12467 L
.79341 .12475 L
.79342 .12489 L
.79343 .12509 L
.79342 .12534 L
.79341 .12561 L
.79339 .12586 L
.79336 .12608 L
.79334 .12626 L
.79331 .12638 L
.79329 .12645 L
.79328 .12644 L
.79327 .12638 L
.79326 .12628 L
.79326 .12608 L
.79326 .12588 L
.79329 .12563 L
.79334 .12538 L
.79342 .12514 L
.79351 .12494 L
.79357 .12479 L
.79359 .12468 L
.79356 .12458 L
.79349 .1245 L
.79337 .12445 L
.79319 .12442 L
.79292 .12441 L
.79254 .12442 L
.79204 .12447 L
.7914 .12459 L
.79064 .1248 L
.78977 .12509 L
.78882 .12548 L
.78782 .12595 L
.78681 .12649 L
.78591 .12709 L
.78501 .12775 L
.78425 .12842 L
.7836 .12906 L
.78308 .12962 L
Mistroke
.78269 .13006 L
.78244 .13033 L
.78231 .13039 L
.78229 .13024 L
.78233 .12987 L
.7824 .12929 L
.78243 .12853 L
.7823 .12755 L
.78197 .12631 L
.7814 .12497 L
.78059 .12341 L
.77956 .12168 L
.77831 .11992 L
.77679 .11797 L
.77514 .11621 L
.77337 .11439 L
.77145 .11263 L
.7695 .11102 L
.76712 .10932 L
.76508 .10794 L
.763 .1066 L
.76073 .10529 L
.75828 .10401 L
.75565 .10277 L
.75267 .10148 L
.74995 .10014 L
.74681 .09886 L
.74352 .09742 L
.74003 .09584 L
.73635 .09434 L
.73245 .09262 L
.72797 .09076 L
.72411 .08883 L
.71942 .08669 L
.71531 .08488 L
.71174 .08304 L
.70749 .08113 L
.70374 .07942 L
.69981 .07769 L
.69626 .07626 L
.69257 .07468 L
.68929 .07337 L
.68587 .07208 L
.68313 .07082 L
.68041 .06966 L
.67775 .06859 L
.6757 .06764 L
.67387 .06683 L
.67233 .0662 L
.67116 .06568 L
Mistroke
.67027 .06527 L
.66965 .06492 L
.66928 .06464 L
.6691 .06443 L
.6691 .06431 L
.6692 .06425 L
.66934 .06426 L
.66949 .06431 L
.6696 .06438 L
.66968 .06445 L
.66973 .0645 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66976 .06453 L
.66977 .06453 L
.66981 .06454 L
.66989 .06456 L
.67001 .06461 L
.67012 .06468 L
.67018 .06474 L
.67016 .06477 L
.67003 .06475 L
.66979 .06465 L
.6694 .06448 L
.66887 .06421 L
Mistroke
.6682 .06388 L
.66739 .06348 L
.66645 .06303 L
.6655 .06257 L
.66442 .06211 L
.66335 .06165 L
.66226 .0612 L
.6612 .06077 L
.66023 .06039 L
.65944 .06009 L
.65886 .05988 L
.65845 .05975 L
.65819 .05971 L
.658 .05973 L
.65784 .05978 L
.65764 .05984 L
.65735 .0599 L
.65697 .05993 L
.65651 .05996 L
.65602 .05997 L
.65553 .05997 L
.65508 .05994 L
.65465 .05988 L
.65422 .05978 L
.65379 .05964 L
.65337 .05947 L
.65297 .05927 L
.6526 .05905 L
.65228 .05882 L
.65201 .0586 L
.65178 .05837 L
.65159 .05815 L
.65142 .05795 L
.65125 .05778 L
.65101 .05764 L
.65069 .05753 L
.65034 .05747 L
.65001 .05744 L
.64972 .05744 L
.64949 .05746 L
.64934 .05749 L
.64927 .05752 L
.64928 .05753 L
.64935 .05754 L
.64946 .05754 L
.64959 .05755 L
.64973 .05755 L
.64989 .05756 L
.65006 .05756 L
.65026 .05757 L
Mistroke
.65047 .05758 L
.65068 .05759 L
.65089 .05759 L
.6511 .0576 L
.65128 .05761 L
.65144 .05761 L
.65157 .05762 L
.65166 .05762 L
.65172 .05762 L
.65173 .05762 L
.65172 .05762 L
.65169 .05762 L
.65165 .05762 L
.65163 .05762 L
.65161 .05762 L
.65161 .05762 L
.65161 .05762 L
.65164 .0576 L
.65169 .05756 L
.65175 .05748 L
.65181 .05739 L
.65184 .05732 L
.65182 .0573 L
.65174 .05735 L
.6516 .05751 L
.6514 .05781 L
.65113 .05823 L
.65078 .05874 L
.65035 .05934 L
.64984 .06002 L
.64929 .06069 L
.64872 .06142 L
.64817 .06203 L
.64769 .06254 L
.64729 .06294 L
.64701 .06321 L
.64687 .06334 L
.64686 .06335 L
.64695 .06324 L
.64709 .06305 L
.64724 .0628 L
.64743 .06254 L
.64768 .06235 L
.64799 .06225 L
.64841 .06227 L
.649 .06255 L
.64981 .0628 L
.65082 .06317 L
.65205 .06367 L
.65345 .0643 L
Mistroke
.65512 .06498 L
.6569 .06567 L
.65876 .06635 L
.66095 .06697 L
.66314 .06753 L
.66568 .06801 L
.66794 .06847 L
.6703 .06893 L
.67258 .0694 L
.67476 .06988 L
.67678 .07036 L
.67866 .07086 L
.6804 .07138 L
.68205 .07193 L
.68353 .0725 L
.68489 .07309 L
.68615 .07365 L
.68725 .07417 L
.68819 .07463 L
.68892 .07503 L
.68948 .07536 L
.68987 .07561 L
.69011 .07578 L
.69022 .07587 L
.69024 .0759 L
.6902 .07587 L
.69011 .07581 L
.69002 .07572 L
.68993 .07562 L
.68983 .07554 L
.68975 .07547 L
.6897 .07543 L
.68968 .07545 L
.68973 .07554 L
.68983 .07573 L
.68999 .07603 L
.6902 .07641 L
.69045 .07682 L
.69072 .07722 L
.69101 .07757 L
.6913 .07787 L
.69161 .0781 L
.69193 .07827 L
.69222 .07839 L
.69245 .07842 L
.69261 .07834 L
.69267 .07813 L
.69261 .0778 L
.69245 .07733 L
.69215 .07675 L
Mistroke
.69171 .0761 L
.69108 .07543 L
.69023 .07473 L
.68916 .07401 L
.68781 .07325 L
.68625 .07245 L
.68438 .07154 L
.68215 .07051 L
.6799 .06941 L
.67712 .06816 L
.67427 .06676 L
.67122 .06542 L
.66747 .06372 L
.6643 .06228 L
.66062 .06079 L
.65681 .05913 L
.65258 .05735 L
.64869 .05578 L
.64459 .05424 L
.64002 .05239 L
.63618 .05091 L
.63155 .0494 L
.62758 .0478 L
.62273 .04625 L
.61895 .04467 L
.61464 .04312 L
.61079 .04191 L
.60695 .04071 L
.60351 .0396 L
.60042 .03874 L
.59763 .03796 L
.59512 .03729 L
.59286 .03677 L
.59132 .03641 L
.58997 .03619 L
.58893 .03609 L
.58817 .03609 L
.58768 .03614 L
.58742 .03623 L
.58734 .03632 L
.58739 .03639 L
.58755 .03643 L
.5878 .03645 L
.58809 .03646 L
.58838 .03647 L
.58863 .03648 L
.58885 .03648 L
.58907 .03649 L
.58929 .0365 L
.5895 .03651 L
Mistroke
.58971 .03651 L
.5899 .03652 L
.59007 .03653 L
.5902 .03653 L
.59029 .03653 L
.59034 .03654 L
.59036 .03654 L
.59035 .03654 L
.59032 .03653 L
.59028 .03653 L
.59025 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
Mistroke
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59024 .03653 L
.59026 .03653 L
.59031 .03653 L
.59038 .03654 L
.59044 .03654 L
.59047 .03654 L
.59046 .03654 L
.59041 .03654 L
.59032 .03653 L
.59018 .03653 L
.58996 .03652 L
.58965 .03651 L
.58925 .0365 L
.58874 .03648 L
.58812 .03646 L
.58743 .03643 L
.58665 .03641 L
.5858 .03638 L
.58486 .03634 L
.58382 .03631 L
.58272 .03627 L
.58158 .03623 L
.5804 .03618 L
.57919 .03614 L
.57798 .0361 L
.57683 .03606 L
.57567 .03602 L
.57449 .03598 L
.57322 .03594 L
.572 .0359 L
.5707 .03586 L
.56933 .03581 L
.56789 .03576 L
.56639 .03571 L
.56492 .03566 L
.56375 .03562 L
.56257 .03558 L
.56146 .03554 L
.56062 .03552 L
Mistroke
.55982 .03552 L
.55907 .03553 L
.55839 .03553 L
.55777 .03552 L
.55711 .03546 L
.55632 .03536 L
.55529 .03522 L
.55395 .03504 L
.55232 .03485 L
.55008 .03464 L
.54725 .03444 L
.54457 .03426 L
.54103 .03406 L
.53672 .0339 L
.53302 .03376 L
.52849 .03363 L
.52405 .03354 L
.52023 .03348 L
.516 .03346 L
.5125 .03347 L
.50897 .03352 L
.50627 .03357 L
.50387 .03362 L
.50188 .03365 L
.50042 .03365 L
.49923 .03361 L
.49833 .03355 L
.49769 .03349 L
.49719 .03345 L
.49675 .03343 L
.4963 .03341 L
.49585 .0334 L
.49537 .03338 L
.49485 .03337 L
.49433 .03335 L
.49378 .03333 L
.4932 .03331 L
.49262 .03329 L
.49211 .03328 L
.49171 .03326 L
.49143 .03326 L
.49127 .03325 L
.49123 .03325 L
.49127 .03325 L
.49136 .03325 L
.49147 .03326 L
.49157 .03326 L
.49166 .03326 L
.49174 .03327 L
.49181 .03327 L
Mistroke
.49189 .03327 L
.49198 .03327 L
.49203 .03328 L
.49202 .03328 L
.4919 .03327 L
.49164 .03326 L
.49117 .03325 L
.49045 .03323 L
.48946 .0332 L
.48824 .03316 L
.48678 .03311 L
.48507 .03306 L
.48317 .033 L
.4814 .03294 L
.47942 .03287 L
.47762 .03281 L
.47585 .03275 L
.47419 .0327 L
.47288 .03266 L
.4718 .0326 L
.47099 .03252 L
.47042 .03244 L
.47006 .03236 L
.46984 .03233 L
.46973 .03235 L
.46965 .03244 L
.46953 .03261 L
.46936 .03286 L
.46913 .03318 L
.46883 .03356 L
.46842 .03397 L
.46793 .0344 L
.46739 .03483 L
.46683 .03525 L
.46627 .03566 L
.46573 .03605 L
.46525 .03638 L
.46487 .03665 L
.46461 .03684 L
.46446 .03694 L
.46439 .03698 L
.46436 .03697 L
.46435 .03693 L
.4643 .03687 L
.46418 .03679 L
.46397 .03673 L
.46362 .03666 L
.46303 .03659 L
.46217 .03649 L
.46098 .0364 L
Mistroke
.45946 .0363 L
.45758 .0362 L
.45524 .03611 L
.45266 .03601 L
.44958 .03591 L
.44647 .03581 L
.44312 .0357 L
.43961 .03557 L
.43578 .03543 L
.43246 .03531 L
.42879 .03521 L
.42533 .03515 L
.42185 .03513 L
.41871 .03518 L
.41537 .03531 L
.41234 .03552 L
.40924 .03585 L
.40628 .03632 L
.40322 .03693 L
.40055 .03763 L
.39798 .03839 L
.39545 .03922 L
.39327 .0401 L
.39113 .041 L
.38933 .04193 L
.38765 .04286 L
.38623 .04373 L
.385 .04456 L
.38398 .04535 L
.38316 .04608 L
.38255 .04674 L
.38209 .04734 L
.38174 .04784 L
.38147 .04829 L
.38124 .04867 L
.38103 .04899 L
.38084 .04926 L
.38068 .04946 L
.38059 .04961 L
.38055 .0497 L
.38057 .04973 L
.38062 .0497 L
.38069 .04963 L
.38074 .04956 L
.38077 .04951 L
.38078 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
Mistroke
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38079 .04948 L
.38082 .04948 L
.38087 .04948 L
.38095 .04948 L
.38106 .04947 L
.38121 .04942 L
.38134 .04932 L
.38143 .04919 L
.38143 .04905 L
.38131 .04893 L
.38102 .04886 L
.3805 .04888 L
.37971 .04906 L
.37859 .04946 L
.37714 .0501 L
.37529 .05103 L
.37297 .05224 L
.3705 .05361 L
.36753 .05517 L
.36439 .05704 L
.3609 .05906 L
.35737 .06124 L
.35344 .06366 L
.34986 .06587 L
.34606 .06832 L
.34213 .0706 L
.33864 .07278 L
.33491 .07506 L
.3317 .07701 L
.32838 .07901 L
.32554 .0808 L
.32277 .0826 L
.32037 .08423 L
.31824 .08577 L
.31645 .08711 L
.31494 .08831 L
.31377 .08933 L
.3129 .0901 L
.31225 .09073 L
.31177 .09124 L
Mistroke
.31139 .09166 L
.31102 .09205 L
.31063 .09245 L
.31018 .09289 L
.30969 .09337 L
.30913 .09389 L
.30852 .09445 L
.30793 .09498 L
.30733 .09559 L
.30682 .09617 L
.30638 .09674 L
.30601 .09726 L
.30571 .09769 L
.30548 .09801 L
.30526 .09817 L
.30497 .09823 L
.30451 .09825 L
.30381 .09829 L
.30277 .09842 L
.30131 .09874 L
.29941 .09935 L
.29747 .10029 L
.29475 .10146 L
.29206 .10292 L
.28876 .10476 L
.28523 .1069 L
.28139 .10922 L
.27782 .11155 L
.27333 .11416 L
.26962 .11689 L
.26505 .1199 L
.26156 .12266 L
.25754 .12562 L
.25379 .12851 L
.24986 .13149 L
.24647 .13416 L
.24289 .13685 L
.24013 .13928 L
.23745 .14162 L
.23514 .14368 L
.23321 .14549 L
.23164 .14709 L
.23048 .14836 L
.22963 .14937 L
.22904 .15009 L
.22868 .15057 L
.2285 .15082 L
.22846 .15092 L
.22851 .1509 L
.2286 .15081 L
Mistroke
.22872 .15067 L
.22885 .15052 L
.22896 .1504 L
.22903 .15034 L
.22906 .1503 L
.22907 .1503 L
.22907 .1503 L
.22907 .1503 L
.22907 .1503 L
.22907 .15029 L
.2291 .15025 L
.22915 .15016 L
.22922 .15005 L
.22929 .14994 L
.22933 .14985 L
.2293 .14983 L
.2292 .14993 L
.22902 .15019 L
.22874 .15063 L
.22839 .15125 L
.22798 .15204 L
.22753 .15297 L
.22705 .15401 L
.22657 .15504 L
.2261 .15614 L
.22564 .15725 L
.22521 .15835 L
.22483 .15932 L
.22453 .16018 L
.22432 .16089 L
.22421 .16141 L
.22421 .1617 L
.22431 .16176 L
.22448 .16164 L
.22467 .16141 L
.22483 .16115 L
.22493 .16096 L
.22495 .16087 L
.22486 .16095 L
.22464 .16127 L
.22424 .16186 L
.22363 .16278 L
.22276 .16407 L
.22161 .16578 L
.22029 .16766 L
.21868 .17009 L
.21686 .17273 L
.21477 .1759 L
.21263 .17904 L
.21043 .18254 L
Mistroke
.20804 .18642 L
.20573 .18997 L
.20331 .19387 L
.20094 .19804 L
.19865 .20185 L
.19633 .2059 L
.19394 .21025 L
.19164 .21433 L
.18938 .21833 L
.18697 .22289 L
.18471 .2267 L
.18226 .23113 L
.17991 .235 L
.17747 .23918 L
.17496 .24345 L
.17256 .24738 L
.17015 .25132 L
.16779 .25518 L
.16545 .25908 L
.16325 .26266 L
.16106 .26632 L
.15885 .27019 L
.15666 .27392 L
.1546 .2774 L
.15243 .28131 L
.15028 .28512 L
.14817 .28858 L
.14602 .29241 L
.14412 .29586 L
.14226 .29935 L
.14054 .30273 L
.13901 .30576 L
.13759 .30863 L
.13647 .31102 L
.13551 .3132 L
.13475 .31505 L
.13418 .31649 L
.13381 .31761 L
.13363 .31839 L
.13361 .31885 L
.13371 .31905 L
.13385 .31903 L
.13401 .31885 L
.13415 .3186 L
.13423 .31834 L
.13422 .31813 L
.13414 .31806 L
.13398 .3182 L
.13376 .3186 L
.13347 .31932 L
Mistroke
.13309 .32046 L
.13262 .32206 L
.13206 .32414 L
.1314 .32687 L
.13065 .3299 L
.12986 .33368 L
.12903 .33818 L
.12819 .34263 L
.12739 .34804 L
.12663 .35291 L
.12593 .35849 L
.12531 .36436 L
.12478 .37009 L
.12432 .37485 L
.12395 .37993 L
.12367 .38511 L
.12348 .3893 L
.12337 .39259 L
.12332 .39569 L
.12331 .39847 L
.12332 .40043 L
.12335 .40194 L
.12338 .40301 L
.1234 .40367 L
.12341 .404 L
Mfstroke
.12328 .4077 m
.12338 .40787 L
.12353 .40804 L
.12372 .40823 L
.12396 .4084 L
.12424 .40856 L
.12458 .40868 L
.12497 .4088 L
.12544 .40893 L
.12602 .40908 L
.1267 .40928 L
.12745 .40954 L
.12827 .40987 L
.12915 .41031 L
.13008 .41088 L
.13093 .41161 L
.13181 .4125 L
.13263 .41351 L
.13347 .41472 L
.13417 .41616 L
.13479 .41776 L
.1353 .41957 L
.13568 .42161 L
.1359 .42392 L
.13596 .42645 L
.13585 .42923 L
.1356 .4322 L
.1352 .43545 L
.13467 .43849 L
.13399 .44179 L
.13315 .44532 L
.1321 .44872 L
.13081 .45228 L
.12938 .45604 L
.1277 .45977 L
.1258 .46327 L
.12349 .46705 L
.12174 .47081 L
.11942 .47488 L
.1177 .47862 L
.11546 .48263 L
.11367 .48681 L
.11211 .4911 L
.11072 .4953 L
.10949 .49962 L
.1085 .50327 L
.1078 .5069 L
.10737 .51003 L
.10716 .51276 L
.10711 .51494 L
Mistroke
.10714 .51659 L
.10723 .51779 L
.10732 .5186 L
.10734 .51912 L
.10729 .51944 L
.10725 .51968 L
.10725 .52 L
.1073 .52054 L
.10742 .5214 L
.10758 .52263 L
.10781 .52438 L
.1081 .5268 L
.10847 .52974 L
.10892 .53335 L
.10946 .53743 L
.11011 .54192 L
.1108 .54707 L
.11153 .55186 L
.11227 .55762 L
.11294 .56268 L
.11362 .56834 L
.11427 .57444 L
.11491 .57962 L
.11559 .58592 L
.11627 .59107 L
.11698 .59706 L
.11775 .60244 L
.11857 .60776 L
.11944 .61321 L
.12029 .61841 L
.12086 .62354 L
.12171 .62926 L
.12253 .6339 L
.12337 .63909 L
.12422 .64402 L
.12499 .64848 L
.12567 .65302 L
.12621 .65662 L
.1266 .66002 L
.12688 .66329 L
.12707 .66572 L
.12718 .66792 L
.12727 .66988 L
.12738 .6715 L
.12754 .67283 L
.12773 .67393 L
.12797 .67491 L
.12826 .67588 L
.12861 .67685 L
.12898 .67797 L
Mistroke
.12939 .67928 L
.12983 .68082 L
.13027 .68252 L
.13069 .68435 L
.13106 .68621 L
.13138 .68801 L
.13164 .68965 L
.13182 .69105 L
.13194 .69229 L
.132 .69332 L
.132 .69413 L
.13197 .69471 L
.13192 .69505 L
.13185 .69518 L
.13177 .69512 L
.1317 .69492 L
.13166 .69461 L
.13165 .69424 L
.13166 .69393 L
.13172 .69378 L
.13181 .69384 L
.13197 .69416 L
.13219 .69479 L
.13249 .69576 L
.13285 .69711 L
.13328 .69879 L
.13378 .70089 L
.13436 .70336 L
.135 .70572 L
.13567 .70877 L
.13638 .71159 L
.13709 .71467 L
.13777 .71785 L
.13841 .72075 L
.139 .72353 L
.13952 .72588 L
.13997 .72791 L
.14035 .72954 L
.14066 .73088 L
.14089 .73194 L
.14106 .73276 L
.14116 .7334 L
.14121 .73388 L
.14122 .73422 L
.1412 .73448 L
.14117 .7347 L
.14112 .73493 L
.14108 .73519 L
.14104 .73552 L
.14102 .73594 L
Mistroke
.14101 .73641 L
.141 .73684 L
.14099 .7372 L
.14099 .73751 L
.14098 .73774 L
.14098 .73791 L
.14098 .73803 L
.14098 .73809 L
.14098 .73809 L
.14098 .73805 L
.14098 .73797 L
.14099 .73786 L
.14099 .73773 L
.14099 .73755 L
.14099 .73736 L
.141 .73716 L
.141 .73695 L
.14099 .73673 L
.14096 .73651 L
.14092 .73631 L
.14086 .73612 L
.1408 .73596 L
.14075 .73584 L
.14072 .73574 L
.14075 .73571 L
.14082 .73578 L
.14097 .73597 L
.1412 .73628 L
.14153 .73671 L
.14198 .73724 L
.14257 .73788 L
.14333 .73866 L
.14428 .7396 L
.14538 .7407 L
.14672 .742 L
.14819 .7434 L
.14992 .74502 L
.15177 .74691 L
.15388 .74907 L
.15611 .75158 L
.15878 .75436 L
.16157 .75743 L
.16419 .76073 L
.1671 .76426 L
.1701 .76779 L
.17313 .77156 L
.17623 .77547 L
.17947 .77921 L
.18276 .78319 L
.18623 .78717 L
Mistroke
.18942 .79095 L
.19301 .79478 L
.19644 .79866 L
.20006 .80265 L
.20368 .8062 L
.20734 .81005 L
.21125 .81386 L
.21496 .81787 L
.21885 .82176 L
.22274 .82574 L
.22677 .8298 L
.23065 .83373 L
.23456 .8376 L
.23864 .84149 L
.24248 .84535 L
.24648 .84895 L
.25034 .85266 L
.25424 .85648 L
.25794 .85984 L
.26168 .86344 L
.26501 .86656 L
.2682 .86947 L
.27093 .87214 L
.27345 .87452 L
.27555 .87663 L
.27721 .8785 L
.2785 .87986 L
.27938 .88092 L
.27988 .88168 L
.28006 .88212 L
.27999 .88227 L
.27972 .88214 L
.27935 .88186 L
.27897 .88153 L
.2787 .88126 L
.27862 .88111 L
.27879 .88115 L
.27924 .88142 L
.28 .88188 L
.28106 .88261 L
.28242 .88351 L
.2841 .88455 L
.28589 .88568 L
.28808 .88694 L
.29046 .88838 L
.29299 .88983 L
.29585 .89143 L
.29885 .89306 L
.30211 .89475 L
.30544 .89647 L
Mistroke
.30924 .89804 L
.31296 .89974 L
.31648 .9014 L
.32041 .90308 L
.32476 .90481 L
.32858 .90652 L
.33312 .90823 L
.33722 .90994 L
.34159 .91156 L
.34595 .91317 L
.35019 .91475 L
.35438 .91631 L
.35862 .91783 L
.36287 .91939 L
.36698 .92087 L
.37119 .92239 L
.37556 .92389 L
.37957 .92545 L
.38388 .92691 L
.3882 .92853 L
.39243 .92998 L
.39675 .93146 L
.40112 .93297 L
.40549 .93452 L
.40983 .93609 L
.41405 .93756 L
.41832 .93889 L
.42254 .94027 L
.42679 .94168 L
.43103 .94304 L
.4349 .94437 L
.43877 .94568 L
.44273 .94702 L
.44655 .94833 L
.45024 .94959 L
.454 .95082 L
.45763 .95199 L
.46129 .95315 L
.46487 .95417 L
.46855 .95509 L
.4721 .95589 L
.47552 .95654 L
.47893 .95705 L
.48223 .95745 L
.4852 .95772 L
.48807 .95785 L
.49057 .95787 L
.49284 .95778 L
.49485 .9576 L
.49648 .95738 L
Mistroke
.49784 .95717 L
.49889 .95698 L
.49962 .95683 L
.50008 .9567 L
.50035 .95663 L
.50048 .95659 L
.50055 .95655 L
.50061 .95652 L
.50066 .9565 L
.50074 .95647 L
.50087 .95644 L
.50105 .95641 L
.50127 .95639 L
.50149 .95637 L
.50171 .95636 L
.50188 .95636 L
.502 .95637 L
.50201 .9564 L
.50189 .95643 L
.50164 .95647 L
.5013 .95651 L
.5009 .95655 L
.50048 .95658 L
.50005 .95661 L
.49964 .95663 L
.49928 .95666 L
.49899 .95671 L
.49877 .95679 L
.49857 .95684 L
.49838 .95685 L
.49819 .95681 L
.49803 .95672 L
.49793 .95661 L
.49786 .95647 L
.49781 .95632 L
.49778 .9562 L
.49777 .95611 L
.49785 .95604 L
.49812 .95597 L
.49864 .9559 L
.49946 .95581 L
.5006 .95571 L
.50215 .95563 L
.50407 .95555 L
.50647 .9555 L
.50926 .95545 L
.5124 .95536 L
.51605 .95519 L
.52007 .9549 L
.52444 .95444 L
Mistroke
.52907 .95381 L
.53402 .953 L
.53916 .95205 L
.54421 .95104 L
.54968 .95001 L
.5548 .94895 L
.56044 .9479 L
.56571 .94686 L
.57133 .94582 L
.57655 .94482 L
.58221 .94386 L
.58772 .94297 L
.59322 .94213 L
.59876 .94135 L
.60378 .94058 L
.60912 .93981 L
.61419 .93902 L
.61942 .93814 L
.6243 .93734 L
.62937 .93641 L
.63379 .93542 L
.63845 .93444 L
.64286 .93345 L
.64745 .93246 L
.65122 .93151 L
.65495 .93063 L
.65863 .92982 L
.66207 .9291 L
.66541 .92844 L
.66879 .92782 L
.67176 .92722 L
.67456 .92661 L
.67737 .92595 L
.68009 .92519 L
.68283 .92432 L
.68535 .92332 L
.68797 .92219 L
.69068 .92096 L
.69354 .91959 L
.6966 .91801 L
.69978 .91619 L
.70321 .9143 L
.70666 .91215 L
.71044 .90983 L
.71419 .90735 L
.71796 .90488 L
.7217 .90217 L
.72552 .89958 L
.72914 .89701 L
.73296 .89416 L
Mistroke
.73673 .89129 L
.74042 .88875 L
.74392 .88602 L
.74749 .88332 L
.75107 .88053 L
.75462 .87779 L
.75838 .87484 L
.76177 .8722 L
.7654 .86938 L
.76918 .86653 L
.7728 .86366 L
.77654 .86083 L
.7803 .85794 L
.78418 .85491 L
.78774 .8521 L
.79134 .84912 L
.79499 .84625 L
.79822 .84345 L
.80156 .84072 L
.80484 .83801 L
.80817 .83534 L
.81141 .83263 L
.81477 .82995 L
.81806 .82723 L
.82134 .82445 L
.82475 .82172 L
.82802 .81893 L
.83124 .81625 L
.83445 .81362 L
.83748 .81099 L
.84043 .80849 L
.84327 .80616 L
.84577 .80391 L
.8481 .80181 L
.85012 .79986 L
.85185 .79815 L
.85333 .79666 L
.85452 .7954 L
.85549 .79438 L
.85626 .79358 L
.85689 .79295 L
.85741 .79246 L
.85781 .79206 L
.85812 .79172 L
.85835 .7914 L
.85854 .79108 L
.85864 .79073 L
.85872 .79033 L
.85879 .78985 L
.85887 .78925 L
Mistroke
.85897 .78856 L
.85905 .78785 L
.85908 .78718 L
.85907 .78659 L
.85901 .78611 L
.85893 .7858 L
.85884 .78568 L
.85876 .78575 L
.85872 .78598 L
.85871 .78632 L
.85869 .78676 L
.85866 .78732 L
.85861 .78786 L
.85855 .78837 L
.85849 .78892 L
.85845 .78939 L
.85843 .78972 L
.85843 .78995 L
.85845 .79008 L
.85846 .79017 L
.85844 .79022 L
.85837 .79028 L
.85828 .79033 L
.85819 .79039 L
.85814 .7905 L
.85818 .79061 L
.85836 .79065 L
.85869 .7906 L
.85926 .79034 L
.85986 .78993 L
.8607 .78921 L
.86172 .78815 L
.86285 .78669 L
.86425 .78479 L
.8658 .78237 L
.86756 .77953 L
.86945 .77621 L
.87145 .77232 L
.87345 .76849 L
.87547 .76409 L
.87741 .75937 L
.87924 .75483 L
.88094 .75007 L
.8825 .74542 L
.88393 .74103 L
.88517 .73695 L
.88627 .73338 L
.88721 .72995 L
.88798 .72724 L
.88862 .72465 L
Mistroke
.88916 .72245 L
.88962 .72041 L
.89002 .71848 L
.89037 .71666 L
.89072 .71491 L
.89114 .71305 L
.89168 .7109 L
.89234 .70846 L
.89317 .70567 L
.89407 .70228 L
.89516 .69863 L
.89633 .69438 L
.8976 .69002 L
.89904 .68502 L
.90042 .68034 L
.90209 .67512 L
.90369 .66926 L
.90522 .66409 L
.90695 .65834 L
.90856 .65248 L
.91024 .64628 L
.91177 .64072 L
.91332 .63483 L
.91486 .62856 L
.91617 .62329 L
.91752 .61763 L
.91891 .61197 L
.92017 .60634 L
.92149 .60074 L
.92272 .59527 L
.92391 .59023 L
.92503 .58538 L
.9261 .58081 L
.92707 .57678 L
.92791 .57321 L
.92868 .57004 L
.92931 .56732 L
.9298 .56523 L
.93016 .56366 L
.93038 .56253 L
.93049 .56184 L
.9305 .56157 L
.93045 .56161 L
.93033 .56184 L
.93019 .56219 L
.93005 .56257 L
.92992 .56292 L
.92982 .5632 L
.92975 .5634 L
.92972 .56349 L
Mistroke
.92972 .56346 L
.92975 .56338 L
.9298 .56327 L
.92984 .56315 L
.92986 .56302 L
.92985 .5629 L
.92984 .56277 L
.92981 .56262 L
.92979 .56246 L
.92978 .56229 L
.92979 .56206 L
.92983 .56172 L
.92991 .56127 L
.93003 .56071 L
.93018 .56007 L
.93037 .55937 L
.93059 .55863 L
.93084 .55787 L
.93112 .5571 L
.93142 .55633 L
.93172 .55559 L
.93201 .55488 L
.93228 .55422 L
.93251 .55364 L
.93271 .55312 L
.93286 .55275 L
.93298 .55248 L
.93306 .55232 L
.93311 .55223 L
.93314 .55219 L
.93316 .55217 L
.93317 .55216 L
.93316 .55217 L
.93314 .55218 L
.93312 .55217 L
.9331 .55218 L
.93309 .55219 L
.93309 .55222 L
.93309 .55224 L
.93309 .55224 L
.93309 .55225 L
.93309 .55228 L
.93309 .55231 L
.93309 .55235 L
.93309 .55236 L
.93309 .55235 L
.93309 .55231 L
.93309 .55222 L
.93308 .5521 L
.93308 .55194 L
Mistroke
.93307 .55176 L
.93307 .55159 L
.93305 .55149 L
.93303 .55149 L
.933 .55153 L
.93298 .55158 L
.93297 .5516 L
.93298 .55153 L
.93301 .55131 L
.93308 .55085 L
.93316 .55005 L
.93327 .54873 L
.93338 .54679 L
.9335 .54425 L
.9336 .54132 L
.93367 .5379 L
.93371 .53395 L
.93372 .52959 L
.9337 .525 L
.93361 .51999 L
.93346 .51549 L
.93323 .51066 L
.93293 .50597 L
.93259 .50152 L
.93218 .49736 L
.93172 .49303 L
.93128 .48874 L
.93082 .48422 L
.93037 .47981 L
.92994 .47556 L
.92952 .47107 L
.92916 .46633 L
.92883 .46237 L
.92857 .45815 L
.92833 .45425 L
.92815 .45115 L
.92801 .44813 L
.92792 .44587 L
.92784 .44398 L
.92777 .44255 L
.92769 .4416 L
.92757 .4409 L
.9274 .44019 L
.92717 .43932 L
.92687 .43812 L
.92653 .43657 L
.92616 .43445 L
.92574 .43187 L
.92531 .42872 L
.92488 .4251 L
Mistroke
.92448 .42125 L
.9241 .4171 L
.92373 .41276 L
.92338 .40883 L
.92303 .40454 L
.92269 .40021 L
.92233 .39598 L
.92192 .39188 L
.92145 .38763 L
.92093 .3833 L
.92036 .37872 L
.91981 .37483 L
.91919 .37065 L
.91856 .36655 L
.91792 .36253 L
.91732 .35878 L
.91679 .35514 L
.91633 .3519 L
.91595 .34918 L
.91564 .34672 L
.91542 .34469 L
.91528 .34309 L
.91523 .34195 L
.91524 .34126 L
.91528 .34086 L
.91534 .34067 L
.9154 .34064 L
.91545 .34069 L
.91546 .34073 L
.91543 .34065 L
.91535 .34042 L
.91523 .33999 L
.91507 .33935 L
.91488 .33848 L
.91468 .33737 L
.91446 .33609 L
.91423 .33462 L
.914 .33307 L
.91378 .33157 L
.91358 .33001 L
.9134 .32857 L
.91324 .32715 L
.91313 .32588 L
.91306 .32477 L
.91303 .32388 L
.91303 .32323 L
.91305 .32278 L
.91308 .32248 L
.91309 .32221 L
.91308 .32191 L
Mistroke
.91304 .32147 L
.91295 .32083 L
.91281 .31996 L
.9126 .31887 L
.91232 .31757 L
.91197 .31611 L
.91156 .31461 L
.91109 .313 L
.91058 .31134 L
.91004 .30968 L
.90951 .30803 L
.90899 .30648 L
.90849 .30502 L
.90805 .30374 L
.90768 .30271 L
.90737 .30193 L
.90713 .3014 L
.90696 .30108 L
.90685 .30094 L
.90679 .30094 L
.90678 .30107 L
.9068 .30129 L
.90685 .30156 L
.9069 .30183 L
.90695 .30208 L
.90698 .30228 L
.90701 .3024 L
.90702 .30246 L
.90702 .30248 L
.90702 .30245 L
.90702 .30239 L
.90701 .30233 L
.90701 .30222 L
.907 .30207 L
.90699 .3019 L
.90698 .30173 L
.90696 .30156 L
.90695 .30141 L
.90694 .30129 L
.90694 .30121 L
.90693 .30117 L
.90693 .30119 L
.90694 .30126 L
.90694 .30135 L
.90695 .30144 L
.90695 .30153 L
.90696 .30163 L
.90696 .30173 L
.90697 .30183 L
.90697 .30191 L
Mistroke
.90697 .30197 L
.90697 .30201 L
.90697 .30203 L
.90697 .30202 L
.90697 .30198 L
.90697 .30193 L
.90697 .30186 L
.90696 .30176 L
.90696 .30166 L
.90695 .30155 L
.90695 .30146 L
.90695 .30139 L
.90695 .30134 L
.90695 .30132 L
.90696 .3013 L
.90697 .30127 L
.90697 .30125 L
.90699 .30125 L
.907 .30127 L
.907 .30132 L
.907 .30139 L
.90698 .30149 L
.90694 .30161 L
.90689 .30174 L
.90682 .30185 L
.90674 .30193 L
.90662 .30197 L
.90647 .30194 L
.90625 .30188 L
.90597 .30179 L
.90562 .30163 L
.90518 .3014 L
.90464 .30111 L
.90402 .30077 L
.90335 .30041 L
.90262 .30008 L
.90188 .29978 L
.90118 .29952 L
.90057 .29933 L
.90006 .29921 L
.89969 .29915 L
.89947 .29913 L
.89939 .29905 L
.89944 .29893 L
.8996 .29873 L
.89982 .29838 L
.90008 .29784 L
.9003 .29707 L
.90044 .29603 L
.90042 .29469 L
Mistroke
.90022 .29299 L
.89981 .29109 L
.89919 .28883 L
.8983 .28625 L
.89714 .28334 L
.89572 .28028 L
.89397 .27652 L
.8922 .27328 L
.8901 .26955 L
.88788 .26565 L
.88563 .26156 L
.88306 .25718 L
.88076 .25317 L
.87822 .24898 L
.87546 .24434 L
.873 .24049 L
.87035 .23626 L
.86772 .23201 L
.8649 .22808 L
.86259 .22398 L
.86012 .22037 L
.8578 .21676 L
.85545 .21338 L
.8533 .21011 L
.8512 .20691 L
.84911 .20388 L
.84703 .20082 L
.84492 .19775 L
.84278 .19463 L
.84061 .19146 L
.8383 .18799 L
.83602 .18472 L
.83356 .18118 L
.8311 .17796 L
.82832 .17417 L
.82577 .17046 L
.82319 .16667 L
.82066 .16313 L
.81795 .15927 L
.81533 .15553 L
.81268 .15181 L
.81018 .14819 L
.80772 .14478 L
.80539 .14148 L
.80333 .13845 L
.80136 .13563 L
.79957 .13304 L
.798 .1308 L
.79666 .1289 L
.79554 .12731 L
Mistroke
.79468 .12612 L
.79401 .12522 L
.79352 .12461 L
.7932 .12423 L
.79302 .12407 L
.79296 .12406 L
.79297 .12414 L
.79303 .12426 L
.79312 .1244 L
.79322 .12453 L
.7933 .12462 L
.79336 .12468 L
.79338 .12471 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.79339 .12472 L
.7934 .12474 L
.79342 .12478 L
.79346 .12482 L
.79349 .12486 L
.7935 .12488 L
.79349 .12487 L
.79345 .1248 L
.79338 .12469 L
.79327 .12453 L
.79313 .12432 L
.79299 .12408 L
.79287 .12382 L
.79277 .12355 L
.79266 .12326 L
.7925 .12294 L
.79227 .12256 L
.79194 .12214 L
.79152 .12168 L
.791 .12119 L
.79038 .12078 L
.78968 .12037 L
.78893 .11997 L
.78819 .11958 L
.78755 .11919 L
.78681 .11878 L
.78612 .11839 L
.78538 .11802 L
.78462 .11769 L
.7839 .11748 L
Mistroke
.78323 .11743 L
.78259 .11749 L
.78191 .11772 L
.78114 .11806 L
.78023 .11848 L
.7791 .11894 L
.77789 .11949 L
.77645 .12009 L
.77472 .12073 L
.77281 .12143 L
.77086 .12217 L
.76864 .123 L
.76642 .12391 L
.76399 .12488 L
.76183 .12591 L
.75951 .12693 L
.75714 .12801 L
.75519 .12914 L
.75321 .1303 L
.75123 .13153 L
.74937 .13273 L
.74761 .1341 L
.74599 .13538 L
.74439 .13667 L
.74296 .13791 L
.74163 .13903 L
.74043 .13999 L
.73939 .14073 L
.7386 .14121 L
.73794 .14148 L
.73741 .14154 L
.73704 .14147 L
.73683 .14131 L
.73679 .14108 L
.73692 .14085 L
.73721 .14062 L
.73764 .1405 L
.73818 .14054 L
.73884 .14081 L
.73958 .14138 L
.7404 .14236 L
.74131 .14361 L
.74233 .1454 L
.74351 .14737 L
.74485 .1498 L
.74621 .1524 L
.74775 .15531 L
.7494 .15806 L
.75112 .16118 L
.75293 .16406 L
Mistroke
.75479 .16715 L
.75667 .17023 L
.75868 .1734 L
.76069 .17668 L
.76267 .17985 L
.76476 .18322 L
.76669 .18663 L
.76867 .19009 L
.7707 .19379 L
.77256 .19698 L
.77441 .20026 L
.77625 .20353 L
.77787 .20626 L
.77942 .20891 L
.78079 .2112 L
.78197 .21327 L
.78294 .21482 L
.78368 .21615 L
.78421 .21699 L
.78457 .21758 L
.78479 .21788 L
.78491 .21793 L
.78493 .21781 L
.78488 .2176 L
.78476 .21736 L
.78458 .21716 L
.78439 .21703 L
.78426 .21701 L
.78423 .21714 L
.78433 .21744 L
.78458 .2179 L
.78501 .21854 L
.78565 .21938 L
.78649 .22036 L
.78753 .2215 L
.78875 .22278 L
.78992 .22412 L
.79143 .22547 L
.79283 .22678 L
.7943 .22792 L
.79572 .22894 L
.79703 .22977 L
.79815 .23047 L
.79917 .23111 L
.79997 .23157 L
.8007 .232 L
.80137 .2324 L
.80203 .23281 L
.80274 .23326 L
.80358 .23381 L
Mistroke
.8046 .23452 L
.80577 .23536 L
.80716 .23648 L
.80882 .23779 L
.81076 .23939 L
.81298 .24121 L
.81554 .24317 L
.81819 .24534 L
.82113 .24742 L
.82401 .24956 L
.82713 .25181 L
.83033 .25396 L
.83341 .25593 L
.83672 .25794 L
.83999 .25983 L
.84334 .26159 L
.84674 .26311 L
.85048 .26443 L
.85351 .26553 L
.85683 .26638 L
.86022 .26705 L
.86316 .26755 L
.86607 .26792 L
.86878 .26815 L
.87126 .2683 L
.87333 .26837 L
.87524 .26839 L
.87688 .26837 L
.87826 .26833 L
.87952 .2683 L
.88064 .2683 L
.88171 .26839 L
.88275 .26857 L
.88373 .26887 L
.88475 .26925 L
.8857 .26968 L
.88668 .27016 L
.88765 .27067 L
.88859 .27121 L
.88944 .27177 L
.8902 .27235 L
.89081 .27294 L
.89129 .27355 L
.89165 .27419 L
.89189 .27484 L
.89205 .27549 L
.89217 .27615 L
.89229 .27682 L
.89241 .27745 L
.89256 .27807 L
Mistroke
.89271 .27864 L
.89287 .27913 L
.89304 .27953 L
.8932 .27982 L
.89331 .28001 L
.89334 .2801 L
.89329 .28012 L
.89314 .28012 L
.8929 .28015 L
.89258 .28024 L
.89222 .28041 L
.89185 .28063 L
.8915 .2809 L
.8912 .28118 L
.89096 .28146 L
.89077 .28177 L
.89063 .2821 L
.89053 .2824 L
.89049 .28268 L
.89052 .28289 L
.89061 .28303 L
.89076 .28302 L
.89095 .28286 L
.89116 .28254 L
.89133 .28211 L
.89142 .28155 L
.89139 .28086 L
.89121 .28004 L
.89088 .27903 L
.89042 .27776 L
.88982 .27619 L
.88911 .27441 L
.88819 .27219 L
.88703 .26968 L
.88564 .26678 L
.88406 .26365 L
.88222 .26021 L
.88035 .25674 L
.87831 .25321 L
.87636 .24977 L
.87453 .24642 L
.87287 .24352 L
.87137 .24086 L
.87001 .23838 L
.86897 .23657 L
.86814 .23503 L
.86752 .23377 L
.86714 .23296 L
.86697 .23245 L
.867 .23223 L
Mistroke
.86718 .23224 L
.86746 .23239 L
.86778 .23261 L
.86808 .23285 L
.86836 .23305 L
.86859 .23321 L
.86877 .23329 L
.86892 .2333 L
.86905 .2333 L
.86915 .23331 L
.8692 .23335 L
.86916 .23341 L
.86903 .23347 L
.86878 .2335 L
.86842 .23347 L
.86795 .23337 L
.86737 .2332 L
.8667 .23294 L
.86598 .23262 L
.86528 .23224 L
.86456 .23182 L
.86383 .23138 L
.86312 .23095 L
.86249 .2305 L
.86196 .23006 L
.86155 .22962 L
.86126 .22922 L
.8611 .2289 L
.86105 .22868 L
.86108 .2286 L
.86116 .22866 L
.86124 .22886 L
.86132 .22916 L
.8614 .22954 L
.86147 .22999 L
.86152 .23047 L
.86153 .23097 L
.86153 .23146 L
.86151 .23194 L
.86149 .2324 L
.86146 .23281 L
.8614 .23313 L
.86131 .23331 L
.86116 .23333 L
.86092 .23314 L
.86064 .23271 L
.86022 .23204 L
.85952 .23111 L
.85889 .22995 L
.85816 .22853 L
Mistroke
.85732 .22679 L
.85641 .22481 L
.85534 .22242 L
.85414 .22001 L
.8528 .21715 L
.85129 .21415 L
.84963 .21082 L
.84783 .20747 L
.8459 .20392 L
.84384 .20011 L
.84163 .19618 L
.8392 .19213 L
.83666 .18758 L
.83395 .1835 L
.83104 .1789 L
.82796 .17417 L
.82486 .16963 L
.8217 .1648 L
.81842 .15991 L
.81518 .15509 L
.81198 .15056 L
.80861 .14554 L
.80547 .1414 L
.80218 .13707 L
.79892 .13309 L
.79555 .12946 L
.79249 .12629 L
.78935 .12341 L
.78636 .12074 L
.7835 .11866 L
.78066 .11673 L
.77765 .11496 L
.77504 .11335 L
.77229 .11181 L
.7694 .11039 L
.76658 .10893 L
.76351 .1074 L
.76052 .10584 L
.75712 .10415 L
.75375 .10235 L
.74988 .10038 L
.74602 .09842 L
.74179 .09628 L
.73688 .09415 L
.73261 .09207 L
.72751 .0899 L
.72282 .08781 L
.71762 .08562 L
.71287 .08358 L
.70795 .08149 L
Mistroke
.70317 .07946 L
.69871 .07743 L
.69444 .07565 L
.69042 .07384 L
.68647 .07221 L
.68316 .07065 L
.67991 .06922 L
.67673 .06787 L
.67409 .06672 L
.67153 .06565 L
.66905 .06466 L
.66683 .06372 L
.66459 .06282 L
.66227 .06191 L
.66004 .061 L
.65746 .05997 L
.65493 .05885 L
.65211 .05768 L
.64899 .05643 L
.64583 .05511 L
.6423 .05373 L
.63885 .05226 L
.63504 .05074 L
.63149 .04925 L
.62777 .04774 L
.62406 .04625 L
.62033 .04478 L
.61686 .04336 L
.6134 .04211 L
.60998 .04094 L
.60688 .03986 L
.60388 .03895 L
.60095 .03814 L
.59823 .03744 L
.59544 .03688 L
.59283 .03647 L
.59013 .03619 L
.5873 .03604 L
.58457 .03598 L
.58153 .03598 L
.57845 .03599 L
.57531 .03599 L
.57173 .03593 L
.56844 .0358 L
.56484 .0356 L
.5607 .03536 L
.55721 .03509 L
.55321 .03482 L
.54914 .03456 L
.54495 .03431 L
Mistroke
.54069 .03409 L
.5365 .0339 L
.53193 .03373 L
.52794 .0336 L
.52343 .03349 L
.51937 .03341 L
.51575 .03337 L
.51191 .03336 L
.50877 .03339 L
.5056 .03344 L
.5033 .03349 L
.50128 .03354 L
.49955 .03356 L
.49822 .03356 L
.4971 .03353 L
.49614 .03348 L
.49528 .03342 L
.49437 .03337 L
.49327 .03332 L
.49183 .03328 L
.49013 .03322 L
.48791 .03315 L
.48509 .03307 L
.48217 .03296 L
.47866 .03285 L
.47493 .03272 L
.47114 .03259 L
.46738 .03244 L
.46373 .03229 L
.4603 .03218 L
.45753 .0321 L
.45467 .03205 L
.45254 .03203 L
.4507 .03202 L
.44919 .032 L
.4481 .03197 L
.44739 .03195 L
.44696 .03196 L
.44675 .03202 L
.44669 .03214 L
.44671 .03231 L
.44675 .03252 L
.44672 .03276 L
.44661 .03303 L
.44646 .03331 L
.44629 .0336 L
.44611 .03391 L
.4459 .03424 L
.44564 .03457 L
.44528 .03491 L
Mistroke
.44479 .03519 L
.44413 .03548 L
.44332 .03575 L
.4424 .03588 L
.44139 .03593 L
.44034 .0359 L
.43926 .0358 L
.43823 .03568 L
.43722 .03556 L
.43623 .03545 L
.43529 .03535 L
.43443 .03528 L
.43365 .03521 L
.433 .03516 L
.43249 .03514 L
.4321 .03514 L
.43183 .03515 L
.43165 .03521 L
.43152 .03529 L
.43141 .03538 L
.43131 .03548 L
.43122 .03557 L
.43115 .03565 L
.43111 .03571 L
.4311 .03575 L
.43112 .03577 L
.43115 .03577 L
.43119 .03574 L
.43122 .03571 L
.43123 .0357 L
.43124 .03569 L
.43129 .0357 L
.4314 .0357 L
.43156 .0357 L
.43172 .03571 L
.43187 .03571 L
.43198 .03569 L
.43201 .03563 L
.43193 .03555 L
.43164 .03545 L
.43107 .03537 L
.43012 .03533 L
.42874 .03534 L
.42684 .03542 L
.42463 .03558 L
.42199 .03583 L
.41872 .03617 L
.41545 .03663 L
.41149 .03721 L
.40794 .03791 L
Mistroke
.40394 .03873 L
.40017 .03972 L
.39684 .04077 L
.39354 .04192 L
.39084 .04312 L
.3883 .04422 L
.38639 .04528 L
.38489 .04626 L
.38382 .04714 L
.38311 .04786 L
.3827 .04848 L
.3825 .04899 L
.38244 .0494 L
.38247 .04968 L
.38255 .04985 L
.38265 .04991 L
.38276 .04988 L
.38284 .04981 L
.38291 .04972 L
.38295 .04965 L
.38298 .04958 L
.38299 .04955 L
.383 .04955 L
.383 .04955 L
.383 .04955 L
.383 .04955 L
.383 .04955 L
.383 .04955 L
.383 .04955 L
.38303 .04955 L
.3831 .04955 L
.3832 .04955 L
.3833 .04954 L
.38335 .04952 L
.38332 .04948 L
.38319 .04942 L
.38295 .04935 L
.3826 .04928 L
.38214 .04925 L
.38158 .04929 L
.38095 .04942 L
.38025 .04965 L
.37952 .04999 L
.37877 .05043 L
.37799 .05096 L
.37721 .05154 L
.37646 .05217 L
.37579 .05282 L
.37522 .05348 L
.37478 .05412 L
Mistroke
.37445 .05473 L
.37424 .0553 L
.37414 .05578 L
.37412 .0561 L
.37417 .05625 L
.37428 .05621 L
.37444 .05602 L
.37465 .05575 L
.37488 .05544 L
.37509 .05514 L
.37527 .0549 L
.37539 .05473 L
.37543 .05463 L
.37542 .05456 L
.37537 .05446 L
.37532 .05431 L
.37527 .05412 L
.3752 .05394 L
.37511 .05381 L
.375 .05373 L
.37492 .05372 L
.37486 .05372 L
.37478 .05375 L
.37468 .0538 L
.37453 .05383 L
.37429 .05385 L
.37395 .05391 L
.37348 .05406 L
.37284 .05436 L
.37202 .05479 L
.371 .05533 L
.36978 .05595 L
.36838 .05663 L
.3669 .05736 L
.36526 .05812 L
.36346 .05891 L
.36167 .05973 L
.35983 .06056 L
.35795 .0614 L
.35623 .0622 L
.35456 .06302 L
.35296 .06383 L
.35151 .06457 L
.35018 .06528 L
.34909 .06597 L
.34817 .06664 L
.34746 .06732 L
.34696 .06789 L
.34665 .06844 L
.3465 .0689 L
Mistroke
.3465 .06925 L
.34658 .06957 L
.34671 .06987 L
.34687 .07014 L
.34704 .07038 L
.34721 .07057 L
.34735 .0707 L
.34746 .07077 L
.34756 .07077 L
.34764 .07067 L
.34771 .07045 L
.34776 .07019 L
.34781 .06986 L
.34786 .06951 L
.34791 .06917 L
.34799 .06886 L
.34809 .06855 L
.34815 .06829 L
.34813 .06812 L
.34798 .06805 L
.34763 .06812 L
.34708 .06836 L
.34622 .06885 L
.34502 .06954 L
.34337 .07055 L
.34133 .07186 L
.33879 .07346 L
.33555 .07543 L
.33261 .07744 L
.329 .07976 L
.32475 .08214 L
.32111 .08462 L
.31684 .08706 L
.31281 .08966 L
.30819 .09213 L
.30472 .09457 L
.30082 .09697 L
.29702 .09945 L
.29365 .1016 L
.28999 .10383 L
.28694 .10597 L
.28373 .10804 L
.28066 .11012 L
.27767 .11212 L
.27456 .11408 L
.27176 .11603 L
.26882 .1179 L
.26589 .11976 L
.26285 .12163 L
.26017 .1234 L
Mistroke
.25734 .12519 L
.25463 .12693 L
.25216 .12859 L
.24971 .13021 L
.2474 .13177 L
.24556 .13314 L
.24392 .13441 L
.24246 .13556 L
.24119 .13657 L
.24017 .13742 L
.23933 .13813 L
.23868 .13871 L
.23821 .13915 L
.23787 .13948 L
.23763 .1397 L
.23747 .13986 L
.23734 .13998 L
.23719 .14012 L
.23699 .14031 L
.23677 .14057 L
.23652 .14091 L
.2362 .14133 L
.23583 .14186 L
.23545 .14249 L
.23504 .14316 L
.23463 .1439 L
.23425 .14466 L
.23387 .14548 L
.2335 .14631 L
.23315 .1471 L
.23281 .14784 L
.23248 .14846 L
.23217 .14897 L
.2319 .14934 L
.23167 .14954 L
.23149 .1496 L
.23137 .1495 L
.23133 .14927 L
.23138 .14894 L
.23149 .14857 L
.23162 .14823 L
.23173 .14794 L
.23176 .14779 L
.23167 .14781 L
.23144 .14804 L
.23104 .14856 L
.23048 .14931 L
.22976 .15033 L
.22891 .15159 L
.22795 .15307 L
Mistroke
.22699 .15463 L
.22603 .15621 L
.22506 .15777 L
.22408 .15928 L
.22317 .1607 L
.22235 .16206 L
.22162 .16345 L
.22096 .16472 L
.22029 .16604 L
.21957 .16746 L
.21874 .16907 L
.21776 .17093 L
.21654 .17308 L
.21518 .17535 L
.21348 .17802 L
.21154 .18108 L
.20941 .1844 L
.20708 .18815 L
.20447 .19214 L
.20199 .19628 L
.19934 .20056 L
.19664 .20486 L
.19405 .20926 L
.19157 .21334 L
.18903 .21749 L
.18658 .22208 L
.18416 .22587 L
.18158 .23012 L
.17916 .23435 L
.17665 .23873 L
.1741 .24345 L
.17154 .24773 L
.16898 .25222 L
.16637 .25708 L
.16391 .26119 L
.16131 .2657 L
.15869 .27035 L
.15602 .27484 L
.1535 .27925 L
.15099 .28366 L
.14858 .2881 L
.14621 .29269 L
.14411 .29688 L
.14207 .30124 L
.14006 .30607 L
.13831 .31006 L
.13661 .3147 L
.135 .3192 L
.13351 .32346 L
.13215 .32792 L
Mistroke
.1309 .33229 L
.12978 .33653 L
.1288 .34069 L
.12791 .34492 L
.1271 .34938 L
.12636 .3535 L
.12568 .3583 L
.12507 .36247 L
.12458 .36714 L
.12418 .37158 L
.12388 .37603 L
.12367 .38012 L
.12353 .38431 L
.12345 .38764 L
.12341 .39076 L
.1234 .3936 L
.12341 .39584 L
.12343 .39759 L
.12345 .39877 L
.12348 .39942 L
.12348 .39966 L
Mfstroke
.12321 .39912 m
.12313 .39928 L
.12307 .39957 L
.12311 .39997 L
.12329 .40051 L
.12362 .40118 L
.12412 .40204 L
.12483 .40308 L
.12577 .40435 L
.12677 .40579 L
.128 .40744 L
.12914 .40932 L
.13029 .41144 L
.13156 .4137 L
.13251 .41628 L
.13335 .41908 L
.13403 .42224 L
.13451 .42549 L
.13474 .42909 L
.13471 .4327 L
.13439 .43656 L
.13384 .44013 L
.1331 .44387 L
.13215 .44765 L
.13115 .45103 L
.12999 .45445 L
.12871 .45777 L
.12727 .46097 L
.12583 .46413 L
.12408 .46733 L
.12251 .4705 L
.12068 .47385 L
.11891 .47729 L
.11695 .48113 L
.11504 .48507 L
.11347 .48917 L
.11195 .49388 L
.11052 .49849 L
.10938 .50351 L
.10854 .50861 L
.10796 .51375 L
.10766 .51892 L
.10759 .52401 L
.10768 .52884 L
.10792 .53333 L
.10828 .53736 L
.10873 .54114 L
.10921 .54418 L
.10971 .54712 L
.11019 .54959 L
Mistroke
.11068 .55196 L
.11116 .55442 L
.11164 .55699 L
.11211 .55948 L
.11257 .56228 L
.11304 .56545 L
.11351 .56846 L
.114 .57189 L
.1145 .57554 L
.11498 .57851 L
.11545 .5819 L
.1159 .58508 L
.11629 .58755 L
.11661 .58971 L
.11686 .5915 L
.11706 .59282 L
.11721 .5936 L
.11732 .59395 L
.11742 .59399 L
.11749 .59387 L
.11757 .5937 L
.11766 .59354 L
.11779 .59346 L
.11798 .59352 L
.11823 .59374 L
.11854 .59402 L
.1189 .59425 L
.1193 .5944 L
.11972 .59448 L
.12015 .5945 L
.12054 .59448 L
.1209 .59444 L
.1212 .59441 L
.12144 .59447 L
.12162 .59466 L
.12173 .59505 L
.1218 .59573 L
.12185 .59675 L
.12188 .59817 L
.12189 .59997 L
.12188 .60229 L
.12185 .605 L
.12184 .60827 L
.12189 .61177 L
.12201 .61582 L
.12223 .61999 L
.12252 .62447 L
.12288 .62917 L
.1233 .63401 L
.12377 .63908 L
Mistroke
.12431 .64439 L
.12488 .6497 L
.12552 .65501 L
.12622 .66068 L
.12696 .66602 L
.12775 .67112 L
.12859 .67671 L
.12941 .68139 L
.13026 .68631 L
.13109 .69105 L
.1319 .69504 L
.13269 .69903 L
.13343 .70259 L
.13417 .70586 L
.1349 .70854 L
.13559 .71094 L
.1362 .71291 L
.13672 .7146 L
.13713 .71601 L
.13744 .71716 L
.13765 .71806 L
.1378 .71876 L
.13789 .71927 L
.13796 .71958 L
.13802 .71975 L
.1381 .71979 L
.1382 .71982 L
.13832 .71982 L
.13847 .71982 L
.13865 .71983 L
.13888 .71984 L
.13915 .71988 L
.13947 .71999 L
.13983 .72017 L
.14021 .72038 L
.14057 .72059 L
.14089 .72079 L
.14115 .72097 L
.14132 .72111 L
.14142 .72118 L
.14144 .72121 L
.14143 .7212 L
.1414 .72118 L
.14136 .72117 L
.14131 .72122 L
.14128 .72137 L
.14125 .72166 L
.14124 .7221 L
.14123 .72272 L
.14122 .72336 L
Mistroke
.14121 .72414 L
.14119 .72496 L
.14117 .72586 L
.14115 .72678 L
.1411 .72769 L
.14105 .72853 L
.141 .72929 L
.14097 .72996 L
.14098 .73051 L
.14102 .73094 L
.14112 .73124 L
.14126 .7314 L
.14145 .73143 L
.14167 .7314 L
.14192 .73133 L
.14218 .73124 L
.14244 .73114 L
.1427 .73106 L
.14293 .731 L
.14312 .73096 L
.14325 .73093 L
.14333 .73092 L
.14338 .73092 L
.1434 .73092 L
.14342 .73093 L
.1435 .73094 L
.14369 .73098 L
.14399 .73105 L
.14442 .7312 L
.14497 .73142 L
.14564 .73171 L
.14635 .73209 L
.14714 .73248 L
.14792 .73292 L
.14872 .73336 L
.1495 .73375 L
.15032 .73409 L
.15107 .73438 L
.15185 .73458 L
.15267 .73472 L
.15354 .73479 L
.15448 .73472 L
.15554 .7345 L
.15665 .73414 L
.15802 .73359 L
.15942 .73286 L
.16094 .73201 L
.1627 .73109 L
.16427 .73015 L
.16594 .72922 L
Mistroke
.16765 .72828 L
.16916 .7274 L
.17045 .72659 L
.17156 .72588 L
.17241 .72531 L
.17297 .72493 L
.17323 .72473 L
.17318 .72469 L
.17284 .72481 L
.1723 .72509 L
.17174 .72553 L
.17127 .72614 L
.17089 .72691 L
.17065 .72782 L
.17051 .72887 L
.1705 .73006 L
.17067 .73137 L
.17113 .73274 L
.17175 .73396 L
.17274 .73528 L
.17379 .73669 L
.175 .73828 L
.17623 .74 L
.17749 .7418 L
.17868 .74385 L
.17971 .74625 L
.18062 .74892 L
.18149 .75197 L
.18234 .75549 L
.18321 .75918 L
.18409 .76264 L
.18512 .76625 L
.18632 .77047 L
.18765 .77498 L
.18912 .77944 L
.19065 .78361 L
.19225 .78782 L
.19378 .79166 L
.19527 .79497 L
.19672 .79814 L
.19802 .80067 L
.19923 .8029 L
.20025 .80451 L
.20113 .80576 L
.20186 .80669 L
.20239 .80731 L
.20273 .80765 L
.20289 .80777 L
.20291 .80772 L
.20288 .80759 L
Mistroke
.20287 .80741 L
.20294 .80724 L
.20311 .8071 L
.20343 .80706 L
.20391 .80713 L
.20448 .80727 L
.20514 .80744 L
.20586 .80765 L
.20659 .80789 L
.20733 .80817 L
.20807 .80847 L
.20874 .80876 L
.20932 .80902 L
.20976 .80919 L
.21005 .80923 L
.21018 .80915 L
.21019 .80902 L
.21011 .80886 L
.20997 .80872 L
.20982 .80868 L
.20975 .80882 L
.2098 .80921 L
.21006 .80988 L
.21056 .81085 L
.21132 .81213 L
.21237 .81371 L
.21361 .81539 L
.21509 .81737 L
.21677 .81953 L
.21859 .82173 L
.2204 .82386 L
.22223 .82592 L
.22396 .8276 L
.22547 .82902 L
.22685 .83014 L
.22797 .83094 L
.22885 .83141 L
.22946 .83155 L
.22982 .83147 L
.22998 .83123 L
.23001 .83091 L
.22993 .83057 L
.2298 .83025 L
.22966 .82998 L
.22955 .82983 L
.22949 .82976 L
.22946 .82975 L
.22944 .82979 L
.22944 .82986 L
.22944 .82993 L
Mistroke
.22944 .82998 L
.22943 .82999 L
.22942 .82994 L
.22938 .82984 L
.22932 .8297 L
.22921 .82955 L
.22908 .82943 L
.22897 .82939 L
.2289 .82946 L
.22892 .82966 L
.22906 .83004 L
.22935 .8306 L
.22981 .83135 L
.23046 .83227 L
.23133 .83335 L
.23237 .83466 L
.23367 .83614 L
.23515 .83795 L
.23691 .83985 L
.23883 .84206 L
.24106 .84451 L
.24352 .84717 L
.2462 .85 L
.24917 .85313 L
.25218 .85603 L
.25536 .85925 L
.25868 .86273 L
.26233 .86607 L
.2656 .8695 L
.26914 .87295 L
.27297 .87599 L
.27611 .87899 L
.27953 .88179 L
.28308 .88453 L
.28609 .88692 L
.28925 .88924 L
.29239 .89121 L
.29555 .89312 L
.29892 .89494 L
.30209 .89676 L
.30543 .89832 L
.30897 .90001 L
.31269 .90156 L
.31631 .90312 L
.32013 .90461 L
.32387 .90607 L
.32753 .90735 L
.33114 .90858 L
.33442 .90969 L
.33749 .91061 L
Mistroke
.34028 .91139 L
.34277 .91206 L
.34494 .91258 L
.34682 .91298 L
.34841 .91326 L
.34972 .91345 L
.35078 .91353 L
.35163 .91354 L
.35228 .91351 L
.35277 .91347 L
.35312 .91345 L
.35335 .91344 L
.35348 .91343 L
.35353 .91341 L
.35353 .91339 L
.35349 .91336 L
.3534 .91333 L
.35326 .9133 L
.35305 .91324 L
.3528 .91315 L
.35257 .91303 L
.35239 .91294 L
.35231 .9129 L
.35238 .91296 L
.35269 .91313 L
.35328 .91342 L
.3542 .91384 L
.35552 .91439 L
.35729 .91509 L
.35937 .91595 L
.36172 .91688 L
.36472 .91816 L
.36788 .91941 L
.37161 .92082 L
.37577 .92243 L
.38013 .92416 L
.38438 .92601 L
.38904 .92766 L
.39381 .92946 L
.39862 .93114 L
.40307 .93283 L
.40774 .93458 L
.41231 .93616 L
.41682 .93782 L
.42132 .93942 L
.42573 .94098 L
.43007 .94245 L
.43406 .94389 L
.43823 .9452 L
.44241 .94649 L
Mistroke
.44683 .94779 L
.4504 .94902 L
.45436 .95026 L
.45812 .95144 L
.46202 .9526 L
.46556 .95366 L
.46912 .95461 L
.47254 .95547 L
.47562 .9562 L
.47858 .95678 L
.48106 .95723 L
.48336 .95757 L
.48532 .95782 L
.48691 .95798 L
.48818 .95806 L
.48914 .95808 L
.48979 .95805 L
.49019 .95799 L
.49041 .95792 L
.49052 .95785 L
.49055 .95778 L
.49053 .95772 L
.49046 .95768 L
.49035 .95766 L
.49023 .95764 L
.49014 .95761 L
.49011 .95758 L
.49015 .95756 L
.49023 .95755 L
.4904 .95754 L
.49061 .95754 L
.49083 .95754 L
.49097 .95753 L
.49104 .95749 L
.49104 .95741 L
.49099 .95727 L
.49091 .95707 L
.49083 .95682 L
.49075 .9565 L
.49066 .95612 L
.49053 .95571 L
.49039 .95527 L
.49023 .95483 L
.49004 .95437 L
.4898 .95391 L
.48956 .95351 L
.48936 .95319 L
.4892 .95294 L
.48907 .95274 L
.48897 .95259 L
Mistroke
.4889 .95248 L
.4888 .95238 L
.48867 .95228 L
.48851 .95218 L
.48839 .95207 L
.48826 .95193 L
.48817 .95175 L
.48809 .95156 L
.48805 .95138 L
.48798 .95122 L
.4879 .95108 L
.48783 .951 L
.48781 .95099 L
.48783 .95105 L
.48788 .95118 L
.48795 .95136 L
.48803 .95161 L
.48808 .95185 L
.4881 .95206 L
.48811 .95229 L
.48813 .9525 L
.48817 .95271 L
.48822 .95292 L
.4883 .95312 L
.48838 .95336 L
.48845 .95361 L
.48851 .95381 L
.48859 .95401 L
.48874 .9542 L
.48894 .95437 L
.48916 .95451 L
.48939 .9546 L
.48961 .95461 L
.48979 .95454 L
.48985 .95437 L
.4898 .95411 L
.48961 .95379 L
.48929 .95339 L
.48888 .953 L
.48846 .95269 L
.48811 .95252 L
.48779 .95251 L
.48755 .95264 L
.48738 .95287 L
.48736 .95312 L
.48748 .95354 L
.48782 .95412 L
.48843 .95481 L
.48934 .95552 L
.49058 .9562 L
Mistroke
.49218 .95678 L
.49412 .95724 L
.49642 .95753 L
.49909 .95761 L
.50215 .95748 L
.50561 .95715 L
.50927 .9567 L
.51362 .95617 L
.51768 .95559 L
.52227 .95498 L
.52747 .95435 L
.53196 .95371 L
.53691 .95308 L
.54191 .95247 L
.54734 .95189 L
.55199 .95133 L
.55713 .95076 L
.56235 .95018 L
.56727 .94956 L
.5724 .94887 L
.57757 .94808 L
.58284 .9472 L
.58802 .94624 L
.59341 .9452 L
.59868 .94413 L
.60399 .94303 L
.60887 .94196 L
.61371 .94088 L
.61832 .93986 L
.62251 .93895 L
.62625 .9382 L
.62962 .9376 L
.6325 .93714 L
.63475 .93682 L
.63665 .93663 L
.63809 .93652 L
.63911 .93646 L
.63976 .93643 L
.64009 .93643 L
.64014 .93645 L
.63997 .93646 L
.63963 .93648 L
.63922 .93649 L
.63879 .93648 L
.63838 .93644 L
.63801 .93634 L
.63772 .93619 L
.63752 .93597 L
.63752 .93571 L
.63778 .93539 L
Mistroke
.63831 .93501 L
.63915 .93459 L
.64029 .93412 L
.6418 .93363 L
.64373 .93313 L
.64609 .93257 L
.64884 .93199 L
.65186 .93138 L
.65526 .93074 L
.65893 .93006 L
.66272 .92937 L
.66649 .92868 L
.67032 .928 L
.67368 .92736 L
.67707 .92676 L
.68009 .92621 L
.6826 .92572 L
.68489 .92525 L
.68691 .92482 L
.68856 .92445 L
.69003 .92417 L
.69126 .924 L
.6923 .92391 L
.69309 .92389 L
.69366 .9239 L
.69417 .92391 L
.69467 .92387 L
.69519 .92372 L
.69579 .92342 L
.69635 .92297 L
.69692 .92239 L
.69743 .92171 L
.69785 .92095 L
.69825 .92011 L
.69859 .91922 L
.69888 .91831 L
.69913 .91744 L
.69935 .91666 L
.69953 .91608 L
.69971 .91562 L
.69983 .91538 L
.69993 .91523 L
.69998 .91518 L
.69998 .91522 L
.69995 .91538 L
.69992 .91555 L
.69988 .9157 L
.69981 .91586 L
.6997 .91606 L
.69959 .91627 L
Mistroke
.69947 .91646 L
.69934 .91658 L
.69918 .91669 L
.69901 .91683 L
.69884 .91698 L
.69866 .91717 L
.69849 .91735 L
.69834 .91754 L
.69823 .91765 L
.69816 .91772 L
.69818 .91773 L
.6983 .9176 L
.69854 .91732 L
.69881 .91691 L
.69911 .91643 L
.6994 .91596 L
.69966 .91554 L
.69987 .91521 L
.69999 .91492 L
.70002 .91459 L
.69994 .91425 L
.69974 .91395 L
.69942 .91364 L
.69899 .91326 L
.69844 .91279 L
.69779 .91218 L
.69705 .91131 L
.69621 .91038 L
.69526 .90912 L
.69423 .90775 L
.69306 .90649 L
.69178 .90486 L
.69039 .90323 L
.6889 .90153 L
.68748 .89987 L
.686 .89835 L
.68449 .8969 L
.68305 .89554 L
.6816 .89427 L
.68038 .89305 L
.67922 .89195 L
.67816 .89102 L
.67724 .89017 L
.67646 .88937 L
.67585 .88861 L
.67536 .88788 L
.67496 .88717 L
.67464 .88648 L
.67437 .88583 L
.67415 .88523 L
Mistroke
.67395 .88468 L
.67373 .88417 L
.67354 .88374 L
.67339 .88337 L
.67329 .88307 L
.67323 .88282 L
.67321 .88259 L
.6732 .88238 L
.67321 .88219 L
.67322 .88202 L
.67322 .88187 L
.67323 .88169 L
.67325 .88149 L
.67329 .88128 L
.67337 .88109 L
.67346 .88093 L
.67357 .88082 L
.67367 .88075 L
.67376 .88072 L
.67383 .88073 L
.67385 .88076 L
.67385 .8808 L
.67379 .88083 L
.67377 .88085 L
.67376 .88085 L
.67375 .88086 L
.67374 .88089 L
.67374 .88094 L
.67377 .88101 L
.67383 .88107 L
.67395 .8811 L
.67414 .88105 L
.67439 .88093 L
.67471 .88071 L
.6751 .8804 L
.67551 .88001 L
.67591 .87956 L
.6763 .87907 L
.67668 .87854 L
.67705 .87803 L
.67735 .87753 L
.67758 .87709 L
.6777 .87672 L
.6777 .87645 L
.67753 .87627 L
.67721 .87617 L
.67672 .87612 L
.67608 .87607 L
.67534 .87601 L
.67453 .87591 L
Mistroke
.67372 .87573 L
.67294 .87552 L
.67217 .87523 L
.67144 .87491 L
.67076 .87459 L
.6702 .87426 L
.66977 .87392 L
.66944 .87356 L
.66916 .87315 L
.66891 .87266 L
.66865 .87209 L
.66835 .87144 L
.66796 .87072 L
.66746 .86992 L
.66692 .86907 L
.66633 .86814 L
.66575 .86722 L
.66518 .86628 L
.66462 .86531 L
.66413 .86444 L
.6637 .86362 L
.66333 .86283 L
.66302 .86207 L
.66277 .86131 L
.66257 .86056 L
.66242 .8598 L
.66229 .85901 L
.66218 .8582 L
.66205 .85729 L
.66188 .85633 L
.66167 .85526 L
.66141 .85407 L
.6611 .85291 L
.66078 .85176 L
.66046 .85068 L
.66016 .84971 L
.65988 .84889 L
.65964 .84824 L
.65944 .84776 L
.65926 .84738 L
.65909 .84707 L
.65892 .84678 L
.65877 .84649 L
.65864 .8462 L
.65854 .84591 L
.65849 .84564 L
.65847 .84541 L
.65849 .84522 L
.65852 .84505 L
.65855 .84489 L
Mistroke
.65858 .84471 L
.65859 .8445 L
.65859 .8443 L
.65859 .84412 L
.65859 .84397 L
.65859 .84387 L
.65859 .84381 L
.65859 .84379 L
.65859 .84381 L
.65859 .84385 L
.65859 .84389 L
.65859 .84394 L
.65859 .84401 L
.65859 .84409 L
.6586 .84415 L
.65861 .84419 L
.65862 .84416 L
.65862 .84406 L
.6586 .84388 L
.65858 .84362 L
.65855 .84328 L
.65852 .84288 L
.65849 .84244 L
.65846 .84197 L
.65843 .8415 L
.65842 .84104 L
.65841 .84058 L
.6584 .84016 L
.6584 .8398 L
.6584 .8395 L
.65842 .83929 L
.65844 .83918 L
.65848 .83917 L
.65853 .83924 L
.6586 .83938 L
.65866 .83951 L
.6587 .8396 L
.6587 .8396 L
.65866 .83951 L
.65857 .83933 L
.65843 .83905 L
.65826 .83867 L
.65807 .8382 L
.65786 .8377 L
.65764 .83721 L
.65742 .83679 L
.6572 .83643 L
.65702 .83617 L
.6569 .83602 L
.65684 .83601 L
Mistroke
.65679 .83613 L
.65675 .83637 L
.65669 .83673 L
.65661 .83718 L
.65643 .8377 L
.65612 .83825 L
.65567 .8388 L
.6551 .83929 L
.65439 .83969 L
.65354 .84 L
.65266 .84021 L
.65175 .84036 L
.6508 .84044 L
.64983 .84047 L
.64889 .8405 L
.64802 .84051 L
.64737 .84051 L
.64688 .84046 L
.64652 .84034 L
.6463 .84019 L
.64617 .8401 L
.6461 .8401 L
.64602 .84024 L
.64587 .84054 L
.64561 .84101 L
.64523 .84169 L
.64472 .84258 L
.64405 .84369 L
.64316 .84504 L
.64221 .84644 L
.64096 .84823 L
.63983 .84994 L
.63865 .85176 L
.63743 .85364 L
.63622 .85549 L
.63508 .85719 L
.63409 .85861 L
.63324 .85981 L
.63248 .86082 L
.63182 .86162 L
.63124 .86223 L
.63074 .86266 L
.63032 .86293 L
.63001 .863 L
.62982 .86291 L
.62973 .86274 L
.62968 .86257 L
.62966 .86248 L
.62961 .86255 L
.62951 .86282 L
Mistroke
.62937 .8633 L
.62918 .86401 L
.62898 .86499 L
.62876 .86629 L
.62855 .86798 L
.62835 .87005 L
.62809 .87226 L
.6278 .87486 L
.62749 .87794 L
.62719 .88097 L
.62694 .88449 L
.62677 .88784 L
.62667 .89138 L
.62667 .89508 L
.62678 .89818 L
.62698 .90139 L
.62725 .90449 L
.62762 .90717 L
.62806 .90968 L
.62855 .91193 L
.62911 .91393 L
.6297 .91579 L
.6303 .91756 L
.6309 .91937 L
.63148 .92075 L
.63205 .92224 L
.6326 .9236 L
.63311 .92488 L
.63353 .92605 L
.63386 .92718 L
.63406 .92818 L
.63414 .92905 L
.63406 .92978 L
.63381 .93041 L
.63339 .93088 L
.6329 .93122 L
.63234 .9315 L
.63175 .93176 L
.63112 .93198 L
.63066 .93225 L
.63023 .93262 L
.62987 .93303 L
.62959 .93342 L
.62946 .93382 L
.62949 .93424 L
.62962 .93465 L
.62985 .93499 L
.63013 .93526 L
.63042 .93544 L
.6306 .93553 L
Mistroke
.63066 .93552 L
.63053 .93545 L
.63025 .93536 L
.62983 .9352 L
.62927 .93497 L
.62857 .93477 L
.6278 .93459 L
.62698 .93439 L
.62618 .9342 L
.62542 .93401 L
.62477 .93389 L
.62421 .93374 L
.62378 .9336 L
.62346 .93352 L
.62326 .93347 L
.62314 .93339 L
.6231 .93333 L
.62314 .93328 L
.62323 .93323 L
.62333 .93316 L
.62344 .93306 L
.62356 .93298 L
.62367 .93294 L
.62375 .93291 L
.6238 .9329 L
.62387 .93293 L
.62396 .933 L
.62408 .93306 L
.62424 .93308 L
.62442 .93309 L
.6247 .93311 L
.62501 .93313 L
.62537 .93315 L
.62575 .93322 L
.62619 .93333 L
.62661 .9335 L
.62707 .9337 L
.62752 .93387 L
.62789 .93402 L
.62814 .93411 L
.62819 .93413 L
.62802 .93413 L
.62771 .93412 L
.62723 .93407 L
.62658 .93395 L
.62587 .93384 L
.62517 .93373 L
.62441 .93358 L
.62376 .93341 L
.62327 .93321 L
Mistroke
.62297 .93303 L
.62287 .93289 L
.62296 .93282 L
.62321 .9328 L
.62361 .93283 L
.62411 .93287 L
.62468 .93294 L
.62533 .93304 L
.62596 .93314 L
.62658 .93318 L
.62716 .93316 L
.62775 .93312 L
.62835 .9331 L
.629 .9331 L
.62967 .93312 L
.63041 .93318 L
.63122 .93333 L
.63208 .93353 L
.63294 .9338 L
.63375 .93412 L
.63453 .93446 L
.63529 .93478 L
.63604 .93504 L
.63673 .93526 L
.63742 .93539 L
.63815 .93543 L
.63889 .93533 L
.63968 .9351 L
.64053 .93479 L
.64143 .93443 L
.64228 .934 L
.64323 .93356 L
.64425 .93312 L
.64533 .93274 L
.64645 .93243 L
.64751 .93219 L
.64847 .93201 L
.64929 .93185 L
.64992 .93171 L
.65036 .93159 L
.65065 .93148 L
.65075 .93129 L
.65075 .93101 L
.65067 .93061 L
.65052 .93007 L
.65024 .92938 L
.64982 .92852 L
.64925 .9275 L
.64851 .92629 L
.64762 .925 L
Mistroke
.64659 .92361 L
.6454 .92195 L
.64421 .9206 L
.64291 .91899 L
.64158 .91736 L
.64034 .91579 L
.63906 .91423 L
.63791 .91283 L
.63683 .91154 L
.63581 .91036 L
.63495 .90945 L
.63421 .90871 L
.63364 .90819 L
.63326 .90792 L
.63306 .90787 L
.63302 .90799 L
.6331 .90816 L
.63329 .90834 L
.63356 .90852 L
.63391 .90866 L
.63437 .9088 L
.63497 .90894 L
.63573 .90915 L
.63666 .9094 L
.63778 .9097 L
.63917 .91009 L
.6408 .91059 L
.64267 .91124 L
.64473 .91199 L
.64695 .91278 L
.6494 .91361 L
.65171 .91446 L
.65423 .91536 L
.65663 .91611 L
.65907 .91675 L
.66157 .91738 L
.66384 .91787 L
.66593 .91826 L
.66797 .91857 L
.66981 .91876 L
.67146 .91893 L
.67296 .9191 L
.67426 .91927 L
.67543 .91948 L
.67646 .9197 L
.67737 .91998 L
.67805 .92028 L
.67865 .92059 L
.67914 .92088 L
.6795 .92113 L
Mistroke
.67975 .92135 L
.6799 .92146 L
.67996 .92147 L
.67995 .92145 L
.67992 .92142 L
.67984 .92141 L
.67974 .92146 L
.67964 .92159 L
.67956 .92182 L
.67949 .92208 L
.67943 .92235 L
.6794 .92259 L
.67941 .92281 L
.6794 .92295 L
.67937 .92299 L
.67932 .92298 L
.67926 .92295 L
.6792 .92289 L
.67916 .92276 L
.67917 .92263 L
.67922 .9225 L
.67927 .9224 L
.67929 .92234 L
.67925 .92237 L
.67918 .92249 L
.67905 .92271 L
.6789 .92299 L
.67879 .92335 L
.67875 .92375 L
.67879 .92412 L
.67897 .92443 L
.67926 .92468 L
.67961 .92486 L
.68011 .92495 L
.68069 .92489 L
.68138 .92466 L
.68217 .92423 L
.68302 .92359 L
.68392 .92277 L
.68481 .92179 L
.68567 .92074 L
.68646 .9196 L
.68711 .91845 L
.68757 .91736 L
.68785 .91641 L
.68803 .91559 L
.68813 .91491 L
.68817 .91441 L
.68815 .9141 L
.6881 .91395 L
Mistroke
.68803 .91394 L
.68797 .91405 L
.68793 .91423 L
.6879 .91446 L
.68789 .91472 L
.68789 .91497 L
.6879 .91517 L
.68791 .91528 L
.68793 .9153 L
.68795 .91527 L
.68796 .91522 L
.68794 .91517 L
.68789 .91512 L
.68781 .91513 L
.68772 .91519 L
.68761 .91528 L
.68751 .91536 L
.68742 .91541 L
.68733 .91542 L
.68725 .91543 L
.68715 .91543 L
.68707 .91547 L
.68699 .91554 L
.68693 .91565 L
.68693 .91578 L
.68701 .91593 L
.6872 .91605 L
.68751 .91611 L
.68796 .91611 L
.68856 .91612 L
.68931 .91614 L
.6902 .91613 L
.69127 .91613 L
.69256 .91606 L
.69411 .91586 L
.69601 .91548 L
.69814 .9149 L
.70061 .91412 L
.70338 .91313 L
.70635 .91193 L
.70968 .91054 L
.71317 .90896 L
.71646 .90725 L
.72012 .90526 L
.7238 .90299 L
.72772 .90045 L
.73182 .89784 L
.73537 .89504 L
.73923 .89219 L
.7431 .88928 L
Mistroke
.74679 .88636 L
.75019 .8835 L
.75372 .8805 L
.75719 .87749 L
.76039 .87463 L
.76379 .87166 L
.76686 .86883 L
.76965 .86615 L
.77243 .86361 L
.77483 .86132 L
.77703 .85922 L
.7789 .85727 L
.78045 .85563 L
.78176 .85416 L
.78278 .85288 L
.78352 .8518 L
.78399 .85091 L
.78422 .85019 L
.78422 .84963 L
.78407 .84916 L
.78382 .84876 L
.78351 .84841 L
.78317 .84809 L
.78283 .84777 L
.78249 .84746 L
.78216 .84715 L
.78186 .84687 L
.78163 .8466 L
.78148 .84635 L
.78138 .84607 L
.78129 .84573 L
.78121 .84529 L
.78111 .84474 L
.78093 .84411 L
.78065 .84338 L
.78024 .84257 L
.77969 .84168 L
.77899 .84072 L
.77815 .83971 L
.77724 .83868 L
.77629 .83779 L
.77529 .83695 L
.77432 .83628 L
.77337 .83568 L
.77256 .83528 L
.77186 .8349 L
.77131 .83462 L
.77092 .83446 L
.77067 .83441 L
.77055 .83444 L
Mistroke
.77048 .83454 L
.77042 .83463 L
.77026 .83478 L
.76998 .83496 L
.76951 .83514 L
.76889 .83528 L
.76802 .8355 L
.76688 .83586 L
.76547 .8364 L
.76393 .83721 L
.7622 .8382 L
.76029 .8392 L
.75821 .84055 L
.75592 .84154 L
.75398 .84276 L
.75208 .84393 L
.7501 .84499 L
.7484 .84595 L
.74713 .84684 L
.74591 .84759 L
.74499 .84821 L
.74427 .84864 L
.74376 .8489 L
.74344 .84898 L
.74325 .84889 L
.74311 .84869 L
.74289 .84837 L
.74249 .84797 L
.74187 .84749 L
.74098 .84695 L
.73966 .84633 L
.7381 .84557 L
.73613 .84466 L
.73403 .84365 L
.73174 .84249 L
.72919 .84125 L
.72677 .83999 L
.72399 .83868 L
.72157 .83735 L
.71907 .83599 L
.7166 .83463 L
.71459 .83342 L
.7126 .83225 L
.71094 .83128 L
.70941 .83045 L
.708 .82976 L
.70667 .8292 L
.70542 .82874 L
.70414 .82838 L
.70279 .82811 L
Mistroke
.70136 .82791 L
.69982 .82777 L
.69837 .82768 L
.69664 .82759 L
.69466 .82747 L
.69269 .82728 L
.69052 .82702 L
.68819 .82669 L
.686 .82631 L
.68371 .82591 L
.68157 .82549 L
.67964 .8251 L
.67785 .82475 L
.67633 .82443 L
.675 .82416 L
.6739 .82391 L
.67298 .82366 L
.67224 .82339 L
.67168 .8231 L
.67125 .82287 L
.67097 .82272 L
.6708 .82263 L
.67074 .82263 L
.67075 .82269 L
.67081 .82279 L
.67091 .8229 L
.67102 .82301 L
.67109 .82311 L
.67114 .82322 L
.67112 .82329 L
.67101 .82331 L
.6708 .82324 L
.67048 .823 L
.6701 .82253 L
.66967 .82184 L
.66921 .82093 L
.6687 .81989 L
.66814 .81874 L
.6675 .81757 L
.6668 .81651 L
.66603 .81541 L
.66524 .81446 L
.66446 .81361 L
.66369 .81288 L
.66291 .81227 L
.66209 .81178 L
.66124 .81142 L
.66033 .81118 L
.65928 .81102 L
.65809 .81087 L
Mistroke
.65677 .81068 L
.65539 .81039 L
.65396 .80996 L
.65253 .80937 L
.65126 .80865 L
.64993 .80789 L
.64868 .80711 L
.64745 .80634 L
.64621 .80561 L
.64509 .80493 L
.64402 .80432 L
.64305 .80376 L
.64218 .80325 L
.64141 .80278 L
.64077 .80237 L
.64018 .80202 L
.63964 .80173 L
.63912 .80149 L
.63864 .80128 L
.63823 .80112 L
.63788 .80098 L
.6376 .80085 L
.63739 .80072 L
.63725 .80058 L
.63718 .80045 L
.63715 .80035 L
.63715 .80029 L
.63716 .80028 L
.63718 .80029 L
.63721 .80032 L
.63725 .80036 L
.63731 .80038 L
.63737 .80039 L
.63745 .80039 L
.63752 .80041 L
.63758 .80047 L
.63759 .80054 L
.63753 .80062 L
.6374 .80068 L
.63719 .80073 L
.63689 .80072 L
.63648 .80063 L
.63597 .80043 L
.63535 .80011 L
.63465 .79967 L
.63387 .79912 L
.63306 .79846 L
.63224 .79777 L
.63143 .79701 L
.63062 .79623 L
Mistroke
.6298 .79545 L
.62897 .79471 L
.62815 .79405 L
.62727 .79345 L
.62632 .79289 L
.62529 .79237 L
.62416 .7919 L
.62296 .79144 L
.62182 .79099 L
.62058 .79053 L
.61942 .79004 L
.61827 .78953 L
.61718 .78902 L
.61619 .78851 L
.61534 .788 L
.61463 .7875 L
.6141 .78707 L
.61375 .7867 L
.61358 .78641 L
.61356 .78618 L
.61364 .78602 L
.61379 .78593 L
.61398 .78592 L
.61419 .786 L
.61434 .78616 L
.61437 .78639 L
.6142 .78669 L
.61381 .78705 L
.61316 .78748 L
.61224 .78798 L
.61099 .78855 L
.60958 .78917 L
.60785 .78984 L
.60582 .79055 L
.6038 .7913 L
.60166 .79204 L
.59903 .79274 L
.5967 .7934 L
.5942 .79398 L
.5917 .79447 L
.58934 .79488 L
.5871 .79523 L
.5853 .79553 L
.58368 .7958 L
.58228 .79603 L
.58109 .79622 L
.5802 .79635 L
.57947 .79643 L
.57893 .79646 L
.57857 .79645 L
Mistroke
.57842 .79643 L
.57843 .79639 L
.57855 .79637 L
.57875 .79634 L
.57897 .79632 L
.57918 .7963 L
.57935 .79629 L
.57946 .79628 L
.57949 .79627 L
.57947 .79628 L
.57943 .79628 L
.57941 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.57939 .79628 L
.5794 .79628 L
.57944 .79625 L
.57952 .79618 L
.57963 .79609 L
.57976 .79599 L
.57987 .79588 L
.57994 .79581 L
.57992 .79579 L
.57981 .79584 L
.57954 .79599 L
.57907 .7963 L
.57837 .7968 L
.57742 .79754 L
.5762 .79855 L
.5748 .79982 L
.57316 .80137 L
.57123 .80326 L
.56907 .80535 L
.56685 .8077 L
.56432 .81039 L
.56176 .81286 L
.55898 .81596 L
.5564 .81854 L
.55354 .8213 L
.55072 .8242 L
.5479 .82694 L
.54486 .82978 L
Mistroke
.54228 .8322 L
.53933 .83487 L
.53682 .83711 L
.53423 .83941 L
.53183 .84179 L
.52927 .84419 L
.52718 .84647 L
.52511 .84895 L
.5231 .85141 L
.52117 .85397 L
.51926 .85669 L
.51751 .85907 L
.51572 .86181 L
.51385 .8644 L
.5119 .86724 L
.51004 .87007 L
.50827 .87248 L
.50639 .87496 L
.50439 .87745 L
.50245 .87961 L
.50062 .88158 L
.49884 .8834 L
.49722 .88498 L
.49578 .8863 L
.49444 .88745 L
.4932 .88842 L
.49207 .88918 L
.49105 .88976 L
.49001 .89019 L
.48892 .89048 L
.48778 .89063 L
.48657 .89067 L
.48528 .89064 L
.48393 .89055 L
.48274 .89041 L
.48148 .89024 L
.48023 .89007 L
.47906 .8899 L
.47792 .88973 L
.47691 .88957 L
.47603 .88944 L
.47533 .88931 L
.47483 .8892 L
.47455 .88908 L
.47449 .88893 L
.47459 .88877 L
.4748 .88864 L
.47502 .88855 L
.47518 .8885 L
.47523 .88853 L
Mistroke
.47511 .88868 L
.47479 .88902 L
.47426 .88959 L
.47348 .89038 L
.47252 .89152 L
.47133 .89303 L
.47005 .8947 L
.4686 .89667 L
.46692 .899 L
.46508 .90148 L
.46311 .90451 L
.46112 .90727 L
.45897 .91037 L
.45685 .91372 L
.4549 .9168 L
.45294 .92012 L
.45103 .9234 L
.44941 .92598 L
.44796 .92851 L
.44669 .93097 L
.44559 .93325 L
.44479 .93493 L
.44416 .9364 L
.44367 .93764 L
.44326 .93858 L
.44285 .93924 L
.44234 .93965 L
.44162 .93985 L
.44064 .93988 L
.43931 .93978 L
.43762 .93954 L
.43601 .93915 L
.43402 .93868 L
.43148 .9382 L
.42925 .93768 L
.4267 .93715 L
.42372 .93656 L
.42127 .93593 L
.4187 .93528 L
.41635 .93462 L
.4142 .93397 L
.41223 .93335 L
.41064 .93277 L
.40933 .93226 L
.40821 .93186 L
.40729 .93156 L
.40658 .93134 L
.40609 .93115 L
.4058 .93098 L
.40569 .93082 L
Mistroke
.40574 .93068 L
.40588 .93054 L
.40611 .93041 L
.40637 .93029 L
.40665 .93021 L
.40692 .93017 L
.40716 .93016 L
.40739 .93018 L
.40759 .93021 L
.40773 .93022 L
.4078 .93023 L
.40782 .93023 L
.40781 .93024 L
.40777 .93024 L
.40773 .93024 L
.4077 .93025 L
.40769 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40768 .93025 L
.40769 .93025 L
.40772 .93028 L
.40779 .93034 L
.40789 .93043 L
.40801 .93055 L
.40812 .93066 L
.40819 .93075 L
.40818 .93077 L
.40803 .93068 L
.40773 .93045 L
.40725 .93005 L
.40659 .92945 L
.40573 .92864 L
.40468 .92762 L
.40355 .92647 L
.40219 .92507 L
.40062 .92347 L
.39901 .92172 L
.39722 .91978 L
.39536 .91763 L
.3935 .91547 L
.39154 .91316 L
.38967 .91079 L
.38774 .90847 L
Mistroke
.38584 .906 L
.38395 .90361 L
.38205 .90107 L
.38015 .89849 L
.37826 .8958 L
.37642 .89306 L
.37455 .89018 L
.37281 .88734 L
.37102 .88444 L
.36924 .88158 L
.36752 .87865 L
.36577 .87582 L
.3641 .87296 L
.36247 .87013 L
.36091 .86726 L
.35943 .8645 L
.35805 .86173 L
.35665 .85901 L
.35539 .85622 L
.35411 .85349 L
.3528 .85065 L
.35153 .84787 L
.35028 .84507 L
.34906 .84216 L
.34794 .83963 L
.34683 .83716 L
.34579 .83479 L
.34488 .8328 L
.34398 .8309 L
.34317 .8294 L
.34242 .82806 L
.34177 .82686 L
.34127 .82578 L
.34094 .82475 L
.34079 .82375 L
.34082 .82265 L
.34097 .82129 L
.34119 .8196 L
.34143 .81761 L
.34164 .81565 L
.34182 .81332 L
.34193 .81049 L
.34208 .80768 L
.34223 .80468 L
.34239 .80205 L
.34254 .79948 L
.34268 .79723 L
.34279 .79509 L
.34286 .79337 L
.34291 .79187 L
Mistroke
.34298 .79061 L
.34309 .78957 L
.34327 .78863 L
.34353 .78774 L
.34389 .78687 L
.34433 .78596 L
.34482 .78507 L
.34534 .78414 L
.34579 .78318 L
.34626 .78213 L
.34672 .78102 L
.34715 .77996 L
.34756 .77905 L
.34793 .7783 L
.34823 .77774 L
.34846 .77738 L
.34863 .77723 L
.34874 .77725 L
.34881 .77738 L
.34883 .77753 L
.34882 .77763 L
.34881 .77764 L
.34875 .77748 L
.34863 .77707 L
.3484 .77634 L
.34804 .77528 L
.3475 .77392 L
.34675 .77218 L
.34587 .77026 L
.34472 .76792 L
.34343 .76544 L
.34184 .76254 L
.34023 .75961 L
.33832 .75636 L
.33631 .75292 L
.33442 .74968 L
.33228 .74621 L
.33009 .74276 L
.32782 .73922 L
.32568 .73593 L
.32354 .73263 L
.32141 .72931 L
.31946 .72628 L
.31751 .72315 L
.31562 .72 L
.31378 .71677 L
.31207 .71368 L
.31041 .71043 L
.3088 .70716 L
.30731 .70371 L
Mistroke
.30587 .70043 L
.30448 .69697 L
.30319 .69351 L
.30193 .69026 L
.30081 .68688 L
.29975 .68336 L
.29885 .68049 L
.29801 .67758 L
.29727 .67473 L
.29664 .67233 L
.29609 .67005 L
.29562 .66796 L
.29523 .66618 L
.29492 .66448 L
.29467 .66288 L
.29448 .6613 L
.29433 .6598 L
.2942 .65833 L
.29407 .65687 L
.29395 .65549 L
.29385 .65423 L
.29377 .65307 L
.2937 .65201 L
.29366 .65109 L
.29366 .65028 L
.29367 .64957 L
.2937 .64893 L
.29375 .6484 L
.29378 .64796 L
.29379 .6476 L
.2938 .6473 L
.2938 .64707 L
.2938 .64688 L
.2938 .64671 L
.2938 .64657 L
.29381 .64644 L
.29381 .64632 L
.29381 .64621 L
.29381 .64616 L
.29381 .64614 L
.29381 .64616 L
.29381 .6462 L
.29381 .64624 L
.29381 .64631 L
.29381 .64641 L
.29381 .64655 L
.2938 .64669 L
.2938 .6468 L
.2938 .64684 L
.2938 .6468 L
Mistroke
.2938 .64663 L
.29381 .64631 L
.29381 .64578 L
.29382 .64499 L
.29383 .64393 L
.29384 .6426 L
.29386 .64122 L
.29386 .6394 L
.29386 .63759 L
.29383 .63552 L
.29379 .63334 L
.29377 .63106 L
.29378 .62885 L
.29384 .62659 L
.29398 .62441 L
.2942 .62236 L
.2945 .62027 L
.29487 .6183 L
.29531 .6164 L
.29578 .6145 L
.29626 .61282 L
.29674 .61117 L
.29721 .60966 L
.29764 .6083 L
.29804 .60711 L
.2984 .60617 L
.29873 .60544 L
.29902 .60497 L
.2993 .60478 L
.29958 .60484 L
.29986 .60511 L
.30018 .60555 L
.30052 .6061 L
.30092 .60672 L
.30138 .60735 L
.3019 .60801 L
.30246 .60865 L
.30298 .60922 L
.30343 .60969 L
.30376 .61 L
.30391 .61013 L
.30384 .61003 L
.30356 .6097 L
.30308 .60912 L
.30243 .60827 L
.30166 .60714 L
.30081 .60572 L
.29998 .60418 L
.29908 .60213 L
.29825 .59993 L
Mistroke
.29747 .59732 L
.29675 .59437 L
.29616 .59124 L
.29569 .588 L
.29537 .58453 L
.29515 .5806 L
.29502 .57742 L
.29493 .57369 L
.29484 .57018 L
.29471 .56642 L
.29454 .56293 L
.29434 .55921 L
.29412 .55541 L
.29388 .55216 L
.29361 .54861 L
.29332 .54508 L
.29301 .54146 L
.29267 .53782 L
.29232 .53426 L
.29197 .53048 L
.29162 .52669 L
.29127 .52337 L
.29093 .51975 L
.29055 .51607 L
.29014 .51297 L
.28969 .50969 L
.2892 .5066 L
.28872 .50368 L
.28829 .50117 L
.28795 .49894 L
.28771 .49698 L
.28754 .49537 L
.28736 .49413 L
.28711 .49305 L
.28674 .49213 L
.28622 .49134 L
.2855 .49065 L
.28461 .49002 L
.28357 .48942 L
.28243 .48886 L
.28127 .48834 L
.28029 .48789 L
.27906 .48745 L
.27805 .48698 L
.27709 .48642 L
.27621 .48584 L
.27551 .48535 L
.27503 .48497 L
.27476 .48476 L
.27461 .48472 L
Mistroke
.27449 .48484 L
.27431 .4851 L
.27394 .48548 L
.27326 .48594 L
.27224 .48646 L
.27083 .48702 L
.26919 .48761 L
.26723 .48823 L
.26489 .48889 L
.26239 .48957 L
.25982 .49024 L
.25685 .49085 L
.2539 .49137 L
.25116 .49179 L
.24781 .49211 L
.24506 .49233 L
.24209 .49247 L
.23907 .49252 L
.23599 .49251 L
.23268 .49243 L
.22993 .49228 L
.22662 .49202 L
.22373 .49163 L
.22048 .49113 L
.21738 .49051 L
.21403 .4898 L
.211 .48898 L
.20765 .4881 L
.20469 .48714 L
.20154 .48607 L
.1987 .48489 L
.19582 .48368 L
.193 .48235 L
.19025 .48104 L
.18757 .47968 L
.18491 .47831 L
.18224 .47703 L
.17979 .47581 L
.17715 .47463 L
.17454 .47351 L
.17202 .47247 L
.16927 .47144 L
.16669 .47041 L
.16397 .46939 L
.16138 .46835 L
.15868 .46727 L
.15634 .46621 L
.15384 .46513 L
.15182 .46399 L
.14989 .46277 L
Mistroke
.14814 .46151 L
.1466 .46007 L
.14532 .45854 L
.14423 .45681 L
.14335 .45494 L
.14261 .45299 L
.14197 .4508 L
.14143 .44868 L
.14094 .44639 L
.14048 .44391 L
.14003 .44165 L
.13957 .43927 L
.13915 .43684 L
.13876 .43483 L
.13837 .43284 L
.13804 .43105 L
.13776 .42951 L
.13756 .42831 L
.13743 .42743 L
.13741 .42679 L
.13748 .42635 L
.13762 .42604 L
.13782 .42581 L
.13812 .42559 L
.13853 .42532 L
.13909 .42499 L
.1398 .42459 L
.14067 .42413 L
.14166 .42362 L
.14272 .42306 L
.14384 .42242 L
.14498 .42172 L
.14603 .42103 L
.14707 .4204 L
.14795 .41985 L
.14872 .41941 L
.14939 .41908 L
.14994 .41889 L
.1504 .41884 L
.1508 .41892 L
.15117 .41912 L
.15153 .41941 L
.15192 .41982 L
.15235 .42036 L
.15283 .421 L
.15342 .42174 L
.15411 .42256 L
.15486 .42341 L
.15564 .42427 L
.15637 .42511 L
Mistroke
.15705 .42591 L
.15767 .42665 L
.15822 .42735 L
.15871 .42794 L
.15916 .42849 L
.15963 .42907 L
.16016 .42963 L
.16077 .43028 L
.16152 .431 L
.1624 .43186 L
.16348 .43289 L
.1648 .43417 L
.16621 .43569 L
.1679 .4372 L
.16956 .43897 L
.17146 .44077 L
.17341 .44281 L
.17534 .44457 L
.17739 .44632 L
.17913 .44794 L
.18085 .44939 L
.18241 .45062 L
.18369 .45156 L
.18482 .4523 L
.18575 .45282 L
.18646 .45315 L
.18697 .45334 L
.18731 .45343 L
.18749 .45344 L
.18754 .4534 L
.18751 .45333 L
.18741 .45324 L
.18727 .45314 L
.18713 .45308 L
.18699 .45305 L
.18688 .45304 L
.18683 .45304 L
.18686 .45304 L
.187 .45304 L
.18724 .45304 L
.1876 .45304 L
.18808 .45304 L
.18872 .45303 L
.18948 .45303 L
.19046 .45302 L
.19159 .45302 L
.19293 .45301 L
.19434 .45301 L
.19591 .453 L
.19747 .45299 L
Mistroke
.19904 .45293 L
.20058 .45282 L
.20194 .45267 L
.20316 .45248 L
.20425 .45232 L
.2051 .45222 L
.20579 .45223 L
.2063 .45242 L
.20664 .45285 L
.20684 .45356 L
.20693 .45462 L
.20697 .45609 L
.207 .45799 L
.20707 .45983 L
.20719 .46242 L
.20738 .46529 L
.20773 .46803 L
.20824 .47129 L
.20897 .47507 L
.20979 .4781 L
.21077 .48159 L
.21191 .48472 L
.21311 .48784 L
.21443 .49046 L
.21576 .49291 L
.21716 .49511 L
.21865 .49691 L
.22016 .49857 L
.22185 .50003 L
.22371 .5013 L
.22565 .50244 L
.22786 .50347 L
.22991 .50435 L
.23216 .50516 L
.23455 .5059 L
.23675 .50656 L
.23909 .50716 L
.24157 .50767 L
.24371 .50806 L
.24609 .5083 L
.24811 .50836 L
.25022 .5083 L
.25219 .50798 L
.25407 .50747 L
.25588 .50681 L
.25765 .50602 L
.25935 .50515 L
.26102 .50426 L
.26266 .50328 L
.26429 .50228 L
Mistroke
.26572 .50119 L
.26718 .50005 L
.26859 .4989 L
.26981 .49778 L
.27095 .49682 L
.27199 .49597 L
.2729 .49529 L
.27365 .49477 L
.27427 .49439 L
.27478 .49414 L
.2752 .49399 L
.27552 .49393 L
.27579 .49397 L
.27604 .49414 L
.27625 .4944 L
.27642 .49473 L
.27653 .49507 L
.27658 .49536 L
.27658 .49561 L
.27656 .49578 L
.27652 .49587 L
.27648 .49587 L
.27645 .49582 L
.27642 .49575 L
.27641 .4957 L
.2764 .49568 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.27641 .49567 L
.2764 .49567 L
.2764 .4957 L
.2764 .49575 L
.27639 .49582 L
.27637 .4959 L
.27632 .49596 L
.27623 .496 L
.27613 .496 L
.27603 .49595 L
.27595 .49583 L
.27592 .49563 L
.27599 .4953 L
Mistroke
.27619 .49481 L
.27654 .49414 L
.27708 .49327 L
.27785 .49221 L
.27888 .49092 L
.28008 .48942 L
.28153 .48768 L
.28322 .48574 L
.28509 .48355 L
.2871 .48121 L
.28933 .47851 L
.29146 .47598 L
.29367 .47317 L
.29582 .47039 L
.29798 .46748 L
.29983 .4646 L
.30167 .46168 L
.30333 .45851 L
.30491 .45533 L
.30638 .45247 L
.3078 .44933 L
.30918 .44592 L
.31051 .44235 L
.31191 .43948 L
.31327 .43618 L
.31465 .43266 L
.31608 .42955 L
.31753 .42623 L
.319 .42269 L
.32048 .41972 L
.32195 .41649 L
.32342 .41351 L
.32488 .41047 L
.32632 .40782 L
.32768 .40509 L
.32899 .40258 L
.33023 .40008 L
.33143 .3976 L
.33251 .39537 L
.33352 .39318 L
.33448 .39128 L
.33533 .38951 L
.33613 .388 L
.33689 .38667 L
.33762 .38562 L
.33837 .38476 L
.33916 .38409 L
.33998 .38362 L
.34089 .38332 L
.34188 .38314 L
Mistroke
.34299 .38306 L
.34409 .38304 L
.3453 .38307 L
.34657 .38313 L
.34778 .38321 L
.34898 .38324 L
.35005 .38323 L
.35107 .38311 L
.35191 .38307 L
.35258 .38305 L
.35308 .38307 L
.35338 .38312 L
.3535 .38319 L
.35345 .38328 L
.35328 .38338 L
.35303 .38347 L
.3528 .38354 L
.35266 .38356 L
.35271 .38352 L
.35302 .38342 L
.35363 .38324 L
.35454 .38297 L
.35576 .38261 L
.35725 .38217 L
.35898 .38166 L
.36091 .38111 L
.36303 .38053 L
.36533 .37991 L
.36773 .37926 L
.37023 .37857 L
.37272 .37783 L
.37521 .37703 L
.37768 .37618 L
.38012 .37528 L
.38253 .37432 L
.38498 .37331 L
.38746 .37227 L
.38999 .37124 L
.39255 .37018 L
.39513 .36911 L
.39761 .36809 L
.39996 .36717 L
.4021 .36635 L
.404 .36564 L
.40559 .36506 L
.40688 .36465 L
.40786 .36442 L
.40854 .3644 L
.40891 .36456 L
.40901 .36484 L
Mistroke
.40889 .36517 L
.40861 .36548 L
.40821 .36576 L
.40776 .36599 L
.40731 .36619 L
.40688 .36637 L
.40648 .36656 L
.40614 .36673 L
.40588 .36691 L
.40575 .36706 L
.40581 .36725 L
.4061 .36745 L
.40664 .36771 L
.40743 .36803 L
.40844 .36848 L
.4096 .36906 L
.41088 .36976 L
.41219 .37058 L
.41345 .37146 L
.41462 .37234 L
.41567 .3732 L
.41659 .37396 L
.41738 .37457 L
.41806 .37502 L
.4187 .37525 L
.41935 .37526 L
.42008 .37499 L
.42097 .3744 L
.42207 .37346 L
.42342 .37221 L
.425 .37069 L
.42683 .36898 L
.42886 .36722 L
.431 .36541 L
.43313 .36353 L
.43519 .36163 L
.43709 .3597 L
.43882 .35784 L
.44032 .35594 L
.44158 .35418 L
.44267 .35248 L
.44376 .35069 L
.44501 .34873 L
.44652 .34659 L
.44839 .34417 L
.45065 .34132 L
.45323 .33786 L
.45614 .33392 L
.45929 .32929 L
.46247 .32539 L
Mistroke
.46571 .32086 L
.46889 .31698 L
.47178 .31336 L
.47443 .31017 L
.47676 .30715 L
.47868 .3043 L
.48014 .30202 L
.48113 .30055 L
.48169 .29977 L
.48188 .29947 L
.48179 .29948 L
.48152 .29978 L
.48122 .30026 L
.48103 .30065 L
.48097 .30078 L
.48099 .30086 L
.48105 .30098 L
.4812 .30111 L
.48147 .30122 L
.48194 .30124 L
.48273 .30113 L
.48398 .30086 L
.48578 .30039 L
.48811 .29974 L
.49101 .29891 L
.49443 .29793 L
.49833 .29683 L
.50229 .29576 L
.50643 .29468 L
.5104 .29369 L
.51444 .29272 L
.51896 .29171 L
.52323 .29072 L
.52775 .28971 L
.53251 .28871 L
.53746 .28768 L
.54252 .28663 L
.54715 .28558 L
.55172 .28453 L
.55606 .28348 L
.55997 .28249 L
.56332 .28151 L
.5665 .28053 L
.5696 .27958 L
.57244 .27872 L
.57477 .27802 L
.57652 .27749 L
.57778 .27713 L
.57867 .27688 L
.57945 .27673 L
Mistroke
.58039 .2766 L
.58165 .27642 L
.58332 .27607 L
.58584 .27549 L
.58902 .27465 L
.59296 .27358 L
.59792 .27226 L
.60412 .27072 L
.6113 .26906 L
.61953 .26729 L
.62807 .26549 L
.6352 .26373 L
.64207 .26209 L
.64853 .26064 L
.65449 .25926 L
.66064 .25799 L
.66671 .2569 L
.67133 .25605 L
.67391 .25551 L
.67496 .25524 L
.6752 .25517 L
.67501 .25525 L
.67437 .2554 L
.67365 .25554 L
.6737 .25561 L
.67438 .25559 L
.67548 .25555 L
.67695 .25558 L
.67882 .25572 L
.68108 .25599 L
.68372 .25637 L
.68675 .25687 L
.6901 .25744 L
.69367 .25808 L
.69723 .25876 L
.70072 .25943 L
.70397 .26011 L
.70697 .26078 L
.70964 .26144 L
.71192 .26207 L
.71381 .26262 L
.71537 .26307 L
.71666 .26335 L
.71777 .26343 L
.71874 .26329 L
.71966 .26293 L
.72067 .26234 L
.7219 .26156 L
.72342 .26057 L
.72521 .25937 L
Mistroke
.72722 .25802 L
.72954 .25643 L
.73214 .25467 L
.73489 .25281 L
.73775 .25081 L
.74062 .24882 L
.74354 .24674 L
.74647 .24463 L
.74946 .24258 L
.75248 .24053 L
.75557 .23854 L
.75877 .23656 L
.76203 .23456 L
.76536 .23255 L
.76873 .23053 L
.772 .22848 L
.77517 .22643 L
.77807 .22452 L
.78077 .22258 L
.78325 .22064 L
.78551 .2187 L
.78752 .21682 L
.78931 .21498 L
.79089 .21305 L
.79231 .211 L
.79359 .20888 L
.7948 .20669 L
.79599 .20438 L
.79722 .20199 L
.7985 .19956 L
.79979 .19722 L
.801 .195 L
.80209 .193 L
.80308 .19117 L
.80394 .18966 L
.80465 .18841 L
.80519 .18745 L
.80561 .18677 L
.806 .18633 L
.80644 .1861 L
.80699 .18602 L
.80772 .18605 L
.80867 .18613 L
.80987 .18618 L
.81129 .18616 L
.81289 .186 L
.81463 .18571 L
.81644 .18535 L
.81825 .18495 L
.82003 .18455 L
Mistroke
.82171 .18421 L
.82324 .18396 L
.82458 .18381 L
.82571 .18379 L
.82666 .18394 L
.82743 .18425 L
.82803 .1847 L
.8285 .18523 L
.82886 .18579 L
.82918 .18637 L
.82949 .18695 L
.82982 .18752 L
.83016 .18804 L
.83041 .18825 L
.8307 .18851 L
.83093 .18865 L
.8311 .18869 L
.8312 .18862 L
.83123 .18845 L
.8312 .18823 L
.83112 .18798 L
.83104 .18781 L
.83096 .18765 L
.83088 .18752 L
.83082 .18744 L
.8308 .18744 L
.83082 .1875 L
.83087 .1876 L
.83091 .1877 L
.83093 .18777 L
.83092 .1878 L
.8309 .1878 L
.83086 .18777 L
.83077 .18767 L
.83064 .18746 L
.83043 .1871 L
.83019 .18657 L
.82991 .18584 L
.82958 .18491 L
.82927 .1838 L
.82889 .18248 L
.82846 .18098 L
.82799 .17943 L
.82751 .17781 L
.82701 .17611 L
.82649 .17444 L
.82597 .17286 L
.82547 .17145 L
.82498 .17015 L
.82454 .16901 L
Mistroke
.82414 .16811 L
.82375 .1674 L
.82335 .16688 L
.8229 .16655 L
.82243 .16638 L
.82189 .16631 L
.82125 .16631 L
.82067 .16634 L
.82002 .16639 L
.81935 .16643 L
.81869 .16643 L
.81802 .1664 L
.81739 .16632 L
.81676 .16625 L
.81618 .16622 L
.81569 .16625 L
.81531 .16635 L
.81507 .16651 L
.81497 .16672 L
.81498 .167 L
.81503 .16738 L
.81509 .16785 L
.81513 .16844 L
.81513 .16911 L
.81507 .16989 L
.81497 .17073 L
.81487 .1716 L
.81479 .17248 L
.81472 .17332 L
.81467 .17406 L
.81464 .17468 L
.81463 .17519 L
.81464 .1756 L
.81467 .17591 L
.81473 .17612 L
.81484 .17627 L
.81499 .1764 L
.81517 .17658 L
.81535 .17685 L
.81555 .17727 L
.81582 .17789 L
.81616 .17876 L
.81658 .17994 L
.81717 .18122 L
.81797 .1828 L
.81906 .18468 L
.82038 .18661 L
.82193 .18889 L
.82379 .19115 L
.82594 .19369 L
Mistroke
.82776 .19607 L
.82998 .19848 L
.83216 .20076 L
.83435 .20291 L
.83642 .20484 L
.83844 .20658 L
.83998 .20822 L
.84135 .20951 L
.84258 .21065 L
.84353 .21156 L
.84424 .21222 L
.84467 .21259 L
.84488 .21273 L
.84499 .21269 L
.84503 .21257 L
.84502 .21243 L
.84499 .21238 L
.84502 .21245 L
.84512 .2127 L
.8453 .21314 L
.8455 .21376 L
.84575 .21453 L
.84604 .21544 L
.84635 .21642 L
.84667 .21754 L
.84699 .21881 L
.84731 .22022 L
.84759 .22159 L
.84785 .22295 L
.84806 .22425 L
.84823 .22539 L
.84836 .2263 L
.84847 .22703 L
.84855 .22761 L
.84861 .22803 L
.84864 .22831 L
.84864 .22844 L
.8486 .22844 L
.84853 .22827 L
.84844 .22796 L
.84834 .2275 L
.84825 .2269 L
.84813 .22622 L
.848 .22553 L
.84784 .22484 L
.84764 .22419 L
.8474 .2235 L
.84709 .22276 L
.84671 .22195 L
.84628 .22101 L
Mistroke
.84585 .22004 L
.84537 .21891 L
.84481 .21762 L
.84431 .21618 L
.84376 .21465 L
.84315 .21319 L
.84256 .21168 L
.84192 .21006 L
.84131 .20862 L
.84072 .20715 L
.84019 .20583 L
.83977 .20462 L
.8394 .20366 L
.8391 .20279 L
.83886 .20222 L
.83869 .20176 L
.83856 .20151 L
.83845 .20144 L
.83834 .20145 L
.83824 .20151 L
.83814 .20158 L
.83806 .20166 L
.83799 .20174 L
.83793 .20179 L
.83787 .20181 L
.83782 .20181 L
.83779 .20181 L
.83779 .20182 L
.83781 .20182 L
.83785 .20183 L
.83792 .20184 L
.83803 .20186 L
.83817 .20188 L
.83832 .20191 L
.83845 .20192 L
.83854 .20191 L
.83858 .20189 L
.83857 .20185 L
.83851 .20181 L
.83842 .20176 L
.83833 .20172 L
.83825 .20169 L
.83818 .20167 L
.83812 .20166 L
.83809 .20165 L
.83807 .20165 L
.83809 .20165 L
.83815 .20166 L
.83825 .20168 L
.8384 .20171 L
Mistroke
.8386 .20176 L
.83883 .20181 L
.83907 .20185 L
.83932 .20189 L
.83955 .20193 L
.83976 .20195 L
.83994 .20195 L
.8401 .20194 L
.84022 .20192 L
.84033 .20192 L
.84041 .20192 L
.84046 .20192 L
.84047 .20192 L
.84046 .20193 L
.84044 .20195 L
.84044 .202 L
.84044 .20206 L
.84046 .20212 L
.84047 .20215 L
.84046 .20213 L
.84042 .20205 L
.84034 .2019 L
.84023 .20164 L
.84008 .20131 L
.8399 .20092 L
.83971 .2005 L
.8395 .20005 L
.83929 .19961 L
.83908 .19918 L
.83888 .19876 L
.8387 .19838 L
.83853 .19804 L
.83838 .19778 L
.83826 .19759 L
.83818 .19748 L
.83815 .19745 L
.83818 .19749 L
.83825 .19756 L
.83836 .19765 L
.83849 .19773 L
.83865 .19778 L
.83885 .19785 L
.8391 .19793 L
.83936 .198 L
.83959 .19803 L
.83978 .19801 L
.83992 .19793 L
.83998 .19777 L
.83992 .19752 L
.83975 .19721 L
Mistroke
.83948 .19684 L
.83916 .19643 L
.83879 .196 L
.83838 .19558 L
.83799 .19519 L
.83762 .19481 L
.83722 .19447 L
.83687 .19419 L
.8366 .19399 L
.83642 .19386 L
.83632 .19378 L
.83627 .1937 L
.83627 .19358 L
.83629 .19337 L
.8363 .19302 L
.83625 .19251 L
.83613 .19183 L
.83591 .19094 L
.8356 .18985 L
.83518 .18864 L
.83463 .18723 L
.83394 .18553 L
.8331 .18384 L
.83216 .18191 L
.83104 .17979 L
.82981 .17763 L
.82849 .17526 L
.82699 .17297 L
.82548 .17056 L
.82387 .16808 L
.82229 .1657 L
.82073 .1634 L
.81926 .16121 L
.81788 .15913 L
.8167 .15737 L
.81559 .15569 L
.81474 .15449 L
.81403 .15347 L
.81345 .15266 L
.81302 .15208 L
.81273 .15172 L
.81257 .15153 L
.81252 .15148 L
.81254 .15152 L
.81261 .15161 L
.8127 .15174 L
.8128 .15188 L
.81288 .15199 L
.81294 .15206 L
.81297 .15209 L
Mistroke
.81301 .15213 L
.81309 .15218 L
.81321 .15226 L
.81332 .15236 L
.81338 .15245 L
.81336 .15248 L
.81324 .15241 L
.81294 .1522 L
.81244 .15179 L
.81169 .15114 L
.81071 .15017 L
.80946 .14886 L
.80788 .14718 L
.80609 .1452 L
.80448 .1434 L
.8025 .14113 L
.80043 .1389 L
.79828 .13635 L
.7958 .13359 L
.79388 .13114 L
.79199 .12883 L
.79004 .12632 L
.78837 .12416 L
.78699 .12246 L
.78575 .12089 L
.78473 .11952 L
.78394 .11846 L
.78334 .1177 L
.78283 .11703 L
.78244 .11659 L
.78209 .11621 L
.78175 .11592 L
.78139 .1157 L
.78098 .11553 L
.78048 .11536 L
.77985 .11517 L
.77909 .11498 L
.7784 .1148 L
.77759 .11463 L
.77675 .11445 L
.77596 .11426 L
.7753 .1141 L
.77479 .11397 L
.77439 .11387 L
.77412 .11381 L
.774 .11372 L
.774 .11373 L
.77411 .11376 L
.77437 .11379 L
.77469 .11381 L
Mistroke
.77504 .11382 L
.77541 .11383 L
.77577 .11383 L
.77603 .11383 L
.77618 .11384 L
.77625 .11384 L
.77626 .11385 L
.77624 .11385 L
.77619 .11385 L
.77613 .11385 L
.7761 .11385 L
.77608 .11384 L
.77608 .11384 L
.77607 .11384 L
.77607 .11384 L
.77606 .11385 L
.77606 .11384 L
.77606 .11384 L
.77608 .11384 L
.7761 .11383 L
.77613 .11383 L
.77616 .11384 L
.77618 .11385 L
.7762 .11386 L
.77621 .11387 L
.7762 .11388 L
.7762 .11389 L
.77619 .1139 L
.77618 .11391 L
.77617 .11391 L
.77615 .11391 L
.77614 .11391 L
.77611 .11391 L
.77608 .11391 L
.77605 .1139 L
.77604 .11389 L
.77603 .11388 L
.77603 .11386 L
.77604 .11385 L
.77606 .11384 L
.77607 .11383 L
.77609 .11383 L
.77609 .11383 L
.77609 .11384 L
.77609 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
Mistroke
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
Mistroke
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77607 .11384 L
.77605 .11384 L
.77603 .11384 L
.776 .11384 L
.776 .11384 L
.77603 .11385 L
.7761 .11385 L
.77617 .11385 L
.77626 .11385 L
.77635 .11385 L
.77643 .11385 L
.77649 .11385 L
.77652 .11385 L
.77651 .11385 L
.77648 .11385 L
.77644 .11385 L
.77641 .11385 L
.77641 .11385 L
Mistroke
.7764 .11385 L
.7764 .11385 L
.77642 .11385 L
.77647 .11385 L
.77656 .11386 L
.77668 .11386 L
.77684 .11387 L
.77702 .11388 L
.77723 .11389 L
.77746 .1139 L
.77766 .1139 L
.77783 .11391 L
.77794 .11391 L
.77803 .11391 L
.77808 .11392 L
.77809 .11392 L
.77808 .11392 L
.77805 .11392 L
.77802 .11391 L
.778 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
Mistroke
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
Mistroke
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11391 L
.77798 .11389 L
.778 .11387 L
.77804 .11386 L
.77808 .11386 L
.7781 .11387 L
.77809 .1139 L
.77803 .11395 L
.77793 .11402 L
.77779 .1141 L
.7776 .1142 L
.7774 .11428 L
.77717 .11436 L
.77699 .11442 L
.77679 .11446 L
.77661 .11448 L
.77642 .11448 L
.77624 .11445 L
.77609 .11441 L
.77598 .11436 L
.77592 .11428 L
.7759 .11418 L
.77592 .11408 L
.77596 .11398 L
Mistroke
.77602 .1139 L
.77607 .11384 L
.7761 .11381 L
.77611 .11379 L
.7761 .11379 L
.77609 .1138 L
.77608 .11381 L
.77608 .11383 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77607 .11383 L
.77605 .11381 L
.77603 .11378 L
.77601 .11375 L
.77602 .11375 L
.77606 .11376 L
.77611 .1138 L
.77619 .11387 L
.77626 .11398 L
.77632 .11411 L
.77636 .11427 L
.7764 .11445 L
.77643 .11463 L
.77645 .11481 L
.77647 .11496 L
.77651 .1151 L
.77656 .11524 L
.77663 .11534 L
.7767 .11543 L
.77676 .1155 L
.77683 .11557 L
.77687 .11562 L
.77689 .11565 L
.77689 .11568 L
.77686 .11568 L
.77682 .11566 L
.77677 .11565 L
.77669 .11562 L
.77658 .11556 L
.77643 .11546 L
.77627 .11533 L
.77613 .11519 L
.776 .11502 L
.77589 .11483 L
.77582 .11462 L
.77579 .11443 L
.77578 .11423 L
.7758 .11406 L
Mistroke
.77587 .11393 L
.77595 .11385 L
.77602 .1138 L
.77609 .11378 L
.77614 .11378 L
.77619 .11379 L
.7762 .1138 L
.77619 .1138 L
.77616 .11381 L
.77611 .1138 L
.77602 .1138 L
.77592 .11379 L
.7758 .11381 L
.77568 .11384 L
.77555 .11388 L
.7754 .11393 L
.77526 .11399 L
.77513 .11406 L
.77502 .11415 L
.77492 .11424 L
.77487 .11432 L
.77485 .1144 L
.77488 .11446 L
.77495 .1145 L
.77506 .11452 L
.77519 .11451 L
.77534 .11448 L
.77548 .11441 L
.7756 .11434 L
.77572 .11426 L
.7758 .11417 L
.77589 .11409 L
.77597 .11401 L
.77604 .11394 L
.77609 .11389 L
.77612 .11385 L
.77613 .11383 L
.77612 .11381 L
.77611 .11379 L
.77611 .1138 L
.77615 .11382 L
.77621 .11384 L
.77627 .11384 L
.77629 .11383 L
.77628 .11382 L
.77622 .11381 L
.7761 .11382 L
.7759 .11384 L
.77562 .11386 L
.77526 .11389 L
Mistroke
.77483 .11391 L
.77432 .11392 L
.77379 .11393 L
.77324 .11393 L
.77268 .11393 L
.77213 .11391 L
.77164 .11389 L
.77125 .11389 L
.771 .1139 L
.77087 .11394 L
.77088 .11398 L
.77099 .11404 L
.77121 .1141 L
.7715 .11415 L
.77183 .1142 L
.77219 .11423 L
.77255 .11425 L
.77289 .11424 L
.7732 .11422 L
.77347 .11418 L
.77372 .11414 L
.77392 .11409 L
.7741 .11405 L
.77426 .11405 L
.77439 .11409 L
.77449 .11418 L
.77457 .11432 L
.77463 .11448 L
.77466 .11466 L
.7747 .11485 L
.77474 .11505 L
.77479 .11525 L
.77482 .1154 L
.77484 .11549 L
.77483 .11551 L
.7748 .11547 L
.77477 .11538 L
.77472 .11525 L
.77467 .11508 L
.77463 .11489 L
.77461 .11471 L
.7746 .11455 L
.7746 .11442 L
.7746 .11432 L
.77458 .11424 L
.77452 .11416 L
.77444 .11408 L
.77438 .11402 L
.77431 .11396 L
.77426 .1139 L
Mistroke
.77423 .11386 L
.77422 .11383 L
.77421 .11381 L
.77419 .11378 L
.77418 .11376 L
.77417 .11375 L
.77416 .11375 L
.77416 .11375 L
.77416 .11375 L
.77417 .11377 L
.77418 .11377 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11378 L
.77418 .11377 L
Mistroke
.77417 .11377 L
.77418 .11376 L
.77419 .11375 L
.77422 .11375 L
.77424 .11375 L
.77424 .11375 L
.77422 .11376 L
.77418 .11379 L
.77413 .11383 L
.77408 .1139 L
.77402 .11397 L
.77395 .11405 L
.77387 .11412 L
.77379 .11419 L
.77374 .11423 L
.77371 .11426 L
.77373 .11427 L
.77377 .11426 L
.77386 .11424 L
.77401 .11421 L
.77417 .11417 L
.77439 .11411 L
.77465 .11404 L
.77493 .11397 L
.77518 .11391 L
.77543 .11385 L
.77564 .11382 L
.77581 .11379 L
.77595 .11378 L
.77607 .11379 L
.77616 .11381 L
.7762 .11384 L
.7762 .11385 L
.77618 .11385 L
.77615 .11385 L
.77612 .11385 L
.7761 .11385 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
Mistroke
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77608 .11384 L
.77607 .11383 L
.77604 .1138 L
.77601 .11377 L
.77598 .11374 L
Mistroke
.77597 .11372 L
.77598 .11373 L
.77602 .11378 L
.7761 .11387 L
.77622 .11399 L
.77637 .11415 L
.77654 .11434 L
.77674 .11455 L
.77697 .11477 L
.77719 .11499 L
.77741 .11523 L
.77762 .11546 L
.77779 .11569 L
.77792 .11588 L
.77798 .116 L
.77796 .11606 L
.77788 .11604 L
.77774 .11596 L
.7776 .11585 L
.7775 .11574 L
.77742 .11565 L
.77736 .11557 L
.77732 .11551 L
.77728 .11546 L
.77721 .11539 L
.77709 .11531 L
.77693 .11522 L
.77675 .11513 L
.77655 .11504 L
.77632 .11496 L
.77607 .11487 L
.77582 .11479 L
.77556 .11471 L
.77532 .11464 L
.77507 .11458 L
.77488 .11454 L
.77473 .11451 L
.77462 .1145 L
.77459 .11453 L
.77463 .11457 L
.77471 .11462 L
.77477 .11462 L
.77481 .1146 L
.7748 .11455 L
.77476 .1145 L
.77469 .11442 L
.77464 .11438 L
.77461 .11433 L
.77459 .11431 L
.77461 .1143 L
Mistroke
.77472 .11433 L
.77489 .1144 L
.77513 .11452 L
.77542 .11467 L
.77578 .11487 L
.77618 .1151 L
.77659 .11534 L
.77696 .11553 L
.77731 .11571 L
.7776 .11585 L
.77784 .11595 L
.77801 .116 L
.77812 .11603 L
.77817 .11604 L
.77818 .11603 L
.77814 .116 L
.77807 .11596 L
.77797 .11591 L
.77787 .11584 L
.77776 .11573 L
.77766 .11562 L
.77759 .1155 L
.77755 .11537 L
.77754 .11524 L
.77756 .11511 L
.77763 .11499 L
.77773 .1149 L
.77787 .11486 L
.77807 .11491 L
.7783 .11504 L
.77859 .11524 L
.7789 .11551 L
.77924 .11586 L
.77963 .11626 L
.78009 .11672 L
.78063 .11725 L
.78125 .11788 L
.78196 .11854 L
.78279 .11929 L
.7837 .12012 L
.78471 .12101 L
.7858 .12194 L
.78681 .12287 L
.78787 .1237 L
.78894 .12456 L
.78987 .12541 L
.79076 .12623 L
.7916 .12694 L
.79235 .12761 L
.79298 .12821 L
Mistroke
.79351 .12871 L
.79397 .12912 L
.79438 .12945 L
.79476 .12974 L
.79517 .13005 L
.79566 .13046 L
.79627 .13106 L
.797 .13189 L
.7979 .133 L
.79891 .13431 L
.80014 .13593 L
.80157 .13791 L
.8032 .14013 L
.8051 .14273 L
.80701 .14559 L
.80916 .14878 L
.81154 .1524 L
.81395 .15576 L
.81642 .1596 L
.81905 .16306 L
.82161 .16692 L
.82434 .17033 L
.82712 .17408 L
.82963 .17769 L
.83198 .18101 L
.8345 .18451 L
.83696 .18805 L
.83938 .19136 L
.84198 .19512 L
.84431 .19849 L
.84705 .2027 L
.84955 .20625 L
.85204 .21051 L
.85478 .21483 L
.85746 .21949 L
.86059 .22485 L
.86317 .22903 L
.86603 .23374 L
.86891 .23869 L
.8714 .24247 L
.87389 .24639 L
.87622 .25012 L
.87821 .2533 L
.87987 .2558 L
.88134 .258 L
.88251 .25976 L
.88338 .26112 L
.88399 .26208 L
.88437 .26269 L
.88455 .26302 L
Mistroke
.88461 .2632 L
.88458 .2633 L
.88451 .26335 L
.88445 .26339 L
.88445 .26347 L
.88452 .26357 L
.88463 .26368 L
.88477 .26375 L
.88495 .26379 L
.88513 .26381 L
.8853 .26382 L
.88545 .2638 L
.88556 .26376 L
.88565 .2637 L
.8857 .26365 L
.88573 .26363 L
.88574 .26369 L
.88579 .26388 L
.88591 .26423 L
.88616 .26479 L
.88658 .26564 L
.88721 .26682 L
.88806 .26834 L
.88904 .26998 L
.89019 .27199 L
.89149 .27408 L
.89289 .27643 L
.89427 .27874 L
.89568 .28119 L
.897 .28328 L
.89813 .28528 L
.89921 .28703 L
.90007 .28851 L
.90076 .28967 L
.90125 .29055 L
.90153 .29116 L
.90167 .29153 L
.90169 .29172 L
.90164 .29173 L
.90154 .29162 L
.90143 .29142 L
.90135 .29118 L
.90129 .29092 L
.90126 .29065 L
.90124 .29042 L
.90123 .29023 L
.90123 .29008 L
.90122 .28997 L
.90122 .2899 L
.90122 .28986 L
Mistroke
.90122 .28988 L
.90122 .28994 L
.90122 .29005 L
.90123 .29018 L
.90124 .29035 L
.90124 .29053 L
.90125 .29071 L
.90125 .29088 L
.90126 .29101 L
.90126 .29111 L
.90126 .29117 L
.90127 .29119 L
.90126 .29117 L
.90126 .29111 L
.90126 .29099 L
.90124 .29086 L
.90121 .29075 L
.90118 .29066 L
.90115 .29061 L
.90113 .29062 L
.90112 .29072 L
.90114 .29093 L
.90119 .29126 L
.9013 .29172 L
.90147 .2923 L
.90169 .293 L
.90196 .29375 L
.90228 .29457 L
.90263 .29542 L
.903 .29626 L
.90338 .29705 L
.90376 .29775 L
.90411 .29836 L
.90442 .29884 L
.90469 .29919 L
.90491 .29942 L
.90507 .29955 L
.90517 .29959 L
.90523 .29957 L
.90524 .29952 L
.90523 .29946 L
.9052 .29938 L
.90516 .29932 L
.9051 .29926 L
.90505 .29922 L
.90501 .29919 L
.90499 .29918 L
.905 .29919 L
.90504 .29923 L
.90512 .29929 L
Mistroke
.90521 .29936 L
.90533 .29945 L
.90547 .29959 L
.90565 .29978 L
.90586 .30002 L
.90609 .30032 L
.90634 .30068 L
.90659 .30109 L
.90683 .30153 L
.90705 .302 L
.90723 .30247 L
.90736 .30294 L
.90745 .30339 L
.90749 .30383 L
.9075 .30426 L
.90748 .30469 L
.90744 .30502 L
.90739 .30531 L
.90734 .3055 L
.90728 .30556 L
.90721 .30548 L
.90714 .30527 L
.90707 .30496 L
.90702 .30458 L
.90699 .30417 L
.907 .30375 L
.90703 .30334 L
.90707 .30291 L
.9071 .30249 L
.90712 .30213 L
.90711 .30185 L
.90707 .30166 L
.907 .30155 L
.90691 .30153 L
.90679 .30158 L
.90664 .30162 L
.90645 .30159 L
.90623 .30141 L
.90594 .30102 L
.90558 .30038 L
.9051 .29944 L
.90451 .29823 L
.90375 .29664 L
.90281 .29465 L
.90165 .29215 L
.90027 .28945 L
.89862 .28587 L
.89673 .28254 L
.89451 .27843 L
.89217 .27425 L
Mistroke
.88949 .26972 L
.88665 .26459 L
.88368 .26012 L
.88054 .25479 L
.87736 .24963 L
.87427 .2452 L
.87109 .24015 L
.86785 .23462 L
.86481 .23014 L
.86173 .22511 L
.85867 .22043 L
.85564 .21571 L
.85247 .21074 L
.8494 .20621 L
.84624 .20154 L
.84295 .19656 L
.83954 .19179 L
.83612 .18668 L
.83268 .18197 L
.829 .17657 L
.82556 .1719 L
.82195 .1668 L
.81822 .16111 L
.81477 .15655 L
.81126 .15145 L
.80779 .14619 L
.80436 .14168 L
.80118 .13718 L
.79799 .13317 L
.79482 .1292 L
.79188 .12611 L
.78886 .12303 L
.78588 .12023 L
.78301 .11797 L
.78011 .11591 L
.77765 .11413 L
.77527 .1127 L
.77319 .11146 L
.77117 .11041 L
.76918 .10957 L
.76737 .10865 L
.76566 .10779 L
.76391 .10686 L
.76202 .10583 L
.75994 .10471 L
.7576 .10353 L
.75499 .10228 L
.75259 .10106 L
.74949 .09978 L
.74619 .09839 L
Mistroke
.74242 .09683 L
.73771 .09505 L
.73367 .09324 L
.72873 .09122 L
.72376 .08903 L
.71846 .0868 L
.71303 .08441 L
.70737 .08212 L
.70212 .07975 L
.69647 .07734 L
.69074 .07496 L
.68536 .07257 L
.67932 .0702 L
.67436 .06786 L
.66893 .06555 L
.66352 .06321 L
.65832 .06111 L
.65368 .05904 L
.64894 .05707 L
.64443 .05515 L
.64018 .05339 L
.63586 .05165 L
.632 .05002 L
.62803 .04845 L
.62465 .047 L
.62116 .0456 L
.61798 .04427 L
.61499 .04306 L
.61218 .04196 L
.60979 .04097 L
.60757 .0401 L
.60568 .03938 L
.60397 .03875 L
.60245 .03824 L
.60113 .03779 L
.59998 .0374 L
.59902 .03709 L
.59826 .03687 L
.5977 .03673 L
.59727 .03664 L
.59693 .03659 L
.59667 .03657 L
.59647 .03658 L
.59631 .03662 L
.59621 .03667 L
.59616 .03671 L
.59616 .03674 L
.5962 .03674 L
.59626 .03674 L
.59633 .03675 L
Mistroke
.59639 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59641 .03675 L
.59642 .03675 L
.59645 .03675 L
.59652 .03676 L
.59662 .03676 L
.59671 .03676 L
.59676 .03676 L
.59672 .03676 L
.59659 .03676 L
.59635 .03675 L
.59598 .03673 L
.59551 .03671 L
.59495 .03669 L
.59435 .03667 L
.59374 .03665 L
.59314 .03663 L
.59262 .03661 L
.59208 .03659 L
.59158 .03657 L
.59114 .03656 L
.59074 .03655 L
.59035 .03653 L
.58994 .03652 L
.58948 .0365 L
.58895 .03649 L
.58835 .03646 L
Mistroke
.58765 .03644 L
.58685 .03641 L
.58588 .03638 L
.5848 .03634 L
.58367 .0363 L
.58256 .03626 L
.58144 .03622 L
.58036 .03618 L
.57937 .03615 L
.57849 .03612 L
.57776 .0361 L
.57721 .03608 L
.57677 .03606 L
.57642 .03605 L
.57615 .03604 L
.57592 .03604 L
.57575 .03603 L
.57562 .03602 L
.57554 .03602 L
.57552 .03602 L
.57557 .03602 L
.57568 .03602 L
.57586 .03603 L
.57605 .03604 L
.57622 .03604 L
.57633 .03605 L
.57636 .03605 L
.57629 .03605 L
.57607 .03604 L
.57562 .03603 L
.57492 .03601 L
.57393 .03598 L
.57268 .03593 L
.57114 .03588 L
.56955 .03582 L
.56773 .03576 L
.56569 .03568 L
.56362 .03561 L
.56164 .03554 L
.55967 .03547 L
.55781 .03541 L
.55634 .03535 L
.55506 .03531 L
.554 .03528 L
.55319 .03525 L
.55267 .03523 L
.55238 .0352 L
.55227 .03514 L
.55227 .03507 L
.55236 .035 L
Mistroke
.55251 .03494 L
.55266 .03491 L
.55279 .03497 L
.55285 .03512 L
.55286 .0354 L
.55287 .03581 L
.55287 .03635 L
.55288 .037 L
.55288 .03776 L
.55289 .03852 L
.55294 .03933 L
.55303 .04012 L
.55317 .04089 L
.55329 .04153 L
.55335 .04215 L
.55331 .04272 L
.55314 .04321 L
.55282 .04367 L
.55232 .04416 L
.55168 .04469 L
.55093 .04525 L
.55009 .04585 L
.54921 .04647 L
.54834 .04705 L
.54749 .04769 L
.54664 .04833 L
.54584 .04898 L
.54513 .04959 L
.54461 .05014 L
.54429 .0505 L
.54417 .05071 L
.54424 .05074 L
.54446 .05057 L
.54483 .05023 L
.54532 .04977 L
.54591 .04925 L
.54664 .04872 L
.54757 .0482 L
.54881 .04771 L
.55042 .04728 L
.55244 .04691 L
.55481 .04663 L
.55758 .04647 L
.56056 .04645 L
.56409 .04658 L
.5676 .04687 L
.57179 .04737 L
.57558 .04807 L
.57975 .04894 L
.5842 .04985 L
Mistroke
.58832 .05087 L
.59208 .05195 L
.59589 .05304 L
.59949 .05408 L
.60289 .05506 L
.6061 .056 L
.60923 .05681 L
.61239 .05743 L
.61542 .05789 L
.61869 .05822 L
.62203 .05844 L
.62558 .0586 L
.62943 .05878 L
.63341 .05901 L
.63746 .05935 L
.64226 .05983 L
.6463 .06051 L
.65099 .06141 L
.6559 .06259 L
.66155 .06389 L
.66609 .06551 L
.67153 .06734 L
.67684 .06934 L
.68224 .07139 L
.68737 .07371 L
.69256 .07585 L
.69753 .07815 L
.70174 .08021 L
.70601 .08221 L
.71001 .08414 L
.71333 .08573 L
.71606 .08716 L
.71858 .0884 L
.72044 .08942 L
.72193 .0902 L
.72295 .09078 L
.72355 .09118 L
.72384 .09143 L
.72394 .09157 L
.72393 .09163 L
.72388 .09163 L
.72382 .09159 L
.7238 .09154 L
.72385 .09147 L
.72392 .09141 L
.72402 .09137 L
.72415 .09136 L
.72431 .09135 L
.7245 .09134 L
.72474 .09132 L
Mistroke
.72503 .09132 L
.72533 .09132 L
.72564 .09133 L
.72595 .09134 L
.72625 .09136 L
.72654 .09141 L
.72683 .09151 L
.72714 .09168 L
.7275 .09195 L
.72798 .09234 L
.72859 .09288 L
.72939 .09359 L
.73043 .09451 L
.73171 .09564 L
.73332 .09696 L
.73516 .09827 L
.73735 .09986 L
.73995 .10143 L
.74268 .10315 L
.74578 .10492 L
.7492 .10679 L
.75276 .10859 L
.75659 .11053 L
.76026 .11227 L
.76407 .11402 L
.76799 .11572 L
.77128 .11721 L
.77453 .11859 L
.7774 .11984 L
.77992 .12094 L
.78217 .12188 L
.78398 .12263 L
.78543 .12328 L
.78666 .12387 L
.78762 .12438 L
.78835 .12482 L
.78888 .12521 L
.78928 .12556 L
.78957 .1259 L
.78981 .12624 L
.79 .12659 L
.79019 .12693 L
.79042 .12728 L
.79072 .12764 L
.79104 .128 L
.79135 .1283 L
.79163 .12853 L
.79188 .12869 L
.7921 .12877 L
.7923 .12883 L
Mistroke
.79253 .1289 L
.79279 .12902 L
.79314 .12923 L
.79358 .12955 L
.79411 .13 L
.7947 .13053 L
.79536 .13113 L
.79604 .13175 L
.79674 .13239 L
.79742 .13301 L
.79808 .13358 L
.7987 .1341 L
.79928 .13456 L
.79979 .13493 L
.80024 .1352 L
.80062 .13537 L
.80091 .13544 L
.80112 .1354 L
.80125 .1353 L
.8013 .13517 L
.80126 .13502 L
.80116 .13489 L
.80103 .13482 L
.80091 .1348 L
.80082 .13487 L
.80081 .13506 L
.80088 .13539 L
.80109 .13589 L
.80145 .13666 L
.80199 .13778 L
.80271 .13922 L
.80366 .14104 L
.80479 .14313 L
.80621 .14546 L
.80785 .14827 L
.8097 .15102 L
.81166 .154 L
.8138 .15695 L
.81577 .15975 L
.81783 .16267 L
.8196 .16521 L
.82128 .16721 L
.82278 .16907 L
.82406 .17074 L
.82507 .17203 L
.82588 .17296 L
.82647 .17356 L
.82685 .17386 L
.82704 .17394 L
.82709 .17391 L
Mistroke
.82705 .17381 L
.82696 .17365 L
.82686 .17354 L
.82675 .17352 L
.82664 .17351 L
.82654 .1735 L
.82648 .17348 L
.82643 .17345 L
.8264 .17341 L
.82638 .17336 L
.8264 .17329 L
.82636 .17326 L
.82631 .17325 L
.82622 .17326 L
.82612 .17328 L
.82599 .17326 L
.82585 .17322 L
.82571 .17314 L
.82556 .17306 L
.82542 .17299 L
.82527 .17293 L
.82511 .17289 L
.82494 .17288 L
.82478 .17288 L
.82465 .17287 L
.82455 .17283 L
.82453 .17276 L
.82457 .17268 L
.82468 .17261 L
.82482 .17257 L
.82498 .17256 L
.82514 .17259 L
.8253 .17264 L
.82546 .17275 L
.82565 .17295 L
.82588 .17326 L
.82616 .17371 L
.8265 .17434 L
.82689 .17518 L
.82735 .17618 L
.82787 .17738 L
.82842 .17877 L
.82903 .18032 L
.82969 .18175 L
.83035 .1833 L
.83107 .18489 L
.83174 .18627 L
.83241 .18761 L
.83303 .18887 L
.83357 .18991 L
Mistroke
.83401 .19078 L
.83435 .19146 L
.83459 .19193 L
.83471 .19215 L
.83473 .19215 L
.83466 .19196 L
.83451 .19163 L
.83431 .19118 L
.83406 .19063 L
.83379 .18999 L
.83349 .18927 L
.83318 .18849 L
.83283 .18763 L
.83245 .18665 L
.83197 .18552 L
.83142 .18432 L
.83075 .18295 L
.82994 .1814 L
.82895 .17962 L
.8279 .17773 L
.82662 .17558 L
.8253 .17329 L
.82377 .17064 L
.82213 .16785 L
.82032 .16501 L
.81848 .16218 L
.8167 .15928 L
.81492 .15645 L
.81314 .15348 L
.81166 .15116 L
.81021 .14882 L
.80892 .14681 L
.80768 .14496 L
.80668 .14355 L
.80577 .14238 L
.80493 .14147 L
.80419 .14084 L
.80354 .14045 L
.803 .14025 L
.80258 .14021 L
.80222 .14025 L
.80192 .14036 L
.80167 .14048 L
.80148 .14062 L
.80133 .14075 L
.80122 .14086 L
.80116 .14096 L
.80115 .14106 L
.80118 .14115 L
.80125 .14124 L
Mistroke
.80131 .14129 L
.80135 .1413 L
.80139 .14127 L
.80147 .14121 L
.80156 .14115 L
.80164 .14109 L
.80169 .14105 L
.80167 .14105 L
.80158 .14111 L
.80138 .14127 L
.80104 .14153 L
.80056 .14191 L
.79996 .14242 L
.79927 .14306 L
.7985 .14383 L
.79774 .14462 L
.79695 .14547 L
.79611 .14633 L
.79525 .14716 L
.79447 .14787 L
.7938 .14847 L
.79325 .1489 L
.79291 .14912 L
.79265 .1491 L
.79247 .14883 L
.79236 .14829 L
.79227 .14747 L
.79212 .14646 L
.79184 .14521 L
.79141 .14367 L
.79085 .14196 L
.79014 .14001 L
.7893 .1379 L
.78847 .13566 L
.78743 .13325 L
.78632 .13088 L
.78517 .12846 L
.78399 .12606 L
.78288 .12383 L
.78173 .12172 L
.78065 .11971 L
.77961 .11815 L
.77863 .11677 L
.77771 .11562 L
.77693 .11475 L
.77616 .11412 L
.77544 .11372 L
.77477 .11349 L
.77416 .11339 L
.7736 .11337 L
Mistroke
.77311 .11341 L
.7727 .11348 L
.77238 .11354 L
.77217 .11359 L
.77205 .11362 L
.77201 .11366 L
.77202 .11368 L
.77207 .1137 L
.77213 .1137 L
.77219 .11371 L
.77224 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77227 .11371 L
.77228 .11371 L
.77231 .11371 L
.77238 .11371 L
.77247 .11372 L
.77256 .11374 L
.77262 .11378 L
.77262 .11384 L
Mistroke
.77252 .1139 L
.77233 .1139 L
.77201 .11383 L
.77158 .11368 L
.77103 .11347 L
.77035 .11322 L
.76957 .11294 L
.76873 .11269 L
.76783 .11247 L
.76685 .1123 L
.76583 .11217 L
.76486 .1121 L
.76393 .11206 L
.7631 .11206 L
.76241 .11208 L
.76186 .11218 L
.76142 .11235 L
.7611 .11257 L
.76089 .11284 L
.76075 .11313 L
.76069 .1134 L
.76067 .11361 L
.76069 .11372 L
.76071 .11369 L
.76073 .11355 L
.76071 .11333 L
.76064 .11305 L
.76051 .11271 L
.76034 .11233 L
.76014 .11192 L
.75993 .11148 L
.75972 .11105 L
.75951 .11063 L
.7593 .11021 L
.75911 .10982 L
.75894 .10948 L
.75879 .10921 L
.75867 .10902 L
.75859 .10891 L
.75856 .10888 L
.75858 .1089 L
.75865 .10896 L
.75876 .10904 L
.7589 .10909 L
.75906 .10912 L
.75923 .10913 L
.75942 .10914 L
.75962 .10914 L
.75981 .10913 L
.75998 .10909 L
Mistroke
.76014 .10903 L
.76029 .10897 L
.7604 .10892 L
.76046 .10889 L
.76049 .1089 L
.76052 .10895 L
.76057 .10908 L
.76066 .10929 L
.76082 .1096 L
.76108 .11003 L
.76149 .1106 L
.76206 .11134 L
.76283 .11224 L
.76381 .11332 L
.765 .11463 L
.76634 .11611 L
.76779 .1179 L
.76947 .11981 L
.77127 .12206 L
.77317 .12428 L
.77515 .12673 L
.77713 .12925 L
.77909 .13178 L
.78098 .13445 L
.7827 .13665 L
.7843 .13901 L
.78573 .14148 L
.78697 .14391 L
.78796 .14594 L
.78875 .14796 L
.78934 .15012 L
.7898 .15244 L
.79017 .15481 L
.79052 .1568 L
.79091 .15937 L
.7914 .16181 L
.79205 .16482 L
.79291 .16776 L
.79402 .17072 L
.79542 .17399 L
.79703 .17718 L
.79895 .18043 L
.80119 .18364 L
.80373 .18644 L
.80654 .18927 L
.80977 .19184 L
.81285 .19423 L
.81635 .19632 L
.81971 .1982 L
.823 .19979 L
Mistroke
.82605 .20109 L
.82885 .20218 L
.83179 .20302 L
.83403 .20364 L
.83588 .20406 L
.83758 .20428 L
.83882 .20429 L
.83973 .20413 L
.84037 .20382 L
.84077 .20337 L
.84096 .20279 L
.841 .20207 L
.84092 .20118 L
.84041 .2001 L
.84017 .19887 L
.83994 .19744 L
.83968 .19579 L
.83932 .19404 L
.83884 .1921 L
.83825 .19001 L
.83762 .18812 L
.83682 .18602 L
.8359 .18408 L
.83478 .18211 L
.83356 .18014 L
.83229 .17838 L
.83098 .17667 L
.82968 .17504 L
.82839 .17354 L
.82712 .17206 L
.8259 .1706 L
.82474 .16919 L
.82356 .16776 L
.82239 .16625 L
.8212 .16465 L
.82001 .16309 L
.81888 .16148 L
.81785 .15991 L
.81691 .15838 L
.81608 .15702 L
.81537 .15577 L
.81477 .15469 L
.8143 .15382 L
.81391 .15312 L
.81358 .15259 L
.81329 .15221 L
.81308 .15197 L
.81294 .15185 L
.81291 .15185 L
.81298 .15197 L
Mistroke
.81314 .1522 L
.81335 .15246 L
.81353 .15267 L
.81359 .15277 L
.81344 .15264 L
.81302 .15219 L
.8123 .15137 L
.81127 .15015 L
.80998 .14854 L
.80835 .14643 L
.80635 .1438 L
.80423 .14118 L
.80146 .13827 L
.79871 .13525 L
.79548 .13181 L
.79202 .12772 L
.78852 .12452 L
.78465 .12137 L
.78129 .11823 L
.77747 .1154 L
.77385 .11277 L
.76984 .11042 L
.76565 .10817 L
.76183 .10619 L
.75727 .10413 L
.75288 .102 L
.74811 .09977 L
.74277 .09744 L
.7383 .09534 L
.73362 .09315 L
.72832 .09081 L
.72421 .08887 L
.71972 .08694 L
.71555 .08512 L
.71157 .08352 L
.7083 .08219 L
.70533 .08107 L
.70294 .08017 L
.70088 .07952 L
.69921 .0791 L
.69787 .07886 L
.6968 .07874 L
.69596 .0787 L
.69532 .07872 L
.69483 .07876 L
.69447 .07885 L
.69418 .07892 L
.69395 .07898 L
.69376 .07907 L
.69363 .07921 L
Mistroke
.69355 .07937 L
.69353 .07956 L
.69355 .07974 L
.69361 .0799 L
.6937 .08002 L
.69378 .08008 L
.69386 .08009 L
.6939 .08006 L
.69391 .08002 L
.69391 .07998 L
.69392 .07995 L
.69396 .07992 L
.69402 .07989 L
.69408 .07986 L
.69411 .07984 L
.69409 .07985 L
.694 .0799 L
.69384 .07997 L
.69361 .08009 L
.69332 .08024 L
.69297 .08041 L
.69258 .0806 L
.69218 .0808 L
.69177 .081 L
.69136 .08121 L
.69097 .08141 L
.69061 .0816 L
.69029 .08178 L
.69004 .08194 L
.68986 .08206 L
.68976 .08212 L
.68973 .08213 L
.68976 .08207 L
.68981 .08195 L
.68988 .0818 L
.68993 .08162 L
.68995 .08142 L
.68995 .08121 L
.68995 .08099 L
.68994 .08078 L
.68994 .08056 L
.68993 .08035 L
.68993 .08016 L
.68996 .08002 L
.69004 .07994 L
.69018 .07992 L
.69034 .07994 L
.6905 .08001 L
.69063 .08011 L
.69067 .08019 L
Mistroke
.69057 .0802 L
.69029 .08009 L
.6898 .07983 L
.68905 .07936 L
.68799 .07866 L
.68657 .07771 L
.68489 .07654 L
.68273 .07514 L
.68033 .07351 L
.67746 .07166 L
.67434 .06986 L
.67097 .06765 L
.66732 .06577 L
.6637 .06369 L
.65998 .0616 L
.65611 .05959 L
.65258 .05778 L
.64892 .05599 L
.64526 .05442 L
.64164 .05299 L
.63815 .0517 L
.63467 .05058 L
.63146 .04963 L
.62818 .04877 L
.62508 .04799 L
.62187 .04727 L
.61846 .04657 L
.61511 .04584 L
.61137 .04507 L
.60761 .04425 L
.60348 .04338 L
.5997 .04247 L
.59565 .04164 L
.59193 .04073 L
.58841 .03981 L
.58502 .03888 L
.58176 .03809 L
.57923 .03736 L
.57695 .03672 L
.57494 .03619 L
.57348 .03582 L
.57235 .0356 L
.57157 .03552 L
.57105 .03555 L
.57064 .03565 L
.5702 .03576 L
.56957 .03587 L
.56864 .03595 L
.56739 .03597 L
.56569 .03594 L
Mistroke
.56344 .03588 L
.56076 .03578 L
.55767 .03567 L
.55406 .03557 L
.5506 .03543 L
.54695 .03529 L
.54338 .03512 L
.54 .03496 L
.53661 .0348 L
.53402 .03465 L
.5317 .03452 L
.52965 .03443 L
.52823 .03436 L
.52722 .03433 L
.52667 .03434 L
.52659 .03437 L
.52685 .03439 L
.52732 .03441 L
.52787 .03443 L
.52844 .03445 L
.52898 .03447 L
.5294 .03448 L
.52971 .03449 L
.52996 .03449 L
.53018 .03448 L
.53037 .03444 L
.53054 .03437 L
.53064 .03432 L
.53064 .03429 L
.5305 .0343 L
.53018 .03438 L
.52958 .03453 L
.52862 .03475 L
.52726 .03503 L
.5255 .03536 L
.52351 .03571 L
.52105 .03607 L
.51837 .03641 L
.51542 .03675 L
.51251 .03708 L
.50957 .03739 L
.50704 .03765 L
.50464 .03786 L
.50288 .038 L
.50146 .03807 L
.50044 .03808 L
.49985 .03804 L
.49964 .03797 L
.49966 .0379 L
.49978 .03783 L
Mistroke
.49988 .03777 L
.49988 .03769 L
.49974 .03762 L
.49941 .03757 L
.49881 .03755 L
.49797 .03756 L
.49687 .03762 L
.49565 .03774 L
.49446 .03795 L
.49327 .03826 L
.49214 .0387 L
.49115 .03928 L
.49034 .03999 L
.4897 .0408 L
.48921 .04171 L
.48884 .04273 L
.48857 .04381 L
.48835 .04486 L
.48815 .04574 L
.488 .04645 L
.4879 .047 L
.48788 .04739 L
.48791 .04761 L
.488 .04766 L
.48808 .04755 L
.48803 .04735 L
.4878 .04714 L
.48734 .04695 L
.48662 .04683 L
.48558 .04672 L
.4842 .04666 L
.4825 .0467 L
.48079 .04649 L
.4787 .04661 L
.47645 .0467 L
.47367 .04671 L
.47123 .04662 L
.46847 .04639 L
.4655 .04602 L
.46245 .04548 L
.45974 .04482 L
.45706 .04406 L
.45464 .04326 L
.45271 .0425 L
.45099 .04182 L
.44945 .04125 L
.44825 .04082 L
.44726 .0405 L
.44659 .04031 L
.44629 .04023 L
Mistroke
.44633 .04024 L
.44667 .04031 L
.44726 .0404 L
.44795 .04048 L
.44862 .04054 L
.44913 .04059 L
.4494 .04061 L
.4493 .04061 L
.44877 .0406 L
.44776 .04057 L
.44629 .04052 L
.44432 .04045 L
.44209 .04033 L
.43932 .04014 L
.43611 .03988 L
.43279 .0396 L
.42892 .03934 L
.42492 .03912 L
.42058 .03901 L
.41579 .03908 L
.41154 .03936 L
.40685 .03988 L
.40219 .04067 L
.39771 .04176 L
.3928 .04316 L
.38852 .04474 L
.38364 .04668 L
.37931 .04879 L
.37453 .05116 L
.36993 .05368 L
.36537 .0564 L
.36098 .05909 L
.35611 .06197 L
.35175 .06486 L
.34681 .06784 L
.34251 .07076 L
.33774 .07384 L
.33318 .07677 L
.32843 .07986 L
.32342 .083 L
.3188 .08613 L
.31352 .08949 L
.30901 .09262 L
.30394 .09598 L
.29882 .09935 L
.29416 .1026 L
.28896 .106 L
.28423 .10912 L
.27942 .11225 L
.27466 .11535 L
Mistroke
.26994 .11838 L
.2654 .12156 L
.26073 .12487 L
.25638 .12817 L
.25193 .13173 L
.24765 .13539 L
.24349 .1392 L
.23937 .14334 L
.23565 .14731 L
.23201 .15159 L
.22843 .1563 L
.2252 .16065 L
.22199 .1655 L
.21893 .17057 L
.21595 .17533 L
.21309 .18031 L
.21028 .18526 L
.2075 .19035 L
.20478 .19492 L
.20199 .19997 L
.1993 .20452 L
.19659 .20917 L
.19373 .21367 L
.19092 .21835 L
.188 .22332 L
.18516 .22772 L
.18221 .23273 L
.17923 .23775 L
.17634 .24222 L
.17328 .24743 L
.17026 .25247 L
.16747 .2578 L
.16437 .26319 L
.16106 .2686 L
.15806 .27395 L
.15475 .27956 L
.15206 .28431 L
.14915 .28906 L
.14661 .29345 L
.14434 .29752 L
.14248 .30078 L
.14081 .30382 L
.13943 .30662 L
.1384 .30892 L
.13752 .31114 L
.13675 .31339 L
.13606 .31577 L
.13539 .31842 L
.13469 .32115 L
.13394 .32452 L
Mistroke
.13319 .32785 L
.13232 .33177 L
.13141 .33615 L
.13043 .34086 L
.12938 .34619 L
.12839 .35119 L
.1274 .3569 L
.12649 .36186 L
.12569 .36742 L
.12504 .372 L
.12455 .37675 L
.12419 .38102 L
.12395 .38472 L
.12377 .38809 L
.12364 .39094 L
.12352 .39334 L
.12341 .39521 L
.12331 .39664 L
.12325 .39764 L
.12322 .39828 L
.1232 .39861 L
Mfstroke
1 1 0 r
.008 w
.11404 .48067 Mdot
.016 w
.11404 .48067 m
.11398 .48083 L
s
.008 w
.11398 .48083 Mdot
.016 w
.11398 .48083 m
.11385 .48123 L
s
1 .999 0 r
.008 w
.11385 .48123 Mdot
.016 w
.11385 .48123 m
.11363 .48193 L
s
.008 w
.11363 .48193 Mdot
.016 w
.11363 .48193 m
.11332 .48299 L
s
.008 w
.11332 .48299 Mdot
.016 w
.11332 .48299 m
.11292 .48445 L
s
.008 w
.11292 .48445 Mdot
.016 w
.11292 .48445 m
.11244 .48638 L
s
.008 w
.11244 .48638 Mdot
.016 w
.11244 .48638 m
.11191 .48853 L
s
1 .998 0 r
.008 w
.11191 .48853 Mdot
.016 w
.11191 .48853 m
.11133 .4914 L
s
.008 w
.11133 .4914 Mdot
.016 w
.11133 .4914 m
.11075 .49442 L
s
.008 w
.11075 .49442 Mdot
.016 w
.11075 .49442 m
.1102 .49805 L
s
.008 w
.1102 .49805 Mdot
.016 w
.1102 .49805 m
.10971 .50193 L
s
.008 w
.10971 .50193 Mdot
.016 w
.10971 .50193 m
.10932 .50611 L
s
.008 w
.10932 .50611 Mdot
.016 w
.10932 .50611 m
.10905 .51096 L
s
1 .997 0 r
.008 w
.10905 .51096 Mdot
.016 w
.10905 .51096 m
.10892 .5152 L
s
.008 w
.10892 .5152 Mdot
.016 w
.10892 .5152 m
.10899 .51973 L
s
.008 w
.10899 .51973 Mdot
.016 w
.10899 .51973 m
.10917 .52479 L
s
.008 w
.10917 .52479 Mdot
.016 w
.10917 .52479 m
.10952 .52934 L
s
.008 w
.10952 .52934 Mdot
.016 w
.10952 .52934 m
.11005 .53475 L
s
1 .996 0 r
.008 w
.11005 .53475 Mdot
.016 w
.11005 .53475 m
.11071 .53925 L
s
.008 w
.11071 .53925 Mdot
.016 w
.11071 .53925 m
.11147 .54407 L
s
.008 w
.11147 .54407 Mdot
.016 w
.11147 .54407 m
.11229 .54861 L
s
.008 w
.11229 .54861 Mdot
.016 w
.11229 .54861 m
.11311 .55328 L
s
.008 w
.11311 .55328 Mdot
.016 w
.11311 .55328 m
.1139 .55786 L
s
1 .995 0 r
.008 w
.1139 .55786 Mdot
.016 w
.1139 .55786 m
.11465 .5623 L
s
.008 w
.11465 .5623 Mdot
.016 w
.11465 .5623 m
.11531 .56666 L
s
.008 w
.11531 .56666 Mdot
.016 w
.11531 .56666 m
.11592 .57066 L
s
.008 w
.11592 .57066 Mdot
.016 w
.11592 .57066 m
.11648 .57452 L
s
.008 w
.11648 .57452 Mdot
.016 w
.11648 .57452 m
.11697 .5781 L
s
1 .994 0 r
.008 w
.11697 .5781 Mdot
.016 w
.11697 .5781 m
.11743 .58125 L
s
.008 w
.11743 .58125 Mdot
.016 w
.11743 .58125 m
.11784 .58418 L
s
.008 w
.11784 .58418 Mdot
.016 w
.11784 .58418 m
.1182 .58652 L
s
.008 w
.1182 .58652 Mdot
.016 w
.1182 .58652 m
.11851 .58856 L
s
.008 w
.11851 .58856 Mdot
.016 w
.11851 .58856 m
.11877 .59021 L
s
.008 w
.11877 .59021 Mdot
.016 w
.11877 .59021 m
.11898 .59144 L
s
1 .993 0 r
.008 w
.11898 .59144 Mdot
.016 w
.11898 .59144 m
.11917 .59235 L
s
.008 w
.11917 .59235 Mdot
.016 w
.11917 .59235 m
.11934 .59296 L
s
.008 w
.11934 .59296 Mdot
.016 w
.11934 .59296 m
.11951 .5933 L
s
.008 w
.11951 .5933 Mdot
.016 w
.11951 .5933 m
.11966 .59342 L
s
.008 w
.11966 .59342 Mdot
.016 w
.11966 .59342 m
.11978 .59341 L
s
1 .992 0 r
.008 w
.11978 .59341 Mdot
.016 w
.11978 .59341 m
.11987 .5933 L
s
.008 w
.11987 .5933 Mdot
.016 w
.11987 .5933 m
.11993 .59316 L
s
.008 w
.11993 .59316 Mdot
.016 w
.11993 .59316 m
.11995 .59302 L
s
.008 w
.11995 .59302 Mdot
.016 w
.11995 .59302 m
.11994 .5929 L
s
.008 w
.11994 .5929 Mdot
.016 w
.11994 .5929 m
.1199 .59282 L
s
1 .991 0 r
.008 w
.1199 .59282 Mdot
.016 w
.1199 .59282 m
.11986 .59275 L
s
.008 w
.11986 .59275 Mdot
.016 w
.11986 .59275 m
.11983 .59272 L
s
.008 w
.11983 .59272 Mdot
.016 w
.11983 .59272 m
.11982 .59272 L
s
.008 w
.11982 .59272 Mdot
.016 w
.11982 .59272 m
.11981 .59272 L
s
.008 w
.11981 .59272 Mdot
.016 w
.11981 .59272 m
.11981 .59272 L
s
.008 w
.11981 .59272 Mdot
.016 w
.11981 .59272 m
.1198 .59272 L
s
1 .99 0 r
.008 w
.1198 .59272 Mdot
.016 w
.1198 .59272 m
.11977 .59272 L
s
.008 w
.11977 .59272 Mdot
.016 w
.11977 .59272 m
.11973 .59272 L
s
.008 w
.11973 .59272 Mdot
.016 w
.11973 .59272 m
.11969 .59272 L
s
.008 w
.11969 .59272 Mdot
.016 w
.11969 .59272 m
.11967 .59272 L
s
.008 w
.11967 .59272 Mdot
.016 w
.11967 .59272 m
.11969 .59272 L
s
1 .989 0 r
.008 w
.11969 .59272 Mdot
.016 w
.11969 .59272 m
.11974 .59272 L
s
.008 w
.11974 .59272 Mdot
.016 w
.11974 .59272 m
.11984 .59271 L
s
.008 w
.11984 .59271 Mdot
.016 w
.11984 .59271 m
.11999 .59271 L
s
.008 w
.11999 .59271 Mdot
.016 w
.11999 .59271 m
.12018 .59269 L
s
.008 w
.12018 .59269 Mdot
.016 w
.12018 .59269 m
.12042 .59263 L
s
1 .988 0 r
.008 w
.12042 .59263 Mdot
.016 w
.12042 .59263 m
.12069 .59251 L
s
.008 w
.12069 .59251 Mdot
.016 w
.12069 .59251 m
.12098 .59234 L
s
.008 w
.12098 .59234 Mdot
.016 w
.12098 .59234 m
.12125 .59213 L
s
.008 w
.12125 .59213 Mdot
.016 w
.12125 .59213 m
.1215 .59193 L
s
.008 w
.1215 .59193 Mdot
.016 w
.1215 .59193 m
.12171 .59176 L
s
1 .987 0 r
.008 w
.12171 .59176 Mdot
.016 w
.12171 .59176 m
.12187 .59167 L
s
.008 w
.12187 .59167 Mdot
.016 w
.12187 .59167 m
.12198 .59176 L
s
.008 w
.12198 .59176 Mdot
.016 w
.12198 .59176 m
.12202 .5921 L
s
.008 w
.12202 .5921 Mdot
.016 w
.12202 .5921 m
.12201 .59275 L
s
.008 w
.12201 .59275 Mdot
.016 w
.12201 .59275 m
.12196 .59379 L
s
.008 w
.12196 .59379 Mdot
.016 w
.12196 .59379 m
.1219 .59528 L
s
1 .986 0 r
.008 w
.1219 .59528 Mdot
.016 w
.1219 .59528 m
.12184 .59731 L
s
.008 w
.12184 .59731 Mdot
.016 w
.12184 .59731 m
.12181 .59949 L
s
.008 w
.12181 .59949 Mdot
.016 w
.12181 .59949 m
.12183 .60243 L
s
.008 w
.12183 .60243 Mdot
.016 w
.12183 .60243 m
.12191 .60569 L
s
.008 w
.12191 .60569 Mdot
.016 w
.12191 .60569 m
.1221 .60956 L
s
1 .985 0 r
.008 w
.1221 .60956 Mdot
.016 w
.1221 .60956 m
.12239 .61382 L
s
.008 w
.12239 .61382 Mdot
.016 w
.12239 .61382 m
.12275 .61875 L
s
.008 w
.12275 .61875 Mdot
.016 w
.12275 .61875 m
.12319 .62303 L
s
.008 w
.12319 .62303 Mdot
.016 w
.12319 .62303 m
.12368 .62855 L
s
.008 w
.12368 .62855 Mdot
.016 w
.12368 .62855 m
.12423 .63348 L
s
1 .984 0 r
.008 w
.12423 .63348 Mdot
.016 w
.12423 .63348 m
.12478 .63866 L
s
.008 w
.12478 .63866 Mdot
.016 w
.12478 .63866 m
.12535 .64393 L
s
.008 w
.12535 .64393 Mdot
.016 w
.12535 .64393 m
.12593 .64869 L
s
.008 w
.12593 .64869 Mdot
.016 w
.12593 .64869 m
.12649 .65348 L
s
.008 w
.12649 .65348 Mdot
.016 w
.12649 .65348 m
.12702 .65798 L
s
1 .983 0 r
.008 w
.12702 .65798 Mdot
.016 w
.12702 .65798 m
.12756 .66217 L
s
.008 w
.12756 .66217 Mdot
.016 w
.12756 .66217 m
.12813 .66636 L
s
.008 w
.12813 .66636 Mdot
.016 w
.12813 .66636 m
.12872 .67003 L
s
.008 w
.12872 .67003 Mdot
.016 w
.12872 .67003 m
.1293 .6737 L
s
.008 w
.1293 .6737 Mdot
.016 w
.1293 .6737 m
.1299 .67682 L
s
.008 w
.1299 .67682 Mdot
.016 w
.1299 .67682 m
.13052 .67992 L
s
1 .982 0 r
.008 w
.13052 .67992 Mdot
.016 w
.13052 .67992 m
.13111 .68257 L
s
.008 w
.13111 .68257 Mdot
.016 w
.13111 .68257 m
.13168 .68507 L
s
.008 w
.13168 .68507 Mdot
.016 w
.13168 .68507 m
.13223 .68728 L
s
.008 w
.13223 .68728 Mdot
.016 w
.13223 .68728 m
.13274 .68891 L
s
.008 w
.13274 .68891 Mdot
.016 w
.13274 .68891 m
.1332 .69053 L
s
1 .981 0 r
.008 w
.1332 .69053 Mdot
.016 w
.1332 .69053 m
.13359 .69178 L
s
.008 w
.13359 .69178 Mdot
.016 w
.13359 .69178 m
.13391 .69286 L
s
.008 w
.13391 .69286 Mdot
.016 w
.13391 .69286 m
.13415 .69376 L
s
.008 w
.13415 .69376 Mdot
.016 w
.13415 .69376 m
.13431 .69444 L
s
.008 w
.13431 .69444 Mdot
.016 w
.13431 .69444 m
.13441 .69491 L
s
1 .98 0 r
.008 w
.13441 .69491 Mdot
.016 w
.13441 .69491 m
.13446 .69515 L
s
.008 w
.13446 .69515 Mdot
.016 w
.13446 .69515 m
.13448 .69521 L
s
.008 w
.13448 .69521 Mdot
.016 w
.13448 .69521 m
.13447 .69514 L
s
.008 w
.13447 .69514 Mdot
.016 w
.13447 .69514 m
.13444 .69498 L
s
.008 w
.13444 .69498 Mdot
.016 w
.13444 .69498 m
.1344 .6948 L
s
1 .979 0 r
.008 w
.1344 .6948 Mdot
.016 w
.1344 .6948 m
.13436 .69464 L
s
.008 w
.13436 .69464 Mdot
.016 w
.13436 .69464 m
.13432 .69454 L
s
.008 w
.13432 .69454 Mdot
.016 w
.13432 .69454 m
.13427 .69448 L
s
.008 w
.13427 .69448 Mdot
.016 w
.13427 .69448 m
.13423 .69443 L
s
.008 w
.13423 .69443 Mdot
.016 w
.13423 .69443 m
.13419 .6944 L
s
.008 w
.13419 .6944 Mdot
.016 w
.13419 .6944 m
.13416 .69438 L
s
1 .978 0 r
.008 w
.13416 .69438 Mdot
.016 w
.13416 .69438 m
.13414 .69439 L
s
.008 w
.13414 .69439 Mdot
.016 w
.13414 .69439 m
.13416 .69445 L
s
.008 w
.13416 .69445 Mdot
.016 w
.13416 .69445 m
.13423 .69454 L
s
.008 w
.13423 .69454 Mdot
.016 w
.13423 .69454 m
.13435 .69468 L
s
.008 w
.13435 .69468 Mdot
.016 w
.13435 .69468 m
.13455 .69486 L
s
1 .977 0 r
.008 w
.13455 .69486 Mdot
.016 w
.13455 .69486 m
.13482 .69507 L
s
.008 w
.13482 .69507 Mdot
.016 w
.13482 .69507 m
.13517 .69529 L
s
.008 w
.13517 .69529 Mdot
.016 w
.13517 .69529 m
.13557 .69553 L
s
.008 w
.13557 .69553 Mdot
.016 w
.13557 .69553 m
.136 .69577 L
s
.008 w
.136 .69577 Mdot
.016 w
.136 .69577 m
.13647 .696 L
s
1 .976 0 r
.008 w
.13647 .696 Mdot
.016 w
.13647 .696 m
.13695 .69623 L
s
.008 w
.13695 .69623 Mdot
.016 w
.13695 .69623 m
.13744 .69644 L
s
.008 w
.13744 .69644 Mdot
.016 w
.13744 .69644 m
.13789 .69662 L
s
.008 w
.13789 .69662 Mdot
.016 w
.13789 .69662 m
.1383 .69676 L
s
.008 w
.1383 .69676 Mdot
.016 w
.1383 .69676 m
.13866 .69685 L
s
1 .975 0 r
.008 w
.13866 .69685 Mdot
.016 w
.13866 .69685 m
.13896 .6969 L
s
.008 w
.13896 .6969 Mdot
.016 w
.13896 .6969 m
.13918 .69691 L
s
.008 w
.13918 .69691 Mdot
.016 w
.13918 .69691 m
.13933 .69689 L
s
.008 w
.13933 .69689 Mdot
.016 w
.13933 .69689 m
.13941 .69685 L
s
.008 w
.13941 .69685 Mdot
.016 w
.13941 .69685 m
.13943 .69681 L
s
.008 w
.13943 .69681 Mdot
.016 w
.13943 .69681 m
.13942 .69677 L
s
1 .974 0 r
.008 w
.13942 .69677 Mdot
.016 w
.13942 .69677 m
.1394 .69676 L
s
.008 w
.1394 .69676 Mdot
.016 w
.1394 .69676 m
.13936 .69676 L
s
.008 w
.13936 .69676 Mdot
.016 w
.13936 .69676 m
.13931 .69675 L
s
.008 w
.13931 .69675 Mdot
.016 w
.13931 .69675 m
.13926 .69673 L
s
.008 w
.13926 .69673 Mdot
.016 w
.13926 .69673 m
.13922 .69667 L
s
1 .973 0 r
.008 w
.13922 .69667 Mdot
.016 w
.13922 .69667 m
.13918 .69658 L
s
.008 w
.13918 .69658 Mdot
.016 w
.13918 .69658 m
.13914 .69649 L
s
.008 w
.13914 .69649 Mdot
.016 w
.13914 .69649 m
.1391 .69639 L
s
.008 w
.1391 .69639 Mdot
.016 w
.1391 .69639 m
.13907 .69632 L
s
.008 w
.13907 .69632 Mdot
.016 w
.13907 .69632 m
.13906 .69633 L
s
1 .972 0 r
.008 w
.13906 .69633 Mdot
.016 w
.13906 .69633 m
.13908 .69646 L
s
.008 w
.13908 .69646 Mdot
.016 w
.13908 .69646 m
.13915 .69673 L
s
.008 w
.13915 .69673 Mdot
.016 w
.13915 .69673 m
.13929 .69717 L
s
.008 w
.13929 .69717 Mdot
.016 w
.13929 .69717 m
.13951 .69775 L
s
.008 w
.13951 .69775 Mdot
.016 w
.13951 .69775 m
.13983 .69848 L
s
.008 w
.13983 .69848 Mdot
.016 w
.13983 .69848 m
.14023 .69932 L
s
1 .971 0 r
.008 w
.14023 .69932 Mdot
.016 w
.14023 .69932 m
.14074 .70024 L
s
.008 w
.14074 .70024 Mdot
.016 w
.14074 .70024 m
.14134 .70128 L
s
.008 w
.14134 .70128 Mdot
.016 w
.14134 .70128 m
.14205 .70244 L
s
.008 w
.14205 .70244 Mdot
.016 w
.14205 .70244 m
.14288 .70374 L
s
.008 w
.14288 .70374 Mdot
.016 w
.14288 .70374 m
.14377 .70517 L
s
1 .97 0 r
.008 w
.14377 .70517 Mdot
.016 w
.14377 .70517 m
.14481 .70665 L
s
.008 w
.14481 .70665 Mdot
.016 w
.14481 .70665 m
.14585 .70827 L
s
.008 w
.14585 .70827 Mdot
.016 w
.14585 .70827 m
.147 .71003 L
s
.008 w
.147 .71003 Mdot
.016 w
.147 .71003 m
.1482 .71193 L
s
.008 w
.1482 .71193 Mdot
.016 w
.1482 .71193 m
.14945 .71377 L
s
1 .969 0 r
.008 w
.14945 .71377 Mdot
.016 w
.14945 .71377 m
.1508 .71584 L
s
.008 w
.1508 .71584 Mdot
.016 w
.1508 .71584 m
.15211 .7179 L
s
.008 w
.15211 .7179 Mdot
.016 w
.15211 .7179 m
.15342 .72012 L
s
.008 w
.15342 .72012 Mdot
.016 w
.15342 .72012 m
.15479 .72245 L
s
.008 w
.15479 .72245 Mdot
.016 w
.15479 .72245 m
.15608 .72472 L
s
1 .968 0 r
.008 w
.15608 .72472 Mdot
.016 w
.15608 .72472 m
.15737 .72707 L
s
.008 w
.15737 .72707 Mdot
.016 w
.15737 .72707 m
.15854 .72916 L
s
.008 w
.15854 .72916 Mdot
.016 w
.15854 .72916 m
.15965 .73116 L
s
.008 w
.15965 .73116 Mdot
.016 w
.15965 .73116 m
.16061 .73291 L
s
.008 w
.16061 .73291 Mdot
.016 w
.16061 .73291 m
.16148 .73443 L
s
.008 w
.16148 .73443 Mdot
.016 w
.16148 .73443 m
.16216 .7356 L
s
1 .967 0 r
.008 w
.16216 .7356 Mdot
.016 w
.16216 .7356 m
.16272 .73651 L
s
.008 w
.16272 .73651 Mdot
.016 w
.16272 .73651 m
.16315 .73717 L
s
.008 w
.16315 .73717 Mdot
.016 w
.16315 .73717 m
.16345 .73762 L
s
.008 w
.16345 .73762 Mdot
.016 w
.16345 .73762 m
.16364 .73789 L
s
.008 w
.16364 .73789 Mdot
.016 w
.16364 .73789 m
.16373 .73801 L
s
1 .966 0 r
.008 w
.16373 .73801 Mdot
.016 w
.16373 .73801 m
.16374 .73802 L
s
.008 w
.16374 .73802 Mdot
.016 w
.16374 .73802 m
.16372 .73796 L
s
.008 w
.16372 .73796 Mdot
.016 w
.16372 .73796 m
.16367 .73788 L
s
.008 w
.16367 .73788 Mdot
.016 w
.16367 .73788 m
.16362 .73778 L
s
.008 w
.16362 .73778 Mdot
.016 w
.16362 .73778 m
.16356 .73767 L
s
1 .965 0 r
.008 w
.16356 .73767 Mdot
.016 w
.16356 .73767 m
.16349 .73756 L
s
.008 w
.16349 .73756 Mdot
.016 w
.16349 .73756 m
.16343 .73749 L
s
.008 w
.16343 .73749 Mdot
.016 w
.16343 .73749 m
.16337 .73743 L
s
.008 w
.16337 .73743 Mdot
.016 w
.16337 .73743 m
.16329 .73736 L
s
.008 w
.16329 .73736 Mdot
.016 w
.16329 .73736 m
.1632 .73725 L
s
1 .964 0 r
.008 w
.1632 .73725 Mdot
.016 w
.1632 .73725 m
.16309 .73707 L
s
.008 w
.16309 .73707 Mdot
.016 w
.16309 .73707 m
.16299 .73685 L
s
.008 w
.16299 .73685 Mdot
.016 w
.16299 .73685 m
.16288 .73663 L
s
.008 w
.16288 .73663 Mdot
.016 w
.16288 .73663 m
.16275 .73645 L
s
.008 w
.16275 .73645 Mdot
.016 w
.16275 .73645 m
.16261 .73636 L
s
.008 w
.16261 .73636 Mdot
.016 w
.16261 .73636 m
.16249 .73639 L
s
1 .963 0 r
.008 w
.16249 .73639 Mdot
.016 w
.16249 .73639 m
.16243 .73661 L
s
.008 w
.16243 .73661 Mdot
.016 w
.16243 .73661 m
.16245 .73705 L
s
.008 w
.16245 .73705 Mdot
.016 w
.16245 .73705 m
.16261 .73775 L
s
.008 w
.16261 .73775 Mdot
.016 w
.16261 .73775 m
.16297 .73876 L
s
.008 w
.16297 .73876 Mdot
.016 w
.16297 .73876 m
.16356 .74014 L
s
1 .962 0 r
.008 w
.16356 .74014 Mdot
.016 w
.16356 .74014 m
.16443 .74192 L
s
.008 w
.16443 .74192 Mdot
.016 w
.16443 .74192 m
.16559 .74385 L
s
.008 w
.16559 .74385 Mdot
.016 w
.16559 .74385 m
.16708 .7464 L
s
.008 w
.16708 .7464 Mdot
.016 w
.16708 .7464 m
.16904 .74902 L
s
.008 w
.16904 .74902 Mdot
.016 w
.16904 .74902 m
.17105 .75219 L
s
1 .961 0 r
.008 w
.17105 .75219 Mdot
.016 w
.17105 .75219 m
.17315 .75547 L
s
.008 w
.17315 .75547 Mdot
.016 w
.17315 .75547 m
.17567 .7592 L
s
.008 w
.17567 .7592 Mdot
.016 w
.17567 .7592 m
.17851 .76302 L
s
.008 w
.17851 .76302 Mdot
.016 w
.17851 .76302 m
.18135 .76699 L
s
.008 w
.18135 .76699 Mdot
.016 w
.18135 .76699 m
.18443 .77112 L
s
1 .96 0 r
.008 w
.18443 .77112 Mdot
.016 w
.18443 .77112 m
.18741 .7753 L
s
.008 w
.18741 .7753 Mdot
.016 w
.18741 .7753 m
.19031 .77934 L
s
.008 w
.19031 .77934 Mdot
.016 w
.19031 .77934 m
.19322 .78348 L
s
.008 w
.19322 .78348 Mdot
.016 w
.19322 .78348 m
.196 .78767 L
s
.008 w
.196 .78767 Mdot
.016 w
.196 .78767 m
.19869 .7918 L
s
.008 w
.19869 .7918 Mdot
.016 w
.19869 .7918 m
.20128 .79582 L
s
1 .959 0 r
.008 w
.20128 .79582 Mdot
.016 w
.20128 .79582 m
.2038 .79988 L
s
.008 w
.2038 .79988 Mdot
.016 w
.2038 .79988 m
.20633 .80389 L
s
.008 w
.20633 .80389 Mdot
.016 w
.20633 .80389 m
.20894 .80766 L
s
.008 w
.20894 .80766 Mdot
.016 w
.20894 .80766 m
.21164 .8116 L
s
.008 w
.21164 .8116 Mdot
.016 w
.21164 .8116 m
.21452 .81542 L
s
1 .958 0 r
.008 w
.21452 .81542 Mdot
.016 w
.21452 .81542 m
.21751 .81911 L
s
.008 w
.21751 .81911 Mdot
.016 w
.21751 .81911 m
.22091 .82305 L
s
.008 w
.22091 .82305 Mdot
.016 w
.22091 .82305 m
.22432 .82698 L
s
.008 w
.22432 .82698 Mdot
.016 w
.22432 .82698 m
.22792 .83079 L
s
.008 w
.22792 .83079 Mdot
.016 w
.22792 .83079 m
.2318 .83499 L
s
1 .957 0 r
.008 w
.2318 .83499 Mdot
.016 w
.2318 .83499 m
.23572 .83895 L
s
.008 w
.23572 .83895 Mdot
.016 w
.23572 .83895 m
.23982 .84331 L
s
.008 w
.23982 .84331 Mdot
.016 w
.23982 .84331 m
.24404 .84687 L
s
.008 w
.24404 .84687 Mdot
.016 w
.24404 .84687 m
.24825 .85118 L
s
.008 w
.24825 .85118 Mdot
.016 w
.24825 .85118 m
.25249 .85497 L
s
.008 w
.25249 .85497 Mdot
.016 w
.25249 .85497 m
.25679 .85939 L
s
1 .956 0 r
.008 w
.25679 .85939 Mdot
.016 w
.25679 .85939 m
.2611 .86312 L
s
.008 w
.2611 .86312 Mdot
.016 w
.2611 .86312 m
.26531 .86686 L
s
.008 w
.26531 .86686 Mdot
.016 w
.26531 .86686 m
.2695 .87066 L
s
.008 w
.2695 .87066 Mdot
.016 w
.2695 .87066 m
.27392 .87435 L
s
.008 w
.27392 .87435 Mdot
.016 w
.27392 .87435 m
.27784 .87802 L
s
1 .955 0 r
.008 w
.27784 .87802 Mdot
.016 w
.27784 .87802 m
.28218 .88144 L
s
.008 w
.28218 .88144 Mdot
.016 w
.28218 .88144 m
.28616 .88443 L
s
.008 w
.28616 .88443 Mdot
.016 w
.28616 .88443 m
.29032 .88744 L
s
.008 w
.29032 .88744 Mdot
.016 w
.29032 .88744 m
.29438 .88993 L
s
.008 w
.29438 .88993 Mdot
.016 w
.29438 .88993 m
.29841 .89241 L
s
1 .954 0 r
.008 w
.29841 .89241 Mdot
.016 w
.29841 .89241 m
.30247 .8947 L
s
.008 w
.30247 .8947 Mdot
.016 w
.30247 .8947 m
.30636 .89666 L
s
.008 w
.30636 .89666 Mdot
.016 w
.30636 .89666 m
.31038 .89853 L
s
.008 w
.31038 .89853 Mdot
.016 w
.31038 .89853 m
.3143 .90022 L
s
.008 w
.3143 .90022 Mdot
.016 w
.3143 .90022 m
.31833 .90183 L
s
1 .953 0 r
.008 w
.31833 .90183 Mdot
.016 w
.31833 .90183 m
.32217 .90335 L
s
.008 w
.32217 .90335 Mdot
.016 w
.32217 .90335 m
.32642 .90487 L
s
.008 w
.32642 .90487 Mdot
.016 w
.32642 .90487 m
.33058 .90643 L
s
.008 w
.33058 .90643 Mdot
.016 w
.33058 .90643 m
.33493 .90792 L
s
.008 w
.33493 .90792 Mdot
.016 w
.33493 .90792 m
.33983 .90962 L
s
.008 w
.33983 .90962 Mdot
.016 w
.33983 .90962 m
.34406 .91135 L
s
1 .952 0 r
.008 w
.34406 .91135 Mdot
.016 w
.34406 .91135 m
.34882 .91318 L
s
.008 w
.34882 .91318 Mdot
.016 w
.34882 .91318 m
.35391 .91513 L
s
.008 w
.35391 .91513 Mdot
.016 w
.35391 .91513 m
.35871 .91703 L
s
.008 w
.35871 .91703 Mdot
.016 w
.35871 .91703 m
.36379 .91907 L
s
.008 w
.36379 .91907 Mdot
.016 w
.36379 .91907 m
.36966 .92111 L
s
1 .951 0 r
.008 w
.36966 .92111 Mdot
.016 w
.36966 .92111 m
.37438 .9231 L
s
.008 w
.37438 .9231 Mdot
.016 w
.37438 .9231 m
.37968 .92515 L
s
.008 w
.37968 .92515 Mdot
.016 w
.37968 .92515 m
.385 .92702 L
s
.008 w
.385 .92702 Mdot
.016 w
.385 .92702 m
.39026 .92887 L
s
.008 w
.39026 .92887 Mdot
.016 w
.39026 .92887 m
.39532 .93055 L
s
1 .95 0 r
.008 w
.39532 .93055 Mdot
.016 w
.39532 .93055 m
.40024 .93222 L
s
.008 w
.40024 .93222 Mdot
.016 w
.40024 .93222 m
.40502 .93384 L
s
.008 w
.40502 .93384 Mdot
.016 w
.40502 .93384 m
.40972 .93543 L
s
.008 w
.40972 .93543 Mdot
.016 w
.40972 .93543 m
.41428 .93697 L
s
.008 w
.41428 .93697 Mdot
.016 w
.41428 .93697 m
.41882 .93849 L
s
1 .949 0 r
.008 w
.41882 .93849 Mdot
.016 w
.41882 .93849 m
.42321 .93989 L
s
.008 w
.42321 .93989 Mdot
.016 w
.42321 .93989 m
.42731 .94126 L
s
.008 w
.42731 .94126 Mdot
.016 w
.42731 .94126 m
.43135 .94257 L
s
.008 w
.43135 .94257 Mdot
.016 w
.43135 .94257 m
.4353 .9439 L
s
.008 w
.4353 .9439 Mdot
.016 w
.4353 .9439 m
.43891 .94517 L
s
.008 w
.43891 .94517 Mdot
.016 w
.43891 .94517 m
.44269 .94647 L
s
1 .948 0 r
.008 w
.44269 .94647 Mdot
.016 w
.44269 .94647 m
.44609 .94781 L
s
.008 w
.44609 .94781 Mdot
.016 w
.44609 .94781 m
.44948 .94912 L
s
.008 w
.44948 .94912 Mdot
.016 w
.44948 .94912 m
.45291 .95043 L
s
.008 w
.45291 .95043 Mdot
.016 w
.45291 .95043 m
.45647 .95172 L
s
.008 w
.45647 .95172 Mdot
.016 w
.45647 .95172 m
.46009 .95293 L
s
1 .947 0 r
.008 w
.46009 .95293 Mdot
.016 w
.46009 .95293 m
.46361 .95403 L
s
.008 w
.46361 .95403 Mdot
.016 w
.46361 .95403 m
.46743 .955 L
s
.008 w
.46743 .955 Mdot
.016 w
.46743 .955 m
.47105 .95583 L
s
.008 w
.47105 .95583 Mdot
.016 w
.47105 .95583 m
.47457 .95652 L
s
.008 w
.47457 .95652 Mdot
.016 w
.47457 .95652 m
.47841 .95705 L
s
1 .946 0 r
.008 w
.47841 .95705 Mdot
.016 w
.47841 .95705 m
.48176 .95746 L
s
.008 w
.48176 .95746 Mdot
.016 w
.48176 .95746 m
.48528 .95773 L
s
.008 w
.48528 .95773 Mdot
.016 w
.48528 .95773 m
.48883 .95786 L
s
.008 w
.48883 .95786 Mdot
.016 w
.48883 .95786 m
.49255 .95783 L
s
.008 w
.49255 .95783 Mdot
.016 w
.49255 .95783 m
.49592 .95765 L
s
1 .945 0 r
.008 w
.49592 .95765 Mdot
.016 w
.49592 .95765 m
.49954 .95734 L
s
.008 w
.49954 .95734 Mdot
.016 w
.49954 .95734 m
.50322 .95693 L
s
.008 w
.50322 .95693 Mdot
.016 w
.50322 .95693 m
.50689 .95649 L
s
.008 w
.50689 .95649 Mdot
.016 w
.50689 .95649 m
.51086 .95604 L
s
.008 w
.51086 .95604 Mdot
.016 w
.51086 .95604 m
.5151 .95561 L
s
.008 w
.5151 .95561 Mdot
.016 w
.5151 .95561 m
.51939 .95515 L
s
1 .944 0 r
.008 w
.51939 .95515 Mdot
.016 w
.51939 .95515 m
.52399 .95465 L
s
.008 w
.52399 .95465 Mdot
.016 w
.52399 .95465 m
.52895 .95408 L
s
.008 w
.52895 .95408 Mdot
.016 w
.52895 .95408 m
.53409 .9534 L
s
.008 w
.53409 .9534 Mdot
.016 w
.53409 .9534 m
.53955 .95262 L
s
.008 w
.53955 .95262 Mdot
.016 w
.53955 .95262 m
.54508 .95171 L
s
1 .943 0 r
.008 w
.54508 .95171 Mdot
.016 w
.54508 .95171 m
.55075 .95071 L
s
.008 w
.55075 .95071 Mdot
.016 w
.55075 .95071 m
.5564 .94964 L
s
.008 w
.5564 .94964 Mdot
.016 w
.5564 .94964 m
.56216 .94855 L
s
.008 w
.56216 .94855 Mdot
.016 w
.56216 .94855 m
.56784 .94744 L
s
.008 w
.56784 .94744 Mdot
.016 w
.56784 .94744 m
.57323 .94639 L
s
1 .942 0 r
.008 w
.57323 .94639 Mdot
.016 w
.57323 .94639 m
.57844 .94539 L
s
.008 w
.57844 .94539 Mdot
.016 w
.57844 .94539 m
.58358 .94445 L
s
.008 w
.58358 .94445 Mdot
.016 w
.58358 .94445 m
.58825 .94358 L
s
.008 w
.58825 .94358 Mdot
.016 w
.58825 .94358 m
.59273 .94283 L
s
.008 w
.59273 .94283 Mdot
.016 w
.59273 .94283 m
.59693 .94218 L
s
.008 w
.59693 .94218 Mdot
.016 w
.59693 .94218 m
.60077 .94163 L
s
1 .941 0 r
.008 w
.60077 .94163 Mdot
.016 w
.60077 .94163 m
.60427 .94112 L
s
.008 w
.60427 .94112 Mdot
.016 w
.60427 .94112 m
.60737 .94077 L
s
.008 w
.60737 .94077 Mdot
.016 w
.60737 .94077 m
.61012 .94047 L
s
.008 w
.61012 .94047 Mdot
.016 w
.61012 .94047 m
.61251 .94019 L
s
.008 w
.61251 .94019 Mdot
.016 w
.61251 .94019 m
.61463 .93988 L
s
1 .94 0 r
.008 w
.61463 .93988 Mdot
.016 w
.61463 .93988 m
.61651 .93956 L
s
.008 w
.61651 .93956 Mdot
.016 w
.61651 .93956 m
.61818 .93917 L
s
.008 w
.61818 .93917 Mdot
.016 w
.61818 .93917 m
.61972 .93872 L
s
.008 w
.61972 .93872 Mdot
.016 w
.61972 .93872 m
.6212 .93824 L
s
.008 w
.6212 .93824 Mdot
.016 w
.6212 .93824 m
.62272 .93769 L
s
1 .939 0 r
.008 w
.62272 .93769 Mdot
.016 w
.62272 .93769 m
.62437 .93713 L
s
.008 w
.62437 .93713 Mdot
.016 w
.62437 .93713 m
.62609 .93653 L
s
.008 w
.62609 .93653 Mdot
.016 w
.62609 .93653 m
.62805 .93586 L
s
.008 w
.62805 .93586 Mdot
.016 w
.62805 .93586 m
.63031 .93514 L
s
.008 w
.63031 .93514 Mdot
.016 w
.63031 .93514 m
.63274 .93436 L
s
1 .938 0 r
.008 w
.63274 .93436 Mdot
.016 w
.63274 .93436 m
.63555 .93349 L
s
.008 w
.63555 .93349 Mdot
.016 w
.63555 .93349 m
.63851 .93246 L
s
.008 w
.63851 .93246 Mdot
.016 w
.63851 .93246 m
.64182 .9314 L
s
.008 w
.64182 .9314 Mdot
.016 w
.64182 .9314 m
.64496 .93045 L
s
.008 w
.64496 .93045 Mdot
.016 w
.64496 .93045 m
.64833 .92933 L
s
.008 w
.64833 .92933 Mdot
.016 w
.64833 .92933 m
.65205 .92818 L
s
1 .937 0 r
.008 w
.65205 .92818 Mdot
.016 w
.65205 .92818 m
.65524 .927 L
s
.008 w
.65524 .927 Mdot
.016 w
.65524 .927 m
.65854 .92569 L
s
.008 w
.65854 .92569 Mdot
.016 w
.65854 .92569 m
.66188 .92468 L
s
.008 w
.66188 .92468 Mdot
.016 w
.66188 .92468 m
.66516 .92349 L
s
.008 w
.66516 .92349 Mdot
.016 w
.66516 .92349 m
.66834 .92221 L
s
1 .936 0 r
.008 w
.66834 .92221 Mdot
.016 w
.66834 .92221 m
.67151 .92074 L
s
.008 w
.67151 .92074 Mdot
.016 w
.67151 .92074 m
.67437 .91934 L
s
.008 w
.67437 .91934 Mdot
.016 w
.67437 .91934 m
.67715 .91778 L
s
.008 w
.67715 .91778 Mdot
.016 w
.67715 .91778 m
.67998 .91629 L
s
.008 w
.67998 .91629 Mdot
.016 w
.67998 .91629 m
.68279 .91459 L
s
1 .935 0 r
.008 w
.68279 .91459 Mdot
.016 w
.68279 .91459 m
.68566 .91271 L
s
.008 w
.68566 .91271 Mdot
.016 w
.68566 .91271 m
.68846 .91082 L
s
.008 w
.68846 .91082 Mdot
.016 w
.68846 .91082 m
.69148 .90892 L
s
.008 w
.69148 .90892 Mdot
.016 w
.69148 .90892 m
.69424 .90687 L
s
.008 w
.69424 .90687 Mdot
.016 w
.69424 .90687 m
.69707 .90491 L
s
1 .934 0 r
.008 w
.69707 .90491 Mdot
.016 w
.69707 .90491 m
.69994 .903 L
s
.008 w
.69994 .903 Mdot
.016 w
.69994 .903 m
.70277 .9012 L
s
.008 w
.70277 .9012 Mdot
.016 w
.70277 .9012 m
.70571 .89956 L
s
.008 w
.70571 .89956 Mdot
.016 w
.70571 .89956 m
.70856 .89812 L
s
.008 w
.70856 .89812 Mdot
.016 w
.70856 .89812 m
.71156 .89692 L
s
.008 w
.71156 .89692 Mdot
.016 w
.71156 .89692 m
.71461 .89591 L
s
1 .933 0 r
.008 w
.71461 .89591 Mdot
.016 w
.71461 .89591 m
.71772 .89499 L
s
.008 w
.71772 .89499 Mdot
.016 w
.71772 .89499 m
.72096 .89411 L
s
.008 w
.72096 .89411 Mdot
.016 w
.72096 .89411 m
.72414 .8932 L
s
.008 w
.72414 .8932 Mdot
.016 w
.72414 .8932 m
.72752 .89219 L
s
.008 w
.72752 .89219 Mdot
.016 w
.72752 .89219 m
.73103 .891 L
s
1 .932 0 r
.008 w
.73103 .891 Mdot
.016 w
.73103 .891 m
.73471 .88957 L
s
.008 w
.73471 .88957 Mdot
.016 w
.73471 .88957 m
.73851 .88795 L
s
.008 w
.73851 .88795 Mdot
.016 w
.73851 .88795 m
.74245 .88605 L
s
.008 w
.74245 .88605 Mdot
.016 w
.74245 .88605 m
.74649 .88388 L
s
.008 w
.74649 .88388 Mdot
.016 w
.74649 .88388 m
.75059 .88149 L
s
1 .931 0 r
.008 w
.75059 .88149 Mdot
.016 w
.75059 .88149 m
.75468 .87889 L
s
.008 w
.75468 .87889 Mdot
.016 w
.75468 .87889 m
.75879 .87602 L
s
.008 w
.75879 .87602 Mdot
.016 w
.75879 .87602 m
.763 .87307 L
s
.008 w
.763 .87307 Mdot
.016 w
.763 .87307 m
.76713 .87 L
s
.008 w
.76713 .87 Mdot
.016 w
.76713 .87 m
.7712 .86684 L
s
1 .93 0 r
.008 w
.7712 .86684 Mdot
.016 w
.7712 .86684 m
.77528 .86359 L
s
.008 w
.77528 .86359 Mdot
.016 w
.77528 .86359 m
.7793 .8604 L
s
.008 w
.7793 .8604 Mdot
.016 w
.7793 .8604 m
.78346 .85708 L
s
.008 w
.78346 .85708 Mdot
.016 w
.78346 .85708 m
.78749 .85369 L
s
.008 w
.78749 .85369 Mdot
.016 w
.78749 .85369 m
.79184 .85026 L
s
.008 w
.79184 .85026 Mdot
.016 w
.79184 .85026 m
.79567 .84688 L
s
1 .929 0 r
.008 w
.79567 .84688 Mdot
.016 w
.79567 .84688 m
.79973 .84346 L
s
.008 w
.79973 .84346 Mdot
.016 w
.79973 .84346 m
.80375 .84005 L
s
.008 w
.80375 .84005 Mdot
.016 w
.80375 .84005 m
.80793 .83655 L
s
.008 w
.80793 .83655 Mdot
.016 w
.80793 .83655 m
.81191 .83308 L
s
.008 w
.81191 .83308 Mdot
.016 w
.81191 .83308 m
.8159 .82969 L
s
1 .928 0 r
.008 w
.8159 .82969 Mdot
.016 w
.8159 .82969 m
.82045 .82605 L
s
.008 w
.82045 .82605 Mdot
.016 w
.82045 .82605 m
.82427 .82267 L
s
.008 w
.82427 .82267 Mdot
.016 w
.82427 .82267 m
.82847 .81914 L
s
.008 w
.82847 .81914 Mdot
.016 w
.82847 .81914 m
.83268 .81571 L
s
.008 w
.83268 .81571 Mdot
.016 w
.83268 .81571 m
.8371 .81222 L
s
1 .927 0 r
.008 w
.8371 .81222 Mdot
.016 w
.8371 .81222 m
.84108 .80905 L
s
.008 w
.84108 .80905 Mdot
.016 w
.84108 .80905 m
.84504 .8058 L
s
.008 w
.84504 .8058 Mdot
.016 w
.84504 .8058 m
.84905 .80256 L
s
.008 w
.84905 .80256 Mdot
.016 w
.84905 .80256 m
.85274 .79927 L
s
.008 w
.85274 .79927 Mdot
.016 w
.85274 .79927 m
.8563 .79582 L
s
1 .926 0 r
.008 w
.8563 .79582 Mdot
.016 w
.8563 .79582 m
.85977 .79232 L
s
.008 w
.85977 .79232 Mdot
.016 w
.85977 .79232 m
.86298 .78864 L
s
.008 w
.86298 .78864 Mdot
.016 w
.86298 .78864 m
.86584 .7845 L
s
.008 w
.86584 .7845 Mdot
.016 w
.86584 .7845 m
.86859 .78047 L
s
.008 w
.86859 .78047 Mdot
.016 w
.86859 .78047 m
.87105 .77614 L
s
.008 w
.87105 .77614 Mdot
.016 w
.87105 .77614 m
.87325 .77176 L
s
1 .925 0 r
.008 w
.87325 .77176 Mdot
.016 w
.87325 .77176 m
.87522 .76708 L
s
.008 w
.87522 .76708 Mdot
.016 w
.87522 .76708 m
.8769 .763 L
s
.008 w
.8769 .763 Mdot
.016 w
.8769 .763 m
.87842 .7588 L
s
.008 w
.87842 .7588 Mdot
.016 w
.87842 .7588 m
.87979 .7548 L
s
.008 w
.87979 .7548 Mdot
.016 w
.87979 .7548 m
.88095 .75106 L
s
1 .924 0 r
.008 w
.88095 .75106 Mdot
.016 w
.88095 .75106 m
.88202 .74786 L
s
.008 w
.88202 .74786 Mdot
.016 w
.88202 .74786 m
.88296 .74496 L
s
.008 w
.88296 .74496 Mdot
.016 w
.88296 .74496 m
.8838 .74267 L
s
.008 w
.8838 .74267 Mdot
.016 w
.8838 .74267 m
.88451 .74083 L
s
.008 w
.88451 .74083 Mdot
.016 w
.88451 .74083 m
.88507 .73949 L
s
1 .923 0 r
.008 w
.88507 .73949 Mdot
.016 w
.88507 .73949 m
.8855 .73863 L
s
.008 w
.8855 .73863 Mdot
.016 w
.8855 .73863 m
.88579 .73817 L
s
.008 w
.88579 .73817 Mdot
.016 w
.88579 .73817 m
.88597 .73805 L
s
.008 w
.88597 .73805 Mdot
.016 w
.88597 .73805 m
.88607 .73814 L
s
.008 w
.88607 .73814 Mdot
.016 w
.88607 .73814 m
.88615 .73836 L
s
.008 w
.88615 .73836 Mdot
.016 w
.88615 .73836 m
.88621 .73864 L
s
1 .922 0 r
.008 w
.88621 .73864 Mdot
.016 w
.88621 .73864 m
.88627 .73894 L
s
.008 w
.88627 .73894 Mdot
.016 w
.88627 .73894 m
.88631 .73918 L
s
.008 w
.88631 .73918 Mdot
.016 w
.88631 .73918 m
.88626 .73932 L
s
.008 w
.88626 .73932 Mdot
.016 w
.88626 .73932 m
.88608 .73937 L
s
.008 w
.88608 .73937 Mdot
.016 w
.88608 .73937 m
.88576 .73934 L
s
1 .921 0 r
.008 w
.88576 .73934 Mdot
.016 w
.88576 .73934 m
.88529 .73923 L
s
.008 w
.88529 .73923 Mdot
.016 w
.88529 .73923 m
.88469 .73906 L
s
.008 w
.88469 .73906 Mdot
.016 w
.88469 .73906 m
.88399 .73887 L
s
.008 w
.88399 .73887 Mdot
.016 w
.88399 .73887 m
.88323 .7387 L
s
.008 w
.88323 .7387 Mdot
.016 w
.88323 .7387 m
.88246 .73859 L
s
1 .92 0 r
.008 w
.88246 .73859 Mdot
.016 w
.88246 .73859 m
.88178 .73858 L
s
.008 w
.88178 .73858 Mdot
.016 w
.88178 .73858 m
.88112 .73865 L
s
.008 w
.88112 .73865 Mdot
.016 w
.88112 .73865 m
.88051 .73881 L
s
.008 w
.88051 .73881 Mdot
.016 w
.88051 .73881 m
.88005 .73902 L
s
.008 w
.88005 .73902 Mdot
.016 w
.88005 .73902 m
.87972 .73923 L
s
1 .919 0 r
.008 w
.87972 .73923 Mdot
.016 w
.87972 .73923 m
.87955 .73935 L
s
.008 w
.87955 .73935 Mdot
.016 w
.87955 .73935 m
.87959 .73933 L
s
.008 w
.87959 .73933 Mdot
.016 w
.87959 .73933 m
.87988 .73913 L
s
.008 w
.87988 .73913 Mdot
.016 w
.87988 .73913 m
.88044 .73857 L
s
.008 w
.88044 .73857 Mdot
.016 w
.88044 .73857 m
.88125 .73754 L
s
.008 w
.88125 .73754 Mdot
.016 w
.88125 .73754 m
.8823 .73601 L
s
1 .918 0 r
.008 w
.8823 .73601 Mdot
.016 w
.8823 .73601 m
.88364 .73403 L
s
.008 w
.88364 .73403 Mdot
.016 w
.88364 .73403 m
.88499 .73137 L
s
.008 w
.88499 .73137 Mdot
.016 w
.88499 .73137 m
.88646 .72807 L
s
.008 w
.88646 .72807 Mdot
.016 w
.88646 .72807 m
.88811 .72383 L
s
.008 w
.88811 .72383 Mdot
.016 w
.88811 .72383 m
.88973 .71952 L
s
1 .917 0 r
.008 w
.88973 .71952 Mdot
.016 w
.88973 .71952 m
.89132 .71448 L
s
.008 w
.89132 .71448 Mdot
.016 w
.89132 .71448 m
.893 .70908 L
s
.008 w
.893 .70908 Mdot
.016 w
.893 .70908 m
.89466 .70356 L
s
.008 w
.89466 .70356 Mdot
.016 w
.89466 .70356 m
.89634 .69771 L
s
.008 w
.89634 .69771 Mdot
.016 w
.89634 .69771 m
.8981 .69243 L
s
1 .916 0 r
.008 w
.8981 .69243 Mdot
.016 w
.8981 .69243 m
.89957 .68759 L
s
.008 w
.89957 .68759 Mdot
.016 w
.89957 .68759 m
.90103 .68239 L
s
.008 w
.90103 .68239 Mdot
.016 w
.90103 .68239 m
.90246 .67731 L
s
.008 w
.90246 .67731 Mdot
.016 w
.90246 .67731 m
.90377 .67259 L
s
.008 w
.90377 .67259 Mdot
.016 w
.90377 .67259 m
.90509 .66809 L
s
1 .915 0 r
.008 w
.90509 .66809 Mdot
.016 w
.90509 .66809 m
.9064 .66318 L
s
.008 w
.9064 .66318 Mdot
.016 w
.9064 .66318 m
.90758 .65887 L
s
.008 w
.90758 .65887 Mdot
.016 w
.90758 .65887 m
.90885 .65416 L
s
.008 w
.90885 .65416 Mdot
.016 w
.90885 .65416 m
.91017 .64906 L
s
.008 w
.91017 .64906 Mdot
.016 w
.91017 .64906 m
.91151 .64418 L
s
.008 w
.91151 .64418 Mdot
.016 w
.91151 .64418 m
.91289 .63908 L
s
1 .914 0 r
.008 w
.91289 .63908 Mdot
.016 w
.91289 .63908 m
.91424 .63373 L
s
.008 w
.91424 .63373 Mdot
.016 w
.91424 .63373 m
.91568 .62839 L
s
.008 w
.91568 .62839 Mdot
.016 w
.91568 .62839 m
.91705 .62259 L
s
.008 w
.91705 .62259 Mdot
.016 w
.91705 .62259 m
.9184 .61701 L
s
.008 w
.9184 .61701 Mdot
.016 w
.9184 .61701 m
.91965 .6121 L
s
1 .913 0 r
.008 w
.91965 .6121 Mdot
.016 w
.91965 .6121 m
.92091 .60617 L
s
.008 w
.92091 .60617 Mdot
.016 w
.92091 .60617 m
.92211 .60131 L
s
.008 w
.92211 .60131 Mdot
.016 w
.92211 .60131 m
.92328 .59605 L
s
.008 w
.92328 .59605 Mdot
.016 w
.92328 .59605 m
.92444 .59054 L
s
.008 w
.92444 .59054 Mdot
.016 w
.92444 .59054 m
.92558 .58555 L
s
1 .912 0 r
.008 w
.92558 .58555 Mdot
.016 w
.92558 .58555 m
.9267 .58053 L
s
.008 w
.9267 .58053 Mdot
.016 w
.9267 .58053 m
.92782 .5754 L
s
.008 w
.92782 .5754 Mdot
.016 w
.92782 .5754 m
.92888 .57034 L
s
.008 w
.92888 .57034 Mdot
.016 w
.92888 .57034 m
.92988 .56513 L
s
.008 w
.92988 .56513 Mdot
.016 w
.92988 .56513 m
.93081 .55985 L
s
1 .911 0 r
.008 w
.93081 .55985 Mdot
.016 w
.93081 .55985 m
.93165 .55471 L
s
.008 w
.93165 .55471 Mdot
.016 w
.93165 .55471 m
.93239 .54943 L
s
.008 w
.93239 .54943 Mdot
.016 w
.93239 .54943 m
.93299 .54439 L
s
.008 w
.93299 .54439 Mdot
.016 w
.93299 .54439 m
.93343 .53946 L
s
.008 w
.93343 .53946 Mdot
.016 w
.93343 .53946 m
.93373 .53512 L
s
.008 w
.93373 .53512 Mdot
.016 w
.93373 .53512 m
.93389 .53099 L
s
1 .91 0 r
.008 w
.93389 .53099 Mdot
.016 w
.93389 .53099 m
.93392 .52731 L
s
.008 w
.93392 .52731 Mdot
.016 w
.93392 .52731 m
.93383 .5241 L
s
.008 w
.93383 .5241 Mdot
.016 w
.93383 .5241 m
.93365 .52126 L
s
.008 w
.93365 .52126 Mdot
.016 w
.93365 .52126 m
.9334 .51865 L
s
.008 w
.9334 .51865 Mdot
.016 w
.9334 .51865 m
.93311 .51644 L
s
1 .909 0 r
.008 w
.93311 .51644 Mdot
.016 w
.93311 .51644 m
.93283 .51435 L
s
.008 w
.93283 .51435 Mdot
.016 w
.93283 .51435 m
.93257 .5123 L
s
.008 w
.93257 .5123 Mdot
.016 w
.93257 .5123 m
.93234 .51025 L
s
.008 w
.93234 .51025 Mdot
.016 w
.93234 .51025 m
.93212 .50801 L
s
.008 w
.93212 .50801 Mdot
.016 w
.93212 .50801 m
.93193 .50551 L
s
1 .908 0 r
.008 w
.93193 .50551 Mdot
.016 w
.93193 .50551 m
.93175 .50296 L
s
.008 w
.93175 .50296 Mdot
.016 w
.93175 .50296 m
.93156 .50013 L
s
.008 w
.93156 .50013 Mdot
.016 w
.93156 .50013 m
.93136 .49726 L
s
.008 w
.93136 .49726 Mdot
.016 w
.93136 .49726 m
.93113 .49417 L
s
.008 w
.93113 .49417 Mdot
.016 w
.93113 .49417 m
.93087 .49097 L
s
.008 w
.93087 .49097 Mdot
.016 w
.93087 .49097 m
.93059 .48769 L
s
1 .907 0 r
.008 w
.93059 .48769 Mdot
.016 w
.93059 .48769 m
.93027 .48448 L
s
.008 w
.93027 .48448 Mdot
.016 w
.93027 .48448 m
.92991 .48132 L
s
.008 w
.92991 .48132 Mdot
.016 w
.92991 .48132 m
.92951 .47835 L
s
.008 w
.92951 .47835 Mdot
.016 w
.92951 .47835 m
.92904 .47568 L
s
.008 w
.92904 .47568 Mdot
.016 w
.92904 .47568 m
.92851 .47329 L
s
1 .906 0 r
.008 w
.92851 .47329 Mdot
.016 w
.92851 .47329 m
.92795 .47118 L
s
.008 w
.92795 .47118 Mdot
.016 w
.92795 .47118 m
.92737 .46943 L
s
.008 w
.92737 .46943 Mdot
.016 w
.92737 .46943 m
.92679 .46795 L
s
.008 w
.92679 .46795 Mdot
.016 w
.92679 .46795 m
.92621 .4667 L
s
.008 w
.92621 .4667 Mdot
.016 w
.92621 .4667 m
.92566 .46568 L
s
1 .905 0 r
.008 w
.92566 .46568 Mdot
.016 w
.92566 .46568 m
.92515 .46482 L
s
.008 w
.92515 .46482 Mdot
.016 w
.92515 .46482 m
.92468 .46412 L
s
.008 w
.92468 .46412 Mdot
.016 w
.92468 .46412 m
.92426 .46356 L
s
.008 w
.92426 .46356 Mdot
.016 w
.92426 .46356 m
.9239 .46309 L
s
.008 w
.9239 .46309 Mdot
.016 w
.9239 .46309 m
.92363 .46269 L
s
1 .904 0 r
.008 w
.92363 .46269 Mdot
.016 w
.92363 .46269 m
.92347 .46233 L
s
.008 w
.92347 .46233 Mdot
.016 w
.92347 .46233 m
.9234 .46203 L
s
.008 w
.9234 .46203 Mdot
.016 w
.9234 .46203 m
.9234 .4618 L
s
.008 w
.9234 .4618 Mdot
.016 w
.9234 .4618 m
.92343 .46168 L
s
.008 w
.92343 .46168 Mdot
.016 w
.92343 .46168 m
.92345 .46166 L
s
.008 w
.92345 .46166 Mdot
.016 w
.92345 .46166 m
.92341 .46176 L
s
1 .903 0 r
.008 w
.92341 .46176 Mdot
.016 w
.92341 .46176 m
.92327 .46201 L
s
.008 w
.92327 .46201 Mdot
.016 w
.92327 .46201 m
.92299 .46243 L
s
.008 w
.92299 .46243 Mdot
.016 w
.92299 .46243 m
.92256 .46301 L
s
.008 w
.92256 .46301 Mdot
.016 w
.92256 .46301 m
.92197 .4638 L
s
.008 w
.92197 .4638 Mdot
.016 w
.92197 .4638 m
.92122 .46479 L
s
1 .902 0 r
.008 w
.92122 .46479 Mdot
.016 w
.92122 .46479 m
.92033 .46599 L
s
.008 w
.92033 .46599 Mdot
.016 w
.92033 .46599 m
.91942 .46731 L
s
.008 w
.91942 .46731 Mdot
.016 w
.91942 .46731 m
.91836 .46885 L
s
.008 w
.91836 .46885 Mdot
.016 w
.91836 .46885 m
.91709 .4706 L
s
.008 w
.91709 .4706 Mdot
.016 w
.91709 .4706 m
.91583 .47247 L
s
1 .901 0 r
.008 w
.91583 .47247 Mdot
.016 w
.91583 .47247 m
.91442 .47451 L
s
.008 w
.91442 .47451 Mdot
.016 w
.91442 .47451 m
.91289 .47665 L
s
.008 w
.91289 .47665 Mdot
.016 w
.91289 .47665 m
.9114 .47875 L
s
.008 w
.9114 .47875 Mdot
.016 w
.9114 .47875 m
.90985 .4809 L
s
.008 w
.90985 .4809 Mdot
.016 w
.90985 .4809 m
.90843 .483 L
s
1 .9 0 r
.008 w
.90843 .483 Mdot
.016 w
.90843 .483 m
.90699 .48501 L
s
.008 w
.90699 .48501 Mdot
.016 w
.90699 .48501 m
.90567 .48708 L
s
.008 w
.90567 .48708 Mdot
.016 w
.90567 .48708 m
.9045 .48914 L
s
.008 w
.9045 .48914 Mdot
.016 w
.9045 .48914 m
.90339 .49125 L
s
.008 w
.90339 .49125 Mdot
.016 w
.90339 .49125 m
.90229 .49355 L
s
.008 w
.90229 .49355 Mdot
.016 w
.90229 .49355 m
.90133 .49576 L
s
1 .899 0 r
.008 w
.90133 .49576 Mdot
.016 w
.90133 .49576 m
.90046 .4982 L
s
.008 w
.90046 .4982 Mdot
.016 w
.90046 .4982 m
.89971 .50067 L
s
.008 w
.89971 .50067 Mdot
.016 w
.89971 .50067 m
.89908 .50333 L
s
.008 w
.89908 .50333 Mdot
.016 w
.89908 .50333 m
.89856 .50592 L
s
.008 w
.89856 .50592 Mdot
.016 w
.89856 .50592 m
.89815 .50874 L
s
1 .898 0 r
.008 w
.89815 .50874 Mdot
.016 w
.89815 .50874 m
.89783 .5114 L
s
.008 w
.89783 .5114 Mdot
.016 w
.89783 .5114 m
.89756 .51432 L
s
.008 w
.89756 .51432 Mdot
.016 w
.89756 .51432 m
.89733 .51706 L
s
.008 w
.89733 .51706 Mdot
.016 w
.89733 .51706 m
.89709 .51999 L
s
.008 w
.89709 .51999 Mdot
.016 w
.89709 .51999 m
.89682 .52295 L
s
1 .897 0 r
.008 w
.89682 .52295 Mdot
.016 w
.89682 .52295 m
.89653 .52565 L
s
.008 w
.89653 .52565 Mdot
.016 w
.89653 .52565 m
.89621 .52856 L
s
.008 w
.89621 .52856 Mdot
.016 w
.89621 .52856 m
.89591 .53133 L
s
.008 w
.89591 .53133 Mdot
.016 w
.89591 .53133 m
.89564 .53408 L
s
.008 w
.89564 .53408 Mdot
.016 w
.89564 .53408 m
.8954 .53697 L
s
1 .896 0 r
.008 w
.8954 .53697 Mdot
.016 w
.8954 .53697 m
.89521 .53966 L
s
.008 w
.89521 .53966 Mdot
.016 w
.89521 .53966 m
.89504 .54217 L
s
.008 w
.89504 .54217 Mdot
.016 w
.89504 .54217 m
.89489 .54481 L
s
.008 w
.89489 .54481 Mdot
.016 w
.89489 .54481 m
.89477 .54735 L
s
.008 w
.89477 .54735 Mdot
.016 w
.89477 .54735 m
.89466 .54989 L
s
.008 w
.89466 .54989 Mdot
.016 w
.89466 .54989 m
.89457 .55222 L
s
1 .895 0 r
.008 w
.89457 .55222 Mdot
.016 w
.89457 .55222 m
.89449 .55435 L
s
.008 w
.89449 .55435 Mdot
.016 w
.89449 .55435 m
.89444 .55625 L
s
.008 w
.89444 .55625 Mdot
.016 w
.89444 .55625 m
.89439 .55779 L
s
.008 w
.89439 .55779 Mdot
.016 w
.89439 .55779 m
.89437 .55914 L
s
.008 w
.89437 .55914 Mdot
.016 w
.89437 .55914 m
.89436 .56035 L
s
1 .894 0 r
.008 w
.89436 .56035 Mdot
.016 w
.89436 .56035 m
.89436 .56132 L
s
.008 w
.89436 .56132 Mdot
.016 w
.89436 .56132 m
.89438 .56217 L
s
.008 w
.89438 .56217 Mdot
.016 w
.89438 .56217 m
.8944 .56298 L
s
.008 w
.8944 .56298 Mdot
.016 w
.8944 .56298 m
.89443 .56376 L
s
.008 w
.89443 .56376 Mdot
.016 w
.89443 .56376 m
.89443 .56447 L
s
1 .893 0 r
.008 w
.89443 .56447 Mdot
.016 w
.89443 .56447 m
.89442 .56511 L
s
.008 w
.89442 .56511 Mdot
.016 w
.89442 .56511 m
.89439 .56566 L
s
.008 w
.89439 .56566 Mdot
.016 w
.89439 .56566 m
.89437 .56612 L
s
.008 w
.89437 .56612 Mdot
.016 w
.89437 .56612 m
.89435 .56647 L
s
.008 w
.89435 .56647 Mdot
.016 w
.89435 .56647 m
.89434 .56674 L
s
1 .892 0 r
.008 w
.89434 .56674 Mdot
.016 w
.89434 .56674 m
.89433 .56695 L
s
.008 w
.89433 .56695 Mdot
.016 w
.89433 .56695 m
.89431 .56711 L
s
.008 w
.89431 .56711 Mdot
.016 w
.89431 .56711 m
.89427 .56716 L
s
.008 w
.89427 .56716 Mdot
.016 w
.89427 .56716 m
.89422 .56705 L
s
.008 w
.89422 .56705 Mdot
.016 w
.89422 .56705 m
.89418 .56675 L
s
.008 w
.89418 .56675 Mdot
.016 w
.89418 .56675 m
.89416 .5663 L
s
1 .891 0 r
.008 w
.89416 .5663 Mdot
.016 w
.89416 .5663 m
.89416 .56578 L
s
.008 w
.89416 .56578 Mdot
.016 w
.89416 .56578 m
.89421 .56527 L
s
.008 w
.89421 .56527 Mdot
.016 w
.89421 .56527 m
.89431 .56487 L
s
.008 w
.89431 .56487 Mdot
.016 w
.89431 .56487 m
.89447 .56467 L
s
.008 w
.89447 .56467 Mdot
.016 w
.89447 .56467 m
.8947 .5648 L
s
1 .89 0 r
.008 w
.8947 .5648 Mdot
.016 w
.8947 .5648 m
.895 .56526 L
s
.008 w
.895 .56526 Mdot
.016 w
.895 .56526 m
.89534 .56601 L
s
.008 w
.89534 .56601 Mdot
.016 w
.89534 .56601 m
.89571 .56696 L
s
.008 w
.89571 .56696 Mdot
.016 w
.89571 .56696 m
.8961 .56804 L
s
.008 w
.8961 .56804 Mdot
.016 w
.8961 .56804 m
.89649 .56917 L
s
1 .889 0 r
.008 w
.89649 .56917 Mdot
.016 w
.89649 .56917 m
.89687 .5702 L
s
.008 w
.89687 .5702 Mdot
.016 w
.89687 .5702 m
.89723 .5713 L
s
.008 w
.89723 .5713 Mdot
.016 w
.89723 .5713 m
.89759 .57226 L
s
.008 w
.89759 .57226 Mdot
.016 w
.89759 .57226 m
.89794 .57318 L
s
.008 w
.89794 .57318 Mdot
.016 w
.89794 .57318 m
.89826 .57399 L
s
.008 w
.89826 .57399 Mdot
.016 w
.89826 .57399 m
.89852 .57462 L
s
1 .888 0 r
.008 w
.89852 .57462 Mdot
.016 w
.89852 .57462 m
.8987 .57502 L
s
.008 w
.8987 .57502 Mdot
.016 w
.8987 .57502 m
.89877 .57521 L
s
.008 w
.89877 .57521 Mdot
.016 w
.89877 .57521 m
.89874 .57528 L
s
.008 w
.89874 .57528 Mdot
.016 w
.89874 .57528 m
.8986 .57529 L
s
.008 w
.8986 .57529 Mdot
.016 w
.8986 .57529 m
.89837 .57534 L
s
1 .887 0 r
.008 w
.89837 .57534 Mdot
.016 w
.89837 .57534 m
.89802 .57549 L
s
.008 w
.89802 .57549 Mdot
.016 w
.89802 .57549 m
.89754 .57585 L
s
.008 w
.89754 .57585 Mdot
.016 w
.89754 .57585 m
.89694 .57645 L
s
.008 w
.89694 .57645 Mdot
.016 w
.89694 .57645 m
.89619 .57729 L
s
.008 w
.89619 .57729 Mdot
.016 w
.89619 .57729 m
.89532 .57836 L
s
1 .886 0 r
.008 w
.89532 .57836 Mdot
.016 w
.89532 .57836 m
.89431 .57972 L
s
.008 w
.89431 .57972 Mdot
.016 w
.89431 .57972 m
.89313 .58143 L
s
.008 w
.89313 .58143 Mdot
.016 w
.89313 .58143 m
.8918 .58349 L
s
.008 w
.8918 .58349 Mdot
.016 w
.8918 .58349 m
.89034 .58568 L
s
.008 w
.89034 .58568 Mdot
.016 w
.89034 .58568 m
.88876 .58824 L
s
1 .885 0 r
.008 w
.88876 .58824 Mdot
.016 w
.88876 .58824 m
.88727 .59089 L
s
.008 w
.88727 .59089 Mdot
.016 w
.88727 .59089 m
.88575 .59385 L
s
.008 w
.88575 .59385 Mdot
.016 w
.88575 .59385 m
.88427 .59654 L
s
.008 w
.88427 .59654 Mdot
.016 w
.88427 .59654 m
.88293 .59937 L
s
.008 w
.88293 .59937 Mdot
.016 w
.88293 .59937 m
.88169 .60187 L
s
.008 w
.88169 .60187 Mdot
.016 w
.88169 .60187 m
.88059 .60438 L
s
1 .884 0 r
.008 w
.88059 .60438 Mdot
.016 w
.88059 .60438 m
.87963 .60667 L
s
.008 w
.87963 .60667 Mdot
.016 w
.87963 .60667 m
.87884 .60848 L
s
.008 w
.87884 .60848 Mdot
.016 w
.87884 .60848 m
.87821 .61009 L
s
.008 w
.87821 .61009 Mdot
.016 w
.87821 .61009 m
.87774 .61146 L
s
.008 w
.87774 .61146 Mdot
.016 w
.87774 .61146 m
.87743 .61248 L
s
1 .883 0 r
.008 w
.87743 .61248 Mdot
.016 w
.87743 .61248 m
.87725 .61315 L
s
.008 w
.87725 .61315 Mdot
.016 w
.87725 .61315 m
.87718 .61349 L
s
.008 w
.87718 .61349 Mdot
.016 w
.87718 .61349 m
.87718 .61359 L
s
.008 w
.87718 .61359 Mdot
.016 w
.87718 .61359 m
.87722 .61353 L
s
.008 w
.87722 .61353 Mdot
.016 w
.87722 .61353 m
.87731 .6134 L
s
1 .882 0 r
.008 w
.87731 .6134 Mdot
.016 w
.87731 .6134 m
.87745 .61324 L
s
.008 w
.87745 .61324 Mdot
.016 w
.87745 .61324 m
.87761 .6131 L
s
.008 w
.87761 .6131 Mdot
.016 w
.87761 .6131 m
.87778 .61304 L
s
.008 w
.87778 .61304 Mdot
.016 w
.87778 .61304 m
.87795 .61308 L
s
.008 w
.87795 .61308 Mdot
.016 w
.87795 .61308 m
.87814 .61315 L
s
1 .881 0 r
.008 w
.87814 .61315 Mdot
.016 w
.87814 .61315 m
.87834 .6132 L
s
.008 w
.87834 .6132 Mdot
.016 w
.87834 .6132 m
.87855 .61324 L
s
.008 w
.87855 .61324 Mdot
.016 w
.87855 .61324 m
.87876 .61326 L
s
.008 w
.87876 .61326 Mdot
.016 w
.87876 .61326 m
.87895 .61326 L
s
.008 w
.87895 .61326 Mdot
.016 w
.87895 .61326 m
.87914 .61324 L
s
.008 w
.87914 .61324 Mdot
.016 w
.87914 .61324 m
.8793 .6132 L
s
1 .88 0 r
.008 w
.8793 .6132 Mdot
.016 w
.8793 .6132 m
.87943 .61316 L
s
.008 w
.87943 .61316 Mdot
.016 w
.87943 .61316 m
.87954 .61309 L
s
.008 w
.87954 .61309 Mdot
.016 w
.87954 .61309 m
.8796 .61301 L
s
.008 w
.8796 .61301 Mdot
.016 w
.8796 .61301 m
.87963 .61292 L
s
.008 w
.87963 .61292 Mdot
.016 w
.87963 .61292 m
.87963 .61283 L
s
1 .879 0 r
.008 w
.87963 .61283 Mdot
.016 w
.87963 .61283 m
.87963 .61276 L
s
.008 w
.87963 .61276 Mdot
.016 w
.87963 .61276 m
.87966 .61269 L
s
.008 w
.87966 .61269 Mdot
.016 w
.87966 .61269 m
.87971 .61265 L
s
.008 w
.87971 .61265 Mdot
.016 w
.87971 .61265 m
.87977 .61263 L
s
.008 w
.87977 .61263 Mdot
.016 w
.87977 .61263 m
.87984 .61262 L
s
1 .878 0 r
.008 w
.87984 .61262 Mdot
.016 w
.87984 .61262 m
.8799 .61264 L
s
.008 w
.8799 .61264 Mdot
.016 w
.8799 .61264 m
.87992 .6127 L
s
.008 w
.87992 .6127 Mdot
.016 w
.87992 .6127 m
.87979 .61279 L
s
.008 w
.87979 .61279 Mdot
.016 w
.87979 .61279 m
.87947 .61289 L
s
.008 w
.87947 .61289 Mdot
.016 w
.87947 .61289 m
.87897 .61295 L
s
1 .877 0 r
.008 w
.87897 .61295 Mdot
.016 w
.87897 .61295 m
.8783 .61297 L
s
.008 w
.8783 .61297 Mdot
.016 w
.8783 .61297 m
.87741 .6129 L
s
.008 w
.87741 .6129 Mdot
.016 w
.87741 .6129 m
.87633 .61268 L
s
.008 w
.87633 .61268 Mdot
.016 w
.87633 .61268 m
.87527 .61235 L
s
.008 w
.87527 .61235 Mdot
.016 w
.87527 .61235 m
.87406 .61194 L
s
.008 w
.87406 .61194 Mdot
.016 w
.87406 .61194 m
.87273 .6115 L
s
1 .876 0 r
.008 w
.87273 .6115 Mdot
.016 w
.87273 .6115 m
.87136 .61107 L
s
.008 w
.87136 .61107 Mdot
.016 w
.87136 .61107 m
.86979 .61071 L
s
.008 w
.86979 .61071 Mdot
.016 w
.86979 .61071 m
.86826 .61053 L
s
.008 w
.86826 .61053 Mdot
.016 w
.86826 .61053 m
.86673 .61056 L
s
.008 w
.86673 .61056 Mdot
.016 w
.86673 .61056 m
.86507 .61085 L
s
1 .875 0 r
.008 w
.86507 .61085 Mdot
.016 w
.86507 .61085 m
.86316 .61142 L
s
.008 w
.86316 .61142 Mdot
.016 w
.86316 .61142 m
.86102 .61231 L
s
.008 w
.86102 .61231 Mdot
.016 w
.86102 .61231 m
.85881 .61356 L
s
.008 w
.85881 .61356 Mdot
.016 w
.85881 .61356 m
.85681 .61497 L
s
.008 w
.85681 .61497 Mdot
.016 w
.85681 .61497 m
.85445 .61682 L
s
1 .874 0 r
.008 w
.85445 .61682 Mdot
.016 w
.85445 .61682 m
.85166 .61888 L
s
.008 w
.85166 .61888 Mdot
.016 w
.85166 .61888 m
.84885 .62119 L
s
.008 w
.84885 .62119 Mdot
.016 w
.84885 .62119 m
.84579 .6237 L
s
.008 w
.84579 .6237 Mdot
.016 w
.84579 .6237 m
.84238 .62636 L
s
.008 w
.84238 .62636 Mdot
.016 w
.84238 .62636 m
.83928 .62875 L
s
.008 w
.83928 .62875 Mdot
.016 w
.83928 .62875 m
.83593 .63121 L
s
1 .873 0 r
.008 w
.83593 .63121 Mdot
.016 w
.83593 .63121 m
.83255 .63358 L
s
.008 w
.83255 .63358 Mdot
.016 w
.83255 .63358 m
.82945 .63578 L
s
.008 w
.82945 .63578 Mdot
.016 w
.82945 .63578 m
.82642 .6378 L
s
.008 w
.82642 .6378 Mdot
.016 w
.82642 .6378 m
.82366 .63965 L
s
.008 w
.82366 .63965 Mdot
.016 w
.82366 .63965 m
.82104 .64125 L
s
1 .872 0 r
.008 w
.82104 .64125 Mdot
.016 w
.82104 .64125 m
.81887 .64264 L
s
.008 w
.81887 .64264 Mdot
.016 w
.81887 .64264 m
.81692 .64386 L
s
.008 w
.81692 .64386 Mdot
.016 w
.81692 .64386 m
.81533 .64489 L
s
.008 w
.81533 .64489 Mdot
.016 w
.81533 .64489 m
.81383 .64576 L
s
.008 w
.81383 .64576 Mdot
.016 w
.81383 .64576 m
.81264 .64651 L
s
1 .871 0 r
.008 w
.81264 .64651 Mdot
.016 w
.81264 .64651 m
.81158 .64714 L
s
.008 w
.81158 .64714 Mdot
.016 w
.81158 .64714 m
.81065 .64764 L
s
.008 w
.81065 .64764 Mdot
.016 w
.81065 .64764 m
.80977 .64802 L
s
.008 w
.80977 .64802 Mdot
.016 w
.80977 .64802 m
.80887 .6483 L
s
.008 w
.80887 .6483 Mdot
.016 w
.80887 .6483 m
.80786 .64851 L
s
1 .87 0 r
.008 w
.80786 .64851 Mdot
.016 w
.80786 .64851 m
.8067 .6487 L
s
.008 w
.8067 .6487 Mdot
.016 w
.8067 .6487 m
.80535 .64892 L
s
.008 w
.80535 .64892 Mdot
.016 w
.80535 .64892 m
.80394 .6492 L
s
.008 w
.80394 .6492 Mdot
.016 w
.80394 .6492 m
.80225 .64956 L
s
.008 w
.80225 .64956 Mdot
.016 w
.80225 .64956 m
.80045 .65002 L
s
.008 w
.80045 .65002 Mdot
.016 w
.80045 .65002 m
.79836 .65059 L
s
1 .869 0 r
.008 w
.79836 .65059 Mdot
.016 w
.79836 .65059 m
.79622 .65125 L
s
.008 w
.79622 .65125 Mdot
.016 w
.79622 .65125 m
.79394 .65193 L
s
.008 w
.79394 .65193 Mdot
.016 w
.79394 .65193 m
.79186 .65255 L
s
.008 w
.79186 .65255 Mdot
.016 w
.79186 .65255 m
.79006 .6531 L
s
.008 w
.79006 .6531 Mdot
.016 w
.79006 .6531 m
.78826 .65354 L
s
1 .868 0 r
.008 w
.78826 .65354 Mdot
.016 w
.78826 .65354 m
.78696 .65384 L
s
.008 w
.78696 .65384 Mdot
.016 w
.78696 .65384 m
.78583 .65403 L
s
.008 w
.78583 .65403 Mdot
.016 w
.78583 .65403 m
.78503 .65411 L
s
.008 w
.78503 .65411 Mdot
.016 w
.78503 .65411 m
.78454 .65408 L
s
.008 w
.78454 .65408 Mdot
.016 w
.78454 .65408 m
.7843 .65395 L
s
1 .867 0 r
.008 w
.7843 .65395 Mdot
.016 w
.7843 .65395 m
.78424 .65374 L
s
.008 w
.78424 .65374 Mdot
.016 w
.78424 .65374 m
.78429 .65347 L
s
.008 w
.78429 .65347 Mdot
.016 w
.78429 .65347 m
.78437 .6531 L
s
.008 w
.78437 .6531 Mdot
.016 w
.78437 .6531 m
.78437 .65271 L
s
.008 w
.78437 .65271 Mdot
.016 w
.78437 .65271 m
.78423 .65232 L
s
1 .866 0 r
.008 w
.78423 .65232 Mdot
.016 w
.78423 .65232 m
.78391 .65198 L
s
.008 w
.78391 .65198 Mdot
.016 w
.78391 .65198 m
.78338 .65173 L
s
.008 w
.78338 .65173 Mdot
.016 w
.78338 .65173 m
.78266 .6516 L
s
.008 w
.78266 .6516 Mdot
.016 w
.78266 .6516 m
.78179 .65156 L
s
.008 w
.78179 .65156 Mdot
.016 w
.78179 .65156 m
.78089 .65161 L
s
.008 w
.78089 .65161 Mdot
.016 w
.78089 .65161 m
.77997 .65172 L
s
1 .865 0 r
.008 w
.77997 .65172 Mdot
.016 w
.77997 .65172 m
.77907 .65189 L
s
.008 w
.77907 .65189 Mdot
.016 w
.77907 .65189 m
.77828 .65208 L
s
.008 w
.77828 .65208 Mdot
.016 w
.77828 .65208 m
.77759 .65224 L
s
.008 w
.77759 .65224 Mdot
.016 w
.77759 .65224 m
.77703 .65235 L
s
.008 w
.77703 .65235 Mdot
.016 w
.77703 .65235 m
.77654 .65239 L
s
1 .864 0 r
.008 w
.77654 .65239 Mdot
.016 w
.77654 .65239 m
.77608 .65234 L
s
.008 w
.77608 .65234 Mdot
.016 w
.77608 .65234 m
.77564 .65217 L
s
.008 w
.77564 .65217 Mdot
.016 w
.77564 .65217 m
.77518 .65187 L
s
.008 w
.77518 .65187 Mdot
.016 w
.77518 .65187 m
.77465 .65144 L
s
.008 w
.77465 .65144 Mdot
.016 w
.77465 .65144 m
.77404 .65086 L
s
1 .863 0 r
.008 w
.77404 .65086 Mdot
.016 w
.77404 .65086 m
.77337 .65018 L
s
.008 w
.77337 .65018 Mdot
.016 w
.77337 .65018 m
.77255 .64938 L
s
.008 w
.77255 .64938 Mdot
.016 w
.77255 .64938 m
.77159 .64848 L
s
.008 w
.77159 .64848 Mdot
.016 w
.77159 .64848 m
.77056 .64752 L
s
.008 w
.77056 .64752 Mdot
.016 w
.77056 .64752 m
.76945 .64648 L
s
1 .862 0 r
.008 w
.76945 .64648 Mdot
.016 w
.76945 .64648 m
.76819 .64537 L
s
.008 w
.76819 .64537 Mdot
.016 w
.76819 .64537 m
.76679 .64421 L
s
.008 w
.76679 .64421 Mdot
.016 w
.76679 .64421 m
.76543 .64306 L
s
.008 w
.76543 .64306 Mdot
.016 w
.76543 .64306 m
.76412 .64193 L
s
.008 w
.76412 .64193 Mdot
.016 w
.76412 .64193 m
.76294 .64084 L
s
.008 w
.76294 .64084 Mdot
.016 w
.76294 .64084 m
.76196 .63985 L
s
1 .861 0 r
.008 w
.76196 .63985 Mdot
.016 w
.76196 .63985 m
.76115 .63894 L
s
.008 w
.76115 .63894 Mdot
.016 w
.76115 .63894 m
.7605 .63815 L
s
.008 w
.7605 .63815 Mdot
.016 w
.7605 .63815 m
.75997 .63748 L
s
.008 w
.75997 .63748 Mdot
.016 w
.75997 .63748 m
.75956 .6369 L
s
.008 w
.75956 .6369 Mdot
.016 w
.75956 .6369 m
.75922 .63642 L
s
1 .86 0 r
.008 w
.75922 .63642 Mdot
.016 w
.75922 .63642 m
.75894 .63602 L
s
.008 w
.75894 .63602 Mdot
.016 w
.75894 .63602 m
.75872 .6357 L
s
.008 w
.75872 .6357 Mdot
.016 w
.75872 .6357 m
.75859 .63547 L
s
.008 w
.75859 .63547 Mdot
.016 w
.75859 .63547 m
.75856 .63536 L
s
.008 w
.75856 .63536 Mdot
.016 w
.75856 .63536 m
.75863 .63537 L
s
1 .859 0 r
.008 w
.75863 .63537 Mdot
.016 w
.75863 .63537 m
.75877 .63549 L
s
.008 w
.75877 .63549 Mdot
.016 w
.75877 .63549 m
.75895 .63568 L
s
.008 w
.75895 .63568 Mdot
.016 w
.75895 .63568 m
.75911 .63589 L
s
.008 w
.75911 .63589 Mdot
.016 w
.75911 .63589 m
.75924 .63603 L
s
.008 w
.75924 .63603 Mdot
.016 w
.75924 .63603 m
.75931 .63605 L
s
1 .858 0 r
.008 w
.75931 .63605 Mdot
.016 w
.75931 .63605 m
.75932 .63589 L
s
.008 w
.75932 .63589 Mdot
.016 w
.75932 .63589 m
.75925 .63551 L
s
.008 w
.75925 .63551 Mdot
.016 w
.75925 .63551 m
.75913 .6349 L
s
.008 w
.75913 .6349 Mdot
.016 w
.75913 .6349 m
.75896 .63403 L
s
.008 w
.75896 .63403 Mdot
.016 w
.75896 .63403 m
.75875 .63292 L
s
.008 w
.75875 .63292 Mdot
.016 w
.75875 .63292 m
.75851 .63156 L
s
1 .857 0 r
.008 w
.75851 .63156 Mdot
.016 w
.75851 .63156 m
.75825 .63013 L
s
.008 w
.75825 .63013 Mdot
.016 w
.75825 .63013 m
.75796 .62846 L
s
.008 w
.75796 .62846 Mdot
.016 w
.75796 .62846 m
.75771 .62672 L
s
.008 w
.75771 .62672 Mdot
.016 w
.75771 .62672 m
.75752 .62495 L
s
.008 w
.75752 .62495 Mdot
.016 w
.75752 .62495 m
.75738 .62319 L
s
1 .856 0 r
.008 w
.75738 .62319 Mdot
.016 w
.75738 .62319 m
.75725 .62163 L
s
.008 w
.75725 .62163 Mdot
.016 w
.75725 .62163 m
.75712 .62018 L
s
.008 w
.75712 .62018 Mdot
.016 w
.75712 .62018 m
.75696 .61884 L
s
.008 w
.75696 .61884 Mdot
.016 w
.75696 .61884 m
.75671 .61771 L
s
.008 w
.75671 .61771 Mdot
.016 w
.75671 .61771 m
.75634 .61671 L
s
1 .855 0 r
.008 w
.75634 .61671 Mdot
.016 w
.75634 .61671 m
.75581 .61586 L
s
.008 w
.75581 .61586 Mdot
.016 w
.75581 .61586 m
.75508 .61512 L
s
.008 w
.75508 .61512 Mdot
.016 w
.75508 .61512 m
.75413 .61446 L
s
.008 w
.75413 .61446 Mdot
.016 w
.75413 .61446 m
.75296 .6138 L
s
.008 w
.75296 .6138 Mdot
.016 w
.75296 .6138 m
.75161 .61311 L
s
.008 w
.75161 .61311 Mdot
.016 w
.75161 .61311 m
.75034 .61241 L
s
1 .854 0 r
.008 w
.75034 .61241 Mdot
.016 w
.75034 .61241 m
.7489 .61168 L
s
.008 w
.7489 .61168 Mdot
.016 w
.7489 .61168 m
.74749 .61092 L
s
.008 w
.74749 .61092 Mdot
.016 w
.74749 .61092 m
.74605 .61012 L
s
.008 w
.74605 .61012 Mdot
.016 w
.74605 .61012 m
.74462 .60929 L
s
.008 w
.74462 .60929 Mdot
.016 w
.74462 .60929 m
.74351 .60854 L
s
1 .853 0 r
.008 w
.74351 .60854 Mdot
.016 w
.74351 .60854 m
.74254 .60783 L
s
.008 w
.74254 .60783 Mdot
.016 w
.74254 .60783 m
.74181 .60723 L
s
.008 w
.74181 .60723 Mdot
.016 w
.74181 .60723 m
.74131 .60673 L
s
.008 w
.74131 .60673 Mdot
.016 w
.74131 .60673 m
.74104 .60634 L
s
.008 w
.74104 .60634 Mdot
.016 w
.74104 .60634 m
.74096 .60605 L
s
1 .852 0 r
.008 w
.74096 .60605 Mdot
.016 w
.74096 .60605 m
.74102 .60584 L
s
.008 w
.74102 .60584 Mdot
.016 w
.74102 .60584 m
.74118 .60573 L
s
.008 w
.74118 .60573 Mdot
.016 w
.74118 .60573 m
.74138 .60564 L
s
.008 w
.74138 .60564 Mdot
.016 w
.74138 .60564 m
.74162 .60559 L
s
.008 w
.74162 .60559 Mdot
.016 w
.74162 .60559 m
.74191 .60558 L
s
1 .851 0 r
.008 w
.74191 .60558 Mdot
.016 w
.74191 .60558 m
.74221 .60561 L
s
.008 w
.74221 .60561 Mdot
.016 w
.74221 .60561 m
.74249 .6057 L
s
.008 w
.74249 .6057 Mdot
.016 w
.74249 .6057 m
.74272 .60584 L
s
.008 w
.74272 .60584 Mdot
.016 w
.74272 .60584 m
.74288 .60599 L
s
.008 w
.74288 .60599 Mdot
.016 w
.74288 .60599 m
.74292 .60611 L
s
.008 w
.74292 .60611 Mdot
.016 w
.74292 .60611 m
.74279 .60621 L
s
1 .85 0 r
.008 w
.74279 .60621 Mdot
.016 w
.74279 .60621 m
.74244 .60624 L
s
.008 w
.74244 .60624 Mdot
.016 w
.74244 .60624 m
.74187 .6062 L
s
.008 w
.74187 .6062 Mdot
.016 w
.74187 .6062 m
.74103 .60599 L
s
.008 w
.74103 .60599 Mdot
.016 w
.74103 .60599 m
.73994 .6056 L
s
.008 w
.73994 .6056 Mdot
.016 w
.73994 .6056 m
.73862 .605 L
s
1 .849 0 r
.008 w
.73862 .605 Mdot
.016 w
.73862 .605 m
.73729 .60421 L
s
.008 w
.73729 .60421 Mdot
.016 w
.73729 .60421 m
.73579 .60324 L
s
.008 w
.73579 .60324 Mdot
.016 w
.73579 .60324 m
.73421 .60216 L
s
.008 w
.73421 .60216 Mdot
.016 w
.73421 .60216 m
.73261 .60098 L
s
.008 w
.73261 .60098 Mdot
.016 w
.73261 .60098 m
.73121 .59985 L
s
1 .848 0 r
.008 w
.73121 .59985 Mdot
.016 w
.73121 .59985 m
.72987 .59878 L
s
.008 w
.72987 .59878 Mdot
.016 w
.72987 .59878 m
.72863 .5978 L
s
.008 w
.72863 .5978 Mdot
.016 w
.72863 .5978 m
.7276 .59686 L
s
.008 w
.7276 .59686 Mdot
.016 w
.7276 .59686 m
.72677 .59604 L
s
.008 w
.72677 .59604 Mdot
.016 w
.72677 .59604 m
.72613 .59526 L
s
1 .847 0 r
.008 w
.72613 .59526 Mdot
.016 w
.72613 .59526 m
.72568 .59447 L
s
.008 w
.72568 .59447 Mdot
.016 w
.72568 .59447 m
.72539 .59363 L
s
.008 w
.72539 .59363 Mdot
.016 w
.72539 .59363 m
.72521 .59268 L
s
.008 w
.72521 .59268 Mdot
.016 w
.72521 .59268 m
.7251 .59149 L
s
.008 w
.7251 .59149 Mdot
.016 w
.7251 .59149 m
.72503 .58997 L
s
.008 w
.72503 .58997 Mdot
.016 w
.72503 .58997 m
.72498 .58805 L
s
1 .846 0 r
.008 w
.72498 .58805 Mdot
.016 w
.72498 .58805 m
.72492 .58598 L
s
.008 w
.72492 .58598 Mdot
.016 w
.72492 .58598 m
.72483 .58349 L
s
.008 w
.72483 .58349 Mdot
.016 w
.72483 .58349 m
.72474 .5804 L
s
.008 w
.72474 .5804 Mdot
.016 w
.72474 .5804 m
.72467 .5771 L
s
.008 w
.72467 .5771 Mdot
.016 w
.72467 .5771 m
.72461 .57324 L
s
1 .845 0 r
.008 w
.72461 .57324 Mdot
.016 w
.72461 .57324 m
.72456 .56891 L
s
.008 w
.72456 .56891 Mdot
.016 w
.72456 .56891 m
.72455 .56447 L
s
.008 w
.72455 .56447 Mdot
.016 w
.72455 .56447 m
.72457 .55991 L
s
.008 w
.72457 .55991 Mdot
.016 w
.72457 .55991 m
.7246 .55513 L
s
.008 w
.7246 .55513 Mdot
.016 w
.7246 .55513 m
.72464 .55079 L
s
1 .844 0 r
.008 w
.72464 .55079 Mdot
.016 w
.72464 .55079 m
.72467 .54621 L
s
.008 w
.72467 .54621 Mdot
.016 w
.72467 .54621 m
.72465 .54174 L
s
.008 w
.72465 .54174 Mdot
.016 w
.72465 .54174 m
.72459 .53729 L
s
.008 w
.72459 .53729 Mdot
.016 w
.72459 .53729 m
.72448 .53297 L
s
.008 w
.72448 .53297 Mdot
.016 w
.72448 .53297 m
.72433 .52894 L
s
1 .843 0 r
.008 w
.72433 .52894 Mdot
.016 w
.72433 .52894 m
.72416 .52497 L
s
.008 w
.72416 .52497 Mdot
.016 w
.72416 .52497 m
.72399 .52127 L
s
.008 w
.72399 .52127 Mdot
.016 w
.72399 .52127 m
.7238 .51803 L
s
.008 w
.7238 .51803 Mdot
.016 w
.7238 .51803 m
.72361 .51506 L
s
.008 w
.72361 .51506 Mdot
.016 w
.72361 .51506 m
.72341 .51259 L
s
.008 w
.72341 .51259 Mdot
.016 w
.72341 .51259 m
.72322 .51042 L
s
1 .842 0 r
.008 w
.72322 .51042 Mdot
.016 w
.72322 .51042 m
.72306 .50875 L
s
.008 w
.72306 .50875 Mdot
.016 w
.72306 .50875 m
.72297 .50728 L
s
.008 w
.72297 .50728 Mdot
.016 w
.72297 .50728 m
.72298 .50594 L
s
.008 w
.72298 .50594 Mdot
.016 w
.72298 .50594 m
.72316 .50463 L
s
.008 w
.72316 .50463 Mdot
.016 w
.72316 .50463 m
.72353 .5034 L
s
1 .841 0 r
.008 w
.72353 .5034 Mdot
.016 w
.72353 .5034 m
.72412 .50222 L
s
.008 w
.72412 .50222 Mdot
.016 w
.72412 .50222 m
.72496 .50081 L
s
.008 w
.72496 .50081 Mdot
.016 w
.72496 .50081 m
.72607 .49917 L
s
.008 w
.72607 .49917 Mdot
.016 w
.72607 .49917 m
.72752 .49712 L
s
.008 w
.72752 .49712 Mdot
.016 w
.72752 .49712 m
.72917 .49485 L
s
1 .84 0 r
.008 w
.72917 .49485 Mdot
.016 w
.72917 .49485 m
.73103 .49214 L
s
.008 w
.73103 .49214 Mdot
.016 w
.73103 .49214 m
.73299 .48886 L
s
.008 w
.73299 .48886 Mdot
.016 w
.73299 .48886 m
.73518 .48533 L
s
.008 w
.73518 .48533 Mdot
.016 w
.73518 .48533 m
.73726 .48138 L
s
.008 w
.73726 .48138 Mdot
.016 w
.73726 .48138 m
.73941 .47739 L
s
.008 w
.73941 .47739 Mdot
.016 w
.73941 .47739 m
.74126 .47355 L
s
1 .839 0 r
.008 w
.74126 .47355 Mdot
.016 w
.74126 .47355 m
.74299 .46966 L
s
.008 w
.74299 .46966 Mdot
.016 w
.74299 .46966 m
.74447 .46582 L
s
.008 w
.74447 .46582 Mdot
.016 w
.74447 .46582 m
.74577 .46239 L
s
.008 w
.74577 .46239 Mdot
.016 w
.74577 .46239 m
.74671 .45912 L
s
.008 w
.74671 .45912 Mdot
.016 w
.74671 .45912 m
.74743 .45637 L
s
1 .838 0 r
.008 w
.74743 .45637 Mdot
.016 w
.74743 .45637 m
.74795 .45409 L
s
.008 w
.74795 .45409 Mdot
.016 w
.74795 .45409 m
.74827 .45207 L
s
.008 w
.74827 .45207 Mdot
.016 w
.74827 .45207 m
.74842 .45035 L
s
.008 w
.74842 .45035 Mdot
.016 w
.74842 .45035 m
.74848 .44891 L
s
.008 w
.74848 .44891 Mdot
.016 w
.74848 .44891 m
.74846 .44767 L
s
1 .837 0 r
.008 w
.74846 .44767 Mdot
.016 w
.74846 .44767 m
.74845 .4465 L
s
.008 w
.74845 .4465 Mdot
.016 w
.74845 .4465 m
.74848 .44533 L
s
.008 w
.74848 .44533 Mdot
.016 w
.74848 .44533 m
.74862 .44405 L
s
.008 w
.74862 .44405 Mdot
.016 w
.74862 .44405 m
.74888 .44256 L
s
.008 w
.74888 .44256 Mdot
.016 w
.74888 .44256 m
.74931 .44074 L
s
1 .836 0 r
.008 w
.74931 .44074 Mdot
.016 w
.74931 .44074 m
.74993 .43876 L
s
.008 w
.74993 .43876 Mdot
.016 w
.74993 .43876 m
.75072 .43635 L
s
.008 w
.75072 .43635 Mdot
.016 w
.75072 .43635 m
.75169 .43352 L
s
.008 w
.75169 .43352 Mdot
.016 w
.75169 .43352 m
.75286 .43008 L
s
.008 w
.75286 .43008 Mdot
.016 w
.75286 .43008 m
.75416 .42644 L
s
.008 w
.75416 .42644 Mdot
.016 w
.75416 .42644 m
.75565 .42266 L
s
1 .835 0 r
.008 w
.75565 .42266 Mdot
.016 w
.75565 .42266 m
.75729 .41857 L
s
.008 w
.75729 .41857 Mdot
.016 w
.75729 .41857 m
.75903 .41415 L
s
.008 w
.75903 .41415 Mdot
.016 w
.75903 .41415 m
.76089 .40988 L
s
.008 w
.76089 .40988 Mdot
.016 w
.76089 .40988 m
.76284 .40548 L
s
.008 w
.76284 .40548 Mdot
.016 w
.76284 .40548 m
.76487 .40094 L
s
1 .834 0 r
.008 w
.76487 .40094 Mdot
.016 w
.76487 .40094 m
.76693 .39666 L
s
.008 w
.76693 .39666 Mdot
.016 w
.76693 .39666 m
.76896 .39239 L
s
.008 w
.76896 .39239 Mdot
.016 w
.76896 .39239 m
.7712 .38779 L
s
.008 w
.7712 .38779 Mdot
.016 w
.7712 .38779 m
.77329 .38373 L
s
.008 w
.77329 .38373 Mdot
.016 w
.77329 .38373 m
.77557 .37943 L
s
1 .833 0 r
.008 w
.77557 .37943 Mdot
.016 w
.77557 .37943 m
.77792 .37515 L
s
.008 w
.77792 .37515 Mdot
.016 w
.77792 .37515 m
.78049 .37066 L
s
.008 w
.78049 .37066 Mdot
.016 w
.78049 .37066 m
.78303 .3669 L
s
.008 w
.78303 .3669 Mdot
.016 w
.78303 .3669 m
.78579 .36297 L
s
.008 w
.78579 .36297 Mdot
.016 w
.78579 .36297 m
.7888 .35909 L
s
1 .832 0 r
.008 w
.7888 .35909 Mdot
.016 w
.7888 .35909 m
.79185 .35566 L
s
.008 w
.79185 .35566 Mdot
.016 w
.79185 .35566 m
.79523 .35223 L
s
.008 w
.79523 .35223 Mdot
.016 w
.79523 .35223 m
.79857 .34894 L
s
.008 w
.79857 .34894 Mdot
.016 w
.79857 .34894 m
.80235 .34586 L
s
.008 w
.80235 .34586 Mdot
.016 w
.80235 .34586 m
.80582 .34287 L
s
.008 w
.80582 .34287 Mdot
.016 w
.80582 .34287 m
.80974 .34009 L
s
1 .831 0 r
.008 w
.80974 .34009 Mdot
.016 w
.80974 .34009 m
.81364 .33744 L
s
.008 w
.81364 .33744 Mdot
.016 w
.81364 .33744 m
.8173 .33493 L
s
.008 w
.8173 .33493 Mdot
.016 w
.8173 .33493 m
.82109 .33257 L
s
.008 w
.82109 .33257 Mdot
.016 w
.82109 .33257 m
.8248 .33032 L
s
.008 w
.8248 .33032 Mdot
.016 w
.8248 .33032 m
.82856 .3281 L
s
1 .83 0 r
.008 w
.82856 .3281 Mdot
.016 w
.82856 .3281 m
.83194 .32598 L
s
.008 w
.83194 .32598 Mdot
.016 w
.83194 .32598 m
.83523 .32393 L
s
.008 w
.83523 .32393 Mdot
.016 w
.83523 .32393 m
.83873 .32188 L
s
.008 w
.83873 .32188 Mdot
.016 w
.83873 .32188 m
.84173 .32 L
s
.008 w
.84173 .32 Mdot
.016 w
.84173 .32 m
.8447 .31812 L
s
1 .829 0 r
.008 w
.8447 .31812 Mdot
.016 w
.8447 .31812 m
.84778 .31638 L
s
.008 w
.84778 .31638 Mdot
.016 w
.84778 .31638 m
.85069 .31473 L
s
.008 w
.85069 .31473 Mdot
.016 w
.85069 .31473 m
.85375 .31316 L
s
.008 w
.85375 .31316 Mdot
.016 w
.85375 .31316 m
.85664 .31178 L
s
.008 w
.85664 .31178 Mdot
.016 w
.85664 .31178 m
.85987 .31048 L
s
1 .828 0 r
.008 w
.85987 .31048 Mdot
.016 w
.85987 .31048 m
.86317 .30932 L
s
.008 w
.86317 .30932 Mdot
.016 w
.86317 .30932 m
.86677 .30827 L
s
.008 w
.86677 .30827 Mdot
.016 w
.86677 .30827 m
.87015 .30736 L
s
.008 w
.87015 .30736 Mdot
.016 w
.87015 .30736 m
.87376 .30661 L
s
.008 w
.87376 .30661 Mdot
.016 w
.87376 .30661 m
.87777 .30601 L
s
.008 w
.87777 .30601 Mdot
.016 w
.87777 .30601 m
.88101 .30555 L
s
1 .827 0 r
.008 w
.88101 .30555 Mdot
.016 w
.88101 .30555 m
.88461 .30523 L
s
.008 w
.88461 .30523 Mdot
.016 w
.88461 .30523 m
.88784 .30506 L
s
.008 w
.88784 .30506 Mdot
.016 w
.88784 .30506 m
.89102 .30499 L
s
.008 w
.89102 .30499 Mdot
.016 w
.89102 .30499 m
.89377 .305 L
s
.008 w
.89377 .305 Mdot
.016 w
.89377 .305 m
.89617 .30507 L
s
1 .826 0 r
.008 w
.89617 .30507 Mdot
.016 w
.89617 .30507 m
.898 .30516 L
s
.008 w
.898 .30516 Mdot
.016 w
.898 .30516 m
.89958 .30525 L
s
.008 w
.89958 .30525 Mdot
.016 w
.89958 .30525 m
.90085 .30533 L
s
.008 w
.90085 .30533 Mdot
.016 w
.90085 .30533 m
.90175 .30539 L
s
.008 w
.90175 .30539 Mdot
.016 w
.90175 .30539 m
.90229 .30542 L
s
1 .825 0 r
.008 w
.90229 .30542 Mdot
.016 w
.90229 .30542 m
.90255 .30543 L
s
.008 w
.90255 .30543 Mdot
.016 w
.90255 .30543 m
.90261 .30543 L
s
.008 w
.90261 .30543 Mdot
.016 w
.90261 .30543 m
.90253 .30543 L
s
.008 w
.90253 .30543 Mdot
.016 w
.90253 .30543 m
.90236 .30543 L
s
.008 w
.90236 .30543 Mdot
.016 w
.90236 .30543 m
.90213 .30542 L
s
.008 w
.90213 .30542 Mdot
.016 w
.90213 .30542 m
.90192 .30542 L
s
1 .824 0 r
.008 w
.90192 .30542 Mdot
.016 w
.90192 .30542 m
.9018 .30542 L
s
.008 w
.9018 .30542 Mdot
.016 w
.9018 .30542 m
.90178 .30543 L
s
.008 w
.90178 .30543 Mdot
.016 w
.90178 .30543 m
.90178 .30545 L
s
.008 w
.90178 .30545 Mdot
.016 w
.90178 .30545 m
.90181 .30551 L
s
.008 w
.90181 .30551 Mdot
.016 w
.90181 .30551 m
.90183 .30559 L
s
1 .823 0 r
.008 w
.90183 .30559 Mdot
.016 w
.90183 .30559 m
.90186 .3057 L
s
.008 w
.90186 .3057 Mdot
.016 w
.90186 .3057 m
.90186 .30581 L
s
.008 w
.90186 .30581 Mdot
.016 w
.90186 .30581 m
.90183 .3059 L
s
.008 w
.90183 .3059 Mdot
.016 w
.90183 .3059 m
.90179 .30594 L
s
.008 w
.90179 .30594 Mdot
.016 w
.90179 .30594 m
.90175 .30591 L
s
1 .822 0 r
.008 w
.90175 .30591 Mdot
.016 w
.90175 .30591 m
.90173 .30578 L
s
.008 w
.90173 .30578 Mdot
.016 w
.90173 .30578 m
.90172 .30551 L
s
.008 w
.90172 .30551 Mdot
.016 w
.90172 .30551 m
.90171 .30505 L
s
.008 w
.90171 .30505 Mdot
.016 w
.90171 .30505 m
.90167 .30434 L
s
.008 w
.90167 .30434 Mdot
.016 w
.90167 .30434 m
.90156 .30334 L
s
1 .821 0 r
.008 w
.90156 .30334 Mdot
.016 w
.90156 .30334 m
.90137 .30206 L
s
.008 w
.90137 .30206 Mdot
.016 w
.90137 .30206 m
.90107 .30043 L
s
.008 w
.90107 .30043 Mdot
.016 w
.90107 .30043 m
.90067 .29848 L
s
.008 w
.90067 .29848 Mdot
.016 w
.90067 .29848 m
.90014 .29622 L
s
.008 w
.90014 .29622 Mdot
.016 w
.90014 .29622 m
.89946 .29371 L
s
.008 w
.89946 .29371 Mdot
.016 w
.89946 .29371 m
.89866 .29082 L
s
1 .82 0 r
.008 w
.89866 .29082 Mdot
.016 w
.89866 .29082 m
.89778 .28828 L
s
.008 w
.89778 .28828 Mdot
.016 w
.89778 .28828 m
.89677 .28519 L
s
.008 w
.89677 .28519 Mdot
.016 w
.89677 .28519 m
.89569 .28265 L
s
.008 w
.89569 .28265 Mdot
.016 w
.89569 .28265 m
.89454 .28003 L
s
.008 w
.89454 .28003 Mdot
.016 w
.89454 .28003 m
.89336 .27751 L
s
1 .819 0 r
.008 w
.89336 .27751 Mdot
.016 w
.89336 .27751 m
.89222 .27541 L
s
.008 w
.89222 .27541 Mdot
.016 w
.89222 .27541 m
.89104 .2735 L
s
.008 w
.89104 .2735 Mdot
.016 w
.89104 .2735 m
.88987 .27193 L
s
.008 w
.88987 .27193 Mdot
.016 w
.88987 .27193 m
.88869 .2706 L
s
.008 w
.88869 .2706 Mdot
.016 w
.88869 .2706 m
.8876 .26954 L
s
1 .818 0 r
.008 w
.8876 .26954 Mdot
.016 w
.8876 .26954 m
.88655 .26866 L
s
.008 w
.88655 .26866 Mdot
.016 w
.88655 .26866 m
.88554 .26795 L
s
.008 w
.88554 .26795 Mdot
.016 w
.88554 .26795 m
.88454 .26737 L
s
.008 w
.88454 .26737 Mdot
.016 w
.88454 .26737 m
.88358 .26687 L
s
.008 w
.88358 .26687 Mdot
.016 w
.88358 .26687 m
.88267 .26641 L
s
1 .817 0 r
.008 w
.88267 .26641 Mdot
.016 w
.88267 .26641 m
.88192 .26599 L
s
.008 w
.88192 .26599 Mdot
.016 w
.88192 .26599 m
.88116 .26564 L
s
.008 w
.88116 .26564 Mdot
.016 w
.88116 .26564 m
.88052 .26529 L
s
.008 w
.88052 .26529 Mdot
.016 w
.88052 .26529 m
.87996 .26497 L
s
.008 w
.87996 .26497 Mdot
.016 w
.87996 .26497 m
.87949 .26467 L
s
.008 w
.87949 .26467 Mdot
.016 w
.87949 .26467 m
.8791 .26439 L
s
1 .816 0 r
.008 w
.8791 .26439 Mdot
.016 w
.8791 .26439 m
.87882 .26415 L
s
.008 w
.87882 .26415 Mdot
.016 w
.87882 .26415 m
.87864 .26398 L
s
.008 w
.87864 .26398 Mdot
.016 w
.87864 .26398 m
.87854 .26388 L
s
.008 w
.87854 .26388 Mdot
.016 w
.87854 .26388 m
.8785 .26387 L
s
.008 w
.8785 .26387 Mdot
.016 w
.8785 .26387 m
.87849 .26393 L
s
1 .815 0 r
.008 w
.87849 .26393 Mdot
.016 w
.87849 .26393 m
.87846 .26406 L
s
.008 w
.87846 .26406 Mdot
.016 w
.87846 .26406 m
.87837 .26424 L
s
.008 w
.87837 .26424 Mdot
.016 w
.87837 .26424 m
.87822 .26446 L
s
.008 w
.87822 .26446 Mdot
.016 w
.87822 .26446 m
.87804 .26471 L
s
.008 w
.87804 .26471 Mdot
.016 w
.87804 .26471 m
.87785 .26499 L
s
1 .814 0 r
.008 w
.87785 .26499 Mdot
.016 w
.87785 .26499 m
.87767 .26527 L
s
.008 w
.87767 .26527 Mdot
.016 w
.87767 .26527 m
.87752 .26558 L
s
.008 w
.87752 .26558 Mdot
.016 w
.87752 .26558 m
.87742 .2659 L
s
.008 w
.87742 .2659 Mdot
.016 w
.87742 .2659 m
.87735 .26619 L
s
.008 w
.87735 .26619 Mdot
.016 w
.87735 .26619 m
.87733 .26642 L
s
1 .813 0 r
.008 w
.87733 .26642 Mdot
.016 w
.87733 .26642 m
.87736 .26658 L
s
.008 w
.87736 .26658 Mdot
.016 w
.87736 .26658 m
.87744 .26663 L
s
.008 w
.87744 .26663 Mdot
.016 w
.87744 .26663 m
.87754 .2666 L
s
.008 w
.87754 .2666 Mdot
.016 w
.87754 .2666 m
.87768 .26652 L
s
.008 w
.87768 .26652 Mdot
.016 w
.87768 .26652 m
.87784 .26642 L
s
.008 w
.87784 .26642 Mdot
.016 w
.87784 .26642 m
.87797 .26634 L
s
1 .812 0 r
.008 w
.87797 .26634 Mdot
.016 w
.87797 .26634 m
.87805 .26626 L
s
.008 w
.87805 .26626 Mdot
.016 w
.87805 .26626 m
.87806 .26619 L
s
.008 w
.87806 .26619 Mdot
.016 w
.87806 .26619 m
.87797 .26615 L
s
.008 w
.87797 .26615 Mdot
.016 w
.87797 .26615 m
.87776 .26613 L
s
.008 w
.87776 .26613 Mdot
.016 w
.87776 .26613 m
.8774 .26617 L
s
1 .811 0 r
.008 w
.8774 .26617 Mdot
.016 w
.8774 .26617 m
.87688 .26634 L
s
.008 w
.87688 .26634 Mdot
.016 w
.87688 .26634 m
.87624 .26659 L
s
.008 w
.87624 .26659 Mdot
.016 w
.87624 .26659 m
.87548 .26697 L
s
.008 w
.87548 .26697 Mdot
.016 w
.87548 .26697 m
.87461 .26742 L
s
.008 w
.87461 .26742 Mdot
.016 w
.87461 .26742 m
.87368 .2679 L
s
1 .81 0 r
.008 w
.87368 .2679 Mdot
.016 w
.87368 .2679 m
.87278 .26835 L
s
.008 w
.87278 .26835 Mdot
.016 w
.87278 .26835 m
.87193 .26874 L
s
.008 w
.87193 .26874 Mdot
.016 w
.87193 .26874 m
.87115 .26905 L
s
.008 w
.87115 .26905 Mdot
.016 w
.87115 .26905 m
.8705 .26924 L
s
.008 w
.8705 .26924 Mdot
.016 w
.8705 .26924 m
.87001 .26932 L
s
1 .809 0 r
.008 w
.87001 .26932 Mdot
.016 w
.87001 .26932 m
.86966 .26929 L
s
.008 w
.86966 .26929 Mdot
.016 w
.86966 .26929 m
.86947 .26919 L
s
.008 w
.86947 .26919 Mdot
.016 w
.86947 .26919 m
.86945 .26909 L
s
.008 w
.86945 .26909 Mdot
.016 w
.86945 .26909 m
.86957 .269 L
s
.008 w
.86957 .269 Mdot
.016 w
.86957 .269 m
.86983 .26893 L
s
.008 w
.86983 .26893 Mdot
.016 w
.86983 .26893 m
.87016 .26889 L
s
1 .808 0 r
.008 w
.87016 .26889 Mdot
.016 w
.87016 .26889 m
.87053 .26888 L
s
.008 w
.87053 .26888 Mdot
.016 w
.87053 .26888 m
.87091 .2689 L
s
.008 w
.87091 .2689 Mdot
.016 w
.87091 .2689 m
.87128 .26895 L
s
.008 w
.87128 .26895 Mdot
.016 w
.87128 .26895 m
.87158 .26904 L
s
.008 w
.87158 .26904 Mdot
.016 w
.87158 .26904 m
.87181 .2692 L
s
1 .807 0 r
.008 w
.87181 .2692 Mdot
.016 w
.87181 .2692 m
.87197 .26941 L
s
.008 w
.87197 .26941 Mdot
.016 w
.87197 .26941 m
.87207 .26965 L
s
.008 w
.87207 .26965 Mdot
.016 w
.87207 .26965 m
.87215 .26988 L
s
.008 w
.87215 .26988 Mdot
.016 w
.87215 .26988 m
.87223 .27007 L
s
.008 w
.87223 .27007 Mdot
.016 w
.87223 .27007 m
.87229 .27019 L
s
1 .806 0 r
.008 w
.87229 .27019 Mdot
.016 w
.87229 .27019 m
.87233 .27022 L
s
.008 w
.87233 .27022 Mdot
.016 w
.87233 .27022 m
.87235 .27016 L
s
.008 w
.87235 .27016 Mdot
.016 w
.87235 .27016 m
.87234 .27006 L
s
.008 w
.87234 .27006 Mdot
.016 w
.87234 .27006 m
.87231 .26988 L
s
.008 w
.87231 .26988 Mdot
.016 w
.87231 .26988 m
.8723 .26968 L
s
.008 w
.8723 .26968 Mdot
.016 w
.8723 .26968 m
.8723 .26944 L
s
1 .805 0 r
.008 w
.8723 .26944 Mdot
.016 w
.8723 .26944 m
.87235 .2692 L
s
.008 w
.87235 .2692 Mdot
.016 w
.87235 .2692 m
.87246 .26899 L
s
.008 w
.87246 .26899 Mdot
.016 w
.87246 .26899 m
.87263 .26879 L
s
.008 w
.87263 .26879 Mdot
.016 w
.87263 .26879 m
.87285 .2686 L
s
.008 w
.87285 .2686 Mdot
.016 w
.87285 .2686 m
.8731 .26844 L
s
1 .804 0 r
.008 w
.8731 .26844 Mdot
.016 w
.8731 .26844 m
.87336 .2683 L
s
.008 w
.87336 .2683 Mdot
.016 w
.87336 .2683 m
.8736 .26819 L
s
.008 w
.8736 .26819 Mdot
.016 w
.8736 .26819 m
.87381 .26812 L
s
.008 w
.87381 .26812 Mdot
.016 w
.87381 .26812 m
.874 .26809 L
s
.008 w
.874 .26809 Mdot
.016 w
.874 .26809 m
.87415 .2681 L
s
1 .803 0 r
.008 w
.87415 .2681 Mdot
.016 w
.87415 .2681 m
.87428 .26814 L
s
.008 w
.87428 .26814 Mdot
.016 w
.87428 .26814 m
.87439 .26821 L
s
.008 w
.87439 .26821 Mdot
.016 w
.87439 .26821 m
.87448 .26833 L
s
.008 w
.87448 .26833 Mdot
.016 w
.87448 .26833 m
.87452 .26847 L
s
.008 w
.87452 .26847 Mdot
.016 w
.87452 .26847 m
.87452 .26859 L
s
1 .802 0 r
.008 w
.87452 .26859 Mdot
.016 w
.87452 .26859 m
.87448 .26869 L
s
.008 w
.87448 .26869 Mdot
.016 w
.87448 .26869 m
.8744 .26876 L
s
.008 w
.8744 .26876 Mdot
.016 w
.8744 .26876 m
.8743 .26878 L
s
.008 w
.8743 .26878 Mdot
.016 w
.8743 .26878 m
.87421 .26871 L
s
.008 w
.87421 .26871 Mdot
.016 w
.87421 .26871 m
.87417 .26849 L
s
.008 w
.87417 .26849 Mdot
.016 w
.87417 .26849 m
.87416 .26808 L
s
1 .801 0 r
.008 w
.87416 .26808 Mdot
.016 w
.87416 .26808 m
.87419 .26739 L
s
.008 w
.87419 .26739 Mdot
.016 w
.87419 .26739 m
.87421 .26633 L
s
.008 w
.87421 .26633 Mdot
.016 w
.87421 .26633 m
.87417 .26491 L
s
.008 w
.87417 .26491 Mdot
.016 w
.87417 .26491 m
.87402 .26305 L
s
.008 w
.87402 .26305 Mdot
.016 w
.87402 .26305 m
.87375 .26077 L
s
1 .8 0 r
.008 w
.87375 .26077 Mdot
.016 w
.87375 .26077 m
.87328 .25804 L
s
.008 w
.87328 .25804 Mdot
.016 w
.87328 .25804 m
.87259 .25493 L
s
.008 w
.87259 .25493 Mdot
.016 w
.87259 .25493 m
.87169 .25161 L
s
.008 w
.87169 .25161 Mdot
.016 w
.87169 .25161 m
.87056 .24775 L
s
.008 w
.87056 .24775 Mdot
.016 w
.87056 .24775 m
.86918 .24412 L
s
1 .799 0 r
.008 w
.86918 .24412 Mdot
.016 w
.86918 .24412 m
.86764 .24 L
s
.008 w
.86764 .24 Mdot
.016 w
.86764 .24 m
.86592 .23569 L
s
.008 w
.86592 .23569 Mdot
.016 w
.86592 .23569 m
.86407 .23146 L
s
.008 w
.86407 .23146 Mdot
.016 w
.86407 .23146 m
.86208 .22731 L
s
.008 w
.86208 .22731 Mdot
.016 w
.86208 .22731 m
.86005 .2234 L
s
1 .798 0 r
.008 w
.86005 .2234 Mdot
.016 w
.86005 .2234 m
.85801 .21971 L
s
.008 w
.85801 .21971 Mdot
.016 w
.85801 .21971 m
.85602 .21631 L
s
.008 w
.85602 .21631 Mdot
.016 w
.85602 .21631 m
.85419 .21349 L
s
.008 w
.85419 .21349 Mdot
.016 w
.85419 .21349 m
.85262 .21095 L
s
.008 w
.85262 .21095 Mdot
.016 w
.85262 .21095 m
.85112 .20878 L
s
.008 w
.85112 .20878 Mdot
.016 w
.85112 .20878 m
.84997 .20717 L
s
1 .797 0 r
.008 w
.84997 .20717 Mdot
.016 w
.84997 .20717 m
.84904 .20588 L
s
.008 w
.84904 .20588 Mdot
.016 w
.84904 .20588 m
.84834 .20491 L
s
.008 w
.84834 .20491 Mdot
.016 w
.84834 .20491 m
.84788 .20425 L
s
.008 w
.84788 .20425 Mdot
.016 w
.84788 .20425 m
.84762 .2039 L
s
.008 w
.84762 .2039 Mdot
.016 w
.84762 .2039 m
.8475 .20379 L
s
1 .796 0 r
.008 w
.8475 .20379 Mdot
.016 w
.8475 .20379 m
.84745 .20378 L
s
.008 w
.84745 .20378 Mdot
.016 w
.84745 .20378 m
.84738 .20373 L
s
.008 w
.84738 .20373 Mdot
.016 w
.84738 .20373 m
.84723 .20352 L
s
.008 w
.84723 .20352 Mdot
.016 w
.84723 .20352 m
.84687 .20302 L
s
.008 w
.84687 .20302 Mdot
.016 w
.84687 .20302 m
.84623 .20213 L
s
1 .795 0 r
.008 w
.84623 .20213 Mdot
.016 w
.84623 .20213 m
.84528 .20079 L
s
.008 w
.84528 .20079 Mdot
.016 w
.84528 .20079 m
.84396 .19889 L
s
.008 w
.84396 .19889 Mdot
.016 w
.84396 .19889 m
.84235 .19663 L
s
.008 w
.84235 .19663 Mdot
.016 w
.84235 .19663 m
.84035 .19383 L
s
.008 w
.84035 .19383 Mdot
.016 w
.84035 .19383 m
.83791 .1904 L
s
1 .794 0 r
.008 w
.83791 .1904 Mdot
.016 w
.83791 .1904 m
.83561 .18695 L
s
.008 w
.83561 .18695 Mdot
.016 w
.83561 .18695 m
.83271 .18252 L
s
.008 w
.83271 .18252 Mdot
.016 w
.83271 .18252 m
.82985 .17866 L
s
.008 w
.82985 .17866 Mdot
.016 w
.82985 .17866 m
.82675 .17416 L
s
.008 w
.82675 .17416 Mdot
.016 w
.82675 .17416 m
.82344 .16945 L
s
.008 w
.82344 .16945 Mdot
.016 w
.82344 .16945 m
.82019 .16464 L
s
1 .793 0 r
.008 w
.82019 .16464 Mdot
.016 w
.82019 .16464 m
.81729 .1603 L
s
.008 w
.81729 .1603 Mdot
.016 w
.81729 .1603 m
.81419 .15573 L
s
.008 w
.81419 .15573 Mdot
.016 w
.81419 .15573 m
.81096 .15094 L
s
.008 w
.81096 .15094 Mdot
.016 w
.81096 .15094 m
.80812 .14664 L
s
.008 w
.80812 .14664 Mdot
.016 w
.80812 .14664 m
.80537 .14282 L
s
1 .792 0 r
.008 w
.80537 .14282 Mdot
.016 w
.80537 .14282 m
.8025 .1388 L
s
.008 w
.8025 .1388 Mdot
.016 w
.8025 .1388 m
.79963 .13505 L
s
.008 w
.79963 .13505 Mdot
.016 w
.79963 .13505 m
.79648 .13127 L
s
.008 w
.79648 .13127 Mdot
.016 w
.79648 .13127 m
.79354 .12824 L
s
.008 w
.79354 .12824 Mdot
.016 w
.79354 .12824 m
.79032 .12523 L
s
1 .791 0 r
.008 w
.79032 .12523 Mdot
.016 w
.79032 .12523 m
.78707 .12214 L
s
.008 w
.78707 .12214 Mdot
.016 w
.78707 .12214 m
.78418 .11977 L
s
.008 w
.78418 .11977 Mdot
.016 w
.78418 .11977 m
.78072 .11753 L
s
.008 w
.78072 .11753 Mdot
.016 w
.78072 .11753 m
.7777 .11541 L
s
.008 w
.7777 .11541 Mdot
.016 w
.7777 .11541 m
.77457 .11354 L
s
.008 w
.77457 .11354 Mdot
.016 w
.77457 .11354 m
.77182 .11191 L
s
1 .79 0 r
.008 w
.77182 .11191 Mdot
.016 w
.77182 .11191 m
.76905 .1106 L
s
.008 w
.76905 .1106 Mdot
.016 w
.76905 .1106 m
.76672 .1097 L
s
.008 w
.76672 .1097 Mdot
.016 w
.76672 .1097 m
.76497 .10899 L
s
.008 w
.76497 .10899 Mdot
.016 w
.76497 .10899 m
.76357 .10852 L
s
.008 w
.76357 .10852 Mdot
.016 w
.76357 .10852 m
.76259 .10825 L
s
1 .789 0 r
.008 w
.76259 .10825 Mdot
.016 w
.76259 .10825 m
.76199 .10809 L
s
.008 w
.76199 .10809 Mdot
.016 w
.76199 .10809 m
.76172 .10803 L
s
.008 w
.76172 .10803 Mdot
.016 w
.76172 .10803 m
.76172 .10806 L
s
.008 w
.76172 .10806 Mdot
.016 w
.76172 .10806 m
.76194 .10813 L
s
.008 w
.76194 .10813 Mdot
.016 w
.76194 .10813 m
.76231 .1083 L
s
1 .788 0 r
.008 w
.76231 .1083 Mdot
.016 w
.76231 .1083 m
.76277 .10852 L
s
.008 w
.76277 .10852 Mdot
.016 w
.76277 .10852 m
.76327 .10877 L
s
.008 w
.76327 .10877 Mdot
.016 w
.76327 .10877 m
.76378 .10901 L
s
.008 w
.76378 .10901 Mdot
.016 w
.76378 .10901 m
.76423 .10921 L
s
.008 w
.76423 .10921 Mdot
.016 w
.76423 .10921 m
.76457 .10934 L
s
1 .787 0 r
.008 w
.76457 .10934 Mdot
.016 w
.76457 .10934 m
.76482 .10941 L
s
.008 w
.76482 .10941 Mdot
.016 w
.76482 .10941 m
.76501 .10943 L
s
.008 w
.76501 .10943 Mdot
.016 w
.76501 .10943 m
.76517 .10942 L
s
.008 w
.76517 .10942 Mdot
.016 w
.76517 .10942 m
.76531 .10941 L
s
.008 w
.76531 .10941 Mdot
.016 w
.76531 .10941 m
.76546 .1094 L
s
.008 w
.76546 .1094 Mdot
.016 w
.76546 .1094 m
.76561 .10938 L
s
1 .786 0 r
.008 w
.76561 .10938 Mdot
.016 w
.76561 .10938 m
.76578 .10937 L
s
.008 w
.76578 .10937 Mdot
.016 w
.76578 .10937 m
.76596 .10937 L
s
.008 w
.76596 .10937 Mdot
.016 w
.76596 .10937 m
.76614 .10938 L
s
.008 w
.76614 .10938 Mdot
.016 w
.76614 .10938 m
.7663 .10939 L
s
.008 w
.7663 .10939 Mdot
.016 w
.7663 .10939 m
.76645 .10939 L
s
1 .785 0 r
.008 w
.76645 .10939 Mdot
.016 w
.76645 .10939 m
.7666 .1094 L
s
.008 w
.7666 .1094 Mdot
.016 w
.7666 .1094 m
.76674 .1094 L
s
.008 w
.76674 .1094 Mdot
.016 w
.76674 .1094 m
.76684 .10939 L
s
.008 w
.76684 .10939 Mdot
.016 w
.76684 .10939 m
.76687 .10937 L
s
.008 w
.76687 .10937 Mdot
.016 w
.76687 .10937 m
.76681 .10935 L
s
1 .784 0 r
.008 w
.76681 .10935 Mdot
.016 w
.76681 .10935 m
.76665 .10934 L
s
.008 w
.76665 .10934 Mdot
.016 w
.76665 .10934 m
.7664 .10933 L
s
.008 w
.7664 .10933 Mdot
.016 w
.7664 .10933 m
.76605 .10931 L
s
.008 w
.76605 .10931 Mdot
.016 w
.76605 .10931 m
.76561 .10929 L
s
.008 w
.76561 .10929 Mdot
.016 w
.76561 .10929 m
.7651 .10928 L
s
1 .783 0 r
.008 w
.7651 .10928 Mdot
.016 w
.7651 .10928 m
.76454 .10931 L
s
.008 w
.76454 .10931 Mdot
.016 w
.76454 .10931 m
.76395 .10943 L
s
.008 w
.76395 .10943 Mdot
.016 w
.76395 .10943 m
.76336 .10962 L
s
.008 w
.76336 .10962 Mdot
.016 w
.76336 .10962 m
.76278 .10987 L
s
.008 w
.76278 .10987 Mdot
.016 w
.76278 .10987 m
.76221 .11018 L
s
.008 w
.76221 .11018 Mdot
.016 w
.76221 .11018 m
.76168 .11052 L
s
1 .782 0 r
.008 w
.76168 .11052 Mdot
.016 w
.76168 .11052 m
.76126 .11083 L
s
.008 w
.76126 .11083 Mdot
.016 w
.76126 .11083 m
.76101 .11112 L
s
.008 w
.76101 .11112 Mdot
.016 w
.76101 .11112 m
.76095 .11134 L
s
.008 w
.76095 .11134 Mdot
.016 w
.76095 .11134 m
.76106 .11148 L
s
.008 w
.76106 .11148 Mdot
.016 w
.76106 .11148 m
.76127 .11153 L
s
1 .781 0 r
.008 w
.76127 .11153 Mdot
.016 w
.76127 .11153 m
.76151 .11146 L
s
.008 w
.76151 .11146 Mdot
.016 w
.76151 .11146 m
.76168 .11122 L
s
.008 w
.76168 .11122 Mdot
.016 w
.76168 .11122 m
.76164 .11081 L
s
.008 w
.76164 .11081 Mdot
.016 w
.76164 .11081 m
.76129 .11018 L
s
.008 w
.76129 .11018 Mdot
.016 w
.76129 .11018 m
.76054 .10931 L
s
1 .78 0 r
.008 w
.76054 .10931 Mdot
.016 w
.76054 .10931 m
.75933 .10818 L
s
.008 w
.75933 .10818 Mdot
.016 w
.75933 .10818 m
.75755 .1068 L
s
.008 w
.75755 .1068 Mdot
.016 w
.75755 .1068 m
.75518 .10522 L
s
.008 w
.75518 .10522 Mdot
.016 w
.75518 .10522 m
.75263 .10341 L
s
.008 w
.75263 .10341 Mdot
.016 w
.75263 .10341 m
.74949 .10148 L
s
1 .779 0 r
.008 w
.74949 .10148 Mdot
.016 w
.74949 .10148 m
.74568 .09947 L
s
.008 w
.74568 .09947 Mdot
.016 w
.74568 .09947 m
.74184 .09738 L
s
.008 w
.74184 .09738 Mdot
.016 w
.74184 .09738 m
.73738 .0952 L
s
.008 w
.73738 .0952 Mdot
.016 w
.73738 .0952 m
.73205 .09293 L
s
.008 w
.73205 .09293 Mdot
.016 w
.73205 .09293 m
.72749 .0906 L
s
.008 w
.72749 .0906 Mdot
.016 w
.72749 .0906 m
.72228 .08819 L
s
1 .778 0 r
.008 w
.72228 .08819 Mdot
.016 w
.72228 .08819 m
.71657 .08566 L
s
.008 w
.71657 .08566 Mdot
.016 w
.71657 .08566 m
.71139 .08328 L
s
.008 w
.71139 .08328 Mdot
.016 w
.71139 .08328 m
.70529 .08081 L
s
.008 w
.70529 .08081 Mdot
.016 w
.70529 .08081 m
.70037 .07841 L
s
.008 w
.70037 .07841 Mdot
.016 w
.70037 .07841 m
.69479 .07608 L
s
1 .777 0 r
.008 w
.69479 .07608 Mdot
.016 w
.69479 .07608 m
.68867 .07367 L
s
.008 w
.68867 .07367 Mdot
.016 w
.68867 .07367 m
.6837 .07139 L
s
.008 w
.6837 .07139 Mdot
.016 w
.6837 .07139 m
.67801 .06905 L
s
.008 w
.67801 .06905 Mdot
.016 w
.67801 .06905 m
.67223 .06666 L
s
.008 w
.67223 .06666 Mdot
.016 w
.67223 .06666 m
.66683 .06436 L
s
1 .776 0 r
.008 w
.66683 .06436 Mdot
.016 w
.66683 .06436 m
.66127 .06198 L
s
.008 w
.66127 .06198 Mdot
.016 w
.66127 .06198 m
.65532 .0597 L
s
.008 w
.65532 .0597 Mdot
.016 w
.65532 .0597 m
.65031 .05749 L
s
.008 w
.65031 .05749 Mdot
.016 w
.65031 .05749 m
.64468 .05525 L
s
.008 w
.64468 .05525 Mdot
.016 w
.64468 .05525 m
.63987 .05319 L
s
1 .775 0 r
.008 w
.63987 .05319 Mdot
.016 w
.63987 .05319 m
.63482 .05109 L
s
.008 w
.63482 .05109 Mdot
.016 w
.63482 .05109 m
.63005 .04916 L
s
.008 w
.63005 .04916 Mdot
.016 w
.63005 .04916 m
.62539 .04724 L
s
.008 w
.62539 .04724 Mdot
.016 w
.62539 .04724 m
.62078 .04543 L
s
.008 w
.62078 .04543 Mdot
.016 w
.62078 .04543 m
.61617 .04371 L
s
.008 w
.61617 .04371 Mdot
.016 w
.61617 .04371 m
.61187 .04221 L
s
1 .774 0 r
.008 w
.61187 .04221 Mdot
.016 w
.61187 .04221 m
.60762 .04084 L
s
.008 w
.60762 .04084 Mdot
.016 w
.60762 .04084 m
.60341 .03965 L
s
.008 w
.60341 .03965 Mdot
.016 w
.60341 .03965 m
.5997 .03867 L
s
.008 w
.5997 .03867 Mdot
.016 w
.5997 .03867 m
.59602 .03787 L
s
.008 w
.59602 .03787 Mdot
.016 w
.59602 .03787 m
.59271 .03722 L
s
1 .773 0 r
.008 w
.59271 .03722 Mdot
.016 w
.59271 .03722 m
.5894 .03671 L
s
.008 w
.5894 .03671 Mdot
.016 w
.5894 .03671 m
.5866 .03634 L
s
.008 w
.5866 .03634 Mdot
.016 w
.5866 .03634 m
.58374 .03606 L
s
.008 w
.58374 .03606 Mdot
.016 w
.58374 .03606 m
.58067 .03588 L
s
.008 w
.58067 .03588 Mdot
.016 w
.58067 .03588 m
.57793 .03578 L
s
1 .772 0 r
.008 w
.57793 .03578 Mdot
.016 w
.57793 .03578 m
.575 .03571 L
s
.008 w
.575 .03571 Mdot
.016 w
.575 .03571 m
.57182 .03567 L
s
.008 w
.57182 .03567 Mdot
.016 w
.57182 .03567 m
.56841 .03563 L
s
.008 w
.56841 .03563 Mdot
.016 w
.56841 .03563 m
.56542 .0356 L
s
.008 w
.56542 .0356 Mdot
.016 w
.56542 .0356 m
.56175 .03553 L
s
.008 w
.56175 .03553 Mdot
.016 w
.56175 .03553 m
.55809 .03543 L
s
1 .771 0 r
.008 w
.55809 .03543 Mdot
.016 w
.55809 .03543 m
.55405 .0353 L
s
.008 w
.55405 .0353 Mdot
.016 w
.55405 .0353 m
.5494 .03515 L
s
.008 w
.5494 .03515 Mdot
.016 w
.5494 .03515 m
.54515 .035 L
s
.008 w
.54515 .035 Mdot
.016 w
.54515 .035 m
.54041 .03484 L
s
.008 w
.54041 .03484 Mdot
.016 w
.54041 .03484 m
.53545 .03468 L
s
1 .77 0 r
.008 w
.53545 .03468 Mdot
.016 w
.53545 .03468 m
.53087 .03452 L
s
.008 w
.53087 .03452 Mdot
.016 w
.53087 .03452 m
.52595 .03437 L
s
.008 w
.52595 .03437 Mdot
.016 w
.52595 .03437 m
.52198 .03423 L
s
.008 w
.52198 .03423 Mdot
.016 w
.52198 .03423 m
.5177 .0341 L
s
.008 w
.5177 .0341 Mdot
.016 w
.5177 .0341 m
.51418 .03398 L
s
1 .769 0 r
.008 w
.51418 .03398 Mdot
.016 w
.51418 .03398 m
.51071 .03387 L
s
.008 w
.51071 .03387 Mdot
.016 w
.51071 .03387 m
.50778 .03377 L
s
.008 w
.50778 .03377 Mdot
.016 w
.50778 .03377 m
.50487 .03367 L
s
.008 w
.50487 .03367 Mdot
.016 w
.50487 .03367 m
.50269 .03358 L
s
.008 w
.50269 .03358 Mdot
.016 w
.50269 .03358 m
.50082 .0335 L
s
1 .768 0 r
.008 w
.50082 .0335 Mdot
.016 w
.50082 .0335 m
.49933 .03346 L
s
.008 w
.49933 .03346 Mdot
.016 w
.49933 .03346 m
.4982 .03344 L
s
.008 w
.4982 .03344 Mdot
.016 w
.4982 .03344 m
.49742 .03345 L
s
.008 w
.49742 .03345 Mdot
.016 w
.49742 .03345 m
.49691 .03348 L
s
.008 w
.49691 .03348 Mdot
.016 w
.49691 .03348 m
.49663 .03352 L
s
.008 w
.49663 .03352 Mdot
.016 w
.49663 .03352 m
.49651 .03357 L
s
1 .767 0 r
.008 w
.49651 .03357 Mdot
.016 w
.49651 .03357 m
.4965 .03361 L
s
.008 w
.4965 .03361 Mdot
.016 w
.4965 .03361 m
.4966 .03364 L
s
.008 w
.4966 .03364 Mdot
.016 w
.4966 .03364 m
.49678 .03364 L
s
.008 w
.49678 .03364 Mdot
.016 w
.49678 .03364 m
.49699 .0336 L
s
.008 w
.49699 .0336 Mdot
.016 w
.49699 .0336 m
.4972 .03354 L
s
1 .766 0 r
.008 w
.4972 .03354 Mdot
.016 w
.4972 .03354 m
.49741 .03348 L
s
.008 w
.49741 .03348 Mdot
.016 w
.49741 .03348 m
.49761 .03342 L
s
.008 w
.49761 .03342 Mdot
.016 w
.49761 .03342 m
.49779 .03338 L
s
.008 w
.49779 .03338 Mdot
.016 w
.49779 .03338 m
.49791 .03338 L
s
.008 w
.49791 .03338 Mdot
.016 w
.49791 .03338 m
.49794 .03346 L
s
1 .765 0 r
.008 w
.49794 .03346 Mdot
.016 w
.49794 .03346 m
.49788 .03363 L
s
.008 w
.49788 .03363 Mdot
.016 w
.49788 .03363 m
.49773 .03393 L
s
.008 w
.49773 .03393 Mdot
.016 w
.49773 .03393 m
.49751 .03436 L
s
.008 w
.49751 .03436 Mdot
.016 w
.49751 .03436 m
.49719 .03491 L
s
.008 w
.49719 .03491 Mdot
.016 w
.49719 .03491 m
.49679 .03557 L
s
1 .764 0 r
.008 w
.49679 .03557 Mdot
.016 w
.49679 .03557 m
.49629 .03631 L
s
.008 w
.49629 .03631 Mdot
.016 w
.49629 .03631 m
.49572 .03712 L
s
.008 w
.49572 .03712 Mdot
.016 w
.49572 .03712 m
.49509 .03797 L
s
.008 w
.49509 .03797 Mdot
.016 w
.49509 .03797 m
.49443 .03881 L
s
.008 w
.49443 .03881 Mdot
.016 w
.49443 .03881 m
.49379 .03959 L
s
.008 w
.49379 .03959 Mdot
.016 w
.49379 .03959 m
.49321 .04029 L
s
1 .763 0 r
.008 w
.49321 .04029 Mdot
.016 w
.49321 .04029 m
.49268 .0409 L
s
.008 w
.49268 .0409 Mdot
.016 w
.49268 .0409 m
.49223 .0414 L
s
.008 w
.49223 .0414 Mdot
.016 w
.49223 .0414 m
.49187 .04177 L
s
.008 w
.49187 .04177 Mdot
.016 w
.49187 .04177 m
.4916 .04202 L
s
.008 w
.4916 .04202 Mdot
.016 w
.4916 .04202 m
.49144 .04215 L
s
1 .762 0 r
.008 w
.49144 .04215 Mdot
.016 w
.49144 .04215 m
.49136 .04219 L
s
.008 w
.49136 .04219 Mdot
.016 w
.49136 .04219 m
.49135 .04217 L
s
.008 w
.49135 .04217 Mdot
.016 w
.49135 .04217 m
.49139 .04212 L
s
.008 w
.49139 .04212 Mdot
.016 w
.49139 .04212 m
.49146 .04205 L
s
.008 w
.49146 .04205 Mdot
.016 w
.49146 .04205 m
.49153 .04198 L
s
1 .761 0 r
.008 w
.49153 .04198 Mdot
.016 w
.49153 .04198 m
.49159 .04192 L
s
.008 w
.49159 .04192 Mdot
.016 w
.49159 .04192 m
.49161 .04189 L
s
.008 w
.49161 .04189 Mdot
.016 w
.49161 .04189 m
.49162 .04189 L
s
.008 w
.49162 .04189 Mdot
.016 w
.49162 .04189 m
.49162 .04188 L
s
.008 w
.49162 .04188 Mdot
.016 w
.49162 .04188 m
.4916 .04183 L
s
1 .76 0 r
.008 w
.4916 .04183 Mdot
.016 w
.4916 .04183 m
.49156 .04173 L
s
.008 w
.49156 .04173 Mdot
.016 w
.49156 .04173 m
.4915 .04157 L
s
.008 w
.4915 .04157 Mdot
.016 w
.4915 .04157 m
.49143 .04141 L
s
.008 w
.49143 .04141 Mdot
.016 w
.49143 .04141 m
.49137 .04129 L
s
.008 w
.49137 .04129 Mdot
.016 w
.49137 .04129 m
.49133 .04122 L
s
.008 w
.49133 .04122 Mdot
.016 w
.49133 .04122 m
.49132 .04125 L
s
1 .759 0 r
.008 w
.49132 .04125 Mdot
.016 w
.49132 .04125 m
.49139 .04142 L
s
.008 w
.49139 .04142 Mdot
.016 w
.49139 .04142 m
.49153 .04179 L
s
.008 w
.49153 .04179 Mdot
.016 w
.49153 .04179 m
.49177 .04237 L
s
.008 w
.49177 .04237 Mdot
.016 w
.49177 .04237 m
.49209 .04321 L
s
.008 w
.49209 .04321 Mdot
.016 w
.49209 .04321 m
.49253 .04435 L
s
1 .758 0 r
.008 w
.49253 .04435 Mdot
.016 w
.49253 .04435 m
.49308 .04582 L
s
.008 w
.49308 .04582 Mdot
.016 w
.49308 .04582 m
.49374 .04748 L
s
.008 w
.49374 .04748 Mdot
.016 w
.49374 .04748 m
.49455 .04965 L
s
.008 w
.49455 .04965 Mdot
.016 w
.49455 .04965 m
.49551 .05198 L
s
.008 w
.49551 .05198 Mdot
.016 w
.49551 .05198 m
.49663 .05472 L
s
1 .757 0 r
.008 w
.49663 .05472 Mdot
.016 w
.49663 .05472 m
.49788 .05769 L
s
.008 w
.49788 .05769 Mdot
.016 w
.49788 .05769 m
.49923 .06094 L
s
.008 w
.49923 .06094 Mdot
.016 w
.49923 .06094 m
.50064 .06398 L
s
.008 w
.50064 .06398 Mdot
.016 w
.50064 .06398 m
.50208 .06734 L
s
.008 w
.50208 .06734 Mdot
.016 w
.50208 .06734 m
.50346 .07068 L
s
.008 w
.50346 .07068 Mdot
.016 w
.50346 .07068 m
.50482 .07408 L
s
1 .756 0 r
.008 w
.50482 .07408 Mdot
.016 w
.50482 .07408 m
.50609 .07727 L
s
.008 w
.50609 .07727 Mdot
.016 w
.50609 .07727 m
.5073 .08039 L
s
.008 w
.5073 .08039 Mdot
.016 w
.5073 .08039 m
.50844 .08338 L
s
.008 w
.50844 .08338 Mdot
.016 w
.50844 .08338 m
.50945 .08606 L
s
.008 w
.50945 .08606 Mdot
.016 w
.50945 .08606 m
.51038 .08849 L
s
1 .755 0 r
.008 w
.51038 .08849 Mdot
.016 w
.51038 .08849 m
.51121 .0904 L
s
.008 w
.51121 .0904 Mdot
.016 w
.51121 .0904 m
.51191 .09209 L
s
.008 w
.51191 .09209 Mdot
.016 w
.51191 .09209 m
.51247 .09334 L
s
.008 w
.51247 .09334 Mdot
.016 w
.51247 .09334 m
.51288 .09434 L
s
.008 w
.51288 .09434 Mdot
.016 w
.51288 .09434 m
.51314 .09508 L
s
1 .754 0 r
.008 w
.51314 .09508 Mdot
.016 w
.51314 .09508 m
.51324 .09568 L
s
.008 w
.51324 .09568 Mdot
.016 w
.51324 .09568 m
.51319 .09624 L
s
.008 w
.51319 .09624 Mdot
.016 w
.51319 .09624 m
.51302 .09688 L
s
.008 w
.51302 .09688 Mdot
.016 w
.51302 .09688 m
.51272 .09769 L
s
.008 w
.51272 .09769 Mdot
.016 w
.51272 .09769 m
.51231 .09877 L
s
1 .753 0 r
.008 w
.51231 .09877 Mdot
.016 w
.51231 .09877 m
.51178 .10014 L
s
.008 w
.51178 .10014 Mdot
.016 w
.51178 .10014 m
.51115 .10182 L
s
.008 w
.51115 .10182 Mdot
.016 w
.51115 .10182 m
.51045 .10349 L
s
.008 w
.51045 .10349 Mdot
.016 w
.51045 .10349 m
.50967 .10565 L
s
.008 w
.50967 .10565 Mdot
.016 w
.50967 .10565 m
.50884 .10786 L
s
.008 w
.50884 .10786 Mdot
.016 w
.50884 .10786 m
.50798 .11033 L
s
1 .752 0 r
.008 w
.50798 .11033 Mdot
.016 w
.50798 .11033 m
.50722 .11282 L
s
.008 w
.50722 .11282 Mdot
.016 w
.50722 .11282 m
.5065 .11494 L
s
.008 w
.5065 .11494 Mdot
.016 w
.5065 .11494 m
.50588 .11694 L
s
.008 w
.50588 .11694 Mdot
.016 w
.50588 .11694 m
.50538 .11876 L
s
.008 w
.50538 .11876 Mdot
.016 w
.50538 .11876 m
.50501 .12017 L
s
1 .751 0 r
.008 w
.50501 .12017 Mdot
.016 w
.50501 .12017 m
.50477 .12124 L
s
.008 w
.50477 .12124 Mdot
.016 w
.50477 .12124 m
.50465 .12192 L
s
.008 w
.50465 .12192 Mdot
.016 w
.50465 .12192 m
.50465 .12225 L
s
.008 w
.50465 .12225 Mdot
.016 w
.50465 .12225 m
.50478 .12236 L
s
.008 w
.50478 .12236 Mdot
.016 w
.50478 .12236 m
.50504 .1224 L
s
1 .75 0 r
.008 w
.50504 .1224 Mdot
.016 w
.50504 .1224 m
.50548 .12248 L
s
.008 w
.50548 .12248 Mdot
.016 w
.50548 .12248 m
.50612 .12269 L
s
.008 w
.50612 .12269 Mdot
.016 w
.50612 .12269 m
.50702 .12309 L
s
.008 w
.50702 .12309 Mdot
.016 w
.50702 .12309 m
.50821 .12373 L
s
.008 w
.50821 .12373 Mdot
.016 w
.50821 .12373 m
.50967 .12461 L
s
1 .749 0 r
.008 w
.50967 .12461 Mdot
.016 w
.50967 .12461 m
.51141 .12574 L
s
.008 w
.51141 .12574 Mdot
.016 w
.51141 .12574 m
.51344 .12716 L
s
.008 w
.51344 .12716 Mdot
.016 w
.51344 .12716 m
.51564 .12873 L
s
.008 w
.51564 .12873 Mdot
.016 w
.51564 .12873 m
.51796 .13052 L
s
.008 w
.51796 .13052 Mdot
.016 w
.51796 .13052 m
.52036 .13233 L
s
.008 w
.52036 .13233 Mdot
.016 w
.52036 .13233 m
.52277 .1342 L
s
1 .748 0 r
.008 w
.52277 .1342 Mdot
.016 w
.52277 .1342 m
.52507 .13599 L
s
.008 w
.52507 .13599 Mdot
.016 w
.52507 .13599 m
.52728 .13761 L
s
.008 w
.52728 .13761 Mdot
.016 w
.52728 .13761 m
.52911 .13894 L
s
.008 w
.52911 .13894 Mdot
.016 w
.52911 .13894 m
.53072 .13997 L
s
.008 w
.53072 .13997 Mdot
.016 w
.53072 .13997 m
.532 .14071 L
s
1 .747 0 r
.008 w
.532 .14071 Mdot
.016 w
.532 .14071 m
.53294 .14114 L
s
.008 w
.53294 .14114 Mdot
.016 w
.53294 .14114 m
.53358 .14135 L
s
.008 w
.53358 .14135 Mdot
.016 w
.53358 .14135 m
.53393 .14137 L
s
.008 w
.53393 .14137 Mdot
.016 w
.53393 .14137 m
.53402 .14132 L
s
.008 w
.53402 .14132 Mdot
.016 w
.53402 .14132 m
.53391 .14128 L
s
1 .746 0 r
.008 w
.53391 .14128 Mdot
.016 w
.53391 .14128 m
.53368 .14136 L
s
.008 w
.53368 .14136 Mdot
.016 w
.53368 .14136 m
.53339 .14166 L
s
.008 w
.53339 .14166 Mdot
.016 w
.53339 .14166 m
.53309 .14225 L
s
.008 w
.53309 .14225 Mdot
.016 w
.53309 .14225 m
.53285 .14322 L
s
.008 w
.53285 .14322 Mdot
.016 w
.53285 .14322 m
.53269 .14457 L
s
1 .745 0 r
.008 w
.53269 .14457 Mdot
.016 w
.53269 .14457 m
.53261 .14654 L
s
.008 w
.53261 .14654 Mdot
.016 w
.53261 .14654 m
.5326 .14894 L
s
.008 w
.5326 .14894 Mdot
.016 w
.5326 .14894 m
.53263 .15192 L
s
.008 w
.53263 .15192 Mdot
.016 w
.53263 .15192 m
.53269 .15535 L
s
.008 w
.53269 .15535 Mdot
.016 w
.53269 .15535 m
.53272 .15925 L
s
.008 w
.53272 .15925 Mdot
.016 w
.53272 .15925 m
.5327 .16362 L
s
1 .744 0 r
.008 w
.5327 .16362 Mdot
.016 w
.5327 .16362 m
.5326 .16777 L
s
.008 w
.5326 .16777 Mdot
.016 w
.5326 .16777 m
.53241 .17242 L
s
.008 w
.53241 .17242 Mdot
.016 w
.53241 .17242 m
.53213 .17721 L
s
.008 w
.53213 .17721 Mdot
.016 w
.53213 .17721 m
.53177 .18233 L
s
.008 w
.53177 .18233 Mdot
.016 w
.53177 .18233 m
.53133 .18685 L
s
1 .743 0 r
.008 w
.53133 .18685 Mdot
.016 w
.53133 .18685 m
.53082 .19202 L
s
.008 w
.53082 .19202 Mdot
.016 w
.53082 .19202 m
.53026 .19611 L
s
.008 w
.53026 .19611 Mdot
.016 w
.53026 .19611 m
.52968 .20061 L
s
.008 w
.52968 .20061 Mdot
.016 w
.52968 .20061 m
.52911 .20436 L
s
.008 w
.52911 .20436 Mdot
.016 w
.52911 .20436 m
.52855 .20788 L
s
1 .742 0 r
.008 w
.52855 .20788 Mdot
.016 w
.52855 .20788 m
.52804 .21146 L
s
.008 w
.52804 .21146 Mdot
.016 w
.52804 .21146 m
.52761 .21394 L
s
.008 w
.52761 .21394 Mdot
.016 w
.52761 .21394 m
.52726 .21603 L
s
.008 w
.52726 .21603 Mdot
.016 w
.52726 .21603 m
.52702 .21768 L
s
.008 w
.52702 .21768 Mdot
.016 w
.52702 .21768 m
.5269 .21888 L
s
.008 w
.5269 .21888 Mdot
.016 w
.5269 .21888 m
.52687 .21962 L
s
1 .741 0 r
.008 w
.52687 .21962 Mdot
.016 w
.52687 .21962 m
.52691 .21994 L
s
.008 w
.52691 .21994 Mdot
.016 w
.52691 .21994 m
.52694 .21995 L
s
.008 w
.52694 .21995 Mdot
.016 w
.52694 .21995 m
.52693 .21979 L
s
.008 w
.52693 .21979 Mdot
.016 w
.52693 .21979 m
.52679 .2196 L
s
.008 w
.52679 .2196 Mdot
.016 w
.52679 .2196 m
.52647 .21949 L
s
1 .74 0 r
.008 w
.52647 .21949 Mdot
.016 w
.52647 .21949 m
.52592 .21954 L
s
.008 w
.52592 .21954 Mdot
.016 w
.52592 .21954 m
.52511 .21985 L
s
.008 w
.52511 .21985 Mdot
.016 w
.52511 .21985 m
.52402 .22054 L
s
.008 w
.52402 .22054 Mdot
.016 w
.52402 .22054 m
.52261 .2216 L
s
.008 w
.52261 .2216 Mdot
.016 w
.52261 .2216 m
.52087 .2229 L
s
1 .739 0 r
.008 w
.52087 .2229 Mdot
.016 w
.52087 .2229 m
.51901 .22426 L
s
.008 w
.51901 .22426 Mdot
.016 w
.51901 .22426 m
.51686 .2258 L
s
.008 w
.51686 .2258 Mdot
.016 w
.51686 .2258 m
.5145 .22738 L
s
.008 w
.5145 .22738 Mdot
.016 w
.5145 .22738 m
.51217 .22889 L
s
.008 w
.51217 .22889 Mdot
.016 w
.51217 .22889 m
.50975 .23037 L
s
1 .738 0 r
.008 w
.50975 .23037 Mdot
.016 w
.50975 .23037 m
.50749 .23176 L
s
.008 w
.50749 .23176 Mdot
.016 w
.50749 .23176 m
.50547 .23292 L
s
.008 w
.50547 .23292 Mdot
.016 w
.50547 .23292 m
.50368 .23382 L
s
.008 w
.50368 .23382 Mdot
.016 w
.50368 .23382 m
.50221 .23446 L
s
.008 w
.50221 .23446 Mdot
.016 w
.50221 .23446 m
.50115 .23485 L
s
.008 w
.50115 .23485 Mdot
.016 w
.50115 .23485 m
.50044 .23498 L
s
1 .737 0 r
.008 w
.50044 .23498 Mdot
.016 w
.50044 .23498 m
.50008 .2349 L
s
.008 w
.50008 .2349 Mdot
.016 w
.50008 .2349 m
.50008 .23471 L
s
.008 w
.50008 .23471 Mdot
.016 w
.50008 .23471 m
.50042 .23453 L
s
.008 w
.50042 .23453 Mdot
.016 w
.50042 .23453 m
.50109 .2345 L
s
.008 w
.50109 .2345 Mdot
.016 w
.50109 .2345 m
.50208 .23477 L
s
1 .736 0 r
.008 w
.50208 .23477 Mdot
.016 w
.50208 .23477 m
.50338 .23542 L
s
.008 w
.50338 .23542 Mdot
.016 w
.50338 .23542 m
.50491 .23648 L
s
.008 w
.50491 .23648 Mdot
.016 w
.50491 .23648 m
.50667 .23794 L
s
.008 w
.50667 .23794 Mdot
.016 w
.50667 .23794 m
.50851 .23974 L
s
.008 w
.50851 .23974 Mdot
.016 w
.50851 .23974 m
.5104 .24184 L
s
1 .735 0 r
.008 w
.5104 .24184 Mdot
.016 w
.5104 .24184 m
.51227 .24427 L
s
.008 w
.51227 .24427 Mdot
.016 w
.51227 .24427 m
.51412 .24685 L
s
.008 w
.51412 .24685 Mdot
.016 w
.51412 .24685 m
.51581 .24903 L
s
.008 w
.51581 .24903 Mdot
.016 w
.51581 .24903 m
.51748 .2515 L
s
.008 w
.51748 .2515 Mdot
.016 w
.51748 .2515 m
.51894 .25366 L
s
1 .734 0 r
.008 w
.51894 .25366 Mdot
.016 w
.51894 .25366 m
.52028 .25608 L
s
.008 w
.52028 .25608 Mdot
.016 w
.52028 .25608 m
.5214 .25801 L
s
.008 w
.5214 .25801 Mdot
.016 w
.5214 .25801 m
.52229 .25983 L
s
.008 w
.52229 .25983 Mdot
.016 w
.52229 .25983 m
.52289 .26152 L
s
.008 w
.52289 .26152 Mdot
.016 w
.52289 .26152 m
.52317 .26309 L
s
.008 w
.52317 .26309 Mdot
.016 w
.52317 .26309 m
.52313 .26469 L
s
1 .733 0 r
.008 w
.52313 .26469 Mdot
.016 w
.52313 .26469 m
.52279 .26646 L
s
.008 w
.52279 .26646 Mdot
.016 w
.52279 .26646 m
.52222 .26849 L
s
.008 w
.52222 .26849 Mdot
.016 w
.52222 .26849 m
.52145 .27059 L
s
.008 w
.52145 .27059 Mdot
.016 w
.52145 .27059 m
.52055 .273 L
s
.008 w
.52055 .273 Mdot
.016 w
.52055 .273 m
.51955 .27584 L
s
1 .732 0 r
.008 w
.51955 .27584 Mdot
.016 w
.51955 .27584 m
.5185 .27912 L
s
.008 w
.5185 .27912 Mdot
.016 w
.5185 .27912 m
.51745 .28223 L
s
.008 w
.51745 .28223 Mdot
.016 w
.51745 .28223 m
.51635 .28575 L
s
.008 w
.51635 .28575 Mdot
.016 w
.51635 .28575 m
.51527 .2891 L
s
.008 w
.51527 .2891 Mdot
.016 w
.51527 .2891 m
.51423 .29251 L
s
1 .731 0 r
.008 w
.51423 .29251 Mdot
.016 w
.51423 .29251 m
.5133 .29564 L
s
.008 w
.5133 .29564 Mdot
.016 w
.5133 .29564 m
.51255 .29824 L
s
.008 w
.51255 .29824 Mdot
.016 w
.51255 .29824 m
.51198 .30056 L
s
.008 w
.51198 .30056 Mdot
.016 w
.51198 .30056 m
.51156 .30246 L
s
.008 w
.51156 .30246 Mdot
.016 w
.51156 .30246 m
.51127 .30384 L
s
1 .73 0 r
.008 w
.51127 .30384 Mdot
.016 w
.51127 .30384 m
.51108 .30488 L
s
.008 w
.51108 .30488 Mdot
.016 w
.51108 .30488 m
.5109 .30568 L
s
.008 w
.5109 .30568 Mdot
.016 w
.5109 .30568 m
.51059 .3063 L
s
.008 w
.51059 .3063 Mdot
.016 w
.51059 .3063 m
.5101 .30679 L
s
.008 w
.5101 .30679 Mdot
.016 w
.5101 .30679 m
.50939 .30723 L
s
.008 w
.50939 .30723 Mdot
.016 w
.50939 .30723 m
.50838 .30767 L
s
1 .729 0 r
.008 w
.50838 .30767 Mdot
.016 w
.50838 .30767 m
.50701 .30811 L
s
.008 w
.50701 .30811 Mdot
.016 w
.50701 .30811 m
.50523 .30859 L
s
.008 w
.50523 .30859 Mdot
.016 w
.50523 .30859 m
.5033 .30914 L
s
.008 w
.5033 .30914 Mdot
.016 w
.5033 .30914 m
.50086 .30975 L
s
.008 w
.50086 .30975 Mdot
.016 w
.50086 .30975 m
.49814 .31045 L
s
1 .728 0 r
.008 w
.49814 .31045 Mdot
.016 w
.49814 .31045 m
.49485 .31123 L
s
.008 w
.49485 .31123 Mdot
.016 w
.49485 .31123 m
.49162 .31209 L
s
.008 w
.49162 .31209 Mdot
.016 w
.49162 .31209 m
.48777 .31301 L
s
.008 w
.48777 .31301 Mdot
.016 w
.48777 .31301 m
.48443 .31396 L
s
.008 w
.48443 .31396 Mdot
.016 w
.48443 .31396 m
.4806 .31494 L
s
1 .727 0 r
.008 w
.4806 .31494 Mdot
.016 w
.4806 .31494 m
.47664 .31594 L
s
.008 w
.47664 .31594 Mdot
.016 w
.47664 .31594 m
.47216 .31693 L
s
.008 w
.47216 .31693 Mdot
.016 w
.47216 .31693 m
.46838 .31791 L
s
.008 w
.46838 .31791 Mdot
.016 w
.46838 .31791 m
.46402 .31886 L
s
.008 w
.46402 .31886 Mdot
.016 w
.46402 .31886 m
.4598 .31976 L
s
1 .726 0 r
.008 w
.4598 .31976 Mdot
.016 w
.4598 .31976 m
.45534 .32059 L
s
.008 w
.45534 .32059 Mdot
.016 w
.45534 .32059 m
.45042 .32131 L
s
.008 w
.45042 .32131 Mdot
.016 w
.45042 .32131 m
.4462 .32188 L
s
.008 w
.4462 .32188 Mdot
.016 w
.4462 .32188 m
.44156 .32231 L
s
.008 w
.44156 .32231 Mdot
.016 w
.44156 .32231 m
.43636 .32256 L
s
.008 w
.43636 .32256 Mdot
.016 w
.43636 .32256 m
.43223 .3226 L
s
1 .725 0 r
.008 w
.43223 .3226 Mdot
.016 w
.43223 .3226 m
.42744 .3224 L
s
.008 w
.42744 .3224 Mdot
.016 w
.42744 .3224 m
.42291 .32195 L
s
.008 w
.42291 .32195 Mdot
.016 w
.42291 .32195 m
.41857 .32123 L
s
.008 w
.41857 .32123 Mdot
.016 w
.41857 .32123 m
.41381 .32024 L
s
.008 w
.41381 .32024 Mdot
.016 w
.41381 .32024 m
.4101 .31899 L
s
1 .724 0 r
.008 w
.4101 .31899 Mdot
.016 w
.4101 .31899 m
.40607 .31756 L
s
.008 w
.40607 .31756 Mdot
.016 w
.40607 .31756 m
.4027 .316 L
s
.008 w
.4027 .316 Mdot
.016 w
.4027 .316 m
.39935 .31436 L
s
.008 w
.39935 .31436 Mdot
.016 w
.39935 .31436 m
.3966 .31278 L
s
.008 w
.3966 .31278 Mdot
.016 w
.3966 .31278 m
.39387 .31129 L
s
1 .723 0 r
.008 w
.39387 .31129 Mdot
.016 w
.39387 .31129 m
.39185 .30991 L
s
.008 w
.39185 .30991 Mdot
.016 w
.39185 .30991 m
.39009 .30863 L
s
.008 w
.39009 .30863 Mdot
.016 w
.39009 .30863 m
.3886 .30754 L
s
.008 w
.3886 .30754 Mdot
.016 w
.3886 .30754 m
.38744 .30661 L
s
.008 w
.38744 .30661 Mdot
.016 w
.38744 .30661 m
.38664 .30586 L
s
.008 w
.38664 .30586 Mdot
.016 w
.38664 .30586 m
.38619 .30535 L
s
1 .722 0 r
.008 w
.38619 .30535 Mdot
.016 w
.38619 .30535 m
.38601 .30511 L
s
.008 w
.38601 .30511 Mdot
.016 w
.38601 .30511 m
.386 .30514 L
s
.008 w
.386 .30514 Mdot
.016 w
.386 .30514 m
.38611 .30537 L
s
.008 w
.38611 .30537 Mdot
.016 w
.38611 .30537 m
.38631 .30576 L
s
.008 w
.38631 .30576 Mdot
.016 w
.38631 .30576 m
.38655 .30625 L
s
1 .721 0 r
.008 w
.38655 .30625 Mdot
.016 w
.38655 .30625 m
.38675 .3068 L
s
.008 w
.38675 .3068 Mdot
.016 w
.38675 .3068 m
.38685 .30734 L
s
.008 w
.38685 .30734 Mdot
.016 w
.38685 .30734 m
.38686 .30789 L
s
.008 w
.38686 .30789 Mdot
.016 w
.38686 .30789 m
.38686 .30838 L
s
.008 w
.38686 .30838 Mdot
.016 w
.38686 .30838 m
.38685 .30879 L
s
1 .72 0 r
.008 w
.38685 .30879 Mdot
.016 w
.38685 .30879 m
.38685 .30911 L
s
.008 w
.38685 .30911 Mdot
.016 w
.38685 .30911 m
.38685 .30931 L
s
.008 w
.38685 .30931 Mdot
.016 w
.38685 .30931 m
.38685 .30938 L
s
.008 w
.38685 .30938 Mdot
.016 w
.38685 .30938 m
.38685 .30933 L
s
.008 w
.38685 .30933 Mdot
.016 w
.38685 .30933 m
.38685 .30921 L
s
1 .719 0 r
.008 w
.38685 .30921 Mdot
.016 w
.38685 .30921 m
.38685 .30902 L
s
.008 w
.38685 .30902 Mdot
.016 w
.38685 .30902 m
.38686 .30876 L
s
.008 w
.38686 .30876 Mdot
.016 w
.38686 .30876 m
.38686 .30842 L
s
.008 w
.38686 .30842 Mdot
.016 w
.38686 .30842 m
.38686 .30808 L
s
.008 w
.38686 .30808 Mdot
.016 w
.38686 .30808 m
.38686 .30776 L
s
.008 w
.38686 .30776 Mdot
.016 w
.38686 .30776 m
.38686 .30751 L
s
1 .718 0 r
.008 w
.38686 .30751 Mdot
.016 w
.38686 .30751 m
.38686 .30733 L
s
.008 w
.38686 .30733 Mdot
.016 w
.38686 .30733 m
.38686 .3072 L
s
.008 w
.38686 .3072 Mdot
.016 w
.38686 .3072 m
.38686 .30713 L
s
.008 w
.38686 .30713 Mdot
.016 w
.38686 .30713 m
.38686 .3071 L
s
.008 w
.38686 .3071 Mdot
.016 w
.38686 .3071 m
.38686 .30708 L
s
1 .717 0 r
.008 w
.38686 .30708 Mdot
.016 w
.38686 .30708 m
.38686 .3071 L
s
.008 w
.38686 .3071 Mdot
.016 w
.38686 .3071 m
.38686 .30714 L
s
.008 w
.38686 .30714 Mdot
.016 w
.38686 .30714 m
.38686 .30719 L
s
.008 w
.38686 .30719 Mdot
.016 w
.38686 .30719 m
.38686 .30723 L
s
.008 w
.38686 .30723 Mdot
.016 w
.38686 .30723 m
.38686 .30728 L
s
1 .716 0 r
.008 w
.38686 .30728 Mdot
.016 w
.38686 .30728 m
.38686 .30736 L
s
.008 w
.38686 .30736 Mdot
.016 w
.38686 .30736 m
.38686 .30749 L
s
.008 w
.38686 .30749 Mdot
.016 w
.38686 .30749 m
.38686 .30762 L
s
.008 w
.38686 .30762 Mdot
.016 w
.38686 .30762 m
.38686 .30775 L
s
.008 w
.38686 .30775 Mdot
.016 w
.38686 .30775 m
.38686 .30785 L
s
1 .715 0 r
.008 w
.38686 .30785 Mdot
.016 w
.38686 .30785 m
.38686 .30796 L
s
.008 w
.38686 .30796 Mdot
.016 w
.38686 .30796 m
.38686 .308 L
s
.008 w
.38686 .308 Mdot
.016 w
.38686 .308 m
.38686 .30803 L
s
.008 w
.38686 .30803 Mdot
.016 w
.38686 .30803 m
.38686 .30809 L
s
.008 w
.38686 .30809 Mdot
.016 w
.38686 .30809 m
.38686 .30817 L
s
.008 w
.38686 .30817 Mdot
.016 w
.38686 .30817 m
.38686 .3083 L
s
1 .714 0 r
.008 w
.38686 .3083 Mdot
.016 w
.38686 .3083 m
.38686 .30848 L
s
.008 w
.38686 .30848 Mdot
.016 w
.38686 .30848 m
.38686 .30869 L
s
.008 w
.38686 .30869 Mdot
.016 w
.38686 .30869 m
.38686 .30885 L
s
.008 w
.38686 .30885 Mdot
.016 w
.38686 .30885 m
.38685 .30896 L
s
.008 w
.38685 .30896 Mdot
.016 w
.38685 .30896 m
.38685 .30902 L
s
1 .713 0 r
.008 w
.38685 .30902 Mdot
.016 w
.38685 .30902 m
.38685 .30913 L
s
.008 w
.38685 .30913 Mdot
.016 w
.38685 .30913 m
.38685 .30927 L
s
.008 w
.38685 .30927 Mdot
.016 w
.38685 .30927 m
.38685 .30944 L
s
.008 w
.38685 .30944 Mdot
.016 w
.38685 .30944 m
.38685 .30962 L
s
.008 w
.38685 .30962 Mdot
.016 w
.38685 .30962 m
.38685 .30979 L
s
1 .712 0 r
.008 w
.38685 .30979 Mdot
.016 w
.38685 .30979 m
.38684 .30993 L
s
.008 w
.38684 .30993 Mdot
.016 w
.38684 .30993 m
.38684 .31003 L
s
.008 w
.38684 .31003 Mdot
.016 w
.38684 .31003 m
.38684 .3101 L
s
.008 w
.38684 .3101 Mdot
.016 w
.38684 .3101 m
.38684 .31012 L
s
.008 w
.38684 .31012 Mdot
.016 w
.38684 .31012 m
.38684 .31008 L
s
1 .711 0 r
.008 w
.38684 .31008 Mdot
.016 w
.38684 .31008 m
.38684 .31002 L
s
.008 w
.38684 .31002 Mdot
.016 w
.38684 .31002 m
.38684 .30998 L
s
.008 w
.38684 .30998 Mdot
.016 w
.38684 .30998 m
.38684 .30999 L
s
.008 w
.38684 .30999 Mdot
.016 w
.38684 .30999 m
.38684 .31004 L
s
.008 w
.38684 .31004 Mdot
.016 w
.38684 .31004 m
.38684 .31011 L
s
.008 w
.38684 .31011 Mdot
.016 w
.38684 .31011 m
.38684 .31018 L
s
1 .71 0 r
.008 w
.38684 .31018 Mdot
.016 w
.38684 .31018 m
.38684 .31021 L
s
.008 w
.38684 .31021 Mdot
.016 w
.38684 .31021 m
.38684 .31019 L
s
.008 w
.38684 .31019 Mdot
.016 w
.38684 .31019 m
.38684 .31009 L
s
.008 w
.38684 .31009 Mdot
.016 w
.38684 .31009 m
.38684 .30991 L
s
.008 w
.38684 .30991 Mdot
.016 w
.38684 .30991 m
.38685 .30965 L
s
1 .709 0 r
.008 w
.38685 .30965 Mdot
.016 w
.38685 .30965 m
.38685 .30931 L
s
.008 w
.38685 .30931 Mdot
.016 w
.38685 .30931 m
.38685 .30891 L
s
.008 w
.38685 .30891 Mdot
.016 w
.38685 .30891 m
.38685 .30847 L
s
.008 w
.38685 .30847 Mdot
.016 w
.38685 .30847 m
.38686 .30801 L
s
.008 w
.38686 .30801 Mdot
.016 w
.38686 .30801 m
.38686 .30755 L
s
1 .708 0 r
.008 w
.38686 .30755 Mdot
.016 w
.38686 .30755 m
.38687 .30709 L
s
.008 w
.38687 .30709 Mdot
.016 w
.38687 .30709 m
.38687 .30665 L
s
.008 w
.38687 .30665 Mdot
.016 w
.38687 .30665 m
.38687 .30623 L
s
.008 w
.38687 .30623 Mdot
.016 w
.38687 .30623 m
.38687 .30586 L
s
.008 w
.38687 .30586 Mdot
.016 w
.38687 .30586 m
.38688 .30557 L
s
.008 w
.38688 .30557 Mdot
.016 w
.38688 .30557 m
.38688 .30534 L
s
1 .707 0 r
.008 w
.38688 .30534 Mdot
.016 w
.38688 .30534 m
.38688 .30518 L
s
.008 w
.38688 .30518 Mdot
.016 w
.38688 .30518 m
.38688 .30507 L
s
.008 w
.38688 .30507 Mdot
.016 w
.38688 .30507 m
.38688 .30504 L
s
.008 w
.38688 .30504 Mdot
.016 w
.38688 .30504 m
.38688 .30507 L
s
.008 w
.38688 .30507 Mdot
.016 w
.38688 .30507 m
.38688 .30517 L
s
1 .706 0 r
.008 w
.38688 .30517 Mdot
.016 w
.38688 .30517 m
.38688 .30532 L
s
.008 w
.38688 .30532 Mdot
.016 w
.38688 .30532 m
.38688 .30552 L
s
.008 w
.38688 .30552 Mdot
.016 w
.38688 .30552 m
.38688 .30579 L
s
.008 w
.38688 .30579 Mdot
.016 w
.38688 .30579 m
.38687 .30613 L
s
.008 w
.38687 .30613 Mdot
.016 w
.38687 .30613 m
.38687 .30653 L
s
1 .705 0 r
.008 w
.38687 .30653 Mdot
.016 w
.38687 .30653 m
.38687 .30697 L
s
.008 w
.38687 .30697 Mdot
.016 w
.38687 .30697 m
.38686 .30743 L
s
.008 w
.38686 .30743 Mdot
.016 w
.38686 .30743 m
.38686 .3079 L
s
.008 w
.38686 .3079 Mdot
.016 w
.38686 .3079 m
.38686 .30837 L
s
.008 w
.38686 .30837 Mdot
.016 w
.38686 .30837 m
.38685 .30883 L
s
1 .704 0 r
.008 w
.38685 .30883 Mdot
.016 w
.38685 .30883 m
.38685 .30924 L
s
.008 w
.38685 .30924 Mdot
.016 w
.38685 .30924 m
.38685 .3096 L
s
.008 w
.38685 .3096 Mdot
.016 w
.38685 .3096 m
.38684 .30988 L
s
.008 w
.38684 .30988 Mdot
.016 w
.38684 .30988 m
.38684 .31006 L
s
.008 w
.38684 .31006 Mdot
.016 w
.38684 .31006 m
.38684 .31015 L
s
.008 w
.38684 .31015 Mdot
.016 w
.38684 .31015 m
.38684 .31016 L
s
1 .703 0 r
.008 w
.38684 .31016 Mdot
.016 w
.38684 .31016 m
.38684 .31011 L
s
.008 w
.38684 .31011 Mdot
.016 w
.38684 .31011 m
.38684 .31002 L
s
.008 w
.38684 .31002 Mdot
.016 w
.38684 .31002 m
.38685 .30993 L
s
.008 w
.38685 .30993 Mdot
.016 w
.38685 .30993 m
.38685 .30987 L
s
.008 w
.38685 .30987 Mdot
.016 w
.38685 .30987 m
.38685 .30983 L
s
1 .702 0 r
.008 w
.38685 .30983 Mdot
.016 w
.38685 .30983 m
.38685 .30983 L
s
.008 w
.38685 .30983 Mdot
.016 w
.38685 .30983 m
.38684 .30983 L
s
.008 w
.38684 .30983 Mdot
.016 w
.38684 .30983 m
.38683 .30983 L
s
.008 w
.38683 .30983 Mdot
.016 w
.38683 .30983 m
.3868 .30984 L
s
.008 w
.3868 .30984 Mdot
.016 w
.3868 .30984 m
.38677 .30986 L
s
1 .701 0 r
.008 w
.38677 .30986 Mdot
.016 w
.38677 .30986 m
.38674 .30988 L
s
.008 w
.38674 .30988 Mdot
.016 w
.38674 .30988 m
.38672 .30991 L
s
.008 w
.38672 .30991 Mdot
.016 w
.38672 .30991 m
.38673 .30993 L
s
.008 w
.38673 .30993 Mdot
.016 w
.38673 .30993 m
.38678 .30995 L
s
.008 w
.38678 .30995 Mdot
.016 w
.38678 .30995 m
.38686 .30997 L
s
1 .7 0 r
.008 w
.38686 .30997 Mdot
.016 w
.38686 .30997 m
.38699 .30998 L
s
.008 w
.38699 .30998 Mdot
.016 w
.38699 .30998 m
.38716 .30998 L
s
.008 w
.38716 .30998 Mdot
.016 w
.38716 .30998 m
.38736 .30997 L
s
.008 w
.38736 .30997 Mdot
.016 w
.38736 .30997 m
.38757 .30995 L
s
.008 w
.38757 .30995 Mdot
.016 w
.38757 .30995 m
.3878 .30994 L
s
.008 w
.3878 .30994 Mdot
.016 w
.3878 .30994 m
.38803 .30993 L
s
1 .699 0 r
.008 w
.38803 .30993 Mdot
.016 w
.38803 .30993 m
.38826 .30992 L
s
.008 w
.38826 .30992 Mdot
.016 w
.38826 .30992 m
.38848 .30992 L
s
.008 w
.38848 .30992 Mdot
.016 w
.38848 .30992 m
.38869 .30991 L
s
.008 w
.38869 .30991 Mdot
.016 w
.38869 .30991 m
.38886 .30991 L
s
.008 w
.38886 .30991 Mdot
.016 w
.38886 .30991 m
.389 .3099 L
s
1 .698 0 r
.008 w
.389 .3099 Mdot
.016 w
.389 .3099 m
.3891 .3099 L
s
.008 w
.3891 .3099 Mdot
.016 w
.3891 .3099 m
.38916 .3099 L
s
.008 w
.38916 .3099 Mdot
.016 w
.38916 .3099 m
.38918 .3099 L
s
.008 w
.38918 .3099 Mdot
.016 w
.38918 .3099 m
.38916 .3099 L
s
.008 w
.38916 .3099 Mdot
.016 w
.38916 .3099 m
.38913 .3099 L
s
1 .697 0 r
.008 w
.38913 .3099 Mdot
.016 w
.38913 .3099 m
.38909 .3099 L
s
.008 w
.38909 .3099 Mdot
.016 w
.38909 .3099 m
.38906 .3099 L
s
.008 w
.38906 .3099 Mdot
.016 w
.38906 .3099 m
.38905 .3099 L
s
.008 w
.38905 .3099 Mdot
.016 w
.38905 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
1 .696 0 r
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
1 .695 0 r
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38904 .3099 L
s
.008 w
.38904 .3099 Mdot
.016 w
.38904 .3099 m
.38905 .3099 L
s
.008 w
.38905 .3099 Mdot
.016 w
.38905 .3099 m
.38906 .30988 L
s
.008 w
.38906 .30988 Mdot
.016 w
.38906 .30988 m
.38909 .30983 L
s
1 .694 0 r
.008 w
.38909 .30983 Mdot
.016 w
.38909 .30983 m
.38912 .30977 L
s
.008 w
.38912 .30977 Mdot
.016 w
.38912 .30977 m
.38916 .30971 L
s
.008 w
.38916 .30971 Mdot
.016 w
.38916 .30971 m
.38917 .30969 L
s
.008 w
.38917 .30969 Mdot
.016 w
.38917 .30969 m
.38916 .30972 L
s
.008 w
.38916 .30972 Mdot
.016 w
.38916 .30972 m
.38911 .3098 L
s
1 .693 0 r
.008 w
.38911 .3098 Mdot
.016 w
.38911 .3098 m
.38902 .30997 L
s
.008 w
.38902 .30997 Mdot
.016 w
.38902 .30997 m
.38889 .31022 L
s
.008 w
.38889 .31022 Mdot
.016 w
.38889 .31022 m
.38872 .31056 L
s
.008 w
.38872 .31056 Mdot
.016 w
.38872 .31056 m
.38852 .31094 L
s
.008 w
.38852 .31094 Mdot
.016 w
.38852 .31094 m
.3883 .31134 L
s
1 .692 0 r
.008 w
.3883 .31134 Mdot
.016 w
.3883 .31134 m
.38807 .31171 L
s
.008 w
.38807 .31171 Mdot
.016 w
.38807 .31171 m
.38784 .31205 L
s
.008 w
.38784 .31205 Mdot
.016 w
.38784 .31205 m
.38761 .31232 L
s
.008 w
.38761 .31232 Mdot
.016 w
.38761 .31232 m
.38738 .31254 L
s
.008 w
.38738 .31254 Mdot
.016 w
.38738 .31254 m
.38718 .31269 L
s
.008 w
.38718 .31269 Mdot
.016 w
.38718 .31269 m
.387 .31274 L
s
1 .691 0 r
.008 w
.387 .31274 Mdot
.016 w
.387 .31274 m
.38686 .3127 L
s
.008 w
.38686 .3127 Mdot
.016 w
.38686 .3127 m
.38678 .31257 L
s
.008 w
.38678 .31257 Mdot
.016 w
.38678 .31257 m
.38675 .31238 L
s
.008 w
.38675 .31238 Mdot
.016 w
.38675 .31238 m
.38678 .31214 L
s
.008 w
.38678 .31214 Mdot
.016 w
.38678 .31214 m
.38686 .31183 L
s
1 .69 0 r
.008 w
.38686 .31183 Mdot
.016 w
.38686 .31183 m
.38699 .31142 L
s
.008 w
.38699 .31142 Mdot
.016 w
.38699 .31142 m
.38712 .31104 L
s
.008 w
.38712 .31104 Mdot
.016 w
.38712 .31104 m
.38722 .31064 L
s
.008 w
.38722 .31064 Mdot
.016 w
.38722 .31064 m
.38726 .31028 L
s
.008 w
.38726 .31028 Mdot
.016 w
.38726 .31028 m
.3872 .30995 L
s
1 .689 0 r
.008 w
.3872 .30995 Mdot
.016 w
.3872 .30995 m
.38702 .30963 L
s
.008 w
.38702 .30963 Mdot
.016 w
.38702 .30963 m
.3867 .3093 L
s
.008 w
.3867 .3093 Mdot
.016 w
.3867 .3093 m
.38622 .30893 L
s
.008 w
.38622 .30893 Mdot
.016 w
.38622 .30893 m
.38557 .3085 L
s
.008 w
.38557 .3085 Mdot
.016 w
.38557 .3085 m
.38474 .30796 L
s
.008 w
.38474 .30796 Mdot
.016 w
.38474 .30796 m
.38373 .30731 L
s
1 .688 0 r
.008 w
.38373 .30731 Mdot
.016 w
.38373 .30731 m
.38254 .30657 L
s
.008 w
.38254 .30657 Mdot
.016 w
.38254 .30657 m
.38117 .30572 L
s
.008 w
.38117 .30572 Mdot
.016 w
.38117 .30572 m
.37969 .30478 L
s
.008 w
.37969 .30478 Mdot
.016 w
.37969 .30478 m
.37799 .30371 L
s
.008 w
.37799 .30371 Mdot
.016 w
.37799 .30371 m
.37607 .30258 L
s
1 .687 0 r
.008 w
.37607 .30258 Mdot
.016 w
.37607 .30258 m
.37389 .30126 L
s
.008 w
.37389 .30126 Mdot
.016 w
.37389 .30126 m
.37166 .29986 L
s
.008 w
.37166 .29986 Mdot
.016 w
.37166 .29986 m
.36913 .29828 L
s
.008 w
.36913 .29828 Mdot
.016 w
.36913 .29828 m
.36659 .29652 L
s
.008 w
.36659 .29652 Mdot
.016 w
.36659 .29652 m
.36392 .2947 L
s
1 .686 0 r
.008 w
.36392 .2947 Mdot
.016 w
.36392 .2947 m
.36094 .29264 L
s
.008 w
.36094 .29264 Mdot
.016 w
.36094 .29264 m
.35826 .29054 L
s
.008 w
.35826 .29054 Mdot
.016 w
.35826 .29054 m
.3552 .28843 L
s
.008 w
.3552 .28843 Mdot
.016 w
.3552 .28843 m
.35193 .2861 L
s
.008 w
.35193 .2861 Mdot
.016 w
.35193 .2861 m
.34872 .2839 L
s
1 .685 0 r
.008 w
.34872 .2839 Mdot
.016 w
.34872 .2839 m
.345 .28153 L
s
.008 w
.345 .28153 Mdot
.016 w
.345 .28153 m
.34198 .27904 L
s
.008 w
.34198 .27904 Mdot
.016 w
.34198 .27904 m
.33869 .27671 L
s
.008 w
.33869 .27671 Mdot
.016 w
.33869 .27671 m
.33535 .27426 L
s
.008 w
.33535 .27426 Mdot
.016 w
.33535 .27426 m
.33283 .27221 L
s
.008 w
.33283 .27221 Mdot
.016 w
.33283 .27221 m
.33023 .27029 L
s
1 .684 0 r
.008 w
.33023 .27029 Mdot
.016 w
.33023 .27029 m
.32812 .26861 L
s
.008 w
.32812 .26861 Mdot
.016 w
.32812 .26861 m
.32626 .2673 L
s
.008 w
.32626 .2673 Mdot
.016 w
.32626 .2673 m
.3247 .26612 L
s
.008 w
.3247 .26612 Mdot
.016 w
.3247 .26612 m
.32363 .26534 L
s
.008 w
.32363 .26534 Mdot
.016 w
.32363 .26534 m
.32284 .26474 L
s
1 .683 0 r
.008 w
.32284 .26474 Mdot
.016 w
.32284 .26474 m
.32233 .26429 L
s
.008 w
.32233 .26429 Mdot
.016 w
.32233 .26429 m
.32215 .264 L
s
.008 w
.32215 .264 Mdot
.016 w
.32215 .264 m
.32226 .26394 L
s
.008 w
.32226 .26394 Mdot
.016 w
.32226 .26394 m
.32258 .26406 L
s
.008 w
.32258 .26406 Mdot
.016 w
.32258 .26406 m
.32303 .26434 L
s
1 .682 0 r
.008 w
.32303 .26434 Mdot
.016 w
.32303 .26434 m
.32352 .26468 L
s
.008 w
.32352 .26468 Mdot
.016 w
.32352 .26468 m
.32398 .26502 L
s
.008 w
.32398 .26502 Mdot
.016 w
.32398 .26502 m
.32438 .26532 L
s
.008 w
.32438 .26532 Mdot
.016 w
.32438 .26532 m
.32472 .26556 L
s
.008 w
.32472 .26556 Mdot
.016 w
.32472 .26556 m
.32498 .2657 L
s
1 .681 0 r
.008 w
.32498 .2657 Mdot
.016 w
.32498 .2657 m
.32513 .26571 L
s
.008 w
.32513 .26571 Mdot
.016 w
.32513 .26571 m
.3252 .26566 L
s
.008 w
.3252 .26566 Mdot
.016 w
.3252 .26566 m
.32523 .26559 L
s
.008 w
.32523 .26559 Mdot
.016 w
.32523 .26559 m
.32523 .26555 L
s
.008 w
.32523 .26555 Mdot
.016 w
.32523 .26555 m
.32522 .26552 L
s
.008 w
.32522 .26552 Mdot
.016 w
.32522 .26552 m
.32518 .26552 L
s
1 .68 0 r
.008 w
.32518 .26552 Mdot
.016 w
.32518 .26552 m
.32514 .26552 L
s
.008 w
.32514 .26552 Mdot
.016 w
.32514 .26552 m
.32511 .26552 L
s
.008 w
.32511 .26552 Mdot
.016 w
.32511 .26552 m
.3251 .26552 L
s
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.3251 .26552 L
s
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.3251 .26552 L
s
1 .679 0 r
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.3251 .26552 L
s
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.3251 .26552 L
s
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.3251 .26552 L
s
.008 w
.3251 .26552 Mdot
.016 w
.3251 .26552 m
.32509 .26552 L
s
.008 w
.32509 .26552 Mdot
.016 w
.32509 .26552 m
.32508 .26552 L
s
1 .678 0 r
.008 w
.32508 .26552 Mdot
.016 w
.32508 .26552 m
.32505 .26552 L
s
.008 w
.32505 .26552 Mdot
.016 w
.32505 .26552 m
.32502 .26552 L
s
.008 w
.32502 .26552 Mdot
.016 w
.32502 .26552 m
.32498 .26552 L
s
.008 w
.32498 .26552 Mdot
.016 w
.32498 .26552 m
.32497 .26552 L
s
.008 w
.32497 .26552 Mdot
.016 w
.32497 .26552 m
.32498 .26552 L
s
1 .677 0 r
.008 w
.32498 .26552 Mdot
.016 w
.32498 .26552 m
.32503 .26552 L
s
.008 w
.32503 .26552 Mdot
.016 w
.32503 .26552 m
.32512 .26552 L
s
.008 w
.32512 .26552 Mdot
.016 w
.32512 .26552 m
.32525 .26552 L
s
.008 w
.32525 .26552 Mdot
.016 w
.32525 .26552 m
.32542 .26552 L
s
.008 w
.32542 .26552 Mdot
.016 w
.32542 .26552 m
.32562 .26552 L
s
.008 w
.32562 .26552 Mdot
.016 w
.32562 .26552 m
.32583 .26549 L
s
1 .676 0 r
.008 w
.32583 .26549 Mdot
.016 w
.32583 .26549 m
.32607 .26544 L
s
.008 w
.32607 .26544 Mdot
.016 w
.32607 .26544 m
.3263 .26537 L
s
.008 w
.3263 .26537 Mdot
.016 w
.3263 .26537 m
.32653 .26531 L
s
.008 w
.32653 .26531 Mdot
.016 w
.32653 .26531 m
.32676 .26527 L
s
.008 w
.32676 .26527 Mdot
.016 w
.32676 .26527 m
.32696 .2653 L
s
1 .675 0 r
.008 w
.32696 .2653 Mdot
.016 w
.32696 .2653 m
.32714 .26539 L
s
.008 w
.32714 .26539 Mdot
.016 w
.32714 .26539 m
.32728 .26556 L
s
.008 w
.32728 .26556 Mdot
.016 w
.32728 .26556 m
.32738 .26583 L
s
.008 w
.32738 .26583 Mdot
.016 w
.32738 .26583 m
.32744 .26618 L
s
.008 w
.32744 .26618 Mdot
.016 w
.32744 .26618 m
.32746 .26659 L
s
1 .674 0 r
.008 w
.32746 .26659 Mdot
.016 w
.32746 .26659 m
.32744 .26703 L
s
.008 w
.32744 .26703 Mdot
.016 w
.32744 .26703 m
.32741 .26748 L
s
.008 w
.32741 .26748 Mdot
.016 w
.32741 .26748 m
.32737 .26794 L
s
.008 w
.32737 .26794 Mdot
.016 w
.32737 .26794 m
.32734 .26841 L
s
.008 w
.32734 .26841 Mdot
.016 w
.32734 .26841 m
.32733 .26886 L
s
.008 w
.32733 .26886 Mdot
.016 w
.32733 .26886 m
.32733 .26926 L
s
1 .673 0 r
.008 w
.32733 .26926 Mdot
.016 w
.32733 .26926 m
.32733 .2696 L
s
.008 w
.32733 .2696 Mdot
.016 w
.32733 .2696 m
.32733 .26987 L
s
.008 w
.32733 .26987 Mdot
.016 w
.32733 .26987 m
.32733 .27005 L
s
.008 w
.32733 .27005 Mdot
.016 w
.32733 .27005 m
.32733 .27015 L
s
.008 w
.32733 .27015 Mdot
.016 w
.32733 .27015 m
.32733 .27016 L
s
1 .672 0 r
.008 w
.32733 .27016 Mdot
.016 w
.32733 .27016 m
.32733 .27012 L
s
.008 w
.32733 .27012 Mdot
.016 w
.32733 .27012 m
.32733 .27003 L
s
.008 w
.32733 .27003 Mdot
.016 w
.32733 .27003 m
.32733 .26995 L
s
.008 w
.32733 .26995 Mdot
.016 w
.32733 .26995 m
.32733 .26989 L
s
.008 w
.32733 .26989 Mdot
.016 w
.32733 .26989 m
.32733 .26987 L
s
1 .671 0 r
.008 w
.32733 .26987 Mdot
.016 w
.32733 .26987 m
.32733 .26989 L
s
.008 w
.32733 .26989 Mdot
.016 w
.32733 .26989 m
.32733 .26991 L
s
.008 w
.32733 .26991 Mdot
.016 w
.32733 .26991 m
.32733 .26993 L
s
.008 w
.32733 .26993 Mdot
.016 w
.32733 .26993 m
.32733 .26995 L
s
.008 w
.32733 .26995 Mdot
.016 w
.32733 .26995 m
.32733 .26997 L
s
1 .67 0 r
.008 w
.32733 .26997 Mdot
.016 w
.32733 .26997 m
.32733 .26998 L
s
.008 w
.32733 .26998 Mdot
.016 w
.32733 .26998 m
.32733 .27 L
s
.008 w
.32733 .27 Mdot
.016 w
.32733 .27 m
.32733 .27002 L
s
.008 w
.32733 .27002 Mdot
.016 w
.32733 .27002 m
.32733 .27005 L
s
.008 w
.32733 .27005 Mdot
.016 w
.32733 .27005 m
.32736 .27007 L
s
.008 w
.32736 .27007 Mdot
.016 w
.32736 .27007 m
.32743 .27008 L
s
1 .669 0 r
.008 w
.32743 .27008 Mdot
.016 w
.32743 .27008 m
.32754 .27008 L
s
.008 w
.32754 .27008 Mdot
.016 w
.32754 .27008 m
.32764 .27008 L
s
.008 w
.32764 .27008 Mdot
.016 w
.32764 .27008 m
.32772 .27007 L
s
.008 w
.32772 .27007 Mdot
.016 w
.32772 .27007 m
.32775 .27006 L
s
.008 w
.32775 .27006 Mdot
.016 w
.32775 .27006 m
.32769 .27006 L
s
1 .668 0 r
.008 w
.32769 .27006 Mdot
.016 w
.32769 .27006 m
.32753 .27006 L
s
.008 w
.32753 .27006 Mdot
.016 w
.32753 .27006 m
.32723 .27006 L
s
.008 w
.32723 .27006 Mdot
.016 w
.32723 .27006 m
.32681 .27006 L
s
.008 w
.32681 .27006 Mdot
.016 w
.32681 .27006 m
.32626 .27009 L
s
.008 w
.32626 .27009 Mdot
.016 w
.32626 .27009 m
.32558 .27014 L
s
1 .667 0 r
.008 w
.32558 .27014 Mdot
.016 w
.32558 .27014 m
.32479 .27021 L
s
.008 w
.32479 .27021 Mdot
.016 w
.32479 .27021 m
.32386 .27028 L
s
.008 w
.32386 .27028 Mdot
.016 w
.32386 .27028 m
.32281 .27034 L
s
.008 w
.32281 .27034 Mdot
.016 w
.32281 .27034 m
.32157 .27037 L
s
.008 w
.32157 .27037 Mdot
.016 w
.32157 .27037 m
.32014 .27035 L
s
1 .666 0 r
.008 w
.32014 .27035 Mdot
.016 w
.32014 .27035 m
.31849 .27025 L
s
.008 w
.31849 .27025 Mdot
.016 w
.31849 .27025 m
.31677 .27005 L
s
.008 w
.31677 .27005 Mdot
.016 w
.31677 .27005 m
.31482 .26974 L
s
.008 w
.31482 .26974 Mdot
.016 w
.31482 .26974 m
.31261 .2693 L
s
.008 w
.31261 .2693 Mdot
.016 w
.31261 .2693 m
.31049 .26872 L
s
.008 w
.31049 .26872 Mdot
.016 w
.31049 .26872 m
.30808 .268 L
s
1 .665 0 r
.008 w
.30808 .268 Mdot
.016 w
.30808 .268 m
.30555 .26717 L
s
.008 w
.30555 .26717 Mdot
.016 w
.30555 .26717 m
.30272 .26623 L
s
.008 w
.30272 .26623 Mdot
.016 w
.30272 .26623 m
.30019 .26516 L
s
.008 w
.30019 .26516 Mdot
.016 w
.30019 .26516 m
.29731 .26394 L
s
.008 w
.29731 .26394 Mdot
.016 w
.29731 .26394 m
.29441 .26261 L
s
1 .664 0 r
.008 w
.29441 .26261 Mdot
.016 w
.29441 .26261 m
.29132 .2612 L
s
.008 w
.29132 .2612 Mdot
.016 w
.29132 .2612 m
.28823 .25964 L
s
.008 w
.28823 .25964 Mdot
.016 w
.28823 .25964 m
.28567 .25802 L
s
.008 w
.28567 .25802 Mdot
.016 w
.28567 .25802 m
.28316 .2563 L
s
.008 w
.28316 .2563 Mdot
.016 w
.28316 .2563 m
.28085 .25466 L
s
1 .663 0 r
.008 w
.28085 .25466 Mdot
.016 w
.28085 .25466 m
.27885 .25302 L
s
.008 w
.27885 .25302 Mdot
.016 w
.27885 .25302 m
.27711 .25139 L
s
.008 w
.27711 .25139 Mdot
.016 w
.27711 .25139 m
.27573 .24994 L
s
.008 w
.27573 .24994 Mdot
.016 w
.27573 .24994 m
.27446 .24847 L
s
.008 w
.27446 .24847 Mdot
.016 w
.27446 .24847 m
.27343 .24713 L
s
1 .662 0 r
.008 w
.27343 .24713 Mdot
.016 w
.27343 .24713 m
.27244 .24576 L
s
.008 w
.27244 .24576 Mdot
.016 w
.27244 .24576 m
.27155 .24464 L
s
.008 w
.27155 .24464 Mdot
.016 w
.27155 .24464 m
.27049 .24356 L
s
.008 w
.27049 .24356 Mdot
.016 w
.27049 .24356 m
.26923 .2425 L
s
.008 w
.26923 .2425 Mdot
.016 w
.26923 .2425 m
.26773 .24145 L
s
.008 w
.26773 .24145 Mdot
.016 w
.26773 .24145 m
.2659 .24042 L
s
1 .661 0 r
.008 w
.2659 .24042 Mdot
.016 w
.2659 .24042 m
.26384 .23938 L
s
.008 w
.26384 .23938 Mdot
.016 w
.26384 .23938 m
.26203 .23839 L
s
.008 w
.26203 .23839 Mdot
.016 w
.26203 .23839 m
.25963 .23726 L
s
.008 w
.25963 .23726 Mdot
.016 w
.25963 .23726 m
.25691 .23599 L
s
.008 w
.25691 .23599 Mdot
.016 w
.25691 .23599 m
.254 .23455 L
s
1 .66 0 r
.008 w
.254 .23455 Mdot
.016 w
.254 .23455 m
.25061 .23287 L
s
.008 w
.25061 .23287 Mdot
.016 w
.25061 .23287 m
.2473 .23109 L
s
.008 w
.2473 .23109 Mdot
.016 w
.2473 .23109 m
.24353 .22892 L
s
.008 w
.24353 .22892 Mdot
.016 w
.24353 .22892 m
.24044 .22688 L
s
.008 w
.24044 .22688 Mdot
.016 w
.24044 .22688 m
.23705 .22461 L
s
1 .659 0 r
.008 w
.23705 .22461 Mdot
.016 w
.23705 .22461 m
.23388 .22227 L
s
.008 w
.23388 .22227 Mdot
.016 w
.23388 .22227 m
.23063 .21972 L
s
.008 w
.23063 .21972 Mdot
.016 w
.23063 .21972 m
.22792 .21752 L
s
.008 w
.22792 .21752 Mdot
.016 w
.22792 .21752 m
.22521 .21515 L
s
.008 w
.22521 .21515 Mdot
.016 w
.22521 .21515 m
.22261 .21265 L
s
1 .658 0 r
.008 w
.22261 .21265 Mdot
.016 w
.22261 .21265 m
.22036 .21052 L
s
.008 w
.22036 .21052 Mdot
.016 w
.22036 .21052 m
.21826 .20828 L
s
.008 w
.21826 .20828 Mdot
.016 w
.21826 .20828 m
.21635 .20612 L
s
.008 w
.21635 .20612 Mdot
.016 w
.21635 .20612 m
.2147 .20401 L
s
.008 w
.2147 .20401 Mdot
.016 w
.2147 .20401 m
.21333 .20206 L
s
.008 w
.21333 .20206 Mdot
.016 w
.21333 .20206 m
.21225 .20016 L
s
1 .657 0 r
.008 w
.21225 .20016 Mdot
.016 w
.21225 .20016 m
.21149 .19852 L
s
.008 w
.21149 .19852 Mdot
.016 w
.21149 .19852 m
.211 .19702 L
s
.008 w
.211 .19702 Mdot
.016 w
.211 .19702 m
.21074 .19567 L
s
.008 w
.21074 .19567 Mdot
.016 w
.21074 .19567 m
.21067 .19453 L
s
.008 w
.21067 .19453 Mdot
.016 w
.21067 .19453 m
.21074 .19345 L
s
1 .656 0 r
.008 w
.21074 .19345 Mdot
.016 w
.21074 .19345 m
.21093 .19257 L
s
.008 w
.21093 .19257 Mdot
.016 w
.21093 .19257 m
.2112 .19182 L
s
.008 w
.2112 .19182 Mdot
.016 w
.2112 .19182 m
.2115 .19123 L
s
.008 w
.2115 .19123 Mdot
.016 w
.2115 .19123 m
.2118 .19079 L
s
.008 w
.2118 .19079 Mdot
.016 w
.2118 .19079 m
.21208 .19051 L
s
1 .655 0 r
.008 w
.21208 .19051 Mdot
.016 w
.21208 .19051 m
.2123 .19037 L
s
.008 w
.2123 .19037 Mdot
.016 w
.2123 .19037 m
.21246 .19035 L
s
.008 w
.21246 .19035 Mdot
.016 w
.21246 .19035 m
.21256 .19041 L
s
.008 w
.21256 .19041 Mdot
.016 w
.21256 .19041 m
.21261 .19051 L
s
.008 w
.21261 .19051 Mdot
.016 w
.21261 .19051 m
.21261 .19063 L
s
.008 w
.21261 .19063 Mdot
.016 w
.21261 .19063 m
.21258 .19074 L
s
1 .654 0 r
.008 w
.21258 .19074 Mdot
.016 w
.21258 .19074 m
.21253 .19083 L
s
.008 w
.21253 .19083 Mdot
.016 w
.21253 .19083 m
.21247 .19089 L
s
.008 w
.21247 .19089 Mdot
.016 w
.21247 .19089 m
.2124 .19096 L
s
.008 w
.2124 .19096 Mdot
.016 w
.2124 .19096 m
.21231 .19102 L
s
.008 w
.21231 .19102 Mdot
.016 w
.21231 .19102 m
.21224 .19109 L
s
1 .653 0 r
.008 w
.21224 .19109 Mdot
.016 w
.21224 .19109 m
.21217 .19112 L
s
.008 w
.21217 .19112 Mdot
.016 w
.21217 .19112 m
.21214 .19111 L
s
.008 w
.21214 .19111 Mdot
.016 w
.21214 .19111 m
.21215 .19105 L
s
.008 w
.21215 .19105 Mdot
.016 w
.21215 .19105 m
.21224 .19091 L
s
.008 w
.21224 .19091 Mdot
.016 w
.21224 .19091 m
.21245 .19068 L
s
1 .652 0 r
.008 w
.21245 .19068 Mdot
.016 w
.21245 .19068 m
.2128 .19035 L
s
.008 w
.2128 .19035 Mdot
.016 w
.2128 .19035 m
.2133 .18992 L
s
.008 w
.2133 .18992 Mdot
.016 w
.2133 .18992 m
.21394 .1894 L
s
.008 w
.21394 .1894 Mdot
.016 w
.21394 .1894 m
.21473 .18878 L
s
.008 w
.21473 .18878 Mdot
.016 w
.21473 .18878 m
.21568 .18805 L
s
1 .651 0 r
.008 w
.21568 .18805 Mdot
.016 w
.21568 .18805 m
.21684 .1872 L
s
.008 w
.21684 .1872 Mdot
.016 w
.21684 .1872 m
.21817 .18619 L
s
.008 w
.21817 .18619 Mdot
.016 w
.21817 .18619 m
.21971 .18506 L
s
.008 w
.21971 .18506 Mdot
.016 w
.21971 .18506 m
.22132 .18383 L
s
.008 w
.22132 .18383 Mdot
.016 w
.22132 .18383 m
.22304 .18251 L
s
.008 w
.22304 .18251 Mdot
.016 w
.22304 .18251 m
.22478 .1812 L
s
1 .65 0 r
.008 w
.22478 .1812 Mdot
.016 w
.22478 .1812 m
.22643 .17993 L
s
.008 w
.22643 .17993 Mdot
.016 w
.22643 .17993 m
.22801 .17869 L
s
.008 w
.22801 .17869 Mdot
.016 w
.22801 .17869 m
.2294 .17752 L
s
.008 w
.2294 .17752 Mdot
.016 w
.2294 .17752 m
.23061 .17653 L
s
.008 w
.23061 .17653 Mdot
.016 w
.23061 .17653 m
.23163 .1756 L
s
1 .649 0 r
.008 w
.23163 .1756 Mdot
.016 w
.23163 .1756 m
.23244 .17481 L
s
.008 w
.23244 .17481 Mdot
.016 w
.23244 .17481 m
.23307 .17413 L
s
.008 w
.23307 .17413 Mdot
.016 w
.23307 .17413 m
.23355 .17358 L
s
.008 w
.23355 .17358 Mdot
.016 w
.23355 .17358 m
.23388 .17318 L
s
.008 w
.23388 .17318 Mdot
.016 w
.23388 .17318 m
.23409 .17295 L
s
1 .648 0 r
.008 w
.23409 .17295 Mdot
.016 w
.23409 .17295 m
.23418 .17288 L
s
.008 w
.23418 .17288 Mdot
.016 w
.23418 .17288 m
.23417 .17295 L
s
.008 w
.23417 .17295 Mdot
.016 w
.23417 .17295 m
.23408 .17312 L
s
.008 w
.23408 .17312 Mdot
.016 w
.23408 .17312 m
.23394 .17334 L
s
.008 w
.23394 .17334 Mdot
.016 w
.23394 .17334 m
.23377 .17356 L
s
1 .647 0 r
.008 w
.23377 .17356 Mdot
.016 w
.23377 .17356 m
.23363 .17369 L
s
.008 w
.23363 .17369 Mdot
.016 w
.23363 .17369 m
.23353 .17367 L
s
.008 w
.23353 .17367 Mdot
.016 w
.23353 .17367 m
.23349 .17342 L
s
.008 w
.23349 .17342 Mdot
.016 w
.23349 .17342 m
.23352 .1729 L
s
.008 w
.23352 .1729 Mdot
.016 w
.23352 .1729 m
.23363 .17211 L
s
.008 w
.23363 .17211 Mdot
.016 w
.23363 .17211 m
.23385 .17105 L
s
1 .646 0 r
.008 w
.23385 .17105 Mdot
.016 w
.23385 .17105 m
.23417 .1697 L
s
.008 w
.23417 .1697 Mdot
.016 w
.23417 .1697 m
.2346 .16826 L
s
.008 w
.2346 .16826 Mdot
.016 w
.2346 .16826 m
.23514 .16646 L
s
.008 w
.23514 .16646 Mdot
.016 w
.23514 .16646 m
.23576 .1646 L
s
.008 w
.23576 .1646 Mdot
.016 w
.23576 .1646 m
.23646 .16256 L
s
1 .645 0 r
.008 w
.23646 .16256 Mdot
.016 w
.23646 .16256 m
.23724 .16028 L
s
.008 w
.23724 .16028 Mdot
.016 w
.23724 .16028 m
.23811 .15818 L
s
.008 w
.23811 .15818 Mdot
.016 w
.23811 .15818 m
.23909 .1558 L
s
.008 w
.23909 .1558 Mdot
.016 w
.23909 .1558 m
.24024 .15353 L
s
.008 w
.24024 .15353 Mdot
.016 w
.24024 .15353 m
.24148 .15134 L
s
1 .644 0 r
.008 w
.24148 .15134 Mdot
.016 w
.24148 .15134 m
.24285 .14903 L
s
.008 w
.24285 .14903 Mdot
.016 w
.24285 .14903 m
.24434 .14689 L
s
.008 w
.24434 .14689 Mdot
.016 w
.24434 .14689 m
.2459 .14476 L
s
.008 w
.2459 .14476 Mdot
.016 w
.2459 .14476 m
.24755 .14264 L
s
.008 w
.24755 .14264 Mdot
.016 w
.24755 .14264 m
.24917 .14086 L
s
1 .643 0 r
.008 w
.24917 .14086 Mdot
.016 w
.24917 .14086 m
.25077 .13909 L
s
.008 w
.25077 .13909 Mdot
.016 w
.25077 .13909 m
.25236 .1374 L
s
.008 w
.25236 .1374 Mdot
.016 w
.25236 .1374 m
.25386 .13592 L
s
.008 w
.25386 .13592 Mdot
.016 w
.25386 .13592 m
.25538 .13442 L
s
.008 w
.25538 .13442 Mdot
.016 w
.25538 .13442 m
.25673 .13323 L
s
.008 w
.25673 .13323 Mdot
.016 w
.25673 .13323 m
.258 .13218 L
s
1 .642 0 r
.008 w
.258 .13218 Mdot
.016 w
.258 .13218 m
.25916 .13132 L
s
.008 w
.25916 .13132 Mdot
.016 w
.25916 .13132 m
.26017 .13065 L
s
.008 w
.26017 .13065 Mdot
.016 w
.26017 .13065 m
.26105 .13018 L
s
.008 w
.26105 .13018 Mdot
.016 w
.26105 .13018 m
.26184 .12988 L
s
.008 w
.26184 .12988 Mdot
.016 w
.26184 .12988 m
.26258 .1297 L
s
1 .641 0 r
.008 w
.26258 .1297 Mdot
.016 w
.26258 .1297 m
.26339 .12961 L
s
.008 w
.26339 .12961 Mdot
.016 w
.26339 .12961 m
.26435 .12956 L
s
.008 w
.26435 .12956 Mdot
.016 w
.26435 .12956 m
.26554 .12951 L
s
.008 w
.26554 .12951 Mdot
.016 w
.26554 .12951 m
.26702 .12945 L
s
.008 w
.26702 .12945 Mdot
.016 w
.26702 .12945 m
.26877 .12936 L
s
1 .64 0 r
.008 w
.26877 .12936 Mdot
.016 w
.26877 .12936 m
.27081 .12928 L
s
.008 w
.27081 .12928 Mdot
.016 w
.27081 .12928 m
.27315 .12921 L
s
.008 w
.27315 .12921 Mdot
.016 w
.27315 .12921 m
.27559 .12916 L
s
.008 w
.27559 .12916 Mdot
.016 w
.27559 .12916 m
.27804 .12915 L
s
.008 w
.27804 .12915 Mdot
.016 w
.27804 .12915 m
.28049 .12916 L
s
.008 w
.28049 .12916 Mdot
.016 w
.28049 .12916 m
.28287 .12917 L
s
1 .639 0 r
.008 w
.28287 .12917 Mdot
.016 w
.28287 .12917 m
.28517 .1292 L
s
.008 w
.28517 .1292 Mdot
.016 w
.28517 .1292 m
.28721 .12922 L
s
.008 w
.28721 .12922 Mdot
.016 w
.28721 .12922 m
.28898 .12925 L
s
.008 w
.28898 .12925 Mdot
.016 w
.28898 .12925 m
.2906 .1293 L
s
.008 w
.2906 .1293 Mdot
.016 w
.2906 .1293 m
.29192 .12938 L
s
1 .638 0 r
.008 w
.29192 .12938 Mdot
.016 w
.29192 .12938 m
.29299 .12949 L
s
.008 w
.29299 .12949 Mdot
.016 w
.29299 .12949 m
.29378 .12962 L
s
.008 w
.29378 .12962 Mdot
.016 w
.29378 .12962 m
.29432 .12978 L
s
.008 w
.29432 .12978 Mdot
.016 w
.29432 .12978 m
.29465 .12999 L
s
.008 w
.29465 .12999 Mdot
.016 w
.29465 .12999 m
.29485 .13025 L
s
1 .637 0 r
.008 w
.29485 .13025 Mdot
.016 w
.29485 .13025 m
.29496 .13054 L
s
.008 w
.29496 .13054 Mdot
.016 w
.29496 .13054 m
.29503 .13085 L
s
.008 w
.29503 .13085 Mdot
.016 w
.29503 .13085 m
.2951 .13118 L
s
.008 w
.2951 .13118 Mdot
.016 w
.2951 .13118 m
.2952 .13151 L
s
.008 w
.2952 .13151 Mdot
.016 w
.2952 .13151 m
.29535 .1318 L
s
1 .636 0 r
.008 w
.29535 .1318 Mdot
.016 w
.29535 .1318 m
.2955 .13205 L
s
.008 w
.2955 .13205 Mdot
.016 w
.2955 .13205 m
.29563 .13225 L
s
.008 w
.29563 .13225 Mdot
.016 w
.29563 .13225 m
.29572 .13238 L
s
.008 w
.29572 .13238 Mdot
.016 w
.29572 .13238 m
.29578 .13245 L
s
.008 w
.29578 .13245 Mdot
.016 w
.29578 .13245 m
.29579 .13247 L
s
.008 w
.29579 .13247 Mdot
.016 w
.29579 .13247 m
.29578 .13246 L
s
1 .635 0 r
.008 w
.29578 .13246 Mdot
.016 w
.29578 .13246 m
.29574 .1324 L
s
.008 w
.29574 .1324 Mdot
.016 w
.29574 .1324 m
.2957 .13231 L
s
.008 w
.2957 .13231 Mdot
.016 w
.2957 .13231 m
.29568 .1322 L
s
.008 w
.29568 .1322 Mdot
.016 w
.29568 .1322 m
.29566 .1321 L
s
.008 w
.29566 .1321 Mdot
.016 w
.29566 .1321 m
.29566 .132 L
s
1 .634 0 r
.008 w
.29566 .132 Mdot
.016 w
.29566 .132 m
.29566 .13191 L
s
.008 w
.29566 .13191 Mdot
.016 w
.29566 .13191 m
.29566 .13184 L
s
.008 w
.29566 .13184 Mdot
.016 w
.29566 .13184 m
.29566 .13179 L
s
.008 w
.29566 .13179 Mdot
.016 w
.29566 .13179 m
.29566 .13175 L
s
.008 w
.29566 .13175 Mdot
.016 w
.29566 .13175 m
.29567 .13179 L
s
1 .633 0 r
.008 w
.29567 .13179 Mdot
.016 w
.29567 .13179 m
.29571 .13185 L
s
.008 w
.29571 .13185 Mdot
.016 w
.29571 .13185 m
.2958 .13189 L
s
.008 w
.2958 .13189 Mdot
.016 w
.2958 .13189 m
.29592 .13187 L
s
.008 w
.29592 .13187 Mdot
.016 w
.29592 .13187 m
.29606 .13176 L
s
.008 w
.29606 .13176 Mdot
.016 w
.29606 .13176 m
.29623 .13158 L
s
1 .632 0 r
.008 w
.29623 .13158 Mdot
.016 w
.29623 .13158 m
.29638 .13134 L
s
.008 w
.29638 .13134 Mdot
.016 w
.29638 .13134 m
.29647 .13108 L
s
.008 w
.29647 .13108 Mdot
.016 w
.29647 .13108 m
.29643 .13086 L
s
.008 w
.29643 .13086 Mdot
.016 w
.29643 .13086 m
.29618 .13071 L
s
.008 w
.29618 .13071 Mdot
.016 w
.29618 .13071 m
.29569 .13064 L
s
.008 w
.29569 .13064 Mdot
.016 w
.29569 .13064 m
.29488 .1307 L
s
1 .631 0 r
.008 w
.29488 .1307 Mdot
.016 w
.29488 .1307 m
.29373 .13093 L
s
.008 w
.29373 .13093 Mdot
.016 w
.29373 .13093 m
.29217 .13137 L
s
.008 w
.29217 .13137 Mdot
.016 w
.29217 .13137 m
.29033 .13204 L
s
.008 w
.29033 .13204 Mdot
.016 w
.29033 .13204 m
.28802 .13296 L
s
.008 w
.28802 .13296 Mdot
.016 w
.28802 .13296 m
.28509 .13413 L
s
1 .63 0 r
.008 w
.28509 .13413 Mdot
.016 w
.28509 .13413 m
.28211 .13545 L
s
.008 w
.28211 .13545 Mdot
.016 w
.28211 .13545 m
.27837 .13699 L
s
.008 w
.27837 .13699 Mdot
.016 w
.27837 .13699 m
.27441 .13864 L
s
.008 w
.27441 .13864 Mdot
.016 w
.27441 .13864 m
.27056 .14043 L
s
.008 w
.27056 .14043 Mdot
.016 w
.27056 .14043 m
.26577 .14237 L
s
1 .629 0 r
.008 w
.26577 .14237 Mdot
.016 w
.26577 .14237 m
.26166 .14437 L
s
.008 w
.26166 .14437 Mdot
.016 w
.26166 .14437 m
.25665 .14654 L
s
.008 w
.25665 .14654 Mdot
.016 w
.25665 .14654 m
.25233 .14872 L
s
.008 w
.25233 .14872 Mdot
.016 w
.25233 .14872 m
.24766 .15107 L
s
.008 w
.24766 .15107 Mdot
.016 w
.24766 .15107 m
.24275 .15358 L
s
1 .628 0 r
.008 w
.24275 .15358 Mdot
.016 w
.24275 .15358 m
.23856 .15632 L
s
.008 w
.23856 .15632 Mdot
.016 w
.23856 .15632 m
.23413 .15912 L
s
.008 w
.23413 .15912 Mdot
.016 w
.23413 .15912 m
.23011 .16213 L
s
.008 w
.23011 .16213 Mdot
.016 w
.23011 .16213 m
.22601 .16545 L
s
.008 w
.22601 .16545 Mdot
.016 w
.22601 .16545 m
.2225 .16891 L
s
.008 w
.2225 .16891 Mdot
.016 w
.2225 .16891 m
.219 .17263 L
s
1 .627 0 r
.008 w
.219 .17263 Mdot
.016 w
.219 .17263 m
.21568 .17661 L
s
.008 w
.21568 .17661 Mdot
.016 w
.21568 .17661 m
.21267 .18077 L
s
.008 w
.21267 .18077 Mdot
.016 w
.21267 .18077 m
.20981 .18506 L
s
.008 w
.20981 .18506 Mdot
.016 w
.20981 .18506 m
.20698 .18956 L
s
.008 w
.20698 .18956 Mdot
.016 w
.20698 .18956 m
.20423 .19421 L
s
1 .626 0 r
.008 w
.20423 .19421 Mdot
.016 w
.20423 .19421 m
.20142 .19916 L
s
.008 w
.20142 .19916 Mdot
.016 w
.20142 .19916 m
.19871 .20386 L
s
.008 w
.19871 .20386 Mdot
.016 w
.19871 .20386 m
.1958 .2089 L
s
.008 w
.1958 .2089 Mdot
.016 w
.1958 .2089 m
.19294 .21437 L
s
.008 w
.19294 .21437 Mdot
.016 w
.19294 .21437 m
.19021 .21911 L
s
1 .625 0 r
.008 w
.19021 .21911 Mdot
.016 w
.19021 .21911 m
.18718 .22443 L
s
.008 w
.18718 .22443 Mdot
.016 w
.18718 .22443 m
.18422 .22966 L
s
.008 w
.18422 .22966 Mdot
.016 w
.18422 .22966 m
.18102 .23515 L
s
.008 w
.18102 .23515 Mdot
.016 w
.18102 .23515 m
.17812 .24028 L
s
.008 w
.17812 .24028 Mdot
.016 w
.17812 .24028 m
.17508 .24548 L
s
.008 w
.17508 .24548 Mdot
.016 w
.17508 .24548 m
.1722 .25078 L
s
1 .624 0 r
.008 w
.1722 .25078 Mdot
.016 w
.1722 .25078 m
.16938 .25556 L
s
.008 w
.16938 .25556 Mdot
.016 w
.16938 .25556 m
.16645 .26067 L
s
.008 w
.16645 .26067 Mdot
.016 w
.16645 .26067 m
.16386 .26532 L
s
.008 w
.16386 .26532 Mdot
.016 w
.16386 .26532 m
.16106 .27002 L
s
.008 w
.16106 .27002 Mdot
.016 w
.16106 .27002 m
.15841 .27461 L
s
1 .623 0 r
.008 w
.15841 .27461 Mdot
.016 w
.15841 .27461 m
.15569 .27927 L
s
.008 w
.15569 .27927 Mdot
.016 w
.15569 .27927 m
.15295 .28414 L
s
.008 w
.15295 .28414 Mdot
.016 w
.15295 .28414 m
.1503 .2886 L
s
.008 w
.1503 .2886 Mdot
.016 w
.1503 .2886 m
.14754 .29352 L
s
.008 w
.14754 .29352 Mdot
.016 w
.14754 .29352 m
.14506 .29821 L
s
1 .622 0 r
.008 w
.14506 .29821 Mdot
.016 w
.14506 .29821 m
.14248 .30313 L
s
.008 w
.14248 .30313 Mdot
.016 w
.14248 .30313 m
.14022 .30788 L
s
.008 w
.14022 .30788 Mdot
.016 w
.14022 .30788 m
.13803 .31274 L
s
.008 w
.13803 .31274 Mdot
.016 w
.13803 .31274 m
.13603 .31752 L
s
.008 w
.13603 .31752 Mdot
.016 w
.13603 .31752 m
.13418 .32273 L
s
1 .621 0 r
.008 w
.13418 .32273 Mdot
.016 w
.13418 .32273 m
.13258 .32718 L
s
.008 w
.13258 .32718 Mdot
.016 w
.13258 .32718 m
.13111 .33202 L
s
.008 w
.13111 .33202 Mdot
.016 w
.13111 .33202 m
.12983 .3369 L
s
.008 w
.12983 .3369 Mdot
.016 w
.12983 .3369 m
.12874 .34206 L
s
.008 w
.12874 .34206 Mdot
.016 w
.12874 .34206 m
.12782 .34716 L
s
.008 w
.12782 .34716 Mdot
.016 w
.12782 .34716 m
.12703 .3525 L
s
1 .62 0 r
.008 w
.12703 .3525 Mdot
.016 w
.12703 .3525 m
.12638 .35785 L
s
.008 w
.12638 .35785 Mdot
.016 w
.12638 .35785 m
.12579 .36369 L
s
.008 w
.12579 .36369 Mdot
.016 w
.12579 .36369 m
.12526 .369 L
s
.008 w
.12526 .369 Mdot
.016 w
.12526 .369 m
.1248 .37405 L
s
.008 w
.1248 .37405 Mdot
.016 w
.1248 .37405 m
.12441 .37938 L
s
1 .619 0 r
.008 w
.12441 .37938 Mdot
.016 w
.12441 .37938 m
.12408 .3839 L
s
.008 w
.12408 .3839 Mdot
.016 w
.12408 .3839 m
.12379 .38836 L
s
.008 w
.12379 .38836 Mdot
.016 w
.12379 .38836 m
.12354 .39276 L
s
.008 w
.12354 .39276 Mdot
.016 w
.12354 .39276 m
.12332 .39596 L
s
.008 w
.12332 .39596 Mdot
.016 w
.12332 .39596 m
.1231 .39874 L
s
1 .618 0 r
.008 w
.1231 .39874 Mdot
.016 w
.1231 .39874 m
.12297 .40048 L
s
.008 w
.12297 .40048 Mdot
.016 w
.12297 .40048 m
.1229 .40224 L
s
.008 w
.1229 .40224 Mdot
.016 w
.1229 .40224 m
.12294 .40356 L
s
.008 w
.12294 .40356 Mdot
.016 w
.12294 .40356 m
.12313 .40447 L
s
.008 w
.12313 .40447 Mdot
.016 w
.12313 .40447 m
.12344 .40498 L
s
1 .617 0 r
.008 w
.12344 .40498 Mdot
.016 w
.12344 .40498 m
.12388 .40534 L
s
.008 w
.12388 .40534 Mdot
.016 w
.12388 .40534 m
.12451 .40566 L
s
.008 w
.12451 .40566 Mdot
.016 w
.12451 .40566 m
.12543 .40605 L
s
.008 w
.12543 .40605 Mdot
.016 w
.12543 .40605 m
.12662 .40652 L
s
.008 w
.12662 .40652 Mdot
.016 w
.12662 .40652 m
.12763 .40718 L
s
.008 w
.12763 .40718 Mdot
.016 w
.12763 .40718 m
.12895 .40817 L
s
1 .616 0 r
.008 w
.12895 .40817 Mdot
.016 w
.12895 .40817 m
.12984 .40951 L
s
.008 w
.12984 .40951 Mdot
.016 w
.12984 .40951 m
.13119 .4111 L
s
.008 w
.13119 .4111 Mdot
.016 w
.13119 .4111 m
.13239 .41301 L
s
.008 w
.13239 .41301 Mdot
.016 w
.13239 .41301 m
.13346 .41508 L
s
.008 w
.13346 .41508 Mdot
.016 w
.13346 .41508 m
.13437 .41759 L
s
1 .615 0 r
.008 w
.13437 .41759 Mdot
.016 w
.13437 .41759 m
.13522 .42028 L
s
.008 w
.13522 .42028 Mdot
.016 w
.13522 .42028 m
.13589 .42331 L
s
.008 w
.13589 .42331 Mdot
.016 w
.13589 .42331 m
.1363 .42702 L
s
.008 w
.1363 .42702 Mdot
.016 w
.1363 .42702 m
.13648 .43043 L
s
.008 w
.13648 .43043 Mdot
.016 w
.13648 .43043 m
.13639 .43404 L
s
1 .614 0 r
.008 w
.13639 .43404 Mdot
.016 w
.13639 .43404 m
.13608 .43762 L
s
.008 w
.13608 .43762 Mdot
.016 w
.13608 .43762 m
.13556 .44166 L
s
.008 w
.13556 .44166 Mdot
.016 w
.13556 .44166 m
.13478 .44647 L
s
.008 w
.13478 .44647 Mdot
.016 w
.13478 .44647 m
.13368 .45027 L
s
.008 w
.13368 .45027 Mdot
.016 w
.13368 .45027 m
.13226 .45441 L
s
1 .613 0 r
.008 w
.13226 .45441 Mdot
.016 w
.13226 .45441 m
.13092 .45866 L
s
.008 w
.13092 .45866 Mdot
.016 w
.13092 .45866 m
.12932 .46293 L
s
.008 w
.12932 .46293 Mdot
.016 w
.12932 .46293 m
.12718 .46713 L
s
.008 w
.12718 .46713 Mdot
.016 w
.12718 .46713 m
.12541 .47097 L
s
.008 w
.12541 .47097 Mdot
.016 w
.12541 .47097 m
.1233 .47485 L
s
.008 w
.1233 .47485 Mdot
.016 w
.1233 .47485 m
.1216 .47848 L
s
1 .612 0 r
.008 w
.1216 .47848 Mdot
.016 w
.1216 .47848 m
.11928 .48233 L
s
.008 w
.11928 .48233 Mdot
.016 w
.11928 .48233 m
.11749 .48546 L
s
.008 w
.11749 .48546 Mdot
.016 w
.11749 .48546 m
.11597 .48838 L
s
.008 w
.11597 .48838 Mdot
.016 w
.11597 .48838 m
.11427 .49168 L
s
.008 w
.11427 .49168 Mdot
.016 w
.11427 .49168 m
.113 .49422 L
s
1 .611 0 r
.008 w
.113 .49422 Mdot
.016 w
.113 .49422 m
.11193 .49682 L
s
.008 w
.11193 .49682 Mdot
.016 w
.11193 .49682 m
.11112 .49911 L
s
.008 w
.11112 .49911 Mdot
.016 w
.11112 .49911 m
.11059 .50111 L
s
.008 w
.11059 .50111 Mdot
.016 w
.11059 .50111 m
.11028 .50283 L
s
.008 w
.11028 .50283 Mdot
.016 w
.11028 .50283 m
.11014 .50418 L
s
1 .61 0 r
.008 w
.11014 .50418 Mdot
.016 w
.11014 .50418 m
.11013 .50528 L
s
.008 w
.11013 .50528 Mdot
.016 w
.11013 .50528 m
.11019 .50624 L
s
.008 w
.11019 .50624 Mdot
.016 w
.11019 .50624 m
.1103 .50705 L
s
.008 w
.1103 .50705 Mdot
.016 w
.1103 .50705 m
.1104 .50776 L
s
.008 w
.1104 .50776 Mdot
.016 w
.1104 .50776 m
.11045 .5083 L
s
1 .609 0 r
.008 w
.11045 .5083 Mdot
.016 w
.11045 .5083 m
.11049 .50879 L
s
.008 w
.11049 .50879 Mdot
.016 w
.11049 .50879 m
.11053 .50921 L
s
.008 w
.11053 .50921 Mdot
.016 w
.11053 .50921 m
.11054 .50955 L
s
.008 w
.11054 .50955 Mdot
.016 w
.11054 .50955 m
.11051 .50983 L
s
.008 w
.11051 .50983 Mdot
.016 w
.11051 .50983 m
.11047 .51005 L
s
.008 w
.11047 .51005 Mdot
.016 w
.11047 .51005 m
.11042 .5103 L
s
1 .608 0 r
.008 w
.11042 .5103 Mdot
.016 w
.11042 .5103 m
.11034 .51058 L
s
.008 w
.11034 .51058 Mdot
.016 w
.11034 .51058 m
.11022 .5109 L
s
.008 w
.11022 .5109 Mdot
.016 w
.11022 .5109 m
.11007 .51123 L
s
.008 w
.11007 .51123 Mdot
.016 w
.11007 .51123 m
.10992 .51149 L
s
.008 w
.10992 .51149 Mdot
.016 w
.10992 .51149 m
.10981 .51172 L
s
1 .607 0 r
.008 w
.10981 .51172 Mdot
.016 w
.10981 .51172 m
.10976 .51186 L
s
.008 w
.10976 .51186 Mdot
.016 w
.10976 .51186 m
.10977 .51194 L
s
.008 w
.10977 .51194 Mdot
.016 w
.10977 .51194 m
.10983 .51194 L
s
.008 w
.10983 .51194 Mdot
.016 w
.10983 .51194 m
.10995 .51192 L
s
.008 w
.10995 .51192 Mdot
.016 w
.10995 .51192 m
.11013 .51191 L
s
1 .606 0 r
.008 w
.11013 .51191 Mdot
.016 w
.11013 .51191 m
.1104 .51191 L
s
.008 w
.1104 .51191 Mdot
.016 w
.1104 .51191 m
.1107 .51194 L
s
.008 w
.1107 .51194 Mdot
.016 w
.1107 .51194 m
.11102 .51199 L
s
.008 w
.11102 .51199 Mdot
.016 w
.11102 .51199 m
.11138 .51201 L
s
.008 w
.11138 .51201 Mdot
.016 w
.11138 .51201 m
.11171 .51202 L
s
.008 w
.11171 .51202 Mdot
.016 w
.11171 .51202 m
.11204 .51202 L
s
1 .605 0 r
.008 w
.11204 .51202 Mdot
.016 w
.11204 .51202 m
.11235 .51201 L
s
.008 w
.11235 .51201 Mdot
.016 w
.11235 .51201 m
.11262 .512 L
s
.008 w
.11262 .512 Mdot
.016 w
.11262 .512 m
.11282 .51199 L
s
.008 w
.11282 .51199 Mdot
.016 w
.11282 .51199 m
.11293 .51198 L
s
.008 w
.11293 .51198 Mdot
.016 w
.11293 .51198 m
.11297 .51197 L
s
1 .604 0 r
.008 w
.11297 .51197 Mdot
.016 w
.11297 .51197 m
.11297 .51196 L
s
.008 w
.11297 .51196 Mdot
.016 w
.11297 .51196 m
.11295 .51197 L
s
.008 w
.11295 .51197 Mdot
.016 w
.11295 .51197 m
.11292 .51197 L
s
.008 w
.11292 .51197 Mdot
.016 w
.11292 .51197 m
.11287 .51197 L
s
.008 w
.11287 .51197 Mdot
.016 w
.11287 .51197 m
.11284 .51197 L
s
1 .603 0 r
.008 w
.11284 .51197 Mdot
.016 w
.11284 .51197 m
.11282 .51197 L
s
.008 w
.11282 .51197 Mdot
.016 w
.11282 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
1 .602 0 r
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51197 L
s
.008 w
.11281 .51197 Mdot
.016 w
.11281 .51197 m
.11281 .51196 L
s
1 .601 0 r
.008 w
.11281 .51196 Mdot
.016 w
.11281 .51196 m
.11282 .51193 L
s
.008 w
.11282 .51193 Mdot
.016 w
.11282 .51193 m
.11284 .51185 L
s
.008 w
.11284 .51185 Mdot
.016 w
.11284 .51185 m
.11288 .51174 L
s
.008 w
.11288 .51174 Mdot
.016 w
.11288 .51174 m
.11293 .51163 L
s
.008 w
.11293 .51163 Mdot
.016 w
.11293 .51163 m
.11295 .51156 L
s
1 .6 0 r
.008 w
.11295 .51156 Mdot
.016 w
.11295 .51156 m
.11295 .51154 L
s
.008 w
.11295 .51154 Mdot
.016 w
.11295 .51154 m
.11291 .51162 L
s
.008 w
.11291 .51162 Mdot
.016 w
.11291 .51162 m
.11282 .51182 L
s
.008 w
.11282 .51182 Mdot
.016 w
.11282 .51182 m
.11266 .51217 L
s
.008 w
.11266 .51217 Mdot
.016 w
.11266 .51217 m
.11245 .51267 L
s
1 .599 0 r
.008 w
.11245 .51267 Mdot
.016 w
.11245 .51267 m
.1122 .51332 L
s
.008 w
.1122 .51332 Mdot
.016 w
.1122 .51332 m
.11192 .5141 L
s
.008 w
.11192 .5141 Mdot
.016 w
.11192 .5141 m
.11163 .51501 L
s
.008 w
.11163 .51501 Mdot
.016 w
.11163 .51501 m
.11132 .51601 L
s
.008 w
.11132 .51601 Mdot
.016 w
.11132 .51601 m
.11106 .51711 L
s
1 .598 0 r
.008 w
.11106 .51711 Mdot
.016 w
.11106 .51711 m
.11075 .51834 L
s
.008 w
.11075 .51834 Mdot
.016 w
.11075 .51834 m
.11044 .51971 L
s
.008 w
.11044 .51971 Mdot
.016 w
.11044 .51971 m
.11013 .52124 L
s
.008 w
.11013 .52124 Mdot
.016 w
.11013 .52124 m
.10987 .52273 L
s
.008 w
.10987 .52273 Mdot
.016 w
.10987 .52273 m
.10967 .52433 L
s
.008 w
.10967 .52433 Mdot
.016 w
.10967 .52433 m
.10955 .52601 L
s
1 .597 0 r
.008 w
.10955 .52601 Mdot
.016 w
.10955 .52601 m
.10951 .52773 L
s
.008 w
.10951 .52773 Mdot
.016 w
.10951 .52773 m
.10956 .52925 L
s
.008 w
.10956 .52925 Mdot
.016 w
.10956 .52925 m
.10967 .53079 L
s
.008 w
.10967 .53079 Mdot
.016 w
.10967 .53079 m
.10984 .53235 L
s
.008 w
.10984 .53235 Mdot
.016 w
.10984 .53235 m
.11004 .53384 L
s
1 .596 0 r
.008 w
.11004 .53384 Mdot
.016 w
.11004 .53384 m
.11025 .53524 L
s
.008 w
.11025 .53524 Mdot
.016 w
.11025 .53524 m
.11047 .53655 L
s
.008 w
.11047 .53655 Mdot
.016 w
.11047 .53655 m
.11069 .5377 L
s
.008 w
.11069 .5377 Mdot
.016 w
.11069 .5377 m
.11091 .53864 L
s
.008 w
.11091 .53864 Mdot
.016 w
.11091 .53864 m
.11112 .5394 L
s
1 .595 0 r
.008 w
.11112 .5394 Mdot
.016 w
.11112 .5394 m
.11133 .53999 L
s
.008 w
.11133 .53999 Mdot
.016 w
.11133 .53999 m
.11152 .5404 L
s
.008 w
.11152 .5404 Mdot
.016 w
.11152 .5404 m
.11168 .54064 L
s
.008 w
.11168 .54064 Mdot
.016 w
.11168 .54064 m
.11179 .54075 L
s
.008 w
.11179 .54075 Mdot
.016 w
.11179 .54075 m
.11185 .54076 L
s
1 .594 0 r
.008 w
.11185 .54076 Mdot
.016 w
.11185 .54076 m
.11187 .54072 L
s
.008 w
.11187 .54072 Mdot
.016 w
.11187 .54072 m
.11186 .54064 L
s
.008 w
.11186 .54064 Mdot
.016 w
.11186 .54064 m
.11183 .54054 L
s
.008 w
.11183 .54054 Mdot
.016 w
.11183 .54054 m
.11179 .54045 L
s
.008 w
.11179 .54045 Mdot
.016 w
.11179 .54045 m
.11176 .54039 L
s
.008 w
.11176 .54039 Mdot
.016 w
.11176 .54039 m
.11174 .54036 L
s
1 .593 0 r
.008 w
.11174 .54036 Mdot
.016 w
.11174 .54036 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .592 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .591 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .59 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .589 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .588 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .587 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .586 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .585 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .584 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .583 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .582 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .581 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .58 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .579 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .578 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .577 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .576 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .575 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .574 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .573 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .572 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .571 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .57 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .569 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .568 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .567 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .566 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .565 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .564 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .563 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .562 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .561 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .56 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .559 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .558 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .557 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .556 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .555 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .554 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .553 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .552 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .551 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .55 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .549 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .548 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .547 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .546 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .545 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .544 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .543 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .542 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .541 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .54 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .539 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .538 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .537 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .536 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .535 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .534 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .533 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .532 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .531 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .53 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .529 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .528 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .527 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .526 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .525 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .524 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .523 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .522 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .521 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .52 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .519 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .518 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .517 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .516 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .515 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .514 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .513 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .512 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .511 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .51 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .509 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .508 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .507 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .506 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .505 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .504 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .503 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .502 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .501 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .5 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .499 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .498 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .497 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .496 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .495 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .494 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .493 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .492 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .491 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .49 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .489 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .488 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .487 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .486 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .485 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .484 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .483 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .482 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .481 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .48 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .479 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .478 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .477 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .476 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .475 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .474 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .473 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .472 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .471 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .47 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .469 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .468 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .467 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .466 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .465 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .464 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .463 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .462 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11173 .54033 L
s
1 .461 0 r
.008 w
.11173 .54033 Mdot
.016 w
.11173 .54033 m
.1117 .54031 L
s
.008 w
.1117 .54031 Mdot
.016 w
.1117 .54031 m
.11166 .54027 L
s
.008 w
.11166 .54027 Mdot
.016 w
.11166 .54027 m
.11163 .54023 L
s
.008 w
.11163 .54023 Mdot
.016 w
.11163 .54023 m
.11161 .54022 L
s
.008 w
.11161 .54022 Mdot
.016 w
.11161 .54022 m
.11162 .54023 L
s
1 .46 0 r
.008 w
.11162 .54023 Mdot
.016 w
.11162 .54023 m
.11167 .54028 L
s
.008 w
.11167 .54028 Mdot
.016 w
.11167 .54028 m
.11177 .54037 L
s
.008 w
.11177 .54037 Mdot
.016 w
.11177 .54037 m
.11192 .54051 L
s
.008 w
.11192 .54051 Mdot
.016 w
.11192 .54051 m
.1121 .54068 L
s
.008 w
.1121 .54068 Mdot
.016 w
.1121 .54068 m
.11232 .54088 L
s
1 .459 0 r
.008 w
.11232 .54088 Mdot
.016 w
.11232 .54088 m
.11256 .54111 L
s
.008 w
.11256 .54111 Mdot
.016 w
.11256 .54111 m
.11282 .54135 L
s
.008 w
.11282 .54135 Mdot
.016 w
.11282 .54135 m
.1131 .54159 L
s
.008 w
.1131 .54159 Mdot
.016 w
.1131 .54159 m
.11338 .54182 L
s
.008 w
.11338 .54182 Mdot
.016 w
.11338 .54182 m
.11363 .54206 L
s
1 .458 0 r
.008 w
.11363 .54206 Mdot
.016 w
.11363 .54206 m
.11384 .54227 L
s
.008 w
.11384 .54227 Mdot
.016 w
.11384 .54227 m
.114 .54245 L
s
.008 w
.114 .54245 Mdot
.016 w
.114 .54245 m
.11411 .54261 L
s
.008 w
.11411 .54261 Mdot
.016 w
.11411 .54261 m
.11415 .54271 L
s
.008 w
.11415 .54271 Mdot
.016 w
.11415 .54271 m
.11413 .54278 L
s
.008 w
.11413 .54278 Mdot
.016 w
.11413 .54278 m
.11407 .5428 L
s
1 .457 0 r
.008 w
.11407 .5428 Mdot
.016 w
.11407 .5428 m
.11399 .54279 L
s
.008 w
.11399 .54279 Mdot
.016 w
.11399 .54279 m
.11391 .54275 L
s
.008 w
.11391 .54275 Mdot
.016 w
.11391 .54275 m
.11385 .54272 L
s
.008 w
.11385 .54272 Mdot
.016 w
.11385 .54272 m
.1138 .54269 L
s
.008 w
.1138 .54269 Mdot
.016 w
.1138 .54269 m
.11379 .54267 L
s
1 .456 0 r
.008 w
.11379 .54267 Mdot
.016 w
.11379 .54267 m
.11379 .54267 L
s
.008 w
.11379 .54267 Mdot
.016 w
.11379 .54267 m
.11379 .54267 L
s
.008 w
.11379 .54267 Mdot
.016 w
.11379 .54267 m
.11381 .54267 L
s
.008 w
.11381 .54267 Mdot
.016 w
.11381 .54267 m
.11385 .54267 L
s
.008 w
.11385 .54267 Mdot
.016 w
.11385 .54267 m
.11391 .54266 L
s
1 .455 0 r
.008 w
.11391 .54266 Mdot
.016 w
.11391 .54266 m
.11398 .54266 L
s
.008 w
.11398 .54266 Mdot
.016 w
.11398 .54266 m
.11406 .54265 L
s
.008 w
.11406 .54265 Mdot
.016 w
.11406 .54265 m
.11413 .54265 L
s
.008 w
.11413 .54265 Mdot
.016 w
.11413 .54265 m
.11419 .54265 L
s
.008 w
.11419 .54265 Mdot
.016 w
.11419 .54265 m
.11423 .54264 L
s
.008 w
.11423 .54264 Mdot
.016 w
.11423 .54264 m
.11424 .54264 L
s
1 .454 0 r
.008 w
.11424 .54264 Mdot
.016 w
.11424 .54264 m
.11422 .54264 L
s
.008 w
.11422 .54264 Mdot
.016 w
.11422 .54264 m
.1142 .54264 L
s
.008 w
.1142 .54264 Mdot
.016 w
.1142 .54264 m
.11418 .54265 L
s
.008 w
.11418 .54265 Mdot
.016 w
.11418 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
1 .453 0 r
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
1 .452 0 r
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
1 .451 0 r
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
1 .45 0 r
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
1 .449 0 r
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11417 .54265 L
s
.008 w
.11417 .54265 Mdot
.016 w
.11417 .54265 m
.11418 .54266 L
s
.008 w
.11418 .54266 Mdot
.016 w
.11418 .54266 m
.11421 .54269 L
s
.008 w
.11421 .54269 Mdot
.016 w
.11421 .54269 m
.11425 .54273 L
s
1 .448 0 r
.008 w
.11425 .54273 Mdot
.016 w
.11425 .54273 m
.11428 .54276 L
s
.008 w
.11428 .54276 Mdot
.016 w
.11428 .54276 m
.1143 .54278 L
s
.008 w
.1143 .54278 Mdot
.016 w
.1143 .54278 m
.11429 .54277 L
s
.008 w
.11429 .54277 Mdot
.016 w
.11429 .54277 m
.11424 .54272 L
s
.008 w
.11424 .54272 Mdot
.016 w
.11424 .54272 m
.11414 .54262 L
s
1 .447 0 r
.008 w
.11414 .54262 Mdot
.016 w
.11414 .54262 m
.114 .54249 L
s
.008 w
.114 .54249 Mdot
.016 w
.114 .54249 m
.11381 .54231 L
s
.008 w
.11381 .54231 Mdot
.016 w
.11381 .54231 m
.1136 .54211 L
s
.008 w
.1136 .54211 Mdot
.016 w
.1136 .54211 m
.11336 .54189 L
s
.008 w
.11336 .54189 Mdot
.016 w
.11336 .54189 m
.11311 .54165 L
s
.008 w
.11311 .54165 Mdot
.016 w
.11311 .54165 m
.11286 .54141 L
s
1 .446 0 r
.008 w
.11286 .54141 Mdot
.016 w
.11286 .54141 m
.11262 .54117 L
s
.008 w
.11262 .54117 Mdot
.016 w
.11262 .54117 m
.11238 .54094 L
s
.008 w
.11238 .54094 Mdot
.016 w
.11238 .54094 m
.11215 .54072 L
s
.008 w
.11215 .54072 Mdot
.016 w
.11215 .54072 m
.11196 .54054 L
s
.008 w
.11196 .54054 Mdot
.016 w
.11196 .54054 m
.1118 .54039 L
s
1 .445 0 r
.008 w
.1118 .54039 Mdot
.016 w
.1118 .54039 m
.11169 .54029 L
s
.008 w
.11169 .54029 Mdot
.016 w
.11169 .54029 m
.11162 .54023 L
s
.008 w
.11162 .54023 Mdot
.016 w
.11162 .54023 m
.11161 .54021 L
s
.008 w
.11161 .54021 Mdot
.016 w
.11161 .54021 m
.11162 .54023 L
s
.008 w
.11162 .54023 Mdot
.016 w
.11162 .54023 m
.11165 .54026 L
s
1 .444 0 r
.008 w
.11165 .54026 Mdot
.016 w
.11165 .54026 m
.11169 .5403 L
s
.008 w
.11169 .5403 Mdot
.016 w
.11169 .5403 m
.11173 .54033 L
s
.008 w
.11173 .54033 Mdot
.016 w
.11173 .54033 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .443 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .442 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .441 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .44 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .439 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
1 .438 0 r
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11174 .54035 L
s
.008 w
.11174 .54035 Mdot
.016 w
.11174 .54035 m
.11173 .54033 L
s
1 .437 0 r
.008 w
.11173 .54033 Mdot
.016 w
.11173 .54033 m
.1117 .54031 L
s
.008 w
.1117 .54031 Mdot
.016 w
.1117 .54031 m
.11166 .54027 L
s
.008 w
.11166 .54027 Mdot
.016 w
.11166 .54027 m
.11163 .54023 L
s
.008 w
.11163 .54023 Mdot
.016 w
.11163 .54023 m
.11161 .54022 L
s
.008 w
.11161 .54022 Mdot
.016 w
.11161 .54022 m
.11162 .54023 L
s
1 .436 0 r
.008 w
.11162 .54023 Mdot
.016 w
.11162 .54023 m
.11167 .54028 L
s
.008 w
.11167 .54028 Mdot
.016 w
.11167 .54028 m
.11177 .54037 L
s
.008 w
.11177 .54037 Mdot
.016 w
.11177 .54037 m
.11191 .54051 L
s
.008 w
.11191 .54051 Mdot
.016 w
.11191 .54051 m
.1121 .54068 L
s
.008 w
.1121 .54068 Mdot
.016 w
.1121 .54068 m
.11231 .54088 L
s
.008 w
.11231 .54088 Mdot
.016 w
.11231 .54088 m
.11255 .54111 L
s
1 .435 0 r
.008 w
.11255 .54111 Mdot
.016 w
.11255 .54111 m
.1128 .54135 L
s
.008 w
.1128 .54135 Mdot
.016 w
.1128 .54135 m
.11305 .54159 L
s
.008 w
.11305 .54159 Mdot
.016 w
.11305 .54159 m
.11329 .54183 L
s
.008 w
.11329 .54183 Mdot
.016 w
.11329 .54183 m
.11353 .54206 L
s
.008 w
.11353 .54206 Mdot
.016 w
.11353 .54206 m
.11376 .54228 L
s
1 .434 0 r
.008 w
.11376 .54228 Mdot
.016 w
.11376 .54228 m
.11396 .54243 L
s
.008 w
.11396 .54243 Mdot
.016 w
.11396 .54243 m
.11412 .54246 L
s
.008 w
.11412 .54246 Mdot
.016 w
.11412 .54246 m
.11424 .54239 L
s
.008 w
.11424 .54239 Mdot
.016 w
.11424 .54239 m
.11431 .54225 L
s
.008 w
.11431 .54225 Mdot
.016 w
.11431 .54225 m
.11433 .54207 L
s
1 .433 0 r
.008 w
.11433 .54207 Mdot
.016 w
.11433 .54207 m
.11431 .54191 L
s
.008 w
.11431 .54191 Mdot
.016 w
.11431 .54191 m
.11425 .54182 L
s
.008 w
.11425 .54182 Mdot
.016 w
.11425 .54182 m
.11416 .54192 L
s
.008 w
.11416 .54192 Mdot
.016 w
.11416 .54192 m
.11408 .54229 L
s
.008 w
.11408 .54229 Mdot
.016 w
.11408 .54229 m
.11399 .54296 L
s
1 .432 0 r
.008 w
.11399 .54296 Mdot
.016 w
.11399 .54296 m
.11393 .54401 L
s
.008 w
.11393 .54401 Mdot
.016 w
.11393 .54401 m
.11389 .5455 L
s
.008 w
.11389 .5455 Mdot
.016 w
.11389 .5455 m
.11388 .54751 L
s
.008 w
.11388 .54751 Mdot
.016 w
.11388 .54751 m
.11392 .54959 L
s
.008 w
.11392 .54959 Mdot
.016 w
.11392 .54959 m
.11401 .55216 L
s
.008 w
.11401 .55216 Mdot
.016 w
.11401 .55216 m
.11416 .55558 L
s
1 .431 0 r
.008 w
.11416 .55558 Mdot
.016 w
.11416 .55558 m
.11437 .55856 L
s
.008 w
.11437 .55856 Mdot
.016 w
.11437 .55856 m
.11465 .56275 L
s
.008 w
.11465 .56275 Mdot
.016 w
.11465 .56275 m
.11498 .56677 L
s
.008 w
.11498 .56677 Mdot
.016 w
.11498 .56677 m
.11536 .57106 L
s
.008 w
.11536 .57106 Mdot
.016 w
.11536 .57106 m
.1158 .57475 L
s
1 .43 0 r
.008 w
.1158 .57475 Mdot
.016 w
.1158 .57475 m
.1163 .57922 L
s
.008 w
.1163 .57922 Mdot
.016 w
.1163 .57922 m
.11678 .58414 L
s
.008 w
.11678 .58414 Mdot
.016 w
.11678 .58414 m
.11731 .58821 L
s
.008 w
.11731 .58821 Mdot
.016 w
.11731 .58821 m
.11787 .5927 L
s
.008 w
.11787 .5927 Mdot
.016 w
.11787 .5927 m
.11847 .59742 L
s
1 .429 0 r
.008 w
.11847 .59742 Mdot
.016 w
.11847 .59742 m
.11906 .60201 L
s
.008 w
.11906 .60201 Mdot
.016 w
.11906 .60201 m
.11968 .60731 L
s
.008 w
.11968 .60731 Mdot
.016 w
.11968 .60731 m
.12035 .61128 L
s
.008 w
.12035 .61128 Mdot
.016 w
.12035 .61128 m
.12098 .61617 L
s
.008 w
.12098 .61617 Mdot
.016 w
.12098 .61617 m
.12167 .62225 L
s
1 .428 0 r
.008 w
.12167 .62225 Mdot
.016 w
.12167 .62225 m
.12241 .6267 L
s
.008 w
.12241 .6267 Mdot
.016 w
.12241 .6267 m
.12311 .63265 L
s
.008 w
.12311 .63265 Mdot
.016 w
.12311 .63265 m
.12398 .63744 L
s
.008 w
.12398 .63744 Mdot
.016 w
.12398 .63744 m
.12474 .64402 L
s
.008 w
.12474 .64402 Mdot
.016 w
.12474 .64402 m
.12557 .64952 L
s
.008 w
.12557 .64952 Mdot
.016 w
.12557 .64952 m
.12649 .65443 L
s
1 .427 0 r
.008 w
.12649 .65443 Mdot
.016 w
.12649 .65443 m
.12736 .66009 L
s
.008 w
.12736 .66009 Mdot
.016 w
.12736 .66009 m
.12831 .66679 L
s
.008 w
.12831 .66679 Mdot
.016 w
.12831 .66679 m
.12935 .67167 L
s
.008 w
.12935 .67167 Mdot
.016 w
.12935 .67167 m
.13026 .67735 L
s
.008 w
.13026 .67735 Mdot
.016 w
.13026 .67735 m
.13128 .6832 L
s
1 .426 0 r
.008 w
.13128 .6832 Mdot
.016 w
.13128 .6832 m
.13229 .68939 L
s
.008 w
.13229 .68939 Mdot
.016 w
.13229 .68939 m
.13336 .69497 L
s
.008 w
.13336 .69497 Mdot
.016 w
.13336 .69497 m
.1344 .69935 L
s
.008 w
.1344 .69935 Mdot
.016 w
.1344 .69935 m
.13551 .70447 L
s
.008 w
.13551 .70447 Mdot
.016 w
.13551 .70447 m
.13649 .70849 L
s
1 .425 0 r
.008 w
.13649 .70849 Mdot
.016 w
.13649 .70849 m
.13749 .71307 L
s
.008 w
.13749 .71307 Mdot
.016 w
.13749 .71307 m
.13833 .7161 L
s
.008 w
.13833 .7161 Mdot
.016 w
.13833 .7161 m
.1391 .71909 L
s
.008 w
.1391 .71909 Mdot
.016 w
.1391 .71909 m
.13978 .72169 L
s
.008 w
.13978 .72169 Mdot
.016 w
.13978 .72169 m
.1403 .7235 L
s
.008 w
.1403 .7235 Mdot
.016 w
.1403 .7235 m
.14072 .72491 L
s
1 .424 0 r
.008 w
.14072 .72491 Mdot
.016 w
.14072 .72491 m
.14103 .72596 L
s
.008 w
.14103 .72596 Mdot
.016 w
.14103 .72596 m
.14125 .72662 L
s
.008 w
.14125 .72662 Mdot
.016 w
.14125 .72662 m
.14138 .7269 L
s
.008 w
.14138 .7269 Mdot
.016 w
.14138 .7269 m
.14143 .72692 L
s
.008 w
.14143 .72692 Mdot
.016 w
.14143 .72692 m
.14143 .72682 L
s
1 .423 0 r
.008 w
.14143 .72682 Mdot
.016 w
.14143 .72682 m
.14138 .72664 L
s
.008 w
.14138 .72664 Mdot
.016 w
.14138 .72664 m
.14133 .72644 L
s
.008 w
.14133 .72644 Mdot
.016 w
.14133 .72644 m
.14127 .7263 L
s
.008 w
.14127 .7263 Mdot
.016 w
.14127 .7263 m
.14123 .72629 L
s
.008 w
.14123 .72629 Mdot
.016 w
.14123 .72629 m
.14119 .72643 L
s
1 .422 0 r
.008 w
.14119 .72643 Mdot
.016 w
.14119 .72643 m
.14117 .72675 L
s
.008 w
.14117 .72675 Mdot
.016 w
.14117 .72675 m
.14115 .72719 L
s
.008 w
.14115 .72719 Mdot
.016 w
.14115 .72719 m
.14114 .7277 L
s
.008 w
.14114 .7277 Mdot
.016 w
.14114 .7277 m
.14112 .72828 L
s
.008 w
.14112 .72828 Mdot
.016 w
.14112 .72828 m
.14111 .72875 L
s
1 .421 0 r
.008 w
.14111 .72875 Mdot
.016 w
.14111 .72875 m
.14109 .72921 L
s
.008 w
.14109 .72921 Mdot
.016 w
.14109 .72921 m
.14108 .72969 L
s
.008 w
.14108 .72969 Mdot
.016 w
.14108 .72969 m
.14107 .7301 L
s
.008 w
.14107 .7301 Mdot
.016 w
.14107 .7301 m
.14107 .73055 L
s
.008 w
.14107 .73055 Mdot
.016 w
.14107 .73055 m
.14106 .73096 L
s
.008 w
.14106 .73096 Mdot
.016 w
.14106 .73096 m
.14106 .73124 L
s
1 .42 0 r
.008 w
.14106 .73124 Mdot
.016 w
.14106 .73124 m
.14106 .73139 L
s
.008 w
.14106 .73139 Mdot
.016 w
.14106 .73139 m
.14106 .73146 L
s
.008 w
.14106 .73146 Mdot
.016 w
.14106 .73146 m
.14106 .73149 L
s
.008 w
.14106 .73149 Mdot
.016 w
.14106 .73149 m
.14107 .73149 L
s
.008 w
.14107 .73149 Mdot
.016 w
.14107 .73149 m
.14107 .73145 L
s
1 .419 0 r
.008 w
.14107 .73145 Mdot
.016 w
.14107 .73145 m
.14108 .73138 L
s
.008 w
.14108 .73138 Mdot
.016 w
.14108 .73138 m
.14109 .73132 L
s
.008 w
.14109 .73132 Mdot
.016 w
.14109 .73132 m
.14109 .7312 L
s
.008 w
.14109 .7312 Mdot
.016 w
.14109 .7312 m
.1411 .731 L
s
.008 w
.1411 .731 Mdot
.016 w
.1411 .731 m
.14111 .73073 L
s
1 .418 0 r
.008 w
.14111 .73073 Mdot
.016 w
.14111 .73073 m
.14111 .73037 L
s
.008 w
.14111 .73037 Mdot
.016 w
.14111 .73037 m
.14112 .72994 L
s
.008 w
.14112 .72994 Mdot
.016 w
.14112 .72994 m
.14112 .72946 L
s
.008 w
.14112 .72946 Mdot
.016 w
.14112 .72946 m
.14113 .72895 L
s
.008 w
.14113 .72895 Mdot
.016 w
.14113 .72895 m
.14114 .72845 L
s
1 .417 0 r
.008 w
.14114 .72845 Mdot
.016 w
.14114 .72845 m
.14115 .72795 L
s
.008 w
.14115 .72795 Mdot
.016 w
.14115 .72795 m
.14116 .72746 L
s
.008 w
.14116 .72746 Mdot
.016 w
.14116 .72746 m
.14117 .727 L
s
.008 w
.14117 .727 Mdot
.016 w
.14117 .727 m
.14117 .7266 L
s
.008 w
.14117 .7266 Mdot
.016 w
.14117 .7266 m
.14118 .72628 L
s
.008 w
.14118 .72628 Mdot
.016 w
.14118 .72628 m
.14118 .72606 L
s
1 .416 0 r
.008 w
.14118 .72606 Mdot
.016 w
.14118 .72606 m
.14118 .72593 L
s
.008 w
.14118 .72593 Mdot
.016 w
.14118 .72593 m
.14118 .72589 L
s
.008 w
.14118 .72589 Mdot
.016 w
.14118 .72589 m
.14118 .72592 L
s
.008 w
.14118 .72592 Mdot
.016 w
.14118 .72592 m
.14118 .72599 L
s
.008 w
.14118 .72599 Mdot
.016 w
.14118 .72599 m
.14118 .72608 L
s
1 .415 0 r
.008 w
.14118 .72608 Mdot
.016 w
.14118 .72608 m
.14118 .72614 L
s
.008 w
.14118 .72614 Mdot
.016 w
.14118 .72614 m
.14118 .72616 L
s
.008 w
.14118 .72616 Mdot
.016 w
.14118 .72616 m
.14118 .72614 L
s
.008 w
.14118 .72614 Mdot
.016 w
.14118 .72614 m
.14119 .72609 L
s
.008 w
.14119 .72609 Mdot
.016 w
.14119 .72609 m
.14119 .72603 L
s
1 .414 0 r
.008 w
.14119 .72603 Mdot
.016 w
.14119 .72603 m
.14119 .72598 L
s
.008 w
.14119 .72598 Mdot
.016 w
.14119 .72598 m
.14119 .72597 L
s
.008 w
.14119 .72597 Mdot
.016 w
.14119 .72597 m
.14118 .726 L
s
.008 w
.14118 .726 Mdot
.016 w
.14118 .726 m
.14117 .7261 L
s
.008 w
.14117 .7261 Mdot
.016 w
.14117 .7261 m
.14116 .72627 L
s
1 .413 0 r
.008 w
.14116 .72627 Mdot
.016 w
.14116 .72627 m
.14115 .72655 L
s
.008 w
.14115 .72655 Mdot
.016 w
.14115 .72655 m
.14113 .72691 L
s
.008 w
.14113 .72691 Mdot
.016 w
.14113 .72691 m
.14112 .72736 L
s
.008 w
.14112 .72736 Mdot
.016 w
.14112 .72736 m
.14111 .72783 L
s
.008 w
.14111 .72783 Mdot
.016 w
.14111 .72783 m
.1411 .72835 L
s
.008 w
.1411 .72835 Mdot
.016 w
.1411 .72835 m
.14108 .7288 L
s
1 .412 0 r
.008 w
.14108 .7288 Mdot
.016 w
.14108 .7288 m
.14107 .72927 L
s
.008 w
.14107 .72927 Mdot
.016 w
.14107 .72927 m
.14105 .72968 L
s
.008 w
.14105 .72968 Mdot
.016 w
.14105 .72968 m
.14104 .73013 L
s
.008 w
.14104 .73013 Mdot
.016 w
.14104 .73013 m
.14103 .73053 L
s
.008 w
.14103 .73053 Mdot
.016 w
.14103 .73053 m
.14103 .73084 L
s
1 .411 0 r
.008 w
.14103 .73084 Mdot
.016 w
.14103 .73084 m
.14103 .73104 L
s
.008 w
.14103 .73104 Mdot
.016 w
.14103 .73104 m
.14103 .73115 L
s
.008 w
.14103 .73115 Mdot
.016 w
.14103 .73115 m
.14104 .7312 L
s
.008 w
.14104 .7312 Mdot
.016 w
.14104 .7312 m
.14105 .73119 L
s
.008 w
.14105 .73119 Mdot
.016 w
.14105 .73119 m
.14105 .73115 L
s
1 .41 0 r
.008 w
.14105 .73115 Mdot
.016 w
.14105 .73115 m
.14106 .73109 L
s
.008 w
.14106 .73109 Mdot
.016 w
.14106 .73109 m
.14107 .73105 L
s
.008 w
.14107 .73105 Mdot
.016 w
.14107 .73105 m
.14107 .73104 L
s
.008 w
.14107 .73104 Mdot
.016 w
.14107 .73104 m
.14107 .73104 L
s
.008 w
.14107 .73104 Mdot
.016 w
.14107 .73104 m
.14108 .73106 L
s
1 .409 0 r
.008 w
.14108 .73106 Mdot
.016 w
.14108 .73106 m
.14109 .73109 L
s
.008 w
.14109 .73109 Mdot
.016 w
.14109 .73109 m
.14111 .73115 L
s
.008 w
.14111 .73115 Mdot
.016 w
.14111 .73115 m
.14112 .73123 L
s
.008 w
.14112 .73123 Mdot
.016 w
.14112 .73123 m
.14113 .73131 L
s
.008 w
.14113 .73131 Mdot
.016 w
.14113 .73131 m
.14112 .73135 L
s
.008 w
.14112 .73135 Mdot
.016 w
.14112 .73135 m
.1411 .73134 L
s
1 .408 0 r
.008 w
.1411 .73134 Mdot
.016 w
.1411 .73134 m
.14107 .73126 L
s
.008 w
.14107 .73126 Mdot
.016 w
.14107 .73126 m
.14104 .73112 L
s
.008 w
.14104 .73112 Mdot
.016 w
.14104 .73112 m
.14101 .73089 L
s
.008 w
.14101 .73089 Mdot
.016 w
.14101 .73089 m
.14099 .73057 L
s
.008 w
.14099 .73057 Mdot
.016 w
.14099 .73057 m
.14097 .73018 L
s
1 .407 0 r
.008 w
.14097 .73018 Mdot
.016 w
.14097 .73018 m
.14096 .72973 L
s
.008 w
.14096 .72973 Mdot
.016 w
.14096 .72973 m
.14096 .72924 L
s
.008 w
.14096 .72924 Mdot
.016 w
.14096 .72924 m
.14096 .72871 L
s
.008 w
.14096 .72871 Mdot
.016 w
.14096 .72871 m
.14097 .7282 L
s
.008 w
.14097 .7282 Mdot
.016 w
.14097 .7282 m
.14098 .7276 L
s
1 .406 0 r
.008 w
.14098 .7276 Mdot
.016 w
.14098 .7276 m
.141 .72713 L
s
.008 w
.141 .72713 Mdot
.016 w
.141 .72713 m
.14102 .72665 L
s
.008 w
.14102 .72665 Mdot
.016 w
.14102 .72665 m
.14105 .72624 L
s
.008 w
.14105 .72624 Mdot
.016 w
.14105 .72624 m
.14108 .72596 L
s
.008 w
.14108 .72596 Mdot
.016 w
.14108 .72596 m
.14112 .72586 L
s
.008 w
.14112 .72586 Mdot
.016 w
.14112 .72586 m
.14115 .72596 L
s
1 .405 0 r
.008 w
.14115 .72596 Mdot
.016 w
.14115 .72596 m
.14117 .72624 L
s
.008 w
.14117 .72624 Mdot
.016 w
.14117 .72624 m
.14118 .72666 L
s
.008 w
.14118 .72666 Mdot
.016 w
.14118 .72666 m
.14119 .72716 L
s
.008 w
.14119 .72716 Mdot
.016 w
.14119 .72716 m
.14118 .72768 L
s
.008 w
.14118 .72768 Mdot
.016 w
.14118 .72768 m
.14115 .7282 L
s
1 .404 0 r
.008 w
.14115 .7282 Mdot
.016 w
.14115 .7282 m
.14113 .72871 L
s
.008 w
.14113 .72871 Mdot
.016 w
.14113 .72871 m
.14112 .72917 L
s
.008 w
.14112 .72917 Mdot
.016 w
.14112 .72917 m
.14111 .72959 L
s
.008 w
.14111 .72959 Mdot
.016 w
.14111 .72959 m
.1411 .73006 L
s
.008 w
.1411 .73006 Mdot
.016 w
.1411 .73006 m
.14109 .7305 L
s
1 .403 0 r
.008 w
.14109 .7305 Mdot
.016 w
.14109 .7305 m
.14107 .73087 L
s
.008 w
.14107 .73087 Mdot
.016 w
.14107 .73087 m
.14101 .73115 L
s
.008 w
.14101 .73115 Mdot
.016 w
.14101 .73115 m
.14093 .73134 L
s
.008 w
.14093 .73134 Mdot
.016 w
.14093 .73134 m
.14085 .73147 L
s
.008 w
.14085 .73147 Mdot
.016 w
.14085 .73147 m
.14079 .73159 L
s
1 .402 0 r
.008 w
.14079 .73159 Mdot
.016 w
.14079 .73159 m
.14075 .73175 L
s
.008 w
.14075 .73175 Mdot
.016 w
.14075 .73175 m
.14077 .73197 L
s
.008 w
.14077 .73197 Mdot
.016 w
.14077 .73197 m
.14088 .73229 L
s
.008 w
.14088 .73229 Mdot
.016 w
.14088 .73229 m
.1411 .73272 L
s
.008 w
.1411 .73272 Mdot
.016 w
.1411 .73272 m
.14143 .73322 L
s
.008 w
.14143 .73322 Mdot
.016 w
.14143 .73322 m
.14191 .73378 L
s
1 .401 0 r
.008 w
.14191 .73378 Mdot
.016 w
.14191 .73378 m
.14253 .73441 L
s
.008 w
.14253 .73441 Mdot
.016 w
.14253 .73441 m
.14329 .73513 L
s
.008 w
.14329 .73513 Mdot
.016 w
.14329 .73513 m
.144 .736 L
s
.008 w
.144 .736 Mdot
.016 w
.144 .736 m
.14493 .73694 L
s
.008 w
.14493 .73694 Mdot
.016 w
.14493 .73694 m
.1459 .738 L
s
1 .4 0 r
.008 w
.1459 .738 Mdot
.016 w
.1459 .738 m
.14706 .73936 L
s
.008 w
.14706 .73936 Mdot
.016 w
.14706 .73936 m
.14837 .74054 L
s
.008 w
.14837 .74054 Mdot
.016 w
.14837 .74054 m
.1495 .74199 L
s
.008 w
.1495 .74199 Mdot
.016 w
.1495 .74199 m
.15069 .74348 L
s
.008 w
.15069 .74348 Mdot
.016 w
.15069 .74348 m
.15205 .74466 L
s
1 .399 0 r
.008 w
.15205 .74466 Mdot
.016 w
.15205 .74466 m
.15338 .74644 L
s
.008 w
.15338 .74644 Mdot
.016 w
.15338 .74644 m
.15493 .74802 L
s
.008 w
.15493 .74802 Mdot
.016 w
.15493 .74802 m
.15629 .74979 L
s
.008 w
.15629 .74979 Mdot
.016 w
.15629 .74979 m
.15778 .75196 L
s
.008 w
.15778 .75196 Mdot
.016 w
.15778 .75196 m
.15967 .75404 L
s
1 .398 0 r
.008 w
.15967 .75404 Mdot
.016 w
.15967 .75404 m
.16147 .7565 L
s
.008 w
.16147 .7565 Mdot
.016 w
.16147 .7565 m
.16343 .75913 L
s
.008 w
.16343 .75913 Mdot
.016 w
.16343 .75913 m
.16563 .76186 L
s
.008 w
.16563 .76186 Mdot
.016 w
.16563 .76186 m
.16792 .76486 L
s
.008 w
.16792 .76486 Mdot
.016 w
.16792 .76486 m
.17046 .76812 L
s
.008 w
.17046 .76812 Mdot
.016 w
.17046 .76812 m
.17308 .77096 L
s
1 .397 0 r
.008 w
.17308 .77096 Mdot
.016 w
.17308 .77096 m
.17583 .7744 L
s
.008 w
.17583 .7744 Mdot
.016 w
.17583 .7744 m
.17869 .77761 L
s
.008 w
.17869 .77761 Mdot
.016 w
.17869 .77761 m
.1817 .7813 L
s
.008 w
.1817 .7813 Mdot
.016 w
.1817 .7813 m
.1848 .78494 L
s
.008 w
.1848 .78494 Mdot
.016 w
.1848 .78494 m
.18811 .78871 L
s
1 .396 0 r
.008 w
.18811 .78871 Mdot
.016 w
.18811 .78871 m
.19149 .79245 L
s
.008 w
.19149 .79245 Mdot
.016 w
.19149 .79245 m
.19509 .79615 L
s
.008 w
.19509 .79615 Mdot
.016 w
.19509 .79615 m
.19872 .79999 L
s
.008 w
.19872 .79999 Mdot
.016 w
.19872 .79999 m
.20254 .8038 L
s
.008 w
.20254 .8038 Mdot
.016 w
.20254 .8038 m
.20675 .80812 L
s
1 .395 0 r
.008 w
.20675 .80812 Mdot
.016 w
.20675 .80812 m
.21067 .81181 L
s
.008 w
.21067 .81181 Mdot
.016 w
.21067 .81181 m
.21491 .81604 L
s
.008 w
.21491 .81604 Mdot
.016 w
.21491 .81604 m
.2192 .82036 L
s
.008 w
.2192 .82036 Mdot
.016 w
.2192 .82036 m
.22351 .82473 L
s
.008 w
.22351 .82473 Mdot
.016 w
.22351 .82473 m
.22795 .82924 L
s
1 .394 0 r
.008 w
.22795 .82924 Mdot
.016 w
.22795 .82924 m
.23265 .83391 L
s
.008 w
.23265 .83391 Mdot
.016 w
.23265 .83391 m
.23692 .83835 L
s
.008 w
.23692 .83835 Mdot
.016 w
.23692 .83835 m
.24142 .84285 L
s
.008 w
.24142 .84285 Mdot
.016 w
.24142 .84285 m
.24587 .84738 L
s
.008 w
.24587 .84738 Mdot
.016 w
.24587 .84738 m
.25039 .85204 L
s
.008 w
.25039 .85204 Mdot
.016 w
.25039 .85204 m
.25451 .85639 L
s
1 .393 0 r
.008 w
.25451 .85639 Mdot
.016 w
.25451 .85639 m
.25876 .86074 L
s
.008 w
.25876 .86074 Mdot
.016 w
.25876 .86074 m
.26285 .86497 L
s
.008 w
.26285 .86497 Mdot
.016 w
.26285 .86497 m
.26665 .86909 L
s
.008 w
.26665 .86909 Mdot
.016 w
.26665 .86909 m
.27052 .87285 L
s
.008 w
.27052 .87285 Mdot
.016 w
.27052 .87285 m
.27409 .87624 L
s
1 .392 0 r
.008 w
.27409 .87624 Mdot
.016 w
.27409 .87624 m
.27757 .87955 L
s
.008 w
.27757 .87955 Mdot
.016 w
.27757 .87955 m
.28108 .88243 L
s
.008 w
.28108 .88243 Mdot
.016 w
.28108 .88243 m
.28433 .88518 L
s
.008 w
.28433 .88518 Mdot
.016 w
.28433 .88518 m
.28766 .88771 L
s
.008 w
.28766 .88771 Mdot
.016 w
.28766 .88771 m
.29085 .88981 L
s
1 .391 0 r
.008 w
.29085 .88981 Mdot
.016 w
.29085 .88981 m
.29406 .89178 L
s
.008 w
.29406 .89178 Mdot
.016 w
.29406 .89178 m
.29743 .89354 L
s
.008 w
.29743 .89354 Mdot
.016 w
.29743 .89354 m
.30068 .89516 L
s
.008 w
.30068 .89516 Mdot
.016 w
.30068 .89516 m
.30427 .89668 L
s
.008 w
.30427 .89668 Mdot
.016 w
.30427 .89668 m
.30763 .89803 L
s
.008 w
.30763 .89803 Mdot
.016 w
.30763 .89803 m
.31119 .89944 L
s
1 .39 0 r
.008 w
.31119 .89944 Mdot
.016 w
.31119 .89944 m
.31465 .90079 L
s
.008 w
.31465 .90079 Mdot
.016 w
.31465 .90079 m
.31819 .90217 L
s
.008 w
.31819 .90217 Mdot
.016 w
.31819 .90217 m
.32182 .90355 L
s
.008 w
.32182 .90355 Mdot
.016 w
.32182 .90355 m
.32556 .90496 L
s
.008 w
.32556 .90496 Mdot
.016 w
.32556 .90496 m
.32967 .90635 L
s
1 .389 0 r
.008 w
.32967 .90635 Mdot
.016 w
.32967 .90635 m
.33341 .90775 L
s
.008 w
.33341 .90775 Mdot
.016 w
.33341 .90775 m
.3376 .90921 L
s
.008 w
.3376 .90921 Mdot
.016 w
.3376 .90921 m
.34191 .91065 L
s
.008 w
.34191 .91065 Mdot
.016 w
.34191 .91065 m
.34674 .91218 L
s
.008 w
.34674 .91218 Mdot
.016 w
.34674 .91218 m
.35091 .91379 L
s
1 .388 0 r
.008 w
.35091 .91379 Mdot
.016 w
.35091 .91379 m
.35578 .91554 L
s
.008 w
.35578 .91554 Mdot
.016 w
.35578 .91554 m
.36087 .91733 L
s
.008 w
.36087 .91733 Mdot
.016 w
.36087 .91733 m
.36571 .91929 L
s
.008 w
.36571 .91929 Mdot
.016 w
.36571 .91929 m
.37093 .92126 L
s
.008 w
.37093 .92126 Mdot
.016 w
.37093 .92126 m
.37625 .9233 L
s
1 .387 0 r
.008 w
.37625 .9233 Mdot
.016 w
.37625 .9233 m
.38226 .9254 L
s
.008 w
.38226 .9254 Mdot
.016 w
.38226 .9254 m
.38709 .92748 L
s
.008 w
.38709 .92748 Mdot
.016 w
.38709 .92748 m
.39264 .92962 L
s
.008 w
.39264 .92962 Mdot
.016 w
.39264 .92962 m
.39826 .9317 L
s
.008 w
.39826 .9317 Mdot
.016 w
.39826 .9317 m
.40334 .93373 L
s
.008 w
.40334 .93373 Mdot
.016 w
.40334 .93373 m
.40863 .93568 L
s
1 .386 0 r
.008 w
.40863 .93568 Mdot
.016 w
.40863 .93568 m
.41388 .93749 L
s
.008 w
.41388 .93749 Mdot
.016 w
.41388 .93749 m
.41895 .9392 L
s
.008 w
.41895 .9392 Mdot
.016 w
.41895 .9392 m
.42401 .94078 L
s
.008 w
.42401 .94078 Mdot
.016 w
.42401 .94078 m
.42901 .94231 L
s
.008 w
.42901 .94231 Mdot
.016 w
.42901 .94231 m
.43385 .94382 L
s
1 .385 0 r
.008 w
.43385 .94382 Mdot
.016 w
.43385 .94382 m
.43893 .94525 L
s
.008 w
.43893 .94525 Mdot
.016 w
.43893 .94525 m
.44361 .94671 L
s
.008 w
.44361 .94671 Mdot
.016 w
.44361 .94671 m
.44851 .94817 L
s
.008 w
.44851 .94817 Mdot
.016 w
.44851 .94817 m
.45335 .94958 L
s
.008 w
.45335 .94958 Mdot
.016 w
.45335 .94958 m
.458 .95099 L
s
1 .384 0 r
.008 w
.458 .95099 Mdot
.016 w
.458 .95099 m
.4626 .95229 L
s
.008 w
.4626 .95229 Mdot
.016 w
.4626 .95229 m
.46711 .9535 L
s
.008 w
.46711 .9535 Mdot
.016 w
.46711 .9535 m
.47163 .95455 L
s
.008 w
.47163 .95455 Mdot
.016 w
.47163 .95455 m
.47596 .95548 L
s
.008 w
.47596 .95548 Mdot
.016 w
.47596 .95548 m
.4803 .95621 L
s
1 .383 0 r
.008 w
.4803 .95621 Mdot
.016 w
.4803 .95621 m
.48464 .95674 L
s
.008 w
.48464 .95674 Mdot
.016 w
.48464 .95674 m
.48902 .95707 L
s
.008 w
.48902 .95707 Mdot
.016 w
.48902 .95707 m
.49348 .95721 L
s
.008 w
.49348 .95721 Mdot
.016 w
.49348 .95721 m
.49785 .95716 L
s
.008 w
.49785 .95716 Mdot
.016 w
.49785 .95716 m
.50229 .95698 L
s
.008 w
.50229 .95698 Mdot
.016 w
.50229 .95698 m
.50657 .95665 L
s
1 .382 0 r
.008 w
.50657 .95665 Mdot
.016 w
.50657 .95665 m
.51076 .95621 L
s
.008 w
.51076 .95621 Mdot
.016 w
.51076 .95621 m
.51481 .95569 L
s
.008 w
.51481 .95569 Mdot
.016 w
.51481 .95569 m
.51873 .95515 L
s
.008 w
.51873 .95515 Mdot
.016 w
.51873 .95515 m
.52229 .95463 L
s
.008 w
.52229 .95463 Mdot
.016 w
.52229 .95463 m
.52565 .95417 L
s
1 .381 0 r
.008 w
.52565 .95417 Mdot
.016 w
.52565 .95417 m
.52873 .95375 L
s
.008 w
.52873 .95375 Mdot
.016 w
.52873 .95375 m
.53124 .95341 L
s
.008 w
.53124 .95341 Mdot
.016 w
.53124 .95341 m
.53341 .95315 L
s
.008 w
.53341 .95315 Mdot
.016 w
.53341 .95315 m
.53515 .95294 L
s
.008 w
.53515 .95294 Mdot
.016 w
.53515 .95294 m
.53644 .95278 L
s
1 .38 0 r
.008 w
.53644 .95278 Mdot
.016 w
.53644 .95278 m
.53735 .95266 L
s
.008 w
.53735 .95266 Mdot
.016 w
.53735 .95266 m
.53796 .95256 L
s
.008 w
.53796 .95256 Mdot
.016 w
.53796 .95256 m
.53834 .95248 L
s
.008 w
.53834 .95248 Mdot
.016 w
.53834 .95248 m
.53853 .95242 L
s
.008 w
.53853 .95242 Mdot
.016 w
.53853 .95242 m
.53855 .95239 L
s
1 .379 0 r
.008 w
.53855 .95239 Mdot
.016 w
.53855 .95239 m
.53843 .95239 L
s
.008 w
.53843 .95239 Mdot
.016 w
.53843 .95239 m
.53825 .95242 L
s
.008 w
.53825 .95242 Mdot
.016 w
.53825 .95242 m
.53804 .95246 L
s
.008 w
.53804 .95246 Mdot
.016 w
.53804 .95246 m
.53787 .95251 L
s
.008 w
.53787 .95251 Mdot
.016 w
.53787 .95251 m
.5378 .95257 L
s
.008 w
.5378 .95257 Mdot
.016 w
.5378 .95257 m
.53792 .95259 L
s
1 .378 0 r
.008 w
.53792 .95259 Mdot
.016 w
.53792 .95259 m
.53828 .95262 L
s
.008 w
.53828 .95262 Mdot
.016 w
.53828 .95262 m
.53898 .9526 L
s
.008 w
.53898 .9526 Mdot
.016 w
.53898 .9526 m
.54009 .95255 L
s
.008 w
.54009 .95255 Mdot
.016 w
.54009 .95255 m
.54169 .95246 L
s
.008 w
.54169 .95246 Mdot
.016 w
.54169 .95246 m
.5437 .95233 L
s
1 .377 0 r
.008 w
.5437 .95233 Mdot
.016 w
.5437 .95233 m
.54581 .95217 L
s
.008 w
.54581 .95217 Mdot
.016 w
.54581 .95217 m
.54858 .95193 L
s
.008 w
.54858 .95193 Mdot
.016 w
.54858 .95193 m
.55194 .95159 L
s
.008 w
.55194 .95159 Mdot
.016 w
.55194 .95159 m
.5558 .95113 L
s
.008 w
.5558 .95113 Mdot
.016 w
.5558 .95113 m
.56012 .95056 L
s
1 .376 0 r
.008 w
.56012 .95056 Mdot
.016 w
.56012 .95056 m
.56477 .94986 L
s
.008 w
.56477 .94986 Mdot
.016 w
.56477 .94986 m
.56968 .94905 L
s
.008 w
.56968 .94905 Mdot
.016 w
.56968 .94905 m
.57497 .94814 L
s
.008 w
.57497 .94814 Mdot
.016 w
.57497 .94814 m
.58027 .94721 L
s
.008 w
.58027 .94721 Mdot
.016 w
.58027 .94721 m
.58586 .94623 L
s
1 .375 0 r
.008 w
.58586 .94623 Mdot
.016 w
.58586 .94623 m
.59124 .94518 L
s
.008 w
.59124 .94518 Mdot
.016 w
.59124 .94518 m
.59706 .94408 L
s
.008 w
.59706 .94408 Mdot
.016 w
.59706 .94408 m
.6025 .94298 L
s
.008 w
.6025 .94298 Mdot
.016 w
.6025 .94298 m
.60818 .94181 L
s
.008 w
.60818 .94181 Mdot
.016 w
.60818 .94181 m
.61432 .94059 L
s
.008 w
.61432 .94059 Mdot
.016 w
.61432 .94059 m
.61971 .93936 L
s
1 .374 0 r
.008 w
.61971 .93936 Mdot
.016 w
.61971 .93936 m
.62551 .93813 L
s
.008 w
.62551 .93813 Mdot
.016 w
.62551 .93813 m
.63149 .93694 L
s
.008 w
.63149 .93694 Mdot
.016 w
.63149 .93694 m
.63707 .93574 L
s
.008 w
.63707 .93574 Mdot
.016 w
.63707 .93574 m
.6427 .93459 L
s
.008 w
.6427 .93459 Mdot
.016 w
.6427 .93459 m
.64834 .93343 L
s
1 .373 0 r
.008 w
.64834 .93343 Mdot
.016 w
.64834 .93343 m
.65345 .93236 L
s
.008 w
.65345 .93236 Mdot
.016 w
.65345 .93236 m
.65837 .9313 L
s
.008 w
.65837 .9313 Mdot
.016 w
.65837 .9313 m
.66278 .93017 L
s
.008 w
.66278 .93017 Mdot
.016 w
.66278 .93017 m
.66685 .92928 L
s
.008 w
.66685 .92928 Mdot
.016 w
.66685 .92928 m
.6702 .92844 L
s
1 .372 0 r
.008 w
.6702 .92844 Mdot
.016 w
.6702 .92844 m
.67329 .92775 L
s
.008 w
.67329 .92775 Mdot
.016 w
.67329 .92775 m
.6759 .92719 L
s
.008 w
.6759 .92719 Mdot
.016 w
.6759 .92719 m
.67819 .92671 L
s
.008 w
.67819 .92671 Mdot
.016 w
.67819 .92671 m
.68034 .92626 L
s
.008 w
.68034 .92626 Mdot
.016 w
.68034 .92626 m
.6824 .92576 L
s
.008 w
.6824 .92576 Mdot
.016 w
.6824 .92576 m
.68446 .92513 L
s
1 .371 0 r
.008 w
.68446 .92513 Mdot
.016 w
.68446 .92513 m
.68663 .92434 L
s
.008 w
.68663 .92434 Mdot
.016 w
.68663 .92434 m
.68892 .92332 L
s
.008 w
.68892 .92332 Mdot
.016 w
.68892 .92332 m
.69148 .92215 L
s
.008 w
.69148 .92215 Mdot
.016 w
.69148 .92215 m
.6941 .92069 L
s
.008 w
.6941 .92069 Mdot
.016 w
.6941 .92069 m
.69718 .91895 L
s
1 .37 0 r
.008 w
.69718 .91895 Mdot
.016 w
.69718 .91895 m
.70035 .91722 L
s
.008 w
.70035 .91722 Mdot
.016 w
.70035 .91722 m
.70395 .91511 L
s
.008 w
.70395 .91511 Mdot
.016 w
.70395 .91511 m
.7077 .91283 L
s
.008 w
.7077 .91283 Mdot
.016 w
.7077 .91283 m
.7115 .91048 L
s
.008 w
.7115 .91048 Mdot
.016 w
.7115 .91048 m
.71556 .90788 L
s
1 .369 0 r
.008 w
.71556 .90788 Mdot
.016 w
.71556 .90788 m
.7191 .90546 L
s
.008 w
.7191 .90546 Mdot
.016 w
.7191 .90546 m
.72275 .90297 L
s
.008 w
.72275 .90297 Mdot
.016 w
.72275 .90297 m
.72602 .90067 L
s
.008 w
.72602 .90067 Mdot
.016 w
.72602 .90067 m
.72902 .89851 L
s
.008 w
.72902 .89851 Mdot
.016 w
.72902 .89851 m
.73163 .89659 L
s
1 .368 0 r
.008 w
.73163 .89659 Mdot
.016 w
.73163 .89659 m
.73389 .89487 L
s
.008 w
.73389 .89487 Mdot
.016 w
.73389 .89487 m
.73576 .89341 L
s
.008 w
.73576 .89341 Mdot
.016 w
.73576 .89341 m
.73734 .89214 L
s
.008 w
.73734 .89214 Mdot
.016 w
.73734 .89214 m
.73857 .89103 L
s
.008 w
.73857 .89103 Mdot
.016 w
.73857 .89103 m
.73958 .89006 L
s
.008 w
.73958 .89006 Mdot
.016 w
.73958 .89006 m
.74035 .88924 L
s
1 .367 0 r
.008 w
.74035 .88924 Mdot
.016 w
.74035 .88924 m
.74091 .88857 L
s
.008 w
.74091 .88857 Mdot
.016 w
.74091 .88857 m
.74128 .88804 L
s
.008 w
.74128 .88804 Mdot
.016 w
.74128 .88804 m
.74152 .8876 L
s
.008 w
.74152 .8876 Mdot
.016 w
.74152 .8876 m
.74166 .88729 L
s
.008 w
.74166 .88729 Mdot
.016 w
.74166 .88729 m
.74174 .88708 L
s
1 .366 0 r
.008 w
.74174 .88708 Mdot
.016 w
.74174 .88708 m
.74181 .88691 L
s
.008 w
.74181 .88691 Mdot
.016 w
.74181 .88691 m
.74187 .88679 L
s
.008 w
.74187 .88679 Mdot
.016 w
.74187 .88679 m
.74196 .88671 L
s
.008 w
.74196 .88671 Mdot
.016 w
.74196 .88671 m
.74207 .88663 L
s
.008 w
.74207 .88663 Mdot
.016 w
.74207 .88663 m
.74223 .88656 L
s
1 .365 0 r
.008 w
.74223 .88656 Mdot
.016 w
.74223 .88656 m
.74238 .8865 L
s
.008 w
.74238 .8865 Mdot
.016 w
.74238 .8865 m
.7425 .88644 L
s
.008 w
.7425 .88644 Mdot
.016 w
.7425 .88644 m
.74259 .8864 L
s
.008 w
.74259 .8864 Mdot
.016 w
.74259 .8864 m
.74264 .88637 L
s
.008 w
.74264 .88637 Mdot
.016 w
.74264 .88637 m
.74266 .88638 L
s
1 .364 0 r
.008 w
.74266 .88638 Mdot
.016 w
.74266 .88638 m
.74264 .88642 L
s
.008 w
.74264 .88642 Mdot
.016 w
.74264 .88642 m
.74259 .88648 L
s
.008 w
.74259 .88648 Mdot
.016 w
.74259 .88648 m
.74252 .88653 L
s
.008 w
.74252 .88653 Mdot
.016 w
.74252 .88653 m
.74244 .88658 L
s
.008 w
.74244 .88658 Mdot
.016 w
.74244 .88658 m
.74236 .88662 L
s
.008 w
.74236 .88662 Mdot
.016 w
.74236 .88662 m
.74229 .88665 L
s
1 .363 0 r
.008 w
.74229 .88665 Mdot
.016 w
.74229 .88665 m
.74226 .88667 L
s
.008 w
.74226 .88667 Mdot
.016 w
.74226 .88667 m
.74231 .88666 L
s
.008 w
.74231 .88666 Mdot
.016 w
.74231 .88666 m
.74243 .88661 L
s
.008 w
.74243 .88661 Mdot
.016 w
.74243 .88661 m
.74263 .8865 L
s
.008 w
.74263 .8865 Mdot
.016 w
.74263 .8865 m
.7429 .88632 L
s
1 .362 0 r
.008 w
.7429 .88632 Mdot
.016 w
.7429 .88632 m
.74324 .88607 L
s
.008 w
.74324 .88607 Mdot
.016 w
.74324 .88607 m
.74364 .88574 L
s
.008 w
.74364 .88574 Mdot
.016 w
.74364 .88574 m
.74411 .88533 L
s
.008 w
.74411 .88533 Mdot
.016 w
.74411 .88533 m
.74464 .88484 L
s
.008 w
.74464 .88484 Mdot
.016 w
.74464 .88484 m
.74525 .88429 L
s
1 .361 0 r
.008 w
.74525 .88429 Mdot
.016 w
.74525 .88429 m
.74593 .8837 L
s
.008 w
.74593 .8837 Mdot
.016 w
.74593 .8837 m
.74665 .88307 L
s
.008 w
.74665 .88307 Mdot
.016 w
.74665 .88307 m
.74735 .88241 L
s
.008 w
.74735 .88241 Mdot
.016 w
.74735 .88241 m
.748 .88172 L
s
.008 w
.748 .88172 Mdot
.016 w
.748 .88172 m
.74854 .88105 L
s
1 .36 0 r
.008 w
.74854 .88105 Mdot
.016 w
.74854 .88105 m
.74895 .88037 L
s
.008 w
.74895 .88037 Mdot
.016 w
.74895 .88037 m
.74922 .87982 L
s
.008 w
.74922 .87982 Mdot
.016 w
.74922 .87982 m
.74935 .87934 L
s
.008 w
.74935 .87934 Mdot
.016 w
.74935 .87934 m
.74936 .87899 L
s
.008 w
.74936 .87899 Mdot
.016 w
.74936 .87899 m
.74927 .87876 L
s
.008 w
.74927 .87876 Mdot
.016 w
.74927 .87876 m
.74912 .87863 L
s
1 .359 0 r
.008 w
.74912 .87863 Mdot
.016 w
.74912 .87863 m
.74895 .87857 L
s
.008 w
.74895 .87857 Mdot
.016 w
.74895 .87857 m
.7488 .87853 L
s
.008 w
.7488 .87853 Mdot
.016 w
.7488 .87853 m
.74867 .87848 L
s
.008 w
.74867 .87848 Mdot
.016 w
.74867 .87848 m
.74856 .87839 L
s
.008 w
.74856 .87839 Mdot
.016 w
.74856 .87839 m
.7485 .87824 L
s
1 .358 0 r
.008 w
.7485 .87824 Mdot
.016 w
.7485 .87824 m
.74852 .87804 L
s
.008 w
.74852 .87804 Mdot
.016 w
.74852 .87804 m
.74869 .87777 L
s
.008 w
.74869 .87777 Mdot
.016 w
.74869 .87777 m
.74905 .87743 L
s
.008 w
.74905 .87743 Mdot
.016 w
.74905 .87743 m
.74961 .87701 L
s
.008 w
.74961 .87701 Mdot
.016 w
.74961 .87701 m
.75038 .87649 L
s
1 .357 0 r
.008 w
.75038 .87649 Mdot
.016 w
.75038 .87649 m
.7514 .87585 L
s
.008 w
.7514 .87585 Mdot
.016 w
.7514 .87585 m
.75263 .87508 L
s
.008 w
.75263 .87508 Mdot
.016 w
.75263 .87508 m
.75413 .87417 L
s
.008 w
.75413 .87417 Mdot
.016 w
.75413 .87417 m
.75588 .87308 L
s
.008 w
.75588 .87308 Mdot
.016 w
.75588 .87308 m
.75793 .87183 L
s
.008 w
.75793 .87183 Mdot
.016 w
.75793 .87183 m
.76033 .87045 L
s
1 .356 0 r
.008 w
.76033 .87045 Mdot
.016 w
.76033 .87045 m
.76301 .86891 L
s
.008 w
.76301 .86891 Mdot
.016 w
.76301 .86891 m
.76608 .86721 L
s
.008 w
.76608 .86721 Mdot
.016 w
.76608 .86721 m
.7694 .86533 L
s
.008 w
.7694 .86533 Mdot
.016 w
.7694 .86533 m
.77309 .86316 L
s
.008 w
.77309 .86316 Mdot
.016 w
.77309 .86316 m
.77684 .86083 L
s
1 .355 0 r
.008 w
.77684 .86083 Mdot
.016 w
.77684 .86083 m
.78097 .85818 L
s
.008 w
.78097 .85818 Mdot
.016 w
.78097 .85818 m
.78512 .85524 L
s
.008 w
.78512 .85524 Mdot
.016 w
.78512 .85524 m
.78935 .85221 L
s
.008 w
.78935 .85221 Mdot
.016 w
.78935 .85221 m
.79396 .84891 L
s
.008 w
.79396 .84891 Mdot
.016 w
.79396 .84891 m
.79806 .84561 L
s
1 .354 0 r
.008 w
.79806 .84561 Mdot
.016 w
.79806 .84561 m
.80227 .84212 L
s
.008 w
.80227 .84212 Mdot
.016 w
.80227 .84212 m
.80641 .83875 L
s
.008 w
.80641 .83875 Mdot
.016 w
.80641 .83875 m
.81062 .83497 L
s
.008 w
.81062 .83497 Mdot
.016 w
.81062 .83497 m
.81445 .83184 L
s
.008 w
.81445 .83184 Mdot
.016 w
.81445 .83184 m
.81834 .82851 L
s
1 .353 0 r
.008 w
.81834 .82851 Mdot
.016 w
.81834 .82851 m
.82201 .82513 L
s
.008 w
.82201 .82513 Mdot
.016 w
.82201 .82513 m
.82562 .82203 L
s
.008 w
.82562 .82203 Mdot
.016 w
.82562 .82203 m
.82915 .81877 L
s
.008 w
.82915 .81877 Mdot
.016 w
.82915 .81877 m
.83261 .8158 L
s
.008 w
.83261 .8158 Mdot
.016 w
.83261 .8158 m
.83609 .81272 L
s
.008 w
.83609 .81272 Mdot
.016 w
.83609 .81272 m
.83947 .8099 L
s
1 .352 0 r
.008 w
.83947 .8099 Mdot
.016 w
.83947 .8099 m
.8429 .80697 L
s
.008 w
.8429 .80697 Mdot
.016 w
.8429 .80697 m
.84608 .80432 L
s
.008 w
.84608 .80432 Mdot
.016 w
.84608 .80432 m
.84915 .80176 L
s
.008 w
.84915 .80176 Mdot
.016 w
.84915 .80176 m
.85203 .79934 L
s
.008 w
.85203 .79934 Mdot
.016 w
.85203 .79934 m
.8546 .79719 L
s
1 .351 0 r
.008 w
.8546 .79719 Mdot
.016 w
.8546 .79719 m
.85704 .79535 L
s
.008 w
.85704 .79535 Mdot
.016 w
.85704 .79535 m
.85894 .79381 L
s
.008 w
.85894 .79381 Mdot
.016 w
.85894 .79381 m
.86041 .79251 L
s
.008 w
.86041 .79251 Mdot
.016 w
.86041 .79251 m
.86172 .79141 L
s
.008 w
.86172 .79141 Mdot
.016 w
.86172 .79141 m
.86269 .79057 L
s
1 .35 0 r
.008 w
.86269 .79057 Mdot
.016 w
.86269 .79057 m
.86346 .78989 L
s
.008 w
.86346 .78989 Mdot
.016 w
.86346 .78989 m
.86402 .78947 L
s
.008 w
.86402 .78947 Mdot
.016 w
.86402 .78947 m
.86437 .78926 L
s
.008 w
.86437 .78926 Mdot
.016 w
.86437 .78926 m
.86453 .78921 L
s
.008 w
.86453 .78921 Mdot
.016 w
.86453 .78921 m
.86453 .78924 L
s
1 .349 0 r
.008 w
.86453 .78924 Mdot
.016 w
.86453 .78924 m
.86453 .78928 L
s
.008 w
.86453 .78928 Mdot
.016 w
.86453 .78928 m
.86451 .78927 L
s
.008 w
.86451 .78927 Mdot
.016 w
.86451 .78927 m
.86457 .78915 L
s
.008 w
.86457 .78915 Mdot
.016 w
.86457 .78915 m
.86471 .78892 L
s
.008 w
.86471 .78892 Mdot
.016 w
.86471 .78892 m
.86489 .78862 L
s
.008 w
.86489 .78862 Mdot
.016 w
.86489 .78862 m
.86508 .78828 L
s
1 .348 0 r
.008 w
.86508 .78828 Mdot
.016 w
.86508 .78828 m
.86529 .78793 L
s
.008 w
.86529 .78793 Mdot
.016 w
.86529 .78793 m
.86554 .78758 L
s
.008 w
.86554 .78758 Mdot
.016 w
.86554 .78758 m
.86577 .78722 L
s
.008 w
.86577 .78722 Mdot
.016 w
.86577 .78722 m
.86594 .78687 L
s
.008 w
.86594 .78687 Mdot
.016 w
.86594 .78687 m
.86609 .7865 L
s
1 .347 0 r
.008 w
.86609 .7865 Mdot
.016 w
.86609 .7865 m
.86618 .78614 L
s
.008 w
.86618 .78614 Mdot
.016 w
.86618 .78614 m
.8662 .78583 L
s
.008 w
.8662 .78583 Mdot
.016 w
.8662 .78583 m
.86613 .78561 L
s
.008 w
.86613 .78561 Mdot
.016 w
.86613 .78561 m
.866 .78545 L
s
.008 w
.866 .78545 Mdot
.016 w
.866 .78545 m
.86583 .78536 L
s
1 .346 0 r
.008 w
.86583 .78536 Mdot
.016 w
.86583 .78536 m
.86565 .78533 L
s
.008 w
.86565 .78533 Mdot
.016 w
.86565 .78533 m
.86547 .78537 L
s
.008 w
.86547 .78537 Mdot
.016 w
.86547 .78537 m
.86531 .78541 L
s
.008 w
.86531 .78541 Mdot
.016 w
.86531 .78541 m
.86521 .78543 L
s
.008 w
.86521 .78543 Mdot
.016 w
.86521 .78543 m
.86515 .78543 L
s
1 .345 0 r
.008 w
.86515 .78543 Mdot
.016 w
.86515 .78543 m
.86511 .78542 L
s
.008 w
.86511 .78542 Mdot
.016 w
.86511 .78542 m
.86508 .78538 L
s
.008 w
.86508 .78538 Mdot
.016 w
.86508 .78538 m
.86505 .78532 L
s
.008 w
.86505 .78532 Mdot
.016 w
.86505 .78532 m
.86501 .78529 L
s
.008 w
.86501 .78529 Mdot
.016 w
.86501 .78529 m
.865 .78524 L
s
.008 w
.865 .78524 Mdot
.016 w
.865 .78524 m
.86501 .78519 L
s
1 .344 0 r
.008 w
.86501 .78519 Mdot
.016 w
.86501 .78519 m
.86506 .78511 L
s
.008 w
.86506 .78511 Mdot
.016 w
.86506 .78511 m
.86515 .78504 L
s
.008 w
.86515 .78504 Mdot
.016 w
.86515 .78504 m
.86528 .78496 L
s
.008 w
.86528 .78496 Mdot
.016 w
.86528 .78496 m
.86542 .78488 L
s
.008 w
.86542 .78488 Mdot
.016 w
.86542 .78488 m
.86559 .7848 L
s
1 .343 0 r
.008 w
.86559 .7848 Mdot
.016 w
.86559 .7848 m
.86571 .78477 L
s
.008 w
.86571 .78477 Mdot
.016 w
.86571 .78477 m
.8658 .78477 L
s
.008 w
.8658 .78477 Mdot
.016 w
.8658 .78477 m
.86585 .78481 L
s
.008 w
.86585 .78481 Mdot
.016 w
.86585 .78481 m
.86589 .78487 L
s
.008 w
.86589 .78487 Mdot
.016 w
.86589 .78487 m
.86592 .78497 L
s
1 .342 0 r
.008 w
.86592 .78497 Mdot
.016 w
.86592 .78497 m
.86597 .78509 L
s
.008 w
.86597 .78509 Mdot
.016 w
.86597 .78509 m
.86604 .78518 L
s
.008 w
.86604 .78518 Mdot
.016 w
.86604 .78518 m
.86612 .78518 L
s
.008 w
.86612 .78518 Mdot
.016 w
.86612 .78518 m
.86621 .78508 L
s
.008 w
.86621 .78508 Mdot
.016 w
.86621 .78508 m
.8663 .78484 L
s
.008 w
.8663 .78484 Mdot
.016 w
.8663 .78484 m
.86638 .78443 L
s
1 .341 0 r
.008 w
.86638 .78443 Mdot
.016 w
.86638 .78443 m
.86645 .78378 L
s
.008 w
.86645 .78378 Mdot
.016 w
.86645 .78378 m
.86652 .78285 L
s
.008 w
.86652 .78285 Mdot
.016 w
.86652 .78285 m
.86661 .78158 L
s
.008 w
.86661 .78158 Mdot
.016 w
.86661 .78158 m
.86672 .78002 L
s
.008 w
.86672 .78002 Mdot
.016 w
.86672 .78002 m
.86687 .77807 L
s
1 .34 0 r
.008 w
.86687 .77807 Mdot
.016 w
.86687 .77807 m
.86702 .77585 L
s
.008 w
.86702 .77585 Mdot
.016 w
.86702 .77585 m
.86718 .77333 L
s
.008 w
.86718 .77333 Mdot
.016 w
.86718 .77333 m
.86734 .77082 L
s
.008 w
.86734 .77082 Mdot
.016 w
.86734 .77082 m
.86748 .76813 L
s
.008 w
.86748 .76813 Mdot
.016 w
.86748 .76813 m
.86761 .76544 L
s
1 .339 0 r
.008 w
.86761 .76544 Mdot
.016 w
.86761 .76544 m
.86772 .7629 L
s
.008 w
.86772 .7629 Mdot
.016 w
.86772 .7629 m
.86781 .76044 L
s
.008 w
.86781 .76044 Mdot
.016 w
.86781 .76044 m
.86786 .75839 L
s
.008 w
.86786 .75839 Mdot
.016 w
.86786 .75839 m
.86788 .75657 L
s
.008 w
.86788 .75657 Mdot
.016 w
.86788 .75657 m
.86787 .75503 L
s
1 .338 0 r
.008 w
.86787 .75503 Mdot
.016 w
.86787 .75503 m
.86784 .75382 L
s
.008 w
.86784 .75382 Mdot
.016 w
.86784 .75382 m
.8678 .75286 L
s
.008 w
.8678 .75286 Mdot
.016 w
.8678 .75286 m
.86776 .7522 L
s
.008 w
.86776 .7522 Mdot
.016 w
.86776 .7522 m
.86773 .75176 L
s
.008 w
.86773 .75176 Mdot
.016 w
.86773 .75176 m
.86774 .7515 L
s
.008 w
.86774 .7515 Mdot
.016 w
.86774 .7515 m
.8678 .7514 L
s
1 .337 0 r
.008 w
.8678 .7514 Mdot
.016 w
.8678 .7514 m
.86789 .75141 L
s
.008 w
.86789 .75141 Mdot
.016 w
.86789 .75141 m
.86798 .75148 L
s
.008 w
.86798 .75148 Mdot
.016 w
.86798 .75148 m
.86802 .75155 L
s
.008 w
.86802 .75155 Mdot
.016 w
.86802 .75155 m
.86799 .7516 L
s
.008 w
.86799 .7516 Mdot
.016 w
.86799 .7516 m
.86787 .75165 L
s
1 .336 0 r
.008 w
.86787 .75165 Mdot
.016 w
.86787 .75165 m
.86764 .7517 L
s
.008 w
.86764 .7517 Mdot
.016 w
.86764 .7517 m
.86731 .75176 L
s
.008 w
.86731 .75176 Mdot
.016 w
.86731 .75176 m
.86689 .75183 L
s
.008 w
.86689 .75183 Mdot
.016 w
.86689 .75183 m
.86639 .75191 L
s
.008 w
.86639 .75191 Mdot
.016 w
.86639 .75191 m
.86584 .75198 L
s
1 .335 0 r
.008 w
.86584 .75198 Mdot
.016 w
.86584 .75198 m
.86527 .75204 L
s
.008 w
.86527 .75204 Mdot
.016 w
.86527 .75204 m
.86469 .7521 L
s
.008 w
.86469 .7521 Mdot
.016 w
.86469 .7521 m
.86416 .75216 L
s
.008 w
.86416 .75216 Mdot
.016 w
.86416 .75216 m
.86361 .75221 L
s
.008 w
.86361 .75221 Mdot
.016 w
.86361 .75221 m
.86309 .75226 L
s
1 .334 0 r
.008 w
.86309 .75226 Mdot
.016 w
.86309 .75226 m
.86264 .7523 L
s
.008 w
.86264 .7523 Mdot
.016 w
.86264 .7523 m
.86228 .75233 L
s
.008 w
.86228 .75233 Mdot
.016 w
.86228 .75233 m
.86204 .75235 L
s
.008 w
.86204 .75235 Mdot
.016 w
.86204 .75235 m
.86191 .75236 L
s
.008 w
.86191 .75236 Mdot
.016 w
.86191 .75236 m
.86187 .75236 L
s
.008 w
.86187 .75236 Mdot
.016 w
.86187 .75236 m
.86191 .75236 L
s
1 .333 0 r
.008 w
.86191 .75236 Mdot
.016 w
.86191 .75236 m
.86199 .75235 L
s
.008 w
.86199 .75235 Mdot
.016 w
.86199 .75235 m
.86206 .75234 L
s
.008 w
.86206 .75234 Mdot
.016 w
.86206 .75234 m
.8621 .75234 L
s
.008 w
.8621 .75234 Mdot
.016 w
.8621 .75234 m
.8621 .75234 L
s
.008 w
.8621 .75234 Mdot
.016 w
.8621 .75234 m
.86209 .75234 L
s
1 .332 0 r
.008 w
.86209 .75234 Mdot
.016 w
.86209 .75234 m
.8621 .75234 L
s
.008 w
.8621 .75234 Mdot
.016 w
.8621 .75234 m
.86214 .75234 L
s
.008 w
.86214 .75234 Mdot
.016 w
.86214 .75234 m
.86221 .75233 L
s
.008 w
.86221 .75233 Mdot
.016 w
.86221 .75233 m
.86232 .75232 L
s
.008 w
.86232 .75232 Mdot
.016 w
.86232 .75232 m
.86246 .7523 L
s
1 .331 0 r
.008 w
.86246 .7523 Mdot
.016 w
.86246 .7523 m
.86261 .75229 L
s
.008 w
.86261 .75229 Mdot
.016 w
.86261 .75229 m
.86277 .75227 L
s
.008 w
.86277 .75227 Mdot
.016 w
.86277 .75227 m
.86292 .75226 L
s
.008 w
.86292 .75226 Mdot
.016 w
.86292 .75226 m
.86308 .75225 L
s
.008 w
.86308 .75225 Mdot
.016 w
.86308 .75225 m
.86323 .75226 L
s
1 .33 0 r
.008 w
.86323 .75226 Mdot
.016 w
.86323 .75226 m
.86339 .75231 L
s
.008 w
.86339 .75231 Mdot
.016 w
.86339 .75231 m
.86355 .7524 L
s
.008 w
.86355 .7524 Mdot
.016 w
.86355 .7524 m
.8637 .75251 L
s
.008 w
.8637 .75251 Mdot
.016 w
.8637 .75251 m
.86384 .75264 L
s
.008 w
.86384 .75264 Mdot
.016 w
.86384 .75264 m
.86399 .75274 L
s
.008 w
.86399 .75274 Mdot
.016 w
.86399 .75274 m
.86416 .75278 L
s
1 .329 0 r
.008 w
.86416 .75278 Mdot
.016 w
.86416 .75278 m
.86437 .75272 L
s
.008 w
.86437 .75272 Mdot
.016 w
.86437 .75272 m
.86464 .75254 L
s
.008 w
.86464 .75254 Mdot
.016 w
.86464 .75254 m
.86501 .75219 L
s
.008 w
.86501 .75219 Mdot
.016 w
.86501 .75219 m
.86553 .75162 L
s
.008 w
.86553 .75162 Mdot
.016 w
.86553 .75162 m
.86623 .75079 L
s
1 .328 0 r
.008 w
.86623 .75079 Mdot
.016 w
.86623 .75079 m
.86715 .74964 L
s
.008 w
.86715 .74964 Mdot
.016 w
.86715 .74964 m
.86833 .74811 L
s
.008 w
.86833 .74811 Mdot
.016 w
.86833 .74811 m
.86975 .74612 L
s
.008 w
.86975 .74612 Mdot
.016 w
.86975 .74612 m
.87143 .74367 L
s
.008 w
.87143 .74367 Mdot
.016 w
.87143 .74367 m
.87326 .74082 L
s
1 .327 0 r
.008 w
.87326 .74082 Mdot
.016 w
.87326 .74082 m
.87529 .7375 L
s
.008 w
.87529 .7375 Mdot
.016 w
.87529 .7375 m
.87742 .73385 L
s
.008 w
.87742 .73385 Mdot
.016 w
.87742 .73385 m
.87975 .72979 L
s
.008 w
.87975 .72979 Mdot
.016 w
.87975 .72979 m
.882 .72564 L
s
.008 w
.882 .72564 Mdot
.016 w
.882 .72564 m
.88449 .72108 L
s
1 .326 0 r
.008 w
.88449 .72108 Mdot
.016 w
.88449 .72108 m
.88663 .71651 L
s
.008 w
.88663 .71651 Mdot
.016 w
.88663 .71651 m
.88906 .71159 L
s
.008 w
.88906 .71159 Mdot
.016 w
.88906 .71159 m
.89152 .70639 L
s
.008 w
.89152 .70639 Mdot
.016 w
.89152 .70639 m
.89362 .70114 L
s
.008 w
.89362 .70114 Mdot
.016 w
.89362 .70114 m
.89591 .69571 L
s
.008 w
.89591 .69571 Mdot
.016 w
.89591 .69571 m
.89793 .69005 L
s
1 .325 0 r
.008 w
.89793 .69005 Mdot
.016 w
.89793 .69005 m
.89998 .68427 L
s
.008 w
.89998 .68427 Mdot
.016 w
.89998 .68427 m
.90199 .678 L
s
.008 w
.90199 .678 Mdot
.016 w
.90199 .678 m
.90391 .67243 L
s
.008 w
.90391 .67243 Mdot
.016 w
.90391 .67243 m
.90589 .66623 L
s
.008 w
.90589 .66623 Mdot
.016 w
.90589 .66623 m
.90771 .66021 L
s
1 .324 0 r
.008 w
.90771 .66021 Mdot
.016 w
.90771 .66021 m
.90966 .65365 L
s
.008 w
.90966 .65365 Mdot
.016 w
.90966 .65365 m
.91143 .64702 L
s
.008 w
.91143 .64702 Mdot
.016 w
.91143 .64702 m
.9132 .64019 L
s
.008 w
.9132 .64019 Mdot
.016 w
.9132 .64019 m
.91494 .63406 L
s
.008 w
.91494 .63406 Mdot
.016 w
.91494 .63406 m
.91663 .62742 L
s
1 .323 0 r
.008 w
.91663 .62742 Mdot
.016 w
.91663 .62742 m
.91828 .62072 L
s
.008 w
.91828 .62072 Mdot
.016 w
.91828 .62072 m
.91988 .61392 L
s
.008 w
.91988 .61392 Mdot
.016 w
.91988 .61392 m
.92146 .6065 L
s
.008 w
.92146 .6065 Mdot
.016 w
.92146 .6065 m
.92301 .6002 L
s
.008 w
.92301 .6002 Mdot
.016 w
.92301 .6002 m
.92451 .59324 L
s
.008 w
.92451 .59324 Mdot
.016 w
.92451 .59324 m
.92595 .58623 L
s
1 .322 0 r
.008 w
.92595 .58623 Mdot
.016 w
.92595 .58623 m
.92732 .57917 L
s
.008 w
.92732 .57917 Mdot
.016 w
.92732 .57917 m
.9286 .57288 L
s
.008 w
.9286 .57288 Mdot
.016 w
.9286 .57288 m
.92978 .56666 L
s
.008 w
.92978 .56666 Mdot
.016 w
.92978 .56666 m
.93091 .56036 L
s
.008 w
.93091 .56036 Mdot
.016 w
.93091 .56036 m
.93183 .55563 L
s
1 .321 0 r
.008 w
.93183 .55563 Mdot
.016 w
.93183 .55563 m
.93266 .5512 L
s
.008 w
.93266 .5512 Mdot
.016 w
.93266 .5512 m
.93333 .54732 L
s
.008 w
.93333 .54732 Mdot
.016 w
.93333 .54732 m
.93386 .54437 L
s
.008 w
.93386 .54437 Mdot
.016 w
.93386 .54437 m
.93426 .54205 L
s
.008 w
.93426 .54205 Mdot
.016 w
.93426 .54205 m
.93452 .54049 L
s
1 .32 0 r
.008 w
.93452 .54049 Mdot
.016 w
.93452 .54049 m
.93467 .53958 L
s
.008 w
.93467 .53958 Mdot
.016 w
.93467 .53958 m
.93474 .53921 L
s
.008 w
.93474 .53921 Mdot
.016 w
.93474 .53921 m
.93476 .5393 L
s
.008 w
.93476 .5393 Mdot
.016 w
.93476 .5393 m
.93474 .53976 L
s
.008 w
.93474 .53976 Mdot
.016 w
.93474 .53976 m
.9347 .54044 L
s
1 .319 0 r
.008 w
.9347 .54044 Mdot
.016 w
.9347 .54044 m
.93467 .5412 L
s
.008 w
.93467 .5412 Mdot
.016 w
.93467 .5412 m
.93466 .54191 L
s
.008 w
.93466 .54191 Mdot
.016 w
.93466 .54191 m
.93466 .54243 L
s
.008 w
.93466 .54243 Mdot
.016 w
.93466 .54243 m
.93467 .54268 L
s
.008 w
.93467 .54268 Mdot
.016 w
.93467 .54268 m
.93469 .54256 L
s
.008 w
.93469 .54256 Mdot
.016 w
.93469 .54256 m
.93468 .54197 L
s
1 .318 0 r
.008 w
.93468 .54197 Mdot
.016 w
.93468 .54197 m
.93464 .54083 L
s
.008 w
.93464 .54083 Mdot
.016 w
.93464 .54083 m
.93454 .53912 L
s
.008 w
.93454 .53912 Mdot
.016 w
.93454 .53912 m
.93438 .53679 L
s
.008 w
.93438 .53679 Mdot
.016 w
.93438 .53679 m
.93414 .53381 L
s
.008 w
.93414 .53381 Mdot
.016 w
.93414 .53381 m
.93383 .53009 L
s
1 .317 0 r
.008 w
.93383 .53009 Mdot
.016 w
.93383 .53009 m
.93342 .52557 L
s
.008 w
.93342 .52557 Mdot
.016 w
.93342 .52557 m
.93294 .5206 L
s
.008 w
.93294 .5206 Mdot
.016 w
.93294 .5206 m
.9324 .51471 L
s
.008 w
.9324 .51471 Mdot
.016 w
.9324 .51471 m
.93179 .50864 L
s
.008 w
.93179 .50864 Mdot
.016 w
.93179 .50864 m
.93115 .50199 L
s
1 .316 0 r
.008 w
.93115 .50199 Mdot
.016 w
.93115 .50199 m
.93046 .49482 L
s
.008 w
.93046 .49482 Mdot
.016 w
.93046 .49482 m
.92977 .48774 L
s
.008 w
.92977 .48774 Mdot
.016 w
.92977 .48774 m
.92907 .48048 L
s
.008 w
.92907 .48048 Mdot
.016 w
.92907 .48048 m
.92836 .47332 L
s
.008 w
.92836 .47332 Mdot
.016 w
.92836 .47332 m
.92768 .4655 L
s
1 .315 0 r
.008 w
.92768 .4655 Mdot
.016 w
.92768 .4655 m
.92705 .45877 L
s
.008 w
.92705 .45877 Mdot
.016 w
.92705 .45877 m
.92646 .45199 L
s
.008 w
.92646 .45199 Mdot
.016 w
.92646 .45199 m
.92593 .44539 L
s
.008 w
.92593 .44539 Mdot
.016 w
.92593 .44539 m
.92545 .43899 L
s
.008 w
.92545 .43899 Mdot
.016 w
.92545 .43899 m
.92501 .43263 L
s
.008 w
.92501 .43263 Mdot
.016 w
.92501 .43263 m
.92462 .42698 L
s
1 .314 0 r
.008 w
.92462 .42698 Mdot
.016 w
.92462 .42698 m
.92424 .42142 L
s
.008 w
.92424 .42142 Mdot
.016 w
.92424 .42142 m
.92386 .41622 L
s
.008 w
.92386 .41622 Mdot
.016 w
.92386 .41622 m
.92347 .41118 L
s
.008 w
.92347 .41118 Mdot
.016 w
.92347 .41118 m
.92304 .40623 L
s
.008 w
.92304 .40623 Mdot
.016 w
.92304 .40623 m
.92258 .40132 L
s
1 .313 0 r
.008 w
.92258 .40132 Mdot
.016 w
.92258 .40132 m
.92207 .39629 L
s
.008 w
.92207 .39629 Mdot
.016 w
.92207 .39629 m
.92151 .39148 L
s
.008 w
.92151 .39148 Mdot
.016 w
.92151 .39148 m
.9209 .38643 L
s
.008 w
.9209 .38643 Mdot
.016 w
.9209 .38643 m
.92022 .38132 L
s
.008 w
.92022 .38132 Mdot
.016 w
.92022 .38132 m
.91948 .37577 L
s
1 .312 0 r
.008 w
.91948 .37577 Mdot
.016 w
.91948 .37577 m
.9187 .37064 L
s
.008 w
.9187 .37064 Mdot
.016 w
.9187 .37064 m
.91785 .3651 L
s
.008 w
.91785 .3651 Mdot
.016 w
.91785 .3651 m
.91695 .35927 L
s
.008 w
.91695 .35927 Mdot
.016 w
.91695 .35927 m
.91605 .35383 L
s
.008 w
.91605 .35383 Mdot
.016 w
.91605 .35383 m
.91518 .34831 L
s
1 .311 0 r
.008 w
.91518 .34831 Mdot
.016 w
.91518 .34831 m
.91435 .34318 L
s
.008 w
.91435 .34318 Mdot
.016 w
.91435 .34318 m
.91361 .33831 L
s
.008 w
.91361 .33831 Mdot
.016 w
.91361 .33831 m
.91297 .33422 L
s
.008 w
.91297 .33422 Mdot
.016 w
.91297 .33422 m
.91243 .33058 L
s
.008 w
.91243 .33058 Mdot
.016 w
.91243 .33058 m
.91201 .3275 L
s
.008 w
.91201 .3275 Mdot
.016 w
.91201 .3275 m
.91169 .32498 L
s
1 .31 0 r
.008 w
.91169 .32498 Mdot
.016 w
.91169 .32498 m
.91148 .3231 L
s
.008 w
.91148 .3231 Mdot
.016 w
.91148 .3231 m
.91138 .32169 L
s
.008 w
.91138 .32169 Mdot
.016 w
.91138 .32169 m
.91136 .32065 L
s
.008 w
.91136 .32065 Mdot
.016 w
.91136 .32065 m
.91137 .31985 L
s
.008 w
.91137 .31985 Mdot
.016 w
.91137 .31985 m
.9114 .31916 L
s
1 .309 0 r
.008 w
.9114 .31916 Mdot
.016 w
.9114 .31916 m
.91139 .31841 L
s
.008 w
.91139 .31841 Mdot
.016 w
.91139 .31841 m
.91126 .3174 L
s
.008 w
.91126 .3174 Mdot
.016 w
.91126 .3174 m
.91096 .31604 L
s
.008 w
.91096 .31604 Mdot
.016 w
.91096 .31604 m
.91046 .31427 L
s
.008 w
.91046 .31427 Mdot
.016 w
.91046 .31427 m
.90976 .31232 L
s
1 .308 0 r
.008 w
.90976 .31232 Mdot
.016 w
.90976 .31232 m
.90884 .30986 L
s
.008 w
.90884 .30986 Mdot
.016 w
.90884 .30986 m
.90768 .3069 L
s
.008 w
.90768 .3069 Mdot
.016 w
.90768 .3069 m
.9063 .30364 L
s
.008 w
.9063 .30364 Mdot
.016 w
.9063 .30364 m
.90478 .29993 L
s
.008 w
.90478 .29993 Mdot
.016 w
.90478 .29993 m
.90308 .29643 L
s
.008 w
.90308 .29643 Mdot
.016 w
.90308 .29643 m
.90125 .29271 L
s
1 .307 0 r
.008 w
.90125 .29271 Mdot
.016 w
.90125 .29271 m
.89927 .28887 L
s
.008 w
.89927 .28887 Mdot
.016 w
.89927 .28887 m
.89714 .2851 L
s
.008 w
.89714 .2851 Mdot
.016 w
.89714 .2851 m
.89505 .28147 L
s
.008 w
.89505 .28147 Mdot
.016 w
.89505 .28147 m
.89284 .27773 L
s
.008 w
.89284 .27773 Mdot
.016 w
.89284 .27773 m
.89058 .27405 L
s
1 .306 0 r
.008 w
.89058 .27405 Mdot
.016 w
.89058 .27405 m
.88829 .27036 L
s
.008 w
.88829 .27036 Mdot
.016 w
.88829 .27036 m
.88601 .2666 L
s
.008 w
.88601 .2666 Mdot
.016 w
.88601 .2666 m
.88365 .26277 L
s
.008 w
.88365 .26277 Mdot
.016 w
.88365 .26277 m
.88123 .25882 L
s
.008 w
.88123 .25882 Mdot
.016 w
.88123 .25882 m
.87869 .25454 L
s
1 .305 0 r
.008 w
.87869 .25454 Mdot
.016 w
.87869 .25454 m
.8761 .25038 L
s
.008 w
.8761 .25038 Mdot
.016 w
.8761 .25038 m
.87334 .24556 L
s
.008 w
.87334 .24556 Mdot
.016 w
.87334 .24556 m
.87058 .24117 L
s
.008 w
.87058 .24117 Mdot
.016 w
.87058 .24117 m
.86772 .23657 L
s
.008 w
.86772 .23657 Mdot
.016 w
.86772 .23657 m
.86482 .2318 L
s
1 .304 0 r
.008 w
.86482 .2318 Mdot
.016 w
.86482 .2318 m
.86189 .2271 L
s
.008 w
.86189 .2271 Mdot
.016 w
.86189 .2271 m
.85893 .22227 L
s
.008 w
.85893 .22227 Mdot
.016 w
.85893 .22227 m
.85596 .21764 L
s
.008 w
.85596 .21764 Mdot
.016 w
.85596 .21764 m
.85298 .21298 L
s
.008 w
.85298 .21298 Mdot
.016 w
.85298 .21298 m
.84996 .2082 L
s
.008 w
.84996 .2082 Mdot
.016 w
.84996 .2082 m
.84703 .20378 L
s
1 .303 0 r
.008 w
.84703 .20378 Mdot
.016 w
.84703 .20378 m
.84411 .19923 L
s
.008 w
.84411 .19923 Mdot
.016 w
.84411 .19923 m
.84121 .19497 L
s
.008 w
.84121 .19497 Mdot
.016 w
.84121 .19497 m
.83832 .19064 L
s
.008 w
.83832 .19064 Mdot
.016 w
.83832 .19064 m
.83551 .18654 L
s
.008 w
.83551 .18654 Mdot
.016 w
.83551 .18654 m
.83269 .18248 L
s
1 .302 0 r
.008 w
.83269 .18248 Mdot
.016 w
.83269 .18248 m
.82983 .17827 L
s
.008 w
.82983 .17827 Mdot
.016 w
.82983 .17827 m
.82692 .1744 L
s
.008 w
.82692 .1744 Mdot
.016 w
.82692 .1744 m
.82404 .17048 L
s
.008 w
.82404 .17048 Mdot
.016 w
.82404 .17048 m
.82105 .16642 L
s
.008 w
.82105 .16642 Mdot
.016 w
.82105 .16642 m
.81799 .16234 L
s
1 .301 0 r
.008 w
.81799 .16234 Mdot
.016 w
.81799 .16234 m
.81475 .15806 L
s
.008 w
.81475 .15806 Mdot
.016 w
.81475 .15806 m
.8118 .15408 L
s
.008 w
.8118 .15408 Mdot
.016 w
.8118 .15408 m
.80865 .14997 L
s
.008 w
.80865 .14997 Mdot
.016 w
.80865 .14997 m
.8055 .14579 L
s
.008 w
.8055 .14579 Mdot
.016 w
.8055 .14579 m
.80268 .14201 L
s
1 .3 0 r
.008 w
.80268 .14201 Mdot
.016 w
.80268 .14201 m
.79975 .13816 L
s
.008 w
.79975 .13816 Mdot
.016 w
.79975 .13816 m
.79698 .13445 L
s
.008 w
.79698 .13445 Mdot
.016 w
.79698 .13445 m
.79433 .1311 L
s
.008 w
.79433 .1311 Mdot
.016 w
.79433 .1311 m
.792 .12802 L
s
.008 w
.792 .12802 Mdot
.016 w
.792 .12802 m
.78987 .12534 L
s
.008 w
.78987 .12534 Mdot
.016 w
.78987 .12534 m
.78809 .12309 L
s
1 .299 0 r
.008 w
.78809 .12309 Mdot
.016 w
.78809 .12309 m
.78664 .12134 L
s
.008 w
.78664 .12134 Mdot
.016 w
.78664 .12134 m
.78548 .12001 L
s
.008 w
.78548 .12001 Mdot
.016 w
.78548 .12001 m
.78461 .11911 L
s
.008 w
.78461 .11911 Mdot
.016 w
.78461 .11911 m
.78398 .11856 L
s
.008 w
.78398 .11856 Mdot
.016 w
.78398 .11856 m
.78355 .11829 L
s
1 .298 0 r
.008 w
.78355 .11829 Mdot
.016 w
.78355 .11829 m
.7833 .11825 L
s
.008 w
.7833 .11825 Mdot
.016 w
.7833 .11825 m
.78318 .11837 L
s
.008 w
.78318 .11837 Mdot
.016 w
.78318 .11837 m
.78317 .11859 L
s
.008 w
.78317 .11859 Mdot
.016 w
.78317 .11859 m
.78323 .1189 L
s
.008 w
.78323 .1189 Mdot
.016 w
.78323 .1189 m
.78334 .11922 L
s
1 .297 0 r
.008 w
.78334 .11922 Mdot
.016 w
.78334 .11922 m
.78346 .11954 L
s
.008 w
.78346 .11954 Mdot
.016 w
.78346 .11954 m
.7836 .11982 L
s
.008 w
.7836 .11982 Mdot
.016 w
.7836 .11982 m
.7837 .12004 L
s
.008 w
.7837 .12004 Mdot
.016 w
.7837 .12004 m
.78378 .12021 L
s
.008 w
.78378 .12021 Mdot
.016 w
.78378 .12021 m
.78383 .12033 L
s
1 .296 0 r
.008 w
.78383 .12033 Mdot
.016 w
.78383 .12033 m
.78386 .12039 L
s
.008 w
.78386 .12039 Mdot
.016 w
.78386 .12039 m
.78387 .12041 L
s
.008 w
.78387 .12041 Mdot
.016 w
.78387 .12041 m
.78386 .1204 L
s
.008 w
.78386 .1204 Mdot
.016 w
.78386 .1204 m
.78385 .12036 L
s
.008 w
.78385 .12036 Mdot
.016 w
.78385 .12036 m
.78384 .12031 L
s
.008 w
.78384 .12031 Mdot
.016 w
.78384 .12031 m
.78383 .12028 L
s
1 .295 0 r
.008 w
.78383 .12028 Mdot
.016 w
.78383 .12028 m
.78383 .12028 L
s
.008 w
.78383 .12028 Mdot
.016 w
.78383 .12028 m
.78383 .12028 L
s
.008 w
.78383 .12028 Mdot
.016 w
.78383 .12028 m
.78385 .12031 L
s
.008 w
.78385 .12031 Mdot
.016 w
.78385 .12031 m
.78387 .12036 L
s
.008 w
.78387 .12036 Mdot
.016 w
.78387 .12036 m
.78391 .12043 L
s
1 .294 0 r
.008 w
.78391 .12043 Mdot
.016 w
.78391 .12043 m
.78398 .12049 L
s
.008 w
.78398 .12049 Mdot
.016 w
.78398 .12049 m
.7841 .12054 L
s
.008 w
.7841 .12054 Mdot
.016 w
.7841 .12054 m
.78423 .12055 L
s
.008 w
.78423 .12055 Mdot
.016 w
.78423 .12055 m
.78433 .12049 L
s
.008 w
.78433 .12049 Mdot
.016 w
.78433 .12049 m
.78436 .12035 L
s
1 .293 0 r
.008 w
.78436 .12035 Mdot
.016 w
.78436 .12035 m
.78428 .1201 L
s
.008 w
.78428 .1201 Mdot
.016 w
.78428 .1201 m
.78406 .11976 L
s
.008 w
.78406 .11976 Mdot
.016 w
.78406 .11976 m
.78365 .11934 L
s
.008 w
.78365 .11934 Mdot
.016 w
.78365 .11934 m
.78302 .11884 L
s
.008 w
.78302 .11884 Mdot
.016 w
.78302 .11884 m
.78215 .11828 L
s
1 .292 0 r
.008 w
.78215 .11828 Mdot
.016 w
.78215 .11828 m
.78106 .11767 L
s
.008 w
.78106 .11767 Mdot
.016 w
.78106 .11767 m
.77975 .11702 L
s
.008 w
.77975 .11702 Mdot
.016 w
.77975 .11702 m
.77829 .11634 L
s
.008 w
.77829 .11634 Mdot
.016 w
.77829 .11634 m
.77675 .11566 L
s
.008 w
.77675 .11566 Mdot
.016 w
.77675 .11566 m
.77508 .11503 L
s
.008 w
.77508 .11503 Mdot
.016 w
.77508 .11503 m
.77335 .11452 L
s
1 .291 0 r
.008 w
.77335 .11452 Mdot
.016 w
.77335 .11452 m
.77148 .11416 L
s
.008 w
.77148 .11416 Mdot
.016 w
.77148 .11416 m
.76954 .11395 L
s
.008 w
.76954 .11395 Mdot
.016 w
.76954 .11395 m
.76755 .11391 L
s
.008 w
.76755 .11391 Mdot
.016 w
.76755 .11391 m
.76566 .11402 L
s
.008 w
.76566 .11402 Mdot
.016 w
.76566 .11402 m
.76385 .11423 L
s
1 .29 0 r
.008 w
.76385 .11423 Mdot
.016 w
.76385 .11423 m
.7622 .11452 L
s
.008 w
.7622 .11452 Mdot
.016 w
.7622 .11452 m
.76079 .11487 L
s
.008 w
.76079 .11487 Mdot
.016 w
.76079 .11487 m
.75975 .11523 L
s
.008 w
.75975 .11523 Mdot
.016 w
.75975 .11523 m
.7589 .11558 L
s
.008 w
.7589 .11558 Mdot
.016 w
.7589 .11558 m
.75813 .11587 L
s
1 .289 0 r
.008 w
.75813 .11587 Mdot
.016 w
.75813 .11587 m
.75749 .11605 L
s
.008 w
.75749 .11605 Mdot
.016 w
.75749 .11605 m
.75689 .1161 L
s
.008 w
.75689 .1161 Mdot
.016 w
.75689 .1161 m
.7563 .11592 L
s
.008 w
.7563 .11592 Mdot
.016 w
.7563 .11592 m
.75568 .11547 L
s
.008 w
.75568 .11547 Mdot
.016 w
.75568 .11547 m
.75499 .11472 L
s
.008 w
.75499 .11472 Mdot
.016 w
.75499 .11472 m
.75418 .11363 L
s
1 .288 0 r
.008 w
.75418 .11363 Mdot
.016 w
.75418 .11363 m
.75312 .1122 L
s
.008 w
.75312 .1122 Mdot
.016 w
.75312 .1122 m
.75173 .11043 L
s
.008 w
.75173 .11043 Mdot
.016 w
.75173 .11043 m
.74993 .10834 L
s
.008 w
.74993 .10834 Mdot
.016 w
.74993 .10834 m
.74782 .10631 L
s
.008 w
.74782 .10631 Mdot
.016 w
.74782 .10631 m
.74503 .10397 L
s
1 .287 0 r
.008 w
.74503 .10397 Mdot
.016 w
.74503 .10397 m
.74189 .1015 L
s
.008 w
.74189 .1015 Mdot
.016 w
.74189 .1015 m
.73793 .09887 L
s
.008 w
.73793 .09887 Mdot
.016 w
.73793 .09887 m
.73366 .09604 L
s
.008 w
.73366 .09604 Mdot
.016 w
.73366 .09604 m
.72869 .09322 L
s
.008 w
.72869 .09322 Mdot
.016 w
.72869 .09322 m
.72387 .09034 L
s
1 .286 0 r
.008 w
.72387 .09034 Mdot
.016 w
.72387 .09034 m
.71845 .08743 L
s
.008 w
.71845 .08743 Mdot
.016 w
.71845 .08743 m
.71264 .08448 L
s
.008 w
.71264 .08448 Mdot
.016 w
.71264 .08448 m
.70707 .08166 L
s
.008 w
.70707 .08166 Mdot
.016 w
.70707 .08166 m
.70119 .07887 L
s
.008 w
.70119 .07887 Mdot
.016 w
.70119 .07887 m
.69527 .07622 L
s
1 .285 0 r
.008 w
.69527 .07622 Mdot
.016 w
.69527 .07622 m
.68909 .07354 L
s
.008 w
.68909 .07354 Mdot
.016 w
.68909 .07354 m
.68349 .07103 L
s
.008 w
.68349 .07103 Mdot
.016 w
.68349 .07103 m
.67773 .06853 L
s
.008 w
.67773 .06853 Mdot
.016 w
.67773 .06853 m
.6717 .06606 L
s
.008 w
.6717 .06606 Mdot
.016 w
.6717 .06606 m
.66605 .06355 L
s
.008 w
.66605 .06355 Mdot
.016 w
.66605 .06355 m
.66095 .06131 L
s
1 .284 0 r
.008 w
.66095 .06131 Mdot
.016 w
.66095 .06131 m
.65544 .05901 L
s
.008 w
.65544 .05901 Mdot
.016 w
.65544 .05901 m
.65001 .05676 L
s
.008 w
.65001 .05676 Mdot
.016 w
.65001 .05676 m
.64428 .05448 L
s
.008 w
.64428 .05448 Mdot
.016 w
.64428 .05448 m
.63902 .05244 L
s
.008 w
.63902 .05244 Mdot
.016 w
.63902 .05244 m
.63387 .05034 L
s
1 .283 0 r
.008 w
.63387 .05034 Mdot
.016 w
.63387 .05034 m
.62868 .04837 L
s
.008 w
.62868 .04837 Mdot
.016 w
.62868 .04837 m
.62331 .0464 L
s
.008 w
.62331 .0464 Mdot
.016 w
.62331 .0464 m
.61824 .04455 L
s
.008 w
.61824 .04455 Mdot
.016 w
.61824 .04455 m
.61286 .0429 L
s
.008 w
.61286 .0429 Mdot
.016 w
.61286 .0429 m
.6078 .04135 L
s
1 .282 0 r
.008 w
.6078 .04135 Mdot
.016 w
.6078 .04135 m
.60277 .03994 L
s
.008 w
.60277 .03994 Mdot
.016 w
.60277 .03994 m
.59789 .03874 L
s
.008 w
.59789 .03874 Mdot
.016 w
.59789 .03874 m
.59297 .03777 L
s
.008 w
.59297 .03777 Mdot
.016 w
.59297 .03777 m
.58863 .03701 L
s
.008 w
.58863 .03701 Mdot
.016 w
.58863 .03701 m
.58409 .03644 L
s
1 .281 0 r
.008 w
.58409 .03644 Mdot
.016 w
.58409 .03644 m
.58009 .03603 L
s
.008 w
.58009 .03603 Mdot
.016 w
.58009 .03603 m
.57574 .03574 L
s
.008 w
.57574 .03574 Mdot
.016 w
.57574 .03574 m
.57194 .03553 L
s
.008 w
.57194 .03553 Mdot
.016 w
.57194 .03553 m
.56787 .03539 L
s
.008 w
.56787 .03539 Mdot
.016 w
.56787 .03539 m
.56379 .0353 L
s
.008 w
.56379 .0353 Mdot
.016 w
.56379 .0353 m
.55953 .03523 L
s
1 .28 0 r
.008 w
.55953 .03523 Mdot
.016 w
.55953 .03523 m
.55513 .03516 L
s
.008 w
.55513 .03516 Mdot
.016 w
.55513 .03516 m
.55053 .03508 L
s
.008 w
.55053 .03508 Mdot
.016 w
.55053 .03508 m
.54572 .03498 L
s
.008 w
.54572 .03498 Mdot
.016 w
.54572 .03498 m
.54078 .03484 L
s
.008 w
.54078 .03484 Mdot
.016 w
.54078 .03484 m
.53561 .03467 L
s
1 .279 0 r
.008 w
.53561 .03467 Mdot
.016 w
.53561 .03467 m
.53019 .0345 L
s
.008 w
.53019 .0345 Mdot
.016 w
.53019 .0345 m
.52439 .03432 L
s
.008 w
.52439 .03432 Mdot
.016 w
.52439 .03432 m
.51898 .03412 L
s
.008 w
.51898 .03412 Mdot
.016 w
.51898 .03412 m
.51316 .03391 L
s
.008 w
.51316 .03391 Mdot
.016 w
.51316 .03391 m
.5073 .03367 L
s
1 .278 0 r
.008 w
.5073 .03367 Mdot
.016 w
.5073 .03367 m
.50133 .03341 L
s
.008 w
.50133 .03341 Mdot
.016 w
.50133 .03341 m
.49551 .03316 L
s
.008 w
.49551 .03316 Mdot
.016 w
.49551 .03316 m
.48982 .03295 L
s
.008 w
.48982 .03295 Mdot
.016 w
.48982 .03295 m
.48398 .03279 L
s
.008 w
.48398 .03279 Mdot
.016 w
.48398 .03279 m
.47879 .03272 L
s
1 .277 0 r
.008 w
.47879 .03272 Mdot
.016 w
.47879 .03272 m
.47341 .03272 L
s
.008 w
.47341 .03272 Mdot
.016 w
.47341 .03272 m
.46818 .03281 L
s
.008 w
.46818 .03281 Mdot
.016 w
.46818 .03281 m
.46293 .03298 L
s
.008 w
.46293 .03298 Mdot
.016 w
.46293 .03298 m
.45796 .0332 L
s
.008 w
.45796 .0332 Mdot
.016 w
.45796 .0332 m
.45304 .03346 L
s
.008 w
.45304 .03346 Mdot
.016 w
.45304 .03346 m
.44812 .03376 L
s
1 .276 0 r
.008 w
.44812 .03376 Mdot
.016 w
.44812 .03376 m
.44356 .03406 L
s
.008 w
.44356 .03406 Mdot
.016 w
.44356 .03406 m
.43889 .03434 L
s
.008 w
.43889 .03434 Mdot
.016 w
.43889 .03434 m
.43471 .03459 L
s
.008 w
.43471 .03459 Mdot
.016 w
.43471 .03459 m
.43066 .0348 L
s
.008 w
.43066 .0348 Mdot
.016 w
.43066 .0348 m
.42665 .03496 L
s
1 .275 0 r
.008 w
.42665 .03496 Mdot
.016 w
.42665 .03496 m
.42354 .03508 L
s
.008 w
.42354 .03508 Mdot
.016 w
.42354 .03508 m
.42063 .03517 L
s
.008 w
.42063 .03517 Mdot
.016 w
.42063 .03517 m
.41795 .03522 L
s
.008 w
.41795 .03522 Mdot
.016 w
.41795 .03522 m
.41571 .03523 L
s
.008 w
.41571 .03523 Mdot
.016 w
.41571 .03523 m
.41371 .03522 L
s
1 .274 0 r
.008 w
.41371 .03522 Mdot
.016 w
.41371 .03522 m
.41192 .03524 L
s
.008 w
.41192 .03524 Mdot
.016 w
.41192 .03524 m
.4103 .03535 L
s
.008 w
.4103 .03535 Mdot
.016 w
.4103 .03535 m
.40867 .03562 L
s
.008 w
.40867 .03562 Mdot
.016 w
.40867 .03562 m
.40693 .0361 L
s
.008 w
.40693 .0361 Mdot
.016 w
.40693 .0361 m
.40505 .03682 L
s
.008 w
.40505 .03682 Mdot
.016 w
.40505 .03682 m
.4028 .03777 L
s
1 .273 0 r
.008 w
.4028 .03777 Mdot
.016 w
.4028 .03777 m
.40008 .03899 L
s
.008 w
.40008 .03899 Mdot
.016 w
.40008 .03899 m
.3972 .04051 L
s
.008 w
.3972 .04051 Mdot
.016 w
.3972 .04051 m
.39371 .04228 L
s
.008 w
.39371 .04228 Mdot
.016 w
.39371 .04228 m
.38987 .04434 L
s
.008 w
.38987 .04434 Mdot
.016 w
.38987 .04434 m
.38577 .04648 L
s
1 .272 0 r
.008 w
.38577 .04648 Mdot
.016 w
.38577 .04648 m
.38132 .04881 L
s
.008 w
.38132 .04881 Mdot
.016 w
.38132 .04881 m
.37639 .05143 L
s
.008 w
.37639 .05143 Mdot
.016 w
.37639 .05143 m
.37177 .054 L
s
.008 w
.37177 .054 Mdot
.016 w
.37177 .054 m
.3668 .05679 L
s
.008 w
.3668 .05679 Mdot
.016 w
.3668 .05679 m
.36182 .05969 L
s
1 .271 0 r
.008 w
.36182 .05969 Mdot
.016 w
.36182 .05969 m
.35657 .06275 L
s
.008 w
.35657 .06275 Mdot
.016 w
.35657 .06275 m
.35185 .0657 L
s
.008 w
.35185 .0657 Mdot
.016 w
.35185 .0657 m
.34695 .06874 L
s
.008 w
.34695 .06874 Mdot
.016 w
.34695 .06874 m
.34213 .07172 L
s
.008 w
.34213 .07172 Mdot
.016 w
.34213 .07172 m
.33718 .07479 L
s
1 .27 0 r
.008 w
.33718 .07479 Mdot
.016 w
.33718 .07479 m
.33259 .07761 L
s
.008 w
.33259 .07761 Mdot
.016 w
.33259 .07761 m
.32751 .08061 L
s
.008 w
.32751 .08061 Mdot
.016 w
.32751 .08061 m
.32271 .08369 L
s
.008 w
.32271 .08369 Mdot
.016 w
.32271 .08369 m
.31806 .08672 L
s
.008 w
.31806 .08672 Mdot
.016 w
.31806 .08672 m
.31268 .08998 L
s
.008 w
.31268 .08998 Mdot
.016 w
.31268 .08998 m
.30798 .09322 L
s
1 .269 0 r
.008 w
.30798 .09322 Mdot
.016 w
.30798 .09322 m
.30275 .09657 L
s
.008 w
.30275 .09657 Mdot
.016 w
.30275 .09657 m
.29752 .09996 L
s
.008 w
.29752 .09996 Mdot
.016 w
.29752 .09996 m
.29226 .10334 L
s
.008 w
.29226 .10334 Mdot
.016 w
.29226 .10334 m
.28695 .10675 L
s
.008 w
.28695 .10675 Mdot
.016 w
.28695 .10675 m
.28216 .1101 L
s
1 .268 0 r
.008 w
.28216 .1101 Mdot
.016 w
.28216 .1101 m
.27712 .11342 L
s
.008 w
.27712 .11342 Mdot
.016 w
.27712 .11342 m
.27219 .11674 L
s
.008 w
.27219 .11674 Mdot
.016 w
.27219 .11674 m
.26707 .12014 L
s
.008 w
.26707 .12014 Mdot
.016 w
.26707 .12014 m
.26275 .12334 L
s
.008 w
.26275 .12334 Mdot
.016 w
.26275 .12334 m
.25834 .12662 L
s
1 .267 0 r
.008 w
.25834 .12662 Mdot
.016 w
.25834 .12662 m
.2542 .12987 L
s
.008 w
.2542 .12987 Mdot
.016 w
.2542 .12987 m
.25028 .13311 L
s
.008 w
.25028 .13311 Mdot
.016 w
.25028 .13311 m
.24665 .13637 L
s
.008 w
.24665 .13637 Mdot
.016 w
.24665 .13637 m
.24314 .13969 L
s
.008 w
.24314 .13969 Mdot
.016 w
.24314 .13969 m
.23976 .14319 L
s
1 .266 0 r
.008 w
.23976 .14319 Mdot
.016 w
.23976 .14319 m
.23665 .14671 L
s
.008 w
.23665 .14671 Mdot
.016 w
.23665 .14671 m
.23347 .15042 L
s
.008 w
.23347 .15042 Mdot
.016 w
.23347 .15042 m
.23021 .15447 L
s
.008 w
.23021 .15447 Mdot
.016 w
.23021 .15447 m
.22712 .15852 L
s
.008 w
.22712 .15852 Mdot
.016 w
.22712 .15852 m
.224 .16276 L
s
.008 w
.224 .16276 Mdot
.016 w
.224 .16276 m
.22082 .16723 L
s
1 .265 0 r
.008 w
.22082 .16723 Mdot
.016 w
.22082 .16723 m
.21772 .17188 L
s
.008 w
.21772 .17188 Mdot
.016 w
.21772 .17188 m
.21464 .17671 L
s
.008 w
.21464 .17671 Mdot
.016 w
.21464 .17671 m
.21162 .18159 L
s
.008 w
.21162 .18159 Mdot
.016 w
.21162 .18159 m
.20864 .18646 L
s
.008 w
.20864 .18646 Mdot
.016 w
.20864 .18646 m
.20553 .19174 L
s
1 .264 0 r
.008 w
.20553 .19174 Mdot
.016 w
.20553 .19174 m
.20267 .19646 L
s
.008 w
.20267 .19646 Mdot
.016 w
.20267 .19646 m
.19969 .20149 L
s
.008 w
.19969 .20149 Mdot
.016 w
.19969 .20149 m
.19664 .2065 L
s
.008 w
.19664 .2065 Mdot
.016 w
.19664 .2065 m
.19365 .21183 L
s
.008 w
.19365 .21183 Mdot
.016 w
.19365 .21183 m
.19067 .2165 L
s
1 .263 0 r
.008 w
.19067 .2165 Mdot
.016 w
.19067 .2165 m
.18755 .22177 L
s
.008 w
.18755 .22177 Mdot
.016 w
.18755 .22177 m
.18463 .22668 L
s
.008 w
.18463 .22668 Mdot
.016 w
.18463 .22668 m
.18154 .23195 L
s
.008 w
.18154 .23195 Mdot
.016 w
.18154 .23195 m
.17863 .23712 L
s
.008 w
.17863 .23712 Mdot
.016 w
.17863 .23712 m
.17559 .24243 L
s
1 .262 0 r
.008 w
.17559 .24243 Mdot
.016 w
.17559 .24243 m
.17254 .24768 L
s
.008 w
.17254 .24768 Mdot
.016 w
.17254 .24768 m
.16959 .25284 L
s
.008 w
.16959 .25284 Mdot
.016 w
.16959 .25284 m
.16674 .25786 L
s
.008 w
.16674 .25786 Mdot
.016 w
.16674 .25786 m
.16414 .26289 L
s
.008 w
.16414 .26289 Mdot
.016 w
.16414 .26289 m
.16163 .26782 L
s
.008 w
.16163 .26782 Mdot
.016 w
.16163 .26782 m
.15918 .2721 L
s
1 .261 0 r
.008 w
.15918 .2721 Mdot
.016 w
.15918 .2721 m
.15692 .27644 L
s
.008 w
.15692 .27644 Mdot
.016 w
.15692 .27644 m
.15457 .281 L
s
.008 w
.15457 .281 Mdot
.016 w
.15457 .281 m
.15258 .28473 L
s
.008 w
.15258 .28473 Mdot
.016 w
.15258 .28473 m
.15054 .2885 L
s
.008 w
.15054 .2885 Mdot
.016 w
.15054 .2885 m
.14847 .29234 L
s
1 .26 0 r
.008 w
.14847 .29234 Mdot
.016 w
.14847 .29234 m
.14668 .29586 L
s
.008 w
.14668 .29586 Mdot
.016 w
.14668 .29586 m
.14483 .29952 L
s
.008 w
.14483 .29952 Mdot
.016 w
.14483 .29952 m
.14311 .30301 L
s
.008 w
.14311 .30301 Mdot
.016 w
.14311 .30301 m
.1414 .30655 L
s
.008 w
.1414 .30655 Mdot
.016 w
.1414 .30655 m
.13974 .31037 L
s
1 .259 0 r
.008 w
.13974 .31037 Mdot
.016 w
.13974 .31037 m
.13824 .31419 L
s
.008 w
.13824 .31419 Mdot
.016 w
.13824 .31419 m
.13675 .31831 L
s
.008 w
.13675 .31831 Mdot
.016 w
.13675 .31831 m
.13528 .32265 L
s
.008 w
.13528 .32265 Mdot
.016 w
.13528 .32265 m
.13393 .32726 L
s
.008 w
.13393 .32726 Mdot
.016 w
.13393 .32726 m
.13262 .33199 L
s
1 .258 0 r
.008 w
.13262 .33199 Mdot
.016 w
.13262 .33199 m
.13146 .337 L
s
.008 w
.13146 .337 Mdot
.016 w
.13146 .337 m
.13036 .34224 L
s
.008 w
.13036 .34224 Mdot
.016 w
.13036 .34224 m
.12935 .34734 L
s
.008 w
.12935 .34734 Mdot
.016 w
.12935 .34734 m
.12837 .35303 L
s
.008 w
.12837 .35303 Mdot
.016 w
.12837 .35303 m
.12745 .35788 L
s
.008 w
.12745 .35788 Mdot
.016 w
.12745 .35788 m
.12659 .36339 L
s
1 .257 0 r
.008 w
.12659 .36339 Mdot
.016 w
.12659 .36339 m
.1258 .36801 L
s
.008 w
.1258 .36801 Mdot
.016 w
.1258 .36801 m
.12511 .37272 L
s
.008 w
.12511 .37272 Mdot
.016 w
.12511 .37272 m
.12458 .37669 L
s
.008 w
.12458 .37669 Mdot
.016 w
.12458 .37669 m
.12419 .38047 L
s
.008 w
.12419 .38047 Mdot
.016 w
.12419 .38047 m
.12393 .38345 L
s
1 .256 0 r
.008 w
.12393 .38345 Mdot
.016 w
.12393 .38345 m
.1238 .38619 L
s
.008 w
.1238 .38619 Mdot
.016 w
.1238 .38619 m
.1238 .38837 L
s
.008 w
.1238 .38837 Mdot
.016 w
.1238 .38837 m
.12397 .39023 L
s
.008 w
.12397 .39023 Mdot
.016 w
.12397 .39023 m
.12431 .39184 L
s
.008 w
.12431 .39184 Mdot
.016 w
.12431 .39184 m
.12485 .39326 L
s
1 .255 0 r
.008 w
.12485 .39326 Mdot
.016 w
.12485 .39326 m
.12558 .39459 L
s
.008 w
.12558 .39459 Mdot
.016 w
.12558 .39459 m
.12648 .39596 L
s
.008 w
.12648 .39596 Mdot
.016 w
.12648 .39596 m
.12751 .39745 L
s
.008 w
.12751 .39745 Mdot
.016 w
.12751 .39745 m
.1286 .39895 L
s
.008 w
.1286 .39895 Mdot
.016 w
.1286 .39895 m
.12973 .40081 L
s
.008 w
.12973 .40081 Mdot
.016 w
.12973 .40081 m
.13087 .403 L
s
1 .254 0 r
.008 w
.13087 .403 Mdot
.016 w
.13087 .403 m
.1319 .40567 L
s
.008 w
.1319 .40567 Mdot
.016 w
.1319 .40567 m
.13295 .40868 L
s
.008 w
.13295 .40868 Mdot
.016 w
.13295 .40868 m
.13386 .41206 L
s
.008 w
.13386 .41206 Mdot
.016 w
.13386 .41206 m
.13469 .41565 L
s
.008 w
.13469 .41565 Mdot
.016 w
.13469 .41565 m
.13538 .4195 L
s
1 .253 0 r
.008 w
.13538 .4195 Mdot
.016 w
.13538 .4195 m
.13585 .42355 L
s
.008 w
.13585 .42355 Mdot
.016 w
.13585 .42355 m
.13607 .4279 L
s
.008 w
.13607 .4279 Mdot
.016 w
.13607 .4279 m
.13598 .43182 L
s
.008 w
.13598 .43182 Mdot
.016 w
.13598 .43182 m
.13557 .43607 L
s
.008 w
.13557 .43607 Mdot
.016 w
.13557 .43607 m
.13488 .44037 L
s
1 .252 0 r
.008 w
.13488 .44037 Mdot
.016 w
.13488 .44037 m
.13394 .44469 L
s
.008 w
.13394 .44469 Mdot
.016 w
.13394 .44469 m
.13283 .44894 L
s
.008 w
.13283 .44894 Mdot
.016 w
.13283 .44894 m
.13158 .45274 L
s
.008 w
.13158 .45274 Mdot
.016 w
.13158 .45274 m
.1304 .45648 L
s
.008 w
.1304 .45648 Mdot
.016 w
.1304 .45648 m
.1291 .45971 L
s
1 .251 0 r
.008 w
.1291 .45971 Mdot
.016 w
.1291 .45971 m
.12768 .46267 L
s
.008 w
.12768 .46267 Mdot
.016 w
.12768 .46267 m
.1264 .46521 L
s
.008 w
.1264 .46521 Mdot
.016 w
.1264 .46521 m
.12511 .46737 L
s
.008 w
.12511 .46737 Mdot
.016 w
.12511 .46737 m
.12387 .46911 L
s
.008 w
.12387 .46911 Mdot
.016 w
.12387 .46911 m
.1228 .4705 L
s
.008 w
.1228 .4705 Mdot
.016 w
.1228 .4705 m
.12186 .47167 L
s
1 .25 0 r
.008 w
.12186 .47167 Mdot
.016 w
.12186 .47167 m
.12107 .47268 L
s
.008 w
.12107 .47268 Mdot
.016 w
.12107 .47268 m
.12042 .47356 L
s
.008 w
.12042 .47356 Mdot
.016 w
.12042 .47356 m
.11993 .47437 L
s
.008 w
.11993 .47437 Mdot
.016 w
.11993 .47437 m
.11955 .47516 L
s
.008 w
.11955 .47516 Mdot
.016 w
.11955 .47516 m
.11924 .47602 L
s
1 .249 0 r
.008 w
.11924 .47602 Mdot
.016 w
.11924 .47602 m
.11898 .47692 L
s
.008 w
.11898 .47692 Mdot
.016 w
.11898 .47692 m
.11874 .47787 L
s
.008 w
.11874 .47787 Mdot
.016 w
.11874 .47787 m
.11852 .47881 L
s
.008 w
.11852 .47881 Mdot
.016 w
.11852 .47881 m
.11831 .47972 L
s
.008 w
.11831 .47972 Mdot
.016 w
.11831 .47972 m
.11808 .48059 L
s
1 .248 0 r
.008 w
.11808 .48059 Mdot
.016 w
.11808 .48059 m
.11784 .48144 L
s
.008 w
.11784 .48144 Mdot
.016 w
.11784 .48144 m
.11756 .48229 L
s
.008 w
.11756 .48229 Mdot
.016 w
.11756 .48229 m
.11722 .48315 L
s
.008 w
.11722 .48315 Mdot
.016 w
.11722 .48315 m
.11682 .48409 L
s
.008 w
.11682 .48409 Mdot
.016 w
.11682 .48409 m
.11635 .48517 L
s
1 .247 0 r
.008 w
.11635 .48517 Mdot
.016 w
.11635 .48517 m
.11576 .4864 L
s
.008 w
.11576 .4864 Mdot
.016 w
.11576 .4864 m
.11508 .48788 L
s
.008 w
.11508 .48788 Mdot
.016 w
.11508 .48788 m
.11435 .48946 L
s
.008 w
.11435 .48946 Mdot
.016 w
.11435 .48946 m
.11354 .4913 L
s
.008 w
.11354 .4913 Mdot
.016 w
.11354 .4913 m
.11266 .49338 L
s
.008 w
.11266 .49338 Mdot
.016 w
.11266 .49338 m
.11175 .49557 L
s
1 .246 0 r
.008 w
.11175 .49557 Mdot
.016 w
.11175 .49557 m
.11083 .4982 L
s
.008 w
.11083 .4982 Mdot
.016 w
.11083 .4982 m
.10995 .50112 L
s
.008 w
.10995 .50112 Mdot
.016 w
.10995 .50112 m
.1092 .50438 L
s
.008 w
.1092 .50438 Mdot
.016 w
.1092 .50438 m
.10861 .50787 L
s
.008 w
.10861 .50787 Mdot
.016 w
.10861 .50787 m
.1082 .51132 L
s
1 .245 0 r
.008 w
.1082 .51132 Mdot
.016 w
.1082 .51132 m
.10797 .51506 L
s
.008 w
.10797 .51506 Mdot
.016 w
.10797 .51506 m
.1079 .5187 L
s
.008 w
.1079 .5187 Mdot
.016 w
.1079 .5187 m
.10798 .52241 L
s
.008 w
.10798 .52241 Mdot
.016 w
.10798 .52241 m
.10819 .52607 L
s
.008 w
.10819 .52607 Mdot
.016 w
.10819 .52607 m
.10843 .52956 L
s
1 .244 0 r
.008 w
.10843 .52956 Mdot
.016 w
.10843 .52956 m
.10879 .53313 L
s
.008 w
.10879 .53313 Mdot
.016 w
.10879 .53313 m
.10931 .53677 L
s
.008 w
.10931 .53677 Mdot
.016 w
.10931 .53677 m
.10985 .54028 L
s
.008 w
.10985 .54028 Mdot
.016 w
.10985 .54028 m
.11044 .54416 L
s
.008 w
.11044 .54416 Mdot
.016 w
.11044 .54416 m
.11108 .54803 L
s
1 .243 0 r
.008 w
.11108 .54803 Mdot
.016 w
.11108 .54803 m
.11175 .55175 L
s
.008 w
.11175 .55175 Mdot
.016 w
.11175 .55175 m
.11242 .55595 L
s
.008 w
.11242 .55595 Mdot
.016 w
.11242 .55595 m
.11305 .56016 L
s
.008 w
.11305 .56016 Mdot
.016 w
.11305 .56016 m
.1137 .5643 L
s
.008 w
.1137 .5643 Mdot
.016 w
.1137 .5643 m
.11433 .56907 L
s
.008 w
.11433 .56907 Mdot
.016 w
.11433 .56907 m
.11492 .57347 L
s
1 .242 0 r
.008 w
.11492 .57347 Mdot
.016 w
.11492 .57347 m
.11551 .57817 L
s
.008 w
.11551 .57817 Mdot
.016 w
.11551 .57817 m
.1161 .58313 L
s
.008 w
.1161 .58313 Mdot
.016 w
.1161 .58313 m
.11667 .58757 L
s
.008 w
.11667 .58757 Mdot
.016 w
.11667 .58757 m
.11724 .59258 L
s
.008 w
.11724 .59258 Mdot
.016 w
.11724 .59258 m
.11777 .59698 L
s
1 .241 0 r
.008 w
.11777 .59698 Mdot
.016 w
.11777 .59698 m
.11826 .60148 L
s
.008 w
.11826 .60148 Mdot
.016 w
.11826 .60148 m
.11872 .60576 L
s
.008 w
.11872 .60576 Mdot
.016 w
.11872 .60576 m
.11916 .61029 L
s
.008 w
.11916 .61029 Mdot
.016 w
.11916 .61029 m
.11961 .61398 L
s
.008 w
.11961 .61398 Mdot
.016 w
.11961 .61398 m
.12009 .61782 L
s
1 .24 0 r
.008 w
.12009 .61782 Mdot
.016 w
.12009 .61782 m
.12058 .6216 L
s
.008 w
.12058 .6216 Mdot
.016 w
.12058 .6216 m
.12112 .62515 L
s
.008 w
.12112 .62515 Mdot
.016 w
.12112 .62515 m
.12171 .62871 L
s
.008 w
.12171 .62871 Mdot
.016 w
.12171 .62871 m
.12236 .6322 L
s
.008 w
.12236 .6322 Mdot
.016 w
.12236 .6322 m
.12301 .63567 L
s
.008 w
.12301 .63567 Mdot
.016 w
.12301 .63567 m
.12369 .63918 L
s
1 .239 0 r
.008 w
.12369 .63918 Mdot
.016 w
.12369 .63918 m
.12438 .64239 L
s
.008 w
.12438 .64239 Mdot
.016 w
.12438 .64239 m
.12501 .64552 L
s
.008 w
.12501 .64552 Mdot
.016 w
.12501 .64552 m
.12562 .64833 L
s
.008 w
.12562 .64833 Mdot
.016 w
.12562 .64833 m
.12618 .65097 L
s
.008 w
.12618 .65097 Mdot
.016 w
.12618 .65097 m
.12665 .65303 L
s
1 .238 0 r
.008 w
.12665 .65303 Mdot
.016 w
.12665 .65303 m
.12704 .65473 L
s
.008 w
.12704 .65473 Mdot
.016 w
.12704 .65473 m
.12736 .65604 L
s
.008 w
.12736 .65604 Mdot
.016 w
.12736 .65604 m
.1276 .65698 L
s
.008 w
.1276 .65698 Mdot
.016 w
.1276 .65698 m
.12776 .65754 L
s
.008 w
.12776 .65754 Mdot
.016 w
.12776 .65754 m
.12786 .6578 L
s
1 .237 0 r
.008 w
.12786 .6578 Mdot
.016 w
.12786 .6578 m
.12791 .65777 L
s
.008 w
.12791 .65777 Mdot
.016 w
.12791 .65777 m
.12792 .65749 L
s
.008 w
.12792 .65749 Mdot
.016 w
.12792 .65749 m
.1279 .65702 L
s
.008 w
.1279 .65702 Mdot
.016 w
.1279 .65702 m
.12785 .65647 L
s
.008 w
.12785 .65647 Mdot
.016 w
.12785 .65647 m
.12778 .65595 L
s
1 .236 0 r
.008 w
.12778 .65595 Mdot
.016 w
.12778 .65595 m
.1277 .65554 L
s
.008 w
.1277 .65554 Mdot
.016 w
.1277 .65554 m
.12763 .65533 L
s
.008 w
.12763 .65533 Mdot
.016 w
.12763 .65533 m
.12758 .65542 L
s
.008 w
.12758 .65542 Mdot
.016 w
.12758 .65542 m
.12758 .6558 L
s
.008 w
.12758 .6558 Mdot
.016 w
.12758 .6558 m
.12762 .65657 L
s
.008 w
.12762 .65657 Mdot
.016 w
.12762 .65657 m
.12771 .65773 L
s
1 .235 0 r
.008 w
.12771 .65773 Mdot
.016 w
.12771 .65773 m
.12784 .65928 L
s
.008 w
.12784 .65928 Mdot
.016 w
.12784 .65928 m
.12804 .6613 L
s
.008 w
.12804 .6613 Mdot
.016 w
.12804 .6613 m
.12832 .6639 L
s
.008 w
.12832 .6639 Mdot
.016 w
.12832 .6639 m
.12869 .66688 L
s
.008 w
.12869 .66688 Mdot
.016 w
.12869 .66688 m
.12914 .67045 L
s
1 .234 0 r
.008 w
.12914 .67045 Mdot
.016 w
.12914 .67045 m
.12968 .67437 L
s
.008 w
.12968 .67437 Mdot
.016 w
.12968 .67437 m
.1303 .67899 L
s
.008 w
.1303 .67899 Mdot
.016 w
.1303 .67899 m
.13097 .68348 L
s
.008 w
.13097 .68348 Mdot
.016 w
.13097 .68348 m
.13168 .68759 L
s
.008 w
.13168 .68759 Mdot
.016 w
.13168 .68759 m
.13242 .69215 L
s
1 .233 0 r
.008 w
.13242 .69215 Mdot
.016 w
.13242 .69215 m
.1332 .69634 L
s
.008 w
.1332 .69634 Mdot
.016 w
.1332 .69634 m
.13392 .70032 L
s
.008 w
.13392 .70032 Mdot
.016 w
.13392 .70032 m
.13468 .70404 L
s
.008 w
.13468 .70404 Mdot
.016 w
.13468 .70404 m
.13535 .70694 L
s
.008 w
.13535 .70694 Mdot
.016 w
.13535 .70694 m
.13599 .70953 L
s
1 .232 0 r
.008 w
.13599 .70953 Mdot
.016 w
.13599 .70953 m
.13658 .71147 L
s
.008 w
.13658 .71147 Mdot
.016 w
.13658 .71147 m
.13712 .71299 L
s
.008 w
.13712 .71299 Mdot
.016 w
.13712 .71299 m
.13759 .71408 L
s
.008 w
.13759 .71408 Mdot
.016 w
.13759 .71408 m
.13798 .71471 L
s
.008 w
.13798 .71471 Mdot
.016 w
.13798 .71471 m
.13829 .71491 L
s
.008 w
.13829 .71491 Mdot
.016 w
.13829 .71491 m
.13854 .71487 L
s
1 .231 0 r
.008 w
.13854 .71487 Mdot
.016 w
.13854 .71487 m
.13873 .71476 L
s
.008 w
.13873 .71476 Mdot
.016 w
.13873 .71476 m
.13885 .71463 L
s
.008 w
.13885 .71463 Mdot
.016 w
.13885 .71463 m
.13894 .71452 L
s
.008 w
.13894 .71452 Mdot
.016 w
.13894 .71452 m
.139 .7145 L
s
.008 w
.139 .7145 Mdot
.016 w
.139 .7145 m
.13903 .71459 L
s
1 .23 0 r
.008 w
.13903 .71459 Mdot
.016 w
.13903 .71459 m
.13903 .71476 L
s
.008 w
.13903 .71476 Mdot
.016 w
.13903 .71476 m
.13901 .71494 L
s
.008 w
.13901 .71494 Mdot
.016 w
.13901 .71494 m
.13897 .7151 L
s
.008 w
.13897 .7151 Mdot
.016 w
.13897 .7151 m
.13892 .71521 L
s
.008 w
.13892 .71521 Mdot
.016 w
.13892 .71521 m
.13888 .71526 L
s
1 .229 0 r
.008 w
.13888 .71526 Mdot
.016 w
.13888 .71526 m
.13885 .71522 L
s
.008 w
.13885 .71522 Mdot
.016 w
.13885 .71522 m
.13882 .71512 L
s
.008 w
.13882 .71512 Mdot
.016 w
.13882 .71512 m
.13879 .71498 L
s
.008 w
.13879 .71498 Mdot
.016 w
.13879 .71498 m
.13875 .71475 L
s
.008 w
.13875 .71475 Mdot
.016 w
.13875 .71475 m
.13869 .71444 L
s
1 .228 0 r
.008 w
.13869 .71444 Mdot
.016 w
.13869 .71444 m
.13862 .7141 L
s
.008 w
.13862 .7141 Mdot
.016 w
.13862 .7141 m
.13857 .71383 L
s
.008 w
.13857 .71383 Mdot
.016 w
.13857 .71383 m
.13856 .7137 L
s
.008 w
.13856 .7137 Mdot
.016 w
.13856 .7137 m
.13862 .71382 L
s
.008 w
.13862 .71382 Mdot
.016 w
.13862 .71382 m
.13878 .71428 L
s
.008 w
.13878 .71428 Mdot
.016 w
.13878 .71428 m
.13907 .71512 L
s
1 .227 0 r
.008 w
.13907 .71512 Mdot
.016 w
.13907 .71512 m
.13952 .71639 L
s
.008 w
.13952 .71639 Mdot
.016 w
.13952 .71639 m
.14014 .71812 L
s
.008 w
.14014 .71812 Mdot
.016 w
.14014 .71812 m
.14092 .72009 L
s
.008 w
.14092 .72009 Mdot
.016 w
.14092 .72009 m
.14189 .72238 L
s
.008 w
.14189 .72238 Mdot
.016 w
.14189 .72238 m
.14309 .72491 L
s
1 .226 0 r
.008 w
.14309 .72491 Mdot
.016 w
.14309 .72491 m
.14449 .72745 L
s
.008 w
.14449 .72745 Mdot
.016 w
.14449 .72745 m
.14567 .73003 L
s
.008 w
.14567 .73003 Mdot
.016 w
.14567 .73003 m
.1472 .73253 L
s
.008 w
.1472 .73253 Mdot
.016 w
.1472 .73253 m
.14867 .73503 L
s
.008 w
.14867 .73503 Mdot
.016 w
.14867 .73503 m
.15045 .7374 L
s
1 .225 0 r
.008 w
.15045 .7374 Mdot
.016 w
.15045 .7374 m
.15188 .73938 L
s
.008 w
.15188 .73938 Mdot
.016 w
.15188 .73938 m
.15338 .74115 L
s
.008 w
.15338 .74115 Mdot
.016 w
.15338 .74115 m
.15485 .74266 L
s
.008 w
.15485 .74266 Mdot
.016 w
.15485 .74266 m
.15619 .7439 L
s
.008 w
.15619 .7439 Mdot
.016 w
.15619 .7439 m
.15741 .74487 L
s
.008 w
.15741 .74487 Mdot
.016 w
.15741 .74487 m
.15852 .74567 L
s
1 .224 0 r
.008 w
.15852 .74567 Mdot
.016 w
.15852 .74567 m
.15956 .74632 L
s
.008 w
.15956 .74632 Mdot
.016 w
.15956 .74632 m
.16044 .74684 L
s
.008 w
.16044 .74684 Mdot
.016 w
.16044 .74684 m
.16131 .74728 L
s
.008 w
.16131 .74728 Mdot
.016 w
.16131 .74728 m
.16204 .74765 L
s
.008 w
.16204 .74765 Mdot
.016 w
.16204 .74765 m
.16274 .74799 L
s
1 .223 0 r
.008 w
.16274 .74799 Mdot
.016 w
.16274 .74799 m
.16333 .74825 L
s
.008 w
.16333 .74825 Mdot
.016 w
.16333 .74825 m
.16388 .7485 L
s
.008 w
.16388 .7485 Mdot
.016 w
.16388 .7485 m
.16436 .74875 L
s
.008 w
.16436 .74875 Mdot
.016 w
.16436 .74875 m
.16479 .74889 L
s
.008 w
.16479 .74889 Mdot
.016 w
.16479 .74889 m
.16512 .74899 L
s
1 .222 0 r
.008 w
.16512 .74899 Mdot
.016 w
.16512 .74899 m
.16539 .74904 L
s
.008 w
.16539 .74904 Mdot
.016 w
.16539 .74904 m
.16558 .74906 L
s
.008 w
.16558 .74906 Mdot
.016 w
.16558 .74906 m
.16572 .74905 L
s
.008 w
.16572 .74905 Mdot
.016 w
.16572 .74905 m
.16579 .74901 L
s
.008 w
.16579 .74901 Mdot
.016 w
.16579 .74901 m
.16581 .74896 L
s
1 .221 0 r
.008 w
.16581 .74896 Mdot
.016 w
.16581 .74896 m
.16576 .74891 L
s
.008 w
.16576 .74891 Mdot
.016 w
.16576 .74891 m
.16564 .74882 L
s
.008 w
.16564 .74882 Mdot
.016 w
.16564 .74882 m
.16547 .74876 L
s
.008 w
.16547 .74876 Mdot
.016 w
.16547 .74876 m
.16526 .74868 L
s
.008 w
.16526 .74868 Mdot
.016 w
.16526 .74868 m
.16504 .74857 L
s
.008 w
.16504 .74857 Mdot
.016 w
.16504 .74857 m
.16481 .7484 L
s
1 .22 0 r
.008 w
.16481 .7484 Mdot
.016 w
.16481 .7484 m
.16458 .74822 L
s
.008 w
.16458 .74822 Mdot
.016 w
.16458 .74822 m
.16433 .74806 L
s
.008 w
.16433 .74806 Mdot
.016 w
.16433 .74806 m
.16411 .74798 L
s
.008 w
.16411 .74798 Mdot
.016 w
.16411 .74798 m
.16398 .748 L
s
.008 w
.16398 .748 Mdot
.016 w
.16398 .748 m
.16396 .7482 L
s
1 .219 0 r
.008 w
.16396 .7482 Mdot
.016 w
.16396 .7482 m
.16409 .74863 L
s
.008 w
.16409 .74863 Mdot
.016 w
.16409 .74863 m
.1644 .74922 L
s
.008 w
.1644 .74922 Mdot
.016 w
.1644 .74922 m
.16495 .75013 L
s
.008 w
.16495 .75013 Mdot
.016 w
.16495 .75013 m
.16574 .75136 L
s
.008 w
.16574 .75136 Mdot
.016 w
.16574 .75136 m
.16682 .75292 L
s
1 .218 0 r
.008 w
.16682 .75292 Mdot
.016 w
.16682 .75292 m
.16827 .75464 L
s
.008 w
.16827 .75464 Mdot
.016 w
.16827 .75464 m
.17 .75673 L
s
.008 w
.17 .75673 Mdot
.016 w
.17 .75673 m
.1717 .75903 L
s
.008 w
.1717 .75903 Mdot
.016 w
.1717 .75903 m
.17352 .76141 L
s
.008 w
.17352 .76141 Mdot
.016 w
.17352 .76141 m
.17557 .76397 L
s
1 .217 0 r
.008 w
.17557 .76397 Mdot
.016 w
.17557 .76397 m
.17742 .76644 L
s
.008 w
.17742 .76644 Mdot
.016 w
.17742 .76644 m
.17963 .76884 L
s
.008 w
.17963 .76884 Mdot
.016 w
.17963 .76884 m
.18164 .77115 L
s
.008 w
.18164 .77115 Mdot
.016 w
.18164 .77115 m
.18359 .77318 L
s
.008 w
.18359 .77318 Mdot
.016 w
.18359 .77318 m
.18523 .77479 L
s
.008 w
.18523 .77479 Mdot
.016 w
.18523 .77479 m
.18669 .77616 L
s
1 .216 0 r
.008 w
.18669 .77616 Mdot
.016 w
.18669 .77616 m
.18794 .77726 L
s
.008 w
.18794 .77726 Mdot
.016 w
.18794 .77726 m
.18892 .77806 L
s
.008 w
.18892 .77806 Mdot
.016 w
.18892 .77806 m
.1897 .77861 L
s
.008 w
.1897 .77861 Mdot
.016 w
.1897 .77861 m
.19022 .77891 L
s
.008 w
.19022 .77891 Mdot
.016 w
.19022 .77891 m
.19052 .77905 L
s
1 .215 0 r
.008 w
.19052 .77905 Mdot
.016 w
.19052 .77905 m
.19067 .77902 L
s
.008 w
.19067 .77902 Mdot
.016 w
.19067 .77902 m
.19072 .77888 L
s
.008 w
.19072 .77888 Mdot
.016 w
.19072 .77888 m
.19068 .77867 L
s
.008 w
.19068 .77867 Mdot
.016 w
.19068 .77867 m
.19059 .77842 L
s
.008 w
.19059 .77842 Mdot
.016 w
.19059 .77842 m
.19048 .77821 L
s
1 .214 0 r
.008 w
.19048 .77821 Mdot
.016 w
.19048 .77821 m
.19039 .77809 L
s
.008 w
.19039 .77809 Mdot
.016 w
.19039 .77809 m
.19031 .77803 L
s
.008 w
.19031 .77803 Mdot
.016 w
.19031 .77803 m
.19026 .77798 L
s
.008 w
.19026 .77798 Mdot
.016 w
.19026 .77798 m
.19024 .77796 L
s
.008 w
.19024 .77796 Mdot
.016 w
.19024 .77796 m
.19023 .77795 L
s
1 .213 0 r
.008 w
.19023 .77795 Mdot
.016 w
.19023 .77795 m
.19023 .77796 L
s
.008 w
.19023 .77796 Mdot
.016 w
.19023 .77796 m
.19023 .77799 L
s
.008 w
.19023 .77799 Mdot
.016 w
.19023 .77799 m
.19023 .778 L
s
.008 w
.19023 .778 Mdot
.016 w
.19023 .778 m
.19023 .77801 L
s
.008 w
.19023 .77801 Mdot
.016 w
.19023 .77801 m
.19023 .77801 L
s
.008 w
.19023 .77801 Mdot
.016 w
.19023 .77801 m
.19023 .77801 L
s
1 .212 0 r
.008 w
.19023 .77801 Mdot
.016 w
.19023 .77801 m
.19023 .77801 L
s
.008 w
.19023 .77801 Mdot
.016 w
.19023 .77801 m
.19022 .77801 L
s
.008 w
.19022 .77801 Mdot
.016 w
.19022 .77801 m
.19019 .77801 L
s
.008 w
.19019 .77801 Mdot
.016 w
.19019 .77801 m
.19015 .77801 L
s
.008 w
.19015 .77801 Mdot
.016 w
.19015 .77801 m
.19011 .77801 L
s
1 .211 0 r
.008 w
.19011 .77801 Mdot
.016 w
.19011 .77801 m
.19009 .77801 L
s
.008 w
.19009 .77801 Mdot
.016 w
.19009 .77801 m
.1901 .77801 L
s
.008 w
.1901 .77801 Mdot
.016 w
.1901 .77801 m
.19016 .77801 L
s
.008 w
.19016 .77801 Mdot
.016 w
.19016 .77801 m
.19026 .77801 L
s
.008 w
.19026 .77801 Mdot
.016 w
.19026 .77801 m
.1904 .778 L
s
1 .21 0 r
.008 w
.1904 .778 Mdot
.016 w
.1904 .778 m
.19059 .77799 L
s
.008 w
.19059 .77799 Mdot
.016 w
.19059 .77799 m
.19081 .77798 L
s
.008 w
.19081 .77798 Mdot
.016 w
.19081 .77798 m
.19105 .77797 L
s
.008 w
.19105 .77797 Mdot
.016 w
.19105 .77797 m
.19131 .77796 L
s
.008 w
.19131 .77796 Mdot
.016 w
.19131 .77796 m
.19157 .77794 L
s
1 .209 0 r
.008 w
.19157 .77794 Mdot
.016 w
.19157 .77794 m
.19182 .77793 L
s
.008 w
.19182 .77793 Mdot
.016 w
.19182 .77793 m
.19207 .77792 L
s
.008 w
.19207 .77792 Mdot
.016 w
.19207 .77792 m
.1923 .77791 L
s
.008 w
.1923 .77791 Mdot
.016 w
.1923 .77791 m
.1925 .7779 L
s
.008 w
.1925 .7779 Mdot
.016 w
.1925 .7779 m
.19266 .77789 L
s
.008 w
.19266 .77789 Mdot
.016 w
.19266 .77789 m
.19277 .77789 L
s
1 .208 0 r
.008 w
.19277 .77789 Mdot
.016 w
.19277 .77789 m
.19284 .77788 L
s
.008 w
.19284 .77788 Mdot
.016 w
.19284 .77788 m
.19286 .77788 L
s
.008 w
.19286 .77788 Mdot
.016 w
.19286 .77788 m
.19284 .77788 L
s
.008 w
.19284 .77788 Mdot
.016 w
.19284 .77788 m
.1928 .77788 L
s
.008 w
.1928 .77788 Mdot
.016 w
.1928 .77788 m
.19276 .77789 L
s
1 .207 0 r
.008 w
.19276 .77789 Mdot
.016 w
.19276 .77789 m
.19273 .77789 L
s
.008 w
.19273 .77789 Mdot
.016 w
.19273 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
1 .206 0 r
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
1 .205 0 r
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
1 .204 0 r
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77789 L
s
.008 w
.19271 .77789 Mdot
.016 w
.19271 .77789 m
.19271 .77788 L
s
.008 w
.19271 .77788 Mdot
.016 w
.19271 .77788 m
.19269 .77782 L
s
1 .203 0 r
.008 w
.19269 .77782 Mdot
.016 w
.19269 .77782 m
.19264 .77767 L
s
.008 w
.19264 .77767 Mdot
.016 w
.19264 .77767 m
.19256 .77749 L
s
.008 w
.19256 .77749 Mdot
.016 w
.19256 .77749 m
.19248 .7773 L
s
.008 w
.19248 .7773 Mdot
.016 w
.19248 .7773 m
.1924 .77717 L
s
.008 w
.1924 .77717 Mdot
.016 w
.1924 .77717 m
.19235 .7771 L
s
1 .202 0 r
.008 w
.19235 .7771 Mdot
.016 w
.19235 .7771 m
.19236 .77719 L
s
.008 w
.19236 .77719 Mdot
.016 w
.19236 .77719 m
.19248 .77754 L
s
.008 w
.19248 .77754 Mdot
.016 w
.19248 .77754 m
.19275 .77823 L
s
.008 w
.19275 .77823 Mdot
.016 w
.19275 .77823 m
.19315 .77925 L
s
.008 w
.19315 .77925 Mdot
.016 w
.19315 .77925 m
.1937 .78061 L
s
.008 w
.1937 .78061 Mdot
.016 w
.1937 .78061 m
.19438 .78229 L
s
1 .201 0 r
.008 w
.19438 .78229 Mdot
.016 w
.19438 .78229 m
.1952 .78427 L
s
.008 w
.1952 .78427 Mdot
.016 w
.1952 .78427 m
.196 .78622 L
s
.008 w
.196 .78622 Mdot
.016 w
.196 .78622 m
.19695 .78841 L
s
.008 w
.19695 .78841 Mdot
.016 w
.19695 .78841 m
.19792 .7906 L
s
.008 w
.19792 .7906 Mdot
.016 w
.19792 .7906 m
.19888 .79289 L
s
1 .2 0 r
.008 w
.19888 .79289 Mdot
.016 w
.19888 .79289 m
.19981 .79507 L
s
.008 w
.19981 .79507 Mdot
.016 w
.19981 .79507 m
.20064 .79721 L
s
.008 w
.20064 .79721 Mdot
.016 w
.20064 .79721 m
.20136 .79886 L
s
.008 w
.20136 .79886 Mdot
.016 w
.20136 .79886 m
.20196 .80026 L
s
.008 w
.20196 .80026 Mdot
.016 w
.20196 .80026 m
.2024 .80136 L
s
1 .199 0 r
.008 w
.2024 .80136 Mdot
.016 w
.2024 .80136 m
.20268 .8021 L
s
.008 w
.20268 .8021 Mdot
.016 w
.20268 .8021 m
.20281 .80243 L
s
.008 w
.20281 .80243 Mdot
.016 w
.20281 .80243 m
.20283 .80234 L
s
.008 w
.20283 .80234 Mdot
.016 w
.20283 .80234 m
.20277 .80196 L
s
.008 w
.20277 .80196 Mdot
.016 w
.20277 .80196 m
.20268 .80142 L
s
1 .198 0 r
.008 w
.20268 .80142 Mdot
.016 w
.20268 .80142 m
.20259 .80078 L
s
.008 w
.20259 .80078 Mdot
.016 w
.20259 .80078 m
.20251 .8001 L
s
.008 w
.20251 .8001 Mdot
.016 w
.20251 .8001 m
.20246 .79941 L
s
.008 w
.20246 .79941 Mdot
.016 w
.20246 .79941 m
.20244 .79874 L
s
.008 w
.20244 .79874 Mdot
.016 w
.20244 .79874 m
.20242 .7981 L
s
.008 w
.20242 .7981 Mdot
.016 w
.20242 .7981 m
.20236 .79749 L
s
1 .197 0 r
.008 w
.20236 .79749 Mdot
.016 w
.20236 .79749 m
.20226 .79696 L
s
.008 w
.20226 .79696 Mdot
.016 w
.20226 .79696 m
.20214 .79653 L
s
.008 w
.20214 .79653 Mdot
.016 w
.20214 .79653 m
.20203 .79628 L
s
.008 w
.20203 .79628 Mdot
.016 w
.20203 .79628 m
.20193 .79623 L
s
.008 w
.20193 .79623 Mdot
.016 w
.20193 .79623 m
.20185 .7964 L
s
1 .196 0 r
.008 w
.20185 .7964 Mdot
.016 w
.20185 .7964 m
.20184 .79679 L
s
.008 w
.20184 .79679 Mdot
.016 w
.20184 .79679 m
.20194 .79742 L
s
.008 w
.20194 .79742 Mdot
.016 w
.20194 .79742 m
.20223 .79831 L
s
.008 w
.20223 .79831 Mdot
.016 w
.20223 .79831 m
.20274 .79947 L
s
.008 w
.20274 .79947 Mdot
.016 w
.20274 .79947 m
.2035 .80084 L
s
1 .195 0 r
.008 w
.2035 .80084 Mdot
.016 w
.2035 .80084 m
.2046 .80259 L
s
.008 w
.2046 .80259 Mdot
.016 w
.2046 .80259 m
.20602 .80492 L
s
.008 w
.20602 .80492 Mdot
.016 w
.20602 .80492 m
.20781 .80727 L
s
.008 w
.20781 .80727 Mdot
.016 w
.20781 .80727 m
.21001 .81018 L
s
.008 w
.21001 .81018 Mdot
.016 w
.21001 .81018 m
.21263 .81342 L
s
1 .194 0 r
.008 w
.21263 .81342 Mdot
.016 w
.21263 .81342 m
.2158 .81727 L
s
.008 w
.2158 .81727 Mdot
.016 w
.2158 .81727 m
.21901 .82089 L
s
.008 w
.21901 .82089 Mdot
.016 w
.21901 .82089 m
.22276 .82498 L
s
.008 w
.22276 .82498 Mdot
.016 w
.22276 .82498 m
.22684 .82946 L
s
.008 w
.22684 .82946 Mdot
.016 w
.22684 .82946 m
.23102 .83387 L
s
.008 w
.23102 .83387 Mdot
.016 w
.23102 .83387 m
.23538 .8386 L
s
1 .193 0 r
.008 w
.23538 .8386 Mdot
.016 w
.23538 .8386 m
.23988 .84312 L
s
.008 w
.23988 .84312 Mdot
.016 w
.23988 .84312 m
.24477 .84842 L
s
.008 w
.24477 .84842 Mdot
.016 w
.24477 .84842 m
.24909 .85281 L
s
.008 w
.24909 .85281 Mdot
.016 w
.24909 .85281 m
.25378 .8579 L
s
.008 w
.25378 .8579 Mdot
.016 w
.25378 .8579 m
.25887 .86265 L
s
1 .192 0 r
.008 w
.25887 .86265 Mdot
.016 w
.25887 .86265 m
.26313 .86689 L
s
.008 w
.26313 .86689 Mdot
.016 w
.26313 .86689 m
.26773 .87117 L
s
.008 w
.26773 .87117 Mdot
.016 w
.26773 .87117 m
.27229 .87519 L
s
.008 w
.27229 .87519 Mdot
.016 w
.27229 .87519 m
.27683 .87914 L
s
.008 w
.27683 .87914 Mdot
.016 w
.27683 .87914 m
.28148 .88244 L
s
1 .191 0 r
.008 w
.28148 .88244 Mdot
.016 w
.28148 .88244 m
.2857 .88568 L
s
.008 w
.2857 .88568 Mdot
.016 w
.2857 .88568 m
.29029 .88874 L
s
.008 w
.29029 .88874 Mdot
.016 w
.29029 .88874 m
.29482 .89146 L
s
.008 w
.29482 .89146 Mdot
.016 w
.29482 .89146 m
.29919 .89397 L
s
.008 w
.29919 .89397 Mdot
.016 w
.29919 .89397 m
.30382 .89633 L
s
.008 w
.30382 .89633 Mdot
.016 w
.30382 .89633 m
.30853 .89851 L
s
1 .19 0 r
.008 w
.30853 .89851 Mdot
.016 w
.30853 .89851 m
.31354 .90062 L
s
.008 w
.31354 .90062 Mdot
.016 w
.31354 .90062 m
.31813 .90247 L
s
.008 w
.31813 .90247 Mdot
.016 w
.31813 .90247 m
.32305 .90437 L
s
.008 w
.32305 .90437 Mdot
.016 w
.32305 .90437 m
.32831 .90624 L
s
.008 w
.32831 .90624 Mdot
.016 w
.32831 .90624 m
.33327 .90807 L
s
1 .189 0 r
.008 w
.33327 .90807 Mdot
.016 w
.33327 .90807 m
.33838 .90998 L
s
.008 w
.33838 .90998 Mdot
.016 w
.33838 .90998 m
.34419 .91186 L
s
.008 w
.34419 .91186 Mdot
.016 w
.34419 .91186 m
.34955 .91376 L
s
.008 w
.34955 .91376 Mdot
.016 w
.34955 .91376 m
.35494 .91576 L
s
.008 w
.35494 .91576 Mdot
.016 w
.35494 .91576 m
.36069 .91765 L
s
1 .188 0 r
.008 w
.36069 .91765 Mdot
.016 w
.36069 .91765 m
.36633 .91961 L
s
.008 w
.36633 .91961 Mdot
.016 w
.36633 .91961 m
.3718 .92148 L
s
.008 w
.3718 .92148 Mdot
.016 w
.3718 .92148 m
.37722 .92342 L
s
.008 w
.37722 .92342 Mdot
.016 w
.37722 .92342 m
.38305 .92529 L
s
.008 w
.38305 .92529 Mdot
.016 w
.38305 .92529 m
.38844 .92717 L
s
1 .187 0 r
.008 w
.38844 .92717 Mdot
.016 w
.38844 .92717 m
.39396 .92915 L
s
.008 w
.39396 .92915 Mdot
.016 w
.39396 .92915 m
.39944 .93106 L
s
.008 w
.39944 .93106 Mdot
.016 w
.39944 .93106 m
.40445 .93293 L
s
.008 w
.40445 .93293 Mdot
.016 w
.40445 .93293 m
.40973 .93483 L
s
.008 w
.40973 .93483 Mdot
.016 w
.40973 .93483 m
.41472 .93656 L
s
.008 w
.41472 .93656 Mdot
.016 w
.41472 .93656 m
.41952 .93828 L
s
1 .186 0 r
.008 w
.41952 .93828 Mdot
.016 w
.41952 .93828 m
.42404 .9398 L
s
.008 w
.42404 .9398 Mdot
.016 w
.42404 .9398 m
.4284 .94128 L
s
.008 w
.4284 .94128 Mdot
.016 w
.4284 .94128 m
.43248 .94266 L
s
.008 w
.43248 .94266 Mdot
.016 w
.43248 .94266 m
.4364 .94402 L
s
.008 w
.4364 .94402 Mdot
.016 w
.4364 .94402 m
.44013 .94521 L
s
1 .185 0 r
.008 w
.44013 .94521 Mdot
.016 w
.44013 .94521 m
.44347 .94638 L
s
.008 w
.44347 .94638 Mdot
.016 w
.44347 .94638 m
.44663 .94753 L
s
.008 w
.44663 .94753 Mdot
.016 w
.44663 .94753 m
.44963 .94856 L
s
.008 w
.44963 .94856 Mdot
.016 w
.44963 .94856 m
.45242 .94959 L
s
.008 w
.45242 .94959 Mdot
.016 w
.45242 .94959 m
.45511 .9506 L
s
1 .184 0 r
.008 w
.45511 .9506 Mdot
.016 w
.45511 .9506 m
.45777 .95156 L
s
.008 w
.45777 .95156 Mdot
.016 w
.45777 .95156 m
.46043 .95253 L
s
.008 w
.46043 .95253 Mdot
.016 w
.46043 .95253 m
.46318 .95348 L
s
.008 w
.46318 .95348 Mdot
.016 w
.46318 .95348 m
.46618 .95437 L
s
.008 w
.46618 .95437 Mdot
.016 w
.46618 .95437 m
.46924 .95521 L
s
1 .183 0 r
.008 w
.46924 .95521 Mdot
.016 w
.46924 .95521 m
.47255 .95598 L
s
.008 w
.47255 .95598 Mdot
.016 w
.47255 .95598 m
.47628 .95662 L
s
.008 w
.47628 .95662 Mdot
.016 w
.47628 .95662 m
.47963 .9571 L
s
.008 w
.47963 .9571 Mdot
.016 w
.47963 .9571 m
.48327 .95743 L
s
.008 w
.48327 .95743 Mdot
.016 w
.48327 .95743 m
.48705 .95761 L
s
.008 w
.48705 .95761 Mdot
.016 w
.48705 .95761 m
.49079 .95766 L
s
1 .182 0 r
.008 w
.49079 .95766 Mdot
.016 w
.49079 .95766 m
.49427 .95761 L
s
.008 w
.49427 .95761 Mdot
.016 w
.49427 .95761 m
.49751 .95747 L
s
.008 w
.49751 .95747 Mdot
.016 w
.49751 .95747 m
.50057 .95728 L
s
.008 w
.50057 .95728 Mdot
.016 w
.50057 .95728 m
.50296 .95702 L
s
.008 w
.50296 .95702 Mdot
.016 w
.50296 .95702 m
.50517 .95673 L
s
1 .181 0 r
.008 w
.50517 .95673 Mdot
.016 w
.50517 .95673 m
.50686 .95643 L
s
.008 w
.50686 .95643 Mdot
.016 w
.50686 .95643 m
.50824 .95614 L
s
.008 w
.50824 .95614 Mdot
.016 w
.50824 .95614 m
.50928 .9559 L
s
.008 w
.50928 .9559 Mdot
.016 w
.50928 .9559 m
.50995 .95574 L
s
.008 w
.50995 .95574 Mdot
.016 w
.50995 .95574 m
.51031 .95567 L
s
1 .18 0 r
.008 w
.51031 .95567 Mdot
.016 w
.51031 .95567 m
.51046 .95567 L
s
.008 w
.51046 .95567 Mdot
.016 w
.51046 .95567 m
.51045 .95573 L
s
.008 w
.51045 .95573 Mdot
.016 w
.51045 .95573 m
.51034 .95581 L
s
.008 w
.51034 .95581 Mdot
.016 w
.51034 .95581 m
.5102 .9559 L
s
.008 w
.5102 .9559 Mdot
.016 w
.5102 .9559 m
.51008 .95598 L
s
1 .179 0 r
.008 w
.51008 .95598 Mdot
.016 w
.51008 .95598 m
.50999 .95603 L
s
.008 w
.50999 .95603 Mdot
.016 w
.50999 .95603 m
.50993 .95605 L
s
.008 w
.50993 .95605 Mdot
.016 w
.50993 .95605 m
.50987 .95606 L
s
.008 w
.50987 .95606 Mdot
.016 w
.50987 .95606 m
.50984 .95606 L
s
.008 w
.50984 .95606 Mdot
.016 w
.50984 .95606 m
.50981 .95604 L
s
.008 w
.50981 .95604 Mdot
.016 w
.50981 .95604 m
.50979 .956 L
s
1 .178 0 r
.008 w
.50979 .956 Mdot
.016 w
.50979 .956 m
.5098 .95596 L
s
.008 w
.5098 .95596 Mdot
.016 w
.5098 .95596 m
.50981 .9559 L
s
.008 w
.50981 .9559 Mdot
.016 w
.50981 .9559 m
.50982 .95582 L
s
.008 w
.50982 .95582 Mdot
.016 w
.50982 .95582 m
.50981 .95572 L
s
.008 w
.50981 .95572 Mdot
.016 w
.50981 .95572 m
.50977 .95563 L
s
1 .177 0 r
.008 w
.50977 .95563 Mdot
.016 w
.50977 .95563 m
.50968 .95557 L
s
.008 w
.50968 .95557 Mdot
.016 w
.50968 .95557 m
.50955 .95554 L
s
.008 w
.50955 .95554 Mdot
.016 w
.50955 .95554 m
.50939 .95556 L
s
.008 w
.50939 .95556 Mdot
.016 w
.50939 .95556 m
.50923 .9556 L
s
.008 w
.50923 .9556 Mdot
.016 w
.50923 .9556 m
.50909 .95565 L
s
1 .176 0 r
.008 w
.50909 .95565 Mdot
.016 w
.50909 .95565 m
.50898 .9557 L
s
.008 w
.50898 .9557 Mdot
.016 w
.50898 .9557 m
.50889 .95573 L
s
.008 w
.50889 .95573 Mdot
.016 w
.50889 .95573 m
.50881 .95576 L
s
.008 w
.50881 .95576 Mdot
.016 w
.50881 .95576 m
.50872 .95579 L
s
.008 w
.50872 .95579 Mdot
.016 w
.50872 .95579 m
.50862 .9558 L
s
1 .175 0 r
.008 w
.50862 .9558 Mdot
.016 w
.50862 .9558 m
.50854 .95583 L
s
.008 w
.50854 .95583 Mdot
.016 w
.50854 .95583 m
.5085 .95586 L
s
.008 w
.5085 .95586 Mdot
.016 w
.5085 .95586 m
.50853 .95589 L
s
.008 w
.50853 .95589 Mdot
.016 w
.50853 .95589 m
.50861 .9559 L
s
.008 w
.50861 .9559 Mdot
.016 w
.50861 .9559 m
.50871 .9559 L
s
.008 w
.50871 .9559 Mdot
.016 w
.50871 .9559 m
.50881 .95589 L
s
1 .174 0 r
.008 w
.50881 .95589 Mdot
.016 w
.50881 .95589 m
.50887 .95586 L
s
.008 w
.50887 .95586 Mdot
.016 w
.50887 .95586 m
.50888 .95584 L
s
.008 w
.50888 .95584 Mdot
.016 w
.50888 .95584 m
.50886 .9558 L
s
.008 w
.50886 .9558 Mdot
.016 w
.50886 .9558 m
.5088 .95576 L
s
.008 w
.5088 .95576 Mdot
.016 w
.5088 .95576 m
.50872 .95574 L
s
1 .173 0 r
.008 w
.50872 .95574 Mdot
.016 w
.50872 .95574 m
.50862 .95574 L
s
.008 w
.50862 .95574 Mdot
.016 w
.50862 .95574 m
.50851 .95577 L
s
.008 w
.50851 .95577 Mdot
.016 w
.50851 .95577 m
.50844 .95582 L
s
.008 w
.50844 .95582 Mdot
.016 w
.50844 .95582 m
.50838 .95586 L
s
.008 w
.50838 .95586 Mdot
.016 w
.50838 .95586 m
.50835 .95592 L
s
1 .172 0 r
.008 w
.50835 .95592 Mdot
.016 w
.50835 .95592 m
.50837 .95597 L
s
.008 w
.50837 .95597 Mdot
.016 w
.50837 .95597 m
.50848 .95601 L
s
.008 w
.50848 .95601 Mdot
.016 w
.50848 .95601 m
.50867 .95601 L
s
.008 w
.50867 .95601 Mdot
.016 w
.50867 .95601 m
.50896 .95597 L
s
.008 w
.50896 .95597 Mdot
.016 w
.50896 .95597 m
.50937 .95588 L
s
.008 w
.50937 .95588 Mdot
.016 w
.50937 .95588 m
.50989 .95572 L
s
1 .171 0 r
.008 w
.50989 .95572 Mdot
.016 w
.50989 .95572 m
.5105 .95547 L
s
.008 w
.5105 .95547 Mdot
.016 w
.5105 .95547 m
.51112 .9551 L
s
.008 w
.51112 .9551 Mdot
.016 w
.51112 .9551 m
.51177 .95459 L
s
.008 w
.51177 .95459 Mdot
.016 w
.51177 .95459 m
.51242 .95396 L
s
.008 w
.51242 .95396 Mdot
.016 w
.51242 .95396 m
.51315 .9532 L
s
1 .17 0 r
.008 w
.51315 .9532 Mdot
.016 w
.51315 .9532 m
.51374 .9524 L
s
.008 w
.51374 .9524 Mdot
.016 w
.51374 .9524 m
.51441 .95148 L
s
.008 w
.51441 .95148 Mdot
.016 w
.51441 .95148 m
.51506 .95052 L
s
.008 w
.51506 .95052 Mdot
.016 w
.51506 .95052 m
.51565 .94956 L
s
.008 w
.51565 .94956 Mdot
.016 w
.51565 .94956 m
.51616 .94865 L
s
1 .169 0 r
.008 w
.51616 .94865 Mdot
.016 w
.51616 .94865 m
.5166 .94783 L
s
.008 w
.5166 .94783 Mdot
.016 w
.5166 .94783 m
.51697 .9471 L
s
.008 w
.51697 .9471 Mdot
.016 w
.51697 .9471 m
.51729 .94648 L
s
.008 w
.51729 .94648 Mdot
.016 w
.51729 .94648 m
.51754 .94597 L
s
.008 w
.51754 .94597 Mdot
.016 w
.51754 .94597 m
.51779 .94558 L
s
1 .168 0 r
.008 w
.51779 .94558 Mdot
.016 w
.51779 .94558 m
.51804 .94532 L
s
.008 w
.51804 .94532 Mdot
.016 w
.51804 .94532 m
.51832 .9452 L
s
.008 w
.51832 .9452 Mdot
.016 w
.51832 .9452 m
.51856 .94519 L
s
.008 w
.51856 .94519 Mdot
.016 w
.51856 .94519 m
.51881 .94524 L
s
.008 w
.51881 .94524 Mdot
.016 w
.51881 .94524 m
.51904 .94534 L
s
.008 w
.51904 .94534 Mdot
.016 w
.51904 .94534 m
.51924 .94542 L
s
1 .167 0 r
.008 w
.51924 .94542 Mdot
.016 w
.51924 .94542 m
.51944 .9454 L
s
.008 w
.51944 .9454 Mdot
.016 w
.51944 .9454 m
.5197 .94521 L
s
.008 w
.5197 .94521 Mdot
.016 w
.5197 .94521 m
.52009 .94484 L
s
.008 w
.52009 .94484 Mdot
.016 w
.52009 .94484 m
.52061 .94432 L
s
.008 w
.52061 .94432 Mdot
.016 w
.52061 .94432 m
.52133 .94369 L
s
1 .166 0 r
.008 w
.52133 .94369 Mdot
.016 w
.52133 .94369 m
.52231 .94298 L
s
.008 w
.52231 .94298 Mdot
.016 w
.52231 .94298 m
.52355 .94219 L
s
.008 w
.52355 .94219 Mdot
.016 w
.52355 .94219 m
.52497 .94134 L
s
.008 w
.52497 .94134 Mdot
.016 w
.52497 .94134 m
.52652 .94044 L
s
.008 w
.52652 .94044 Mdot
.016 w
.52652 .94044 m
.528 .9395 L
s
1 .165 0 r
.008 w
.528 .9395 Mdot
.016 w
.528 .9395 m
.52961 .93856 L
s
.008 w
.52961 .93856 Mdot
.016 w
.52961 .93856 m
.53137 .93753 L
s
.008 w
.53137 .93753 Mdot
.016 w
.53137 .93753 m
.53292 .93656 L
s
.008 w
.53292 .93656 Mdot
.016 w
.53292 .93656 m
.53447 .93561 L
s
.008 w
.53447 .93561 Mdot
.016 w
.53447 .93561 m
.53577 .93477 L
s
1 .164 0 r
.008 w
.53577 .93477 Mdot
.016 w
.53577 .93477 m
.53712 .93386 L
s
.008 w
.53712 .93386 Mdot
.016 w
.53712 .93386 m
.53834 .93297 L
s
.008 w
.53834 .93297 Mdot
.016 w
.53834 .93297 m
.53965 .93196 L
s
.008 w
.53965 .93196 Mdot
.016 w
.53965 .93196 m
.54066 .93109 L
s
.008 w
.54066 .93109 Mdot
.016 w
.54066 .93109 m
.54169 .93004 L
s
.008 w
.54169 .93004 Mdot
.016 w
.54169 .93004 m
.54279 .92871 L
s
1 .163 0 r
.008 w
.54279 .92871 Mdot
.016 w
.54279 .92871 m
.54377 .92762 L
s
.008 w
.54377 .92762 Mdot
.016 w
.54377 .92762 m
.54494 .92633 L
s
.008 w
.54494 .92633 Mdot
.016 w
.54494 .92633 m
.54622 .92506 L
s
.008 w
.54622 .92506 Mdot
.016 w
.54622 .92506 m
.54775 .92369 L
s
.008 w
.54775 .92369 Mdot
.016 w
.54775 .92369 m
.54898 .92257 L
s
1 .162 0 r
.008 w
.54898 .92257 Mdot
.016 w
.54898 .92257 m
.55045 .92148 L
s
.008 w
.55045 .92148 Mdot
.016 w
.55045 .92148 m
.55172 .92048 L
s
.008 w
.55172 .92048 Mdot
.016 w
.55172 .92048 m
.55302 .9195 L
s
.008 w
.55302 .9195 Mdot
.016 w
.55302 .9195 m
.55411 .91869 L
s
.008 w
.55411 .91869 Mdot
.016 w
.55411 .91869 m
.55507 .918 L
s
1 .161 0 r
.008 w
.55507 .918 Mdot
.016 w
.55507 .918 m
.55584 .91744 L
s
.008 w
.55584 .91744 Mdot
.016 w
.55584 .91744 m
.55642 .91698 L
s
.008 w
.55642 .91698 Mdot
.016 w
.55642 .91698 m
.55688 .9167 L
s
.008 w
.55688 .9167 Mdot
.016 w
.55688 .9167 m
.55719 .91649 L
s
.008 w
.55719 .91649 Mdot
.016 w
.55719 .91649 m
.55741 .91634 L
s
1 .16 0 r
.008 w
.55741 .91634 Mdot
.016 w
.55741 .91634 m
.55757 .91623 L
s
.008 w
.55757 .91623 Mdot
.016 w
.55757 .91623 m
.55769 .91616 L
s
.008 w
.55769 .91616 Mdot
.016 w
.55769 .91616 m
.5578 .91609 L
s
.008 w
.5578 .91609 Mdot
.016 w
.5578 .91609 m
.55789 .91602 L
s
.008 w
.55789 .91602 Mdot
.016 w
.55789 .91602 m
.55795 .91598 L
s
.008 w
.55795 .91598 Mdot
.016 w
.55795 .91598 m
.55797 .91597 L
s
1 .159 0 r
.008 w
.55797 .91597 Mdot
.016 w
.55797 .91597 m
.55798 .91596 L
s
.008 w
.55798 .91596 Mdot
.016 w
.55798 .91596 m
.55799 .91596 L
s
.008 w
.55799 .91596 Mdot
.016 w
.55799 .91596 m
.55798 .91598 L
s
.008 w
.55798 .91598 Mdot
.016 w
.55798 .91598 m
.55796 .91602 L
s
.008 w
.55796 .91602 Mdot
.016 w
.55796 .91602 m
.55793 .91605 L
s
1 .158 0 r
.008 w
.55793 .91605 Mdot
.016 w
.55793 .91605 m
.55791 .91605 L
s
.008 w
.55791 .91605 Mdot
.016 w
.55791 .91605 m
.55789 .91606 L
s
.008 w
.55789 .91606 Mdot
.016 w
.55789 .91606 m
.55789 .91606 L
s
.008 w
.55789 .91606 Mdot
.016 w
.55789 .91606 m
.55789 .91606 L
s
.008 w
.55789 .91606 Mdot
.016 w
.55789 .91606 m
.55789 .91605 L
s
1 .157 0 r
.008 w
.55789 .91605 Mdot
.016 w
.55789 .91605 m
.55791 .91603 L
s
.008 w
.55791 .91603 Mdot
.016 w
.55791 .91603 m
.55793 .91599 L
s
.008 w
.55793 .91599 Mdot
.016 w
.55793 .91599 m
.55796 .91597 L
s
.008 w
.55796 .91597 Mdot
.016 w
.55796 .91597 m
.55798 .91596 L
s
.008 w
.55798 .91596 Mdot
.016 w
.55798 .91596 m
.55795 .91598 L
s
.008 w
.55795 .91598 Mdot
.016 w
.55795 .91598 m
.55785 .91602 L
s
1 .156 0 r
.008 w
.55785 .91602 Mdot
.016 w
.55785 .91602 m
.55768 .91611 L
s
.008 w
.55768 .91611 Mdot
.016 w
.55768 .91611 m
.55746 .91623 L
s
.008 w
.55746 .91623 Mdot
.016 w
.55746 .91623 m
.5572 .91635 L
s
.008 w
.5572 .91635 Mdot
.016 w
.5572 .91635 m
.55697 .91644 L
s
.008 w
.55697 .91644 Mdot
.016 w
.55697 .91644 m
.55677 .91654 L
s
1 .155 0 r
.008 w
.55677 .91654 Mdot
.016 w
.55677 .91654 m
.55666 .91667 L
s
.008 w
.55666 .91667 Mdot
.016 w
.55666 .91667 m
.55666 .91684 L
s
.008 w
.55666 .91684 Mdot
.016 w
.55666 .91684 m
.55685 .91704 L
s
.008 w
.55685 .91704 Mdot
.016 w
.55685 .91704 m
.55728 .91722 L
s
.008 w
.55728 .91722 Mdot
.016 w
.55728 .91722 m
.55802 .91734 L
s
1 .154 0 r
.008 w
.55802 .91734 Mdot
.016 w
.55802 .91734 m
.55913 .91737 L
s
.008 w
.55913 .91737 Mdot
.016 w
.55913 .91737 m
.56072 .91731 L
s
.008 w
.56072 .91731 Mdot
.016 w
.56072 .91731 m
.56281 .91718 L
s
.008 w
.56281 .91718 Mdot
.016 w
.56281 .91718 m
.56533 .91694 L
s
.008 w
.56533 .91694 Mdot
.016 w
.56533 .91694 m
.56832 .91657 L
s
1 .153 0 r
.008 w
.56832 .91657 Mdot
.016 w
.56832 .91657 m
.57162 .91611 L
s
.008 w
.57162 .91611 Mdot
.016 w
.57162 .91611 m
.5754 .91566 L
s
.008 w
.5754 .91566 Mdot
.016 w
.5754 .91566 m
.57893 .91527 L
s
.008 w
.57893 .91527 Mdot
.016 w
.57893 .91527 m
.58261 .91487 L
s
.008 w
.58261 .91487 Mdot
.016 w
.58261 .91487 m
.58629 .91454 L
s
.008 w
.58629 .91454 Mdot
.016 w
.58629 .91454 m
.58937 .91429 L
s
1 .152 0 r
.008 w
.58937 .91429 Mdot
.016 w
.58937 .91429 m
.59231 .9141 L
s
.008 w
.59231 .9141 Mdot
.016 w
.59231 .9141 m
.59488 .91399 L
s
.008 w
.59488 .91399 Mdot
.016 w
.59488 .91399 m
.59688 .91403 L
s
.008 w
.59688 .91403 Mdot
.016 w
.59688 .91403 m
.59852 .91424 L
s
.008 w
.59852 .91424 Mdot
.016 w
.59852 .91424 m
.59973 .91452 L
s
1 .151 0 r
.008 w
.59973 .91452 Mdot
.016 w
.59973 .91452 m
.60048 .91449 L
s
.008 w
.60048 .91449 Mdot
.016 w
.60048 .91449 m
.60095 .91465 L
s
.008 w
.60095 .91465 Mdot
.016 w
.60095 .91465 m
.60117 .91477 L
s
.008 w
.60117 .91477 Mdot
.016 w
.60117 .91477 m
.60122 .91473 L
s
.008 w
.60122 .91473 Mdot
.016 w
.60122 .91473 m
.6012 .91446 L
s
1 .15 0 r
.008 w
.6012 .91446 Mdot
.016 w
.6012 .91446 m
.60116 .91396 L
s
.008 w
.60116 .91396 Mdot
.016 w
.60116 .91396 m
.60115 .9133 L
s
.008 w
.60115 .9133 Mdot
.016 w
.60115 .9133 m
.60118 .91255 L
s
.008 w
.60118 .91255 Mdot
.016 w
.60118 .91255 m
.60129 .9116 L
s
.008 w
.60129 .9116 Mdot
.016 w
.60129 .9116 m
.60147 .91074 L
s
1 .149 0 r
.008 w
.60147 .91074 Mdot
.016 w
.60147 .91074 m
.60172 .90994 L
s
.008 w
.60172 .90994 Mdot
.016 w
.60172 .90994 m
.60201 .909 L
s
.008 w
.60201 .909 Mdot
.016 w
.60201 .909 m
.60233 .90807 L
s
.008 w
.60233 .90807 Mdot
.016 w
.60233 .90807 m
.60267 .90734 L
s
.008 w
.60267 .90734 Mdot
.016 w
.60267 .90734 m
.60307 .90689 L
s
.008 w
.60307 .90689 Mdot
.016 w
.60307 .90689 m
.60357 .90663 L
s
1 .148 0 r
.008 w
.60357 .90663 Mdot
.016 w
.60357 .90663 m
.60425 .9065 L
s
.008 w
.60425 .9065 Mdot
.016 w
.60425 .9065 m
.60518 .90641 L
s
.008 w
.60518 .90641 Mdot
.016 w
.60518 .90641 m
.60645 .90629 L
s
.008 w
.60645 .90629 Mdot
.016 w
.60645 .90629 m
.60811 .90608 L
s
.008 w
.60811 .90608 Mdot
.016 w
.60811 .90608 m
.61024 .90574 L
s
1 .147 0 r
.008 w
.61024 .90574 Mdot
.016 w
.61024 .90574 m
.61267 .90522 L
s
.008 w
.61267 .90522 Mdot
.016 w
.61267 .90522 m
.6156 .90451 L
s
.008 w
.6156 .90451 Mdot
.016 w
.6156 .90451 m
.61886 .90363 L
s
.008 w
.61886 .90363 Mdot
.016 w
.61886 .90363 m
.62272 .90262 L
s
.008 w
.62272 .90262 Mdot
.016 w
.62272 .90262 m
.62656 .90151 L
s
1 .146 0 r
.008 w
.62656 .90151 Mdot
.016 w
.62656 .90151 m
.63076 .90031 L
s
.008 w
.63076 .90031 Mdot
.016 w
.63076 .90031 m
.63502 .89905 L
s
.008 w
.63502 .89905 Mdot
.016 w
.63502 .89905 m
.63954 .89778 L
s
.008 w
.63954 .89778 Mdot
.016 w
.63954 .89778 m
.64385 .89653 L
s
.008 w
.64385 .89653 Mdot
.016 w
.64385 .89653 m
.64824 .89535 L
s
1 .145 0 r
.008 w
.64824 .89535 Mdot
.016 w
.64824 .89535 m
.65235 .8943 L
s
.008 w
.65235 .8943 Mdot
.016 w
.65235 .8943 m
.65609 .8934 L
s
.008 w
.65609 .8934 Mdot
.016 w
.65609 .8934 m
.65958 .89267 L
s
.008 w
.65958 .89267 Mdot
.016 w
.65958 .89267 m
.66266 .89211 L
s
.008 w
.66266 .89211 Mdot
.016 w
.66266 .89211 m
.66509 .89172 L
s
.008 w
.66509 .89172 Mdot
.016 w
.66509 .89172 m
.66728 .89144 L
s
1 .144 0 r
.008 w
.66728 .89144 Mdot
.016 w
.66728 .89144 m
.66907 .89128 L
s
.008 w
.66907 .89128 Mdot
.016 w
.66907 .89128 m
.67046 .89124 L
s
.008 w
.67046 .89124 Mdot
.016 w
.67046 .89124 m
.67153 .89132 L
s
.008 w
.67153 .89132 Mdot
.016 w
.67153 .89132 m
.67236 .89149 L
s
.008 w
.67236 .89149 Mdot
.016 w
.67236 .89149 m
.67307 .89174 L
s
1 .143 0 r
.008 w
.67307 .89174 Mdot
.016 w
.67307 .89174 m
.67379 .89201 L
s
.008 w
.67379 .89201 Mdot
.016 w
.67379 .89201 m
.67461 .89222 L
s
.008 w
.67461 .89222 Mdot
.016 w
.67461 .89222 m
.67565 .89234 L
s
.008 w
.67565 .89234 Mdot
.016 w
.67565 .89234 m
.67691 .89231 L
s
.008 w
.67691 .89231 Mdot
.016 w
.67691 .89231 m
.67856 .89213 L
s
1 .142 0 r
.008 w
.67856 .89213 Mdot
.016 w
.67856 .89213 m
.68051 .89179 L
s
.008 w
.68051 .89179 Mdot
.016 w
.68051 .89179 m
.68276 .89129 L
s
.008 w
.68276 .89129 Mdot
.016 w
.68276 .89129 m
.68515 .89068 L
s
.008 w
.68515 .89068 Mdot
.016 w
.68515 .89068 m
.68793 .88994 L
s
.008 w
.68793 .88994 Mdot
.016 w
.68793 .88994 m
.69077 .88904 L
s
.008 w
.69077 .88904 Mdot
.016 w
.69077 .88904 m
.69382 .88797 L
s
1 .141 0 r
.008 w
.69382 .88797 Mdot
.016 w
.69382 .88797 m
.69678 .88681 L
s
.008 w
.69678 .88681 Mdot
.016 w
.69678 .88681 m
.69968 .88555 L
s
.008 w
.69968 .88555 Mdot
.016 w
.69968 .88555 m
.70245 .88425 L
s
.008 w
.70245 .88425 Mdot
.016 w
.70245 .88425 m
.70492 .88295 L
s
.008 w
.70492 .88295 Mdot
.016 w
.70492 .88295 m
.70713 .88169 L
s
1 .14 0 r
.008 w
.70713 .88169 Mdot
.016 w
.70713 .88169 m
.70904 .88056 L
s
.008 w
.70904 .88056 Mdot
.016 w
.70904 .88056 m
.71066 .87954 L
s
.008 w
.71066 .87954 Mdot
.016 w
.71066 .87954 m
.71196 .87867 L
s
.008 w
.71196 .87867 Mdot
.016 w
.71196 .87867 m
.71299 .87795 L
s
.008 w
.71299 .87795 Mdot
.016 w
.71299 .87795 m
.71375 .87736 L
s
1 .139 0 r
.008 w
.71375 .87736 Mdot
.016 w
.71375 .87736 m
.71426 .87688 L
s
.008 w
.71426 .87688 Mdot
.016 w
.71426 .87688 m
.71454 .87649 L
s
.008 w
.71454 .87649 Mdot
.016 w
.71454 .87649 m
.71462 .8762 L
s
.008 w
.71462 .8762 Mdot
.016 w
.71462 .8762 m
.71455 .876 L
s
.008 w
.71455 .876 Mdot
.016 w
.71455 .876 m
.71438 .87592 L
s
1 .138 0 r
.008 w
.71438 .87592 Mdot
.016 w
.71438 .87592 m
.71419 .87594 L
s
.008 w
.71419 .87594 Mdot
.016 w
.71419 .87594 m
.71406 .87603 L
s
.008 w
.71406 .87603 Mdot
.016 w
.71406 .87603 m
.71407 .87615 L
s
.008 w
.71407 .87615 Mdot
.016 w
.71407 .87615 m
.71428 .87628 L
s
.008 w
.71428 .87628 Mdot
.016 w
.71428 .87628 m
.7147 .87641 L
s
.008 w
.7147 .87641 Mdot
.016 w
.7147 .87641 m
.71537 .87653 L
s
1 .137 0 r
.008 w
.71537 .87653 Mdot
.016 w
.71537 .87653 m
.71627 .87664 L
s
.008 w
.71627 .87664 Mdot
.016 w
.71627 .87664 m
.71739 .87674 L
s
.008 w
.71739 .87674 Mdot
.016 w
.71739 .87674 m
.71864 .87682 L
s
.008 w
.71864 .87682 Mdot
.016 w
.71864 .87682 m
.71997 .87689 L
s
.008 w
.71997 .87689 Mdot
.016 w
.71997 .87689 m
.72142 .87695 L
s
1 .136 0 r
.008 w
.72142 .87695 Mdot
.016 w
.72142 .87695 m
.72291 .877 L
s
.008 w
.72291 .877 Mdot
.016 w
.72291 .877 m
.72451 .87704 L
s
.008 w
.72451 .87704 Mdot
.016 w
.72451 .87704 m
.72583 .87706 L
s
.008 w
.72583 .87706 Mdot
.016 w
.72583 .87706 m
.727 .87706 L
s
.008 w
.727 .87706 Mdot
.016 w
.727 .87706 m
.72796 .87706 L
s
1 .135 0 r
.008 w
.72796 .87706 Mdot
.016 w
.72796 .87706 m
.72868 .87704 L
s
.008 w
.72868 .87704 Mdot
.016 w
.72868 .87704 m
.72922 .87702 L
s
.008 w
.72922 .87702 Mdot
.016 w
.72922 .87702 m
.72959 .87703 L
s
.008 w
.72959 .87703 Mdot
.016 w
.72959 .87703 m
.72983 .87707 L
s
.008 w
.72983 .87707 Mdot
.016 w
.72983 .87707 m
.73007 .87711 L
s
1 .134 0 r
.008 w
.73007 .87711 Mdot
.016 w
.73007 .87711 m
.7305 .87716 L
s
.008 w
.7305 .87716 Mdot
.016 w
.7305 .87716 m
.73124 .87716 L
s
.008 w
.73124 .87716 Mdot
.016 w
.73124 .87716 m
.7324 .87707 L
s
.008 w
.7324 .87707 Mdot
.016 w
.7324 .87707 m
.73397 .87683 L
s
.008 w
.73397 .87683 Mdot
.016 w
.73397 .87683 m
.73617 .8764 L
s
.008 w
.73617 .8764 Mdot
.016 w
.73617 .8764 m
.73879 .87576 L
s
1 .133 0 r
.008 w
.73879 .87576 Mdot
.016 w
.73879 .87576 m
.74148 .87489 L
s
.008 w
.74148 .87489 Mdot
.016 w
.74148 .87489 m
.74514 .87379 L
s
.008 w
.74514 .87379 Mdot
.016 w
.74514 .87379 m
.7486 .87244 L
s
.008 w
.7486 .87244 Mdot
.016 w
.7486 .87244 m
.75275 .87088 L
s
.008 w
.75275 .87088 Mdot
.016 w
.75275 .87088 m
.75738 .86902 L
s
1 .132 0 r
.008 w
.75738 .86902 Mdot
.016 w
.75738 .86902 m
.76223 .86694 L
s
.008 w
.76223 .86694 Mdot
.016 w
.76223 .86694 m
.76662 .86455 L
s
.008 w
.76662 .86455 Mdot
.016 w
.76662 .86455 m
.77151 .86187 L
s
.008 w
.77151 .86187 Mdot
.016 w
.77151 .86187 m
.77646 .85913 L
s
.008 w
.77646 .85913 Mdot
.016 w
.77646 .85913 m
.78109 .85612 L
s
1 .131 0 r
.008 w
.78109 .85612 Mdot
.016 w
.78109 .85612 m
.78563 .85305 L
s
.008 w
.78563 .85305 Mdot
.016 w
.78563 .85305 m
.7902 .84982 L
s
.008 w
.7902 .84982 Mdot
.016 w
.7902 .84982 m
.79494 .8466 L
s
.008 w
.79494 .8466 Mdot
.016 w
.79494 .8466 m
.79885 .84332 L
s
.008 w
.79885 .84332 Mdot
.016 w
.79885 .84332 m
.80305 .83999 L
s
1 .13 0 r
.008 w
.80305 .83999 Mdot
.016 w
.80305 .83999 m
.80733 .83655 L
s
.008 w
.80733 .83655 Mdot
.016 w
.80733 .83655 m
.81125 .83302 L
s
.008 w
.81125 .83302 Mdot
.016 w
.81125 .83302 m
.81492 .82963 L
s
.008 w
.81492 .82963 Mdot
.016 w
.81492 .82963 m
.81879 .82599 L
s
.008 w
.81879 .82599 Mdot
.016 w
.81879 .82599 m
.82225 .8226 L
s
.008 w
.82225 .8226 Mdot
.016 w
.82225 .8226 m
.82572 .81913 L
s
1 .129 0 r
.008 w
.82572 .81913 Mdot
.016 w
.82572 .81913 m
.82903 .81577 L
s
.008 w
.82903 .81577 Mdot
.016 w
.82903 .81577 m
.83215 .81248 L
s
.008 w
.83215 .81248 Mdot
.016 w
.83215 .81248 m
.83522 .80922 L
s
.008 w
.83522 .80922 Mdot
.016 w
.83522 .80922 m
.83814 .80627 L
s
.008 w
.83814 .80627 Mdot
.016 w
.83814 .80627 m
.84093 .8033 L
s
1 .128 0 r
.008 w
.84093 .8033 Mdot
.016 w
.84093 .8033 m
.84365 .80038 L
s
.008 w
.84365 .80038 Mdot
.016 w
.84365 .80038 m
.84647 .79744 L
s
.008 w
.84647 .79744 Mdot
.016 w
.84647 .79744 m
.84894 .79475 L
s
.008 w
.84894 .79475 Mdot
.016 w
.84894 .79475 m
.85158 .79196 L
s
.008 w
.85158 .79196 Mdot
.016 w
.85158 .79196 m
.85408 .78917 L
s
1 .127 0 r
.008 w
.85408 .78917 Mdot
.016 w
.85408 .78917 m
.85659 .78634 L
s
.008 w
.85659 .78634 Mdot
.016 w
.85659 .78634 m
.85916 .78341 L
s
.008 w
.85916 .78341 Mdot
.016 w
.85916 .78341 m
.86156 .78049 L
s
.008 w
.86156 .78049 Mdot
.016 w
.86156 .78049 m
.86392 .77751 L
s
.008 w
.86392 .77751 Mdot
.016 w
.86392 .77751 m
.86621 .77446 L
s
1 .126 0 r
.008 w
.86621 .77446 Mdot
.016 w
.86621 .77446 m
.86825 .77168 L
s
.008 w
.86825 .77168 Mdot
.016 w
.86825 .77168 m
.87017 .76894 L
s
.008 w
.87017 .76894 Mdot
.016 w
.87017 .76894 m
.87195 .76632 L
s
.008 w
.87195 .76632 Mdot
.016 w
.87195 .76632 m
.87342 .76407 L
s
.008 w
.87342 .76407 Mdot
.016 w
.87342 .76407 m
.87473 .76198 L
s
.008 w
.87473 .76198 Mdot
.016 w
.87473 .76198 m
.87581 .76016 L
s
1 .125 0 r
.008 w
.87581 .76016 Mdot
.016 w
.87581 .76016 m
.87663 .75875 L
s
.008 w
.87663 .75875 Mdot
.016 w
.87663 .75875 m
.87718 .75771 L
s
.008 w
.87718 .75771 Mdot
.016 w
.87718 .75771 m
.87747 .75708 L
s
.008 w
.87747 .75708 Mdot
.016 w
.87747 .75708 m
.87753 .7568 L
s
.008 w
.87753 .7568 Mdot
.016 w
.87753 .7568 m
.8774 .75678 L
s
1 .124 0 r
.008 w
.8774 .75678 Mdot
.016 w
.8774 .75678 m
.87714 .75696 L
s
.008 w
.87714 .75696 Mdot
.016 w
.87714 .75696 m
.87681 .75727 L
s
.008 w
.87681 .75727 Mdot
.016 w
.87681 .75727 m
.87644 .75766 L
s
.008 w
.87644 .75766 Mdot
.016 w
.87644 .75766 m
.87608 .75805 L
s
.008 w
.87608 .75805 Mdot
.016 w
.87608 .75805 m
.87575 .75846 L
s
1 .123 0 r
.008 w
.87575 .75846 Mdot
.016 w
.87575 .75846 m
.87543 .7589 L
s
.008 w
.87543 .7589 Mdot
.016 w
.87543 .7589 m
.87517 .75934 L
s
.008 w
.87517 .75934 Mdot
.016 w
.87517 .75934 m
.87493 .75979 L
s
.008 w
.87493 .75979 Mdot
.016 w
.87493 .75979 m
.87473 .76023 L
s
.008 w
.87473 .76023 Mdot
.016 w
.87473 .76023 m
.87459 .76064 L
s
.008 w
.87459 .76064 Mdot
.016 w
.87459 .76064 m
.87448 .761 L
s
1 .122 0 r
.008 w
.87448 .761 Mdot
.016 w
.87448 .761 m
.87441 .76129 L
s
.008 w
.87441 .76129 Mdot
.016 w
.87441 .76129 m
.87436 .76153 L
s
.008 w
.87436 .76153 Mdot
.016 w
.87436 .76153 m
.87432 .76173 L
s
.008 w
.87432 .76173 Mdot
.016 w
.87432 .76173 m
.87431 .76187 L
s
.008 w
.87431 .76187 Mdot
.016 w
.87431 .76187 m
.87433 .76199 L
s
1 .121 0 r
.008 w
.87433 .76199 Mdot
.016 w
.87433 .76199 m
.87435 .76209 L
s
.008 w
.87435 .76209 Mdot
.016 w
.87435 .76209 m
.87436 .76217 L
s
.008 w
.87436 .76217 Mdot
.016 w
.87436 .76217 m
.87438 .76222 L
s
.008 w
.87438 .76222 Mdot
.016 w
.87438 .76222 m
.87441 .76222 L
s
.008 w
.87441 .76222 Mdot
.016 w
.87441 .76222 m
.87446 .76217 L
s
1 .12 0 r
.008 w
.87446 .76217 Mdot
.016 w
.87446 .76217 m
.87453 .76206 L
s
.008 w
.87453 .76206 Mdot
.016 w
.87453 .76206 m
.87459 .76192 L
s
.008 w
.87459 .76192 Mdot
.016 w
.87459 .76192 m
.87463 .76182 L
s
.008 w
.87463 .76182 Mdot
.016 w
.87463 .76182 m
.87466 .76177 L
s
.008 w
.87466 .76177 Mdot
.016 w
.87466 .76177 m
.87467 .76177 L
s
1 .119 0 r
.008 w
.87467 .76177 Mdot
.016 w
.87467 .76177 m
.87466 .76182 L
s
.008 w
.87466 .76182 Mdot
.016 w
.87466 .76182 m
.87461 .76194 L
s
.008 w
.87461 .76194 Mdot
.016 w
.87461 .76194 m
.87448 .76216 L
s
.008 w
.87448 .76216 Mdot
.016 w
.87448 .76216 m
.87429 .76246 L
s
.008 w
.87429 .76246 Mdot
.016 w
.87429 .76246 m
.87402 .76284 L
s
.008 w
.87402 .76284 Mdot
.016 w
.87402 .76284 m
.87367 .76325 L
s
1 .118 0 r
.008 w
.87367 .76325 Mdot
.016 w
.87367 .76325 m
.87324 .76377 L
s
.008 w
.87324 .76377 Mdot
.016 w
.87324 .76377 m
.87274 .76439 L
s
.008 w
.87274 .76439 Mdot
.016 w
.87274 .76439 m
.87223 .76511 L
s
.008 w
.87223 .76511 Mdot
.016 w
.87223 .76511 m
.87171 .76595 L
s
.008 w
.87171 .76595 Mdot
.016 w
.87171 .76595 m
.8712 .76695 L
s
1 .117 0 r
.008 w
.8712 .76695 Mdot
.016 w
.8712 .76695 m
.87072 .76808 L
s
.008 w
.87072 .76808 Mdot
.016 w
.87072 .76808 m
.8703 .76942 L
s
.008 w
.8703 .76942 Mdot
.016 w
.8703 .76942 m
.86991 .77059 L
s
.008 w
.86991 .77059 Mdot
.016 w
.86991 .77059 m
.86956 .77169 L
s
.008 w
.86956 .77169 Mdot
.016 w
.86956 .77169 m
.8693 .77264 L
s
1 .116 0 r
.008 w
.8693 .77264 Mdot
.016 w
.8693 .77264 m
.86912 .77341 L
s
.008 w
.86912 .77341 Mdot
.016 w
.86912 .77341 m
.869 .77407 L
s
.008 w
.869 .77407 Mdot
.016 w
.869 .77407 m
.86891 .77464 L
s
.008 w
.86891 .77464 Mdot
.016 w
.86891 .77464 m
.86885 .77511 L
s
.008 w
.86885 .77511 Mdot
.016 w
.86885 .77511 m
.86881 .77551 L
s
1 .115 0 r
.008 w
.86881 .77551 Mdot
.016 w
.86881 .77551 m
.86875 .77584 L
s
.008 w
.86875 .77584 Mdot
.016 w
.86875 .77584 m
.86867 .7761 L
s
.008 w
.86867 .7761 Mdot
.016 w
.86867 .7761 m
.86858 .77628 L
s
.008 w
.86858 .77628 Mdot
.016 w
.86858 .77628 m
.86849 .77639 L
s
.008 w
.86849 .77639 Mdot
.016 w
.86849 .77639 m
.86841 .77645 L
s
.008 w
.86841 .77645 Mdot
.016 w
.86841 .77645 m
.86837 .77646 L
s
1 .114 0 r
.008 w
.86837 .77646 Mdot
.016 w
.86837 .77646 m
.8684 .77639 L
s
.008 w
.8684 .77639 Mdot
.016 w
.8684 .77639 m
.86848 .7763 L
s
.008 w
.86848 .7763 Mdot
.016 w
.86848 .7763 m
.86861 .77617 L
s
.008 w
.86861 .77617 Mdot
.016 w
.86861 .77617 m
.86884 .77587 L
s
.008 w
.86884 .77587 Mdot
.016 w
.86884 .77587 m
.86922 .77529 L
s
1 .113 0 r
.008 w
.86922 .77529 Mdot
.016 w
.86922 .77529 m
.86977 .77438 L
s
.008 w
.86977 .77438 Mdot
.016 w
.86977 .77438 m
.87056 .77298 L
s
.008 w
.87056 .77298 Mdot
.016 w
.87056 .77298 m
.87142 .77134 L
s
.008 w
.87142 .77134 Mdot
.016 w
.87142 .77134 m
.87254 .76914 L
s
.008 w
.87254 .76914 Mdot
.016 w
.87254 .76914 m
.87379 .76646 L
s
1 .112 0 r
.008 w
.87379 .76646 Mdot
.016 w
.87379 .76646 m
.87517 .76341 L
s
.008 w
.87517 .76341 Mdot
.016 w
.87517 .76341 m
.87661 .75996 L
s
.008 w
.87661 .75996 Mdot
.016 w
.87661 .75996 m
.87809 .7562 L
s
.008 w
.87809 .7562 Mdot
.016 w
.87809 .7562 m
.87964 .75196 L
s
.008 w
.87964 .75196 Mdot
.016 w
.87964 .75196 m
.88123 .74733 L
s
1 .111 0 r
.008 w
.88123 .74733 Mdot
.016 w
.88123 .74733 m
.88302 .74229 L
s
.008 w
.88302 .74229 Mdot
.016 w
.88302 .74229 m
.88464 .73685 L
s
.008 w
.88464 .73685 Mdot
.016 w
.88464 .73685 m
.88644 .7311 L
s
.008 w
.88644 .7311 Mdot
.016 w
.88644 .7311 m
.8883 .72508 L
s
.008 w
.8883 .72508 Mdot
.016 w
.8883 .72508 m
.89015 .71876 L
s
.008 w
.89015 .71876 Mdot
.016 w
.89015 .71876 m
.89214 .71193 L
s
1 .11 0 r
.008 w
.89214 .71193 Mdot
.016 w
.89214 .71193 m
.89406 .70543 L
s
.008 w
.89406 .70543 Mdot
.016 w
.89406 .70543 m
.89616 .69852 L
s
.008 w
.89616 .69852 Mdot
.016 w
.89616 .69852 m
.89821 .69105 L
s
.008 w
.89821 .69105 Mdot
.016 w
.89821 .69105 m
.90002 .68459 L
s
.008 w
.90002 .68459 Mdot
.016 w
.90002 .68459 m
.90191 .67776 L
s
1 .109 0 r
.008 w
.90191 .67776 Mdot
.016 w
.90191 .67776 m
.90372 .67126 L
s
.008 w
.90372 .67126 Mdot
.016 w
.90372 .67126 m
.90542 .66512 L
s
.008 w
.90542 .66512 Mdot
.016 w
.90542 .66512 m
.90688 .65981 L
s
.008 w
.90688 .65981 Mdot
.016 w
.90688 .65981 m
.90816 .65493 L
s
.008 w
.90816 .65493 Mdot
.016 w
.90816 .65493 m
.90926 .65027 L
s
1 .108 0 r
.008 w
.90926 .65027 Mdot
.016 w
.90926 .65027 m
.91018 .64661 L
s
.008 w
.91018 .64661 Mdot
.016 w
.91018 .64661 m
.91105 .64317 L
s
.008 w
.91105 .64317 Mdot
.016 w
.91105 .64317 m
.91185 .63994 L
s
.008 w
.91185 .63994 Mdot
.016 w
.91185 .63994 m
.91263 .63694 L
s
.008 w
.91263 .63694 Mdot
.016 w
.91263 .63694 m
.91344 .63385 L
s
.008 w
.91344 .63385 Mdot
.016 w
.91344 .63385 m
.91429 .63069 L
s
1 .107 0 r
.008 w
.91429 .63069 Mdot
.016 w
.91429 .63069 m
.91512 .62727 L
s
.008 w
.91512 .62727 Mdot
.016 w
.91512 .62727 m
.91604 .62341 L
s
.008 w
.91604 .62341 Mdot
.016 w
.91604 .62341 m
.91693 .61939 L
s
.008 w
.91693 .61939 Mdot
.016 w
.91693 .61939 m
.91789 .61521 L
s
.008 w
.91789 .61521 Mdot
.016 w
.91789 .61521 m
.91894 .61045 L
s
1 .106 0 r
.008 w
.91894 .61045 Mdot
.016 w
.91894 .61045 m
.91999 .60507 L
s
.008 w
.91999 .60507 Mdot
.016 w
.91999 .60507 m
.92111 .59959 L
s
.008 w
.92111 .59959 Mdot
.016 w
.92111 .59959 m
.92222 .59379 L
s
.008 w
.92222 .59379 Mdot
.016 w
.92222 .59379 m
.92328 .58811 L
s
.008 w
.92328 .58811 Mdot
.016 w
.92328 .58811 m
.92432 .58239 L
s
1 .105 0 r
.008 w
.92432 .58239 Mdot
.016 w
.92432 .58239 m
.92529 .57673 L
s
.008 w
.92529 .57673 Mdot
.016 w
.92529 .57673 m
.92621 .5712 L
s
.008 w
.92621 .5712 Mdot
.016 w
.92621 .5712 m
.92709 .566 L
s
.008 w
.92709 .566 Mdot
.016 w
.92709 .566 m
.92792 .56098 L
s
.008 w
.92792 .56098 Mdot
.016 w
.92792 .56098 m
.92873 .55606 L
s
1 .104 0 r
.008 w
.92873 .55606 Mdot
.016 w
.92873 .55606 m
.92947 .55141 L
s
.008 w
.92947 .55141 Mdot
.016 w
.92947 .55141 m
.93014 .54665 L
s
.008 w
.93014 .54665 Mdot
.016 w
.93014 .54665 m
.93069 .5421 L
s
.008 w
.93069 .5421 Mdot
.016 w
.93069 .5421 m
.93113 .53741 L
s
.008 w
.93113 .53741 Mdot
.016 w
.93113 .53741 m
.93141 .53269 L
s
.008 w
.93141 .53269 Mdot
.016 w
.93141 .53269 m
.93156 .52806 L
s
1 .103 0 r
.008 w
.93156 .52806 Mdot
.016 w
.93156 .52806 m
.93158 .52342 L
s
.008 w
.93158 .52342 Mdot
.016 w
.93158 .52342 m
.93148 .51891 L
s
.008 w
.93148 .51891 Mdot
.016 w
.93148 .51891 m
.93128 .5146 L
s
.008 w
.93128 .5146 Mdot
.016 w
.93128 .5146 m
.93101 .51059 L
s
.008 w
.93101 .51059 Mdot
.016 w
.93101 .51059 m
.93069 .50689 L
s
1 .102 0 r
.008 w
.93069 .50689 Mdot
.016 w
.93069 .50689 m
.93036 .50353 L
s
.008 w
.93036 .50353 Mdot
.016 w
.93036 .50353 m
.93003 .50067 L
s
.008 w
.93003 .50067 Mdot
.016 w
.93003 .50067 m
.92974 .49819 L
s
.008 w
.92974 .49819 Mdot
.016 w
.92974 .49819 m
.92951 .49618 L
s
.008 w
.92951 .49618 Mdot
.016 w
.92951 .49618 m
.92935 .49463 L
s
1 .101 0 r
.008 w
.92935 .49463 Mdot
.016 w
.92935 .49463 m
.92927 .4935 L
s
.008 w
.92927 .4935 Mdot
.016 w
.92927 .4935 m
.92925 .49282 L
s
.008 w
.92925 .49282 Mdot
.016 w
.92925 .49282 m
.92929 .49255 L
s
.008 w
.92929 .49255 Mdot
.016 w
.92929 .49255 m
.92938 .49261 L
s
.008 w
.92938 .49261 Mdot
.016 w
.92938 .49261 m
.92951 .49289 L
s
1 .1 0 r
.008 w
.92951 .49289 Mdot
.016 w
.92951 .49289 m
.92966 .49332 L
s
.008 w
.92966 .49332 Mdot
.016 w
.92966 .49332 m
.9298 .49383 L
s
.008 w
.9298 .49383 Mdot
.016 w
.9298 .49383 m
.92988 .49437 L
s
.008 w
.92988 .49437 Mdot
.016 w
.92988 .49437 m
.92989 .49495 L
s
.008 w
.92989 .49495 Mdot
.016 w
.92989 .49495 m
.92982 .4956 L
s
.008 w
.92982 .4956 Mdot
.016 w
.92982 .4956 m
.92965 .49641 L
s
1 .099 0 r
.008 w
.92965 .49641 Mdot
.016 w
.92965 .49641 m
.92939 .49748 L
s
.008 w
.92939 .49748 Mdot
.016 w
.92939 .49748 m
.92904 .49888 L
s
.008 w
.92904 .49888 Mdot
.016 w
.92904 .49888 m
.92862 .5007 L
s
.008 w
.92862 .5007 Mdot
.016 w
.92862 .5007 m
.92813 .503 L
s
.008 w
.92813 .503 Mdot
.016 w
.92813 .503 m
.92758 .5058 L
s
1 .098 0 r
.008 w
.92758 .5058 Mdot
.016 w
.92758 .5058 m
.927 .5088 L
s
.008 w
.927 .5088 Mdot
.016 w
.927 .5088 m
.92638 .5124 L
s
.008 w
.92638 .5124 Mdot
.016 w
.92638 .5124 m
.92576 .51667 L
s
.008 w
.92576 .51667 Mdot
.016 w
.92576 .51667 m
.92517 .52086 L
s
.008 w
.92517 .52086 Mdot
.016 w
.92517 .52086 m
.92464 .52585 L
s
1 .097 0 r
.008 w
.92464 .52585 Mdot
.016 w
.92464 .52585 m
.9242 .53167 L
s
.008 w
.9242 .53167 Mdot
.016 w
.9242 .53167 m
.92387 .53689 L
s
.008 w
.92387 .53689 Mdot
.016 w
.92387 .53689 m
.92366 .54301 L
s
.008 w
.92366 .54301 Mdot
.016 w
.92366 .54301 m
.92354 .54955 L
s
.008 w
.92354 .54955 Mdot
.016 w
.92354 .54955 m
.92346 .55542 L
s
1 .096 0 r
.008 w
.92346 .55542 Mdot
.016 w
.92346 .55542 m
.92336 .56219 L
s
.008 w
.92336 .56219 Mdot
.016 w
.92336 .56219 m
.92318 .5683 L
s
.008 w
.92318 .5683 Mdot
.016 w
.92318 .5683 m
.92287 .57522 L
s
.008 w
.92287 .57522 Mdot
.016 w
.92287 .57522 m
.9224 .58126 L
s
.008 w
.9224 .58126 Mdot
.016 w
.9224 .58126 m
.92175 .5882 L
s
.008 w
.92175 .5882 Mdot
.016 w
.92175 .5882 m
.92095 .59462 L
s
1 .095 0 r
.008 w
.92095 .59462 Mdot
.016 w
.92095 .59462 m
.91997 .60124 L
s
.008 w
.91997 .60124 Mdot
.016 w
.91997 .60124 m
.9188 .60782 L
s
.008 w
.9188 .60782 Mdot
.016 w
.9188 .60782 m
.91747 .6145 L
s
.008 w
.91747 .6145 Mdot
.016 w
.91747 .6145 m
.91598 .62139 L
s
.008 w
.91598 .62139 Mdot
.016 w
.91598 .62139 m
.91434 .62811 L
s
1 .094 0 r
.008 w
.91434 .62811 Mdot
.016 w
.91434 .62811 m
.91259 .63488 L
s
.008 w
.91259 .63488 Mdot
.016 w
.91259 .63488 m
.91073 .64161 L
s
.008 w
.91073 .64161 Mdot
.016 w
.91073 .64161 m
.90881 .64868 L
s
.008 w
.90881 .64868 Mdot
.016 w
.90881 .64868 m
.90687 .6555 L
s
.008 w
.90687 .6555 Mdot
.016 w
.90687 .6555 m
.9049 .66252 L
s
1 .093 0 r
.008 w
.9049 .66252 Mdot
.016 w
.9049 .66252 m
.9029 .66975 L
s
.008 w
.9029 .66975 Mdot
.016 w
.9029 .66975 m
.90089 .67748 L
s
.008 w
.90089 .67748 Mdot
.016 w
.90089 .67748 m
.8989 .68443 L
s
.008 w
.8989 .68443 Mdot
.016 w
.8989 .68443 m
.89693 .69183 L
s
.008 w
.89693 .69183 Mdot
.016 w
.89693 .69183 m
.89502 .69914 L
s
1 .092 0 r
.008 w
.89502 .69914 Mdot
.016 w
.89502 .69914 m
.89314 .7063 L
s
.008 w
.89314 .7063 Mdot
.016 w
.89314 .7063 m
.89128 .71366 L
s
.008 w
.89128 .71366 Mdot
.016 w
.89128 .71366 m
.88943 .72048 L
s
.008 w
.88943 .72048 Mdot
.016 w
.88943 .72048 m
.88759 .72751 L
s
.008 w
.88759 .72751 Mdot
.016 w
.88759 .72751 m
.88577 .73389 L
s
.008 w
.88577 .73389 Mdot
.016 w
.88577 .73389 m
.88391 .74049 L
s
1 .091 0 r
.008 w
.88391 .74049 Mdot
.016 w
.88391 .74049 m
.88201 .74678 L
s
.008 w
.88201 .74678 Mdot
.016 w
.88201 .74678 m
.88003 .75269 L
s
.008 w
.88003 .75269 Mdot
.016 w
.88003 .75269 m
.87787 .75892 L
s
.008 w
.87787 .75892 Mdot
.016 w
.87787 .75892 m
.87561 .76403 L
s
.008 w
.87561 .76403 Mdot
.016 w
.87561 .76403 m
.8731 .76939 L
s
1 .09 0 r
.008 w
.8731 .76939 Mdot
.016 w
.8731 .76939 m
.87025 .77462 L
s
.008 w
.87025 .77462 Mdot
.016 w
.87025 .77462 m
.86714 .77936 L
s
.008 w
.86714 .77936 Mdot
.016 w
.86714 .77936 m
.86362 .78439 L
s
.008 w
.86362 .78439 Mdot
.016 w
.86362 .78439 m
.85998 .78892 L
s
.008 w
.85998 .78892 Mdot
.016 w
.85998 .78892 m
.85583 .79359 L
s
1 .089 0 r
.008 w
.85583 .79359 Mdot
.016 w
.85583 .79359 m
.85199 .79782 L
s
.008 w
.85199 .79782 Mdot
.016 w
.85199 .79782 m
.84786 .80195 L
s
.008 w
.84786 .80195 Mdot
.016 w
.84786 .80195 m
.84347 .80593 L
s
.008 w
.84347 .80593 Mdot
.016 w
.84347 .80593 m
.83949 .80966 L
s
.008 w
.83949 .80966 Mdot
.016 w
.83949 .80966 m
.83524 .81327 L
s
.008 w
.83524 .81327 Mdot
.016 w
.83524 .81327 m
.83103 .81682 L
s
1 .088 0 r
.008 w
.83103 .81682 Mdot
.016 w
.83103 .81682 m
.82637 .82058 L
s
.008 w
.82637 .82058 Mdot
.016 w
.82637 .82058 m
.82236 .82408 L
s
.008 w
.82236 .82408 Mdot
.016 w
.82236 .82408 m
.81785 .82781 L
s
.008 w
.81785 .82781 Mdot
.016 w
.81785 .82781 m
.81333 .83163 L
s
.008 w
.81333 .83163 Mdot
.016 w
.81333 .83163 m
.80827 .83565 L
s
1 .087 0 r
.008 w
.80827 .83565 Mdot
.016 w
.80827 .83565 m
.80391 .83931 L
s
.008 w
.80391 .83931 Mdot
.016 w
.80391 .83931 m
.79868 .84333 L
s
.008 w
.79868 .84333 Mdot
.016 w
.79868 .84333 m
.79402 .84728 L
s
.008 w
.79402 .84728 Mdot
.016 w
.79402 .84728 m
.78848 .85156 L
s
.008 w
.78848 .85156 Mdot
.016 w
.78848 .85156 m
.78343 .8557 L
s
1 .086 0 r
.008 w
.78343 .8557 Mdot
.016 w
.78343 .8557 m
.77798 .86 L
s
.008 w
.77798 .86 Mdot
.016 w
.77798 .86 m
.7723 .86453 L
s
.008 w
.7723 .86453 Mdot
.016 w
.7723 .86453 m
.76704 .8687 L
s
.008 w
.76704 .8687 Mdot
.016 w
.76704 .8687 m
.76144 .87304 L
s
.008 w
.76144 .87304 Mdot
.016 w
.76144 .87304 m
.75592 .87735 L
s
1 .085 0 r
.008 w
.75592 .87735 Mdot
.016 w
.75592 .87735 m
.75055 .88163 L
s
.008 w
.75055 .88163 Mdot
.016 w
.75055 .88163 m
.74502 .88574 L
s
.008 w
.74502 .88574 Mdot
.016 w
.74502 .88574 m
.73973 .88966 L
s
.008 w
.73973 .88966 Mdot
.016 w
.73973 .88966 m
.73435 .89372 L
s
.008 w
.73435 .89372 Mdot
.016 w
.73435 .89372 m
.72897 .89752 L
s
.008 w
.72897 .89752 Mdot
.016 w
.72897 .89752 m
.72395 .90127 L
s
1 .084 0 r
.008 w
.72395 .90127 Mdot
.016 w
.72395 .90127 m
.71922 .90474 L
s
.008 w
.71922 .90474 Mdot
.016 w
.71922 .90474 m
.71459 .9081 L
s
.008 w
.71459 .9081 Mdot
.016 w
.71459 .9081 m
.71043 .91113 L
s
.008 w
.71043 .91113 Mdot
.016 w
.71043 .91113 m
.70623 .91404 L
s
.008 w
.70623 .91404 Mdot
.016 w
.70623 .91404 m
.70289 .91636 L
s
1 .083 0 r
.008 w
.70289 .91636 Mdot
.016 w
.70289 .91636 m
.69987 .91844 L
s
.008 w
.69987 .91844 Mdot
.016 w
.69987 .91844 m
.69727 .92021 L
s
.008 w
.69727 .92021 Mdot
.016 w
.69727 .92021 m
.69525 .92159 L
s
.008 w
.69525 .92159 Mdot
.016 w
.69525 .92159 m
.69374 .92266 L
s
.008 w
.69374 .92266 Mdot
.016 w
.69374 .92266 m
.69273 .92348 L
s
1 .082 0 r
.008 w
.69273 .92348 Mdot
.016 w
.69273 .92348 m
.69211 .92406 L
s
.008 w
.69211 .92406 Mdot
.016 w
.69211 .92406 m
.69178 .92442 L
s
.008 w
.69178 .92442 Mdot
.016 w
.69178 .92442 m
.69162 .9246 L
s
.008 w
.69162 .9246 Mdot
.016 w
.69162 .9246 m
.69151 .92463 L
s
.008 w
.69151 .92463 Mdot
.016 w
.69151 .92463 m
.69132 .92453 L
s
1 .081 0 r
.008 w
.69132 .92453 Mdot
.016 w
.69132 .92453 m
.69093 .92431 L
s
.008 w
.69093 .92431 Mdot
.016 w
.69093 .92431 m
.69029 .924 L
s
.008 w
.69029 .924 Mdot
.016 w
.69029 .924 m
.68934 .92364 L
s
.008 w
.68934 .92364 Mdot
.016 w
.68934 .92364 m
.68806 .92327 L
s
.008 w
.68806 .92327 Mdot
.016 w
.68806 .92327 m
.68632 .92291 L
s
.008 w
.68632 .92291 Mdot
.016 w
.68632 .92291 m
.68403 .92262 L
s
1 .08 0 r
.008 w
.68403 .92262 Mdot
.016 w
.68403 .92262 m
.68121 .92243 L
s
.008 w
.68121 .92243 Mdot
.016 w
.68121 .92243 m
.67799 .92234 L
s
.008 w
.67799 .92234 Mdot
.016 w
.67799 .92234 m
.6741 .92235 L
s
.008 w
.6741 .92235 Mdot
.016 w
.6741 .92235 m
.66952 .92246 L
s
.008 w
.66952 .92246 Mdot
.016 w
.66952 .92246 m
.66507 .92268 L
s
1 .079 0 r
.008 w
.66507 .92268 Mdot
.016 w
.66507 .92268 m
.66006 .92296 L
s
.008 w
.66006 .92296 Mdot
.016 w
.66006 .92296 m
.65542 .9234 L
s
.008 w
.65542 .9234 Mdot
.016 w
.65542 .9234 m
.64998 .92408 L
s
.008 w
.64998 .92408 Mdot
.016 w
.64998 .92408 m
.64491 .92475 L
s
.008 w
.64491 .92475 Mdot
.016 w
.64491 .92475 m
.63924 .92566 L
s
1 .078 0 r
.008 w
.63924 .92566 Mdot
.016 w
.63924 .92566 m
.63409 .92668 L
s
.008 w
.63409 .92668 Mdot
.016 w
.63409 .92668 m
.62842 .92783 L
s
.008 w
.62842 .92783 Mdot
.016 w
.62842 .92783 m
.62299 .92889 L
s
.008 w
.62299 .92889 Mdot
.016 w
.62299 .92889 m
.61801 .93004 L
s
.008 w
.61801 .93004 Mdot
.016 w
.61801 .93004 m
.61265 .93121 L
s
1 .077 0 r
.008 w
.61265 .93121 Mdot
.016 w
.61265 .93121 m
.60771 .9323 L
s
.008 w
.60771 .9323 Mdot
.016 w
.60771 .9323 m
.60263 .93348 L
s
.008 w
.60263 .93348 Mdot
.016 w
.60263 .93348 m
.59771 .93472 L
s
.008 w
.59771 .93472 Mdot
.016 w
.59771 .93472 m
.59274 .93614 L
s
.008 w
.59274 .93614 Mdot
.016 w
.59274 .93614 m
.58806 .93736 L
s
.008 w
.58806 .93736 Mdot
.016 w
.58806 .93736 m
.58302 .93877 L
s
1 .076 0 r
.008 w
.58302 .93877 Mdot
.016 w
.58302 .93877 m
.57839 .94024 L
s
.008 w
.57839 .94024 Mdot
.016 w
.57839 .94024 m
.5733 .94175 L
s
.008 w
.5733 .94175 Mdot
.016 w
.5733 .94175 m
.56831 .94319 L
s
.008 w
.56831 .94319 Mdot
.016 w
.56831 .94319 m
.5633 .94466 L
s
.008 w
.5633 .94466 Mdot
.016 w
.5633 .94466 m
.55769 .94614 L
s
1 .075 0 r
.008 w
.55769 .94614 Mdot
.016 w
.55769 .94614 m
.55259 .9476 L
s
.008 w
.55259 .9476 Mdot
.016 w
.55259 .9476 m
.54695 .94905 L
s
.008 w
.54695 .94905 Mdot
.016 w
.54695 .94905 m
.54112 .9505 L
s
.008 w
.54112 .9505 Mdot
.016 w
.54112 .9505 m
.53522 .95188 L
s
.008 w
.53522 .95188 Mdot
.016 w
.53522 .95188 m
.52891 .95318 L
s
1 .074 0 r
.008 w
.52891 .95318 Mdot
.016 w
.52891 .95318 m
.52331 .95432 L
s
.008 w
.52331 .95432 Mdot
.016 w
.52331 .95432 m
.51688 .95529 L
s
.008 w
.51688 .95529 Mdot
.016 w
.51688 .95529 m
.5108 .95603 L
s
.008 w
.5108 .95603 Mdot
.016 w
.5108 .95603 m
.50512 .95652 L
s
.008 w
.50512 .95652 Mdot
.016 w
.50512 .95652 m
.499 .95676 L
s
.008 w
.499 .95676 Mdot
.016 w
.499 .95676 m
.49352 .95676 L
s
1 .073 0 r
.008 w
.49352 .95676 Mdot
.016 w
.49352 .95676 m
.48791 .9565 L
s
.008 w
.48791 .9565 Mdot
.016 w
.48791 .9565 m
.48233 .95598 L
s
.008 w
.48233 .95598 Mdot
.016 w
.48233 .95598 m
.4772 .95524 L
s
.008 w
.4772 .95524 Mdot
.016 w
.4772 .95524 m
.47203 .95429 L
s
.008 w
.47203 .95429 Mdot
.016 w
.47203 .95429 m
.46714 .95315 L
s
1 .072 0 r
.008 w
.46714 .95315 Mdot
.016 w
.46714 .95315 m
.46219 .95191 L
s
.008 w
.46219 .95191 Mdot
.016 w
.46219 .95191 m
.45784 .95053 L
s
.008 w
.45784 .95053 Mdot
.016 w
.45784 .95053 m
.45348 .9491 L
s
.008 w
.45348 .9491 Mdot
.016 w
.45348 .9491 m
.44931 .94762 L
s
.008 w
.44931 .94762 Mdot
.016 w
.44931 .94762 m
.44528 .94618 L
s
1 .071 0 r
.008 w
.44528 .94618 Mdot
.016 w
.44528 .94618 m
.44144 .94475 L
s
.008 w
.44144 .94475 Mdot
.016 w
.44144 .94475 m
.43775 .94337 L
s
.008 w
.43775 .94337 Mdot
.016 w
.43775 .94337 m
.43416 .94202 L
s
.008 w
.43416 .94202 Mdot
.016 w
.43416 .94202 m
.43067 .94073 L
s
.008 w
.43067 .94073 Mdot
.016 w
.43067 .94073 m
.42744 .93944 L
s
1 .07 0 r
.008 w
.42744 .93944 Mdot
.016 w
.42744 .93944 m
.42423 .93818 L
s
.008 w
.42423 .93818 Mdot
.016 w
.42423 .93818 m
.42122 .93701 L
s
.008 w
.42122 .93701 Mdot
.016 w
.42122 .93701 m
.4183 .9359 L
s
.008 w
.4183 .9359 Mdot
.016 w
.4183 .9359 m
.41571 .93486 L
s
.008 w
.41571 .93486 Mdot
.016 w
.41571 .93486 m
.41331 .93395 L
s
.008 w
.41331 .93395 Mdot
.016 w
.41331 .93395 m
.41127 .93312 L
s
1 .069 0 r
.008 w
.41127 .93312 Mdot
.016 w
.41127 .93312 m
.40949 .93238 L
s
.008 w
.40949 .93238 Mdot
.016 w
.40949 .93238 m
.40801 .93173 L
s
.008 w
.40801 .93173 Mdot
.016 w
.40801 .93173 m
.40683 .9312 L
s
.008 w
.40683 .9312 Mdot
.016 w
.40683 .9312 m
.40593 .93077 L
s
.008 w
.40593 .93077 Mdot
.016 w
.40593 .93077 m
.40528 .93045 L
s
1 .068 0 r
.008 w
.40528 .93045 Mdot
.016 w
.40528 .93045 m
.40487 .93026 L
s
.008 w
.40487 .93026 Mdot
.016 w
.40487 .93026 m
.40468 .93017 L
s
.008 w
.40468 .93017 Mdot
.016 w
.40468 .93017 m
.40466 .93015 L
s
.008 w
.40466 .93015 Mdot
.016 w
.40466 .93015 m
.40474 .93017 L
s
.008 w
.40474 .93017 Mdot
.016 w
.40474 .93017 m
.40487 .93022 L
s
1 .067 0 r
.008 w
.40487 .93022 Mdot
.016 w
.40487 .93022 m
.40501 .93028 L
s
.008 w
.40501 .93028 Mdot
.016 w
.40501 .93028 m
.40513 .93035 L
s
.008 w
.40513 .93035 Mdot
.016 w
.40513 .93035 m
.40525 .93042 L
s
.008 w
.40525 .93042 Mdot
.016 w
.40525 .93042 m
.40535 .93047 L
s
.008 w
.40535 .93047 Mdot
.016 w
.40535 .93047 m
.40542 .93052 L
s
1 .066 0 r
.008 w
.40542 .93052 Mdot
.016 w
.40542 .93052 m
.40547 .93056 L
s
.008 w
.40547 .93056 Mdot
.016 w
.40547 .93056 m
.4055 .93059 L
s
.008 w
.4055 .93059 Mdot
.016 w
.4055 .93059 m
.40553 .93062 L
s
.008 w
.40553 .93062 Mdot
.016 w
.40553 .93062 m
.40555 .93064 L
s
.008 w
.40555 .93064 Mdot
.016 w
.40555 .93064 m
.40557 .93065 L
s
.008 w
.40557 .93065 Mdot
.016 w
.40557 .93065 m
.40555 .93064 L
s
1 .065 0 r
.008 w
.40555 .93064 Mdot
.016 w
.40555 .93064 m
.40555 .93064 L
s
.008 w
.40555 .93064 Mdot
.016 w
.40555 .93064 m
.40554 .93063 L
s
.008 w
.40554 .93063 Mdot
.016 w
.40554 .93063 m
.40551 .9306 L
s
.008 w
.40551 .9306 Mdot
.016 w
.40551 .9306 m
.40546 .93056 L
s
.008 w
.40546 .93056 Mdot
.016 w
.40546 .93056 m
.4054 .93051 L
s
1 .064 0 r
.008 w
.4054 .93051 Mdot
.016 w
.4054 .93051 m
.40536 .93047 L
s
.008 w
.40536 .93047 Mdot
.016 w
.40536 .93047 m
.40533 .93045 L
s
.008 w
.40533 .93045 Mdot
.016 w
.40533 .93045 m
.40534 .93045 L
s
.008 w
.40534 .93045 Mdot
.016 w
.40534 .93045 m
.40538 .93049 L
s
.008 w
.40538 .93049 Mdot
.016 w
.40538 .93049 m
.40545 .93054 L
s
1 .063 0 r
.008 w
.40545 .93054 Mdot
.016 w
.40545 .93054 m
.40553 .93061 L
s
.008 w
.40553 .93061 Mdot
.016 w
.40553 .93061 m
.40562 .93069 L
s
.008 w
.40562 .93069 Mdot
.016 w
.40562 .93069 m
.40575 .93077 L
s
.008 w
.40575 .93077 Mdot
.016 w
.40575 .93077 m
.4059 .93084 L
s
.008 w
.4059 .93084 Mdot
.016 w
.4059 .93084 m
.40609 .93093 L
s
1 .062 0 r
.008 w
.40609 .93093 Mdot
.016 w
.40609 .93093 m
.40628 .93101 L
s
.008 w
.40628 .93101 Mdot
.016 w
.40628 .93101 m
.40647 .93109 L
s
.008 w
.40647 .93109 Mdot
.016 w
.40647 .93109 m
.40662 .93116 L
s
.008 w
.40662 .93116 Mdot
.016 w
.40662 .93116 m
.40668 .93118 L
s
.008 w
.40668 .93118 Mdot
.016 w
.40668 .93118 m
.40658 .93114 L
s
.008 w
.40658 .93114 Mdot
.016 w
.40658 .93114 m
.40626 .931 L
s
1 .061 0 r
.008 w
.40626 .931 Mdot
.016 w
.40626 .931 m
.40566 .93076 L
s
.008 w
.40566 .93076 Mdot
.016 w
.40566 .93076 m
.4047 .9304 L
s
.008 w
.4047 .9304 Mdot
.016 w
.4047 .9304 m
.40335 .92991 L
s
.008 w
.40335 .92991 Mdot
.016 w
.40335 .92991 m
.40156 .9293 L
s
.008 w
.40156 .9293 Mdot
.016 w
.40156 .9293 m
.39953 .92855 L
s
1 .06 0 r
.008 w
.39953 .92855 Mdot
.016 w
.39953 .92855 m
.39703 .92773 L
s
.008 w
.39703 .92773 Mdot
.016 w
.39703 .92773 m
.39411 .92677 L
s
.008 w
.39411 .92677 Mdot
.016 w
.39411 .92677 m
.3909 .92568 L
s
.008 w
.3909 .92568 Mdot
.016 w
.3909 .92568 m
.38716 .9245 L
s
.008 w
.38716 .9245 Mdot
.016 w
.38716 .9245 m
.38333 .92324 L
s
1 .059 0 r
.008 w
.38333 .92324 Mdot
.016 w
.38333 .92324 m
.37888 .92185 L
s
.008 w
.37888 .92185 Mdot
.016 w
.37888 .92185 m
.37474 .92037 L
s
.008 w
.37474 .92037 Mdot
.016 w
.37474 .92037 m
.36983 .91883 L
s
.008 w
.36983 .91883 Mdot
.016 w
.36983 .91883 m
.3655 .91729 L
s
.008 w
.3655 .91729 Mdot
.016 w
.3655 .91729 m
.36047 .9157 L
s
1 .058 0 r
.008 w
.36047 .9157 Mdot
.016 w
.36047 .9157 m
.35618 .91412 L
s
.008 w
.35618 .91412 Mdot
.016 w
.35618 .91412 m
.35146 .91249 L
s
.008 w
.35146 .91249 Mdot
.016 w
.35146 .91249 m
.34699 .91082 L
s
.008 w
.34699 .91082 Mdot
.016 w
.34699 .91082 m
.34254 .90904 L
s
.008 w
.34254 .90904 Mdot
.016 w
.34254 .90904 m
.338 .90734 L
s
.008 w
.338 .90734 Mdot
.016 w
.338 .90734 m
.33395 .90552 L
s
1 .057 0 r
.008 w
.33395 .90552 Mdot
.016 w
.33395 .90552 m
.32987 .90383 L
s
.008 w
.32987 .90383 Mdot
.016 w
.32987 .90383 m
.32586 .90215 L
s
.008 w
.32586 .90215 Mdot
.016 w
.32586 .90215 m
.32223 .90054 L
s
.008 w
.32223 .90054 Mdot
.016 w
.32223 .90054 m
.31871 .89898 L
s
.008 w
.31871 .89898 Mdot
.016 w
.31871 .89898 m
.31528 .8976 L
s
1 .056 0 r
.008 w
.31528 .8976 Mdot
.016 w
.31528 .8976 m
.31211 .89616 L
s
.008 w
.31211 .89616 Mdot
.016 w
.31211 .89616 m
.30894 .89494 L
s
.008 w
.30894 .89494 Mdot
.016 w
.30894 .89494 m
.30619 .89375 L
s
.008 w
.30619 .89375 Mdot
.016 w
.30619 .89375 m
.30349 .89263 L
s
.008 w
.30349 .89263 Mdot
.016 w
.30349 .89263 m
.30092 .89161 L
s
1 .055 0 r
.008 w
.30092 .89161 Mdot
.016 w
.30092 .89161 m
.29883 .8907 L
s
.008 w
.29883 .8907 Mdot
.016 w
.29883 .8907 m
.29682 .88987 L
s
.008 w
.29682 .88987 Mdot
.016 w
.29682 .88987 m
.29506 .88913 L
s
.008 w
.29506 .88913 Mdot
.016 w
.29506 .88913 m
.29356 .88852 L
s
.008 w
.29356 .88852 Mdot
.016 w
.29356 .88852 m
.29237 .888 L
s
.008 w
.29237 .888 Mdot
.016 w
.29237 .888 m
.29143 .88758 L
s
1 .054 0 r
.008 w
.29143 .88758 Mdot
.016 w
.29143 .88758 m
.29074 .88721 L
s
.008 w
.29074 .88721 Mdot
.016 w
.29074 .88721 m
.29027 .88689 L
s
.008 w
.29027 .88689 Mdot
.016 w
.29027 .88689 m
.28999 .88663 L
s
.008 w
.28999 .88663 Mdot
.016 w
.28999 .88663 m
.28987 .88647 L
s
.008 w
.28987 .88647 Mdot
.016 w
.28987 .88647 m
.2899 .88639 L
s
1 .053 0 r
.008 w
.2899 .88639 Mdot
.016 w
.2899 .88639 m
.29002 .88639 L
s
.008 w
.29002 .88639 Mdot
.016 w
.29002 .88639 m
.29019 .88644 L
s
.008 w
.29019 .88644 Mdot
.016 w
.29019 .88644 m
.29034 .88652 L
s
.008 w
.29034 .88652 Mdot
.016 w
.29034 .88652 m
.29046 .8866 L
s
.008 w
.29046 .8866 Mdot
.016 w
.29046 .8866 m
.29058 .88669 L
s
1 .052 0 r
.008 w
.29058 .88669 Mdot
.016 w
.29058 .88669 m
.29073 .88681 L
s
.008 w
.29073 .88681 Mdot
.016 w
.29073 .88681 m
.29091 .88697 L
s
.008 w
.29091 .88697 Mdot
.016 w
.29091 .88697 m
.29109 .88714 L
s
.008 w
.29109 .88714 Mdot
.016 w
.29109 .88714 m
.29123 .88729 L
s
.008 w
.29123 .88729 Mdot
.016 w
.29123 .88729 m
.29132 .88741 L
s
1 .051 0 r
.008 w
.29132 .88741 Mdot
.016 w
.29132 .88741 m
.29127 .88742 L
s
.008 w
.29127 .88742 Mdot
.016 w
.29127 .88742 m
.29101 .88726 L
s
.008 w
.29101 .88726 Mdot
.016 w
.29101 .88726 m
.29051 .8869 L
s
.008 w
.29051 .8869 Mdot
.016 w
.29051 .8869 m
.28972 .88626 L
s
.008 w
.28972 .88626 Mdot
.016 w
.28972 .88626 m
.2886 .88531 L
s
.008 w
.2886 .88531 Mdot
.016 w
.2886 .88531 m
.28714 .88399 L
s
1 .05 0 r
.008 w
.28714 .88399 Mdot
.016 w
.28714 .88399 m
.28531 .88228 L
s
.008 w
.28531 .88228 Mdot
.016 w
.28531 .88228 m
.28345 .8805 L
s
.008 w
.28345 .8805 Mdot
.016 w
.28345 .8805 m
.28108 .87821 L
s
.008 w
.28108 .87821 Mdot
.016 w
.28108 .87821 m
.27864 .87588 L
s
.008 w
.27864 .87588 Mdot
.016 w
.27864 .87588 m
.27583 .87304 L
s
1 .049 0 r
.008 w
.27583 .87304 Mdot
.016 w
.27583 .87304 m
.27283 .87 L
s
.008 w
.27283 .87 Mdot
.016 w
.27283 .87 m
.26987 .867 L
s
.008 w
.26987 .867 Mdot
.016 w
.26987 .867 m
.26695 .86393 L
s
.008 w
.26695 .86393 Mdot
.016 w
.26695 .86393 m
.26393 .86067 L
s
.008 w
.26393 .86067 Mdot
.016 w
.26393 .86067 m
.26094 .85737 L
s
1 .048 0 r
.008 w
.26094 .85737 Mdot
.016 w
.26094 .85737 m
.25809 .85428 L
s
.008 w
.25809 .85428 Mdot
.016 w
.25809 .85428 m
.25532 .85122 L
s
.008 w
.25532 .85122 Mdot
.016 w
.25532 .85122 m
.25267 .84839 L
s
.008 w
.25267 .84839 Mdot
.016 w
.25267 .84839 m
.25006 .84557 L
s
.008 w
.25006 .84557 Mdot
.016 w
.25006 .84557 m
.24743 .843 L
s
1 .047 0 r
.008 w
.24743 .843 Mdot
.016 w
.24743 .843 m
.24484 .84045 L
s
.008 w
.24484 .84045 Mdot
.016 w
.24484 .84045 m
.24214 .83796 L
s
.008 w
.24214 .83796 Mdot
.016 w
.24214 .83796 m
.23956 .83537 L
s
.008 w
.23956 .83537 Mdot
.016 w
.23956 .83537 m
.23682 .83311 L
s
.008 w
.23682 .83311 Mdot
.016 w
.23682 .83311 m
.23421 .83075 L
s
.008 w
.23421 .83075 Mdot
.016 w
.23421 .83075 m
.23154 .8284 L
s
1 .046 0 r
.008 w
.23154 .8284 Mdot
.016 w
.23154 .8284 m
.22896 .82596 L
s
.008 w
.22896 .82596 Mdot
.016 w
.22896 .82596 m
.2264 .82381 L
s
.008 w
.2264 .82381 Mdot
.016 w
.2264 .82381 m
.22388 .82154 L
s
.008 w
.22388 .82154 Mdot
.016 w
.22388 .82154 m
.22126 .81925 L
s
.008 w
.22126 .81925 Mdot
.016 w
.22126 .81925 m
.21889 .81687 L
s
1 .045 0 r
.008 w
.21889 .81687 Mdot
.016 w
.21889 .81687 m
.21644 .81451 L
s
.008 w
.21644 .81451 Mdot
.016 w
.21644 .81451 m
.21401 .81197 L
s
.008 w
.21401 .81197 Mdot
.016 w
.21401 .81197 m
.21164 .80965 L
s
.008 w
.21164 .80965 Mdot
.016 w
.21164 .80965 m
.20928 .8071 L
s
.008 w
.20928 .8071 Mdot
.016 w
.20928 .8071 m
.20715 .80455 L
s
1 .044 0 r
.008 w
.20715 .80455 Mdot
.016 w
.20715 .80455 m
.20501 .80182 L
s
.008 w
.20501 .80182 Mdot
.016 w
.20501 .80182 m
.20301 .79943 L
s
.008 w
.20301 .79943 Mdot
.016 w
.20301 .79943 m
.201 .79686 L
s
.008 w
.201 .79686 Mdot
.016 w
.201 .79686 m
.19903 .79417 L
s
.008 w
.19903 .79417 Mdot
.016 w
.19903 .79417 m
.19708 .7914 L
s
1 .043 0 r
.008 w
.19708 .7914 Mdot
.016 w
.19708 .7914 m
.19516 .78857 L
s
.008 w
.19516 .78857 Mdot
.016 w
.19516 .78857 m
.1932 .78552 L
s
.008 w
.1932 .78552 Mdot
.016 w
.1932 .78552 m
.19134 .78293 L
s
.008 w
.19134 .78293 Mdot
.016 w
.19134 .78293 m
.18955 .78 L
s
.008 w
.18955 .78 Mdot
.016 w
.18955 .78 m
.18784 .77723 L
s
.008 w
.18784 .77723 Mdot
.016 w
.18784 .77723 m
.18632 .77441 L
s
1 .042 0 r
.008 w
.18632 .77441 Mdot
.016 w
.18632 .77441 m
.18494 .77163 L
s
.008 w
.18494 .77163 Mdot
.016 w
.18494 .77163 m
.18374 .76908 L
s
.008 w
.18374 .76908 Mdot
.016 w
.18374 .76908 m
.18267 .76658 L
s
.008 w
.18267 .76658 Mdot
.016 w
.18267 .76658 m
.18182 .76425 L
s
.008 w
.18182 .76425 Mdot
.016 w
.18182 .76425 m
.18114 .76227 L
s
1 .041 0 r
.008 w
.18114 .76227 Mdot
.016 w
.18114 .76227 m
.18065 .76052 L
s
.008 w
.18065 .76052 Mdot
.016 w
.18065 .76052 m
.18034 .75902 L
s
.008 w
.18034 .75902 Mdot
.016 w
.18034 .75902 m
.18021 .75778 L
s
.008 w
.18021 .75778 Mdot
.016 w
.18021 .75778 m
.18021 .75667 L
s
.008 w
.18021 .75667 Mdot
.016 w
.18021 .75667 m
.18025 .75567 L
s
1 .04 0 r
.008 w
.18025 .75567 Mdot
.016 w
.18025 .75567 m
.18026 .75467 L
s
.008 w
.18026 .75467 Mdot
.016 w
.18026 .75467 m
.18018 .7536 L
s
.008 w
.18018 .7536 Mdot
.016 w
.18018 .7536 m
.17993 .7524 L
s
.008 w
.17993 .7524 Mdot
.016 w
.17993 .7524 m
.17945 .75102 L
s
.008 w
.17945 .75102 Mdot
.016 w
.17945 .75102 m
.17874 .74947 L
s
.008 w
.17874 .74947 Mdot
.016 w
.17874 .74947 m
.1778 .74757 L
s
1 .039 0 r
.008 w
.1778 .74757 Mdot
.016 w
.1778 .74757 m
.17662 .74528 L
s
.008 w
.17662 .74528 Mdot
.016 w
.17662 .74528 m
.17529 .74286 L
s
.008 w
.17529 .74286 Mdot
.016 w
.17529 .74286 m
.17367 .7399 L
s
.008 w
.17367 .7399 Mdot
.016 w
.17367 .7399 m
.17184 .73647 L
s
.008 w
.17184 .73647 Mdot
.016 w
.17184 .73647 m
.17003 .7331 L
s
1 .038 0 r
.008 w
.17003 .7331 Mdot
.016 w
.17003 .7331 m
.16797 .72925 L
s
.008 w
.16797 .72925 Mdot
.016 w
.16797 .72925 m
.16588 .72527 L
s
.008 w
.16588 .72527 Mdot
.016 w
.16588 .72527 m
.16368 .72103 L
s
.008 w
.16368 .72103 Mdot
.016 w
.16368 .72103 m
.16136 .717 L
s
.008 w
.16136 .717 Mdot
.016 w
.16136 .717 m
.15918 .71291 L
s
1 .037 0 r
.008 w
.15918 .71291 Mdot
.016 w
.15918 .71291 m
.15702 .70879 L
s
.008 w
.15702 .70879 Mdot
.016 w
.15702 .70879 m
.1551 .70497 L
s
.008 w
.1551 .70497 Mdot
.016 w
.1551 .70497 m
.15322 .70128 L
s
.008 w
.15322 .70128 Mdot
.016 w
.15322 .70128 m
.15151 .69762 L
s
.008 w
.15151 .69762 Mdot
.016 w
.15151 .69762 m
.15008 .69447 L
s
1 .036 0 r
.008 w
.15008 .69447 Mdot
.016 w
.15008 .69447 m
.14885 .69128 L
s
.008 w
.14885 .69128 Mdot
.016 w
.14885 .69128 m
.1479 .68835 L
s
.008 w
.1479 .68835 Mdot
.016 w
.1479 .68835 m
.14725 .68583 L
s
.008 w
.14725 .68583 Mdot
.016 w
.14725 .68583 m
.14689 .68342 L
s
.008 w
.14689 .68342 Mdot
.016 w
.14689 .68342 m
.14677 .68126 L
s
.008 w
.14677 .68126 Mdot
.016 w
.14677 .68126 m
.14685 .6793 L
s
1 .035 0 r
.008 w
.14685 .6793 Mdot
.016 w
.14685 .6793 m
.1471 .67767 L
s
.008 w
.1471 .67767 Mdot
.016 w
.1471 .67767 m
.14747 .67624 L
s
.008 w
.14747 .67624 Mdot
.016 w
.14747 .67624 m
.14789 .67503 L
s
.008 w
.14789 .67503 Mdot
.016 w
.14789 .67503 m
.14833 .67404 L
s
.008 w
.14833 .67404 Mdot
.016 w
.14833 .67404 m
.14876 .67325 L
s
1 .034 0 r
.008 w
.14876 .67325 Mdot
.016 w
.14876 .67325 m
.14916 .67261 L
s
.008 w
.14916 .67261 Mdot
.016 w
.14916 .67261 m
.14949 .67212 L
s
.008 w
.14949 .67212 Mdot
.016 w
.14949 .67212 m
.14975 .67176 L
s
.008 w
.14975 .67176 Mdot
.016 w
.14975 .67176 m
.14991 .67152 L
s
.008 w
.14991 .67152 Mdot
.016 w
.14991 .67152 m
.14999 .67139 L
s
1 .033 0 r
.008 w
.14999 .67139 Mdot
.016 w
.14999 .67139 m
.14999 .67136 L
s
.008 w
.14999 .67136 Mdot
.016 w
.14999 .67136 m
.14995 .67141 L
s
.008 w
.14995 .67141 Mdot
.016 w
.14995 .67141 m
.1499 .6715 L
s
.008 w
.1499 .6715 Mdot
.016 w
.1499 .6715 m
.14985 .6716 L
s
.008 w
.14985 .6716 Mdot
.016 w
.14985 .6716 m
.14981 .6717 L
s
1 .032 0 r
.008 w
.14981 .6717 Mdot
.016 w
.14981 .6717 m
.14979 .67176 L
s
.008 w
.14979 .67176 Mdot
.016 w
.14979 .67176 m
.14979 .67179 L
s
.008 w
.14979 .67179 Mdot
.016 w
.14979 .67179 m
.14979 .6718 L
s
.008 w
.14979 .6718 Mdot
.016 w
.14979 .6718 m
.14979 .6718 L
s
.008 w
.14979 .6718 Mdot
.016 w
.14979 .6718 m
.14979 .6718 L
s
.008 w
.14979 .6718 Mdot
.016 w
.14979 .6718 m
.14979 .6718 L
s
1 .031 0 r
.008 w
.14979 .6718 Mdot
.016 w
.14979 .6718 m
.1498 .6718 L
s
.008 w
.1498 .6718 Mdot
.016 w
.1498 .6718 m
.14988 .67182 L
s
.008 w
.14988 .67182 Mdot
.016 w
.14988 .67182 m
.15004 .67188 L
s
.008 w
.15004 .67188 Mdot
.016 w
.15004 .67188 m
.15021 .67201 L
s
.008 w
.15021 .67201 Mdot
.016 w
.15021 .67201 m
.15037 .67218 L
s
1 .03 0 r
.008 w
.15037 .67218 Mdot
.016 w
.15037 .67218 m
.15048 .67237 L
s
.008 w
.15048 .67237 Mdot
.016 w
.15048 .67237 m
.15048 .67256 L
s
.008 w
.15048 .67256 Mdot
.016 w
.15048 .67256 m
.15026 .67271 L
s
.008 w
.15026 .67271 Mdot
.016 w
.15026 .67271 m
.14978 .67273 L
s
.008 w
.14978 .67273 Mdot
.016 w
.14978 .67273 m
.14903 .67255 L
s
1 .029 0 r
.008 w
.14903 .67255 Mdot
.016 w
.14903 .67255 m
.14798 .67209 L
s
.008 w
.14798 .67209 Mdot
.016 w
.14798 .67209 m
.14659 .67131 L
s
.008 w
.14659 .67131 Mdot
.016 w
.14659 .67131 m
.14488 .67017 L
s
.008 w
.14488 .67017 Mdot
.016 w
.14488 .67017 m
.14304 .66866 L
s
.008 w
.14304 .66866 Mdot
.016 w
.14304 .66866 m
.14157 .66684 L
s
1 .028 0 r
.008 w
.14157 .66684 Mdot
.016 w
.14157 .66684 m
.13953 .6647 L
s
.008 w
.13953 .6647 Mdot
.016 w
.13953 .6647 m
.13719 .66202 L
s
.008 w
.13719 .66202 Mdot
.016 w
.13719 .66202 m
.13529 .659 L
s
.008 w
.13529 .659 Mdot
.016 w
.13529 .659 m
.13287 .65548 L
s
.008 w
.13287 .65548 Mdot
.016 w
.13287 .65548 m
.13095 .65153 L
s
.008 w
.13095 .65153 Mdot
.016 w
.13095 .65153 m
.12905 .64724 L
s
1 .027 0 r
.008 w
.12905 .64724 Mdot
.016 w
.12905 .64724 m
.12721 .64307 L
s
.008 w
.12721 .64307 Mdot
.016 w
.12721 .64307 m
.12557 .63775 L
s
.008 w
.12557 .63775 Mdot
.016 w
.12557 .63775 m
.1243 .63313 L
s
.008 w
.1243 .63313 Mdot
.016 w
.1243 .63313 m
.12313 .62763 L
s
.008 w
.12313 .62763 Mdot
.016 w
.12313 .62763 m
.12214 .62247 L
s
1 .026 0 r
.008 w
.12214 .62247 Mdot
.016 w
.12214 .62247 m
.12122 .61662 L
s
.008 w
.12122 .61662 Mdot
.016 w
.12122 .61662 m
.12036 .6112 L
s
.008 w
.12036 .6112 Mdot
.016 w
.12036 .6112 m
.11957 .60574 L
s
.008 w
.11957 .60574 Mdot
.016 w
.11957 .60574 m
.11881 .60024 L
s
.008 w
.11881 .60024 Mdot
.016 w
.11881 .60024 m
.11811 .59464 L
s
1 .025 0 r
.008 w
.11811 .59464 Mdot
.016 w
.11811 .59464 m
.11747 .58858 L
s
.008 w
.11747 .58858 Mdot
.016 w
.11747 .58858 m
.11691 .58351 L
s
.008 w
.11691 .58351 Mdot
.016 w
.11691 .58351 m
.11641 .57745 L
s
.008 w
.11641 .57745 Mdot
.016 w
.11641 .57745 m
.11593 .57249 L
s
.008 w
.11593 .57249 Mdot
.016 w
.11593 .57249 m
.11546 .56729 L
s
.008 w
.11546 .56729 Mdot
.016 w
.11546 .56729 m
.11496 .56211 L
s
1 .024 0 r
.008 w
.11496 .56211 Mdot
.016 w
.11496 .56211 m
.11445 .55706 L
s
.008 w
.11445 .55706 Mdot
.016 w
.11445 .55706 m
.11393 .55237 L
s
.008 w
.11393 .55237 Mdot
.016 w
.11393 .55237 m
.11339 .54732 L
s
.008 w
.11339 .54732 Mdot
.016 w
.11339 .54732 m
.11286 .54335 L
s
.008 w
.11286 .54335 Mdot
.016 w
.11286 .54335 m
.11236 .53917 L
s
1 .023 0 r
.008 w
.11236 .53917 Mdot
.016 w
.11236 .53917 m
.11187 .53549 L
s
.008 w
.11187 .53549 Mdot
.016 w
.11187 .53549 m
.11141 .5325 L
s
.008 w
.11141 .5325 Mdot
.016 w
.11141 .5325 m
.11099 .5297 L
s
.008 w
.11099 .5297 Mdot
.016 w
.11099 .5297 m
.11062 .52736 L
s
.008 w
.11062 .52736 Mdot
.016 w
.11062 .52736 m
.11031 .52569 L
s
1 .022 0 r
.008 w
.11031 .52569 Mdot
.016 w
.11031 .52569 m
.11006 .52454 L
s
.008 w
.11006 .52454 Mdot
.016 w
.11006 .52454 m
.10989 .52381 L
s
.008 w
.10989 .52381 Mdot
.016 w
.10989 .52381 m
.10978 .52339 L
s
.008 w
.10978 .52339 Mdot
.016 w
.10978 .52339 m
.10971 .52316 L
s
.008 w
.10971 .52316 Mdot
.016 w
.10971 .52316 m
.10969 .52299 L
s
1 .021 0 r
.008 w
.10969 .52299 Mdot
.016 w
.10969 .52299 m
.10971 .52281 L
s
.008 w
.10971 .52281 Mdot
.016 w
.10971 .52281 m
.10977 .52253 L
s
.008 w
.10977 .52253 Mdot
.016 w
.10977 .52253 m
.10987 .52214 L
s
.008 w
.10987 .52214 Mdot
.016 w
.10987 .52214 m
.11 .52163 L
s
.008 w
.11 .52163 Mdot
.016 w
.11 .52163 m
.11017 .52103 L
s
.008 w
.11017 .52103 Mdot
.016 w
.11017 .52103 m
.11036 .52041 L
s
1 .02 0 r
.008 w
.11036 .52041 Mdot
.016 w
.11036 .52041 m
.11057 .51972 L
s
.008 w
.11057 .51972 Mdot
.016 w
.11057 .51972 m
.11081 .51899 L
s
.008 w
.11081 .51899 Mdot
.016 w
.11081 .51899 m
.11106 .51831 L
s
.008 w
.11106 .51831 Mdot
.016 w
.11106 .51831 m
.11131 .5177 L
s
.008 w
.11131 .5177 Mdot
.016 w
.11131 .5177 m
.11155 .51718 L
s
1 .019 0 r
.008 w
.11155 .51718 Mdot
.016 w
.11155 .51718 m
.11179 .51678 L
s
.008 w
.11179 .51678 Mdot
.016 w
.11179 .51678 m
.11202 .5165 L
s
.008 w
.11202 .5165 Mdot
.016 w
.11202 .5165 m
.11223 .51636 L
s
.008 w
.11223 .51636 Mdot
.016 w
.11223 .51636 m
.11242 .51633 L
s
.008 w
.11242 .51633 Mdot
.016 w
.11242 .51633 m
.11257 .51638 L
s
1 .018 0 r
.008 w
.11257 .51638 Mdot
.016 w
.11257 .51638 m
.11269 .51646 L
s
.008 w
.11269 .51646 Mdot
.016 w
.11269 .51646 m
.11276 .51655 L
s
.008 w
.11276 .51655 Mdot
.016 w
.11276 .51655 m
.11279 .51662 L
s
.008 w
.11279 .51662 Mdot
.016 w
.11279 .51662 m
.11277 .51666 L
s
.008 w
.11277 .51666 Mdot
.016 w
.11277 .51666 m
.11273 .51667 L
s
1 .017 0 r
.008 w
.11273 .51667 Mdot
.016 w
.11273 .51667 m
.11269 .51668 L
s
.008 w
.11269 .51668 Mdot
.016 w
.11269 .51668 m
.11266 .51668 L
s
.008 w
.11266 .51668 Mdot
.016 w
.11266 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
1 .016 0 r
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
1 .015 0 r
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
1 .014 0 r
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
1 .013 0 r
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11264 .51668 L
s
.008 w
.11264 .51668 Mdot
.016 w
.11264 .51668 m
.11262 .51668 L
s
.008 w
.11262 .51668 Mdot
.016 w
.11262 .51668 m
.11259 .51668 L
s
1 .012 0 r
.008 w
.11259 .51668 Mdot
.016 w
.11259 .51668 m
.11255 .51668 L
s
.008 w
.11255 .51668 Mdot
.016 w
.11255 .51668 m
.11251 .51668 L
s
.008 w
.11251 .51668 Mdot
.016 w
.11251 .51668 m
.11249 .51668 L
s
.008 w
.11249 .51668 Mdot
.016 w
.11249 .51668 m
.11251 .51668 L
s
.008 w
.11251 .51668 Mdot
.016 w
.11251 .51668 m
.11256 .51668 L
s
1 .011 0 r
.008 w
.11256 .51668 Mdot
.016 w
.11256 .51668 m
.11266 .51668 L
s
.008 w
.11266 .51668 Mdot
.016 w
.11266 .51668 m
.11281 .51667 L
s
.008 w
.11281 .51667 Mdot
.016 w
.11281 .51667 m
.113 .51667 L
s
.008 w
.113 .51667 Mdot
.016 w
.113 .51667 m
.11323 .51666 L
s
.008 w
.11323 .51666 Mdot
.016 w
.11323 .51666 m
.11347 .51666 L
s
1 .01 0 r
.008 w
.11347 .51666 Mdot
.016 w
.11347 .51666 m
.11374 .51665 L
s
.008 w
.11374 .51665 Mdot
.016 w
.11374 .51665 m
.114 .51664 L
s
.008 w
.114 .51664 Mdot
.016 w
.114 .51664 m
.11426 .51664 L
s
.008 w
.11426 .51664 Mdot
.016 w
.11426 .51664 m
.11451 .51663 L
s
.008 w
.11451 .51663 Mdot
.016 w
.11451 .51663 m
.11475 .51662 L
s
1 .009 0 r
.008 w
.11475 .51662 Mdot
.016 w
.11475 .51662 m
.11495 .51662 L
s
.008 w
.11495 .51662 Mdot
.016 w
.11495 .51662 m
.11511 .51661 L
s
.008 w
.11511 .51661 Mdot
.016 w
.11511 .51661 m
.11522 .51661 L
s
.008 w
.11522 .51661 Mdot
.016 w
.11522 .51661 m
.11529 .51661 L
s
.008 w
.11529 .51661 Mdot
.016 w
.11529 .51661 m
.11531 .51661 L
s
.008 w
.11531 .51661 Mdot
.016 w
.11531 .51661 m
.11531 .51664 L
s
1 .008 0 r
.008 w
.11531 .51664 Mdot
.016 w
.11531 .51664 m
.11529 .51669 L
s
.008 w
.11529 .51669 Mdot
.016 w
.11529 .51669 m
.11529 .51677 L
s
.008 w
.11529 .51677 Mdot
.016 w
.11529 .51677 m
.11529 .51684 L
s
.008 w
.11529 .51684 Mdot
.016 w
.11529 .51684 m
.11528 .51687 L
s
.008 w
.11528 .51687 Mdot
.016 w
.11528 .51687 m
.11523 .51685 L
s
1 .007 0 r
.008 w
.11523 .51685 Mdot
.016 w
.11523 .51685 m
.11514 .51675 L
s
.008 w
.11514 .51675 Mdot
.016 w
.11514 .51675 m
.11502 .51657 L
s
.008 w
.11502 .51657 Mdot
.016 w
.11502 .51657 m
.11487 .51629 L
s
.008 w
.11487 .51629 Mdot
.016 w
.11487 .51629 m
.11471 .51594 L
s
.008 w
.11471 .51594 Mdot
.016 w
.11471 .51594 m
.11456 .51553 L
s
1 .006 0 r
.008 w
.11456 .51553 Mdot
.016 w
.11456 .51553 m
.11445 .51507 L
s
.008 w
.11445 .51507 Mdot
.016 w
.11445 .51507 m
.11436 .51458 L
s
.008 w
.11436 .51458 Mdot
.016 w
.11436 .51458 m
.11442 .5141 L
s
.008 w
.11442 .5141 Mdot
.016 w
.11442 .5141 m
.11442 .51361 L
s
.008 w
.11442 .51361 Mdot
.016 w
.11442 .51361 m
.11443 .51314 L
s
.008 w
.11443 .51314 Mdot
.016 w
.11443 .51314 m
.11446 .51273 L
s
1 .005 0 r
.008 w
.11446 .51273 Mdot
.016 w
.11446 .51273 m
.11451 .51241 L
s
.008 w
.11451 .51241 Mdot
.016 w
.11451 .51241 m
.11459 .51224 L
s
.008 w
.11459 .51224 Mdot
.016 w
.11459 .51224 m
.11471 .51221 L
s
.008 w
.11471 .51221 Mdot
.016 w
.11471 .51221 m
.11485 .5123 L
s
.008 w
.11485 .5123 Mdot
.016 w
.11485 .5123 m
.11499 .51245 L
s
1 .004 0 r
.008 w
.11499 .51245 Mdot
.016 w
.11499 .51245 m
.11511 .5126 L
s
.008 w
.11511 .5126 Mdot
.016 w
.11511 .5126 m
.1152 .51267 L
s
.008 w
.1152 .51267 Mdot
.016 w
.1152 .51267 m
.11526 .51252 L
s
.008 w
.11526 .51252 Mdot
.016 w
.11526 .51252 m
.1153 .51204 L
s
.008 w
.1153 .51204 Mdot
.016 w
.1153 .51204 m
.11532 .51116 L
s
1 .003 0 r
.008 w
.11532 .51116 Mdot
.016 w
.11532 .51116 m
.11536 .50984 L
s
.008 w
.11536 .50984 Mdot
.016 w
.11536 .50984 m
.11544 .50801 L
s
.008 w
.11544 .50801 Mdot
.016 w
.11544 .50801 m
.11561 .50584 L
s
.008 w
.11561 .50584 Mdot
.016 w
.11561 .50584 m
.11588 .50291 L
s
.008 w
.11588 .50291 Mdot
.016 w
.11588 .50291 m
.11623 .49993 L
s
1 .002 0 r
.008 w
.11623 .49993 Mdot
.016 w
.11623 .49993 m
.11666 .49641 L
s
.008 w
.11666 .49641 Mdot
.016 w
.11666 .49641 m
.11716 .49251 L
s
.008 w
.11716 .49251 Mdot
.016 w
.11716 .49251 m
.1177 .48875 L
s
.008 w
.1177 .48875 Mdot
.016 w
.1177 .48875 m
.11827 .48469 L
s
.008 w
.11827 .48469 Mdot
.016 w
.11827 .48469 m
.11887 .4809 L
s
.008 w
.11887 .4809 Mdot
.016 w
.11887 .4809 m
.11946 .47765 L
s
1 .001 0 r
.008 w
.11946 .47765 Mdot
.016 w
.11946 .47765 m
.12002 .47446 L
s
.008 w
.12002 .47446 Mdot
.016 w
.12002 .47446 m
.12054 .47173 L
s
.008 w
.12054 .47173 Mdot
.016 w
.12054 .47173 m
.12098 .46937 L
s
.008 w
.12098 .46937 Mdot
.016 w
.12098 .46937 m
.12135 .46771 L
s
.008 w
.12135 .46771 Mdot
.016 w
.12135 .46771 m
.12164 .46646 L
s
1 0 0 r
.008 w
.12164 .46646 Mdot
.016 w
.12164 .46646 m
.12185 .46574 L
s
.008 w
.12185 .46574 Mdot
.016 w
.12185 .46574 m
.12199 .4654 L
s
0 g
.5 Mabswid
newpath
matrix currentmatrix
0.0131274 0.0135877 scale
9.13278 43.691 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0195177 0.0202019 scale
6.89068 34.411 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0124173 0.0128527 scale
13.1824 57.4161 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00737698 0.00763562 scale
120.113 96.6732 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0153564 0.0158948 scale
57.1377 38.6132 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00796805 0.00824741 scale
95.2165 77.063 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011664 0.012073 scale
77.3935 25.3127 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0138011 0.0142849 scale
63.6762 18.4915 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0188077 0.0194671 scale
46.2332 13.8321 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0150582 0.0155861 scale
50.5884 6.93372 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00952364 0.00985754 scale
52.1439 3.41566 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120466 0.0124689 scale
40.795 3.38041 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0370077 0.0383051 scale
10.4322 7.96708 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0250166 0.0258936 scale
12.999 10.2693 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104326 0.0107984 scale
20.3745 17.6369 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00796805 0.00824741 scale
29.3936 20.9848 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120466 0.0124689 scale
24.5639 10.632 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.018565 0.0192159 scale
5.91974 26.6451 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0879069 0.0909889 scale
1.27089 5.94226 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0318722 0.0329896 scale
4.44337 22.0415 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00737698 0.00763562 scale
73.0163 124.748 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104326 0.0107984 scale
71.1901 82.1094 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0197486 0.020441 scale
43.7696 38.6125 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0167681 0.017356 scale
51.7542 43.3044 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00796805 0.00824741 scale
117.33 65.3975 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0120466 0.0124689 scale
65.0767 9.65521 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00796805 0.00824741 scale
16.0755 79.7863 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011664 0.012073 scale
11.9324 59.2041 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104326 0.0107984 scale
15.9011 69.3825 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0240931 0.0249378 scale
7.90931 31.2096 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0108586 0.0112393 scale
18.6828 71.4002 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0197486 0.020441 scale
25.8438 46.7564 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0131274 0.0135877 scale
42.4988 67.428 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0159361 0.0164948 scale
55.068 45.8835 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.00796805 0.00824741 scale
109.058 94.0998 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0173006 0.0179071 scale
23.3958 51.9486 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0104326 0.0107984 scale
27.7888 82.0955 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.011664 0.012073 scale
12.8609 55.63 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0291989 0.0302227 scale
3.76418 17.3224 1 0 365.73 arc
setmatrix s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0028Ool2O@000goo0000000C
0020Ool007aoo`Tmk`Mm0005001o07l0O`000006Ool2?Nl7Ool500000gd0001o001hOol007=ooaUm
00<0009m0003001m07d001=m009o0003?Nmm87dP0080079oo`00L7oo00<mkgd0O@005gd00P000gd0
00<007d000005Wd01gdP0`00KWoo001^Ool2?NlJO@000`00O@000003O@02000GO@07OB000gl0OB00
0003001ZOol006eooa]m0004?Nl007d0O@05000GO@0;OB000gl0OB1oo`03001WOol006]oo`03?Nmm
07d000Um01<mk`03001o07l000=o0003000mkcg_014mk`03OB1m07d000mm8003Oomm87oo00<006Ao
o`00JGoo37d05Cg_0P000gl000<003g_?Nl06Cg_3WdP0goo0`00HGoo001VOol00cg_Oomm000:O@0H
?Nl00gl0000000020005?Nl5OolC?Nl?OB03Ool3001NOol006Eoo`8mk`Qm01Dmk`Moo`Io00Yoo`<m
k`Aoo`hmk`mm80=oo`8005aoo`00I7oo2gd000<mkgoo?Nl013g_1goo13g_2goo1Wl04Goo3cg_00=o
07dPOB0037dP0goo0P00FWoo001ROol00`00O@1m0006O@04?NlMOol6O`0COol@?Nl2O`0;OB04Ool2
001HOol0061oo`03001m07d000Qm0003?Nmoogoo01moo`Io01eoo`Pmk`im809oo`8005Ioo`00GWoo
0P002Wd000<mkgooOol087oo1Gl097oo0cg_0gl02gdP00=o07ooOol00`00Dgoo001LOol00`00O@1m
0009O@02?NlTOol5O`0UOol4?Nl>OB03Ool2001AOol005Yoo`8000Ym0003?Nmoogoo02Eoo`Io02Mo
o`Dmk`]m8004?NmoogooOol2001?Ool005Qoo`800003Oomm07d000Im00@mkbMoo`Io02Yoo`<mk`am
8004O`1oogooOol2001=Ool005Ioo`800003Oomm07d000Mm00DmkbQoo`Io02aoo`@mk`]m8004O`1o
ogoo001<Ool005Eoo`03001oocg_00Ym008mkb]oo`Io02aoo`@mk`9o00Ym8003O`1oogoo008004Yo
o`00E7oo00<007ooO@0027d013g_;Goo1Gl0<goo2WdP00=o03g_Ool01000Agoo001BOol200000cg_
O@1m0007O@04?Nl^Ool5O`0dOol:OB0017l0001o07oo1000AGoo001AOol00`00Oolmk`08O@06?Nl^
Ool5O`0eOol3?Nl7OB000`00O`1o0002?Nl00`00Ool00014Ool004moo`800003?Nmm07d000Mm00Lm
kbeoo`Io03Moo`8mk`Em8003001m87dP009o009o808004Aoo`00CGoo0P0000=oocg_O@001Wd02Cg_
;Woo1Gl0>Woo1GdP00<007dPOB000gl00WlP1000@Goo001<Ool00`00Oomm0009O@06?NlaOol5O`0m
Ool2OB000`00OB1m8005OB000`00OB1m80020010Ool004Yoo`800003?Nmm07d000Qm00Dmkc9oo`=o
0003O^1o07l003eoo`9m8003001m87dP00Em8005001m87dPOB000010Ool004Uoo`03001oocg_00Um
0003?Nl0000000@mkc9oo`Enh3moo`9m808000=m808000Em8003001oogoo03eoo`00B7oo00<003g_
?Nl02Gd000@mk`00?Nlmk`80008mkc9oo`Mnh3ioo`=m80<00003OB0007dP00Am8003000mk`0003eo
o`00Agoo00<003g_O@0027d00gj000H007j0OX1nP7oo000cOol8O^0mOol7?Nl00gdP001m8003OB00
1000OB0mk`00?7oo0015Ool200000cg_O@1m0005O@05OX000`00OX1nP002OX000goo001oo`0bOol9
O^0jOol:?Nl200000gdP00000003OB000goo001oo`0jOol004Aoo`03000mkcg_00Qm00EnP003001n
P7j0009nP003Ool007oo03Aoo`Qnh3Qoo`dmk`03001m87dP00Am8003Ool007oo03Uoo`00@goo00<0
03g_?Nl027d01gj000H007j0OX1nP7oo000fOol9O^0fOol8?Nl2Ool3?Nl7OB000cg_Ool0000iOol0
049oo`04001oocg_?Nl5O@0:OX0200000gj00000000jOol6O^0fOol5?Nl6Ool3?Nl00glPOB1m8004
OB000cg_001oo`0hOol0045oo`04001oocg_?Nl6O@0:OX02Ool00`00Oomoo`0kOol5O^0eOol6?Nl6
Ool4?Nl6OB000glPOol0000hOol0045oo`03000mkcg_00Im00UnP49oo`Enh3Eoo`Hmk`Moo`Dmk`Em
8004Ob1oo`00000fOol0041oo`03001oocg_00Mm00MnP4Eoo`Anh3Eoo`Hmk`Moo`Dmk`Im8004?Nmo
ogoo000eOol003ioo`800003Oolmkgd000Em00InP4Qoo`Anh3Ioo`Dmk`Moo`Hmk`Im80=oo`03001o
ogoo039oo`00?Goo00@007ooOomoo`Im00EnP4Yoo`Anh3Ioo`Hmk`Ioo`Dmk`03Oomo87dP00Am8005
?NmoogooOol0000cOol003aoo`04001oogooOol6O@04OX1<Ool4O^0gOol6?Nl6Ool6?Nl6OB001Cg_
Oomoogoo0000<Woo000kOol01@00Oomoogoo?Nl01Gd00`0000=nP3g_Ool0Bgoo17kP>7oo1Cg_1Woo
1Sg_1gdP00Eo87ooOomoo`00035oo`00>Woo00<007ooOol00Woo1Gd000InP000OX1nP000?Nm<Ool4
O^0hOol6?Nl5Ool5?Nl00goo?Nlmk`06OB04Ool00`00Oomoo`0^Ool003Uoo`03001oogoo009oo`03
?Nmm07d0009m0003OX0007j0009nP003001oogoo04]oo`Anh3Qoo`Lmk`Aoo`Tmk`Im80=oo`03001o
ogoo02ioo`00>7oo00<007ooOol00goo1Wd000D007j0OX1nP00004eoo`Anh3Yoo`Dmk`Aoo`Xmk`Im
80=oo`03001oogoo02eoo`00>7oo00<007ooOol00Woo00=nP7d000000P0000=m07j000001000CGoo
17kP>goo1Cg_1Goo2Cg_17dP00<mkgooOol00Woo00<007ooOol0;7oo000gOol00`00Oomoo`03Ool0
0gd0001m0002O@001@00OX1nP7j0?Nl0Cgoo17kP>goo1Cg_1Goo2Cg_1GdP00<mkgooOol00Woo00<0
07ooOol0:goo000fOol00`00Oomoo`03Ool2O@001P00O@1m07d0OX00009nP4moo`Inh3]oo`Dmk`Eo
o`Pmk`Im8003?Nmoogoo009oo`8002]oo`00=Goo00<007ooOol00goo0Wd000@007d0O@1m009nP003
001nP3g_04moo`Enh3aoo`Dmk`Eoo`Pmk`Mm80Ioo`03001oogoo02Qoo`00=7oo00<007ooOol017oo
0gd000<007d0O@000Wj000<007ooOol0Cgoo1GkP?Goo1Cg_0goo2cg_1WdP1Goo00<007ooOol0:7oo
000dOol00`00Oomoo`03Ool017j0O@1m07d00P0000=nP0000000DWoo17kP?Woo1Sg_0Woo2cg_00=o
87dPOB000gdP00<mkgooOol00goo00<007ooOol09goo000cOol00`00Oomoo`04Ool6O@000`00OX1n
X01BOol4O^0oOol5?Nl00goo?Nlmk`03?Nl00goo?Nlmk`04?Nl00glPOB1m8004OB05Ool00`00Oomo
o`0WOol0039oo`03001oogoo00Aoo`03OX1m07d000=m00EnX55oo`Anh41oo`Xmk`=oo`Dmk`Im8003
Ob1oogoo00=oo`03001oogoo02Ioo`00<Goo00<007ooOol017oo00<mkgd0O@0017d01WjPD7oo17kP
@7oo2Cg_1Woo1Cg_1WdP1Goo00<007ooOol09Goo000`Ool00`00Oomoo`05Ool6O@000cg_OomnX005
OZ1>Ool6O^10Ool8?Nl7Ool4?Nl6OB06Ool00`00Oomoo`0TOol0031oo`03001oogoo00Aoo`Im00<m
k`03OomnX7jP00EnX4]oo`Inh45oo`Pmk`Qoo`<mk`03Ob1m87dP00Am80Eoo`03001oogoo02Aoo`00
;goo00<007ooOol01Goo1Wd00cg_0Woo27jPB7oo1gkP@7oo23g_2Woo0cg_00=o87dPOB000gdP00<m
kgooOol00goo00<007ooOol08goo000^Ool00`00Oomoo`05Ool5O@0017iP?Nlmkcg_17oo27jPAGoo
2GkP?goo2Sg_2Woo0cg_00=o87dPOB000WdP00=o87ooOol017oo00<007ooOol08Woo000^Ool00`00
Oomoo`04Ool00cg_O@1m0003O@000gj0?Nlmk`06Ool9OZ12Ool9O^0nOol>?Nl8Ool3?Nl00glPOB1m
8004OB05Ool00`00Oomoo`0ROol002eoo`03001oogoo00Eoo`03OV1m07d0009m0003OV0mkcg_00Mo
o`]nX3ioo`Ynh3eooa4mk`Moo`@mk`Im8003?Nmoogoo00=oo`03001oogoo025oo`00;Goo00<007oo
Ool017oo00<mkgd0O@000gd00cg_2Goo2WjP?Goo27kP?Woo4cg_27oo0Sg_1gdP1Woo00<007ooOol0
87oo000/Ool00`00Oomoo`05Ool6O@000cg_Oomoo`0;Ool:OZ0=Ool3000[Ool7O^0mOol9?Nl6Ool8
?Nl8Ool00cg_Ob1m8004OB07Ool00`00Oomoo`0OOol002]oo`03001oogoo00Eoo`03?Nmm07d000=m
008mk`ioo`YnX0Uoo`<000=oo`03001oogoo02Qoo`Qnh3]oo`Pmk`Qoo`Tmk`Qoo`9o80Em80Ioo`03
001oogoo01moo`00:goo00<007ooOol01Goo1Wd00Sg_47oo27jP1goo0P001goo00<007ooOol0:Woo
1GkP>Goo23g_3Goo1cg_27oo00=o87dPOB0017dP1Woo00<007ooOol07Woo000ZOol00`00Oomoo`05
Ool6O@02?NlCOol8OZ05Ool00`00Oomoo`07Ool00`00Oomoo`0YOol6O^0gOol8?Nl?Ool8?Nl6Ool6
00000gdP?Nmoo`04Ool00`00Oomoo`0NOol002Uoo`03001oogoo00Eoo`03?Nmm07d000=m0003OV0m
kgoo01Aoo`UnX09oo`03001oogoo00Uoo`03001oogoo02Qoo`Mnh25oo`hmk`Eoo`Xmk`moo`Tmk`Ao
o`06001o87lPOB0007dP0`001Woo00<007ooOol07Goo000YOol00`00Oomoo`05Ool00giPO@1m0003
O@000cg_Oomoo`0EOol:OZ000`00Oomoo`0:Ool00`00Oomoo`0XOol7O^0KOolO?NlEOol8?Nl2Ool0
1000Oomo80000gdP00<007dP00001Goo00<007ooOol07Goo000XOol00`00Oomoo`05Ool00cg_O@1m
0003O@02?NlHOol8OZ001000OZ1oogoo1WjP17oo00<007ooOol0:Woo17kP67oo8Cg_67oo23g_00H0
03g_Oomo8000Ob03OB000`00?Nl00005Ool00`00Oomoo`0LOol002Qoo`03001oogoo00Eoo`Im008m
kaUoo`MnX003001nX7jP00MnX0Aoo`03001oogoo02Yoo`Anh1Aoob@mka]oo`Hmk`04000mkglP0002
Ob03OB000`00OB000006Ool00`00Oomoo`0KOol002Moo`03001oogoo00Eoo`Im00<mka]oo`EnX003
001nX7jP00UnX09oo`03001oogoo00=oo`P001moo`Anh15ooa8mk`Yoo`/mkaaoo`@mk`05000mkcg_
Ob000002Ob04OB020006Ool00`00Oomoo`0KOol002Moo`03001oogoo00Eoo`Im008mkaioo`AnX003
001nX7jP00UnX003Ool007oo009oo`8000Qoo`8001aoo`Inh0]ooa8mkaAoo`Dmkamoo`<mk`06000m
kglPOb0007lP17dP00<007dPOB001Woo00<007ooOol06Woo000WOol00`00Oomoo`04Ool00giPO@1m
0002O@0017iP?Nlmkcg_87oo0WjP00<007jPOZ002GjP00D007ooOomoo`0000aoo`03001oogoo01Uo
o`Enh0Uooa4mkcmoo`04000mkglPOb020002Ob000gdP00000002OB000cg_Oomoo`03Ool00`00Oomo
o`0JOol002Ioo`03001oogoo00Aoo`03?Nmm07d000=m0004OV0mkcg_?NlSOol00`00OZ1nX008OZ00
1@00OZ1oogoo00003Goo00<007ooOol067oo1GkP1Goo4Cg_A7oo00<007ooOb000WlP100017dP1Woo
00<007ooOol06Goo000UOol00`00Oomoo`05Ool00cg_O@1m0003O@03?NlTOol00`00Oomoo`03Ool4
OZ001@00OZ1nX7jP00003goo00<007ooOol05Woo1WkP4cg_Agoo00<007ooOol00goo0P001GdP00=o
@7ooOol00goo00<007ooOol06Goo000UOol00`00Oomoo`04Ool00cg_O@1m0004O@03?NlUOol00`00
Oomoo`04Ool00gjP00000003OZ000`00OZ1oo`0>Ool00`00Oomoo`0EOol5O^0A?Nm;Ool200001Goo
000007oo?Nl01WdP1Woo00<007ooOol067oo000TOol00`00Oomoo`05Ool6O@03?NlWOol20003Ool2
0004OZ000`00OZ1nX002OZ0=Ool00`00Oomoo`0COol2?Nl5O^0<?NmBOol01@00Oomoogoo?Nl01gdP
1Goo00<007ooOol067oo000TOol00`00Oomoo`04Ool00cg_O@1m0004O@02?NlZOol30004Ool2OZ00
0`00OZ1nX003OZ0<Ool00`00Oomoo`0>Ool6?Nl5O^09?NmLOol00gm0OB1m80030006Ool00`00Oomo
o`0GOol002=oo`03001oogoo00Eoo`Im0003?Nmoogoo035oo`03OZ0007jP00InX003O/1oogoo00Uo
o`03001oogoo00]oo`Pmk`Enh0@mkeioo`9o@004Oomo@0000003OB000`00Oomoo`03Ool00`00Oomo
o`0GOol002=oo`03001oogoo00Aoo`03?Nmm07d000=m008mkcAoo`03001nX7jP00InX0=n`0Qoo`03
001oogoo00Yoo`Pmk`Inh5eoo`9o@09oo`Eo@003001m87dP009m8003001oogoo00Aoo`03001oogoo
01Ioo`008goo00<007ooOol00goo00<mkgiPO@0017d000<mkgooOol0<goo00<007ooOZ001gjP0Wk0
00=nh7ooOol01Goo00<007ooOol02Woo13g_0WkP00<mkgkPO^001GkPFWoo2gm000<007m0OB0017dP
00<007ooOol00goo00<007ooOol05Woo000ROol00`00Oomoo`04Ool00cg_O@1m0004O@000cg_Oomo
o`0cOol00`00Oomoo`02Ool4OZ04O/02O^05Ool00`00Oomoo`09Ool3?Nl;O^1JOol<Od000`00Od1m
8004OB000`00Oomoo`04Ool00`00Oomoo`0EOol0029oo`03001oogoo00Aoo`03?Nmm07d000=m0003
?Nmoogoo03Aoo`03001oogoo009oo`03O/1nX7jP00En`0Enh09oo`03001oogoo00Ioo`9nh003?Nmn
h7kP00anh5Qoo`mo@003001o@7dP009m8003001m87oo00Eoo`03001oogoo01Eoo`008Goo00<007oo
Ool017oo00<mkgd0O@0017d000<mkgooOol0=7oo00<007ooOol017oo1Wk01gkP00<007ooOol01Goo
4WkPEWoo3gm00Woo0P000WdP0P0000=m87ooOol017oo00<007ooOol05Goo000QOol00`00Oomoo`03
Ool2?Nl5O@02?NlfOol00`00Oomoo`05Ool5O/06O^000`00O^1nh00EO^1HOol;Od08Ool00cg_0000
0003OB07Ool00`00Oomoo`0DOol0021oo`03001oogoo00=oo`8mk`Im03Uoo`03001oogoo00Moo`Qn
h003001nh7kP015nh5Yoo`Yo@0]oo`8mk`Am80Moo`03001oogoo01Aoo`0087oo00<007ooOol00Woo
0cg_1Gd000<mkgooOol0=goo00<007ooOol02Goo1GkP00<007kPO^003WkPG7oo2gm037oo0Sg_17dP
00<mkgooOol017oo00<007ooOol057oo000OOol00`00Oomoo`05Ool00cg_O@1m0003O@000cg_Oomo
o`0hOol00`00Oomoo`0<Ool00gkP001nh00;O^02?NmMOol:Od0?Ool00cg_OB1m8002OB000cg_Oomo
o`05Ool00`00Oomoo`0COol001moo`03001oogoo00Eoo`03OV1m07d0009m0003OV0mkgoo03Yoo`03
001oogoo00Yoo`8000Qoo`Hmkeeoo`Qo@19oo`03?Nmm87dP00=m80Moo`03001oogoo01=oo`007goo
00<007ooOol01Goo00=nH7d0O@000gd000<mkgooOol0>Woo0P0027oo0P002Goo1Sg_G7oo2Wm04goo
1WdP1goo00<007ooOol04Woo000OOol00`00Oomoo`05Ool00giPO@1m0002O@000cg_Oomoo`0mOol0
0`00Oomoo`03Ool2000;Ool5?NmLOol9Od0EOol5OB000cg_Oomoo`05Ool00`00Oomoo`0BOol001io
o`03001oogoo00Ioo`Em0003?Nmoogoo03ioo`D000aoo`Dmkeaoo`Mo@1Moo`8mk`Am8003?Nmoogoo
00Eoo`03001oogoo019oo`007Woo00<007ooOol01Goo00<mkgd0O@000gd000<mkgooOol0CWoo1Sg_
Fgoo1gm067oo0Sg_17dP2Goo00<007ooOol04Goo000NOol00`00Oomoo`05Ool00cg_O@1m0002O@00
0cg_Oomoo`1?Ool5?NmKOol8Od0HOol2?Nl4OB000cg_Oomoo`06Ool00`00Oomoo`0AOol001eoo`03
001oogoo00Ioo`03OV1m07d0009m0003?Nmoogoo04ioo`HmkeYoo`Io@1aoo`03?Nmm87dP009m8003
?Nmoogoo00Ioo`03001oogoo015oo`007Goo00<007ooOol01Woo1Wd0Cgoo1cg_FGoo1Wm07Woo17dP
00<mkgooOol01goo00<007ooOol047oo000MOol00`00Oomoo`06Ool5O@16Ool7?Nl00goo?Nlmk`05
?NmKOol5Od0OOol5OB09Ool00`00Oomoo`0@Ool001aoo`03001oogoo00Moo`Em04Aooa0mke]oo`Io
@1moo`Em80Uoo`03001oogoo011oo`0077oo00<007ooOol01goo17d000<mkgooOol0@7oo4Cg_G7oo
1Gm08Goo1GdP27oo00<007ooOol047oo000LOol00`00Oomoo`07Ool4O@02?NlmOolD?NmLOol6Od0Q
Ool4OB000cg_Oomoo`06Ool00`00Oomoo`0@Ool001aoo`03001oogoo00Moo`Am008mkcYoo`hmk`03
Oolmkcg_00Hmkeaoo`Ao@2=oo`Am8003?Nmoogoo00Moo`03001oogoo00moo`0077oo00<007ooOol0
1goo17d000<mkgooOol0<goo4Cg_1Woo1Cg_G7oo1Wm08Woo17dP00<mkgooOol01goo00<007ooOol0
3goo000KOol00`00Oomoo`08Ool4O@000cg_Oomoo`0cOol??NmXOol6Od0SOol4OB000ge0Oomoo`07
Ool00`00Oomoo`0?Ool001]oo`03001oogoo00Qoo`Am0003?Nmoogoo039oo`hmkfYoo`Io@2=oo`Em
@0Yoo`03001oogoo00ioo`006goo00<007ooOol027oo17d0=Goo2Cg_KWoo1Wm09Goo1Ge02Goo00<0
07ooOol03Woo000KOol00`00Oomoo`07Ool00giPO@1m0003O@0cOol6?NmbOol5Od0VOol4OD0:Ool0
0`00Oomoo`0>Ool001]oo`03001oogoo00Moo`03OV1m07d000Am039oo`Hmkg9oo`Eo@2Ioo`Am@0Yo
o`03001oogoo00ioo`006Woo00<007ooOol027oo00=nH7d0O@0017d0<Goo1Sg_LWoo1Wm09Woo17e0
2Woo00<007ooOol03Woo000JOol00`00Oomoo`08Ool2OV05O@0aOol6?NmbOol5Od0WOol4OD0;Ool0
0`00Oomoo`0=Ool001Yoo`03001oogoo00Qoo`9nH0Em035oo`Dmkg9oo`Io@2Moo`Am@0]oo`03001o
ogoo00eoo`006Woo00<007ooOol02Goo0WiP1Gd0;goo1Sg_LWoo1Gm0:7oo17e02goo00<007ooOol0
3Goo000JOol00`00Oomoo`09Ool00cg_OV1m0005O@04?NlZOol5?NmcOol5Od0XOol4OD000cg_Oomo
o`08Ool00`00Oomoo`0=Ool001Uoo`03001oogoo00aoo`Em00HmkbQoo`Dmkg=oo`Eo@2Uoo`Am@003
?Nmoogoo00Qoo`03001oogoo00eoo`006Goo00<007ooOol037oo00<mkgd0O@000Wd01cg_9goo1Cg_
Lgoo1Gm0:Goo1Ge02Woo00<007ooOol03Goo000IOol00`00Oomoo`0<Ool00cg_O@1m0002O@08?NlU
Ool5?NmcOol6Od0YOol5OD0;Ool00`00Oomoo`0<Ool001Uoo`03001oogoo00]oo`8mk`Am00PmkbEo
o`Dmkg=oo`Eo@2Yoo`03?Nmm@7e000=m@0Yoo`03001oogoo00aoo`006Goo00<007ooOol02Woo0cg_
1Gd000=oocg_?Nl01Cg_8goo1Cg_M7oo1Gm0:goo17e02goo00<007ooOol037oo000IOol00`00Oomo
o`0<Ool00cg_O@1m0002O@000cg_Oomoo`07?NlROol5?NmcOol6Od0ZOol00cg_OD1m@002OD000cg_
Oomoo`08Ool00`00Oomoo`0<Ool001Uoo`03001oogoo00aoo`Em0003?Nmoogoo009oo`Lmkb1oo`@m
kgAoo`Eo@2]oo`03?Nmm@7e0009m@003?Nmoogoo00Qoo`03001oogoo00aoo`006Goo00<007ooOol0
37oo1Gd000=nH3g_?Nl02cg_7Goo1Cg_M7oo1Gm0:goo00<mkge0OD000We000<mkgooOol027oo00<0
07ooOol037oo000HOol00`00Oomoo`05Ool;00000gd0OV0mk`0C?NlGOol5?NmdOol4Od0/Ool00cg_
OD1m@002OD000cg_Oomoo`08Ool00`00Oomoo`0<Ool001Qoo`04001oogooOol40006Ool2?Nl3O@02
000D?NlFOol5?NmeOol4Od0[Ool2?Nl4OD000cg_Oomoo`08Ool00`00Oomoo`0<Ool001Qoo`@000Qo
o`<mk`Im0080018mkaIoo`DmkgAoo`Eo@2]oo`03?NmoP7e000=m@003?Nmoogoo00Qoo`03001oogoo
00aoo`0067oo00<007ooOol027oo0Sg_17`00gd00cg_0P0043g_5Goo1Cg_MGoo1Gm0:goo0Wn017e0
00<mkgooOol027oo00<007ooOol037oo000GOol2000:Ool2?Nl4O003O@05?Nl2000>?NlEOol5?Nme
Ool5Od0[Ool2Oh04OD000cg_Oomoo`09Ool00`00Oomoo`0;Ool001Eoo`800003Ool007oo00Uoo`8m
k`Al009m0003OV1oocg_00Dmk`03000mkcg_00/mka=oo`HmkgIoo`Eo@2Yoo`=oP0Em@0]oo`03001o
ogoo00]oo`0057oo00D007ooOomoo`0000Yoo`03?Nmlh7`000=l009m009oo`Lmk`03000mkcg_00Xm
ka=oo`HmkgEoo`Eo@2Yoo`AoP0Em@003Oh1oogoo00Qoo`03001oogoo00]oo`0057oo00D007ooOomo
o`0000Yoo`03On1lh7`000=l0003O@1nH3g_009oo`Lmk`03000mkcg_00Tmka9oo`HmkgIoo`Eo@2Yo
o`EoP0Em@0Yoo`03001oogoo00]oo`004goo00<007ooOol00Woo00<007ooOol01goo00<mkgoPO000
1G`033g_00<003g_?Nl02Cg_3goo1cg_MWoo1Wm0:Goo1Wn017e02goo00<007ooOol02goo000BOol0
0`00Oomoo`03Ool00`00Oomoo`07Ool00cg_O>1l0004O0000giP?Nlmk`0;?Nl00`00?Nlmk`08?Nl<
Ool9?NmgOol5Od0YOol7Oh04OD0;Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Aoo`03001oogoo
00Moo`03On1lh7`000Al00lmk`03000mkcg_00Xmk`Aoo`hmkgIoo`Io@2Uoo`IoP003?Nmm@7e0009m
@0]oo`03001oogoo00]oo`004Goo00<007ooOol017oo00<007ooOol01goo00=oh7cPO0000g`00Woo
3Cg_00=oo`00?Nl07Cg_MGoo1Wm0:Goo1gn000<mkgaPO6000WaP00<mkgooOol027oo00<007ooOol0
2goo000@Ool00`00Oomoo`05Ool00`00Oomoo`06Ool70007Ool8?Nl2Ool00`00Oolmk`0K?NmdOol7
Od0YOol6Oh02?Nl4O6000cg_Oomoo`08Ool00`00Oomoo`0;Ool0011oo`03001oogoo00Eoo`03001o
ogoo00Eoo`80009lh0=l008000Qoo`Hmk`=oo`04001oogooOolI?NmdOol5Od0[Ool5Oh000goo?Nlm
k`04O6000cg_Oomoo`08Ool00`00Oomoo`0;Ool000moo`03001oogoo00Ioo`03001oogoo00Aoo`80
0003?Nmlh7`000Al008000Qoo`Dmk`Aoo`03001oogoo009ooaLmkg=oo`Io@2Yoo`EoP09oo`03?Nml
H7aP00=lH003Oj1oogoo00Qoo`03001oogoo00]oo`003goo00<007ooOol01Woo00<007ooOol00goo
0P0000=oocg_O>001G`000=oo`0000001goo1Sg_0goo00<007ooOol00goo5Sg_Lgoo1Gm0:goo1Gn0
0goo1GaP00=m@7nPOol027oo00<007ooOol02goo000>Ool00`00Oomoo`07Ool00`00Oomoo`03Ool2
00000gooO>1lh005O00017oo001oo`001Woo1Sg_0goo00<007ooOol017oo3cg_0Woo13g_Lgoo1Gm0
:goo1Gn00goo1GaP00=m@7ooOol027oo00<007ooOol02goo000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01@00Ool007ooO>001W`000Aoo`00Ool000Ioo`Tmk`03001oogoo00Aoo`hmk`=oo`@mkg=o
o`Ao@2aoo`EoP0=oo`ElH09m@0Uoo`03001oogoo00]oo`003Goo00<007ooOol027oo00D007ooOomo
o`00009oo`03001oogcP00Il0005Ool007ooOol00005Ool9?Nl00`00Oomoo`08Ool8?Nl5Ool5?Nmb
Ool4Od0/Ool4Oh04Ool5O6000ge0Oomoo`08Ool00`00Oomoo`0;Ool000eoo`03001oogoo00Qoo`05
001oogooOol00002Ool00`00Oomlh006O0001Goo001oogoo00001Goo2Sg_00<007ooOol057oo1Cg_
LWoo1Gm0:goo17n017oo1GaP00=m@7ooOol027oo00<007ooOol02goo000=Ool00`00Oomoo`08Ool0
1@00Oomoogoo00000goo00<007cPO00017`000=oo`00Ool00Woo00<007ooOol00goo2Sg_00<007oo
Ool05Goo13g_LWoo1Wm0:Woo17n017oo1GaP00=m@7ooOol027oo00<007ooOol02goo000=Ool00`00
Oomoo`08Ool01@00Oomoogoo00000goo0P0017`000=oo`00Ool00goo00<007ooOol01Woo1cg_00<0
07ooOol05Goo13g_LWoo1Gm0:goo17n00goo1WaP00=m@7ooOol027oo00<007ooOol02goo000=Ool0
0`00Oomoo`08Ool01@00Oomoogoo000017oo00=lh00000000`001Goo00<007ooOol01Woo1cg_00<0
07ooOol05Goo13g_Lgoo17m0:goo17n00goo1GaP0P002Goo00<007ooOol037oo000<Ool00`00Oomo
o`09Ool01@00Oomoogoo000017oo00=lh7`0O0000W`000=lh7ooOol00Woo00<007ooOol01goo1cg_
00<007ooOol05Goo13g_Lgoo17m0:goo17n00goo17aP00@007aPOD0000Qoo`03001oogoo00aoo`00
37oo00<007ooOol02Goo00<007ooOol00Woo00D007ooOomoogcP00El00=oo`03001oogoo00Qoo`Pm
k`03001oogoo01Aoo`@mkg=oo`Ao@2Yoo`EoP0=oo`=lH006001lH7aPOD1oo`001goo00<007ooOol0
37oo000<Ool00`00Oomoo`09Ool00`00Oomoo`02Ool01@00Oomoogoo?Nl01W`00Woo00<007ooOol0
27oo23g_00<007ooOol057oo13g_Lgoo17mP:Woo1Gn00goo17aP00D007aPOD1oo`0000Moo`03001o
ogoo00aoo`0037oo00<007ooOol02Woo00<007ooOol00Woo00@007ooOolmk`El009oo`03001oogoo
00Yoo`Lmk`03001oogoo01Aoo`@mkg=oo`AoH2Yoo`EoP0=oo`AlH004001lH0000008Ool00`00Oomo
o`0<Ool000aoo`03001oogoo00Yoo`03001oogoo00=oo`800003Oomlh7`000=l0003On0007oo00ao
o`Hmk`03000mkgoo01Eoo`@mkg=oo`AoH2Yoo`EoP0=oo`ElH003001m@7oo00Qoo`03001oogoo00ao
o`003Goo00<007ooOol02Goo00<007ooOol01Goo0`0000Al0000000000ioo`Hmk`04000mkcg_?NlD
Ool4?NmcOol4Of0ZOol4Oh04Ool7O6000cg_Oomoo`06Ool00`00Oomoo`0<Ool000eoo`03001oogoo
00Uoo`03001oogoo00Ioo`03O>1l0000009l0003O>1oogoo00ioo`@mk`03000mkcg_008mka=oo`Dm
kg9oo`AoH2Yoo`AoP0Aoo`IlH09m@0Qoo`03001oogoo00aoo`003Goo00<007ooOol02Goo00<007oo
Ool01Woo00=lh7`0O0000W`04Woo0cg_00<003g_?Nl00Sg_4goo1Cg_LWoo17mP:Woo17n017oo1WaP
00=m@7ooOol01goo00<007ooOol037oo000=Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00cg_O01l
0002O00COol2?Nl01000?Nlmkcg_5Goo13g_LWoo17mP:Woo1Gn00goo1WaP00=m@7ooOol01goo00<0
07ooOol037oo000>Ool00`00Oomoo`08Ool00`00Oomoo`07Ool4O0000goPOomoo`0AOol00`00Oomo
o`0GOol4?NmbOol4Of0ZOol5Oh03Ool5O6000ge0?Nmoo`07Ool00`00Oomoo`0=Ool000ioo`03001o
ogoo00Qoo`03001oogoo00Moo`El0003On1oogoo011oo`03001oogoo01Moo`@mkg9oo`AoH2Yoo`Eo
P0=oo`ElH09m@0Qoo`03001oogoo00eoo`003Woo00<007ooOol02Goo00<007ooOol01Woo1G`000=m
X7ooOol047oo00<007ooOol05goo13g_LWoo17mP:Woo1Wn00Woo1GaP00=m@7ooOol01goo00<007oo
Ool03Goo000?Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00gcPO01l0003O00BOol00`00Oomoo`0G
Ool4?NmbOol4Of0ZOol6Oh02Ool6O609Ool00`00Oomoo`0=Ool000moo`03001oogoo00Qoo`03001o
ogoo00Ioo`03O>1l07`000<0019oo`03001oogoo01Moo`@mkg9oo`AoH2Uoo`IoP0=oo`ElH003OD1o
ogoo00Moo`03001oogoo00eoo`0047oo00<007ooOol01goo00<007ooOol01Woo00=lh00000000W`0
00<mk`00Ool03goo00<007ooOol067oo13g_LWoo17mP:Goo1Wn00goo1GaP2Woo00<007ooOol03Goo
000@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01P00O01l07`0O>0000moo`03001oogoo01Uoo`@m
kg9oo`AoH2Qoo`IoP0Aoo`ElH003OD1oogoo00Ioo`03001oogoo00ioo`004Goo00<007ooOol01goo
00<007ooOol01Goo00<007`0O0000W`000=oh7oo00003Goo00<007ooOol06Woo13g_LWoo17mP:7oo
1Wn017oo1GaP00=oX7ooOol01Woo00<007ooOol03Woo000AOol00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00O01l0002O0000goPOol0000=Ool00`00Oomoo`0JOol5?NmaOol6Of0UOol6Oh05Ool5O609
Ool00`00Oomoo`0>Ool0019oo`03001oogoo00Ioo`03001oogoo00Ioo`06001l07`0O01oh0003Goo
00<007ooOol06goo1Cg_LGoo1gmP8goo10000Wn01Goo1GaP00=m@7ooOol01goo00<007ooOol03Woo
000COol00`00Oomoo`05Ool00`00Oomoo`06Ool20002O002000<Ool00`00Oomoo`0LOol6?Nm`Ool9
Of0NOol2Of000`00Oh1oP002Oh020005Ool5O6000ge0Oomoo`07Ool00`00Oomoo`0>Ool001Aoo`03
001oogoo00Aoo`03001oogoo00Ioo`9l00800003O01mX7oo00Uoo`8001moo`Hmkg9oo`QoH1]oo`=o
H003001oH7n000AoP003Ool007oo00=oo`ElH0Uoo`03001oogoo00moo`0057oo0P001Woo00<007oo
Ool01Goo00=lh7`0O0000g`02Goo00<007ooOol07goo1Sg_LWoo2WmP67oo17mP00<007mPOf0017n0
00=oo`00Ool00goo1GaP2Goo00<007ooOol03goo000FOol00`00Oomoo`03Ool00`00Oomoo`05Ool0
0gcPO01l0002O0000gcPOomoo`06Ool00`00Oomoo`0POol4?NmfOol9Of0FOol4Of000`00Of1oH005
Oh000goo001oo`02Ool00cg_O61lH002O6000ge0Oomoo`07Ool00`00Oomoo`0?Ool001Moo`03001o
ogoo009oo`03001oogoo00Eoo`03O>1l07`0009l0003?Nmoogoo00Aoo`80029oo`DmkgMoo`QoH1Ao
o`MoH003001oP7n000=oP09oo`04001oogooOol5O6000ge0Oomoo`06Ool00`00Oomoo`0@Ool001Qo
o`80009oo`03001oogoo00Eoo`03?Nml07`0009l0003On1oogoo009oo`8002Aoo`DmkgUoo`IoH1=o
o`QoH003001oP7n000=oP09oo`04001oogoo?Nl5O609Ool00`00Oomoo`0@Ool001Yoo`<000Qoo`El
009oo`8002Ioo`DmkgYoo`EoH15oo`QoH0=oo`8000=oo`80009oo`8mk`ElH0Uoo`03001oogoo011o
o`0077oo1@0017oo1G`00P00:7oo1Cg_Ngoo00AoH0000000011oo`QoH0Ioo`<000Aoo`8mk`AlH003
OD1oogoo00Moo`03001oogoo011oo`007Goo00@007ooOomoo`T00003O01oogoo02Moo`@mkgaoo`05
Of0007mPOf00000>Ool9Of0<Ool2?Nl5O60:Ool00`00Oomoo`0@Ool001eoo`03001oogoo00Eoo`03
O>1l07`0009l02Yoo`@mkgaoo`05001oH7mPOf00000=Ool7Of0?Ool2?Nl5O6000ge0Oomoo`06Ool0
0`00Oomoo`0AOol001ioo`03001oogoo00Aoo`03O>1l07`000=l02Uoo`@mkgaoo`06001oH7mPOf00
07mP2Woo2GmP3goo0Sg_1GaP2Goo00<007ooOol04Goo000NOol00`00Oomoo`04Ool00gcPO01l0004
O00XOol5?NmkOol50004Of02Ool2Of000gooOf1oH007Of0AOol2?Nl5O609Ool00`00Oomoo`0AOol0
01ioo`03001oogoo00Eoo`Il02Qoo`Dmkg]ooaMoH15oo`03?NmlH7aP00AlH0Qoo`03001oogoo019o
o`007Woo00<007ooOol01Goo00=lh00000000P000W`09goo1Cg_OWoo4WmP4goo00<mkgaPO6000gaP
00=oX7ooOol01Woo00<007ooOol04Woo000OOol00`00Oomoo`04Ool00gcP001l0002O0000`00O01o
o`0VOol4?Nn0Ool@Of0COol2?Nl5O609Ool00`00Oomoo`0BOol001moo`03001oogoo00Aoo`03O>00
07`0009l0003001l07`002Ioo`Dmkgmoo`ioH1Eoo`03?Nml@7a0009l@003O61oX7oo00Moo`03001o
ogoo01=oo`0087oo00<007ooOol00goo00=lh000O0000W`000<007`000000`008goo1Cg_P7oo27mP
5goo0Sg_00=oocg_O4000ga00WaP27oo00<007ooOol04goo000POol00`00Oomoo`03Ool00cg_0000
00020002O0001@00O01l87oo00008goo13g_WWoo1Cg_1Ga000=oX7ooOol01Goo00<007ooOol057oo
000POol00`00Oomoo`04Ool2O>03O0000`00O01l0002O0000goo001oo`0QOol4?NnNOol5?Nl5O408
Ool00`00Oomoo`0DOol0025oo`03001oogoo00=oo`Alh003O00007`000=l0003O20007oo025oo`@m
kiioo`Dmk`Al@003Oj1oogoo00Ioo`03001oogoo01Aoo`008Goo00<007ooOol00goo00=lh0000000
10000g`000=oo`00Ool08Goo1Cg_WGoo13g_1Ga027oo00<007ooOol05Goo000ROol00`00Oomoo`02
Ool01000O>1lh7cP0W`00P0000=l000000008goo1Cg_WGoo13g_1Ga027oo00<007ooOol05Goo000R
Ool00`00Oomoo`02Ool00`00O>1lh002O>03O2000`00Oomoo`0TOol4?NnMOol4?Nl4O4000gnPOomo
o`06Ool00`00Oomoo`0EOol002=oo`04001oogoo0005O>04O2000`00Oomoo`0SOol5?NnLOol3?Nl0
0gaPO41l@002O408Ool00`00Oomoo`0FOol002=oo`05001oogoo000mk`04O>04O2000`00O21oo`0S
Ool5?NnKOol4?Nl5O408Ool00`00Oomoo`0FOol002=oo`03001oo`00009oo`=lh0H002Ioo`@mkiUo
o`Dmk`El@003O61oogoo00Eoo`03001oogoo01Moo`0097oo00D007oo001oogcP00800003O>1mX7`P
009l808002Eoo`DmkiMoo`Hmk`El@003OD1oogoo00Eoo`03001oogoo01Moo`0097oo00<007oo0000
0P000WcP0P000g`P00<007`P000097oo1Cg_UWoo1Sg_00=m@7a0O4000ga01goo00<007ooOol067oo
000TOol01000Ool000000WcP00D007cPO>0007`P0080009l8003001oogoo029oo`Dmki=oo`Pmk`03
OD1l@7a0009l@003O61oogoo00Eoo`03001oogoo01Qoo`009Goo0`000WcP00D007cPO>1lh00000El
8003001oogoo025oo`Dmki5oo`Xmk`El@003O61oogoo00Aoo`03001oogoo01Uoo`009Goo00<007oo
Ool00P0017cP0P0017`P00<007ooOol08Goo1Sg_T7oo2Cg_00=m@7a0O4000ga01goo00<007ooOol0
6Goo000UOol20002Ool500000gfP001l8004O2000`00Oomoo`0QOol5?Nn@Ool9?Nl00ge0O41l@003
O407Ool00`00Oomoo`0IOol002Aoo`07001oogoo001oogcP000017cP00<007`PO2000g`P00<003g_
Ool08Woo1Cg_SWoo1Cg_17oo00<mkge0O4000ga000=lH7ooOol017oo00<007ooOol06Woo000TOol0
1P00Oomoo`00Oomlh0800005O>000000O>1o`004O2000`00?Nlmk`0ROol5?Nn>Ool5?Nl4Ool00ge0
O41l@003O4000gnPOomoo`03Ool00`00Oomoo`0KOol002Aoo`06001oogooOol003g_0WcP00@007cP
O>1lh0H0008mkb=oo`Dmkheoo`Dmk`=oo`9m@0El@003O61oogoo00=oo`03001oogoo01]oo`0097oo
00L007ooOomoo`00OommP005O>000`00O21l8002O2000`00O21oo`0SOol6?Nn;Ool6?Nl3Ool2OD02
O40200000ga0Oomoo`03Ool00`00Oomoo`0LOol002Aoo`03001oogoo009oo`03001mP7cP00=lh003
001lh7`P00=l80800003?Nmoogoo029oo`HmkhYoo`Dmk`03Ool0000000800003OD1l@000009l@003
001oogoo009oo`03001oogoo01eoo`0097oo00<007ooOol00Woo00<007f0OH000gcP00<007cPO>00
1@0000=l87ooOol08goo1Cg_RWoo1Cg_00<007ooOD000We00P000ga000<007ooOol00Woo00<007oo
Ool07Goo000UOol00`00Oomoo`02Ool2OH03O>000`00O>000003O20200000g`P?Nmoo`0SOol6?Nn9
Ool5?Nl01000Oomm@7e01@0000=l@000Ool00Woo00<007ooOol07Woo000UOol00`00Oomoo`02Ool0
0cg_OH1mP003O>02000017cPO20000000g`P97oo1cg_R7oo13g_00H007ooOD1m@000OD02O4030004
Ool00`00Oomoo`0NOol002Ioo`03001oogoo009oo`03?NmmP7cP009lh0800003O<1l8000008000=l
82Eoo`DmkhMoo`Dmk`05001m@7e0001m@004O4000`00O4000002Ool00`00Oomoo`0OOol002Moo`80
00=oo`03?NmmP7f0009lh0<0009l8004001l87`P?Nl3000SOol5?Nn6Ool4?Nl01P00OD1m@7e0001l
H0Al@003001oX000009oo`03001oogoo01moo`00:Goo0P000Woo00@mkgf0OH1lh0800004O<000000
O2030003Ool00`00Oomoo`0POol5?Nn5Ool5?Nl01Woo001m@000OD1lH0Al@005001oo`00Ool0000R
Ool002]oo`H00006O>1l`000O<1l80000g`P17oo00<007ooOol087oo1Cg_Q7oo1Cg_00Eooge0001m
@00000Al@003001l@7oo008002=oo`00;Woo00@003g_?NmmP0=l`003001l87`P009l8003?Nmoogoo
009oo`03001oogoo01moo`DmkhAoo`Dmk`9oo`03001m@00000=l@005001l@7ooOol0000TOol002io
o`03001oocg_009mP003O<0007`P00Al8003Ol1oogoo00=oo`03001oogoo01moo`Dmkh9oo`Hmk`=o
o`D0009l@09oo`03001oogoo029oo`00;goo00H003g_OH1mP7c00006O2000go0Oomoo`02Ool00`00
Oomoo`0OOol5?Nn1Ool6?Nl2Ool7000017aPOol000009Goo000`Ool01000?NmmP0000Wc01W`P00El
`7ooOomoo`00029oo`Dmkh1oo`Hmk`05Ool007ooO8000003O404000VOol0031oo`06001oocg_001m
P7c01W`P00=l`7ooOol00Woo00<007ooOol07goo1Cg_P7oo1Sg_00Ioo`00O81lP7a00002O4020000
0goo001oo`0UOol0035oo`06001oo`00?NmmP7c01W`P00El`7ooOomoo`00021oo`Hmkgmoo`Hmk`04
Ool007b0O802O4001P00O4000000Ool002Moo`00<Woo00D007oo000mkgf000Ml809oo`03001oogoo
01moo`DmkdAoo`LmkcEoo`Dmk`9oo`03001lP7a000=l@003001l@7eP008002Moo`00<goo0P0000@m
kgf0OH1mP0El8003Ol1oo`00025oo`Dmkd1oo`dmkc=oo`@mk`9oo`03O80007a000El@004OD0mkgoo
000WOol003Aoo`8000=mP0Al80@0025oo`Dmkc]ooa<mkc5oo`Dmk`04OomlP7b00006O40017e0Oomo
o`009goo000dOol3000013g_OH1l87`P0P000W`P0P008Goo13g_?7oo5Cg_;goo1Cg_0gb000<007a0
O4000Wa00WeP00@007ooOol002Moo`00=Goo00P007oo000007f0O20007`P0P0000=l8000Ool087oo
13g_>goo33g_00=oocg_?Nl02Cg_;Goo1Cg_00ElP7a0O41l@00000=l@09mH0=oo`03001oogoo02Eo
o`00=Woo00<007ooOol010000g`P00<007f0Ool07goo13g_>Goo2Sg_1goo2Sg_:goo1Cg_00=lP7a0
O4000Wa00P0000=l@7eP00000Woo0P00:7oo000gOol01@00Oolmkcg_000017`P00<007`POH007goo
13g_>Goo1Sg_37oo3Cg_9goo0cg_0Wb01ga00P0000=oo`000000:Woo000hOol00`00Oolmk`020002
O2020002O20OOol4?NlhOol6?Nl?Ool<?NlVOol2?Nl2O808O4000`00Ool0000/Ool003Qoo`05001o
ogoo?Nml`0020005O20MOol5?NlfOol7?NlBOol:?NlVOol00cg_O81lP006O40017nP?Nmoo`00;Woo
000iOol01000Oomoocg_0Wc01W`P00<mkgooOol06Goo1Cg_=Woo1Sg_5Woo23g_97oo00<mkgb0O800
1Wa000AoX3g_Ool002moo`00>Woo00H007ooOomoocg_O<07O202?NlHOol4?NlfOol6?NlIOol;?NlO
Ool00gb0O41l@005O40017ePOj1oo`00<7oo000kOol01P00OomoogooOl1l`0Il8004OH0mkcg_?NlF
Ool5?NlcOol7?NlKOol??NlGOol2?Nl00gb0O41l@005O40013g_Oomoo`00<Goo000lOol00`00Oomo
o`02?Nl00gc0O21l8005O203?NlEOol5?NlcOol6?NlLOolA?NlDOol2?Nl00gb0O41l@006O402Ool0
0`00Oomoo`0`Ool003eoo`05001oogoo?Nmo`008O203?NlEOol5?Nl`Ool7?NlJOolF?Nl7Ool8?Nl2
Ool2?Nl9O402Ool00`00Oomoo`0aOol003ioo`800003Oolmkgo000Ql808mkaEoo`Dmkbmoo`LmkaQo
o`Pmk`Aoo`lmk`Aoo``mk`Ml@005?NmoogooOol0000dOol0041oo`04001oocg_Ol08O202?NlEOol5
?Nl]Ool7?NlIOol8?Nl9OolI?Nl8O40013g_Oomoo`00=Goo0011Ool01000Oomoogc027`P00<mkgoo
Ool04goo1Cg_;7oo1cg_6Goo2Sg_2Woo5Cg_2Ga00goo00<007ooOol0=7oo0011Ool01@00Oomoocg_
O<0027`P5Woo1Cg_:Woo1cg_6Goo2Sg_3goo43g_1ga000=mH7ooOol00Woo00<007ooOol0=Goo0012
Ool00`00Oomoo`02?Nl00gc0O21l8005O20EOol5?NlZOol7?NlHOol6?Nl00goo?Nlmk`02?NlAOol8
?Nl4Ool00gb0O41l@006O404Ool00`00Oomoo`0fOol004=oo`05001oogooOolmk`08O20EOol5?NlX
Ool6?NlJOol5?Nl2Ool5?Nl@Ool8?Nl3Ool00gb0O41l@006O4001Cg_Oomoogoo0000>Goo0014Ool0
1000Oomoogoo0gc01G`P5Goo1Cg_9goo1cg_6Goo1Sg_0Woo1Cg_6Goo0Wb01Wa00Wb000EmH7ooOomo
o`0003Yoo`00AGoo0P000Woo0Wc01W`P57oo1Cg_9goo1Cg_6Woo1cg_0Woo1Cg_67oo00=lP7a0O400
1Ga000=oX3g_?Nl00goo00<007ooOol0>Goo0017Ool01000Oomoogc027`P4Woo1Sg_9Goo1Cg_6goo
1Sg_0goo1Sg_4Woo1Gb01ga000=lP3g_?Nl00goo00<007ooOol0>Woo0018Ool01@00Oomoocg_O<00
1W`P00<mkgooOol047oo1Sg_8goo1Sg_6goo1Sg_17oo1Sg_2Goo0Wb01Goo17b02Ga000AoX7ooOomo
o`8003eoo`00BGoo00<007ooOol00Wc01W`P0Sg_4Goo1Cg_8Woo1Sg_77oo1Cg_1Woo1cg_1Woo2gb0
2Ga000EoX7ooOomoo`0003moo`00BWoo0P0000<mkgc0O2001W`P0`0047oo1Cg_8Goo1Cg_7Goo13g_
1goo1cg_17oo2gb00`001Wa000=oX7ooOol00Woo00<007ooOol0?Woo001<Ool00`00?Nml`004O202
0002O2000cg_001oo`0>Ool6?NlNOol7?NlMOol4?Nl7Ool7?Nl00gooO81lP00;O8001@00O41l@7a0
000017a000@mkgooOomoo`80045oo`00CWoo00<007c0O<000W`P00<007`PO2000W`P00<007ooOol0
3Woo1Cg_67oo13g_00=oocg_?Nl01Sg_7Goo13g_1goo0Wb00Sg_0Wb000<mkgb0O80037b000D007a0
O41l@000009l@004?NmoogooOol20013Ool004moo`8mk`03O20007`P00Al8003001l83g_00ioo`Hm
kaIoo``mkamoo`@mk`Aooa=lP0=oX003O40007a000=l@0800005O41oogooOol00015Ool0051oo`04
?Nmo`7`P0004O2000`00O21l8003O20;Ool7?NlEOol;?NlPOol3?NlGO803Oj03O4000`00O41l@002
O4001@00Oomoogoo0000AWoo001BOol017f0000007`P0P0027`P0Sg_2Goo1Cg_57oo33g_87oo67b0
0gnP1Ga00P0000=l@00000000Woo0P00Agoo001COol2O<000`00O21l800:O2000cg_Oomoo`06Ool6
?NlBOol<?NlPOolFO805Oj08O4001@00?Nmoogoo0000BGoo001EOol2OH0>O206Ool7?NlAOol5?NlF
Ool20009OolHO8000cg_Oj1oX004Oj000gePO41l@006O4000gePOomoo`02001:Ool005Ioo`03001l
`7c000el8003O<1oog`P00Aoo`Dmka1oo`DmkaIoo`03001oogoo008000Moo`mlP0Qoo`03?NmoX7nP
00AoX0Ul@004OF1oo`00001<Ool005Qoo`80009l`0ml809oo`Hmk`ioo`HmkaEoo`03001oogoo00=o
o`04001oogooOol?O805?Nl5Ool6Oj000gePO41l@005O402OF02Ool00`00Oomoo`1<Ool005Yoo`80
009l`0il8003OH1l83g_00@mk`@000Yoo`DmkaIoo`03001lP7b000=lP003001lP7b000elP0/mk`Mo
X003OF1l@7a000El@08mk`03Ool0000004moo`00G7oo0P0000=oogc0O<003W`P00@mkg`P?Nl0008m
k`9oo`03000mkcg_008mk`Aoo`DmkaIoo`03001lX7b000AlP08000UlP0=oo`Lmk`9l@0<mk`IoX003
OF1l@7a000Il@004OF0mk`00001AOol005ioo`80008mk`03O<1l87`P00el8003001l83g_00<mk`04
000mkcg_?Nl4Ool5?NlEOol00gbP001lX005O8000`00O81lP008O804Ool2O4000cg_O41l@00EO402
001COol0061oo`8000=oo`9l`0Yl8006001l87`PO20mkga00Sg_00<003g_?Nl00goo1Cg_5Goo0gbP
00<007b0O8000gb000<007b0O80027b00Wa000=ooga0O4005Wa000=mH3g_Ool0EGoo001ROol20003
Ool00cg_OH1l8007O2000`00O21l8003O2001Ga0?Nlmk`00?Nl00Woo1Sg_57oo17bP0P000WbP0P00
27oo7Wa0F7oo001TOol20004Ool2O<04O2000`00O21l8005O202O4001000O40mkgoo1Cg_4goo27bP
0P001Goo8Wa0FGoo001VOol30003Ool01Go0O<1l`7`P00001g`P0Wa000@007a0O41l@0Dmk`ioo`<0
0003OomlX7bP00ElX0IooaEl@0emH5aoo`00JGoo0`000goo00=o`000O:001G`P0Wa000<007a0O400
0ga000=lX7a0?Nl00Sg_2goo0P000Woo00=lX00000001WbP0goo57a037eP13g_GGoo001/Ool30002
Ool20002O:03O4000`00O41l@009O403?Nl2Ool5?Nl01000?Nlmkcg_17bP00<007bPO:000Wa000=l
X7a0O4003ga03GeP00@mkgoo0000069oo`00Kgoo0`0000Aoo`00001mP08000ml@0Hmk`04000mkcg_
?Nl6O:04000?O40;OF03?Nl017oo00000000I7oo001bOol40002Ool2O:0>O405?Nl00`00?Nlmk`04
O:03O4020002O4000`00O41l@009O409OF07?Nl2001WOol007Eoo`@0009oo`03OH1l@7a000il@003
001l@7a000Ql@08000=l@003001l@7a000=l@0=mP0MmH0<mk`Aoo`8006]oo`00NGoo100000=oogbP
O40037a000<007a0O40027a00`000Wa000<007a0O40027f01Woo1P00KGoo001mOol40002O:0:O400
0`00O41l@007O4000`00O41l@0020004OH000cg_Oomoo`04Ool6001cOol008Aoo`03O:1l@7a000Il
@003001l@7a000Ml@003000mkgoo00Eoo`P007Uoo`00RGoo1Cg_00<003g_00003P00PGoo002>Ool2
0005Ool20029Ool0091oo`800003Ool0000008]oo`00TWoo00<007ooOol0Rgoo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo002:Ool500000goo00000002002<Ool008aoo`05001oogoo
Ool0002?Ool008aoo`03001oogoo009oo`03001oogoo08aoo`00S7oo00<007ooOol00goo00<007oo
Ool0Rgoo002<Ool01@00Oomoogoo00000Woo00<007ooOol0RWoo002;Ool20004Ool2002=Ool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-202.956, -178.701, 1.35993, \
1.31387}}]
}, Closed]],

Cell["\<\
Excluding the last excursion, which is not a complete one, we draw 12 \
excursions.\
\>", "Text",
  FontSize->14],

Cell["\<\
A full dynamic representation of the animal's velocity in reference to its \
momentary location is provided by PhasePlot. This function allows one to \
actually visualize in 3 dimensions the animal's trajectory: Path traced on \
ground proceeds in time from yellow to red. Blue line represents velocity, \
vertical dashed lines are added to the figure to help create a 3-dimensional \
impression.
\
\>", "Text",
  TextJustification->1,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(exc[\([1, 12]\)]\)], "Input"],

Cell[BoxData[
    \({37818, 43082}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(See[PhasePlot[exc[\([1, 11]\)]], 
      PlotLabel -> StyleForm[\ "\<Excursion 11\>", FontSize -> 16], 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72323 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.14925e-017 1.04899 -0.111539 1.04899 [
[.5 .73573 -59.375 0 ]
[.5 .73573 59.375 14.75 ]
[ 0 0 0 0 ]
[ 1 .72323 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .73573 -120.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.75 translate 1 -1 scale
63.000 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Excursion) show
158.625 15.000 moveto
(11) show
177.750 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .72323 L
0 .72323 L
closepath
clip
newpath
0 0 0 r
.004 w
.52443 .5374 Mdot
.52646 .5374 Mdot
.5224 .5374 Mdot
.52848 .53739 Mdot
.52036 .53739 Mdot
.53049 .53737 Mdot
.51831 .53737 Mdot
.5325 .53734 Mdot
.51625 .53734 Mdot
.53449 .53731 Mdot
.51419 .53731 Mdot
.53649 .53727 Mdot
.51211 .53726 Mdot
.53847 .53723 Mdot
.51003 .53721 Mdot
.54045 .53717 Mdot
.50794 .53715 Mdot
.54242 .53711 Mdot
.50585 .53709 Mdot
.54439 .53704 Mdot
.50374 .53701 Mdot
.54634 .53697 Mdot
.50163 .53693 Mdot
.5483 .53689 Mdot
.4995 .53684 Mdot
.55024 .5368 Mdot
.49737 .53673 Mdot
.55218 .53671 Mdot
.49523 .53662 Mdot
.55411 .53661 Mdot
.49308 .53651 Mdot
.55604 .5365 Mdot
.55796 .53638 Mdot
.49092 .53638 Mdot
.55988 .53626 Mdot
.48875 .53624 Mdot
.56179 .53614 Mdot
.48657 .53609 Mdot
.56369 .53601 Mdot
.48439 .53594 Mdot
.56559 .53587 Mdot
.48219 .53577 Mdot
.56748 .53572 Mdot
.47998 .5356 Mdot
.56937 .53557 Mdot
.47776 .53541 Mdot
.57125 .53541 Mdot
.57313 .53525 Mdot
.47553 .53522 Mdot
.575 .53508 Mdot
.47329 .53501 Mdot
.57687 .5349 Mdot
.47103 .5348 Mdot
.57873 .53472 Mdot
.46877 .53457 Mdot
.58058 .53453 Mdot
.58243 .53434 Mdot
.46649 .53433 Mdot
.58428 .53414 Mdot
.46421 .53408 Mdot
.58612 .53393 Mdot
.46191 .53382 Mdot
.58795 .53372 Mdot
1 .929 0 r
.01 w
[ .05 .05 ] 0 setdash
.5144 .53371 m
.51693 .53369 L
s
.5144 .53371 Mdot
.51195 .53366 m
.5144 .53371 L
s
.51936 .5337 m
.5218 .5336 L
s
.51936 .5337 Mdot
.51693 .53369 m
.51936 .5337 L
s
.51693 .53369 Mdot
.51195 .53366 Mdot
1 .93 0 r
.5095 .5336 m
.51195 .53366 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.52175 .58773 m
.5218 .5336 L
s
1 .929 0 r
.01 w
[ .05 .05 ] 0 setdash
.5218 .5336 m
.52439 .53351 L
s
.5218 .5336 Mdot
1 .93 0 r
.5095 .5336 Mdot
.50693 .53343 m
.5095 .5336 L
s
0 0 0 r
.004 w
.45959 .53355 Mdot
1 .928 0 r
.01 w
.52439 .53351 m
.52706 .53334 L
s
.52439 .53351 Mdot
0 0 0 r
.004 w
.58978 .5335 Mdot
1 .93 0 r
.01 w
.50693 .53343 Mdot
.50442 .53321 m
.50693 .53343 L
s
1 .928 0 r
.52706 .53334 m
.52966 .53319 L
s
.52706 .53334 Mdot
0 0 0 r
.004 w
.5916 .53328 Mdot
.45727 .53327 Mdot
1 .93 0 r
.01 w
.50442 .53321 Mdot
.50149 .53297 m
.50442 .53321 L
s
1 .928 0 r
.52966 .53319 m
.53237 .53299 L
s
.52966 .53319 Mdot
0 0 0 r
.004 w
.59342 .53305 Mdot
1 .928 0 r
.01 w
.53237 .53299 m
.53502 .53279 L
s
.53237 .53299 Mdot
1 .93 0 r
.50149 .53297 Mdot
.49862 .5327 m
.50149 .53297 L
s
0 0 0 r
.004 w
.45493 .53297 Mdot
.59524 .53282 Mdot
1 .927 0 r
.01 w
.53502 .53279 m
.53756 .53255 L
s
.53502 .53279 Mdot
1 .93 0 r
.49862 .5327 Mdot
1 .931 0 r
.49584 .53231 m
.49862 .5327 L
s
0 0 0 r
.004 w
.45258 .53266 Mdot
.59705 .53258 Mdot
1 .927 0 r
.01 w
.53756 .53255 m
.54007 .5323 L
s
.53756 .53255 Mdot
0 0 0 r
.004 w
.45021 .53234 Mdot
.59885 .53233 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.49529 .59876 m
.49584 .53231 L
s
1 .931 0 r
.01 w
.49584 .53231 Mdot
[ .05 .05 ] 0 setdash
.49265 .53203 m
.49584 .53231 L
s
1 .927 0 r
.54007 .5323 m
.54234 .53207 L
s
.54007 .5323 Mdot
0 0 0 r
.004 w
.60065 .53208 Mdot
1 .927 0 r
.01 w
.54234 .53207 m
.54443 .53182 L
s
.54234 .53207 Mdot
1 .931 0 r
.49265 .53203 Mdot
.4895 .53157 m
.49265 .53203 L
s
0 0 0 r
.004 w
.44783 .53201 Mdot
.60245 .53182 Mdot
1 .927 0 r
.01 w
.54443 .53182 m
.54631 .53158 L
s
.54443 .53182 Mdot
0 0 0 r
.004 w
.44544 .53166 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.54655 .56878 m
.54631 .53158 L
s
1 .926 0 r
.01 w
[ .05 .05 ] 0 setdash
.54631 .53158 m
.54798 .53135 L
s
.54631 .53158 Mdot
1 .931 0 r
.4895 .53157 Mdot
.48651 .53107 m
.4895 .53157 L
s
0 0 0 r
.004 w
.60424 .53156 Mdot
1 .926 0 r
.01 w
.54798 .53135 m
.54943 .53113 L
s
.54798 .53135 Mdot
0 0 0 r
.004 w
.44303 .5313 Mdot
.60603 .53129 Mdot
1 .926 0 r
.01 w
.54943 .53113 m
.55066 .53092 L
s
.54943 .53113 Mdot
1 .931 0 r
.48651 .53107 Mdot
.48332 .53066 m
.48651 .53107 L
s
0 0 0 r
.004 w
.60781 .53102 Mdot
.44061 .53093 Mdot
1 .926 0 r
.01 w
.55066 .53092 m
.55168 .53073 L
s
.55066 .53092 Mdot
0 0 0 r
.004 w
.60959 .53074 Mdot
1 .926 0 r
.01 w
.55168 .53073 m
.55252 .53056 L
s
.55168 .53073 Mdot
1 .931 0 r
.48332 .53066 Mdot
1 .932 0 r
.48028 .53015 m
.48332 .53066 L
s
1 .925 0 r
.55252 .53056 m
.55317 .5304 L
s
.55252 .53056 Mdot
0 0 0 r
.004 w
.43817 .53054 Mdot
.61136 .53045 Mdot
1 .925 0 r
.01 w
.55317 .5304 m
.55367 .53025 L
s
.55317 .5304 Mdot
.55367 .53025 m
.55405 .53013 L
s
.55367 .53025 Mdot
0 0 0 r
.004 w
.61313 .53016 Mdot
1 .932 0 r
.01 w
.48028 .53015 Mdot
.47741 .5297 m
.48028 .53015 L
s
0 0 0 r
.004 w
.43571 .53013 Mdot
1 .925 0 r
.01 w
.55405 .53013 m
.55433 .53003 L
s
.55405 .53013 Mdot
.55433 .53003 m
.55453 .52996 L
s
.55433 .53003 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55456 .53345 m
.55453 .52996 L
s
1 .924 0 r
.01 w
[ .05 .05 ] 0 setdash
.55453 .52996 m
.55466 .52992 L
s
.55453 .52996 Mdot
1 .922 0 r
.55394 .52994 m
.55417 .52994 L
s
.55394 .52994 Mdot
.55388 .52993 m
.55394 .52994 L
s
1 .921 0 r
.55417 .52994 m
.55461 .52992 L
s
.55417 .52994 Mdot
1 .922 0 r
.55388 .52993 Mdot
.55394 .52993 m
.55388 .52993 L
s
.55394 .52993 Mdot
.55407 .52993 m
.55394 .52993 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5541 .53263 m
.55407 .52993 L
s
1 .922 0 r
.01 w
.55407 .52993 Mdot
[ .05 .05 ] 0 setdash
.55424 .52992 m
.55407 .52993 L
s
1 .921 0 r
.55461 .52992 m
.55529 .52989 L
s
.55461 .52992 Mdot
1 .922 0 r
.55424 .52992 Mdot
1 .923 0 r
.55442 .52991 m
.55424 .52992 L
s
1 .924 0 r
.55466 .52992 m
.55473 .52989 L
s
.55466 .52992 Mdot
1 .923 0 r
.55442 .52991 Mdot
.55456 .52989 m
.55442 .52991 L
s
1 .921 0 r
.55529 .52989 m
.55623 .52984 L
s
.55529 .52989 Mdot
1 .924 0 r
.55473 .52989 m
.55476 .52988 L
s
.55473 .52989 Mdot
1 .923 0 r
.55456 .52989 Mdot
.55466 .52988 m
.55456 .52989 L
s
1 .924 0 r
.55476 .52988 m
.55475 .52987 L
s
.55476 .52988 Mdot
1 .923 0 r
.55466 .52988 Mdot
.55472 .52987 m
.55466 .52988 L
s
.55475 .52987 m
.55472 .52987 L
s
.55475 .52987 Mdot
.55472 .52987 Mdot
0 0 0 r
.004 w
.61489 .52986 Mdot
1 .921 0 r
.01 w
.55623 .52984 m
.55749 .52974 L
s
.55623 .52984 Mdot
.55749 .52974 m
.55898 .52965 L
s
.55749 .52974 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55476 .53021 m
.55475 .53045 L
s
.55474 .53075 m
.55476 .53021 L
s
0 0 0 r
.004 w
.43324 .52971 Mdot
1 .932 0 r
.01 w
.47741 .5297 Mdot
[ .05 .05 ] 0 setdash
.47473 .52932 m
.47741 .5297 L
s
1 .92 0 r
.55898 .52965 m
.56065 .52953 L
s
.55898 .52965 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55475 .53045 m
.55472 .53069 L
s
0 0 0 r
.004 w
.61665 .52956 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5611 .57219 m
.56065 .52953 L
s
1 .92 0 r
.01 w
[ .05 .05 ] 0 setdash
.56065 .52953 m
.56282 .5294 L
s
.56065 .52953 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55468 .53186 m
.55474 .53075 L
s
.55389 .53087 m
.55395 .5314 L
s
.55396 .53215 m
.55389 .53087 L
s
.55472 .53069 m
.55467 .53086 L
s
.55467 .53086 m
.55458 .53124 L
s
1 .92 0 r
.01 w
[ .05 .05 ] 0 setdash
.56282 .5294 m
.56507 .52923 L
s
.56282 .5294 Mdot
1 .932 0 r
.47473 .52932 Mdot
.472 .52886 m
.47473 .52932 L
s
0 0 0 r
.004 w
.43075 .52928 Mdot
.61841 .52925 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55458 .53124 m
.55444 .53189 L
s
1 .92 0 r
.01 w
[ .05 .05 ] 0 setdash
.56507 .52923 m
.56771 .52902 L
s
.56507 .52923 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55395 .5314 m
.55422 .53507 L
s
1 .92 0 r
.01 w
[ .05 .05 ] 0 setdash
.56771 .52902 m
.57066 .52879 L
s
.56771 .52902 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55456 .53345 m
.55468 .53186 L
s
.55444 .53189 m
.55427 .53249 L
s
0 0 0 r
.004 w
.62016 .52894 Mdot
1 .932 0 r
.01 w
.472 .52886 Mdot
1 .933 0 r
[ .05 .05 ] 0 setdash
.46954 .52844 m
.472 .52886 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5541 .53263 m
.55396 .53215 L
s
0 0 0 r
.004 w
.42825 .52883 Mdot
1 .919 0 r
.01 w
[ .05 .05 ] 0 setdash
.57066 .52879 m
.57377 .52857 L
s
.57066 .52879 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55427 .53249 m
.5541 .53263 L
s
0 0 0 r
.004 w
.62191 .52862 Mdot
1 .919 0 r
.01 w
[ .05 .05 ] 0 setdash
.57377 .52857 m
.57684 .5284 L
s
.57377 .52857 Mdot
1 .933 0 r
.46954 .52844 Mdot
.46725 .52804 m
.46954 .52844 L
s
1 .919 0 r
.57684 .5284 m
.58011 .5281 L
s
.57684 .5284 Mdot
0 0 0 r
.004 w
.42572 .52837 Mdot
.62365 .5283 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55437 .53547 m
.55456 .53345 L
s
1 .919 0 r
.01 w
[ .05 .05 ] 0 setdash
.58011 .5281 m
.58349 .52782 L
s
.58011 .5281 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.46647 .57495 m
.46725 .52804 L
s
1 .933 0 r
.01 w
.46725 .52804 Mdot
[ .05 .05 ] 0 setdash
.46517 .52766 m
.46725 .52804 L
s
0 0 0 r
.004 w
.62539 .52797 Mdot
.42318 .52788 Mdot
1 .918 0 r
.01 w
.58349 .52782 m
.58685 .5275 L
s
.58349 .52782 Mdot
1 .933 0 r
.46517 .52766 Mdot
.46334 .5273 m
.46517 .52766 L
s
0 0 0 r
.004 w
.62712 .52763 Mdot
1 .918 0 r
.01 w
.58685 .5275 m
.59001 .52725 L
s
.58685 .5275 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55422 .53507 m
.5547 .53976 L
s
.55411 .53782 m
.55437 .53547 L
s
0 0 0 r
.004 w
.42062 .52738 Mdot
1 .933 0 r
.01 w
.46334 .5273 Mdot
[ .05 .05 ] 0 setdash
.46171 .52701 m
.46334 .5273 L
s
0 0 0 r
.004 w
.62885 .52729 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59134 .59741 m
.59001 .52725 L
s
1 .918 0 r
.01 w
[ .05 .05 ] 0 setdash
.59001 .52725 m
.59331 .52697 L
s
.59001 .52725 Mdot
1 .933 0 r
.46171 .52701 Mdot
1 .934 0 r
.46027 .52671 m
.46171 .52701 L
s
1 .918 0 r
.59331 .52697 m
.59651 .52666 L
s
.59331 .52697 Mdot
0 0 0 r
.004 w
.63058 .52694 Mdot
.41804 .52687 Mdot
1 .934 0 r
.01 w
.46027 .52671 Mdot
.45904 .52647 m
.46027 .52671 L
s
1 .918 0 r
.59651 .52666 m
.59969 .52639 L
s
.59651 .52666 Mdot
0 0 0 r
.004 w
.6323 .52659 Mdot
1 .934 0 r
.01 w
.45904 .52647 Mdot
.45801 .52624 m
.45904 .52647 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55376 .54029 m
.55411 .53782 L
s
1 .917 0 r
.01 w
[ .05 .05 ] 0 setdash
.59969 .52639 m
.60285 .5261 L
s
.59969 .52639 Mdot
0 0 0 r
.004 w
.41543 .52633 Mdot
1 .934 0 r
.01 w
.45801 .52624 Mdot
.45715 .52605 m
.45801 .52624 L
s
0 0 0 r
.004 w
.63401 .52624 Mdot
1 .676 0 r
.01 w
.59132 .52618 m
.59109 .52618 L
s
.59132 .52618 Mdot
.59166 .52616 m
.59132 .52618 L
s
1 .675 0 r
.59109 .52618 m
.59098 .52615 L
s
.59109 .52618 Mdot
1 .676 0 r
.59166 .52616 Mdot
.59215 .5261 m
.59166 .52616 L
s
1 .675 0 r
.59098 .52615 m
.59096 .5261 L
s
.59098 .52615 Mdot
1 .676 0 r
.59215 .5261 Mdot
.59279 .52603 m
.59215 .5261 L
s
1 .917 0 r
.60285 .5261 m
.60595 .52581 L
s
.60285 .5261 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59102 .52916 m
.59096 .5261 L
s
1 .675 0 r
.01 w
[ .05 .05 ] 0 setdash
.59096 .5261 m
.59101 .52603 L
s
.59096 .5261 Mdot
1 .94 0 r
.45527 .52608 m
.45593 .52607 L
s
.45527 .52608 Mdot
.45436 .52602 m
.45527 .52608 L
s
.45593 .52607 m
.45634 .526 L
s
.45593 .52607 Mdot
1 .934 0 r
.45715 .52605 Mdot
.45647 .52588 m
.45715 .52605 L
s
1 .676 0 r
.59279 .52603 Mdot
.59358 .52596 m
.59279 .52603 L
s
1 .675 0 r
.59101 .52603 m
.5911 .52595 L
s
.59101 .52603 Mdot
1 .94 0 r
.45436 .52602 Mdot
.45319 .52591 m
.45436 .52602 L
s
.45634 .526 m
.45652 .52591 L
s
.45634 .526 Mdot
1 .676 0 r
.59358 .52596 Mdot
1 .677 0 r
.59451 .52589 m
.59358 .52596 L
s
1 .674 0 r
.5911 .52595 m
.59123 .52586 L
s
.5911 .52595 Mdot
1 .939 0 r
.45652 .52591 m
.45654 .52581 L
s
.45652 .52591 Mdot
1 .94 0 r
.45319 .52591 Mdot
1 .941 0 r
.45186 .52573 m
.45319 .52591 L
s
1 .677 0 r
.59451 .52589 Mdot
.59564 .52579 m
.59451 .52589 L
s
1 .934 0 r
.45647 .52588 Mdot
1 .935 0 r
.45597 .52572 m
.45647 .52588 L
s
0 0 0 r
.004 w
.63573 .52587 Mdot
1 .674 0 r
.01 w
.59123 .52586 m
.59137 .52579 L
s
.59123 .52586 Mdot
1 .917 0 r
.60595 .52581 m
.60898 .52551 L
s
.60595 .52581 Mdot
1 .939 0 r
.45654 .52581 m
.45645 .52571 L
s
.45654 .52581 Mdot
1 .677 0 r
.59564 .52579 Mdot
.59699 .52564 m
.59564 .52579 L
s
1 .674 0 r
.59137 .52579 m
.59152 .52573 L
s
.59137 .52579 Mdot
0 0 0 r
.004 w
.41281 .52578 Mdot
1 .941 0 r
.01 w
.45186 .52573 Mdot
.45031 .52551 m
.45186 .52573 L
s
1 .674 0 r
.59152 .52573 m
.59166 .52568 L
s
.59152 .52573 Mdot
1 .935 0 r
.45597 .52572 Mdot
.45562 .5256 m
.45597 .52572 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.45635 .53068 m
.45645 .52571 L
s
1 .939 0 r
.01 w
[ .05 .05 ] 0 setdash
.45645 .52571 m
.4563 .52561 L
s
.45645 .52571 Mdot
1 .668 0 r
.59245 .5257 m
.59233 .52569 L
s
.59245 .5257 Mdot
.59245 .52569 m
.59245 .5257 L
s
.59233 .52569 m
.59208 .52567 L
s
.59233 .52569 Mdot
.59245 .52569 Mdot
.59238 .52567 m
.59245 .52569 L
s
1 .674 0 r
.59166 .52568 m
.5918 .52565 L
s
.59166 .52568 Mdot
1 .668 0 r
.59208 .52567 m
.59168 .52563 L
s
.59208 .52567 Mdot
.59238 .52567 Mdot
1 .669 0 r
.59228 .52566 m
.59238 .52567 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59232 .52749 m
.59228 .52566 L
s
1 .669 0 r
.01 w
.59228 .52566 Mdot
[ .05 .05 ] 0 setdash
.59217 .52564 m
.59228 .52566 L
s
1 .673 0 r
.5918 .52565 m
.59193 .52562 L
s
.5918 .52565 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59758 .55345 m
.59699 .52564 L
s
1 .677 0 r
.01 w
.59699 .52564 Mdot
[ .05 .05 ] 0 setdash
.59847 .52546 m
.59699 .52564 L
s
1 .669 0 r
.59217 .52564 Mdot
.59209 .52563 m
.59217 .52564 L
s
1 .667 0 r
.59168 .52563 m
.59111 .52556 L
s
.59168 .52563 Mdot
1 .669 0 r
.59209 .52563 Mdot
.59203 .52562 m
.59209 .52563 L
s
1 .673 0 r
.59193 .52562 m
.59202 .5256 L
s
.59193 .52562 Mdot
1 .669 0 r
.59203 .52562 Mdot
.592 .52562 m
.59203 .52562 L
s
.592 .52562 Mdot
1 .67 0 r
.592 .52562 m
.592 .52562 L
s
1 .671 0 r
.592 .52562 m
.592 .52562 L
s
.592 .52562 Mdot
1 .67 0 r
.592 .52562 Mdot
1 .671 0 r
.592 .52562 Mdot
.592 .52562 Mdot
1 .672 0 r
.592 .52562 m
.592 .52562 L
s
1 .67 0 r
.592 .52562 Mdot
1 .671 0 r
.592 .52562 Mdot
1 .67 0 r
.592 .52562 Mdot
1 .671 0 r
.592 .52562 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.592 .52564 m
.592 .52562 L
s
1 .67 0 r
.01 w
.592 .52562 Mdot
.53 .8 .95 r
.006 w
.592 .52562 m
.592 .52568 L
s
1 .672 0 r
.01 w
.592 .52562 Mdot
[ .05 .05 ] 0 setdash
.59201 .52561 m
.592 .52562 L
s
.59201 .52561 Mdot
.59203 .52561 m
.59201 .52561 L
s
1 .939 0 r
.4563 .52561 m
.45612 .52553 L
s
.4563 .52561 Mdot
1 .672 0 r
.59203 .52561 Mdot
.59205 .5256 m
.59203 .52561 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59201 .52573 m
.592 .52564 L
s
1 .673 0 r
.01 w
[ .05 .05 ] 0 setdash
.59202 .5256 m
.59206 .52559 L
s
.59202 .5256 Mdot
1 .672 0 r
.59205 .5256 Mdot
.59207 .52559 m
.59205 .5256 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.4555 .53172 m
.45562 .5256 L
s
1 .935 0 r
.01 w
.45562 .5256 Mdot
[ .05 .05 ] 0 setdash
.45542 .5255 m
.45562 .5256 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59206 .52566 m
.59206 .52559 L
s
1 .673 0 r
.01 w
[ .05 .05 ] 0 setdash
.59206 .52559 m
.59208 .52559 L
s
.59206 .52559 Mdot
1 .672 0 r
.59207 .52559 Mdot
1 .673 0 r
.59208 .52559 m
.59207 .52559 L
s
.59208 .52559 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.592 .52568 m
.59204 .52595 L
s
1 .667 0 r
.01 w
[ .05 .05 ] 0 setdash
.59111 .52556 m
.59036 .52546 L
s
.59111 .52556 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59206 .52566 m
.59208 .52591 L
s
.59203 .52633 m
.59206 .52566 L
s
.59245 .52598 m
.59238 .52801 L
s
.59248 .52707 m
.59245 .52598 L
s
.59203 .52589 m
.59201 .52573 L
s
1 .939 0 r
.01 w
[ .05 .05 ] 0 setdash
.45612 .52553 m
.45595 .52547 L
s
.45612 .52553 Mdot
1 .937 0 r
.45582 .52552 m
.45579 .5255 L
s
.45582 .52552 Mdot
.45582 .52551 m
.45582 .52552 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.45581 .52598 m
.45582 .52551 L
s
1 .937 0 r
.01 w
.45582 .52551 Mdot
[ .05 .05 ] 0 setdash
.4558 .5255 m
.45582 .52551 L
s
1 .917 0 r
.60898 .52551 m
.6118 .52526 L
s
.60898 .52551 Mdot
1 .941 0 r
.45031 .52551 Mdot
.44858 .52518 m
.45031 .52551 L
s
0 0 0 r
.004 w
.63744 .52551 Mdot
1 .935 0 r
.01 w
.45542 .5255 Mdot
.45534 .52544 m
.45542 .5255 L
s
1 .936 0 r
.45579 .5255 m
.45574 .52548 L
s
.45579 .5255 Mdot
1 .937 0 r
.4558 .5255 Mdot
.45578 .52547 m
.4558 .5255 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45582 .52557 m
.45579 .52583 L
s
.45581 .52598 m
.45582 .52557 L
s
1 .936 0 r
.01 w
[ .05 .05 ] 0 setdash
.45574 .52548 m
.45566 .52545 L
s
.45574 .52548 Mdot
1 .937 0 r
.45578 .52547 Mdot
1 .938 0 r
.45576 .52545 m
.45578 .52547 L
s
.45595 .52547 m
.45584 .52544 L
s
.45595 .52547 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59206 .52604 m
.59203 .52589 L
s
1 .677 0 r
.01 w
.59847 .52546 Mdot
[ .05 .05 ] 0 setdash
.60007 .52526 m
.59847 .52546 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59204 .52595 m
.5921 .52644 L
s
1 .667 0 r
.01 w
[ .05 .05 ] 0 setdash
.59036 .52546 m
.58943 .52532 L
s
.59036 .52546 Mdot
1 .938 0 r
.45576 .52545 Mdot
.45576 .52544 m
.45576 .52545 L
s
1 .936 0 r
.45566 .52545 m
.45555 .52542 L
s
.45566 .52545 Mdot
1 .938 0 r
.45584 .52544 m
.45578 .52543 L
s
.45584 .52544 Mdot
1 .935 0 r
.45534 .52544 Mdot
.45535 .52541 m
.45534 .52544 L
s
1 .938 0 r
.45576 .52544 Mdot
.45578 .52543 m
.45576 .52544 L
s
.45578 .52543 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59208 .52591 m
.59208 .52606 L
s
1 .936 0 r
.01 w
[ .05 .05 ] 0 setdash
.45555 .52542 m
.45543 .5254 L
s
.45555 .52542 Mdot
1 .935 0 r
.45535 .52541 Mdot
1 .936 0 r
.45543 .5254 m
.45535 .52541 L
s
.45543 .5254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59208 .52606 m
.59206 .52604 L
s
.55327 .54338 m
.55376 .54029 L
s
.45579 .52583 m
.45572 .52668 L
s
1 .667 0 r
.01 w
[ .05 .05 ] 0 setdash
.58943 .52532 m
.58841 .52515 L
s
.58943 .52532 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45579 .5263 m
.45581 .52598 L
s
.45577 .52579 m
.45574 .52627 L
s
.45582 .52635 m
.45577 .52579 L
s
1 .677 0 r
.01 w
.60007 .52526 Mdot
1 .678 0 r
[ .05 .05 ] 0 setdash
.6018 .52501 m
.60007 .52526 L
s
1 .917 0 r
.6118 .52526 m
.61469 .52493 L
s
.6118 .52526 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59196 .52723 m
.59203 .52633 L
s
.5921 .52644 m
.5922 .52702 L
s
0 0 0 r
.004 w
.41016 .5252 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.44767 .5662 m
.44858 .52518 L
s
1 .941 0 r
.01 w
.44858 .52518 Mdot
[ .05 .05 ] 0 setdash
.44683 .52483 m
.44858 .52518 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5547 .53976 m
.55542 .54531 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.58891 .55209 m
.58841 .52515 L
s
1 .667 0 r
.01 w
[ .05 .05 ] 0 setdash
.58841 .52515 m
.58718 .52495 L
s
.58841 .52515 Mdot
0 0 0 r
.004 w
.63914 .52513 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45576 .52653 m
.45579 .5263 L
s
.45574 .52627 m
.45574 .52656 L
s
.59242 .52757 m
.59248 .52707 L
s
1 .678 0 r
.01 w
.6018 .52501 Mdot
[ .05 .05 ] 0 setdash
.60346 .52477 m
.6018 .52501 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45591 .5276 m
.45582 .52635 L
s
.5922 .52702 m
.59232 .52749 L
s
.45574 .52656 m
.45576 .52653 L
s
1 .666 0 r
.01 w
[ .05 .05 ] 0 setdash
.58718 .52495 m
.58576 .52473 L
s
.58718 .52495 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59103 .52864 m
.59102 .52916 L
s
.59116 .52961 m
.59103 .52864 L
s
1 .916 0 r
.01 w
[ .05 .05 ] 0 setdash
.61469 .52493 m
.61757 .5246 L
s
.61469 .52493 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45572 .52668 m
.45562 .52734 L
s
.45532 .52658 m
.45536 .52854 L
s
.45532 .52704 m
.45532 .52658 L
s
.59185 .52819 m
.59196 .52723 L
s
1 .941 0 r
.01 w
.44683 .52483 Mdot
1 .942 0 r
[ .05 .05 ] 0 setdash
.44506 .52445 m
.44683 .52483 L
s
1 .678 0 r
.60346 .52477 Mdot
.60541 .52443 m
.60346 .52477 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59232 .52749 m
.59242 .52757 L
s
0 0 0 r
.004 w
.64084 .52475 Mdot
1 .666 0 r
.01 w
[ .05 .05 ] 0 setdash
.58576 .52473 m
.58428 .52446 L
s
.58576 .52473 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45539 .52772 m
.45532 .52704 L
s
.59102 .52916 m
.59108 .52984 L
s
0 0 0 r
.004 w
.4075 .52461 Mdot
1 .916 0 r
.01 w
[ .05 .05 ] 0 setdash
.61757 .5246 m
.6206 .52422 L
s
.61757 .5246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59238 .52801 m
.59219 .53112 L
s
.45562 .52734 m
.4555 .52778 L
s
.59143 .53195 m
.59116 .52961 L
s
1 .666 0 r
.01 w
[ .05 .05 ] 0 setdash
.58428 .52446 m
.58264 .52416 L
s
.58428 .52446 Mdot
1 .942 0 r
.44506 .52445 Mdot
.44339 .52407 m
.44506 .52445 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45605 .52904 m
.45591 .5276 L
s
1 .678 0 r
.01 w
.60541 .52443 Mdot
[ .05 .05 ] 0 setdash
.6071 .52414 m
.60541 .52443 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59173 .529 m
.59185 .52819 L
s
0 0 0 r
.004 w
.64254 .52437 Mdot
.53 .8 .95 r
.006 w
.4555 .52778 m
.45539 .52772 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62224 .58324 m
.6206 .52422 L
s
1 .916 0 r
.01 w
[ .05 .05 ] 0 setdash
.6206 .52422 m
.6231 .52398 L
s
.6206 .52422 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59108 .52984 m
.59119 .53016 L
s
1 .666 0 r
.01 w
[ .05 .05 ] 0 setdash
.58264 .52416 m
.58089 .52381 L
s
.58264 .52416 Mdot
1 .678 0 r
.6071 .52414 Mdot
.60858 .52391 m
.6071 .52414 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55265 .54682 m
.55327 .54338 L
s
1 .942 0 r
.01 w
.44339 .52407 Mdot
[ .05 .05 ] 0 setdash
.44188 .5237 m
.44339 .52407 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59159 .52959 m
.59173 .529 L
s
.45536 .52854 m
.4555 .53172 L
s
0 0 0 r
.004 w
.4048 .52399 Mdot
1 .916 0 r
.01 w
[ .05 .05 ] 0 setdash
.6231 .52398 m
.62585 .52367 L
s
.6231 .52398 Mdot
0 0 0 r
.004 w
.64423 .52398 Mdot
1 .678 0 r
.01 w
.60858 .52391 Mdot
1 .679 0 r
.61025 .52361 m
.60858 .52391 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59119 .53016 m
.59131 .53033 L
s
.45644 .53012 m
.45645 .5305 L
s
.45624 .53088 m
.45644 .53012 L
s
.59145 .53003 m
.59159 .52959 L
s
.45621 .53019 m
.45605 .52904 L
s
1 .665 0 r
.01 w
[ .05 .05 ] 0 setdash
.58089 .52381 m
.57913 .52346 L
s
.58089 .52381 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59131 .53033 m
.59145 .53003 L
s
1 .942 0 r
.01 w
.44188 .5237 Mdot
[ .05 .05 ] 0 setdash
.44061 .52339 m
.44188 .5237 L
s
1 .916 0 r
.62585 .52367 m
.62845 .52338 L
s
.62585 .52367 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45577 .53425 m
.45624 .53088 L
s
1 .679 0 r
.01 w
.61025 .52361 Mdot
[ .05 .05 ] 0 setdash
.61158 .52341 m
.61025 .52361 L
s
0 0 0 r
.004 w
.64592 .52359 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45645 .5305 m
.45635 .53068 L
s
1 .665 0 r
.01 w
[ .05 .05 ] 0 setdash
.57913 .52346 m
.57727 .52307 L
s
.57913 .52346 Mdot
1 .679 0 r
.61158 .52341 Mdot
.61266 .52325 m
.61158 .52341 L
s
1 .942 0 r
.44061 .52339 Mdot
.43949 .52308 m
.44061 .52339 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45635 .53068 m
.45621 .53019 L
s
.59182 .53456 m
.59143 .53195 L
s
1 .915 0 r
.01 w
[ .05 .05 ] 0 setdash
.62845 .52338 m
.63113 .52305 L
s
.62845 .52338 Mdot
0 0 0 r
.004 w
.40209 .52335 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61329 .54761 m
.61266 .52325 L
s
1 .679 0 r
.01 w
.61266 .52325 Mdot
[ .05 .05 ] 0 setdash
.61375 .52302 m
.61266 .52325 L
s
1 .948 0 r
.43316 .5232 m
.43316 .52318 L
s
.43316 .5232 Mdot
.43303 .52319 m
.43316 .5232 L
s
.43303 .52319 Mdot
.43272 .52314 m
.43303 .52319 L
s
0 0 0 r
.004 w
.64761 .52318 Mdot
1 .948 0 r
.01 w
.43316 .52318 m
.4331 .52314 L
s
.43316 .52318 Mdot
.4331 .52314 m
.43303 .52308 L
s
.4331 .52314 Mdot
.43272 .52314 Mdot
1 .949 0 r
.43221 .52304 m
.43272 .52314 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43297 .52561 m
.43303 .52308 L
s
1 .947 0 r
.01 w
[ .05 .05 ] 0 setdash
.43303 .52308 m
.43302 .52302 L
s
.43303 .52308 Mdot
1 .942 0 r
.43949 .52308 Mdot
1 .943 0 r
.43863 .52281 m
.43949 .52308 L
s
1 .665 0 r
.57727 .52307 m
.57544 .52266 L
s
.57727 .52307 Mdot
1 .915 0 r
.63113 .52305 m
.63358 .52276 L
s
.63113 .52305 Mdot
1 .949 0 r
.43221 .52304 Mdot
.43148 .52287 m
.43221 .52304 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59219 .53112 m
.59186 .53485 L
s
1 .679 0 r
.01 w
.61375 .52302 Mdot
1 .68 0 r
[ .05 .05 ] 0 setdash
.61457 .52282 m
.61375 .52302 L
s
1 .947 0 r
.43302 .52302 m
.43307 .52294 L
s
.43302 .52302 Mdot
.43307 .52294 m
.43325 .52287 L
s
.43307 .52294 Mdot
.43325 .52287 m
.43354 .52281 L
s
.43325 .52287 Mdot
1 .949 0 r
.43148 .52287 Mdot
.43056 .52263 m
.43148 .52287 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43314 .52392 m
.4331 .52538 L
s
.43297 .52562 m
.43314 .52392 L
s
1 .68 0 r
.01 w
.61457 .52282 Mdot
[ .05 .05 ] 0 setdash
.61515 .52263 m
.61457 .52282 L
s
1 .943 0 r
.43863 .52281 Mdot
.43802 .52259 m
.43863 .52281 L
s
1 .947 0 r
.43354 .52281 m
.43392 .52275 L
s
.43354 .52281 Mdot
0 0 0 r
.004 w
.64929 .52278 Mdot
1 .915 0 r
.01 w
.63358 .52276 m
.636 .52243 L
s
.63358 .52276 Mdot
1 .946 0 r
.43392 .52275 m
.43436 .52269 L
s
.43392 .52275 Mdot
0 0 0 r
.004 w
.39935 .52269 Mdot
1 .946 0 r
.01 w
.43436 .52269 m
.43485 .52263 L
s
.43436 .52269 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55184 .55049 m
.55265 .54682 L
s
1 .665 0 r
.01 w
[ .05 .05 ] 0 setdash
.57544 .52266 m
.5736 .52226 L
s
.57544 .52266 Mdot
1 .68 0 r
.61515 .52263 Mdot
.61553 .52244 m
.61515 .52263 L
s
1 .946 0 r
.43485 .52263 m
.43535 .52258 L
s
.43485 .52263 Mdot
1 .949 0 r
.43056 .52263 Mdot
.42944 .5223 m
.43056 .52263 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4555 .53172 m
.45577 .53557 L
s
1 .943 0 r
.01 w
.43802 .52259 Mdot
[ .05 .05 ] 0 setdash
.43765 .52242 m
.43802 .52259 L
s
1 .946 0 r
.43535 .52258 m
.43588 .52253 L
s
.43535 .52258 Mdot
.43588 .52253 m
.4364 .5225 L
s
.43588 .52253 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43612 .53362 m
.4364 .5225 L
s
1 .945 0 r
.01 w
[ .05 .05 ] 0 setdash
.4364 .5225 m
.43689 .52247 L
s
.4364 .5225 Mdot
.43689 .52247 m
.43731 .52245 L
s
.43689 .52247 Mdot
.43731 .52245 m
.43762 .52242 L
s
.43731 .52245 Mdot
1 .68 0 r
.61553 .52244 Mdot
.61572 .52222 m
.61553 .52244 L
s
1 .915 0 r
.636 .52243 m
.6383 .52209 L
s
.636 .52243 Mdot
1 .945 0 r
.43762 .52242 m
.4378 .52238 L
s
.43762 .52242 Mdot
1 .943 0 r
.43765 .52242 Mdot
.43749 .52231 m
.43765 .52242 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55542 .54531 m
.55643 .55156 L
s
1 .944 0 r
.01 w
[ .05 .05 ] 0 setdash
.4378 .52238 m
.43785 .52234 L
s
.4378 .52238 Mdot
0 0 0 r
.004 w
.65097 .52237 Mdot
1 .944 0 r
.01 w
.43785 .52234 m
.43782 .52229 L
s
.43785 .52234 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43745 .52416 m
.43749 .52231 L
s
1 .943 0 r
.01 w
.43749 .52231 Mdot
[ .05 .05 ] 0 setdash
.43749 .52225 m
.43749 .52231 L
s
1 .949 0 r
.42944 .5223 Mdot
.428 .52181 m
.42944 .5223 L
s
1 .944 0 r
.43782 .52229 m
.43772 .52226 L
s
.43782 .52229 Mdot
1 .665 0 r
.5736 .52226 m
.57172 .52182 L
s
.5736 .52226 Mdot
1 .944 0 r
.43772 .52226 m
.43759 .52224 L
s
.43772 .52226 Mdot
1 .943 0 r
.43749 .52225 Mdot
1 .944 0 r
.43759 .52224 m
.43749 .52225 L
s
.43759 .52224 Mdot
1 .68 0 r
.61572 .52222 Mdot
.61577 .52194 m
.61572 .52222 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4331 .52538 m
.43302 .5261 L
s
1 .914 0 r
.01 w
[ .05 .05 ] 0 setdash
.6383 .52209 m
.64038 .52178 L
s
.6383 .52209 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.455 .53948 m
.45577 .53425 L
s
.59238 .53768 m
.59182 .53456 L
s
0 0 0 r
.004 w
.39658 .52201 Mdot
.53 .8 .95 r
.006 w
.43254 .52986 m
.43297 .52562 L
s
0 0 0 r
.004 w
.65264 .52195 Mdot
1 .68 0 r
.01 w
.61577 .52194 Mdot
1 .681 0 r
[ .05 .05 ] 0 setdash
.61574 .52157 m
.61577 .52194 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43295 .52537 m
.43298 .52662 L
s
.43297 .52561 m
.43295 .52537 L
s
.43302 .5261 m
.43297 .52561 L
s
.43783 .52338 m
.43776 .52444 L
s
.43773 .52517 m
.43783 .52338 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.5723 .56403 m
.57172 .52182 L
s
1 .664 0 r
.01 w
[ .05 .05 ] 0 setdash
.57172 .52182 m
.56987 .5214 L
s
.57172 .52182 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.427 .55777 m
.428 .52181 L
s
1 .949 0 r
.01 w
.428 .52181 Mdot
1 .95 0 r
[ .05 .05 ] 0 setdash
.42642 .52124 m
.428 .52181 L
s
1 .914 0 r
.64038 .52178 m
.64233 .52143 L
s
.64038 .52178 Mdot
1 .681 0 r
.61574 .52157 Mdot
.61568 .52109 m
.61574 .52157 L
s
0 0 0 r
.004 w
.65431 .52153 Mdot
1 .914 0 r
.01 w
.64233 .52143 m
.64396 .52113 L
s
.64233 .52143 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43745 .52416 m
.43752 .52752 L
s
.43744 .5243 m
.43745 .52416 L
s
1 .664 0 r
.01 w
[ .05 .05 ] 0 setdash
.56987 .5214 m
.56798 .52093 L
s
.56987 .5214 Mdot
0 0 0 r
.004 w
.39378 .5213 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43751 .52544 m
.43744 .5243 L
s
.43776 .52444 m
.43764 .52537 L
s
1 .95 0 r
.01 w
.42642 .52124 Mdot
[ .05 .05 ] 0 setdash
.42454 .52049 m
.42642 .52124 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55084 .55458 m
.55184 .55049 L
s
.43298 .52662 m
.43309 .52862 L
s
.59186 .53485 m
.59137 .53904 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.64514 .55521 m
.64396 .52113 L
s
1 .914 0 r
.01 w
[ .05 .05 ] 0 setdash
.64396 .52113 m
.64545 .52083 L
s
.64396 .52113 Mdot
0 0 0 r
.004 w
.65598 .5211 Mdot
1 .681 0 r
.01 w
.61568 .52109 Mdot
.61562 .52051 m
.61568 .52109 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43749 .52771 m
.43773 .52517 L
s
.45577 .53557 m
.4562 .53976 L
s
1 .664 0 r
.01 w
[ .05 .05 ] 0 setdash
.56798 .52093 m
.56607 .52045 L
s
.56798 .52093 Mdot
1 .914 0 r
.64545 .52083 m
.6467 .52056 L
s
.64545 .52083 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43764 .52537 m
.43751 .52544 L
s
0 0 0 r
.004 w
.65764 .52067 Mdot
.39096 .52057 Mdot
1 .913 0 r
.01 w
[ .05 .05 ] 0 setdash
.6467 .52056 m
.64771 .52033 L
s
.6467 .52056 Mdot
1 .681 0 r
.61562 .52051 Mdot
.61561 .51983 m
.61562 .52051 L
s
1 .95 0 r
.42454 .52049 Mdot
.42258 .5197 m
.42454 .52049 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59309 .54082 m
.59238 .53768 L
s
1 .664 0 r
.01 w
[ .05 .05 ] 0 setdash
.56607 .52045 m
.56412 .51993 L
s
.56607 .52045 Mdot
1 .913 0 r
.64771 .52033 m
.6485 .52013 L
s
.64771 .52033 Mdot
0 0 0 r
.004 w
.6593 .52023 Mdot
1 .913 0 r
.01 w
.6485 .52013 m
.64909 .51997 L
s
.6485 .52013 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43309 .52862 m
.43334 .53058 L
s
1 .913 0 r
.01 w
[ .05 .05 ] 0 setdash
.64909 .51997 m
.64948 .51984 L
s
.64909 .51997 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43752 .52752 m
.43777 .53257 L
s
1 .664 0 r
.01 w
[ .05 .05 ] 0 setdash
.56412 .51993 m
.5622 .51938 L
s
.56412 .51993 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43189 .53492 m
.43254 .52986 L
s
.43712 .53003 m
.43749 .52771 L
s
1 .913 0 r
.01 w
[ .05 .05 ] 0 setdash
.64948 .51984 m
.6497 .51975 L
s
.64948 .51984 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61643 .55051 m
.61561 .51983 L
s
1 .681 0 r
.01 w
.61561 .51983 Mdot
[ .05 .05 ] 0 setdash
.61561 .51891 m
.61561 .51983 L
s
0 0 0 r
.004 w
.38811 .5198 Mdot
.66095 .51979 Mdot
1 .912 0 r
.01 w
.6497 .51975 m
.64981 .51969 L
s
.6497 .51975 Mdot
1 .95 0 r
.42258 .5197 Mdot
.42043 .51875 m
.42258 .5197 L
s
1 .912 0 r
.64981 .51969 m
.64986 .51964 L
s
.64981 .51969 Mdot
.64986 .51964 m
.64986 .51962 L
s
.64986 .51964 Mdot
1 .911 0 r
.64956 .51964 m
.64953 .51963 L
s
.64956 .51964 Mdot
.64962 .51963 m
.64956 .51964 L
s
.64953 .51963 m
.64955 .51962 L
s
.64953 .51963 Mdot
.64962 .51963 Mdot
.6497 .51962 m
.64962 .51963 L
s
1 .91 0 r
.64955 .51962 m
.6496 .5196 L
s
.64955 .51962 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6499 .5208 m
.64986 .51962 L
s
1 .912 0 r
.01 w
[ .05 .05 ] 0 setdash
.64986 .51962 m
.64983 .5196 L
s
.64986 .51962 Mdot
1 .911 0 r
.6497 .51962 Mdot
.64977 .5196 m
.6497 .51962 L
s
.64977 .5196 Mdot
1 .912 0 r
.64983 .5196 m
.64977 .5196 L
s
.64983 .5196 Mdot
1 .91 0 r
.6496 .5196 m
.6497 .51957 L
s
.6496 .5196 Mdot
.6497 .51957 m
.64982 .51953 L
s
.6497 .51957 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45396 .54566 m
.455 .53948 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.64992 .52229 m
.64982 .51953 L
s
1 .91 0 r
.01 w
[ .05 .05 ] 0 setdash
.64982 .51953 m
.64996 .51949 L
s
.64982 .51953 Mdot
1 .909 0 r
.64996 .51949 m
.65004 .51946 L
s
.64996 .51949 Mdot
.65004 .51946 m
.65007 .51944 L
s
.65004 .51946 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61569 .52855 m
.61539 .53168 L
s
.61588 .52842 m
.61569 .52855 L
s
.54963 .55925 m
.55084 .55458 L
s
1 .909 0 r
.01 w
[ .05 .05 ] 0 setdash
.65007 .51944 m
.65005 .51941 L
s
.65007 .51944 Mdot
.65005 .51941 m
.64998 .51938 L
s
.65005 .51941 Mdot
1 .663 0 r
.5622 .51938 m
.56021 .5188 L
s
.5622 .51938 Mdot
1 .909 0 r
.64998 .51938 m
.64987 .51933 L
s
.64998 .51938 Mdot
0 0 0 r
.004 w
.6626 .51934 Mdot
1 .908 0 r
.01 w
.64987 .51933 m
.64975 .51926 L
s
.64987 .51933 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64958 .52028 m
.64957 .52066 L
s
.64965 .52032 m
.64958 .52028 L
s
.55643 .55156 m
.55776 .55831 L
s
.64989 .52037 m
.6499 .5208 L
s
.64987 .5213 m
.64989 .52037 L
s
.64975 .52099 m
.64965 .52032 L
s
1 .908 0 r
.01 w
[ .05 .05 ] 0 setdash
.64975 .51926 m
.64961 .51918 L
s
.64975 .51926 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61601 .53098 m
.61588 .52842 L
s
1 .908 0 r
.01 w
[ .05 .05 ] 0 setdash
.64961 .51918 m
.64945 .51907 L
s
.64961 .51918 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64957 .52066 m
.6496 .52086 L
s
.4562 .53976 m
.4568 .54407 L
s
1 .895 0 r
.01 w
[ .05 .05 ] 0 setdash
.64848 .51912 m
.64942 .51911 L
s
.64848 .51912 Mdot
1 .896 0 r
.64772 .51905 m
.64848 .51912 L
s
1 .895 0 r
.64942 .51911 m
.65056 .51901 L
s
.64942 .51911 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6501 .52015 m
.65008 .52017 L
s
.6501 .52103 m
.6501 .52015 L
s
1 .908 0 r
.01 w
[ .05 .05 ] 0 setdash
.64945 .51907 m
.64925 .51896 L
s
.64945 .51907 Mdot
1 .896 0 r
.64772 .51905 Mdot
.64715 .51894 m
.64772 .51905 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65008 .52017 m
.65005 .52118 L
s
.6499 .5208 m
.6499 .5216 L
s
.43334 .53058 m
.43367 .53245 L
s
0 0 0 r
.004 w
.38522 .51902 Mdot
.53 .8 .95 r
.006 w
.6496 .52086 m
.64968 .52171 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6515 .54453 m
.65056 .51901 L
s
1 .895 0 r
.01 w
[ .05 .05 ] 0 setdash
.65056 .51901 m
.65187 .51881 L
s
.65056 .51901 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59137 .53904 m
.5907 .54343 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6495 .52571 m
.64925 .51896 L
s
1 .908 0 r
.01 w
[ .05 .05 ] 0 setdash
.64925 .51896 m
.64904 .51885 L
s
.64925 .51896 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64984 .52139 m
.64975 .52099 L
s
1 .896 0 r
.01 w
.64715 .51894 Mdot
[ .05 .05 ] 0 setdash
.64678 .51882 m
.64715 .51894 L
s
1 .681 0 r
.61561 .51891 Mdot
1 .682 0 r
.61565 .5179 m
.61561 .51891 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64984 .52361 m
.64987 .5213 L
s
0 0 0 r
.004 w
.66425 .51888 Mdot
1 .907 0 r
.01 w
[ .05 .05 ] 0 setdash
.64904 .51885 m
.64882 .51874 L
s
.64904 .51885 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59394 .54394 m
.59309 .54082 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.64826 .52384 m
.64808 .51882 L
s
1 .899 0 r
.01 w
[ .05 .05 ] 0 setdash
.64808 .51882 m
.64824 .51881 L
s
.64808 .51882 Mdot
.64791 .51882 m
.64808 .51882 L
s
.64791 .51882 Mdot
1 .9 0 r
.64774 .5188 m
.64791 .51882 L
s
1 .896 0 r
.64678 .51882 Mdot
.64659 .5187 m
.64678 .51882 L
s
1 .899 0 r
.64824 .51881 m
.64838 .51878 L
s
.64824 .51881 Mdot
1 .895 0 r
.65187 .51881 m
.65334 .51849 L
s
.65187 .51881 Mdot
1 .663 0 r
.56021 .5188 m
.55831 .51821 L
s
.56021 .5188 Mdot
1 .9 0 r
.64774 .5188 Mdot
.64759 .51877 m
.64774 .5188 L
s
1 .899 0 r
.64838 .51878 m
.64847 .51872 L
s
.64838 .51878 Mdot
1 .9 0 r
.64759 .51877 Mdot
.64748 .51872 m
.64759 .51877 L
s
1 .95 0 r
.42043 .51875 Mdot
1 .951 0 r
.41811 .5177 m
.42043 .51875 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43664 .53202 m
.43712 .53003 L
s
1 .907 0 r
.01 w
[ .05 .05 ] 0 setdash
.64882 .51874 m
.64857 .51862 L
s
.64882 .51874 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6499 .5216 m
.64984 .52139 L
s
1 .899 0 r
.01 w
[ .05 .05 ] 0 setdash
.64847 .51872 m
.64846 .51866 L
s
.64847 .51872 Mdot
1 .9 0 r
.64748 .51872 Mdot
.64739 .51866 m
.64748 .51872 L
s
1 .896 0 r
.64659 .5187 Mdot
.64653 .51862 m
.64659 .5187 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65003 .5215 m
.6501 .52103 L
s
1 .9 0 r
.01 w
.64739 .51866 Mdot
[ .05 .05 ] 0 setdash
.64728 .5186 m
.64739 .51866 L
s
1 .898 0 r
.64846 .51866 m
.64835 .51858 L
s
.64846 .51866 Mdot
1 .896 0 r
.64653 .51862 Mdot
1 .897 0 r
.64657 .51852 m
.64653 .51862 L
s
1 .907 0 r
.64857 .51862 m
.64829 .51852 L
s
.64857 .51862 Mdot
1 .9 0 r
.64728 .5186 Mdot
1 .901 0 r
.64716 .51854 m
.64728 .5186 L
s
1 .898 0 r
.64835 .51858 m
.64815 .51851 L
s
.64835 .51858 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64968 .52171 m
.64979 .52223 L
s
1 .901 0 r
.01 w
.64716 .51854 Mdot
[ .05 .05 ] 0 setdash
.64705 .51849 m
.64716 .51854 L
s
1 .907 0 r
.64829 .51852 m
.64804 .51844 L
s
.64829 .51852 Mdot
1 .897 0 r
.64657 .51852 Mdot
.64668 .51843 m
.64657 .51852 L
s
1 .898 0 r
.64815 .51851 m
.64784 .51844 L
s
.64815 .51851 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64992 .52229 m
.65003 .5215 L
s
.65005 .52118 m
.64998 .52217 L
s
1 .895 0 r
.01 w
[ .05 .05 ] 0 setdash
.65334 .51849 m
.65499 .51804 L
s
.65334 .51849 Mdot
1 .901 0 r
.64705 .51849 Mdot
.64696 .51843 m
.64705 .51849 L
s
1 .898 0 r
.64784 .51844 m
.64748 .51839 L
s
.64784 .51844 Mdot
1 .907 0 r
.64804 .51844 m
.64782 .51837 L
s
.64804 .51844 Mdot
1 .897 0 r
.64668 .51843 Mdot
.64687 .51838 m
.64668 .51843 L
s
1 .901 0 r
.64696 .51843 Mdot
.64688 .51837 m
.64696 .51843 L
s
0 0 0 r
.004 w
.66589 .51842 Mdot
1 .898 0 r
.01 w
.64748 .51839 m
.64713 .51837 L
s
.64748 .51839 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6471 .52489 m
.64687 .51838 L
s
1 .897 0 r
.01 w
.64687 .51838 Mdot
[ .05 .05 ] 0 setdash
.64713 .51837 m
.64687 .51838 L
s
1 .906 0 r
.64782 .51837 m
.64766 .51832 L
s
.64782 .51837 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64698 .52118 m
.64688 .51837 L
s
1 .901 0 r
.01 w
.64688 .51837 Mdot
[ .05 .05 ] 0 setdash
.6468 .51831 m
.64688 .51837 L
s
1 .897 0 r
.64713 .51837 Mdot
1 .906 0 r
.64766 .51832 m
.64752 .51828 L
s
.64766 .51832 Mdot
1 .901 0 r
.6468 .51831 Mdot
1 .902 0 r
.64673 .51823 m
.6468 .51831 L
s
1 .906 0 r
.64752 .51828 m
.64741 .51825 L
s
.64752 .51828 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64979 .52223 m
.64992 .52229 L
s
1 .906 0 r
.01 w
[ .05 .05 ] 0 setdash
.64741 .51825 m
.64734 .51822 L
s
.64741 .51825 Mdot
1 .902 0 r
.64673 .51823 Mdot
.64666 .51817 m
.64673 .51823 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64742 .52043 m
.64734 .51822 L
s
1 .905 0 r
.01 w
[ .05 .05 ] 0 setdash
.64734 .51822 m
.64725 .51821 L
s
.64734 .51822 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61539 .53168 m
.61493 .5364 L
s
1 .905 0 r
.01 w
[ .05 .05 ] 0 setdash
.64725 .51821 m
.64714 .5182 L
s
.64725 .51821 Mdot
1 .663 0 r
.55831 .51821 m
.55636 .51761 L
s
.55831 .51821 Mdot
1 .905 0 r
.64714 .5182 m
.64702 .5182 L
s
.64714 .5182 Mdot
.64702 .5182 m
.64691 .51819 L
s
.64702 .5182 Mdot
0 0 0 r
.004 w
.3823 .5182 Mdot
1 .905 0 r
.01 w
.64691 .51819 m
.64679 .51816 L
s
.64691 .51819 Mdot
1 .902 0 r
.64666 .51817 Mdot
.64656 .5181 m
.64666 .51817 L
s
1 .904 0 r
.64679 .51816 m
.64669 .51812 L
s
.64679 .51816 Mdot
.64669 .51812 m
.64659 .51808 L
s
.64669 .51812 Mdot
1 .902 0 r
.64656 .5181 Mdot
.64644 .51804 m
.64656 .5181 L
s
1 .904 0 r
.64659 .51808 m
.64651 .51803 L
s
.64659 .51808 Mdot
1 .894 0 r
.65499 .51804 m
.65681 .51745 L
s
.65499 .51804 Mdot
1 .902 0 r
.64644 .51804 Mdot
1 .903 0 r
.64634 .51799 m
.64644 .51804 L
s
1 .904 0 r
.64651 .51803 m
.64642 .51799 L
s
.64651 .51803 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43367 .53245 m
.43408 .53369 L
s
1 .903 0 r
.01 w
.64634 .51799 Mdot
[ .05 .05 ] 0 setdash
.64628 .51796 m
.64634 .51799 L
s
1 .904 0 r
.64642 .51799 m
.64633 .51796 L
s
.64642 .51799 Mdot
1 .903 0 r
.64628 .51796 Mdot
.64626 .51795 m
.64628 .51796 L
s
0 0 0 r
.004 w
.66753 .51796 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6464 .52001 m
.64633 .51796 L
s
1 .903 0 r
.01 w
[ .05 .05 ] 0 setdash
.64633 .51796 m
.64627 .51795 L
s
.64633 .51796 Mdot
.64626 .51795 Mdot
.64627 .51795 m
.64626 .51795 L
s
.64627 .51795 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64998 .52217 m
.6499 .52323 L
s
1 .682 0 r
.01 w
.61565 .5179 Mdot
[ .05 .05 ] 0 setdash
.61578 .51683 m
.61565 .5179 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64973 .5268 m
.64984 .52361 L
s
.43612 .53362 m
.43664 .53202 L
s
.43777 .53257 m
.43823 .53859 L
s
1 .951 0 r
.01 w
.41811 .5177 Mdot
[ .05 .05 ] 0 setdash
.41583 .51664 m
.41811 .5177 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64628 .51856 m
.64632 .51906 L
s
.64631 .51909 m
.64628 .51856 L
s
1 .663 0 r
.01 w
[ .05 .05 ] 0 setdash
.55636 .51761 m
.55443 .51701 L
s
.55636 .51761 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61609 .53486 m
.61601 .53098 L
s
.64736 .52079 m
.64748 .52103 L
s
.64723 .52067 m
.64736 .52079 L
s
.5482 .56394 m
.54963 .55925 L
s
.64748 .52103 m
.64758 .5215 L
s
.64714 .52086 m
.64723 .52067 L
s
0 0 0 r
.004 w
.66917 .51749 Mdot
.53 .8 .95 r
.006 w
.64856 .52131 m
.64857 .52181 L
s
.6485 .522 m
.64856 .52131 L
s
1 .894 0 r
.01 w
[ .05 .05 ] 0 setdash
.65681 .51745 m
.65882 .51673 L
s
.65681 .51745 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64632 .51906 m
.64645 .52082 L
s
.6464 .52001 m
.64631 .51909 L
s
.64748 .52004 m
.64742 .52043 L
s
.6476 .52061 m
.64748 .52004 L
s
.64758 .5215 m
.6477 .52192 L
s
0 0 0 r
.004 w
.37935 .51735 Mdot
.53 .8 .95 r
.006 w
.43408 .53369 m
.43454 .53446 L
s
.64705 .5209 m
.64714 .52086 L
s
.6499 .52323 m
.64979 .5242 L
s
.4568 .54407 m
.45758 .54854 L
s
.43101 .54047 m
.43189 .53492 L
s
.6477 .52192 m
.64787 .52243 L
s
.59494 .54708 m
.59394 .54394 L
s
.64698 .52118 m
.64705 .5209 L
s
.64732 .52025 m
.64722 .52041 L
s
.64742 .52043 m
.64732 .52025 L
s
.64841 .52349 m
.6485 .522 L
s
.64777 .52143 m
.6476 .52061 L
s
.6471 .52038 m
.64701 .52099 L
s
.64722 .52041 m
.6471 .52038 L
s
.64857 .52181 m
.64854 .52367 L
s
.43557 .5345 m
.43612 .53362 L
s
.64787 .52243 m
.64806 .52306 L
s
0 0 0 r
.004 w
.6708 .51701 Mdot
1 .663 0 r
.01 w
[ .05 .05 ] 0 setdash
.55443 .51701 m
.55251 .51638 L
s
.55443 .51701 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64692 .52162 m
.64698 .52118 L
s
.64688 .52062 m
.64678 .52063 L
s
.64701 .52099 m
.64688 .52062 L
s
.64652 .5209 m
.6464 .52001 L
s
.64678 .52063 m
.64668 .52061 L
s
.43454 .53446 m
.43503 .53495 L
s
.64668 .52061 m
.64661 .52104 L
s
1 .682 0 r
.01 w
.61578 .51683 Mdot
[ .05 .05 ] 0 setdash
.616 .51572 m
.61578 .51683 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64797 .52255 m
.64777 .52143 L
s
.64806 .52306 m
.64826 .52384 L
s
1 .894 0 r
.01 w
[ .05 .05 ] 0 setdash
.65882 .51673 m
.66091 .51593 L
s
.65882 .51673 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64979 .5242 m
.64968 .52546 L
s
.5907 .54343 m
.58985 .54777 L
s
.43503 .53495 m
.43557 .5345 L
s
.64687 .52218 m
.64692 .52162 L
s
1 .951 0 r
.01 w
.41583 .51664 Mdot
[ .05 .05 ] 0 setdash
.4135 .51548 m
.41583 .51664 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64645 .52082 m
.64658 .52188 L
s
.64661 .52104 m
.64652 .5209 L
s
0 0 0 r
.004 w
.67243 .51653 Mdot
.53 .8 .95 r
.006 w
.64826 .52384 m
.64841 .52349 L
s
0 0 0 r
.004 w
.37636 .51647 Mdot
.53 .8 .95 r
.006 w
.45266 .55183 m
.45396 .54566 L
s
.64947 .53051 m
.64973 .5268 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.55289 .56268 m
.55251 .51638 L
s
1 .662 0 r
.01 w
[ .05 .05 ] 0 setdash
.55251 .51638 m
.5506 .51579 L
s
.55251 .51638 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64823 .52389 m
.64797 .52255 L
s
.6468 .52215 m
.64687 .52218 L
s
.6467 .52201 m
.6468 .52215 L
s
.61493 .5364 m
.61424 .54189 L
s
.64658 .52188 m
.6467 .52201 L
s
.64674 .52345 m
.64673 .52439 L
s
.64686 .5237 m
.64674 .52345 L
s
.64854 .52367 m
.64842 .52604 L
s
0 0 0 r
.004 w
.67406 .51604 Mdot
.53 .8 .95 r
.006 w
.64968 .52546 m
.6495 .52571 L
s
1 .894 0 r
.01 w
[ .05 .05 ] 0 setdash
.66091 .51593 m
.6634 .51498 L
s
.66091 .51593 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55776 .55831 m
.55933 .56515 L
s
.6471 .52489 m
.64686 .5237 L
s
.64673 .52439 m
.64685 .52605 L
s
1 .662 0 r
.01 w
[ .05 .05 ] 0 setdash
.5506 .51579 m
.54873 .51518 L
s
.5506 .51579 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64853 .52505 m
.64823 .52389 L
s
1 .682 0 r
.01 w
.616 .51572 Mdot
[ .05 .05 ] 0 setdash
.61619 .51433 m
.616 .51572 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6495 .52571 m
.6493 .52601 L
s
.59613 .54996 m
.59494 .54708 L
s
.54655 .56878 m
.5482 .56394 L
s
0 0 0 r
.004 w
.37334 .51555 Mdot
.67568 .51555 Mdot
1 .951 0 r
.01 w
.4135 .51548 Mdot
[ .05 .05 ] 0 setdash
.41123 .51428 m
.4135 .51548 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45758 .54854 m
.45853 .5533 L
s
.6493 .52601 m
.6491 .5264 L
s
.64884 .52595 m
.64853 .52505 L
s
.6474 .526 m
.6471 .52489 L
s
1 .662 0 r
.01 w
[ .05 .05 ] 0 setdash
.54873 .51518 m
.54689 .51456 L
s
.54873 .51518 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43823 .53859 m
.43894 .54518 L
s
.64685 .52605 m
.64714 .52877 L
s
.61617 .53969 m
.61609 .53486 L
s
0 0 0 r
.004 w
.67729 .51505 Mdot
.53 .8 .95 r
.006 w
.6491 .5264 m
.64884 .52595 L
s
1 .894 0 r
.01 w
[ .05 .05 ] 0 setdash
.6634 .51498 m
.66572 .51406 L
s
.6634 .51498 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64842 .52604 m
.64815 .5271 L
s
.64904 .53509 m
.64947 .53051 L
s
.64779 .52702 m
.6474 .526 L
s
0 0 0 r
.004 w
.37027 .5146 Mdot
1 .662 0 r
.01 w
[ .05 .05 ] 0 setdash
.54689 .51456 m
.54508 .51393 L
s
.54689 .51456 Mdot
0 0 0 r
.004 w
.67891 .51455 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58985 .54777 m
.58891 .55209 L
s
1 .682 0 r
.01 w
.61619 .51433 Mdot
[ .05 .05 ] 0 setdash
.6164 .51291 m
.61619 .51433 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42992 .5462 m
.43101 .54047 L
s
1 .951 0 r
.01 w
.41123 .51428 Mdot
[ .05 .05 ] 0 setdash
.40913 .51314 m
.41123 .51428 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64815 .5271 m
.64779 .52702 L
s
1 .893 0 r
.01 w
[ .05 .05 ] 0 setdash
.66572 .51406 m
.66834 .51304 L
s
.66572 .51406 Mdot
0 0 0 r
.004 w
.68052 .51404 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59758 .55345 m
.59613 .54996 L
s
.64714 .52877 m
.64761 .53178 L
s
1 .661 0 r
.01 w
[ .05 .05 ] 0 setdash
.54508 .51393 m
.54334 .51331 L
s
.54508 .51393 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61424 .54189 m
.61329 .54761 L
s
0 0 0 r
.004 w
.36716 .51362 Mdot
.53 .8 .95 r
.006 w
.54467 .57361 m
.54655 .56878 L
s
0 0 0 r
.004 w
.68213 .51352 Mdot
.53 .8 .95 r
.006 w
.45853 .5533 m
.45969 .55747 L
s
1 .661 0 r
.01 w
[ .05 .05 ] 0 setdash
.54334 .51331 m
.54167 .51267 L
s
.54334 .51331 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45118 .55794 m
.45266 .55183 L
s
1 .951 0 r
.01 w
.40913 .51314 Mdot
1 .952 0 r
[ .05 .05 ] 0 setdash
.40733 .51217 m
.40913 .51314 L
s
1 .893 0 r
.66834 .51304 m
.67134 .51191 L
s
.66834 .51304 Mdot
0 0 0 r
.004 w
.68373 .513 Mdot
1 .682 0 r
.01 w
.6164 .51291 Mdot
1 .683 0 r
.61668 .51157 m
.6164 .51291 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64842 .54006 m
.64904 .53509 L
s
1 .661 0 r
.01 w
[ .05 .05 ] 0 setdash
.54167 .51267 m
.53999 .51205 L
s
.54167 .51267 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64761 .53178 m
.64831 .53535 L
s
0 0 0 r
.004 w
.36401 .51259 Mdot
.68533 .51248 Mdot
.53 .8 .95 r
.006 w
.55933 .56515 m
.5611 .57219 L
s
.43894 .54518 m
.43992 .55198 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.40536 .56964 m
.40733 .51217 L
s
1 .952 0 r
.01 w
.40733 .51217 Mdot
[ .05 .05 ] 0 setdash
.40566 .51122 m
.40733 .51217 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59915 .5571 m
.59758 .55345 L
s
1 .661 0 r
.01 w
[ .05 .05 ] 0 setdash
.53999 .51205 m
.53839 .51138 L
s
.53999 .51205 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58891 .55209 m
.58774 .5555 L
s
.61628 .54508 m
.61617 .53969 L
s
0 0 0 r
.004 w
.68692 .51194 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67441 .58384 m
.67134 .51191 L
s
1 .893 0 r
.01 w
[ .05 .05 ] 0 setdash
.67134 .51191 m
.6739 .51089 L
s
.67134 .51191 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45969 .55747 m
.46107 .56219 L
s
.54258 .57882 m
.54467 .57361 L
s
1 .683 0 r
.01 w
.61668 .51157 Mdot
[ .05 .05 ] 0 setdash
.61697 .51012 m
.61668 .51157 L
s
0 0 0 r
.004 w
.3608 .51152 Mdot
.68852 .51141 Mdot
1 .661 0 r
.01 w
.53839 .51138 m
.53678 .51073 L
s
.53839 .51138 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61329 .54761 m
.61232 .5524 L
s
1 .952 0 r
.01 w
.40566 .51122 Mdot
[ .05 .05 ] 0 setdash
.40392 .51019 m
.40566 .51122 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42862 .55202 m
.42992 .5462 L
s
.64831 .53535 m
.64917 .53827 L
s
1 .893 0 r
.01 w
[ .05 .05 ] 0 setdash
.6739 .51089 m
.67674 .5098 L
s
.6739 .51089 Mdot
0 0 0 r
.004 w
.69011 .51086 Mdot
1 .66 0 r
.01 w
.53678 .51073 m
.53512 .51005 L
s
.53678 .51073 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64757 .5451 m
.64842 .54006 L
s
0 0 0 r
.004 w
.35755 .5104 Mdot
.69169 .51032 Mdot
1 .952 0 r
.01 w
.40392 .51019 Mdot
[ .05 .05 ] 0 setdash
.40224 .5092 m
.40392 .51019 L
s
1 .683 0 r
.61697 .51012 Mdot
.61737 .50873 m
.61697 .51012 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58774 .5555 m
.58637 .55893 L
s
.60083 .55991 m
.59915 .5571 L
s
.4495 .56308 m
.45118 .55794 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.53525 .55131 m
.53512 .51005 L
s
1 .66 0 r
.01 w
[ .05 .05 ] 0 setdash
.53512 .51005 m
.53349 .50939 L
s
.53512 .51005 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46107 .56219 m
.46265 .56647 L
s
1 .966 0 r
.01 w
[ .05 .05 ] 0 setdash
.37191 .50984 m
.37203 .50982 L
s
.37191 .50984 Mdot
.37177 .50982 m
.37191 .50984 L
s
.37203 .50982 m
.37214 .50977 L
s
.37203 .50982 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37167 .51198 m
.37177 .50982 L
s
1 .966 0 r
.01 w
.37177 .50982 Mdot
[ .05 .05 ] 0 setdash
.37161 .50974 m
.37177 .50982 L
s
1 .892 0 r
.67674 .5098 m
.67963 .5087 L
s
.67674 .5098 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51425 .58322 m
.51682 .58395 L
s
.51177 .58321 m
.51425 .58322 L
s
1 .966 0 r
.01 w
[ .05 .05 ] 0 setdash
.37214 .50977 m
.37226 .5097 L
s
.37214 .50977 Mdot
0 0 0 r
.004 w
.69327 .50976 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64917 .53827 m
.65023 .5413 L
s
1 .966 0 r
.01 w
.37161 .50974 Mdot
1 .967 0 r
[ .05 .05 ] 0 setdash
.37144 .50961 m
.37161 .50974 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50928 .58452 m
.51177 .58321 L
s
1 .965 0 r
.01 w
[ .05 .05 ] 0 setdash
.37226 .5097 m
.37238 .50963 L
s
.37226 .5097 Mdot
.37238 .50963 m
.3725 .50955 L
s
.37238 .50963 Mdot
1 .967 0 r
.37144 .50961 Mdot
.37125 .50943 m
.37144 .50961 L
s
1 .965 0 r
.3725 .50955 m
.37262 .50948 L
s
.3725 .50955 Mdot
.37262 .50948 m
.37274 .50941 L
s
.37262 .50948 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43992 .55198 m
.44105 .55822 L
s
.5403 .5833 m
.54258 .57882 L
s
1 .967 0 r
.01 w
.37125 .50943 Mdot
[ .05 .05 ] 0 setdash
.37104 .50921 m
.37125 .50943 L
s
1 .965 0 r
.37274 .50941 m
.37283 .50937 L
s
.37274 .50941 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51682 .58395 m
.51928 .58563 L
s
1 .66 0 r
.01 w
[ .05 .05 ] 0 setdash
.53349 .50939 m
.53188 .50871 L
s
.53349 .50939 Mdot
1 .964 0 r
.37283 .50937 m
.3729 .50934 L
s
.37283 .50937 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37283 .51086 m
.3729 .50934 L
s
1 .964 0 r
.01 w
[ .05 .05 ] 0 setdash
.3729 .50934 m
.37295 .50932 L
s
.3729 .50934 Mdot
.37295 .50932 m
.37297 .50931 L
s
.37295 .50932 Mdot
.37297 .50931 m
.37298 .5093 L
s
.37297 .50931 Mdot
.37298 .5093 m
.37299 .5093 L
s
.37298 .5093 Mdot
1 .963 0 r
.37299 .5093 m
.37305 .50929 L
s
.37299 .5093 Mdot
.37305 .50929 m
.37317 .50927 L
s
.37305 .50929 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61232 .5524 m
.61108 .55704 L
s
1 .963 0 r
.01 w
[ .05 .05 ] 0 setdash
.37317 .50927 m
.37337 .50924 L
s
.37317 .50927 Mdot
.37337 .50924 m
.37367 .50921 L
s
.37337 .50924 Mdot
0 0 0 r
.004 w
.35424 .50924 Mdot
1 .967 0 r
.01 w
.37104 .50921 Mdot
.37081 .50896 m
.37104 .50921 L
s
1 .962 0 r
.37367 .50921 m
.37406 .50918 L
s
.37367 .50921 Mdot
1 .952 0 r
.40224 .5092 Mdot
.40071 .50838 m
.40224 .5092 L
s
0 0 0 r
.004 w
.69485 .5092 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37296 .50955 m
.37295 .50987 L
s
.37292 .50983 m
.37296 .50955 L
s
1 .962 0 r
.01 w
[ .05 .05 ] 0 setdash
.37406 .50918 m
.37455 .50915 L
s
.37406 .50918 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37406 .52034 m
.37455 .50915 L
s
1 .962 0 r
.01 w
[ .05 .05 ] 0 setdash
.37455 .50915 m
.37509 .50915 L
s
.37455 .50915 Mdot
.37509 .50915 m
.37568 .50913 L
s
.37509 .50915 Mdot
1 .961 0 r
.37629 .50913 m
.3769 .50913 L
s
.37629 .50913 Mdot
1 .962 0 r
.37568 .50913 m
.37629 .50913 L
s
.37568 .50913 Mdot
1 .961 0 r
.3769 .50913 m
.37749 .50911 L
s
.3769 .50913 Mdot
.37749 .50911 m
.37808 .50908 L
s
.37749 .50911 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37298 .50972 m
.37301 .51017 L
s
.37295 .50987 m
.37298 .50972 L
s
1 .961 0 r
.01 w
[ .05 .05 ] 0 setdash
.37808 .50908 m
.37861 .50903 L
s
.37808 .50908 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37283 .51086 m
.37292 .50983 L
s
1 .961 0 r
.01 w
[ .05 .05 ] 0 setdash
.37861 .50903 m
.37913 .50896 L
s
.37861 .50903 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50666 .5866 m
.50928 .58452 L
s
1 .967 0 r
.01 w
.37081 .50896 Mdot
1 .968 0 r
[ .05 .05 ] 0 setdash
.37055 .50868 m
.37081 .50896 L
s
1 .96 0 r
.37913 .50896 m
.37965 .50885 L
s
.37913 .50896 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37301 .51017 m
.37306 .51186 L
s
1 .96 0 r
.01 w
[ .05 .05 ] 0 setdash
.37965 .50885 m
.38018 .50872 L
s
.37965 .50885 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5611 .57219 m
.56337 .57886 L
s
.37181 .512 m
.3719 .51279 L
s
.37167 .51198 m
.37181 .512 L
s
.37145 .5134 m
.37167 .51198 L
s
1 .683 0 r
.01 w
.61737 .50873 Mdot
[ .05 .05 ] 0 setdash
.61776 .50748 m
.61737 .50873 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37971 .51978 m
.38018 .50872 L
s
1 .96 0 r
.01 w
[ .05 .05 ] 0 setdash
.38018 .50872 m
.3807 .50853 L
s
.38018 .50872 Mdot
1 .66 0 r
.53188 .50871 m
.53025 .508 L
s
.53188 .50871 Mdot
1 .892 0 r
.67963 .5087 m
.6828 .50753 L
s
.67963 .5087 Mdot
1 .968 0 r
.37055 .50868 Mdot
.37027 .50838 m
.37055 .50868 L
s
0 0 0 r
.004 w
.69642 .50864 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51928 .58563 m
.52175 .58773 L
s
.37272 .51199 m
.37283 .51086 L
s
.64648 .55011 m
.64757 .5451 L
s
1 .96 0 r
.01 w
[ .05 .05 ] 0 setdash
.3807 .50853 m
.38124 .50826 L
s
.3807 .50853 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61643 .55051 m
.61628 .54508 L
s
.60265 .56282 m
.60083 .55991 L
s
1 .952 0 r
.01 w
.40071 .50838 Mdot
1 .953 0 r
[ .05 .05 ] 0 setdash
.39928 .50768 m
.40071 .50838 L
s
1 .968 0 r
.37027 .50838 Mdot
.36997 .50808 m
.37027 .50838 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3719 .51279 m
.37198 .51346 L
s
.46265 .56647 m
.46443 .57058 L
s
1 .96 0 r
.01 w
[ .05 .05 ] 0 setdash
.38124 .50826 m
.38177 .50795 L
s
.38124 .50826 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65023 .5413 m
.6515 .54453 L
s
1 .968 0 r
.01 w
.36997 .50808 Mdot
[ .05 .05 ] 0 setdash
.36967 .50778 m
.36997 .50808 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58637 .55893 m
.58492 .56094 L
s
.37258 .51297 m
.37272 .51199 L
s
0 0 0 r
.004 w
.698 .50807 Mdot
.35087 .50802 Mdot
1 .66 0 r
.01 w
[ .05 .05 ] 0 setdash
.53025 .508 m
.52879 .50738 L
s
.53025 .508 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37306 .51186 m
.37316 .51399 L
s
.37198 .51346 m
.37208 .51386 L
s
1 .959 0 r
.01 w
[ .05 .05 ] 0 setdash
.38177 .50795 m
.38238 .50752 L
s
.38177 .50795 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37118 .51536 m
.37145 .5134 L
s
.427 .55777 m
.42862 .55202 L
s
1 .968 0 r
.01 w
.36967 .50778 Mdot
[ .05 .05 ] 0 setdash
.3694 .50752 m
.36967 .50778 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50409 .58972 m
.50666 .5866 L
s
1 .953 0 r
.01 w
.39928 .50768 Mdot
[ .05 .05 ] 0 setdash
.39788 .50709 m
.39928 .50768 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37244 .51365 m
.37258 .51297 L
s
.37208 .51386 m
.37219 .51397 L
s
.53777 .5871 m
.5403 .5833 L
s
1 .892 0 r
.01 w
[ .05 .05 ] 0 setdash
.6828 .50753 m
.6855 .50651 L
s
.6828 .50753 Mdot
1 .959 0 r
.38238 .50752 m
.38295 .50703 L
s
.38238 .50752 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36888 .51907 m
.3694 .50752 L
s
1 .968 0 r
.01 w
.3694 .50752 Mdot
1 .969 0 r
[ .05 .05 ] 0 setdash
.36914 .50726 m
.3694 .50752 L
s
0 0 0 r
.004 w
.69956 .50749 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37219 .51397 m
.3723 .51403 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61911 .55711 m
.61776 .50748 L
s
1 .683 0 r
.01 w
.61776 .50748 Mdot
1 .684 0 r
[ .05 .05 ] 0 setdash
.61806 .50614 m
.61776 .50748 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52175 .58773 m
.52439 .58998 L
s
.3723 .51403 m
.37244 .51365 L
s
1 .659 0 r
.01 w
[ .05 .05 ] 0 setdash
.52879 .50738 m
.52736 .50678 L
s
.52879 .50738 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61108 .55704 m
.6095 .56126 L
s
1 .969 0 r
.01 w
.36914 .50726 Mdot
[ .05 .05 ] 0 setdash
.36893 .50705 m
.36914 .50726 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.44767 .5662 m
.4495 .56308 L
s
1 .953 0 r
.01 w
.39788 .50709 Mdot
[ .05 .05 ] 0 setdash
.39649 .50665 m
.39788 .50709 L
s
1 .969 0 r
.36893 .50705 Mdot
.36872 .50685 m
.36893 .50705 L
s
1 .959 0 r
.38295 .50703 m
.38354 .50648 L
s
.38295 .50703 Mdot
0 0 0 r
.004 w
.70113 .50691 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37316 .51399 m
.37336 .51623 L
s
.44105 .55822 m
.44246 .56354 L
s
1 .969 0 r
.01 w
.36872 .50685 Mdot
[ .05 .05 ] 0 setdash
.36858 .50671 m
.36872 .50685 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46443 .57058 m
.46647 .57495 L
s
1 .659 0 r
.01 w
[ .05 .05 ] 0 setdash
.52736 .50678 m
.526 .50621 L
s
.52736 .50678 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37089 .51733 m
.37118 .51536 L
s
0 0 0 r
.004 w
.34744 .50675 Mdot
1 .969 0 r
.01 w
.36858 .50671 Mdot
[ .05 .05 ] 0 setdash
.36849 .50661 m
.36858 .50671 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58492 .56094 m
.58328 .56246 L
s
1 .974 0 r
.01 w
[ .05 .05 ] 0 setdash
.36611 .50667 m
.36617 .50666 L
s
.36611 .50667 Mdot
.36605 .50667 m
.36611 .50667 L
s
.36605 .50667 Mdot
.36596 .50663 m
.36605 .50667 L
s
1 .973 0 r
.36617 .50666 m
.36624 .50664 L
s
.36617 .50666 Mdot
1 .953 0 r
.39649 .50665 Mdot
.39515 .5063 m
.39649 .50665 L
s
1 .973 0 r
.36624 .50664 m
.36634 .50662 L
s
.36624 .50664 Mdot
1 .974 0 r
.36596 .50663 Mdot
.36581 .50654 m
.36596 .50663 L
s
1 .973 0 r
.36634 .50662 m
.36644 .50659 L
s
.36634 .50662 Mdot
1 .969 0 r
.36849 .50661 Mdot
1 .97 0 r
.36846 .50655 m
.36849 .50661 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60437 .56458 m
.60265 .56282 L
s
1 .973 0 r
.01 w
[ .05 .05 ] 0 setdash
.36644 .50659 m
.36658 .50655 L
s
.36644 .50659 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3661 .50686 m
.36613 .50766 L
s
.36602 .50723 m
.3661 .50686 L
s
1 .97 0 r
.01 w
.36846 .50655 Mdot
[ .05 .05 ] 0 setdash
.36847 .50653 m
.36846 .50655 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36635 .51136 m
.36658 .50655 L
s
1 .973 0 r
.01 w
[ .05 .05 ] 0 setdash
.36658 .50655 m
.36675 .50651 L
s
.36658 .50655 Mdot
1 .974 0 r
.36581 .50654 Mdot
.36558 .5064 m
.36581 .50654 L
s
1 .97 0 r
.36847 .50653 Mdot
.3685 .50652 m
.36847 .50653 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64514 .55521 m
.64648 .55011 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.36851 .50697 m
.36853 .50653 L
s
1 .97 0 r
.01 w
[ .05 .05 ] 0 setdash
.36853 .50653 m
.36852 .50652 L
s
.36853 .50653 Mdot
1 .971 0 r
.36851 .50652 m
.36853 .50653 L
s
1 .97 0 r
.36852 .50652 m
.3685 .50652 L
s
.36852 .50652 Mdot
.3685 .50652 Mdot
1 .971 0 r
.36851 .50652 Mdot
.36843 .50652 m
.36851 .50652 L
s
.36843 .50652 Mdot
.36828 .5065 m
.36843 .50652 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6515 .54453 m
.65297 .54845 L
s
1 .972 0 r
.01 w
[ .05 .05 ] 0 setdash
.36675 .50651 m
.36697 .50649 L
s
.36675 .50651 Mdot
1 .892 0 r
.6855 .50651 m
.6885 .50539 L
s
.6855 .50651 Mdot
1 .971 0 r
.36828 .5065 Mdot
.36807 .50649 m
.36828 .5065 L
s
1 .972 0 r
.36697 .50649 m
.36724 .50648 L
s
.36697 .50649 Mdot
1 .971 0 r
.36807 .50649 Mdot
.36781 .50649 m
.36807 .50649 L
s
.36781 .50649 Mdot
1 .972 0 r
.36753 .50648 m
.36781 .50649 L
s
1 .959 0 r
.38354 .50648 m
.38426 .50587 L
s
.38354 .50648 Mdot
1 .972 0 r
.36753 .50648 Mdot
.36724 .50648 m
.36753 .50648 L
s
.36724 .50648 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36585 .509 m
.36602 .50723 L
s
1 .974 0 r
.01 w
.36558 .5064 Mdot
1 .975 0 r
[ .05 .05 ] 0 setdash
.36525 .50619 m
.36558 .5064 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3685 .50683 m
.36851 .50697 L
s
.36836 .50801 m
.3685 .50683 L
s
0 0 0 r
.004 w
.70269 .50632 Mdot
.53 .8 .95 r
.006 w
.36851 .50697 m
.36849 .50728 L
s
1 .953 0 r
.01 w
.39515 .5063 Mdot
[ .05 .05 ] 0 setdash
.39386 .50596 m
.39515 .5063 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36845 .50705 m
.36841 .50772 L
s
.36846 .50722 m
.36845 .50705 L
s
.52439 .58998 m
.5271 .59111 L
s
1 .659 0 r
.01 w
[ .05 .05 ] 0 setdash
.526 .50621 m
.52484 .50573 L
s
.526 .50621 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36469 .51832 m
.36525 .50619 L
s
1 .975 0 r
.01 w
.36525 .50619 Mdot
[ .05 .05 ] 0 setdash
.36482 .50594 m
.36525 .50619 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36849 .50728 m
.36846 .50722 L
s
.36613 .50766 m
.36617 .50815 L
s
.53519 .58955 m
.53777 .5871 L
s
1 .684 0 r
.01 w
.61806 .50614 Mdot
[ .05 .05 ] 0 setdash
.61845 .50501 m
.61806 .50614 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36841 .50772 m
.36838 .50912 L
s
1 .953 0 r
.01 w
.39386 .50596 Mdot
1 .954 0 r
[ .05 .05 ] 0 setdash
.39261 .50567 m
.39386 .50596 L
s
1 .975 0 r
.36482 .50594 Mdot
.36425 .50563 m
.36482 .50594 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36617 .50815 m
.36623 .50896 L
s
.50109 .59236 m
.50409 .58972 L
s
1 .958 0 r
.01 w
[ .05 .05 ] 0 setdash
.38426 .50587 m
.38485 .50528 L
s
.38426 .50587 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36814 .50947 m
.36836 .50801 L
s
.37336 .51623 m
.37366 .51839 L
s
1 .659 0 r
.01 w
[ .05 .05 ] 0 setdash
.52484 .50573 m
.5237 .50528 L
s
.52484 .50573 Mdot
0 0 0 r
.004 w
.70424 .50572 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6095 .56126 m
.60805 .56377 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.39153 .53356 m
.39261 .50567 L
s
1 .954 0 r
.01 w
.39261 .50567 Mdot
[ .05 .05 ] 0 setdash
.39152 .5054 m
.39261 .50567 L
s
1 .975 0 r
.36425 .50563 Mdot
.36353 .50524 m
.36425 .50563 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37059 .51915 m
.37089 .51733 L
s
.58328 .56246 m
.58153 .56345 L
s
.36558 .51157 m
.36585 .509 L
s
.36623 .50896 m
.36628 .51017 L
s
.5271 .59111 m
.52975 .59196 L
s
0 0 0 r
.004 w
.34394 .50541 Mdot
.53 .8 .95 r
.006 w
.56337 .57886 m
.56572 .5841 L
s
1 .954 0 r
.01 w
.39152 .5054 Mdot
[ .05 .05 ] 0 setdash
.3905 .50516 m
.39152 .5054 L
s
1 .892 0 r
.6885 .50539 m
.69154 .50426 L
s
.6885 .50539 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60636 .56464 m
.60437 .56458 L
s
.36838 .50912 m
.36839 .51091 L
s
.5325 .5915 m
.53519 .58955 L
s
1 .958 0 r
.01 w
[ .05 .05 ] 0 setdash
.38485 .50528 m
.38551 .50468 L
s
.38485 .50528 Mdot
1 .659 0 r
.5237 .50528 m
.52275 .50494 L
s
.5237 .50528 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46647 .57495 m
.46872 .5794 L
s
1 .975 0 r
.01 w
.36353 .50524 Mdot
[ .05 .05 ] 0 setdash
.36265 .50479 m
.36353 .50524 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.44588 .5673 m
.44767 .5662 L
s
1 .954 0 r
.01 w
.3905 .50516 Mdot
[ .05 .05 ] 0 setdash
.38973 .50487 m
.3905 .50516 L
s
0 0 0 r
.004 w
.7058 .50512 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36786 .51091 m
.36814 .50947 L
s
1 .684 0 r
.01 w
.61845 .50501 Mdot
[ .05 .05 ] 0 setdash
.61878 .50395 m
.61845 .50501 L
s
1 .658 0 r
.52275 .50494 m
.52188 .50464 L
s
.52275 .50494 Mdot
1 .954 0 r
.38973 .50487 Mdot
1 .955 0 r
.38899 .50451 m
.38973 .50487 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60805 .56377 m
.60636 .56464 L
s
.44246 .56354 m
.44409 .56673 L
s
.61656 .55485 m
.61643 .55051 L
s
.36628 .51017 m
.36635 .51136 L
s
1 .975 0 r
.01 w
.36265 .50479 Mdot
1 .976 0 r
[ .05 .05 ] 0 setdash
.36161 .50427 m
.36265 .50479 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52975 .59196 m
.5325 .5915 L
s
1 .958 0 r
.01 w
[ .05 .05 ] 0 setdash
.38551 .50468 m
.38619 .50406 L
s
.38551 .50468 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.52187 .52334 m
.52188 .50464 L
s
1 .658 0 r
.01 w
[ .05 .05 ] 0 setdash
.52188 .50464 m
.52112 .50437 L
s
.52188 .50464 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37366 .51839 m
.37406 .52034 L
s
.36839 .51091 m
.36844 .51294 L
s
0 0 0 r
.004 w
.70735 .50452 Mdot
1 .955 0 r
.01 w
.38899 .50451 Mdot
[ .05 .05 ] 0 setdash
.38845 .50412 m
.38899 .50451 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58153 .56345 m
.57977 .56349 L
s
.64366 .56016 m
.64514 .55521 L
s
1 .658 0 r
.01 w
[ .05 .05 ] 0 setdash
.52112 .50437 m
.52048 .50411 L
s
.52112 .50437 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37028 .52068 m
.37059 .51915 L
s
.36755 .51216 m
.36786 .51091 L
s
.65297 .54845 m
.65463 .55272 L
s
1 .976 0 r
.01 w
.36161 .50427 Mdot
[ .05 .05 ] 0 setdash
.36039 .50361 m
.36161 .50427 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49814 .5956 m
.50109 .59236 L
s
1 .891 0 r
.01 w
[ .05 .05 ] 0 setdash
.69154 .50426 m
.6944 .50316 L
s
.69154 .50426 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42522 .56324 m
.427 .55777 L
s
.36635 .51136 m
.36647 .51251 L
s
.44409 .56673 m
.44588 .5673 L
s
1 .955 0 r
.01 w
.38845 .50412 Mdot
[ .05 .05 ] 0 setdash
.38805 .50373 m
.38845 .50412 L
s
1 .658 0 r
.52048 .50411 m
.51996 .50384 L
s
.52048 .50411 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37871 .51887 m
.37923 .51898 L
s
.37815 .51975 m
.37871 .51887 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38515 .52976 m
.38619 .50406 L
s
1 .958 0 r
.01 w
[ .05 .05 ] 0 setdash
.38619 .50406 m
.38677 .5035 L
s
.38619 .50406 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36518 .51498 m
.36558 .51157 L
s
0 0 0 r
.004 w
.34037 .50401 Mdot
1 .684 0 r
.01 w
.61878 .50395 Mdot
[ .05 .05 ] 0 setdash
.61909 .50305 m
.61878 .50395 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57977 .56349 m
.57789 .5633 L
s
0 0 0 r
.004 w
.70889 .50391 Mdot
.53 .8 .95 r
.006 w
.37923 .51898 m
.37971 .51978 L
s
.36844 .51294 m
.36854 .51546 L
s
1 .658 0 r
.01 w
[ .05 .05 ] 0 setdash
.51996 .50384 m
.51956 .50354 L
s
.51996 .50384 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37757 .52092 m
.37815 .51975 L
s
1 .955 0 r
.01 w
.38805 .50373 Mdot
[ .05 .05 ] 0 setdash
.38778 .50337 m
.38805 .50373 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46872 .5794 m
.47117 .58342 L
s
.36723 .51312 m
.36755 .51216 L
s
.37406 .52034 m
.37452 .52217 L
s
1 .976 0 r
.01 w
.36039 .50361 Mdot
[ .05 .05 ] 0 setdash
.35904 .50288 m
.36039 .50361 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36647 .51251 m
.36666 .51325 L
s
1 .657 0 r
.01 w
[ .05 .05 ] 0 setdash
.51956 .50354 m
.51923 .50318 L
s
.51956 .50354 Mdot
1 .958 0 r
.38677 .5035 m
.38725 .503 L
s
.38677 .5035 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57789 .5633 m
.57605 .56377 L
s
1 .955 0 r
.01 w
.38778 .50337 Mdot
[ .05 .05 ] 0 setdash
.38761 .50303 m
.38778 .50337 L
s
0 0 0 r
.004 w
.71043 .50329 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37971 .51978 m
.38016 .52151 L
s
.37692 .52241 m
.37757 .52092 L
s
.36691 .51365 m
.36723 .51312 L
s
1 .657 0 r
.01 w
[ .05 .05 ] 0 setdash
.51923 .50318 m
.51889 .50271 L
s
.51923 .50318 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36998 .52131 m
.37028 .52068 L
s
1 .891 0 r
.01 w
[ .05 .05 ] 0 setdash
.6944 .50316 m
.69737 .502 L
s
.6944 .50316 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36666 .51325 m
.36691 .51365 L
s
1 .684 0 r
.01 w
.61909 .50305 Mdot
[ .05 .05 ] 0 setdash
.61937 .50227 m
.61909 .50305 L
s
1 .955 0 r
.38761 .50303 Mdot
1 .956 0 r
.38757 .50271 m
.38761 .50303 L
s
1 .957 0 r
.38725 .503 m
.38765 .50257 L
s
.38725 .503 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36854 .51546 m
.36869 .5172 L
s
1 .976 0 r
.01 w
.35904 .50288 Mdot
[ .05 .05 ] 0 setdash
.35748 .50195 m
.35904 .50288 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37452 .52217 m
.37507 .52316 L
s
1 .657 0 r
.01 w
[ .05 .05 ] 0 setdash
.51889 .50271 m
.51849 .50212 L
s
.51889 .50271 Mdot
1 .956 0 r
.38757 .50271 Mdot
.38764 .50243 m
.38757 .50271 L
s
0 0 0 r
.004 w
.71197 .50266 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56572 .5841 m
.56845 .58861 L
s
.57605 .56377 m
.57419 .56385 L
s
1 .957 0 r
.01 w
[ .05 .05 ] 0 setdash
.38765 .50257 m
.38795 .50223 L
s
.38765 .50257 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3763 .52298 m
.37692 .52241 L
s
0 0 0 r
.004 w
.33672 .50254 Mdot
.53 .8 .95 r
.006 w
.64181 .56439 m
.64366 .56016 L
s
.36966 .52184 m
.36998 .52131 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38715 .51458 m
.38764 .50243 L
s
1 .956 0 r
.01 w
.38764 .50243 Mdot
[ .05 .05 ] 0 setdash
.38781 .50218 m
.38764 .50243 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47117 .58342 m
.47389 .58758 L
s
.36869 .5172 m
.36888 .51907 L
s
.37567 .52341 m
.3763 .52298 L
s
.49529 .59876 m
.49814 .5956 L
s
1 .684 0 r
.01 w
.61937 .50227 Mdot
1 .685 0 r
[ .05 .05 ] 0 setdash
.61965 .50157 m
.61937 .50227 L
s
1 .957 0 r
.38795 .50223 m
.38815 .50201 L
s
.38795 .50223 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37507 .52316 m
.37567 .52341 L
s
1 .956 0 r
.01 w
.38781 .50218 Mdot
[ .05 .05 ] 0 setdash
.38804 .50199 m
.38781 .50218 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36469 .51832 m
.36518 .51498 L
s
1 .657 0 r
.01 w
[ .05 .05 ] 0 setdash
.51849 .50212 m
.51801 .50143 L
s
.51849 .50212 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38016 .52151 m
.38059 .52388 L
s
0 0 0 r
.004 w
.71351 .50204 Mdot
1 .957 0 r
.01 w
[ .05 .05 ] 0 setdash
.38815 .50201 m
.38824 .50189 L
s
.38815 .50201 Mdot
1 .891 0 r
.69737 .502 m
.70034 .50081 L
s
.69737 .502 Mdot
1 .956 0 r
.38804 .50199 Mdot
.38819 .50189 m
.38804 .50199 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57419 .56385 m
.5723 .56403 L
s
1 .976 0 r
.01 w
.35748 .50195 Mdot
1 .977 0 r
[ .05 .05 ] 0 setdash
.35582 .50093 m
.35748 .50195 L
s
1 .957 0 r
.38824 .50189 m
.38819 .50189 L
s
.38824 .50189 Mdot
1 .956 0 r
.38819 .50189 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36888 .51907 m
.36908 .52089 L
s
.65463 .55272 m
.65648 .55741 L
s
.36935 .52171 m
.36966 .52184 L
s
1 .685 0 r
.01 w
.61965 .50157 Mdot
[ .05 .05 ] 0 setdash
.6199 .50102 m
.61965 .50157 L
s
1 .656 0 r
.51801 .50143 m
.51752 .50076 L
s
.51801 .50143 Mdot
0 0 0 r
.004 w
.71504 .5014 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36908 .52089 m
.36935 .52171 L
s
.61675 .55911 m
.61656 .55485 L
s
.5723 .56403 m
.57045 .56477 L
s
.47389 .58758 m
.47656 .59183 L
s
1 .685 0 r
.01 w
.6199 .50102 Mdot
[ .05 .05 ] 0 setdash
.62014 .50062 m
.6199 .50102 L
s
0 0 0 r
.004 w
.33298 .50099 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63986 .56923 m
.64181 .56439 L
s
1 .977 0 r
.01 w
.35582 .50093 Mdot
[ .05 .05 ] 0 setdash
.35398 .49978 m
.35582 .50093 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70419 .57551 m
.70034 .50081 L
s
1 .891 0 r
.01 w
[ .05 .05 ] 0 setdash
.70034 .50081 m
.70335 .49956 L
s
.70034 .50081 Mdot
0 0 0 r
.004 w
.71657 .50076 Mdot
1 .656 0 r
.01 w
.51752 .50076 m
.51689 .49996 L
s
.51752 .50076 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42314 .56871 m
.42522 .56324 L
s
.38809 .50441 m
.38777 .50876 L
s
.38813 .50446 m
.38809 .50441 L
s
1 .685 0 r
.01 w
.62014 .50062 Mdot
[ .05 .05 ] 0 setdash
.6203 .50034 m
.62014 .50062 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38786 .50932 m
.38813 .50446 L
s
.38059 .52388 m
.38098 .52686 L
s
1 .687 0 r
.01 w
[ .05 .05 ] 0 setdash
.62016 .5004 m
.62008 .50036 L
s
.62016 .5004 Mdot
.62037 .50039 m
.62016 .5004 L
s
.62037 .50039 Mdot
.62071 .50034 m
.62037 .50039 L
s
.62008 .50036 m
.6201 .50029 L
s
.62008 .50036 Mdot
1 .685 0 r
.6203 .50034 Mdot
.62039 .50017 m
.6203 .50034 L
s
1 .687 0 r
.62071 .50034 Mdot
.62118 .50025 m
.62071 .50034 L
s
1 .686 0 r
.6201 .50029 m
.62019 .50022 L
s
.6201 .50029 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62146 .5103 m
.62118 .50025 L
s
1 .687 0 r
.01 w
.62118 .50025 Mdot
1 .688 0 r
[ .05 .05 ] 0 setdash
.62175 .50013 m
.62118 .50025 L
s
1 .686 0 r
.62019 .50022 m
.62029 .50014 L
s
.62019 .50022 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57045 .56477 m
.56854 .56555 L
s
.36413 .52083 m
.36469 .51832 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62048 .50353 m
.62039 .50017 L
s
1 .685 0 r
.01 w
.62039 .50017 Mdot
1 .686 0 r
[ .05 .05 ] 0 setdash
.62042 .5001 m
.62039 .50017 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49202 .60089 m
.49529 .59876 L
s
1 .686 0 r
.01 w
[ .05 .05 ] 0 setdash
.62029 .50014 m
.62038 .5001 L
s
.62029 .50014 Mdot
1 .688 0 r
.62175 .50013 Mdot
.62241 .5 m
.62175 .50013 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56845 .58861 m
.57152 .59283 L
s
0 0 0 r
.004 w
.71809 .50011 Mdot
1 .686 0 r
.01 w
.62042 .5001 Mdot
[ .05 .05 ] 0 setdash
.62038 .5001 m
.62042 .5001 L
s
.62038 .5001 Mdot
1 .688 0 r
.62241 .5 Mdot
.62316 .49985 m
.62241 .5 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.51681 .53776 m
.51689 .49996 L
s
1 .656 0 r
.01 w
[ .05 .05 ] 0 setdash
.51689 .49996 m
.51607 .49903 L
s
.51689 .49996 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62043 .50056 m
.62048 .50353 L
s
.62043 .5019 m
.62043 .50056 L
s
1 .688 0 r
.01 w
.62316 .49985 Mdot
[ .05 .05 ] 0 setdash
.62392 .49969 m
.62316 .49985 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35113 .55692 m
.35398 .49978 L
s
1 .977 0 r
.01 w
.35398 .49978 Mdot
[ .05 .05 ] 0 setdash
.35213 .49862 m
.35398 .49978 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6202 .50177 m
.62012 .50184 L
s
.62048 .50427 m
.6202 .50177 L
s
1 .688 0 r
.01 w
.62392 .49969 Mdot
1 .689 0 r
[ .05 .05 ] 0 setdash
.62473 .49952 m
.62392 .49969 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62012 .50184 m
.62018 .50297 L
s
.47656 .59183 m
.47944 .59552 L
s
1 .891 0 r
.01 w
[ .05 .05 ] 0 setdash
.70335 .49956 m
.70629 .4983 L
s
.70335 .49956 Mdot
1 .689 0 r
.62473 .49952 Mdot
.62555 .49934 m
.62473 .49952 L
s
0 0 0 r
.004 w
.71961 .49946 Mdot
.32914 .49935 Mdot
1 .689 0 r
.01 w
.62555 .49934 Mdot
.62632 .49917 m
.62555 .49934 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62037 .50305 m
.62043 .5019 L
s
1 .689 0 r
.01 w
.62632 .49917 Mdot
[ .05 .05 ] 0 setdash
.62717 .49895 m
.62632 .49917 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56854 .56555 m
.56662 .56595 L
s
.63764 .57312 m
.63986 .56923 L
s
1 .656 0 r
.01 w
[ .05 .05 ] 0 setdash
.51607 .49903 m
.51527 .49808 L
s
.51607 .49903 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62018 .50297 m
.62028 .50337 L
s
1 .689 0 r
.01 w
.62717 .49895 Mdot
[ .05 .05 ] 0 setdash
.62797 .49873 m
.62717 .49895 L
s
0 0 0 r
.004 w
.72113 .4988 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65648 .55741 m
.65854 .56262 L
s
1 .689 0 r
.01 w
.62797 .49873 Mdot
1 .69 0 r
[ .05 .05 ] 0 setdash
.62869 .49849 m
.62797 .49873 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48879 .60161 m
.49202 .60089 L
s
.62028 .50337 m
.62037 .50305 L
s
.38777 .50876 m
.38741 .51238 L
s
1 .977 0 r
.01 w
.35213 .49862 Mdot
[ .05 .05 ] 0 setdash
.35 .49723 m
.35213 .49862 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38098 .52686 m
.38147 .52943 L
s
.3634 .52386 m
.36413 .52083 L
s
.62048 .50353 m
.6205 .50752 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62915 .51358 m
.62869 .49849 L
s
1 .69 0 r
.01 w
.62869 .49849 Mdot
[ .05 .05 ] 0 setdash
.62935 .49823 m
.62869 .49849 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47944 .59552 m
.48251 .59887 L
s
.6209 .50719 m
.62048 .50427 L
s
.38747 .51435 m
.38786 .50932 L
s
.51994 .51501 m
.51954 .51559 L
s
.52046 .51649 m
.51994 .51501 L
s
1 .89 0 r
.01 w
[ .05 .05 ] 0 setdash
.70629 .4983 m
.70934 .49697 L
s
.70629 .4983 Mdot
1 .69 0 r
.62935 .49823 Mdot
.62993 .49794 m
.62935 .49823 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56662 .56595 m
.56465 .56574 L
s
0 0 0 r
.004 w
.72265 .49813 Mdot
1 .656 0 r
.01 w
[ .05 .05 ] 0 setdash
.51527 .49808 m
.51441 .49707 L
s
.51527 .49808 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5211 .51938 m
.52046 .51649 L
s
1 .69 0 r
.01 w
.62993 .49794 Mdot
[ .05 .05 ] 0 setdash
.63044 .49761 m
.62993 .49794 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57152 .59283 m
.57472 .59556 L
s
.61699 .56234 m
.61675 .55911 L
s
.63527 .57628 m
.63764 .57312 L
s
.48574 .60068 m
.48879 .60161 L
s
0 0 0 r
.004 w
.32519 .49762 Mdot
.53 .8 .95 r
.006 w
.48251 .59887 m
.48574 .60068 L
s
1 .69 0 r
.01 w
.63044 .49761 Mdot
[ .05 .05 ] 0 setdash
.63089 .49723 m
.63044 .49761 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51954 .51559 m
.5192 .51776 L
s
.56465 .56574 m
.5627 .56575 L
s
0 0 0 r
.004 w
.72416 .49746 Mdot
1 .69 0 r
.01 w
.63089 .49723 Mdot
1 .691 0 r
[ .05 .05 ] 0 setdash
.63136 .49678 m
.63089 .49723 L
s
1 .977 0 r
.35 .49723 Mdot
.3478 .49577 m
.35 .49723 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38741 .51238 m
.38715 .51458 L
s
1 .655 0 r
.01 w
[ .05 .05 ] 0 setdash
.51441 .49707 m
.51368 .49619 L
s
.51441 .49707 Mdot
1 .89 0 r
.70934 .49697 m
.71231 .49566 L
s
.70934 .49697 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52187 .52334 m
.5211 .51938 L
s
.62146 .5103 m
.6209 .50719 L
s
.42098 .57369 m
.42314 .56871 L
s
0 0 0 r
.004 w
.72566 .49678 Mdot
1 .691 0 r
.01 w
.63136 .49678 Mdot
[ .05 .05 ] 0 setdash
.63183 .49623 m
.63136 .49678 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6205 .50752 m
.62046 .51231 L
s
.5627 .56575 m
.5607 .56565 L
s
.38147 .52943 m
.38193 .53155 L
s
.63285 .57849 m
.63527 .57628 L
s
.3625 .52708 m
.3634 .52386 L
s
.38723 .51708 m
.38746 .51848 L
s
.38708 .51642 m
.38723 .51708 L
s
.38746 .51848 m
.38778 .52093 L
s
.38715 .51458 m
.38706 .51548 L
s
.38706 .51548 m
.38708 .51642 L
s
1 .691 0 r
.01 w
.63183 .49623 Mdot
[ .05 .05 ] 0 setdash
.63232 .49561 m
.63183 .49623 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38699 .51903 m
.38747 .51435 L
s
1 .655 0 r
.01 w
[ .05 .05 ] 0 setdash
.51368 .49619 m
.51295 .49531 L
s
.51368 .49619 Mdot
0 0 0 r
.004 w
.72717 .4961 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57472 .59556 m
.57789 .59714 L
s
.63018 .58058 m
.63285 .57849 L
s
.5192 .51776 m
.51886 .52134 L
s
.5607 .56565 m
.55877 .56474 L
s
.61916 .58363 m
.62224 .58324 L
s
.61625 .58473 m
.61916 .58363 L
s
.61334 .58589 m
.61625 .58473 L
s
.38778 .52093 m
.38821 .52424 L
s
1 .977 0 r
.01 w
.3478 .49577 Mdot
1 .978 0 r
[ .05 .05 ] 0 setdash
.34569 .49439 m
.3478 .49577 L
s
0 0 0 r
.004 w
.32111 .49577 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61052 .58807 m
.61334 .58589 L
s
1 .89 0 r
.01 w
[ .05 .05 ] 0 setdash
.71231 .49566 m
.71531 .49432 L
s
.71231 .49566 Mdot
1 .691 0 r
.63232 .49561 Mdot
.63281 .49491 m
.63232 .49561 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62756 .58194 m
.63018 .58058 L
s
.62224 .58324 m
.62479 .58266 L
s
.55877 .56474 m
.55679 .56398 L
s
0 0 0 r
.004 w
.72867 .49541 Mdot
.53 .8 .95 r
.006 w
.62479 .58266 m
.62756 .58194 L
s
.52274 .52785 m
.52187 .52334 L
s
1 .655 0 r
.01 w
[ .05 .05 ] 0 setdash
.51295 .49531 m
.51232 .49455 L
s
.51295 .49531 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65854 .56262 m
.66083 .56826 L
s
.62213 .51342 m
.62146 .5103 L
s
.60747 .58997 m
.61052 .58807 L
s
.57789 .59714 m
.58125 .59827 L
s
1 .691 0 r
.01 w
.63281 .49491 Mdot
[ .05 .05 ] 0 setdash
.63334 .4941 m
.63281 .49491 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38193 .53155 m
.38245 .53313 L
s
.55679 .56398 m
.55483 .56337 L
s
.62046 .51231 m
.62037 .51786 L
s
.38821 .52424 m
.38883 .52756 L
s
0 0 0 r
.004 w
.73016 .49471 Mdot
.53 .8 .95 r
.006 w
.60435 .59185 m
.60747 .58997 L
s
1 .655 0 r
.01 w
[ .05 .05 ] 0 setdash
.51232 .49455 m
.51171 .49383 L
s
.51232 .49455 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61729 .5639 m
.61699 .56234 L
s
.36143 .53052 m
.3625 .52708 L
s
.38642 .52356 m
.38699 .51903 L
s
1 .978 0 r
.01 w
.34569 .49439 Mdot
[ .05 .05 ] 0 setdash
.34325 .49271 m
.34569 .49439 L
s
1 .89 0 r
.71531 .49432 m
.71805 .49307 L
s
.71531 .49432 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55483 .56337 m
.55289 .56268 L
s
.60115 .59324 m
.60435 .59185 L
s
1 .691 0 r
.01 w
.63334 .4941 Mdot
1 .692 0 r
[ .05 .05 ] 0 setdash
.63389 .49318 m
.63334 .4941 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58125 .59827 m
.58471 .59901 L
s
0 0 0 r
.004 w
.73165 .49401 Mdot
.53 .8 .95 r
.006 w
.59795 .5954 m
.60115 .59324 L
s
1 .655 0 r
.01 w
[ .05 .05 ] 0 setdash
.51171 .49383 m
.51121 .49325 L
s
.51171 .49383 Mdot
0 0 0 r
.004 w
.3169 .4938 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55289 .56268 m
.55094 .56151 L
s
.38883 .52756 m
.38951 .53047 L
s
.52369 .53246 m
.52274 .52785 L
s
.62287 .51616 m
.62213 .51342 L
s
.51886 .52134 m
.51845 .52551 L
s
.55094 .56151 m
.54905 .56066 L
s
0 0 0 r
.004 w
.73314 .4933 Mdot
.53 .8 .95 r
.006 w
.38245 .53313 m
.38311 .53382 L
s
.41865 .57741 m
.42098 .57369 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.51121 .49325 m
.51076 .49275 L
s
.51121 .49325 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59471 .59678 m
.59795 .5954 L
s
.58471 .59901 m
.58813 .59818 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.63506 .52965 m
.63389 .49318 L
s
1 .692 0 r
.01 w
.63389 .49318 Mdot
[ .05 .05 ] 0 setdash
.63444 .49219 m
.63389 .49318 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58813 .59818 m
.59134 .59741 L
s
.59134 .59741 m
.59471 .59678 L
s
1 .89 0 r
.01 w
[ .05 .05 ] 0 setdash
.71805 .49307 m
.72076 .49183 L
s
.71805 .49307 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54905 .56066 m
.54718 .55957 L
s
.38581 .52741 m
.38642 .52356 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.51076 .49275 m
.51041 .49233 L
s
.51076 .49275 Mdot
1 .978 0 r
.34325 .49271 Mdot
.341 .49118 m
.34325 .49271 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62037 .51786 m
.62027 .52396 L
s
.38951 .53047 m
.39047 .53258 L
s
0 0 0 r
.004 w
.73463 .49258 Mdot
.53 .8 .95 r
.006 w
.54718 .55957 m
.54535 .55848 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.51035 .505 m
.51041 .49233 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.51041 .49233 m
.51014 .49196 L
s
.51041 .49233 Mdot
1 .692 0 r
.63444 .49219 Mdot
.63499 .49112 m
.63444 .49219 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61752 .5642 m
.61729 .5639 L
s
.36018 .53426 m
.36143 .53052 L
s
.54358 .55655 m
.54189 .555 L
s
.54535 .55848 m
.54358 .55655 L
s
.38311 .53382 m
.3837 .53346 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.51014 .49196 m
.50995 .49162 L
s
.51014 .49196 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62368 .51806 m
.62287 .51616 L
s
.39047 .53258 m
.39153 .53356 L
s
0 0 0 r
.004 w
.73611 .49186 Mdot
.53 .8 .95 r
.006 w
.39153 .53356 m
.39276 .53468 L
s
.54189 .555 m
.54018 .55352 L
s
1 .889 0 r
.01 w
[ .05 .05 ] 0 setdash
.72076 .49183 m
.72335 .49064 L
s
.72076 .49183 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52484 .53711 m
.52369 .53246 L
s
.39404 .53559 m
.39537 .5367 L
s
.39276 .53468 m
.39404 .53559 L
s
.39537 .5367 m
.39672 .53845 L
s
0 0 0 r
.004 w
.31253 .49168 Mdot
.53 .8 .95 r
.006 w
.38515 .52976 m
.38581 .52741 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.50995 .49162 m
.50982 .49128 L
s
.50995 .49162 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54018 .55352 m
.53855 .5522 L
s
.39672 .53845 m
.39804 .54155 L
s
.66083 .56826 m
.66316 .57257 L
s
.3837 .53346 m
.38439 .53205 L
s
.38439 .53205 m
.38515 .52976 L
s
1 .653 0 r
.01 w
[ .05 .05 ] 0 setdash
.50982 .49128 m
.50976 .49093 L
s
.50982 .49128 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53855 .5522 m
.53692 .55159 L
s
1 .978 0 r
.01 w
.341 .49118 Mdot
[ .05 .05 ] 0 setdash
.3387 .48956 m
.341 .49118 L
s
0 0 0 r
.004 w
.73759 .49113 Mdot
1 .692 0 r
.01 w
.63499 .49112 Mdot
.63549 .48993 m
.63499 .49112 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62979 .51257 m
.62915 .51358 L
s
.63037 .51234 m
.62979 .51257 L
s
.62915 .51358 m
.62846 .51509 L
s
.39804 .54155 m
.39934 .54626 L
s
1 .653 0 r
.01 w
[ .05 .05 ] 0 setdash
.50976 .49093 m
.50974 .49055 L
s
.50976 .49093 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62448 .5188 m
.62368 .51806 L
s
.63091 .51294 m
.63037 .51234 L
s
1 .889 0 r
.01 w
[ .05 .05 ] 0 setdash
.72335 .49064 m
.72572 .48957 L
s
.72335 .49064 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53692 .55159 m
.53525 .55131 L
s
.62846 .51509 m
.6277 .51669 L
s
1 .653 0 r
.01 w
[ .05 .05 ] 0 setdash
.50974 .49055 m
.50975 .49016 L
s
.50974 .49055 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51845 .52551 m
.51795 .52993 L
s
.62027 .52396 m
.62015 .53055 L
s
0 0 0 r
.004 w
.73906 .49039 Mdot
.53 .8 .95 r
.006 w
.52601 .54108 m
.52484 .53711 L
s
.62531 .5193 m
.62448 .5188 L
s
1 .653 0 r
.01 w
[ .05 .05 ] 0 setdash
.50975 .49016 m
.50976 .48976 L
s
.50975 .49016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6277 .51669 m
.62688 .51811 L
s
.41618 .57985 m
.41865 .57741 L
s
.63142 .51441 m
.63091 .51294 L
s
1 .692 0 r
.01 w
.63549 .48993 Mdot
1 .693 0 r
[ .05 .05 ] 0 setdash
.63592 .48877 m
.63549 .48993 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61778 .56428 m
.61752 .5642 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.50976 .48976 m
.50973 .48936 L
s
.50976 .48976 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62688 .51811 m
.62614 .51916 L
s
.53525 .55131 m
.5336 .55096 L
s
.62614 .51916 m
.62531 .5193 L
s
.39934 .54626 m
.40073 .5514 L
s
0 0 0 r
.004 w
.74053 .48965 Mdot
1 .889 0 r
.01 w
[ .05 .05 ] 0 setdash
.72572 .48957 m
.72784 .48863 L
s
.72572 .48957 Mdot
1 .978 0 r
.3387 .48956 Mdot
.33629 .48782 m
.3387 .48956 L
s
0 0 0 r
.004 w
.30797 .4894 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35874 .538 m
.36018 .53426 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.50973 .48936 m
.50967 .48893 L
s
.50973 .48936 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52739 .54481 m
.52601 .54108 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.50967 .48893 m
.5096 .48848 L
s
.50967 .48893 Mdot
0 0 0 r
.004 w
.742 .4889 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5336 .55096 m
.53197 .55002 L
s
1 .693 0 r
.01 w
.63592 .48877 Mdot
[ .05 .05 ] 0 setdash
.6363 .48765 m
.63592 .48877 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63196 .5161 m
.63142 .51441 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73087 .53926 m
.72784 .48863 L
s
1 .889 0 r
.01 w
[ .05 .05 ] 0 setdash
.72784 .48863 m
.72979 .48781 L
s
.72784 .48863 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.50952 .50557 m
.5096 .48848 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.5096 .48848 m
.50952 .48805 L
s
.5096 .48848 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40073 .5514 m
.40225 .55765 L
s
.53197 .55002 m
.53032 .54893 L
s
.62015 .53055 m
.62003 .53735 L
s
0 0 0 r
.004 w
.74346 .48815 Mdot
.53 .8 .95 r
.006 w
.66316 .57257 m
.6659 .57669 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.50952 .48805 m
.50948 .48767 L
s
.50952 .48805 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52884 .54756 m
.52739 .54481 L
s
1 .978 0 r
.01 w
.33629 .48782 Mdot
1 .979 0 r
[ .05 .05 ] 0 setdash
.33405 .48618 m
.33629 .48782 L
s
1 .888 0 r
.72979 .48781 m
.73146 .48712 L
s
.72979 .48781 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53032 .54893 m
.52884 .54756 L
s
1 .651 0 r
.01 w
[ .05 .05 ] 0 setdash
.50948 .48767 m
.50946 .48736 L
s
.50948 .48767 Mdot
1 .693 0 r
.6363 .48765 Mdot
.63661 .48637 m
.6363 .48765 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61808 .56396 m
.61778 .56428 L
s
1 .808 0 r
.01 w
[ .05 .05 ] 0 setdash
.72467 .48762 m
.72457 .48762 L
s
.72467 .48762 Mdot
.72481 .4876 m
.72467 .48762 L
s
.72457 .48762 m
.72453 .48761 L
s
.72457 .48762 Mdot
.72453 .48761 m
.72454 .48758 L
s
.72453 .48761 Mdot
.72481 .4876 Mdot
1 .809 0 r
.72503 .48757 m
.72481 .4876 L
s
1 .808 0 r
.72454 .48758 m
.72458 .48755 L
s
.72454 .48758 Mdot
1 .809 0 r
.72503 .48757 Mdot
.72534 .48753 m
.72503 .48757 L
s
1 .807 0 r
.72458 .48755 m
.72463 .4875 L
s
.72458 .48755 Mdot
1 .801 0 r
.7246 .48754 m
.72436 .48753 L
s
.7246 .48754 Mdot
.72496 .48751 m
.7246 .48754 L
s
1 .809 0 r
.72534 .48753 Mdot
.72573 .48748 m
.72534 .48753 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72452 .49021 m
.72436 .48753 L
s
1 .801 0 r
.01 w
[ .05 .05 ] 0 setdash
.72436 .48753 m
.72426 .4875 L
s
.72436 .48753 Mdot
.72496 .48751 Mdot
.72542 .48745 m
.72496 .48751 L
s
1 .807 0 r
.72463 .4875 m
.72467 .48745 L
s
.72463 .4875 Mdot
1 .8 0 r
.72426 .4875 m
.7243 .48746 L
s
.72426 .4875 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72622 .49584 m
.72573 .48748 L
s
1 .809 0 r
.01 w
.72573 .48748 Mdot
[ .05 .05 ] 0 setdash
.72617 .4874 m
.72573 .48748 L
s
1 .8 0 r
.7243 .48746 m
.72445 .48741 L
s
.7243 .48746 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72477 .48924 m
.72467 .48745 L
s
1 .807 0 r
.01 w
[ .05 .05 ] 0 setdash
.72467 .48745 m
.72472 .4874 L
s
.72467 .48745 Mdot
1 .801 0 r
.72542 .48745 Mdot
1 .802 0 r
.72593 .48736 m
.72542 .48745 L
s
1 .8 0 r
.72445 .48741 m
.72471 .48735 L
s
.72445 .48741 Mdot
1 .807 0 r
.72472 .4874 m
.72478 .48737 L
s
.72472 .4874 Mdot
1 .809 0 r
.72617 .4874 Mdot
.7267 .48732 m
.72617 .4874 L
s
0 0 0 r
.004 w
.74492 .48739 Mdot
1 .807 0 r
.01 w
.72478 .48737 m
.72482 .48735 L
s
.72478 .48737 Mdot
1 .651 0 r
.50946 .48736 m
.50946 .48712 L
s
.50946 .48736 Mdot
1 .802 0 r
.72593 .48736 Mdot
.7264 .48726 m
.72593 .48736 L
s
1 .806 0 r
.72482 .48735 m
.72485 .48733 L
s
.72482 .48735 Mdot
1 .8 0 r
.72471 .48735 m
.72503 .48727 L
s
.72471 .48735 Mdot
1 .806 0 r
.72498 .48734 m
.72506 .48733 L
s
.72498 .48734 Mdot
.7249 .48733 m
.72498 .48734 L
s
1 .805 0 r
.72506 .48733 m
.72517 .48731 L
s
.72506 .48733 Mdot
1 .806 0 r
.72485 .48733 m
.7249 .48733 L
s
.72485 .48733 Mdot
.7249 .48733 Mdot
1 .809 0 r
.7267 .48732 Mdot
1 .81 0 r
.72725 .48724 m
.7267 .48732 L
s
1 .805 0 r
.72517 .48731 m
.72529 .48728 L
s
.72517 .48731 Mdot
.72529 .48728 m
.72547 .48724 L
s
.72529 .48728 Mdot
1 .8 0 r
.72503 .48727 m
.72541 .48718 L
s
.72503 .48727 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51795 .52993 m
.51745 .53447 L
s
1 .802 0 r
.01 w
.7264 .48726 Mdot
[ .05 .05 ] 0 setdash
.72688 .48717 m
.7264 .48726 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72457 .48831 m
.72461 .48881 L
s
.72463 .48858 m
.72457 .48831 L
s
.41377 .58181 m
.41618 .57985 L
s
1 .81 0 r
.01 w
.72725 .48724 Mdot
[ .05 .05 ] 0 setdash
.72782 .48715 m
.72725 .48724 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72565 .49031 m
.72547 .48724 L
s
1 .805 0 r
.01 w
[ .05 .05 ] 0 setdash
.72547 .48724 m
.72567 .48719 L
s
.72547 .48724 Mdot
.72567 .48719 m
.7259 .48713 L
s
.72567 .48719 Mdot
1 .799 0 r
.72541 .48718 m
.72584 .4871 L
s
.72541 .48718 Mdot
1 .802 0 r
.72688 .48717 Mdot
.72732 .48709 m
.72688 .48717 L
s
1 .81 0 r
.72782 .48715 Mdot
.72835 .48707 m
.72782 .48715 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72478 .48946 m
.72463 .48858 L
s
.63254 .51885 m
.63196 .5161 L
s
1 .804 0 r
.01 w
[ .05 .05 ] 0 setdash
.7259 .48713 m
.72615 .48708 L
s
.7259 .48713 Mdot
1 .888 0 r
.73146 .48712 m
.73279 .4866 L
s
.73146 .48712 Mdot
1 .651 0 r
.50946 .48712 m
.50948 .48695 L
s
.50946 .48712 Mdot
1 .799 0 r
.72584 .4871 m
.72627 .48701 L
s
.72584 .4871 Mdot
1 .802 0 r
.72732 .48709 Mdot
.72763 .48701 m
.72732 .48709 L
s
1 .804 0 r
.72615 .48708 m
.72646 .48703 L
s
.72615 .48708 Mdot
1 .81 0 r
.72835 .48707 Mdot
.72884 .487 m
.72835 .48707 L
s
1 .804 0 r
.72646 .48703 m
.72677 .48701 L
s
.72646 .48703 Mdot
1 .802 0 r
.72763 .48701 Mdot
1 .803 0 r
.72783 .48696 m
.72763 .48701 L
s
1 .799 0 r
.72627 .48701 m
.72666 .48691 L
s
.72627 .48701 Mdot
1 .804 0 r
.72677 .48701 m
.72712 .48699 L
s
.72677 .48701 Mdot
1 .81 0 r
.72884 .487 Mdot
1 .811 0 r
.72926 .48697 m
.72884 .487 L
s
1 .804 0 r
.72712 .48699 m
.72744 .48697 L
s
.72712 .48699 Mdot
1 .65 0 r
.50978 .48698 m
.50969 .48693 L
s
.50978 .48698 Mdot
.50979 .48697 m
.50978 .48698 L
s
1 .811 0 r
.72926 .48697 Mdot
.72957 .48695 m
.72926 .48697 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.50978 .4883 m
.50979 .48697 L
s
1 .65 0 r
.01 w
.50979 .48697 Mdot
[ .05 .05 ] 0 setdash
.50975 .48693 m
.50979 .48697 L
s
1 .803 0 r
.72744 .48697 m
.72772 .48694 L
s
.72744 .48697 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72461 .48881 m
.72468 .48923 L
s
1 .803 0 r
.01 w
.72783 .48696 Mdot
[ .05 .05 ] 0 setdash
.72794 .48692 m
.72783 .48696 L
s
1 .651 0 r
.50948 .48695 m
.50954 .48687 L
s
.50948 .48695 Mdot
1 .811 0 r
.72957 .48695 Mdot
.72977 .48693 m
.72957 .48695 L
s
1 .812 0 r
.72969 .48695 m
.72983 .48694 L
s
.72969 .48695 Mdot
.72946 .48694 m
.72969 .48695 L
s
1 .811 0 r
.72983 .48694 m
.72986 .48693 L
s
.72983 .48694 Mdot
1 .803 0 r
.72772 .48694 m
.7279 .48693 L
s
.72772 .48694 Mdot
1 .812 0 r
.72946 .48694 Mdot
.72921 .4869 m
.72946 .48694 L
s
1 .65 0 r
.50975 .48693 Mdot
.50969 .48689 m
.50975 .48693 L
s
1 .649 0 r
.50969 .48693 m
.50949 .48682 L
s
.50969 .48693 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72988 .48726 m
.72986 .48693 L
s
1 .811 0 r
.01 w
[ .05 .05 ] 0 setdash
.72986 .48693 m
.72977 .48693 L
s
.72986 .48693 Mdot
.72977 .48693 Mdot
1 .803 0 r
.7279 .48693 m
.72794 .48692 L
s
.7279 .48693 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72804 .48871 m
.72794 .48692 L
s
1 .803 0 r
.01 w
.72794 .48692 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72433 .48866 m
.72455 .49182 L
s
.72452 .49021 m
.72433 .48866 L
s
0 0 0 r
.004 w
.30319 .48692 Mdot
1 .799 0 r
.01 w
[ .05 .05 ] 0 setdash
.72666 .48691 m
.72702 .4868 L
s
.72666 .48691 Mdot
1 .812 0 r
.72921 .4869 Mdot
.72897 .48683 m
.72921 .4869 L
s
1 .65 0 r
.50969 .48689 Mdot
.50962 .48686 m
.50969 .48689 L
s
1 .651 0 r
.50954 .48687 m
.50962 .48686 L
s
.50954 .48687 Mdot
1 .65 0 r
.50962 .48686 Mdot
1 .812 0 r
.72897 .48683 Mdot
.72878 .48672 m
.72897 .48683 L
s
1 .649 0 r
.50949 .48682 m
.50912 .48662 L
s
.50949 .48682 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72746 .49417 m
.72702 .4868 L
s
1 .799 0 r
.01 w
[ .05 .05 ] 0 setdash
.72702 .4868 m
.72738 .48668 L
s
.72702 .4868 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40225 .55765 m
.40383 .56405 L
s
.72988 .48726 m
.72995 .49002 L
s
.72998 .48944 m
.72988 .48726 L
s
.50978 .4874 m
.50968 .49017 L
s
.50978 .4883 m
.50978 .4874 L
s
1 .812 0 r
.01 w
.72878 .48672 Mdot
1 .813 0 r
[ .05 .05 ] 0 setdash
.72865 .48659 m
.72878 .48672 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72492 .48855 m
.72499 .48882 L
s
.7249 .48877 m
.72492 .48855 L
s
.72468 .48923 m
.72473 .48937 L
s
.72496 .49018 m
.72478 .48946 L
s
1 .798 0 r
.01 w
[ .05 .05 ] 0 setdash
.72738 .48668 m
.72775 .48656 L
s
.72738 .48668 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72488 .48906 m
.7249 .48877 L
s
1 .649 0 r
.01 w
[ .05 .05 ] 0 setdash
.50912 .48662 m
.50856 .48634 L
s
.50912 .48662 Mdot
0 0 0 r
.004 w
.74638 .48662 Mdot
1 .888 0 r
.01 w
.73279 .4866 m
.73392 .48618 L
s
.73279 .4866 Mdot
1 .813 0 r
.72865 .48659 Mdot
.72861 .48643 m
.72865 .48659 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72499 .48882 m
.72507 .48897 L
s
.72473 .48937 m
.72477 .48924 L
s
.51009 .50273 m
.5099 .50193 L
s
.51035 .505 m
.51009 .50273 L
s
1 .798 0 r
.01 w
[ .05 .05 ] 0 setdash
.72775 .48656 m
.72816 .48643 L
s
.72775 .48656 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35713 .54228 m
.35874 .538 L
s
.72477 .48924 m
.72484 .48941 L
s
.72484 .48941 m
.72488 .48906 L
s
.72507 .48897 m
.72517 .48919 L
s
.5099 .50193 m
.50978 .50226 L
s
.50953 .48772 m
.50961 .48849 L
s
.50947 .48995 m
.50953 .48772 L
s
1 .798 0 r
.01 w
[ .05 .05 ] 0 setdash
.72816 .48643 m
.72858 .48632 L
s
.72816 .48643 Mdot
1 .813 0 r
.72861 .48643 Mdot
.72868 .48625 m
.72861 .48643 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72517 .48919 m
.72529 .4894 L
s
1 .693 0 r
.01 w
.63661 .48637 Mdot
[ .05 .05 ] 0 setdash
.63697 .48507 m
.63661 .48637 L
s
1 .649 0 r
.50856 .48634 m
.5078 .48599 L
s
.50856 .48634 Mdot
1 .798 0 r
.72858 .48632 m
.72906 .4862 L
s
.72858 .48632 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72528 .49182 m
.72496 .49018 L
s
.50974 .48916 m
.50978 .4883 L
s
.72529 .4894 m
.72543 .48961 L
s
1 .813 0 r
.01 w
.72868 .48625 Mdot
[ .05 .05 ] 0 setdash
.72879 .48605 m
.72868 .48625 L
s
1 .798 0 r
.72906 .4862 m
.72961 .4861 L
s
.72906 .4862 Mdot
1 .888 0 r
.73392 .48618 m
.73479 .48588 L
s
.73392 .48618 Mdot
1 .979 0 r
.33405 .48618 Mdot
.33184 .48453 m
.33405 .48618 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72499 .49418 m
.72452 .49021 L
s
.72543 .48961 m
.72565 .49031 L
s
1 .797 0 r
.01 w
[ .05 .05 ] 0 setdash
.72961 .4861 m
.73021 .48601 L
s
.72961 .4861 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72934 .49514 m
.72879 .48605 L
s
1 .813 0 r
.01 w
.72879 .48605 Mdot
[ .05 .05 ] 0 setdash
.72896 .48585 m
.72879 .48605 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50961 .48849 m
.50968 .48924 L
s
.72804 .48871 m
.72803 .49035 L
s
.72809 .49006 m
.72804 .48871 L
s
.62003 .53735 m
.61986 .54297 L
s
1 .797 0 r
.01 w
[ .05 .05 ] 0 setdash
.73021 .48601 m
.73082 .48594 L
s
.73021 .48601 Mdot
1 .649 0 r
.5078 .48599 m
.5068 .48555 L
s
.5078 .48599 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5107 .50884 m
.51035 .505 L
s
1 .797 0 r
.01 w
[ .05 .05 ] 0 setdash
.73082 .48594 m
.73141 .48589 L
s
.73082 .48594 Mdot
.73141 .48589 m
.732 .48586 L
s
.73141 .48589 Mdot
1 .888 0 r
.73479 .48588 m
.73542 .48567 L
s
.73479 .48588 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.73278 .49869 m
.732 .48586 L
s
1 .796 0 r
.01 w
[ .05 .05 ] 0 setdash
.732 .48586 m
.73256 .48582 L
s
.732 .48586 Mdot
1 .813 0 r
.72896 .48585 Mdot
1 .814 0 r
.72917 .48567 m
.72896 .48585 L
s
1 .885 0 r
.73447 .48584 m
.73429 .48581 L
s
.73447 .48584 Mdot
1 .886 0 r
.73469 .48584 m
.73447 .48584 L
s
0 0 0 r
.004 w
.74783 .48584 Mdot
1 .886 0 r
.01 w
.73469 .48584 Mdot
.73495 .4858 m
.73469 .48584 L
s
1 .796 0 r
.73256 .48582 m
.7331 .48577 L
s
.73256 .48582 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50968 .48924 m
.50974 .48916 L
s
1 .885 0 r
.01 w
[ .05 .05 ] 0 setdash
.73429 .48581 m
.73421 .48572 L
s
.73429 .48581 Mdot
1 .886 0 r
.73495 .4858 Mdot
.73522 .48574 m
.73495 .4858 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50978 .50226 m
.5097 .50337 L
s
1 .796 0 r
.01 w
[ .05 .05 ] 0 setdash
.7331 .48577 m
.73359 .48572 L
s
.7331 .48577 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61836 .56163 m
.61808 .56396 L
s
1 .886 0 r
.01 w
.73522 .48574 Mdot
[ .05 .05 ] 0 setdash
.7355 .48566 m
.73522 .48574 L
s
1 .885 0 r
.73421 .48572 m
.73429 .48556 L
s
.73421 .48572 Mdot
1 .796 0 r
.73359 .48572 m
.73406 .48563 L
s
.73359 .48572 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72996 .49136 m
.72998 .48944 L
s
.72565 .49031 m
.7259 .49124 L
s
1 .814 0 r
.01 w
.72917 .48567 Mdot
[ .05 .05 ] 0 setdash
.72951 .48548 m
.72917 .48567 L
s
1 .887 0 r
.73542 .48567 m
.73582 .48554 L
s
.73542 .48567 Mdot
1 .886 0 r
.7355 .48566 Mdot
.73575 .48558 m
.7355 .48566 L
s
1 .796 0 r
.73406 .48563 m
.73453 .48551 L
s
.73406 .48563 Mdot
1 .886 0 r
.73575 .48558 Mdot
1 .887 0 r
.73596 .48551 m
.73575 .48558 L
s
1 .885 0 r
.73429 .48556 m
.73452 .48534 L
s
.73429 .48556 Mdot
1 .648 0 r
.5068 .48555 m
.50565 .48508 L
s
.5068 .48555 Mdot
1 .887 0 r
.73582 .48554 m
.73602 .48548 L
s
.73582 .48554 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.7362 .48935 m
.73596 .48551 L
s
1 .887 0 r
.01 w
.73596 .48551 Mdot
[ .05 .05 ] 0 setdash
.73606 .48548 m
.73596 .48551 L
s
1 .795 0 r
.73453 .48551 m
.73497 .48534 L
s
.73453 .48551 Mdot
1 .814 0 r
.72951 .48548 Mdot
.72981 .48529 m
.72951 .48548 L
s
1 .887 0 r
.73602 .48548 m
.73606 .48548 L
s
.73602 .48548 Mdot
.73606 .48548 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50943 .49308 m
.50947 .48995 L
s
.7257 .49373 m
.72528 .49182 L
s
.72995 .49002 m
.72995 .49338 L
s
.72804 .49242 m
.72809 .49006 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73518 .49616 m
.73452 .48534 L
s
1 .885 0 r
.01 w
[ .05 .05 ] 0 setdash
.73452 .48534 m
.73493 .48505 L
s
.73452 .48534 Mdot
1 .795 0 r
.73497 .48534 m
.7354 .48512 L
s
.73497 .48534 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50968 .49017 m
.50945 .49395 L
s
1 .814 0 r
.01 w
.72981 .48529 Mdot
[ .05 .05 ] 0 setdash
.73008 .48509 m
.72981 .48529 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72455 .49182 m
.72485 .4943 L
s
.72803 .49035 m
.72801 .49343 L
s
.40383 .56405 m
.40536 .56964 L
s
.7259 .49124 m
.7262 .49225 L
s
1 .795 0 r
.01 w
[ .05 .05 ] 0 setdash
.7354 .48512 m
.73585 .48485 L
s
.7354 .48512 Mdot
1 .814 0 r
.73008 .48509 Mdot
1 .815 0 r
.7303 .48489 m
.73008 .48509 L
s
1 .648 0 r
.50565 .48508 m
.50421 .48452 L
s
.50565 .48508 Mdot
1 .693 0 r
.63697 .48507 Mdot
.63737 .48386 m
.63697 .48507 L
s
0 0 0 r
.004 w
.74928 .48506 Mdot
1 .884 0 r
.01 w
.73493 .48505 m
.73551 .48468 L
s
.73493 .48505 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73609 .48649 m
.73618 .48742 L
s
.73613 .4905 m
.73609 .48649 L
s
.63314 .52185 m
.63254 .51885 L
s
1 .815 0 r
.01 w
.7303 .48489 Mdot
[ .05 .05 ] 0 setdash
.73042 .48465 m
.7303 .48489 L
s
1 .795 0 r
.73585 .48485 m
.73631 .48457 L
s
.73585 .48485 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72985 .49347 m
.72996 .49136 L
s
.61875 .55971 m
.61836 .56163 L
s
.51113 .51377 m
.5107 .50884 L
s
.5097 .50337 m
.50967 .50473 L
s
1 .884 0 r
.01 w
[ .05 .05 ] 0 setdash
.73551 .48468 m
.73633 .48423 L
s
.73551 .48468 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41138 .58107 m
.41377 .58181 L
s
.6659 .57669 m
.66843 .58004 L
s
1 .815 0 r
.01 w
.73042 .48465 Mdot
[ .05 .05 ] 0 setdash
.73041 .4844 m
.73042 .48465 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61986 .54297 m
.61963 .54804 L
s
1 .795 0 r
.01 w
[ .05 .05 ] 0 setdash
.73631 .48457 m
.73673 .48427 L
s
.73631 .48457 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7262 .49225 m
.72649 .49282 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.32771 .55747 m
.33184 .48453 L
s
1 .979 0 r
.01 w
.33184 .48453 Mdot
[ .05 .05 ] 0 setdash
.32965 .48287 m
.33184 .48453 L
s
1 .648 0 r
.50421 .48452 m
.50264 .48393 L
s
.50421 .48452 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73618 .48742 m
.7362 .48935 L
s
.72622 .49584 m
.7257 .49373 L
s
1 .815 0 r
.01 w
.73041 .4844 Mdot
[ .05 .05 ] 0 setdash
.73025 .48414 m
.73041 .4844 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73447 .48876 m
.73446 .48966 L
s
.73474 .49011 m
.73447 .48876 L
s
0 0 0 r
.004 w
.75072 .48427 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.73779 .5012 m
.73673 .48427 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.73673 .48427 m
.73721 .48394 L
s
.73673 .48427 Mdot
1 .884 0 r
.73633 .48423 m
.7374 .48371 L
s
.73633 .48423 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72554 .49736 m
.72499 .49418 L
s
0 0 0 r
.004 w
.29813 .48419 Mdot
.53 .8 .95 r
.006 w
.72787 .49409 m
.72804 .49242 L
s
.72649 .49282 m
.72686 .49381 L
s
1 .815 0 r
.01 w
.73025 .48414 Mdot
[ .05 .05 ] 0 setdash
.72997 .48387 m
.73025 .48414 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50942 .49652 m
.50943 .49308 L
s
.51745 .53447 m
.51681 .53776 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.73721 .48394 m
.73773 .48361 L
s
.73721 .48394 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72485 .4943 m
.7252 .49566 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.50236 .52778 m
.50264 .48393 L
s
1 .648 0 r
.01 w
[ .05 .05 ] 0 setdash
.50264 .48393 m
.50075 .48327 L
s
.50264 .48393 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.73077 .49721 m
.72997 .48387 L
s
1 .815 0 r
.01 w
.72997 .48387 Mdot
1 .816 0 r
[ .05 .05 ] 0 setdash
.72956 .48357 m
.72997 .48387 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40536 .56964 m
.40708 .57406 L
s
1 .693 0 r
.01 w
.63737 .48386 Mdot
1 .694 0 r
[ .05 .05 ] 0 setdash
.63766 .48262 m
.63737 .48386 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72801 .49343 m
.72785 .49599 L
s
.73446 .48966 m
.73469 .49211 L
s
.72995 .49338 m
.7298 .49596 L
s
1 .884 0 r
.01 w
[ .05 .05 ] 0 setdash
.7374 .48371 m
.73873 .48309 L
s
.7374 .48371 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72914 .49272 m
.72936 .49328 L
s
.72901 .49271 m
.72914 .49272 L
s
.73498 .49051 m
.73474 .49011 L
s
.61963 .54804 m
.61934 .5529 L
s
.72965 .49414 m
.72985 .49347 L
s
.72686 .49381 m
.72723 .49479 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.73773 .48361 m
.7383 .48328 L
s
.73773 .48361 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72936 .49328 m
.72965 .49414 L
s
.7362 .48935 m
.73605 .49042 L
s
1 .816 0 r
.01 w
.72956 .48357 Mdot
[ .05 .05 ] 0 setdash
.72905 .48326 m
.72956 .48357 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61911 .55711 m
.61875 .55971 L
s
.72904 .49362 m
.72901 .49271 L
s
.73529 .49117 m
.73498 .49051 L
s
0 0 0 r
.004 w
.75216 .48347 Mdot
.53 .8 .95 r
.006 w
.50967 .50473 m
.50968 .50602 L
s
.72761 .49527 m
.72787 .49409 L
s
.72777 .49325 m
.72816 .49343 L
s
.72746 .49417 m
.72777 .49325 L
s
.35527 .54733 m
.35713 .54228 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.7383 .48328 m
.73891 .48297 L
s
.7383 .48328 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40913 .57791 m
.41138 .58107 L
s
.72675 .49717 m
.72622 .49584 L
s
1 .647 0 r
.01 w
[ .05 .05 ] 0 setdash
.50075 .48327 m
.49883 .4826 L
s
.50075 .48327 Mdot
1 .816 0 r
.72905 .48326 Mdot
.72846 .48295 m
.72905 .48326 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50945 .49395 m
.50907 .4984 L
s
.40708 .57406 m
.40913 .57791 L
s
.7252 .49566 m
.72558 .49667 L
s
.73605 .49042 m
.73586 .49154 L
s
.72723 .49479 m
.72761 .49527 L
s
.73557 .49141 m
.73529 .49117 L
s
.72816 .49343 m
.72862 .49421 L
s
.72714 .49491 m
.72746 .49417 L
s
1 .883 0 r
.01 w
[ .05 .05 ] 0 setdash
.73873 .48309 m
.7403 .48238 L
s
.73873 .48309 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73604 .4957 m
.73613 .4905 L
s
.61934 .5529 m
.61911 .55711 L
s
.51161 .5191 m
.51113 .51377 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.73891 .48297 m
.73952 .4827 L
s
.73891 .48297 Mdot
1 .816 0 r
.72846 .48295 Mdot
.72778 .48262 m
.72846 .48295 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73586 .49154 m
.73557 .49141 L
s
.72677 .49557 m
.72714 .49491 L
s
1 .979 0 r
.01 w
.32965 .48287 Mdot
[ .05 .05 ] 0 setdash
.32757 .48127 m
.32965 .48287 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72916 .49418 m
.72904 .49362 L
s
.50942 .5 m
.50942 .49652 L
s
.72639 .49643 m
.72677 .49557 L
s
1 .793 0 r
.01 w
[ .05 .05 ] 0 setdash
.73952 .4827 m
.74007 .48246 L
s
.73952 .4827 Mdot
0 0 0 r
.004 w
.7536 .48267 Mdot
1 .816 0 r
.01 w
.72778 .48262 Mdot
.72706 .48227 m
.72778 .48262 L
s
1 .694 0 r
.63766 .48262 Mdot
.63804 .4815 m
.63766 .48262 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72785 .49599 m
.72752 .49801 L
s
1 .647 0 r
.01 w
[ .05 .05 ] 0 setdash
.49883 .4826 m
.49664 .48187 L
s
.49883 .4826 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72613 .49946 m
.72554 .49736 L
s
.72558 .49667 m
.72598 .49679 L
s
.72862 .49421 m
.72915 .49581 L
s
.63376 .52493 m
.63314 .52185 L
s
.72739 .49893 m
.72675 .49717 L
s
1 .793 0 r
.01 w
[ .05 .05 ] 0 setdash
.74007 .48246 m
.74054 .48225 L
s
.74007 .48246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7298 .49596 m
.72949 .49785 L
s
.72598 .49679 m
.72639 .49643 L
s
1 .883 0 r
.01 w
[ .05 .05 ] 0 setdash
.7403 .48238 m
.74203 .48162 L
s
.7403 .48238 Mdot
1 .816 0 r
.72706 .48227 Mdot
1 .817 0 r
.72628 .48188 m
.72706 .48227 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73469 .49211 m
.73518 .49616 L
s
.72934 .49514 m
.72916 .49418 L
s
1 .793 0 r
.01 w
[ .05 .05 ] 0 setdash
.74054 .48225 m
.7409 .48209 L
s
.74054 .48225 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50968 .50602 m
.50968 .50737 L
s
1 .793 0 r
.01 w
[ .05 .05 ] 0 setdash
.7409 .48209 m
.74114 .48196 L
s
.7409 .48209 Mdot
1 .792 0 r
.74114 .48196 m
.74129 .48187 L
s
.74114 .48196 Mdot
1 .817 0 r
.72628 .48188 Mdot
.72553 .48153 m
.72628 .48188 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74152 .48545 m
.74129 .48187 L
s
1 .792 0 r
.01 w
[ .05 .05 ] 0 setdash
.74129 .48187 m
.74131 .48179 L
s
.74129 .48187 Mdot
1 .647 0 r
.49664 .48187 m
.49432 .4811 L
s
.49664 .48187 Mdot
0 0 0 r
.004 w
.75503 .48186 Mdot
1 .792 0 r
.01 w
.74131 .48179 m
.74123 .4817 L
s
.74131 .48179 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72752 .49801 m
.72713 .49955 L
s
1 .792 0 r
.01 w
[ .05 .05 ] 0 setdash
.74123 .4817 m
.74107 .48158 L
s
.74123 .4817 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66843 .58004 m
.67124 .58222 L
s
1 .883 0 r
.01 w
[ .05 .05 ] 0 setdash
.74203 .48162 m
.74399 .48077 L
s
.74203 .48162 Mdot
1 .792 0 r
.74107 .48158 m
.74083 .48143 L
s
.74107 .48158 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72949 .49785 m
.72909 .49941 L
s
.72915 .49581 m
.72976 .49777 L
s
1 .817 0 r
.01 w
.72553 .48153 Mdot
[ .05 .05 ] 0 setdash
.72466 .48104 m
.72553 .48153 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6395 .52505 m
.63804 .4815 L
s
1 .694 0 r
.01 w
.63804 .4815 Mdot
[ .05 .05 ] 0 setdash
.63842 .48023 m
.63804 .4815 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72801 .49998 m
.72739 .49893 L
s
.50945 .50321 m
.50942 .5 L
s
.72955 .49572 m
.72934 .49514 L
s
1 .791 0 r
.01 w
[ .05 .05 ] 0 setdash
.74083 .48143 m
.74046 .48125 L
s
.74083 .48143 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7267 .50039 m
.72613 .49946 L
s
.73459 .49424 m
.73505 .49393 L
s
.73415 .49486 m
.73459 .49424 L
s
1 .979 0 r
.01 w
.32757 .48127 Mdot
[ .05 .05 ] 0 setdash
.3256 .47974 m
.32757 .48127 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73073 .49206 m
.73056 .49305 L
s
.73083 .49136 m
.73073 .49206 L
s
.73091 .49263 m
.73083 .49136 L
s
.73505 .49393 m
.73556 .49486 L
s
1 .791 0 r
.01 w
[ .05 .05 ] 0 setdash
.74046 .48125 m
.73996 .48104 L
s
.74046 .48125 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51222 .52464 m
.51161 .5191 L
s
0 0 0 r
.004 w
.29273 .48115 Mdot
.53 .8 .95 r
.006 w
.51681 .53776 m
.51597 .53964 L
s
.73373 .49607 m
.73415 .49486 L
s
1 .647 0 r
.01 w
[ .05 .05 ] 0 setdash
.49432 .4811 m
.49213 .48038 L
s
.49432 .4811 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73056 .49305 m
.73034 .49413 L
s
.72713 .49955 m
.7267 .50039 L
s
1 .791 0 r
.01 w
[ .05 .05 ] 0 setdash
.73996 .48104 m
.73932 .48081 L
s
.73996 .48104 Mdot
0 0 0 r
.004 w
.75646 .48104 Mdot
1 .817 0 r
.01 w
.72466 .48104 Mdot
.72379 .48056 m
.72466 .48104 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50968 .50737 m
.50965 .50793 L
s
.72979 .49598 m
.72955 .49572 L
s
.72909 .49941 m
.72861 .50045 L
s
.73034 .49413 m
.73007 .49492 L
s
.72861 .50045 m
.72801 .49998 L
s
1 .791 0 r
.01 w
[ .05 .05 ] 0 setdash
.73932 .48081 m
.73852 .48055 L
s
.73932 .48081 Mdot
1 .883 0 r
.74399 .48077 m
.74612 .47986 L
s
.74399 .48077 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73007 .49492 m
.72979 .49598 L
s
.50907 .4984 m
.50848 .50329 L
s
.73577 .50167 m
.73604 .4957 L
s
.73325 .49718 m
.73373 .49607 L
s
1 .817 0 r
.01 w
.72379 .48056 Mdot
[ .05 .05 ] 0 setdash
.7229 .48005 m
.72379 .48056 L
s
1 .791 0 r
.73852 .48055 m
.7376 .48028 L
s
.73852 .48055 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73556 .49486 m
.7361 .49629 L
s
.50952 .50557 m
.50945 .50321 L
s
.72976 .49777 m
.73041 .49928 L
s
1 .647 0 r
.01 w
[ .05 .05 ] 0 setdash
.49213 .48038 m
.48972 .47962 L
s
.49213 .48038 Mdot
1 .79 0 r
.7376 .48028 m
.73657 .48001 L
s
.7376 .48028 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73089 .49465 m
.73091 .49263 L
s
1 .694 0 r
.01 w
.63842 .48023 Mdot
[ .05 .05 ] 0 setdash
.63886 .47902 m
.63842 .48023 L
s
0 0 0 r
.004 w
.75788 .48021 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73278 .49869 m
.73325 .49718 L
s
.74152 .48545 m
.74158 .48599 L
s
.74146 .48694 m
.74152 .48545 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.7244 .50584 m
.7229 .48005 L
s
1 .817 0 r
.01 w
.7229 .48005 Mdot
1 .818 0 r
[ .05 .05 ] 0 setdash
.72199 .47949 m
.7229 .48005 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50965 .50793 m
.50959 .50736 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73812 .50475 m
.73657 .48001 L
s
1 .79 0 r
.01 w
[ .05 .05 ] 0 setdash
.73657 .48001 m
.73537 .47968 L
s
.73657 .48001 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63439 .52715 m
.63376 .52493 L
s
.73518 .49616 m
.73587 .50025 L
s
.50959 .50736 m
.50952 .50557 L
s
1 .883 0 r
.01 w
[ .05 .05 ] 0 setdash
.74612 .47986 m
.74832 .47892 L
s
.74612 .47986 Mdot
1 .979 0 r
.3256 .47974 Mdot
1 .98 0 r
.32372 .47824 m
.3256 .47974 L
s
1 .79 0 r
.73537 .47968 m
.73424 .47945 L
s
.73537 .47968 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74158 .48599 m
.74162 .48774 L
s
1 .646 0 r
.01 w
[ .05 .05 ] 0 setdash
.48972 .47962 m
.48728 .47888 L
s
.48972 .47962 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51284 .52968 m
.51222 .52464 L
s
1 .818 0 r
.01 w
.72199 .47949 Mdot
[ .05 .05 ] 0 setdash
.72105 .47883 m
.72199 .47949 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7361 .49629 m
.73667 .49812 L
s
.73041 .49928 m
.73106 .50019 L
s
1 .79 0 r
.01 w
[ .05 .05 ] 0 setdash
.73424 .47945 m
.73298 .47916 L
s
.73424 .47945 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74135 .48914 m
.74146 .48694 L
s
.35327 .55256 m
.35527 .54733 L
s
.73225 .49971 m
.73278 .49869 L
s
0 0 0 r
.004 w
.75931 .47938 Mdot
1 .79 0 r
.01 w
[ .05 .05 ] 0 setdash
.73298 .47916 m
.73169 .47886 L
s
.73298 .47916 Mdot
1 .694 0 r
.63886 .47902 Mdot
.63938 .47782 m
.63886 .47902 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67124 .58222 m
.67441 .58384 L
s
.73168 .50024 m
.73225 .49971 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.75207 .53586 m
.74832 .47892 L
s
1 .882 0 r
.01 w
[ .05 .05 ] 0 setdash
.74832 .47892 m
.75051 .47798 L
s
.74832 .47892 Mdot
1 .646 0 r
.48728 .47888 m
.48476 .47812 L
s
.48728 .47888 Mdot
1 .789 0 r
.73169 .47886 m
.73048 .47857 L
s
.73169 .47886 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73106 .50019 m
.73168 .50024 L
s
.73077 .49721 m
.73089 .49465 L
s
1 .818 0 r
.01 w
.72105 .47883 Mdot
[ .05 .05 ] 0 setdash
.72008 .47807 m
.72105 .47883 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51597 .53964 m
.51515 .54018 L
s
.74162 .48774 m
.74158 .48964 L
s
1 .789 0 r
.01 w
[ .05 .05 ] 0 setdash
.73048 .47857 m
.72924 .47829 L
s
.73048 .47857 Mdot
0 0 0 r
.004 w
.76072 .47854 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74112 .49134 m
.74135 .48914 L
s
1 .789 0 r
.01 w
[ .05 .05 ] 0 setdash
.72924 .47829 m
.72813 .47804 L
s
.72924 .47829 Mdot
1 .98 0 r
.32372 .47824 Mdot
.32195 .4768 m
.32372 .47824 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73667 .49812 m
.73727 .49993 L
s
.51355 .53479 m
.51284 .52968 L
s
1 .646 0 r
.01 w
[ .05 .05 ] 0 setdash
.48476 .47812 m
.4824 .47742 L
s
.48476 .47812 Mdot
1 .818 0 r
.72008 .47807 Mdot
.71909 .47725 m
.72008 .47807 L
s
1 .789 0 r
.72813 .47804 m
.72708 .47781 L
s
.72813 .47804 Mdot
1 .882 0 r
.75051 .47798 m
.75275 .47704 L
s
.75051 .47798 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73529 .5085 m
.73577 .50167 L
s
1 .694 0 r
.01 w
.63938 .47782 Mdot
1 .695 0 r
[ .05 .05 ] 0 setdash
.63993 .47661 m
.63938 .47782 L
s
1 .789 0 r
.72708 .47781 m
.72611 .47761 L
s
.72708 .47781 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50848 .50329 m
.50769 .50871 L
s
0 0 0 r
.004 w
.28689 .47771 Mdot
.76214 .47769 Mdot
.53 .8 .95 r
.006 w
.7408 .49388 m
.74112 .49134 L
s
1 .788 0 r
.01 w
[ .05 .05 ] 0 setdash
.72611 .47761 m
.72532 .47746 L
s
.72611 .47761 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63506 .52965 m
.63439 .52715 L
s
.74158 .48964 m
.74148 .49175 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72621 .49249 m
.72532 .47746 L
s
1 .788 0 r
.01 w
[ .05 .05 ] 0 setdash
.72532 .47746 m
.72465 .47735 L
s
.72532 .47746 Mdot
1 .646 0 r
.4824 .47742 m
.48003 .47672 L
s
.4824 .47742 Mdot
1 .786 0 r
.72419 .47741 m
.72445 .4774 L
s
.72419 .47741 Mdot
1 .787 0 r
.72397 .47741 m
.72419 .47741 L
s
.72397 .47741 Mdot
.72379 .47738 m
.72397 .47741 L
s
1 .786 0 r
.72445 .4774 m
.72477 .47736 L
s
.72445 .4774 Mdot
1 .787 0 r
.72379 .47738 Mdot
.72369 .47734 m
.72379 .47738 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73587 .50025 m
.73675 .50465 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72526 .48555 m
.72477 .47736 L
s
1 .786 0 r
.01 w
[ .05 .05 ] 0 setdash
.72477 .47736 m
.72519 .47729 L
s
.72477 .47736 Mdot
1 .788 0 r
.72465 .47735 m
.72414 .47729 L
s
.72465 .47735 Mdot
1 .787 0 r
.72369 .47734 Mdot
.72369 .47729 m
.72369 .47734 L
s
.72369 .47729 Mdot
.72383 .47727 m
.72369 .47729 L
s
1 .786 0 r
.72519 .47729 m
.72572 .47722 L
s
.72519 .47729 Mdot
1 .788 0 r
.72414 .47729 m
.72383 .47727 L
s
.72414 .47729 Mdot
1 .787 0 r
.72383 .47727 Mdot
1 .818 0 r
.71909 .47725 Mdot
.71805 .47626 m
.71909 .47725 L
s
1 .786 0 r
.72572 .47722 m
.72638 .47713 L
s
.72572 .47722 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73051 .49925 m
.73077 .49721 L
s
1 .785 0 r
.01 w
[ .05 .05 ] 0 setdash
.72638 .47713 m
.72717 .47702 L
s
.72638 .47713 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51515 .54018 m
.51429 .53864 L
s
1 .882 0 r
.01 w
[ .05 .05 ] 0 setdash
.75275 .47704 m
.75469 .47619 L
s
.75275 .47704 Mdot
1 .785 0 r
.72717 .47702 m
.72815 .47689 L
s
.72717 .47702 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51429 .53864 m
.51355 .53479 L
s
1 .785 0 r
.01 w
[ .05 .05 ] 0 setdash
.72815 .47689 m
.72932 .47675 L
s
.72815 .47689 Mdot
0 0 0 r
.004 w
.76354 .47684 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73727 .49993 m
.73779 .5012 L
s
1 .98 0 r
.01 w
.32195 .4768 Mdot
[ .05 .05 ] 0 setdash
.32034 .47544 m
.32195 .4768 L
s
1 .785 0 r
.72932 .47675 m
.73067 .47661 L
s
.72932 .47675 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.47931 .53213 m
.48003 .47672 L
s
1 .646 0 r
.01 w
[ .05 .05 ] 0 setdash
.48003 .47672 m
.47767 .47601 L
s
.48003 .47672 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74039 .4965 m
.7408 .49388 L
s
1 .785 0 r
.01 w
[ .05 .05 ] 0 setdash
.73067 .47661 m
.73218 .47648 L
s
.73067 .47661 Mdot
1 .695 0 r
.63993 .47661 Mdot
.64055 .47545 m
.63993 .47661 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72378 .47887 m
.72383 .47968 L
s
.72402 .48062 m
.72378 .47887 L
s
1 .784 0 r
.01 w
[ .05 .05 ] 0 setdash
.73218 .47648 m
.7338 .47633 L
s
.73218 .47648 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67441 .58384 m
.67705 .58333 L
s
1 .784 0 r
.01 w
[ .05 .05 ] 0 setdash
.7338 .47633 m
.73557 .47614 L
s
.7338 .47633 Mdot
1 .818 0 r
.71805 .47626 Mdot
1 .819 0 r
.71702 .47523 m
.71805 .47626 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74148 .49175 m
.74123 .49338 L
s
1 .882 0 r
.01 w
[ .05 .05 ] 0 setdash
.75469 .47619 m
.75667 .47535 L
s
.75469 .47619 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72383 .47968 m
.724 .48082 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73792 .51391 m
.73557 .47614 L
s
1 .784 0 r
.01 w
[ .05 .05 ] 0 setdash
.73557 .47614 m
.73727 .476 L
s
.73557 .47614 Mdot
1 .645 0 r
.47767 .47601 m
.4755 .47536 L
s
.47767 .47601 Mdot
1 .784 0 r
.73727 .476 m
.73911 .47583 L
s
.73727 .476 Mdot
0 0 0 r
.004 w
.76495 .47598 Mdot
1 .783 0 r
.01 w
.73911 .47583 m
.74083 .47563 L
s
.73911 .47583 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73779 .5012 m
.73832 .5018 L
s
.73992 .4989 m
.74039 .4965 L
s
.73013 .50129 m
.73051 .49925 L
s
.724 .48082 m
.72422 .48177 L
s
1 .783 0 r
.01 w
[ .05 .05 ] 0 setdash
.74083 .47563 m
.74255 .47538 L
s
.74083 .47563 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72454 .48403 m
.72402 .48062 L
s
1 .695 0 r
.01 w
.64055 .47545 Mdot
[ .05 .05 ] 0 setdash
.64143 .47417 m
.64055 .47545 L
s
1 .98 0 r
.32034 .47544 Mdot
.31881 .47411 m
.32034 .47544 L
s
1 .783 0 r
.74255 .47538 m
.7443 .47512 L
s
.74255 .47538 Mdot
1 .645 0 r
.4755 .47536 m
.4733 .47468 L
s
.4755 .47536 Mdot
1 .882 0 r
.75667 .47535 m
.75844 .4746 L
s
.75667 .47535 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35113 .55692 m
.35327 .55256 L
s
1 .819 0 r
.01 w
.71702 .47523 Mdot
[ .05 .05 ] 0 setdash
.71609 .4742 m
.71702 .47523 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72422 .48177 m
.7245 .4828 L
s
.67705 .58333 m
.67996 .58225 L
s
1 .783 0 r
.01 w
[ .05 .05 ] 0 setdash
.7443 .47512 m
.74587 .47486 L
s
.7443 .47512 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74123 .49338 m
.74086 .4953 L
s
0 0 0 r
.004 w
.76635 .47511 Mdot
.53 .8 .95 r
.006 w
.7346 .51619 m
.73529 .5085 L
s
.73832 .5018 m
.73884 .50144 L
s
.73938 .50054 m
.73992 .4989 L
s
.63571 .53169 m
.63506 .52965 L
s
1 .783 0 r
.01 w
[ .05 .05 ] 0 setdash
.74587 .47486 m
.7473 .4746 L
s
.74587 .47486 Mdot
1 .645 0 r
.4733 .47468 m
.47112 .47398 L
s
.4733 .47468 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7245 .4828 m
.72484 .48403 L
s
1 .881 0 r
.01 w
[ .05 .05 ] 0 setdash
.75844 .4746 m
.7599 .47397 L
s
.75844 .4746 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73884 .50144 m
.73938 .50054 L
s
.73675 .50465 m
.7379 .50957 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.7473 .4746 m
.74867 .47432 L
s
.7473 .4746 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50769 .50871 m
.50665 .51401 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.74867 .47432 m
.74989 .47404 L
s
.74867 .47432 Mdot
1 .773 0 r
.75749 .47425 m
.75777 .47424 L
s
.75749 .47425 Mdot
.75724 .47422 m
.75749 .47425 L
s
.75777 .47424 m
.75811 .47418 L
s
.75777 .47424 Mdot
0 0 0 r
.004 w
.76775 .47423 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75756 .47886 m
.75724 .47422 L
s
1 .773 0 r
.01 w
.75724 .47422 Mdot
1 .774 0 r
[ .05 .05 ] 0 setdash
.75705 .47415 m
.75724 .47422 L
s
1 .819 0 r
.71609 .4742 Mdot
.71505 .47297 m
.71609 .4742 L
s
1 .773 0 r
.75811 .47418 m
.75846 .47405 L
s
.75811 .47418 Mdot
1 .695 0 r
.64143 .47417 Mdot
.64222 .47291 m
.64143 .47417 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72967 .50309 m
.73013 .50129 L
s
1 .774 0 r
.01 w
.75705 .47415 Mdot
[ .05 .05 ] 0 setdash
.75692 .47403 m
.75705 .47415 L
s
1 .98 0 r
.31881 .47411 Mdot
1 .981 0 r
.31753 .47294 m
.31881 .47411 L
s
1 .773 0 r
.75846 .47405 m
.75883 .47384 L
s
.75846 .47405 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67996 .58225 m
.68289 .58065 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.74989 .47404 m
.75098 .47378 L
s
.74989 .47404 Mdot
1 .774 0 r
.75692 .47403 Mdot
.75683 .47389 m
.75692 .47403 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72484 .48403 m
.72526 .48555 L
s
1 .645 0 r
.01 w
[ .05 .05 ] 0 setdash
.47112 .47398 m
.46895 .47324 L
s
.47112 .47398 Mdot
1 .881 0 r
.7599 .47397 m
.76123 .47338 L
s
.7599 .47397 Mdot
1 .774 0 r
.75683 .47389 Mdot
.75681 .47375 m
.75683 .47389 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72529 .48816 m
.72454 .48403 L
s
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.75883 .47384 m
.75922 .47355 L
s
.75883 .47384 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74086 .4953 m
.74037 .4975 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.75241 .49527 m
.75098 .47378 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.75098 .47378 m
.75198 .47356 L
s
.75098 .47378 Mdot
1 .774 0 r
.75681 .47375 Mdot
.75682 .47362 m
.75681 .47375 L
s
0 0 0 r
.004 w
.28041 .4737 Mdot
1 .777 0 r
.01 w
.75707 .47366 m
.75702 .47366 L
s
.75707 .47366 Mdot
.7571 .47366 m
.75707 .47366 L
s
1 .776 0 r
.75702 .47366 m
.75697 .47365 L
s
.75702 .47366 Mdot
1 .777 0 r
.7571 .47366 Mdot
.75711 .47364 m
.7571 .47366 L
s
1 .776 0 r
.75697 .47365 m
.75691 .47362 L
s
.75697 .47365 Mdot
1 .777 0 r
.75711 .47364 Mdot
.75708 .47359 m
.75711 .47364 L
s
1 .774 0 r
.75682 .47362 Mdot
1 .775 0 r
.75685 .47353 m
.75682 .47362 L
s
1 .776 0 r
.75691 .47362 m
.75688 .47357 L
s
.75691 .47362 Mdot
1 .777 0 r
.75708 .47359 Mdot
.75702 .47352 m
.75708 .47359 L
s
1 .776 0 r
.75688 .47357 m
.75688 .47352 L
s
.75688 .47357 Mdot
1 .782 0 r
.75198 .47356 m
.75285 .47337 L
s
.75198 .47356 Mdot
1 .772 0 r
.75922 .47355 m
.75959 .47317 L
s
.75922 .47355 Mdot
1 .775 0 r
.75685 .47353 Mdot
.75686 .47347 m
.75685 .47353 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75709 .4766 m
.75688 .47352 L
s
1 .776 0 r
.01 w
[ .05 .05 ] 0 setdash
.75688 .47352 m
.75688 .47348 L
s
.75688 .47352 Mdot
1 .777 0 r
.75702 .47352 Mdot
1 .778 0 r
.75697 .47343 m
.75702 .47352 L
s
1 .775 0 r
.75688 .47348 m
.75687 .47345 L
s
.75688 .47348 Mdot
.75686 .47347 Mdot
.75687 .47345 m
.75686 .47347 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7571 .47406 m
.75709 .47468 L
s
.75717 .47471 m
.7571 .47406 L
s
1 .775 0 r
.01 w
.75687 .47345 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75725 .47757 m
.75697 .47343 L
s
1 .778 0 r
.01 w
.75697 .47343 Mdot
[ .05 .05 ] 0 setdash
.75693 .47333 m
.75697 .47343 L
s
1 .881 0 r
.76123 .47338 m
.76238 .47285 L
s
.76123 .47338 Mdot
1 .781 0 r
.75285 .47337 m
.75365 .47322 L
s
.75285 .47337 Mdot
0 0 0 r
.004 w
.76914 .47334 Mdot
1 .778 0 r
.01 w
.75693 .47333 Mdot
.75691 .47323 m
.75693 .47333 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7569 .47381 m
.75695 .4748 L
s
.75703 .47562 m
.7569 .47381 L
s
1 .645 0 r
.01 w
[ .05 .05 ] 0 setdash
.46895 .47324 m
.4669 .47252 L
s
.46895 .47324 Mdot
1 .778 0 r
.75691 .47323 Mdot
.75689 .47314 m
.75691 .47323 L
s
1 .781 0 r
.75365 .47322 m
.75436 .4731 L
s
.75365 .47322 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72526 .48555 m
.72578 .4873 L
s
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.75959 .47317 m
.75993 .47273 L
s
.75959 .47317 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68289 .58065 m
.68612 .57945 L
s
.75709 .47468 m
.75712 .47582 L
s
1 .778 0 r
.01 w
.75689 .47314 Mdot
[ .05 .05 ] 0 setdash
.75692 .47307 m
.75689 .47314 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75724 .47554 m
.75717 .47471 L
s
1 .781 0 r
.01 w
[ .05 .05 ] 0 setdash
.75436 .4731 m
.75501 .47302 L
s
.75436 .4731 Mdot
1 .778 0 r
.75692 .47307 Mdot
1 .779 0 r
.75697 .47304 m
.75692 .47307 L
s
1 .78 0 r
.75702 .47304 m
.75706 .47304 L
s
.75702 .47304 Mdot
.7569 .47303 m
.75702 .47304 L
s
1 .779 0 r
.75697 .47304 Mdot
.75702 .47303 m
.75697 .47304 L
s
.75706 .47304 m
.75705 .47303 L
s
.75706 .47304 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75701 .47463 m
.7569 .47303 L
s
1 .78 0 r
.01 w
.7569 .47303 Mdot
[ .05 .05 ] 0 setdash
.75668 .47301 m
.7569 .47303 L
s
1 .779 0 r
.75705 .47303 m
.75702 .47303 L
s
.75705 .47303 Mdot
.75702 .47303 Mdot
1 .781 0 r
.75501 .47302 m
.75553 .473 L
s
.75501 .47302 Mdot
1 .78 0 r
.75668 .47301 Mdot
.75638 .47299 m
.75668 .47301 L
s
1 .781 0 r
.75553 .473 m
.75599 .47299 L
s
.75553 .473 Mdot
1 .78 0 r
.75638 .47299 Mdot
.75599 .47299 m
.75638 .47299 L
s
.75599 .47299 Mdot
1 .819 0 r
.71505 .47297 Mdot
.71411 .47176 m
.71505 .47297 L
s
1 .981 0 r
.31753 .47294 Mdot
.31636 .47184 m
.31753 .47294 L
s
1 .695 0 r
.64222 .47291 Mdot
.64315 .47166 m
.64222 .47291 L
s
1 .881 0 r
.76238 .47285 m
.76333 .47242 L
s
.76238 .47285 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75695 .4748 m
.75706 .47669 L
s
.72902 .50336 m
.72967 .50309 L
s
.75706 .47361 m
.75711 .47364 L
s
.75701 .47463 m
.75706 .47361 L
s
.75711 .47364 m
.75711 .47391 L
s
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.75993 .47273 m
.76023 .47223 L
s
.75993 .47273 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75729 .47659 m
.75724 .47554 L
s
.75703 .47389 m
.75702 .47443 L
s
.75709 .474 m
.75703 .47389 L
s
.75711 .47391 m
.75709 .474 L
s
.75712 .47582 m
.75707 .47608 L
s
1 .644 0 r
.01 w
[ .05 .05 ] 0 setdash
.4669 .47252 m
.46483 .47174 L
s
.4669 .47252 Mdot
0 0 0 r
.004 w
.77053 .47245 Mdot
1 .881 0 r
.01 w
.76333 .47242 m
.76419 .47205 L
s
.76333 .47242 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63633 .53246 m
.63571 .53169 L
s
.75709 .4766 m
.75703 .47562 L
s
.75702 .47443 m
.75709 .476 L
s
.75707 .47608 m
.75711 .47687 L
s
.74037 .4975 m
.73977 .50037 L
s
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.76023 .47223 m
.76049 .47171 L
s
.76023 .47223 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75695 .47701 m
.75701 .47463 L
s
.72578 .4873 m
.72644 .48924 L
s
.72835 .50391 m
.72902 .50336 L
s
.7573 .47762 m
.75729 .47659 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76538 .48893 m
.76419 .47205 L
s
1 .88 0 r
.01 w
[ .05 .05 ] 0 setdash
.76419 .47205 m
.76492 .47176 L
s
.76419 .47205 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68612 .57945 m
.68883 .5775 L
s
.75711 .47687 m
.75709 .4766 L
s
.75706 .47669 m
.75715 .47832 L
s
.72621 .49249 m
.72529 .48816 L
s
.75756 .47886 m
.75783 .47921 L
s
.75737 .4788 m
.75756 .47886 L
s
1 .981 0 r
.01 w
.31636 .47184 Mdot
[ .05 .05 ] 0 setdash
.3154 .47092 m
.31636 .47184 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75729 .47943 m
.75737 .4788 L
s
1 .819 0 r
.01 w
.71411 .47176 Mdot
1 .82 0 r
[ .05 .05 ] 0 setdash
.71328 .47059 m
.71411 .47176 L
s
1 .88 0 r
.76492 .47176 m
.76556 .47153 L
s
.76492 .47176 Mdot
1 .644 0 r
.46483 .47174 m
.46278 .47095 L
s
.46483 .47174 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75783 .47921 m
.75818 .4802 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76184 .49109 m
.76049 .47171 L
s
1 .771 0 r
.01 w
[ .05 .05 ] 0 setdash
.76049 .47171 m
.76068 .47118 L
s
.76049 .47171 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73369 .52386 m
.7346 .51619 L
s
.75709 .476 m
.75715 .47679 L
s
1 .695 0 r
.01 w
.64315 .47166 Mdot
1 .696 0 r
[ .05 .05 ] 0 setdash
.64405 .47043 m
.64315 .47166 L
s
0 0 0 r
.004 w
.77191 .47155 Mdot
1 .88 0 r
.01 w
.76556 .47153 m
.76606 .47137 L
s
.76556 .47153 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7379 .50957 m
.73936 .51497 L
s
.75725 .47757 m
.7573 .47762 L
s
.75715 .47679 m
.75721 .4774 L
s
1 .88 0 r
.01 w
[ .05 .05 ] 0 setdash
.76606 .47137 m
.76642 .47127 L
s
.76606 .47137 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68883 .5775 m
.69188 .57611 L
s
.72762 .50433 m
.72835 .50391 L
s
.34897 .5613 m
.35113 .55692 L
s
.75721 .4774 m
.75725 .47757 L
s
.75726 .48008 m
.75729 .47943 L
s
1 .879 0 r
.01 w
[ .05 .05 ] 0 setdash
.76642 .47127 m
.76675 .47118 L
s
.76642 .47127 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75715 .47832 m
.75722 .4797 L
s
.75818 .4802 m
.75866 .48208 L
s
.50665 .51401 m
.50546 .51927 L
s
1 .771 0 r
.01 w
[ .05 .05 ] 0 setdash
.76068 .47118 m
.76078 .47067 L
s
.76068 .47118 Mdot
1 .879 0 r
.76675 .47118 m
.76706 .47107 L
s
.76675 .47118 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72644 .48924 m
.72725 .49181 L
s
1 .879 0 r
.01 w
[ .05 .05 ] 0 setdash
.76706 .47107 m
.76735 .47092 L
s
.76706 .47107 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75679 .47903 m
.75695 .47701 L
s
1 .644 0 r
.01 w
[ .05 .05 ] 0 setdash
.46278 .47095 m
.46074 .47006 L
s
.46278 .47095 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.3132 .50669 m
.3154 .47092 L
s
1 .981 0 r
.01 w
.3154 .47092 Mdot
[ .05 .05 ] 0 setdash
.31458 .47014 m
.3154 .47092 L
s
1 .879 0 r
.76735 .47092 m
.76765 .47071 L
s
.76735 .47092 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75722 .4797 m
.75726 .48008 L
s
1 .879 0 r
.01 w
[ .05 .05 ] 0 setdash
.76765 .47071 m
.76788 .47045 L
s
.76765 .47071 Mdot
1 .771 0 r
.76078 .47067 m
.76077 .47022 L
s
.76078 .47067 Mdot
0 0 0 r
.004 w
.77329 .47064 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71596 .51886 m
.71328 .47059 L
s
1 .82 0 r
.01 w
.71328 .47059 Mdot
[ .05 .05 ] 0 setdash
.71244 .46936 m
.71328 .47059 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72691 .50474 m
.72762 .50433 L
s
.73977 .50037 m
.739 .50261 L
s
1 .878 0 r
.01 w
[ .05 .05 ] 0 setdash
.76788 .47045 m
.76809 .47015 L
s
.76788 .47045 Mdot
1 .696 0 r
.64405 .47043 Mdot
.64509 .46897 m
.64405 .47043 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63691 .53348 m
.63633 .53246 L
s
.69188 .57611 m
.69505 .57619 L
s
1 .771 0 r
.01 w
[ .05 .05 ] 0 setdash
.76077 .47022 m
.76069 .46984 L
s
.76077 .47022 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75866 .48208 m
.75919 .4847 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76884 .48051 m
.76809 .47015 L
s
1 .878 0 r
.01 w
[ .05 .05 ] 0 setdash
.76809 .47015 m
.76823 .46982 L
s
.76809 .47015 Mdot
1 .981 0 r
.31458 .47014 Mdot
.31392 .46953 m
.31458 .47014 L
s
1 .644 0 r
.46074 .47006 m
.45878 .46923 L
s
.46074 .47006 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75658 .48158 m
.75679 .47903 L
s
1 .764 0 r
.01 w
[ .05 .05 ] 0 setdash
.76017 .46985 m
.76039 .46981 L
s
.76017 .46985 Mdot
.76003 .46984 m
.76017 .46985 L
s
1 .77 0 r
.76069 .46984 m
.76058 .46953 L
s
.76069 .46984 Mdot
1 .764 0 r
.76003 .46984 Mdot
.75993 .46981 m
.76003 .46984 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72721 .496 m
.72621 .49249 L
s
1 .878 0 r
.01 w
[ .05 .05 ] 0 setdash
.76823 .46982 m
.76828 .46948 L
s
.76823 .46982 Mdot
1 .764 0 r
.76039 .46981 m
.76068 .46972 L
s
.76039 .46981 Mdot
.75993 .46981 Mdot
.7599 .46976 m
.75993 .46981 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72603 .50433 m
.72691 .50474 L
s
1 .764 0 r
.01 w
.7599 .46976 Mdot
1 .765 0 r
[ .05 .05 ] 0 setdash
.7599 .46971 m
.7599 .46976 L
s
1 .763 0 r
.76068 .46972 m
.76106 .46961 L
s
.76068 .46972 Mdot
0 0 0 r
.004 w
.77467 .46972 Mdot
1 .765 0 r
.01 w
.7599 .46971 Mdot
.75993 .46967 m
.7599 .46971 L
s
.75993 .46967 Mdot
.75998 .46964 m
.75993 .46967 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72725 .49181 m
.72822 .49462 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76005 .47067 m
.75998 .46964 L
s
1 .765 0 r
.01 w
.75998 .46964 Mdot
[ .05 .05 ] 0 setdash
.76004 .46963 m
.75998 .46964 L
s
.76004 .46963 Mdot
.76009 .46961 m
.76004 .46963 L
s
1 .763 0 r
.76106 .46961 m
.76154 .46948 L
s
.76106 .46961 Mdot
1 .765 0 r
.76009 .46961 Mdot
1 .766 0 r
.76014 .46959 m
.76009 .46961 L
s
.76014 .46959 Mdot
.76019 .46955 m
.76014 .46959 L
s
.76019 .46955 Mdot
.76023 .46951 m
.76019 .46955 L
s
1 .77 0 r
.76058 .46953 m
.76046 .46929 L
s
.76058 .46953 Mdot
1 .981 0 r
.31392 .46953 Mdot
1 .982 0 r
.31339 .46906 m
.31392 .46953 L
s
1 .766 0 r
.76023 .46951 Mdot
.76027 .46946 m
.76023 .46951 L
s
1 .878 0 r
.76828 .46948 m
.76832 .46912 L
s
.76828 .46948 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.76235 .48097 m
.76154 .46948 L
s
1 .763 0 r
.01 w
[ .05 .05 ] 0 setdash
.76154 .46948 m
.76211 .46931 L
s
.76154 .46948 Mdot
1 .766 0 r
.76027 .46946 Mdot
1 .767 0 r
.76032 .46942 m
.76027 .46946 L
s
1 .768 0 r
.76044 .46945 m
.76044 .46944 L
s
.76044 .46945 Mdot
.76042 .46945 m
.76044 .46945 L
s
.76042 .46945 Mdot
.76038 .46942 m
.76042 .46945 L
s
1 .767 0 r
.76044 .46944 m
.76044 .46942 L
s
.76044 .46944 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.76051 .47042 m
.76044 .46942 L
s
1 .767 0 r
.01 w
[ .05 .05 ] 0 setdash
.76044 .46942 m
.76041 .46941 L
s
.76044 .46942 Mdot
.76032 .46942 Mdot
.76036 .4694 m
.76032 .46942 L
s
1 .768 0 r
.76038 .46942 Mdot
.76032 .46935 m
.76038 .46942 L
s
1 .767 0 r
.76041 .46941 m
.76036 .4694 L
s
.76041 .46941 Mdot
.76036 .4694 Mdot
1 .82 0 r
.71244 .46936 Mdot
.71177 .46828 m
.71244 .46936 L
s
1 .768 0 r
.76032 .46935 Mdot
.76025 .46927 m
.76032 .46935 L
s
1 .763 0 r
.76211 .46931 m
.76279 .4691 L
s
.76211 .46931 Mdot
1 .77 0 r
.76046 .46929 m
.76035 .46911 L
s
.76046 .46929 Mdot
1 .768 0 r
.76025 .46927 Mdot
1 .769 0 r
.76019 .46918 m
.76025 .46927 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7252 .50471 m
.72603 .50433 L
s
.76045 .46987 m
.76051 .47055 L
s
.76042 .46991 m
.76045 .46987 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.45778 .52073 m
.45878 .46923 L
s
1 .643 0 r
.01 w
[ .05 .05 ] 0 setdash
.45878 .46923 m
.45679 .46832 L
s
.45878 .46923 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76 .47057 m
.75997 .47072 L
s
.76005 .47067 m
.76 .47057 L
s
.75997 .47072 m
.76001 .4714 L
s
1 .769 0 r
.01 w
.76019 .46918 Mdot
[ .05 .05 ] 0 setdash
.76014 .46909 m
.76019 .46918 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76045 .47123 m
.76042 .46991 L
s
.76044 .46993 m
.76042 .47026 L
s
.76051 .47042 m
.76044 .46993 L
s
1 .878 0 r
.01 w
[ .05 .05 ] 0 setdash
.76832 .46912 m
.76829 .46876 L
s
.76832 .46912 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76015 .47129 m
.76005 .47067 L
s
1 .77 0 r
.01 w
[ .05 .05 ] 0 setdash
.76035 .46911 m
.76025 .46901 L
s
.76035 .46911 Mdot
1 .763 0 r
.76279 .4691 m
.76359 .46883 L
s
.76279 .4691 Mdot
1 .769 0 r
.76014 .46909 Mdot
.76012 .46903 m
.76014 .46909 L
s
1 .982 0 r
.31339 .46906 Mdot
.313 .46872 m
.31339 .46906 L
s
1 .769 0 r
.76012 .46903 Mdot
.76013 .46898 m
.76012 .46903 L
s
1 .77 0 r
.76025 .46901 m
.76017 .46897 L
s
.76025 .46901 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.76037 .47239 m
.76013 .46898 L
s
1 .769 0 r
.01 w
.76013 .46898 Mdot
[ .05 .05 ] 0 setdash
.76017 .46897 m
.76013 .46898 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.739 .50261 m
.73812 .50475 L
s
1 .986 0 r
.01 w
[ .05 .05 ] 0 setdash
.30973 .46897 m
.3098 .46897 L
s
.30973 .46897 Mdot
.30953 .46888 m
.30973 .46897 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64699 .52222 m
.64509 .46897 L
s
1 .696 0 r
.01 w
.64509 .46897 Mdot
[ .05 .05 ] 0 setdash
.64599 .46766 m
.64509 .46897 L
s
1 .769 0 r
.76017 .46897 Mdot
1 .986 0 r
.3098 .46897 m
.3098 .46891 L
s
.3098 .46897 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76042 .47026 m
.76042 .47095 L
s
.76001 .4714 m
.7601 .47216 L
s
.76052 .47047 m
.76051 .47042 L
s
.76051 .47055 m
.76052 .47047 L
s
1 .985 0 r
.01 w
[ .05 .05 ] 0 setdash
.3098 .46891 m
.30978 .46884 L
s
.3098 .46891 Mdot
1 .986 0 r
.30953 .46888 Mdot
.30916 .46864 m
.30953 .46888 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76019 .47107 m
.76015 .47129 L
s
.76026 .47131 m
.76019 .47107 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.30968 .47043 m
.30978 .46884 L
s
1 .985 0 r
.01 w
[ .05 .05 ] 0 setdash
.30978 .46884 m
.30977 .46877 L
s
.30978 .46884 Mdot
1 .762 0 r
.76359 .46883 m
.76452 .46848 L
s
.76359 .46883 Mdot
0 0 0 r
.004 w
.77604 .4688 Mdot
.27295 .46879 Mdot
1 .984 0 r
.01 w
.31076 .46877 m
.31105 .46875 L
s
.31076 .46877 Mdot
.31046 .46876 m
.31076 .46877 L
s
1 .985 0 r
.30977 .46877 m
.30982 .46872 L
s
.30977 .46877 Mdot
1 .984 0 r
.31046 .46876 Mdot
.31018 .46873 m
.31046 .46876 L
s
1 .877 0 r
.76829 .46876 m
.76822 .4684 L
s
.76829 .46876 Mdot
1 .984 0 r
.31105 .46875 m
.31133 .46869 L
s
.31105 .46875 Mdot
.31018 .46873 Mdot
.30995 .4687 m
.31018 .46873 L
s
1 .982 0 r
.313 .46872 Mdot
.31271 .46851 m
.313 .46872 L
s
1 .985 0 r
.30982 .46872 m
.30995 .4687 L
s
.30982 .46872 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76034 .47176 m
.76026 .47131 L
s
1 .984 0 r
.01 w
.30995 .4687 Mdot
1 .983 0 r
[ .05 .05 ] 0 setdash
.31133 .46869 m
.31158 .46862 L
s
.31133 .46869 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76042 .47095 m
.76043 .47169 L
s
1 .986 0 r
.01 w
.30916 .46864 Mdot
[ .05 .05 ] 0 setdash
.30857 .46823 m
.30916 .46864 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73243 .53174 m
.73369 .52386 L
s
1 .983 0 r
.01 w
[ .05 .05 ] 0 setdash
.31158 .46862 m
.31181 .46854 L
s
.31158 .46862 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75919 .4847 m
.75973 .48685 L
s
.75627 .48386 m
.75658 .48158 L
s
.7601 .47216 m
.76023 .4728 L
s
.69505 .57619 m
.69799 .57539 L
s
.30967 .46978 m
.30966 .47117 L
s
.30934 .47193 m
.30967 .46978 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.31146 .47403 m
.31181 .46854 L
s
1 .983 0 r
.01 w
[ .05 .05 ] 0 setdash
.31181 .46854 m
.312 .46846 L
s
.31181 .46854 Mdot
1 .982 0 r
.31271 .46851 Mdot
.3125 .4684 m
.31271 .46851 L
s
1 .762 0 r
.76452 .46848 m
.76563 .46799 L
s
.76452 .46848 Mdot
1 .983 0 r
.312 .46846 m
.31217 .46839 L
s
.312 .46846 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7604 .47198 m
.76034 .47176 L
s
1 .877 0 r
.01 w
[ .05 .05 ] 0 setdash
.76822 .4684 m
.76815 .46806 L
s
.76822 .4684 Mdot
1 .982 0 r
.3125 .4684 Mdot
.31233 .46836 m
.3125 .4684 L
s
1 .983 0 r
.31217 .46839 m
.31233 .46836 L
s
.31217 .46839 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76045 .4721 m
.76045 .47123 L
s
1 .982 0 r
.01 w
.31233 .46836 Mdot
1 .872 0 r
[ .05 .05 ] 0 setdash
.76761 .46834 m
.76762 .46833 L
s
.76761 .46834 Mdot
.76763 .4683 m
.76761 .46834 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7244 .50584 m
.7252 .50471 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.7678 .47076 m
.76762 .46833 L
s
1 .872 0 r
.01 w
[ .05 .05 ] 0 setdash
.76762 .46833 m
.76767 .46827 L
s
.76762 .46833 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76023 .4728 m
.76043 .47354 L
s
1 .643 0 r
.01 w
[ .05 .05 ] 0 setdash
.45679 .46832 m
.45487 .4674 L
s
.45679 .46832 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76043 .47169 m
.7604 .47198 L
s
1 .872 0 r
.01 w
.76763 .4683 Mdot
1 .873 0 r
[ .05 .05 ] 0 setdash
.76767 .46824 m
.76763 .4683 L
s
1 .82 0 r
.71177 .46828 Mdot
.71109 .46718 m
.71177 .46828 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72842 .50027 m
.72721 .496 L
s
1 .872 0 r
.01 w
[ .05 .05 ] 0 setdash
.76767 .46827 m
.76774 .46813 L
s
.76767 .46827 Mdot
1 .873 0 r
.76767 .46824 Mdot
.76772 .46815 m
.76767 .46824 L
s
1 .986 0 r
.30857 .46823 Mdot
1 .987 0 r
.30778 .46767 m
.30857 .46823 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76036 .4706 m
.76029 .47061 L
s
.76068 .47395 m
.76036 .4706 L
s
1 .873 0 r
.01 w
.76772 .46815 Mdot
[ .05 .05 ] 0 setdash
.76778 .46805 m
.76772 .46815 L
s
1 .872 0 r
.76774 .46813 m
.7678 .46794 L
s
.76774 .46813 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76029 .47061 m
.76037 .47239 L
s
.72822 .49462 m
.72942 .49811 L
s
.76765 .46885 m
.7678 .47076 L
s
.76785 .47131 m
.76765 .46885 L
s
.6374 .53409 m
.63691 .53348 L
s
1 .877 0 r
.01 w
[ .05 .05 ] 0 setdash
.76815 .46806 m
.76808 .46775 L
s
.76815 .46806 Mdot
1 .873 0 r
.76778 .46805 Mdot
.76784 .46796 m
.76778 .46805 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30968 .47043 m
.30965 .47074 L
s
.30966 .47114 m
.30968 .47043 L
s
1 .762 0 r
.01 w
[ .05 .05 ] 0 setdash
.76563 .46799 m
.76683 .46739 L
s
.76563 .46799 Mdot
1 .873 0 r
.76784 .46796 Mdot
.76791 .46787 m
.76784 .46796 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76043 .47354 m
.76074 .47489 L
s
1 .871 0 r
.01 w
[ .05 .05 ] 0 setdash
.7678 .46794 m
.76786 .46772 L
s
.7678 .46794 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73936 .51497 m
.74106 .52008 L
s
1 .873 0 r
.01 w
.76791 .46787 Mdot
1 .874 0 r
[ .05 .05 ] 0 setdash
.76798 .46779 m
.76791 .46787 L
s
0 0 0 r
.004 w
.77741 .46786 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30966 .47117 m
.30966 .47114 L
s
.50546 .51927 m
.50398 .52415 L
s
.76045 .47296 m
.76045 .4721 L
s
1 .874 0 r
.01 w
.76798 .46779 Mdot
[ .05 .05 ] 0 setdash
.76805 .46773 m
.76798 .46779 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30965 .47074 m
.3096 .47229 L
s
1 .877 0 r
.01 w
[ .05 .05 ] 0 setdash
.76808 .46775 m
.76804 .46752 L
s
.76808 .46775 Mdot
1 .874 0 r
.76805 .46773 Mdot
.7681 .46766 m
.76805 .46773 L
s
1 .871 0 r
.76786 .46772 m
.76791 .46751 L
s
.76786 .46772 Mdot
1 .987 0 r
.30778 .46767 Mdot
.3068 .467 m
.30778 .46767 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.76821 .4692 m
.7681 .46766 L
s
1 .874 0 r
.01 w
.7681 .46766 Mdot
[ .05 .05 ] 0 setdash
.76812 .46757 m
.7681 .46766 L
s
1 .696 0 r
.64599 .46766 Mdot
.64705 .46613 m
.64599 .46766 L
s
1 .874 0 r
.76812 .46757 Mdot
.76814 .46748 m
.76812 .46757 L
s
1 .877 0 r
.76804 .46752 m
.76802 .46733 L
s
.76804 .46752 Mdot
1 .871 0 r
.76791 .46751 m
.76797 .46731 L
s
.76791 .46751 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73812 .50475 m
.73705 .50687 L
s
1 .874 0 r
.01 w
.76814 .46748 Mdot
1 .875 0 r
[ .05 .05 ] 0 setdash
.76815 .46739 m
.76814 .46748 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75593 .48654 m
.75627 .48386 L
s
1 .643 0 r
.01 w
[ .05 .05 ] 0 setdash
.45487 .4674 m
.45302 .46654 L
s
.45487 .4674 Mdot
1 .875 0 r
.76815 .46739 Mdot
.76816 .46733 m
.76815 .46739 L
s
1 .762 0 r
.76683 .46739 m
.76819 .46665 L
s
.76683 .46739 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34657 .56438 m
.34897 .5613 L
s
1 .876 0 r
.01 w
[ .05 .05 ] 0 setdash
.76802 .46733 m
.76804 .46723 L
s
.76802 .46733 Mdot
1 .875 0 r
.76816 .46733 Mdot
.76814 .46727 m
.76816 .46733 L
s
1 .871 0 r
.76797 .46731 m
.76801 .46716 L
s
.76797 .46731 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30861 .47728 m
.30934 .47193 L
s
.69799 .57539 m
.70108 .57529 L
s
1 .875 0 r
.01 w
.76814 .46727 Mdot
[ .05 .05 ] 0 setdash
.76811 .4672 m
.76814 .46727 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76045 .47345 m
.76045 .47296 L
s
.76037 .47239 m
.76043 .4735 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76818 .46926 m
.76804 .46723 L
s
1 .876 0 r
.01 w
[ .05 .05 ] 0 setdash
.76804 .46723 m
.76806 .46716 L
s
.76804 .46723 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75973 .48685 m
.76026 .4887 L
s
.76074 .47489 m
.76117 .47673 L
s
1 .875 0 r
.01 w
.76811 .4672 Mdot
[ .05 .05 ] 0 setdash
.76808 .46715 m
.76811 .4672 L
s
1 .82 0 r
.71109 .46718 Mdot
.71054 .46625 m
.71109 .46718 L
s
1 .87 0 r
.76801 .46716 m
.76801 .46704 L
s
.76801 .46716 Mdot
1 .876 0 r
.76806 .46716 m
.76808 .46713 L
s
.76806 .46716 Mdot
1 .875 0 r
.76808 .46715 Mdot
1 .876 0 r
.76808 .46713 m
.76808 .46715 L
s
.76808 .46713 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7678 .47076 m
.76806 .47382 L
s
1 .87 0 r
.01 w
[ .05 .05 ] 0 setdash
.76801 .46704 m
.76794 .46692 L
s
.76801 .46704 Mdot
1 .987 0 r
.3068 .467 Mdot
.30568 .46624 m
.3068 .467 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72364 .50787 m
.7244 .50584 L
s
1 .87 0 r
.01 w
[ .05 .05 ] 0 setdash
.76794 .46692 m
.7678 .46683 L
s
.76794 .46692 Mdot
0 0 0 r
.004 w
.77877 .46692 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3096 .47229 m
.30963 .47379 L
s
.76821 .4692 m
.76818 .46964 L
s
.76823 .46906 m
.76821 .4692 L
s
.76043 .4735 m
.76045 .47345 L
s
.76735 .47963 m
.76768 .47983 L
s
.76704 .47991 m
.76735 .47963 L
s
.76675 .48113 m
.76704 .47991 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76808 .47073 m
.7678 .46683 L
s
1 .87 0 r
.01 w
[ .05 .05 ] 0 setdash
.7678 .46683 m
.76759 .46676 L
s
.7678 .46683 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76825 .46905 m
.76823 .46906 L
s
1 .87 0 r
.01 w
[ .05 .05 ] 0 setdash
.76759 .46676 m
.7673 .46672 L
s
.76759 .46676 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76796 .47231 m
.76785 .47131 L
s
.76818 .46964 m
.76816 .47024 L
s
.76812 .46796 m
.76826 .46971 L
s
.76818 .46926 m
.76812 .46796 L
s
1 .869 0 r
.01 w
[ .05 .05 ] 0 setdash
.7673 .46672 m
.76692 .46667 L
s
.7673 .46672 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7683 .46941 m
.76825 .46905 L
s
1 .869 0 r
.01 w
[ .05 .05 ] 0 setdash
.76692 .46667 m
.76644 .46661 L
s
.76692 .46667 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31212 .4717 m
.31226 .47216 L
s
.3119 .47268 m
.31212 .4717 L
s
1 .761 0 r
.01 w
[ .05 .05 ] 0 setdash
.76819 .46665 m
.76969 .46579 L
s
.76819 .46665 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76105 .47774 m
.76068 .47395 L
s
1 .869 0 r
.01 w
[ .05 .05 ] 0 setdash
.76644 .46661 m
.76586 .46653 L
s
.76644 .46661 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76768 .47983 m
.76799 .47984 L
s
.76816 .47024 m
.76814 .4711 L
s
1 .643 0 r
.01 w
[ .05 .05 ] 0 setdash
.45302 .46654 m
.45121 .46561 L
s
.45302 .46654 Mdot
1 .869 0 r
.76586 .46653 m
.76515 .46638 L
s
.76586 .46653 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31226 .47216 m
.3123 .47512 L
s
.72966 .50369 m
.72842 .50027 L
s
.76637 .48287 m
.76675 .48113 L
s
1 .869 0 r
.01 w
[ .05 .05 ] 0 setdash
.76515 .46638 m
.76437 .46622 L
s
.76515 .46638 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76799 .47984 m
.76831 .47994 L
s
.76835 .46998 m
.7683 .46941 L
s
1 .82 0 r
.01 w
.71054 .46625 Mdot
1 .821 0 r
[ .05 .05 ] 0 setdash
.71007 .46545 m
.71054 .46625 L
s
1 .987 0 r
.30568 .46624 Mdot
.30426 .46525 m
.30568 .46624 L
s
1 .868 0 r
.76437 .46622 m
.76341 .46598 L
s
.76437 .46622 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76814 .4711 m
.76818 .47268 L
s
.31169 .47338 m
.3119 .47268 L
s
.7684 .47254 m
.76818 .46926 L
s
.7681 .47342 m
.76796 .47231 L
s
.76117 .47673 m
.7617 .47874 L
s
.75538 .48811 m
.75593 .48654 L
s
1 .696 0 r
.01 w
.64705 .46613 Mdot
[ .05 .05 ] 0 setdash
.648 .46466 m
.64705 .46613 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72942 .49811 m
.73083 .50168 L
s
.30963 .47379 m
.30981 .47466 L
s
.76831 .47994 m
.76858 .48019 L
s
.63782 .53404 m
.6374 .53409 L
s
1 .868 0 r
.01 w
[ .05 .05 ] 0 setdash
.76341 .46598 m
.76238 .46571 L
s
.76341 .46598 Mdot
0 0 0 r
.004 w
.78013 .46597 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76834 .47007 m
.76835 .46998 L
s
.31146 .47403 m
.31169 .47338 L
s
.73705 .50687 m
.73603 .50849 L
s
.76834 .47046 m
.76834 .47007 L
s
.76026 .4887 m
.76078 .49032 L
s
.76826 .46971 m
.76835 .47088 L
s
1 .761 0 r
.01 w
[ .05 .05 ] 0 setdash
.76969 .46579 m
.77126 .46482 L
s
.76969 .46579 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76591 .4857 m
.76637 .48287 L
s
.31121 .47452 m
.31146 .47403 L
s
1 .868 0 r
.01 w
[ .05 .05 ] 0 setdash
.76238 .46571 m
.76129 .4655 L
s
.76238 .46571 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73087 .53926 m
.73243 .53174 L
s
.30981 .47466 m
.31005 .47532 L
s
1 .643 0 r
.01 w
[ .05 .05 ] 0 setdash
.45121 .46561 m
.4494 .46462 L
s
.45121 .46561 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31093 .47491 m
.31121 .47452 L
s
.70108 .57529 m
.70419 .57551 L
s
.76818 .47268 m
.76815 .47331 L
s
.76835 .47088 m
.76834 .47046 L
s
.31064 .47521 m
.31093 .47491 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.76321 .49286 m
.76129 .4655 L
s
1 .868 0 r
.01 w
[ .05 .05 ] 0 setdash
.76129 .4655 m
.76003 .46519 L
s
.76129 .4655 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76858 .48019 m
.76884 .48051 L
s
.75478 .48999 m
.75538 .48811 L
s
1 .821 0 r
.01 w
.71007 .46545 Mdot
[ .05 .05 ] 0 setdash
.70962 .46471 m
.71007 .46545 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76815 .47331 m
.7681 .47342 L
s
.31034 .47538 m
.31064 .47521 L
s
.76806 .47382 m
.76825 .4753 L
s
.31005 .47532 m
.31034 .47538 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.30124 .51166 m
.30426 .46525 L
s
1 .987 0 r
.01 w
.30426 .46525 Mdot
[ .05 .05 ] 0 setdash
.30275 .46419 m
.30426 .46525 L
s
1 .868 0 r
.76003 .46519 m
.7587 .46491 L
s
.76003 .46519 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3123 .47512 m
.31231 .47973 L
s
.72286 .51009 m
.72364 .50787 L
s
.7682 .47051 m
.76808 .47073 L
s
.76834 .47159 m
.7682 .47051 L
s
.73093 .50643 m
.72966 .50369 L
s
0 0 0 r
.004 w
.78148 .46501 Mdot
.53 .8 .95 r
.006 w
.76141 .48146 m
.76105 .47774 L
s
.7617 .47874 m
.76235 .48097 L
s
1 .867 0 r
.01 w
[ .05 .05 ] 0 setdash
.7587 .46491 m
.75728 .46461 L
s
.7587 .46491 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76884 .48051 m
.76905 .4813 L
s
.76808 .47073 m
.76797 .47206 L
s
1 .761 0 r
.01 w
[ .05 .05 ] 0 setdash
.77126 .46482 m
.773 .46372 L
s
.77126 .46482 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73603 .50849 m
.73481 .50898 L
s
1 .821 0 r
.01 w
.70962 .46471 Mdot
[ .05 .05 ] 0 setdash
.70927 .4641 m
.70962 .46471 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76844 .47317 m
.76834 .47159 L
s
.75409 .49179 m
.75478 .48999 L
s
.76867 .47638 m
.7684 .47254 L
s
1 .696 0 r
.01 w
.648 .46466 Mdot
1 .697 0 r
[ .05 .05 ] 0 setdash
.6489 .46314 m
.648 .46466 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76538 .48893 m
.76591 .4857 L
s
1 .642 0 r
.01 w
[ .05 .05 ] 0 setdash
.4494 .46462 m
.44789 .46381 L
s
.4494 .46462 Mdot
1 .867 0 r
.75728 .46461 m
.75592 .46432 L
s
.75728 .46461 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50398 .52415 m
.50236 .52778 L
s
.76825 .4753 m
.76841 .47639 L
s
.76078 .49032 m
.76121 .49121 L
s
.74106 .52008 m
.743 .52503 L
s
1 .867 0 r
.01 w
[ .05 .05 ] 0 setdash
.75592 .46432 m
.75456 .46409 L
s
.75592 .46432 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63813 .53267 m
.63782 .53404 L
s
.30755 .48419 m
.30861 .47728 L
s
1 .987 0 r
.01 w
.30275 .46419 Mdot
1 .988 0 r
[ .05 .05 ] 0 setdash
.30139 .46327 m
.30275 .46419 L
s
1 .821 0 r
.70927 .4641 Mdot
.70903 .46361 m
.70927 .4641 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76851 .47477 m
.76844 .47317 L
s
1 .867 0 r
.01 w
[ .05 .05 ] 0 setdash
.75456 .46409 m
.7532 .46388 L
s
.75456 .46409 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73083 .50168 m
.73243 .50547 L
s
.76797 .47206 m
.76781 .47379 L
s
0 0 0 r
.004 w
.78283 .46404 Mdot
.53 .8 .95 r
.006 w
.73481 .50898 m
.73351 .50863 L
s
.73226 .50808 m
.73093 .50643 L
s
.75329 .49312 m
.75409 .49179 L
s
.76905 .4813 m
.76919 .48208 L
s
1 .866 0 r
.01 w
[ .05 .05 ] 0 setdash
.7532 .46388 m
.75191 .46369 L
s
.7532 .46388 Mdot
1 .642 0 r
.44789 .46381 m
.44641 .46298 L
s
.44789 .46381 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73351 .50863 m
.73226 .50808 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.77678 .51519 m
.773 .46372 L
s
1 .761 0 r
.01 w
[ .05 .05 ] 0 setdash
.773 .46372 m
.77481 .46251 L
s
.773 .46372 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34414 .56643 m
.34657 .56438 L
s
1 .866 0 r
.01 w
[ .05 .05 ] 0 setdash
.75191 .46369 m
.75063 .46354 L
s
.75191 .46369 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70419 .57551 m
.70738 .57644 L
s
1 .821 0 r
.01 w
.70903 .46361 Mdot
[ .05 .05 ] 0 setdash
.70889 .46324 m
.70903 .46361 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76841 .47639 m
.76847 .47627 L
s
.76235 .48097 m
.76311 .48366 L
s
.75241 .49527 m
.75329 .49312 L
s
1 .866 0 r
.01 w
[ .05 .05 ] 0 setdash
.75063 .46354 m
.74952 .46336 L
s
.75063 .46354 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76853 .476 m
.76851 .47477 L
s
.76172 .48464 m
.76141 .48146 L
s
.7648 .49325 m
.76538 .48893 L
s
1 .866 0 r
.01 w
[ .05 .05 ] 0 setdash
.74952 .46336 m
.74848 .4632 L
s
.74952 .46336 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76847 .47627 m
.76853 .476 L
s
.76121 .49121 m
.76155 .49132 L
s
1 .988 0 r
.01 w
.30139 .46327 Mdot
[ .05 .05 ] 0 setdash
.29977 .46213 m
.30139 .46327 L
s
1 .821 0 r
.70889 .46324 Mdot
1 .822 0 r
.7088 .46297 m
.70889 .46324 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74976 .48255 m
.74848 .4632 L
s
1 .866 0 r
.01 w
[ .05 .05 ] 0 setdash
.74848 .4632 m
.74755 .46309 L
s
.74848 .4632 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72911 .54713 m
.73087 .53926 L
s
1 .697 0 r
.01 w
.6489 .46314 Mdot
[ .05 .05 ] 0 setdash
.64988 .46166 m
.6489 .46314 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31231 .47973 m
.31238 .48534 L
s
.76781 .47379 m
.76757 .47575 L
s
1 .865 0 r
.01 w
[ .05 .05 ] 0 setdash
.74755 .46309 m
.74672 .46298 L
s
.74755 .46309 Mdot
0 0 0 r
.004 w
.78418 .46306 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76919 .48208 m
.76931 .48296 L
s
.6385 .53139 m
.63813 .53267 L
s
.76892 .47953 m
.76867 .47638 L
s
1 .642 0 r
.01 w
[ .05 .05 ] 0 setdash
.44641 .46298 m
.44501 .46216 L
s
.44641 .46298 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72213 .51369 m
.72286 .51009 L
s
1 .865 0 r
.01 w
[ .05 .05 ] 0 setdash
.74672 .46298 m
.746 .46285 L
s
.74672 .46298 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70923 .47088 m
.7088 .46297 L
s
1 .822 0 r
.01 w
.7088 .46297 Mdot
[ .05 .05 ] 0 setdash
.70876 .46278 m
.7088 .46297 L
s
1 .865 0 r
.746 .46285 m
.74541 .46271 L
s
.746 .46285 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75145 .49758 m
.75241 .49527 L
s
1 .822 0 r
.01 w
.70876 .46278 Mdot
[ .05 .05 ] 0 setdash
.70874 .46266 m
.70876 .46278 L
s
1 .823 0 r
.70898 .46274 m
.70887 .46271 L
s
.70898 .46274 Mdot
.70912 .46274 m
.70898 .46274 L
s
.70912 .46274 Mdot
.7093 .46266 m
.70912 .46274 L
s
1 .865 0 r
.74541 .46271 m
.74489 .46255 L
s
.74541 .46271 Mdot
1 .823 0 r
.70887 .46271 m
.7088 .46266 L
s
.70887 .46271 Mdot
1 .822 0 r
.70874 .46266 Mdot
.70875 .46263 m
.70874 .46266 L
s
.7088 .46266 m
.70875 .46263 L
s
.7088 .46266 Mdot
1 .823 0 r
.7093 .46266 Mdot
1 .824 0 r
.70949 .46249 m
.7093 .46266 L
s
1 .822 0 r
.70875 .46263 Mdot
1 .865 0 r
.74489 .46255 m
.74444 .46239 L
s
.74489 .46255 Mdot
1 .761 0 r
.77481 .46251 m
.77645 .4613 L
s
.77481 .46251 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76155 .49132 m
.76184 .49109 L
s
1 .824 0 r
.01 w
.70949 .46249 Mdot
[ .05 .05 ] 0 setdash
.70968 .46224 m
.70949 .46249 L
s
1 .864 0 r
.74444 .46239 m
.74404 .46222 L
s
.74444 .46239 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70878 .46321 m
.70888 .46515 L
s
.70891 .4647 m
.70878 .46321 L
s
.76191 .48649 m
.76172 .48464 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71021 .47182 m
.70968 .46224 L
s
1 .824 0 r
.01 w
.70968 .46224 Mdot
[ .05 .05 ] 0 setdash
.70988 .46192 m
.70968 .46224 L
s
1 .864 0 r
.74404 .46222 m
.74369 .46204 L
s
.74404 .46222 Mdot
0 0 0 r
.004 w
.26361 .46217 Mdot
1 .642 0 r
.01 w
.44501 .46216 m
.44382 .46146 L
s
.44501 .46216 Mdot
1 .988 0 r
.29977 .46213 Mdot
.29823 .46105 m
.29977 .46213 L
s
0 0 0 r
.004 w
.78552 .46208 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75038 .50013 m
.75145 .49758 L
s
.76931 .48296 m
.76933 .48314 L
s
1 .864 0 r
.01 w
[ .05 .05 ] 0 setdash
.74369 .46204 m
.74339 .46188 L
s
.74369 .46204 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76757 .47575 m
.76727 .47817 L
s
.76311 .48366 m
.76403 .48669 L
s
.73243 .50547 m
.73417 .50898 L
s
1 .824 0 r
.01 w
.70988 .46192 Mdot
[ .05 .05 ] 0 setdash
.71007 .46153 m
.70988 .46192 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76201 .48841 m
.76191 .48649 L
s
1 .864 0 r
.01 w
[ .05 .05 ] 0 setdash
.74339 .46188 m
.7431 .46174 L
s
.74339 .46188 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76184 .49109 m
.76199 .49005 L
s
.50236 .52778 m
.50041 .5308 L
s
.76407 .49686 m
.7648 .49325 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.74363 .46998 m
.7431 .46174 L
s
1 .864 0 r
.01 w
[ .05 .05 ] 0 setdash
.7431 .46174 m
.74283 .4616 L
s
.7431 .46174 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76912 .48151 m
.76892 .47953 L
s
.63889 .52982 m
.6385 .53139 L
s
1 .697 0 r
.01 w
.64988 .46166 Mdot
[ .05 .05 ] 0 setdash
.65073 .46028 m
.64988 .46166 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76199 .49005 m
.76201 .48841 L
s
.70904 .46575 m
.70891 .4647 L
s
1 .863 0 r
.01 w
[ .05 .05 ] 0 setdash
.74283 .4616 m
.74258 .46149 L
s
.74283 .4616 Mdot
1 .824 0 r
.71007 .46153 Mdot
.71026 .46104 m
.71007 .46153 L
s
1 .863 0 r
.74258 .46149 m
.74239 .4614 L
s
.74258 .46149 Mdot
1 .642 0 r
.44382 .46146 m
.44272 .46079 L
s
.44382 .46146 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76933 .48314 m
.76926 .48272 L
s
1 .863 0 r
.01 w
[ .05 .05 ] 0 setdash
.74239 .4614 m
.74224 .46131 L
s
.74239 .4614 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70888 .46515 m
.70904 .46787 L
s
1 .863 0 r
.01 w
[ .05 .05 ] 0 setdash
.74224 .46131 m
.74213 .46124 L
s
.74224 .46131 Mdot
1 .76 0 r
.77645 .4613 m
.77826 .45993 L
s
.77645 .4613 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70738 .57644 m
.71042 .57584 L
s
1 .863 0 r
.01 w
[ .05 .05 ] 0 setdash
.74213 .46124 m
.74205 .46116 L
s
.74213 .46124 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74918 .50316 m
.75038 .50013 L
s
.76926 .48272 m
.76912 .48151 L
s
1 .862 0 r
.01 w
[ .05 .05 ] 0 setdash
.74205 .46116 m
.74199 .46109 L
s
.74205 .46116 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70916 .46614 m
.70904 .46575 L
s
1 .862 0 r
.01 w
[ .05 .05 ] 0 setdash
.74199 .46109 m
.74194 .46103 L
s
.74199 .46109 Mdot
0 0 0 r
.004 w
.78685 .46108 Mdot
1 .988 0 r
.01 w
.29823 .46105 Mdot
.29685 .46012 m
.29823 .46105 L
s
1 .824 0 r
.71026 .46104 Mdot
1 .825 0 r
.71046 .46047 m
.71026 .46104 L
s
1 .862 0 r
.74194 .46103 m
.7419 .46097 L
s
.74194 .46103 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70932 .46639 m
.70916 .46614 L
s
1 .862 0 r
.01 w
[ .05 .05 ] 0 setdash
.7419 .46097 m
.74186 .46092 L
s
.7419 .46097 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74207 .46429 m
.74186 .46092 L
s
1 .861 0 r
.01 w
[ .05 .05 ] 0 setdash
.74186 .46092 m
.74181 .46085 L
s
.74186 .46092 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70958 .46775 m
.70932 .46639 L
s
1 .861 0 r
.01 w
[ .05 .05 ] 0 setdash
.74181 .46085 m
.74177 .46078 L
s
.74181 .46085 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.743 .52503 m
.7451 .52961 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.44203 .48931 m
.44272 .46079 L
s
1 .641 0 r
.01 w
[ .05 .05 ] 0 setdash
.44272 .46079 m
.44173 .46016 L
s
.44272 .46079 Mdot
1 .861 0 r
.74177 .46078 m
.74174 .4607 L
s
.74177 .46078 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31238 .48534 m
.31255 .49168 L
s
1 .861 0 r
.01 w
[ .05 .05 ] 0 setdash
.74174 .4607 m
.74173 .46062 L
s
.74174 .4607 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76727 .47817 m
.76685 .4804 L
s
.63915 .52739 m
.63889 .52982 L
s
.72711 .55504 m
.72911 .54713 L
s
1 .861 0 r
.01 w
[ .05 .05 ] 0 setdash
.74173 .46062 m
.74175 .46055 L
s
.74173 .46062 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76326 .5026 m
.76407 .49686 L
s
1 .86 0 r
.01 w
[ .05 .05 ] 0 setdash
.74175 .46055 m
.74179 .46049 L
s
.74175 .46055 Mdot
1 .857 0 r
.74203 .46053 m
.74211 .46051 L
s
.74203 .46053 Mdot
1 .858 0 r
.74197 .46052 m
.74203 .46053 L
s
.74197 .46052 Mdot
.74193 .4605 m
.74197 .46052 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74227 .46308 m
.74211 .46051 L
s
1 .857 0 r
.01 w
[ .05 .05 ] 0 setdash
.74211 .46051 m
.74221 .46046 L
s
.74211 .46051 Mdot
1 .858 0 r
.74193 .4605 Mdot
.74192 .46048 m
.74193 .4605 L
s
1 .86 0 r
.74179 .46049 m
.74183 .46045 L
s
.74179 .46049 Mdot
1 .858 0 r
.74192 .46048 Mdot
.74192 .46047 m
.74192 .46048 L
s
.74192 .46047 Mdot
1 .859 0 r
.74192 .46047 m
.74192 .46047 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34185 .56755 m
.34414 .56643 L
s
1 .859 0 r
.01 w
.74192 .46047 Mdot
[ .05 .05 ] 0 setdash
.74192 .46046 m
.74192 .46047 L
s
1 .825 0 r
.71046 .46047 Mdot
.71068 .4598 m
.71046 .46047 L
s
1 .857 0 r
.74221 .46046 m
.74234 .46037 L
s
.74221 .46046 Mdot
1 .859 0 r
.74192 .46046 Mdot
.74193 .46045 m
.74192 .46046 L
s
.74193 .46045 Mdot
.74196 .46043 m
.74193 .46045 L
s
1 .86 0 r
.74183 .46045 m
.74188 .46042 L
s
.74183 .46045 Mdot
1 .859 0 r
.74196 .46043 Mdot
.74195 .46042 m
.74196 .46043 L
s
1 .86 0 r
.74188 .46042 m
.74193 .46041 L
s
.74188 .46042 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74201 .46126 m
.74195 .46042 L
s
1 .859 0 r
.01 w
.74195 .46042 Mdot
1 .86 0 r
[ .05 .05 ] 0 setdash
.74193 .46041 m
.74195 .46042 L
s
.74193 .46041 Mdot
1 .857 0 r
.74234 .46037 m
.74249 .46024 L
s
.74234 .46037 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74195 .46077 m
.74197 .46115 L
s
.74199 .46082 m
.74195 .46077 L
s
1 .697 0 r
.01 w
.65073 .46028 Mdot
[ .05 .05 ] 0 setdash
.65156 .45869 m
.65073 .46028 L
s
1 .857 0 r
.74249 .46024 m
.74264 .46006 L
s
.74249 .46024 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74201 .46126 m
.74199 .46082 L
s
.74197 .46115 m
.74202 .46137 L
s
.74197 .46135 m
.74197 .46115 L
s
1 .641 0 r
.01 w
[ .05 .05 ] 0 setdash
.44173 .46016 m
.44089 .45963 L
s
.44173 .46016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70904 .46787 m
.70923 .47088 L
s
1 .988 0 r
.01 w
.29685 .46012 Mdot
[ .05 .05 ] 0 setdash
.29542 .45913 m
.29685 .46012 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74197 .46115 m
.74199 .46152 L
s
.76403 .48669 m
.76507 .48977 L
s
.74202 .46137 m
.74213 .4621 L
s
0 0 0 r
.004 w
.78818 .46008 Mdot
.53 .8 .95 r
.006 w
.30622 .49203 m
.30755 .48419 L
s
.74792 .50627 m
.74918 .50316 L
s
1 .856 0 r
.01 w
[ .05 .05 ] 0 setdash
.74264 .46006 m
.7428 .45985 L
s
.74264 .46006 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70988 .46971 m
.70958 .46775 L
s
.74198 .46152 m
.74197 .46135 L
s
.72138 .51728 m
.72213 .51369 L
s
.74201 .46179 m
.74201 .46126 L
s
.6395 .52505 m
.63915 .52739 L
s
.73417 .50898 m
.736 .51195 L
s
.74199 .46152 m
.74198 .46152 L
s
1 .76 0 r
.01 w
[ .05 .05 ] 0 setdash
.77826 .45993 m
.78 .45845 L
s
.77826 .45993 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7423 .4638 m
.74221 .46365 L
s
.74243 .46425 m
.7423 .4638 L
s
.74221 .46365 m
.74215 .46366 L
s
1 .856 0 r
.01 w
[ .05 .05 ] 0 setdash
.7428 .45985 m
.74293 .45962 L
s
.7428 .45985 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74263 .46515 m
.74243 .46425 L
s
1 .825 0 r
.01 w
.71068 .4598 Mdot
[ .05 .05 ] 0 setdash
.71092 .459 m
.71068 .4598 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74215 .46366 m
.74211 .46373 L
s
.74213 .4621 m
.74227 .46308 L
s
.74199 .46213 m
.74201 .46179 L
s
.71042 .57584 m
.71357 .57503 L
s
.74211 .46373 m
.74209 .4639 L
s
1 .641 0 r
.01 w
[ .05 .05 ] 0 setdash
.44089 .45963 m
.44013 .45911 L
s
.44089 .45963 Mdot
1 .856 0 r
.74293 .45962 m
.74304 .45937 L
s
.74293 .45962 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74188 .46249 m
.7419 .46233 L
s
.74188 .46287 m
.74188 .46249 L
s
.7419 .46233 m
.74195 .46227 L
s
.74195 .46227 m
.74199 .46213 L
s
.74192 .46342 m
.74188 .46287 L
s
.74291 .4665 m
.74263 .46515 L
s
.63986 .52314 m
.6395 .52505 L
s
.74209 .4639 m
.74207 .46429 L
s
.76685 .4804 m
.76633 .48298 L
s
1 .856 0 r
.01 w
[ .05 .05 ] 0 setdash
.74304 .45937 m
.74314 .45912 L
s
.74304 .45937 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74198 .46398 m
.74192 .46342 L
s
.50041 .5308 m
.49845 .53334 L
s
.74227 .46308 m
.74246 .46422 L
s
.74207 .46429 m
.74203 .46429 L
s
.74203 .46429 m
.74198 .46398 L
s
1 .988 0 r
.01 w
.29542 .45913 Mdot
1 .989 0 r
[ .05 .05 ] 0 setdash
.29412 .45826 m
.29542 .45913 L
s
1 .856 0 r
.74314 .45912 m
.74323 .45888 L
s
.74314 .45912 Mdot
1 .641 0 r
.44013 .45911 m
.43944 .45861 L
s
.44013 .45911 Mdot
0 0 0 r
.004 w
.78951 .45907 Mdot
1 .825 0 r
.01 w
.71092 .459 Mdot
.71116 .45813 m
.71092 .459 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74325 .46819 m
.74291 .4665 L
s
1 .852 0 r
.01 w
[ .05 .05 ] 0 setdash
.73826 .45891 m
.73781 .4589 L
s
.73826 .45891 Mdot
.73878 .45888 m
.73826 .45891 L
s
.73781 .4589 m
.73744 .45887 L
s
.73781 .4589 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70923 .47088 m
.7095 .47453 L
s
1 .852 0 r
.01 w
.73878 .45888 Mdot
1 .853 0 r
[ .05 .05 ] 0 setdash
.73934 .45885 m
.73878 .45888 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7465 .50914 m
.74792 .50627 L
s
1 .855 0 r
.01 w
[ .05 .05 ] 0 setdash
.74323 .45888 m
.74329 .45865 L
s
.74323 .45888 Mdot
1 .852 0 r
.73744 .45887 m
.73713 .45881 L
s
.73744 .45887 Mdot
1 .853 0 r
.73934 .45885 Mdot
.73991 .45881 m
.73934 .45885 L
s
1 .852 0 r
.73713 .45881 m
.73684 .45872 L
s
.73713 .45881 Mdot
1 .853 0 r
.73991 .45881 Mdot
.74047 .45873 m
.73991 .45881 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71021 .47182 m
.70988 .46971 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.74134 .4724 m
.74047 .45873 L
s
1 .853 0 r
.01 w
.74047 .45873 Mdot
[ .05 .05 ] 0 setdash
.74103 .45864 m
.74047 .45873 L
s
1 .851 0 r
.73684 .45872 m
.73654 .4586 L
s
.73684 .45872 Mdot
1 .697 0 r
.65156 .45869 Mdot
1 .698 0 r
.65244 .45736 m
.65156 .45869 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74385 .46732 m
.74329 .45865 L
s
1 .855 0 r
.01 w
[ .05 .05 ] 0 setdash
.74329 .45865 m
.74331 .45845 L
s
.74329 .45865 Mdot
1 .853 0 r
.74103 .45864 Mdot
.74158 .45851 m
.74103 .45864 L
s
1 .641 0 r
.43944 .45861 m
.43879 .45811 L
s
.43944 .45861 Mdot
1 .851 0 r
.73654 .4586 m
.73622 .45845 L
s
.73654 .4586 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74246 .46422 m
.74268 .46559 L
s
1 .853 0 r
.01 w
.74158 .45851 Mdot
1 .854 0 r
[ .05 .05 ] 0 setdash
.74207 .45839 m
.74158 .45851 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64032 .52225 m
.63986 .52314 L
s
.76235 .50926 m
.76326 .5026 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73665 .46538 m
.73622 .45845 L
s
1 .851 0 r
.01 w
[ .05 .05 ] 0 setdash
.73622 .45845 m
.73585 .45829 L
s
.73622 .45845 Mdot
1 .855 0 r
.74331 .45845 m
.74328 .4583 L
s
.74331 .45845 Mdot
1 .76 0 r
.78 .45845 m
.78183 .45683 L
s
.78 .45845 Mdot
1 .854 0 r
.74207 .45839 Mdot
.74248 .45829 m
.74207 .45839 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72477 .56148 m
.72711 .55504 L
s
1 .855 0 r
.01 w
[ .05 .05 ] 0 setdash
.74328 .4583 m
.7432 .45821 L
s
.74328 .4583 Mdot
1 .851 0 r
.73585 .45829 m
.7354 .45812 L
s
.73585 .45829 Mdot
1 .854 0 r
.74248 .45829 Mdot
.74281 .45821 m
.74248 .45829 L
s
1 .989 0 r
.29412 .45826 Mdot
.29293 .4575 m
.29412 .45826 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.736 .51195 m
.73792 .51391 L
s
.74363 .46998 m
.74325 .46819 L
s
1 .855 0 r
.01 w
[ .05 .05 ] 0 setdash
.7432 .45821 m
.74305 .45818 L
s
.7432 .45821 Mdot
1 .854 0 r
.74281 .45821 Mdot
.74305 .45818 m
.74281 .45821 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31255 .49168 m
.31279 .49896 L
s
1 .854 0 r
.01 w
.74305 .45818 Mdot
1 .825 0 r
.71116 .45813 Mdot
[ .05 .05 ] 0 setdash
.7114 .45725 m
.71116 .45813 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76507 .48977 m
.76629 .49342 L
s
1 .851 0 r
.01 w
[ .05 .05 ] 0 setdash
.7354 .45812 m
.73486 .45794 L
s
.7354 .45812 Mdot
1 .64 0 r
.43879 .45811 m
.4382 .45763 L
s
.43879 .45811 Mdot
0 0 0 r
.004 w
.79083 .45805 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71357 .57503 m
.71661 .57378 L
s
1 .85 0 r
.01 w
[ .05 .05 ] 0 setdash
.73486 .45794 m
.73427 .45775 L
s
.73486 .45794 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76633 .48298 m
.76573 .48554 L
s
.74487 .51154 m
.7465 .50914 L
s
.33928 .56738 m
.34185 .56755 L
s
1 .85 0 r
.01 w
[ .05 .05 ] 0 setdash
.73427 .45775 m
.73363 .45755 L
s
.73427 .45775 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74268 .46559 m
.7429 .46665 L
s
1 .64 0 r
.01 w
[ .05 .05 ] 0 setdash
.4382 .45763 m
.43762 .45715 L
s
.4382 .45763 Mdot
1 .85 0 r
.73363 .45755 m
.73301 .45735 L
s
.73363 .45755 Mdot
1 .989 0 r
.29293 .4575 Mdot
.29171 .45671 m
.29293 .4575 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74401 .47158 m
.74363 .46998 L
s
.7095 .47453 m
.70988 .47911 L
s
1 .698 0 r
.01 w
.65244 .45736 Mdot
[ .05 .05 ] 0 setdash
.65323 .45595 m
.65244 .45736 L
s
1 .85 0 r
.73301 .45735 m
.73238 .45714 L
s
.73301 .45735 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7451 .52961 m
.74736 .533 L
s
.71055 .47419 m
.71021 .47182 L
s
1 .825 0 r
.01 w
.7114 .45725 Mdot
1 .826 0 r
[ .05 .05 ] 0 setdash
.71163 .45641 m
.7114 .45725 L
s
1 .64 0 r
.43762 .45715 m
.43704 .45667 L
s
.43762 .45715 Mdot
1 .85 0 r
.73238 .45714 m
.73175 .45691 L
s
.73238 .45714 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64085 .5213 m
.64032 .52225 L
s
0 0 0 r
.004 w
.79214 .45702 Mdot
.53 .8 .95 r
.006 w
.74326 .51388 m
.74487 .51154 L
s
.73792 .51391 m
.73972 .51512 L
s
.49845 .53334 m
.4962 .53517 L
s
.7429 .46665 m
.74312 .46747 L
s
.72052 .51956 m
.72138 .51728 L
s
1 .849 0 r
.01 w
[ .05 .05 ] 0 setdash
.73175 .45691 m
.7312 .4567 L
s
.73175 .45691 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72223 .56674 m
.72477 .56148 L
s
.74437 .47248 m
.74401 .47158 L
s
1 .76 0 r
.01 w
[ .05 .05 ] 0 setdash
.78183 .45683 m
.78376 .45514 L
s
.78183 .45683 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74323 .46102 m
.74315 .46342 L
s
.74339 .46111 m
.74323 .46102 L
s
.74361 .46337 m
.74339 .46111 L
s
1 .989 0 r
.01 w
.29171 .45671 Mdot
[ .05 .05 ] 0 setdash
.29052 .45596 m
.29171 .45671 L
s
1 .849 0 r
.7312 .4567 m
.73069 .45651 L
s
.7312 .4567 Mdot
1 .64 0 r
.43704 .45667 m
.43651 .45623 L
s
.43704 .45667 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74478 .47352 m
.74437 .47248 L
s
.71661 .57378 m
.71961 .57126 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73138 .46778 m
.73069 .45651 L
s
1 .849 0 r
.01 w
[ .05 .05 ] 0 setdash
.73069 .45651 m
.73023 .45631 L
s
.73069 .45651 Mdot
1 .826 0 r
.71163 .45641 Mdot
.71186 .4556 m
.71163 .45641 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74521 .47416 m
.74478 .47352 L
s
.74567 .47459 m
.74521 .47416 L
s
.74622 .4752 m
.74567 .47459 L
s
.76573 .48554 m
.76499 .48832 L
s
1 .849 0 r
.01 w
[ .05 .05 ] 0 setdash
.73023 .45631 m
.72982 .45611 L
s
.73023 .45631 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74685 .47582 m
.74622 .4752 L
s
.74312 .46747 m
.74332 .468 L
s
1 .639 0 r
.01 w
[ .05 .05 ] 0 setdash
.43651 .45623 m
.43602 .45581 L
s
.43651 .45623 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74767 .47746 m
.74685 .47582 L
s
.71961 .57126 m
.72223 .56674 L
s
.74161 .5154 m
.74326 .51388 L
s
.73972 .51512 m
.74161 .5154 L
s
1 .848 0 r
.01 w
[ .05 .05 ] 0 setdash
.72982 .45611 m
.72945 .45589 L
s
.72982 .45611 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73716 .46381 m
.7369 .46418 L
s
.73748 .46428 m
.73716 .46381 L
s
.76129 .51595 m
.76235 .50926 L
s
.73786 .46554 m
.73748 .46428 L
s
0 0 0 r
.004 w
.79345 .45597 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.2885 .48512 m
.29052 .45596 L
s
1 .989 0 r
.01 w
.29052 .45596 Mdot
1 .99 0 r
[ .05 .05 ] 0 setdash
.28936 .45524 m
.29052 .45596 L
s
1 .698 0 r
.65323 .45595 Mdot
.65393 .45472 m
.65323 .45595 L
s
1 .848 0 r
.72945 .45589 m
.72911 .45568 L
s
.72945 .45589 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43556 .47321 m
.43602 .45581 L
s
1 .639 0 r
.01 w
[ .05 .05 ] 0 setdash
.43602 .45581 m
.43557 .45543 L
s
.43602 .45581 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64145 .52139 m
.64085 .5213 L
s
.7369 .46418 m
.73665 .46538 L
s
.76629 .49342 m
.76774 .49764 L
s
.74377 .4656 m
.74361 .46337 L
s
1 .848 0 r
.01 w
[ .05 .05 ] 0 setdash
.72911 .45568 m
.7288 .45544 L
s
.72911 .45568 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70988 .47911 m
.71037 .48412 L
s
.74332 .468 m
.74349 .46833 L
s
.71091 .47689 m
.71055 .47419 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71359 .48677 m
.71186 .4556 L
s
1 .826 0 r
.01 w
.71186 .4556 Mdot
[ .05 .05 ] 0 setdash
.71215 .45475 m
.71186 .4556 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74864 .47971 m
.74767 .47746 L
s
.74315 .46342 m
.74299 .46604 L
s
1 .848 0 r
.01 w
[ .05 .05 ] 0 setdash
.7288 .45544 m
.72849 .4552 L
s
.7288 .45544 Mdot
1 .639 0 r
.43557 .45543 m
.43517 .45508 L
s
.43557 .45543 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73835 .46735 m
.73786 .46554 L
s
.31279 .49896 m
.3132 .50669 L
s
.33691 .56727 m
.33928 .56738 L
s
1 .99 0 r
.01 w
.28936 .45524 Mdot
[ .05 .05 ] 0 setdash
.28816 .45448 m
.28936 .45524 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30472 .49943 m
.30622 .49203 L
s
1 .848 0 r
.01 w
[ .05 .05 ] 0 setdash
.72849 .4552 m
.72819 .45494 L
s
.72849 .4552 Mdot
1 .76 0 r
.78376 .45514 m
.78529 .4535 L
s
.78376 .45514 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74349 .46833 m
.74363 .46852 L
s
1 .639 0 r
.01 w
[ .05 .05 ] 0 setdash
.43517 .45508 m
.43484 .45477 L
s
.43517 .45508 Mdot
1 .847 0 r
.72819 .45494 m
.72785 .45466 L
s
.72819 .45494 Mdot
0 0 0 r
.004 w
.79476 .45492 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4962 .53517 m
.49383 .53615 L
s
.73665 .46538 m
.73641 .46735 L
s
1 .639 0 r
.01 w
[ .05 .05 ] 0 setdash
.43484 .45477 m
.43456 .4545 L
s
.43484 .45477 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74385 .46732 m
.74377 .4656 L
s
1 .826 0 r
.01 w
.71215 .45475 Mdot
[ .05 .05 ] 0 setdash
.71235 .45408 m
.71215 .45475 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6557 .50105 m
.65393 .45472 L
s
1 .698 0 r
.01 w
.65393 .45472 Mdot
[ .05 .05 ] 0 setdash
.65466 .45359 m
.65393 .45472 L
s
1 .847 0 r
.72785 .45466 m
.72748 .45436 L
s
.72785 .45466 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74363 .46852 m
.74375 .4686 L
s
.74976 .48255 m
.74864 .47971 L
s
.73892 .46935 m
.73835 .46735 L
s
.76499 .48832 m
.76415 .49083 L
s
1 .638 0 r
.01 w
[ .05 .05 ] 0 setdash
.43456 .4545 m
.43433 .45425 L
s
.43456 .4545 Mdot
1 .99 0 r
.28816 .45448 Mdot
.28679 .45357 m
.28816 .45448 L
s
1 .847 0 r
.72748 .45436 m
.72704 .45403 L
s
.72748 .45436 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74736 .533 m
.74969 .53471 L
s
.74299 .46604 m
.74271 .46827 L
s
.71967 .52182 m
.72052 .51956 L
s
1 .638 0 r
.01 w
[ .05 .05 ] 0 setdash
.43433 .45425 m
.43413 .45402 L
s
.43433 .45425 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74375 .4686 m
.74385 .46842 L
s
.74385 .46842 m
.74385 .46732 L
s
1 .826 0 r
.01 w
.71235 .45408 Mdot
[ .05 .05 ] 0 setdash
.71253 .45345 m
.71235 .45408 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72808 .47139 m
.72704 .45403 L
s
1 .847 0 r
.01 w
[ .05 .05 ] 0 setdash
.72704 .45403 m
.72653 .45367 L
s
.72704 .45403 Mdot
1 .638 0 r
.43413 .45402 m
.43398 .45383 L
s
.43413 .45402 Mdot
0 0 0 r
.004 w
.79606 .45386 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64213 .52156 m
.64145 .52139 L
s
1 .638 0 r
.01 w
[ .05 .05 ] 0 setdash
.43398 .45383 m
.43384 .45367 L
s
.43398 .45383 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71037 .48412 m
.71098 .48971 L
s
1 .638 0 r
.01 w
[ .05 .05 ] 0 setdash
.43384 .45367 m
.43373 .45355 L
s
.43384 .45367 Mdot
1 .847 0 r
.72653 .45367 m
.72601 .45333 L
s
.72653 .45367 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71129 .47984 m
.71091 .47689 L
s
.73641 .46735 m
.73612 .46977 L
s
1 .698 0 r
.01 w
.65466 .45359 Mdot
[ .05 .05 ] 0 setdash
.65532 .45257 m
.65466 .45359 L
s
1 .99 0 r
.28679 .45357 Mdot
.28538 .45262 m
.28679 .45357 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75988 .5222 m
.76129 .51595 L
s
1 .637 0 r
.01 w
[ .05 .05 ] 0 setdash
.43373 .45355 m
.43363 .45344 L
s
.43373 .45355 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73954 .47081 m
.73892 .46935 L
s
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.78529 .4535 m
.787 .45178 L
s
.78529 .4535 Mdot
1 .826 0 r
.71253 .45345 Mdot
1 .827 0 r
.71264 .45294 m
.71253 .45345 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43354 .45705 m
.43363 .45344 L
s
1 .637 0 r
.01 w
[ .05 .05 ] 0 setdash
.43363 .45344 m
.43356 .45337 L
s
.43363 .45344 Mdot
.43356 .45337 m
.43349 .4533 L
s
.43356 .45337 Mdot
1 .846 0 r
.72601 .45333 m
.72549 .453 L
s
.72601 .45333 Mdot
1 .637 0 r
.43349 .4533 m
.43344 .45324 L
s
.43349 .4533 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74271 .46827 m
.74232 .47002 L
s
1 .633 0 r
.01 w
[ .05 .05 ] 0 setdash
.43348 .45329 m
.43346 .45327 L
s
.43348 .45329 Mdot
1 .634 0 r
.43346 .45327 m
.43348 .45329 L
s
1 .633 0 r
.43346 .45327 m
.43341 .45321 L
s
.43346 .45327 Mdot
1 .634 0 r
.43346 .45327 Mdot
.43343 .45323 m
.43346 .45327 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75101 .48584 m
.74976 .48255 L
s
.49383 .53615 m
.4916 .53611 L
s
1 .637 0 r
.01 w
[ .05 .05 ] 0 setdash
.43344 .45324 m
.43339 .45319 L
s
.43344 .45324 Mdot
1 .634 0 r
.43343 .45323 Mdot
.43338 .45318 m
.43343 .45323 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43334 .45573 m
.43341 .45321 L
s
1 .633 0 r
.01 w
[ .05 .05 ] 0 setdash
.43341 .45321 m
.4333 .4531 L
s
.43341 .45321 Mdot
1 .636 0 r
.43339 .45319 m
.43334 .45315 L
s
.43339 .45319 Mdot
1 .634 0 r
.43338 .45318 Mdot
.43334 .45314 m
.43338 .45318 L
s
1 .636 0 r
.43334 .45315 m
.4333 .4531 L
s
.43334 .45315 Mdot
1 .634 0 r
.43334 .45314 Mdot
.4333 .4531 m
.43334 .45314 L
s
1 .636 0 r
.4333 .4531 m
.43327 .45307 L
s
.4333 .4531 Mdot
1 .633 0 r
.4333 .4531 m
.43312 .45292 L
s
.4333 .4531 Mdot
1 .634 0 r
.4333 .4531 Mdot
1 .635 0 r
.43328 .45308 m
.4333 .4531 L
s
.43328 .45308 Mdot
.43326 .45306 m
.43328 .45308 L
s
1 .636 0 r
.43327 .45307 m
.43325 .45305 L
s
.43327 .45307 Mdot
1 .635 0 r
.43326 .45306 Mdot
.43325 .45305 m
.43326 .45306 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43324 .45355 m
.43325 .45305 L
s
1 .635 0 r
.01 w
.43325 .45305 Mdot
[ .05 .05 ] 0 setdash
.43324 .45304 m
.43325 .45305 L
s
1 .636 0 r
.43325 .45305 m
.43324 .45304 L
s
.43325 .45305 Mdot
1 .635 0 r
.43324 .45304 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43325 .45306 m
.43324 .45339 L
s
.43325 .45365 m
.43325 .45306 L
s
.33457 .56524 m
.33691 .56727 L
s
1 .846 0 r
.01 w
[ .05 .05 ] 0 setdash
.72549 .453 m
.72498 .45269 L
s
.72549 .453 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43346 .45391 m
.43345 .45393 L
s
.43343 .45461 m
.43346 .45391 L
s
1 .827 0 r
.01 w
.71264 .45294 Mdot
[ .05 .05 ] 0 setdash
.71271 .45254 m
.71264 .45294 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43345 .45393 m
.43334 .45573 L
s
1 .633 0 r
.01 w
[ .05 .05 ] 0 setdash
.43312 .45292 m
.43286 .45265 L
s
.43312 .45292 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43327 .45342 m
.43329 .45351 L
s
.43325 .45351 m
.43327 .45342 L
s
.43329 .45351 m
.43332 .4539 L
s
.43324 .45339 m
.43324 .45355 L
s
.43324 .45355 m
.43325 .45351 L
s
.76415 .49083 m
.76321 .49286 L
s
.76774 .49764 m
.76926 .50145 L
s
0 0 0 r
.004 w
.79736 .45279 Mdot
.53 .8 .95 r
.006 w
.43327 .45435 m
.43325 .45365 L
s
.43332 .4539 m
.43335 .45444 L
s
.74019 .47213 m
.73954 .47081 L
s
1 .846 0 r
.01 w
[ .05 .05 ] 0 setdash
.72498 .45269 m
.72451 .45241 L
s
.72498 .45269 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3132 .50669 m
.31378 .5139 L
s
1 .632 0 r
.01 w
[ .05 .05 ] 0 setdash
.43286 .45265 m
.43251 .45228 L
s
.43286 .45265 Mdot
1 .99 0 r
.28538 .45262 Mdot
.28372 .4514 m
.28538 .45262 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43339 .45476 m
.43343 .45461 L
s
.74232 .47002 m
.74184 .47134 L
s
1 .698 0 r
.01 w
.65532 .45257 Mdot
1 .699 0 r
[ .05 .05 ] 0 setdash
.65589 .45172 m
.65532 .45257 L
s
1 .827 0 r
.71271 .45254 Mdot
.71276 .45223 m
.71271 .45254 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43335 .45444 m
.43339 .45476 L
s
.4333 .45498 m
.43327 .45435 L
s
1 .846 0 r
.01 w
[ .05 .05 ] 0 setdash
.72451 .45241 m
.7241 .45219 L
s
.72451 .45241 Mdot
1 .632 0 r
.43251 .45228 m
.43206 .45182 L
s
.43251 .45228 Mdot
1 .827 0 r
.71276 .45223 Mdot
.71279 .45201 m
.71276 .45223 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43333 .45545 m
.4333 .45498 L
s
1 .846 0 r
.01 w
[ .05 .05 ] 0 setdash
.7241 .45219 m
.72376 .45201 L
s
.7241 .45219 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4916 .53611 m
.48914 .53592 L
s
.73612 .46977 m
.73575 .47223 L
s
.74184 .47134 m
.74134 .4724 L
s
.74969 .53471 m
.75207 .53586 L
s
.7303 .464 m
.72991 .46355 L
s
.73079 .46547 m
.7303 .464 L
s
.43336 .45584 m
.43333 .45545 L
s
1 .827 0 r
.01 w
.71279 .45201 Mdot
[ .05 .05 ] 0 setdash
.7128 .45188 m
.71279 .45201 L
s
1 .845 0 r
.72376 .45201 m
.7235 .45188 L
s
.72376 .45201 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64305 .52108 m
.64213 .52156 L
s
.74079 .47265 m
.74019 .47213 L
s
.72991 .46355 m
.72962 .4641 L
s
.43334 .45573 m
.43317 .45803 L
s
.43341 .45627 m
.43336 .45584 L
s
1 .827 0 r
.01 w
.7128 .45188 Mdot
1 .828 0 r
[ .05 .05 ] 0 setdash
.71281 .45182 m
.7128 .45188 L
s
1 .845 0 r
.7235 .45188 m
.72327 .45179 L
s
.7235 .45188 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71098 .48971 m
.71176 .49614 L
s
1 .828 0 r
.01 w
[ .05 .05 ] 0 setdash
.71315 .45182 m
.71296 .45181 L
s
.71315 .45182 Mdot
1 .829 0 r
.71341 .45179 m
.71315 .45182 L
s
1 .828 0 r
.71281 .45182 Mdot
.71286 .45181 m
.71281 .45182 L
s
1 .632 0 r
.43206 .45182 m
.4316 .45134 L
s
.43206 .45182 Mdot
1 .828 0 r
.71296 .45181 m
.71286 .45181 L
s
.71296 .45181 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71294 .45324 m
.71286 .45181 L
s
1 .828 0 r
.01 w
.71286 .45181 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75234 .48914 m
.75101 .48584 L
s
1 .829 0 r
.01 w
.71341 .45179 Mdot
[ .05 .05 ] 0 setdash
.71374 .45172 m
.71341 .45179 L
s
1 .845 0 r
.72327 .45179 m
.72308 .45171 L
s
.72327 .45179 Mdot
1 .759 0 r
.787 .45178 m
.78871 .45003 L
s
.787 .45178 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43347 .45673 m
.43341 .45627 L
s
1 .699 0 r
.01 w
.65589 .45172 Mdot
[ .05 .05 ] 0 setdash
.6564 .45101 m
.65589 .45172 L
s
1 .829 0 r
.71374 .45172 Mdot
.71415 .45159 m
.71374 .45172 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72339 .45703 m
.72308 .45171 L
s
1 .845 0 r
.01 w
[ .05 .05 ] 0 setdash
.72308 .45171 m
.72289 .45165 L
s
.72308 .45171 Mdot
0 0 0 r
.004 w
.79865 .45171 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74134 .4724 m
.74079 .47265 L
s
1 .844 0 r
.01 w
[ .05 .05 ] 0 setdash
.72289 .45165 m
.72271 .45158 L
s
.72289 .45165 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43354 .45705 m
.43347 .45673 L
s
.71284 .45222 m
.7129 .45352 L
s
.71294 .45324 m
.71284 .45222 L
s
1 .829 0 r
.01 w
.71415 .45159 Mdot
[ .05 .05 ] 0 setdash
.7147 .45142 m
.71415 .45159 L
s
1 .844 0 r
.72271 .45158 m
.72254 .4515 L
s
.72271 .45158 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73138 .46778 m
.73079 .46547 L
s
.43362 .45777 m
.43354 .45705 L
s
.33214 .56302 m
.33457 .56524 L
s
.75816 .52725 m
.75988 .5222 L
s
.71885 .52316 m
.71967 .52182 L
s
1 .844 0 r
.01 w
[ .05 .05 ] 0 setdash
.72254 .4515 m
.7224 .45142 L
s
.72254 .4515 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76321 .49286 m
.76211 .495 L
s
1 .844 0 r
.01 w
[ .05 .05 ] 0 setdash
.7224 .45142 m
.72229 .45134 L
s
.7224 .45142 Mdot
1 .829 0 r
.7147 .45142 Mdot
.7153 .45123 m
.7147 .45142 L
s
1 .99 0 r
.28372 .4514 Mdot
1 .991 0 r
.28202 .45008 m
.28372 .4514 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71169 .48289 m
.71129 .47984 L
s
.43371 .45866 m
.43362 .45777 L
s
1 .632 0 r
.01 w
[ .05 .05 ] 0 setdash
.4316 .45134 m
.43098 .45071 L
s
.4316 .45134 Mdot
1 .844 0 r
.72229 .45134 m
.72221 .45126 L
s
.72229 .45134 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72962 .4641 m
.7294 .46537 L
s
1 .843 0 r
.01 w
[ .05 .05 ] 0 setdash
.72221 .45126 m
.72217 .45119 L
s
.72221 .45126 Mdot
1 .829 0 r
.7153 .45123 Mdot
1 .83 0 r
.71591 .45103 m
.7153 .45123 L
s
1 .843 0 r
.72217 .45119 m
.72214 .45113 L
s
.72217 .45119 Mdot
.72214 .45113 m
.72212 .45107 L
s
.72214 .45113 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43382 .45977 m
.43371 .45866 L
s
.48914 .53592 m
.48666 .5356 L
s
1 .843 0 r
.01 w
[ .05 .05 ] 0 setdash
.72212 .45107 m
.72208 .451 L
s
.72212 .45107 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71308 .45391 m
.71294 .45324 L
s
.7129 .45352 m
.71304 .45642 L
s
1 .83 0 r
.01 w
.71591 .45103 Mdot
[ .05 .05 ] 0 setdash
.71649 .45082 m
.71591 .45103 L
s
1 .699 0 r
.6564 .45101 Mdot
.65687 .45042 m
.6564 .45101 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72229 .45451 m
.72208 .451 L
s
1 .843 0 r
.01 w
[ .05 .05 ] 0 setdash
.72208 .451 m
.72203 .45092 L
s
.72208 .451 Mdot
1 .842 0 r
.72203 .45092 m
.72197 .45085 L
s
.72203 .45092 Mdot
.72197 .45085 m
.72192 .45079 L
s
.72197 .45085 Mdot
1 .83 0 r
.71649 .45082 Mdot
.71703 .45059 m
.71649 .45082 L
s
1 .839 0 r
.72195 .45081 m
.72195 .4508 L
s
.72195 .45081 Mdot
1 .84 0 r
.72194 .4508 m
.72195 .45081 L
s
.72194 .4508 Mdot
.72191 .45078 m
.72194 .4508 L
s
1 .839 0 r
.72195 .4508 m
.72192 .45077 L
s
.72195 .4508 Mdot
1 .842 0 r
.72192 .45079 m
.72188 .45074 L
s
.72192 .45079 Mdot
1 .84 0 r
.72191 .45078 Mdot
.72189 .45076 m
.72191 .45078 L
s
1 .839 0 r
.72192 .45077 m
.72186 .45071 L
s
.72192 .45077 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43394 .46117 m
.43382 .45977 L
s
1 .84 0 r
.01 w
.72189 .45076 Mdot
[ .05 .05 ] 0 setdash
.72187 .45073 m
.72189 .45076 L
s
1 .842 0 r
.72188 .45074 m
.72185 .45071 L
s
.72188 .45074 Mdot
1 .84 0 r
.72187 .45073 Mdot
.72186 .45071 m
.72187 .45073 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71335 .45537 m
.71308 .45391 L
s
.72196 .45096 m
.72199 .45191 L
s
.72199 .45138 m
.72196 .45096 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72187 .45102 m
.72186 .45071 L
s
1 .84 0 r
.01 w
.72186 .45071 Mdot
1 .841 0 r
[ .05 .05 ] 0 setdash
.72184 .4507 m
.72186 .45071 L
s
1 .632 0 r
.43098 .45071 m
.43036 .45009 L
s
.43098 .45071 Mdot
1 .839 0 r
.72186 .45071 m
.72177 .45062 L
s
.72186 .45071 Mdot
1 .842 0 r
.72185 .45071 m
.72183 .45069 L
s
.72185 .45071 Mdot
1 .841 0 r
.72184 .4507 Mdot
.72183 .45069 m
.72184 .4507 L
s
.72183 .45069 m
.72183 .45068 L
s
.72183 .45069 Mdot
.72183 .45069 Mdot
.72183 .45068 m
.72183 .45069 L
s
.72183 .45068 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73204 .47055 m
.73138 .46778 L
s
.72184 .45071 m
.72185 .451 L
s
.72188 .45127 m
.72184 .45071 L
s
1 .839 0 r
.01 w
[ .05 .05 ] 0 setdash
.72177 .45062 m
.72166 .45051 L
s
.72177 .45062 Mdot
0 0 0 r
.004 w
.79993 .45062 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71787 .46532 m
.71703 .45059 L
s
1 .83 0 r
.01 w
.71703 .45059 Mdot
[ .05 .05 ] 0 setdash
.71753 .45035 m
.71703 .45059 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72189 .45106 m
.72192 .45128 L
s
.72187 .45102 m
.72189 .45106 L
s
.73575 .47223 m
.73531 .47444 L
s
.72187 .45112 m
.72187 .45102 L
s
.43317 .45803 m
.43291 .4609 L
s
.72199 .45164 m
.72199 .45138 L
s
.72185 .451 m
.72186 .45115 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72196 .45564 m
.72166 .45051 L
s
1 .838 0 r
.01 w
[ .05 .05 ] 0 setdash
.72166 .45051 m
.72152 .45038 L
s
.72166 .45051 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72192 .45128 m
.72196 .45156 L
s
.72186 .45115 m
.72187 .45112 L
s
1 .699 0 r
.01 w
.65687 .45042 Mdot
[ .05 .05 ] 0 setdash
.65726 .44998 m
.65687 .45042 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72195 .45198 m
.72188 .45127 L
s
.30311 .50601 m
.30472 .49943 L
s
.31378 .5139 m
.3146 .52097 L
s
1 .838 0 r
.01 w
[ .05 .05 ] 0 setdash
.72152 .45038 m
.72138 .45023 L
s
.72152 .45038 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72196 .45156 m
.72199 .45164 L
s
.75379 .49164 m
.75234 .48914 L
s
1 .83 0 r
.01 w
.71753 .45035 Mdot
[ .05 .05 ] 0 setdash
.71798 .45008 m
.71753 .45035 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4341 .46283 m
.43394 .46117 L
s
.7294 .46537 m
.7292 .46697 L
s
.6439 .52146 m
.64305 .52108 L
s
.7564 .53147 m
.75816 .52725 L
s
1 .838 0 r
.01 w
[ .05 .05 ] 0 setdash
.72138 .45023 m
.72123 .45008 L
s
.72138 .45023 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72199 .45191 m
.722 .45313 L
s
.48666 .5356 m
.4841 .53453 L
s
.72204 .45275 m
.72195 .45198 L
s
1 .631 0 r
.01 w
[ .05 .05 ] 0 setdash
.43036 .45009 m
.42964 .44938 L
s
.43036 .45009 Mdot
1 .991 0 r
.28202 .45008 Mdot
.28021 .44858 m
.28202 .45008 L
s
1 .83 0 r
.71798 .45008 Mdot
1 .831 0 r
.71832 .4498 m
.71798 .45008 L
s
1 .838 0 r
.72123 .45008 m
.72108 .44992 L
s
.72123 .45008 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75207 .53586 m
.75428 .53455 L
s
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.78871 .45003 m
.79031 .44831 L
s
.78871 .45003 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32987 .56087 m
.33214 .56302 L
s
1 .699 0 r
.01 w
.65726 .44998 Mdot
[ .05 .05 ] 0 setdash
.65755 .44968 m
.65726 .44998 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71374 .45765 m
.71335 .45537 L
s
.72244 .45397 m
.72237 .45385 L
s
.72257 .45436 m
.72244 .45397 L
s
.76926 .50145 m
.77097 .50524 L
s
1 .838 0 r
.01 w
[ .05 .05 ] 0 setdash
.72108 .44992 m
.72094 .44976 L
s
.72108 .44992 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72237 .45385 m
.72233 .45394 L
s
.76211 .495 m
.76084 .49591 L
s
.72274 .45494 m
.72257 .45436 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65721 .4508 m
.65717 .44985 L
s
1 .706 0 r
.01 w
[ .05 .05 ] 0 setdash
.65717 .44985 m
.65717 .44983 L
s
.65717 .44985 Mdot
1 .707 0 r
.65728 .44983 m
.65717 .44985 L
s
1 .706 0 r
.65717 .44983 m
.65724 .4498 L
s
.65717 .44983 Mdot
1 .707 0 r
.65728 .44983 Mdot
.6575 .44976 m
.65728 .44983 L
s
1 .831 0 r
.71832 .4498 Mdot
.71855 .44952 m
.71832 .4498 L
s
1 .706 0 r
.65724 .4498 m
.65736 .44975 L
s
.65724 .4498 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43429 .46464 m
.4341 .46283 L
s
.72213 .45352 m
.72204 .45275 L
s
.72233 .45394 m
.72232 .45415 L
s
1 .837 0 r
.01 w
[ .05 .05 ] 0 setdash
.72094 .44976 m
.7208 .44961 L
s
.72094 .44976 Mdot
1 .707 0 r
.6575 .44976 Mdot
.65784 .44964 m
.6575 .44976 L
s
1 .706 0 r
.65736 .44975 m
.65749 .4497 L
s
.65736 .44975 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71304 .45642 m
.7132 .46004 L
s
.72295 .45564 m
.72274 .45494 L
s
1 .706 0 r
.01 w
[ .05 .05 ] 0 setdash
.65749 .4497 m
.65762 .44966 L
s
.65749 .4497 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71176 .49614 m
.71249 .50171 L
s
1 .699 0 r
.01 w
.65755 .44968 Mdot
1 .7 0 r
[ .05 .05 ] 0 setdash
.65775 .44948 m
.65755 .44968 L
s
1 .705 0 r
.65762 .44966 m
.65772 .44962 L
s
.65762 .44966 Mdot
1 .707 0 r
.65784 .44964 Mdot
.65827 .44948 m
.65784 .44964 L
s
1 .705 0 r
.65772 .44962 m
.65779 .44959 L
s
.65772 .44962 Mdot
1 .702 0 r
.65774 .44961 m
.65774 .44961 L
s
.65774 .44961 Mdot
1 .704 0 r
.65774 .44961 Mdot
.65775 .44961 m
.65774 .44961 L
s
1 .702 0 r
.65774 .44961 Mdot
.65774 .44961 Mdot
1 .703 0 r
.65774 .44961 Mdot
.65774 .44961 Mdot
.65774 .44961 Mdot
.65774 .44961 Mdot
1 .702 0 r
.65774 .44961 m
.65775 .44961 L
s
.65774 .44961 Mdot
1 .703 0 r
.65774 .44961 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65775 .44963 m
.65774 .44961 L
s
.65774 .44961 m
.65775 .44968 L
s
1 .837 0 r
.01 w
[ .05 .05 ] 0 setdash
.7208 .44961 m
.72068 .44946 L
s
.7208 .44961 Mdot
1 .704 0 r
.65775 .44961 Mdot
.65775 .44961 m
.65775 .44961 L
s
1 .702 0 r
.65775 .44961 m
.65776 .44959 L
s
.65775 .44961 Mdot
1 .704 0 r
.65775 .44961 Mdot
.65777 .4496 m
.65775 .44961 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65778 .44985 m
.65777 .4496 L
s
1 .704 0 r
.01 w
.65777 .4496 Mdot
[ .05 .05 ] 0 setdash
.65779 .44959 m
.65777 .4496 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65776 .44971 m
.65775 .44963 L
s
1 .705 0 r
.01 w
[ .05 .05 ] 0 setdash
.65779 .44959 m
.65781 .44959 L
s
.65779 .44959 Mdot
1 .704 0 r
.65779 .44959 Mdot
1 .705 0 r
.65781 .44959 m
.65779 .44959 L
s
1 .701 0 r
.65776 .44959 m
.6578 .44955 L
s
.65776 .44959 Mdot
1 .705 0 r
.65781 .44959 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65779 .44963 m
.65782 .44996 L
s
.65775 .45046 m
.65779 .44963 L
s
.65775 .44968 m
.65778 .44999 L
s
.72232 .45415 m
.72232 .45454 L
s
.65778 .44985 m
.65776 .44971 L
s
1 .701 0 r
.01 w
[ .05 .05 ] 0 setdash
.6578 .44955 m
.65784 .4495 L
s
.6578 .44955 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73275 .47324 m
.73204 .47055 L
s
1 .831 0 r
.01 w
.71855 .44952 Mdot
[ .05 .05 ] 0 setdash
.71868 .44925 m
.71855 .44952 L
s
0 0 0 r
.004 w
.80121 .44952 Mdot
1 .701 0 r
.01 w
.65784 .4495 m
.65789 .44944 L
s
.65784 .4495 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4841 .53453 m
.48171 .53332 L
s
1 .7 0 r
.01 w
.65775 .44948 Mdot
[ .05 .05 ] 0 setdash
.65788 .44938 m
.65775 .44948 L
s
1 .707 0 r
.65827 .44948 Mdot
.6588 .44926 m
.65827 .44948 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65781 .44998 m
.65778 .44985 L
s
.72222 .45415 m
.72213 .45352 L
s
.72316 .45633 m
.72295 .45564 L
s
1 .837 0 r
.01 w
[ .05 .05 ] 0 setdash
.72068 .44946 m
.72057 .44934 L
s
.72068 .44946 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.722 .45313 m
.722 .45443 L
s
1 .701 0 r
.01 w
[ .05 .05 ] 0 setdash
.65789 .44944 m
.65793 .44938 L
s
.65789 .44944 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65782 .44996 m
.65781 .44998 L
s
.75428 .53455 m
.7564 .53147 L
s
1 .631 0 r
.01 w
[ .05 .05 ] 0 setdash
.42964 .44938 m
.42887 .44864 L
s
.42964 .44938 Mdot
1 .7 0 r
.65793 .44938 m
.65795 .44934 L
s
.65793 .44938 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65778 .44999 m
.65783 .45053 L
s
1 .7 0 r
.01 w
.65788 .44938 Mdot
[ .05 .05 ] 0 setdash
.65794 .44934 m
.65788 .44938 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65721 .4508 m
.65726 .4522 L
s
.65733 .45122 m
.65721 .4508 L
s
1 .7 0 r
.01 w
[ .05 .05 ] 0 setdash
.65795 .44934 m
.65794 .44934 L
s
.65795 .44934 Mdot
1 .837 0 r
.72057 .44934 m
.72049 .44924 L
s
.72057 .44934 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65795 .44966 m
.65794 .44934 L
s
1 .7 0 r
.01 w
.65794 .44934 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7552 .49358 m
.75379 .49164 L
s
.71784 .52265 m
.71885 .52316 L
s
.72232 .45454 m
.72229 .45451 L
s
1 .707 0 r
.01 w
.6588 .44926 Mdot
1 .708 0 r
[ .05 .05 ] 0 setdash
.65949 .44896 m
.6588 .44926 L
s
1 .831 0 r
.71868 .44925 Mdot
.71872 .449 m
.71868 .44925 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72229 .45451 m
.72222 .45415 L
s
.43453 .46662 m
.43429 .46464 L
s
1 .837 0 r
.01 w
[ .05 .05 ] 0 setdash
.72049 .44924 m
.72044 .44916 L
s
.72049 .44924 Mdot
1 .835 0 r
.72071 .44921 m
.72066 .44919 L
s
.72071 .44921 Mdot
.72071 .44921 m
.72071 .44921 L
s
.72071 .44921 Mdot
.72066 .44919 m
.72071 .44921 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72339 .45703 m
.72316 .45633 L
s
1 .835 0 r
.01 w
[ .05 .05 ] 0 setdash
.72066 .44919 m
.72055 .44915 L
s
.72066 .44919 Mdot
.72066 .44919 Mdot
.72058 .44916 m
.72066 .44919 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65768 .45138 m
.65775 .45046 L
s
.65795 .44966 m
.65797 .4516 L
s
.658 .45053 m
.65795 .44966 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72051 .45045 m
.72044 .44916 L
s
1 .836 0 r
.01 w
[ .05 .05 ] 0 setdash
.72044 .44916 m
.72042 .44912 L
s
.72044 .44916 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72072 .44932 m
.72073 .45048 L
s
.72076 .45006 m
.72072 .44932 L
s
1 .835 0 r
.01 w
.72058 .44916 Mdot
1 .836 0 r
[ .05 .05 ] 0 setdash
.7205 .44912 m
.72058 .44916 L
s
1 .834 0 r
.72055 .44915 m
.72038 .44908 L
s
.72055 .44915 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73531 .47444 m
.73476 .47568 L
s
1 .836 0 r
.01 w
.7205 .44912 Mdot
[ .05 .05 ] 0 setdash
.72044 .44911 m
.7205 .44912 L
s
.72042 .44912 m
.72044 .44911 L
s
.72042 .44912 Mdot
.72044 .44911 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7292 .46697 m
.72902 .46866 L
s
.65768 .45431 m
.65733 .45122 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72063 .45341 m
.72038 .44908 L
s
1 .834 0 r
.01 w
[ .05 .05 ] 0 setdash
.72038 .44908 m
.72016 .44898 L
s
.72038 .44908 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65783 .45053 m
.6579 .45103 L
s
.48171 .53332 m
.47931 .53213 L
s
1 .831 0 r
.01 w
.71872 .449 Mdot
[ .05 .05 ] 0 setdash
.71869 .44878 m
.71872 .449 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76084 .49591 m
.75945 .49605 L
s
1 .834 0 r
.01 w
[ .05 .05 ] 0 setdash
.72016 .44898 m
.71991 .44885 L
s
.72016 .44898 Mdot
1 .708 0 r
.65949 .44896 Mdot
.66031 .44861 m
.65949 .44896 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72363 .45785 m
.72339 .45703 L
s
.71208 .48526 m
.71169 .48289 L
s
1 .834 0 r
.01 w
[ .05 .05 ] 0 setdash
.71991 .44885 m
.71963 .44872 L
s
.71991 .44885 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72045 .44967 m
.7205 .4501 L
s
.72051 .45045 m
.72045 .44967 L
s
1 .831 0 r
.01 w
.71869 .44878 Mdot
1 .832 0 r
[ .05 .05 ] 0 setdash
.71861 .44861 m
.71869 .44878 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43291 .4609 m
.43254 .46422 L
s
.72074 .45067 m
.72076 .45006 L
s
.65759 .45222 m
.65768 .45138 L
s
.71421 .46018 m
.71374 .45765 L
s
.658 .45125 m
.658 .45053 L
s
1 .834 0 r
.01 w
[ .05 .05 ] 0 setdash
.71963 .44872 m
.71935 .44859 L
s
.71963 .44872 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6579 .45103 m
.65796 .45135 L
s
.722 .45443 m
.72196 .45564 L
s
.72391 .45896 m
.72363 .45785 L
s
.43482 .46841 m
.43453 .46662 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.42797 .48036 m
.42887 .44864 L
s
1 .631 0 r
.01 w
[ .05 .05 ] 0 setdash
.42887 .44864 m
.42808 .44785 L
s
.42887 .44864 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47252 .52586 m
.47033 .52428 L
s
.47474 .52792 m
.47252 .52586 L
s
.47692 .53031 m
.47474 .52792 L
s
.75668 .49529 m
.7552 .49358 L
s
1 .832 0 r
.01 w
.71861 .44861 Mdot
[ .05 .05 ] 0 setdash
.71854 .44848 m
.71861 .44861 L
s
1 .708 0 r
.66031 .44861 Mdot
.66126 .44821 m
.66031 .44861 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65726 .4522 m
.65736 .45286 L
s
1 .833 0 r
.01 w
[ .05 .05 ] 0 setdash
.71935 .44859 m
.71909 .44849 L
s
.71935 .44859 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7205 .4501 m
.72059 .45065 L
s
1 .991 0 r
.01 w
.28021 .44858 Mdot
[ .05 .05 ] 0 setdash
.27836 .44693 m
.28021 .44858 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47931 .53213 m
.47692 .53031 L
s
.32771 .55747 m
.32987 .56087 L
s
.72073 .45048 m
.7207 .45186 L
s
.72064 .45179 m
.72051 .45045 L
s
1 .833 0 r
.01 w
[ .05 .05 ] 0 setdash
.71909 .44849 m
.71885 .44841 L
s
.71909 .44849 Mdot
1 .832 0 r
.71854 .44848 Mdot
.7185 .44838 m
.71854 .44848 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75945 .49605 m
.75811 .49636 L
s
.73348 .47505 m
.73275 .47324 L
s
.3146 .52097 m
.31555 .52793 L
s
.65796 .45135 m
.658 .45125 L
s
.72068 .45087 m
.72074 .45067 L
s
1 .833 0 r
.01 w
[ .05 .05 ] 0 setdash
.71885 .44841 m
.71866 .44835 L
s
.71885 .44841 Mdot
0 0 0 r
.004 w
.80249 .44841 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65748 .4528 m
.65759 .45222 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71872 .45221 m
.7185 .44838 L
s
1 .832 0 r
.01 w
.7185 .44838 Mdot
[ .05 .05 ] 0 setdash
.7185 .44833 m
.7185 .44838 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47033 .52428 m
.46814 .52283 L
s
1 .833 0 r
.01 w
[ .05 .05 ] 0 setdash
.71866 .44835 m
.71854 .44833 L
s
.71866 .44835 Mdot
1 .832 0 r
.7185 .44833 Mdot
1 .833 0 r
.71854 .44833 m
.7185 .44833 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72059 .45065 m
.72068 .45087 L
s
1 .833 0 r
.01 w
.71854 .44833 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.79549 .51386 m
.79031 .44831 L
s
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.79031 .44831 m
.79174 .44666 L
s
.79031 .44831 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65797 .4516 m
.65795 .45452 L
s
.65736 .45286 m
.65748 .4528 L
s
.72424 .46006 m
.72391 .45896 L
s
1 .708 0 r
.01 w
.66126 .44821 Mdot
[ .05 .05 ] 0 setdash
.66231 .44775 m
.66126 .44821 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73476 .47568 m
.73417 .47623 L
s
.43517 .47081 m
.43482 .46841 L
s
.7132 .46004 m
.71337 .46429 L
s
.64492 .52228 m
.6439 .52146 L
s
.71249 .50171 m
.71327 .50676 L
s
.75811 .49636 m
.75668 .49529 L
s
.46814 .52283 m
.46608 .5211 L
s
.7208 .45332 m
.72064 .45179 L
s
.73417 .47623 m
.73348 .47505 L
s
1 .631 0 r
.01 w
[ .05 .05 ] 0 setdash
.42808 .44785 m
.42732 .44709 L
s
.42808 .44785 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72196 .45564 m
.72189 .45663 L
s
.72902 .46866 m
.72877 .46994 L
s
.72468 .46197 m
.72424 .46006 L
s
1 .708 0 r
.01 w
.66231 .44775 Mdot
[ .05 .05 ] 0 setdash
.66362 .4472 m
.66231 .44775 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46608 .5211 m
.46398 .52029 L
s
.7207 .45186 m
.72063 .45341 L
s
.32562 .55309 m
.32771 .55747 L
s
.71688 .52132 m
.71784 .52265 L
s
.71859 .44989 m
.71872 .45221 L
s
.71868 .4507 m
.71859 .44989 L
s
.43556 .47321 m
.43517 .47081 L
s
.43957 .48177 m
.43889 .48038 L
s
.4403 .48349 m
.43957 .48177 L
s
.65816 .45766 m
.65768 .45431 L
s
.32358 .5501 m
.32562 .55309 L
s
.43889 .48038 m
.43825 .47936 L
s
.4411 .48578 m
.4403 .48349 L
s
.71476 .46243 m
.71421 .46018 L
s
0 0 0 r
.004 w
.80376 .44729 Mdot
.53 .8 .95 r
.006 w
.72099 .4548 m
.7208 .45332 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.66495 .47916 m
.66362 .4472 L
s
1 .708 0 r
.01 w
.66362 .4472 Mdot
1 .709 0 r
[ .05 .05 ] 0 setdash
.665 .4466 m
.66362 .4472 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43825 .47936 m
.43765 .47897 L
s
.72189 .45663 m
.72179 .45727 L
s
.7252 .46413 m
.72468 .46197 L
s
.71894 .45325 m
.71868 .4507 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.42732 .44709 m
.42659 .44629 L
s
.42732 .44709 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46398 .52029 m
.46188 .52033 L
s
.44203 .48931 m
.4411 .48578 L
s
1 .991 0 r
.01 w
.27836 .44693 Mdot
[ .05 .05 ] 0 setdash
.27651 .44515 m
.27836 .44693 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71327 .50676 m
.71416 .51152 L
s
.77097 .50524 m
.77282 .50903 L
s
.65795 .45452 m
.65789 .45848 L
s
.72063 .45341 m
.72051 .45498 L
s
.43601 .4754 m
.43556 .47321 L
s
.72877 .46994 m
.72849 .47119 L
s
.31555 .52793 m
.3168 .53432 L
s
.72118 .45613 m
.72099 .4548 L
s
.7125 .48771 m
.71208 .48526 L
s
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.79174 .44666 m
.79321 .44493 L
s
.79174 .44666 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43254 .46422 m
.43208 .46776 L
s
.43765 .47897 m
.43708 .47809 L
s
1 .709 0 r
.01 w
.665 .4466 Mdot
[ .05 .05 ] 0 setdash
.66644 .44594 m
.665 .4466 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72179 .45727 m
.72166 .45752 L
s
.71596 .51886 m
.71688 .52132 L
s
.32168 .54679 m
.32358 .5501 L
s
.71337 .46429 m
.71354 .46897 L
s
.71872 .45221 m
.71888 .45442 L
s
.72579 .46631 m
.7252 .46413 L
s
.43708 .47809 m
.43652 .4768 L
s
.43652 .4768 m
.43601 .4754 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.42659 .44629 m
.42592 .44551 L
s
.42659 .44629 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72136 .45712 m
.72118 .45613 L
s
.72166 .45752 m
.72153 .45772 L
s
0 0 0 r
.004 w
.80502 .44616 Mdot
.53 .8 .95 r
.006 w
.71416 .51152 m
.71501 .51573 L
s
.44305 .49358 m
.44203 .48931 L
s
.71541 .46399 m
.71476 .46243 L
s
1 .709 0 r
.01 w
.66644 .44594 Mdot
[ .05 .05 ] 0 setdash
.66785 .44525 m
.66644 .44594 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71501 .51573 m
.71596 .51886 L
s
.72153 .45772 m
.72136 .45712 L
s
.30124 .51166 m
.30311 .50601 L
s
.72051 .45498 m
.72034 .45632 L
s
.6459 .52282 m
.64492 .52228 L
s
.71925 .45539 m
.71894 .45325 L
s
.31989 .54297 m
.32168 .54679 L
s
.46188 .52033 m
.45979 .52033 L
s
.72849 .47119 m
.72808 .47139 L
s
.7264 .46834 m
.72579 .46631 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.42592 .44551 m
.42535 .44476 L
s
.42592 .44551 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3168 .53432 m
.31825 .53883 L
s
.65874 .46116 m
.65816 .45766 L
s
.31825 .53883 m
.31989 .54297 L
s
.71888 .45442 m
.71904 .45604 L
s
1 .709 0 r
.01 w
.66785 .44525 Mdot
[ .05 .05 ] 0 setdash
.66913 .44457 m
.66785 .44525 L
s
0 0 0 r
.004 w
.24288 .44516 Mdot
.24288 .44516 Mdot
1 .991 0 r
.01 w
.27651 .44515 Mdot
.27476 .4433 m
.27651 .44515 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65789 .45848 m
.65778 .46335 L
s
.72701 .47004 m
.7264 .46834 L
s
.72808 .47139 m
.72759 .47121 L
s
0 0 0 r
.004 w
.80628 .44501 Mdot
.53 .8 .95 r
.006 w
.72034 .45632 m
.72012 .45711 L
s
1 .758 0 r
.01 w
[ .05 .05 ] 0 setdash
.79321 .44493 m
.79465 .44321 L
s
.79321 .44493 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.44416 .49825 m
.44305 .49358 L
s
.7161 .46534 m
.71541 .46399 L
s
.71957 .45686 m
.71925 .45539 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.42535 .44476 m
.42482 .44397 L
s
.42535 .44476 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71904 .45604 m
.71918 .45737 L
s
.72759 .47121 m
.72701 .47004 L
s
.71909 .45888 m
.71892 .46014 L
s
.71919 .45816 m
.71909 .45888 L
s
.71354 .46897 m
.71367 .47382 L
s
.71923 .4578 m
.71919 .45816 L
s
1 .709 0 r
.01 w
.66913 .44457 Mdot
[ .05 .05 ] 0 setdash
.67059 .44382 m
.66913 .44457 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71892 .46014 m
.71865 .46181 L
s
.71918 .45737 m
.71923 .4578 L
s
.45979 .52033 m
.45778 .52073 L
s
.72012 .45711 m
.71985 .45717 L
s
.43208 .46776 m
.43153 .47132 L
s
.71289 .48948 m
.7125 .48771 L
s
.71985 .45717 m
.71957 .45686 L
s
.71865 .46181 m
.71829 .46359 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.42482 .44397 m
.42437 .44322 L
s
.42482 .44397 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71676 .46611 m
.7161 .46534 L
s
0 0 0 r
.004 w
.80753 .44386 Mdot
1 .709 0 r
.01 w
.67059 .44382 Mdot
1 .71 0 r
[ .05 .05 ] 0 setdash
.67174 .44314 m
.67059 .44382 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64699 .52222 m
.6459 .52282 L
s
.77282 .50903 m
.77472 .51227 L
s
.44549 .50278 m
.44416 .49825 L
s
.71829 .46359 m
.71787 .46532 L
s
.65942 .46468 m
.65874 .46116 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.26919 .51826 m
.27476 .4433 L
s
1 .991 0 r
.01 w
.27476 .4433 Mdot
1 .992 0 r
[ .05 .05 ] 0 setdash
.27318 .4414 m
.27476 .4433 L
s
1 .629 0 r
.42437 .44322 m
.42398 .44247 L
s
.42437 .44322 Mdot
1 .758 0 r
.79465 .44321 m
.79595 .44159 L
s
.79465 .44321 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71736 .46612 m
.71676 .46611 L
s
1 .71 0 r
.01 w
.67174 .44314 Mdot
[ .05 .05 ] 0 setdash
.6728 .44249 m
.67174 .44314 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65778 .46335 m
.6576 .46899 L
s
.71787 .46532 m
.71736 .46612 L
s
.71367 .47382 m
.71371 .47852 L
s
.45778 .52073 m
.45575 .52071 L
s
0 0 0 r
.004 w
.80877 .44269 Mdot
.53 .8 .95 r
.006 w
.44689 .50793 m
.44549 .50278 L
s
1 .71 0 r
.01 w
.6728 .44249 Mdot
[ .05 .05 ] 0 setdash
.67388 .44184 m
.6728 .44249 L
s
1 .629 0 r
.42398 .44247 m
.42362 .44172 L
s
.42398 .44247 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71322 .49011 m
.71289 .48948 L
s
1 .71 0 r
.01 w
.67388 .44184 Mdot
[ .05 .05 ] 0 setdash
.67478 .44127 m
.67388 .44184 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28972 .4855 m
.29082 .48818 L
s
.2885 .48512 m
.28972 .4855 L
s
.64795 .52222 m
.64699 .52222 L
s
1 .629 0 r
.01 w
[ .05 .05 ] 0 setdash
.42362 .44172 m
.42333 .44103 L
s
.42362 .44172 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43153 .47132 m
.43096 .47463 L
s
.29082 .48818 m
.29177 .49282 L
s
1 .758 0 r
.01 w
[ .05 .05 ] 0 setdash
.79595 .44159 m
.79736 .43989 L
s
.79595 .44159 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45575 .52071 m
.45377 .52057 L
s
0 0 0 r
.004 w
.81001 .44151 Mdot
.53 .8 .95 r
.006 w
.29941 .51515 m
.30124 .51166 L
s
.71371 .47852 m
.71371 .48292 L
s
1 .992 0 r
.01 w
.27318 .4414 Mdot
[ .05 .05 ] 0 setdash
.27177 .43945 m
.27318 .4414 L
s
1 .71 0 r
.67478 .44127 Mdot
1 .711 0 r
.6755 .44078 m
.67478 .44127 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66025 .46777 m
.65942 .46468 L
s
1 .731 0 r
.01 w
[ .05 .05 ] 0 setdash
.7238 .44119 m
.72353 .44116 L
s
.7238 .44119 Mdot
1 .732 0 r
.72396 .44117 m
.7238 .44119 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72407 .44306 m
.72396 .44117 L
s
1 .732 0 r
.01 w
.72396 .44117 Mdot
[ .05 .05 ] 0 setdash
.72402 .44114 m
.72396 .44117 L
s
1 .731 0 r
.72353 .44116 m
.72315 .44107 L
s
.72353 .44116 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.44834 .51231 m
.44689 .50793 L
s
1 .732 0 r
.01 w
.72402 .44114 Mdot
[ .05 .05 ] 0 setdash
.72401 .44111 m
.72402 .44114 L
s
.72401 .44111 Mdot
.72395 .44108 m
.72401 .44111 L
s
.72395 .44108 Mdot
.72387 .44106 m
.72395 .44108 L
s
1 .731 0 r
.72315 .44107 m
.72268 .44092 L
s
.72315 .44107 Mdot
1 .732 0 r
.72387 .44106 Mdot
1 .733 0 r
.72378 .44105 m
.72387 .44106 L
s
.72378 .44105 Mdot
.72368 .44103 m
.72378 .44105 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42257 .46605 m
.42333 .44103 L
s
1 .629 0 r
.01 w
[ .05 .05 ] 0 setdash
.42333 .44103 m
.42305 .44036 L
s
.42333 .44103 Mdot
1 .733 0 r
.72368 .44103 Mdot
.72361 .44101 m
.72368 .44103 L
s
.72361 .44101 Mdot
.72359 .44099 m
.72361 .44101 L
s
.72359 .44099 Mdot
.72363 .44097 m
.72359 .44099 L
s
.72363 .44097 Mdot
1 .734 0 r
.72376 .44097 m
.72363 .44097 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72394 .44405 m
.72376 .44097 L
s
1 .734 0 r
.01 w
.72376 .44097 Mdot
[ .05 .05 ] 0 setdash
.72398 .44097 m
.72376 .44097 L
s
.72398 .44097 Mdot
.72432 .44097 m
.72398 .44097 L
s
.72432 .44097 Mdot
.72477 .44096 m
.72432 .44097 L
s
.72477 .44096 Mdot
.72532 .44091 m
.72477 .44096 L
s
1 .731 0 r
.72268 .44092 m
.72212 .44069 L
s
.72268 .44092 Mdot
1 .734 0 r
.72532 .44091 Mdot
1 .735 0 r
.72598 .44081 m
.72532 .44091 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28713 .4873 m
.2885 .48512 L
s
1 .735 0 r
.01 w
.72598 .44081 Mdot
[ .05 .05 ] 0 setdash
.72676 .44069 m
.72598 .44081 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72361 .44137 m
.72366 .44187 L
s
.72371 .4424 m
.72361 .44137 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.67644 .46162 m
.6755 .44078 L
s
1 .711 0 r
.01 w
.6755 .44078 Mdot
[ .05 .05 ] 0 setdash
.67613 .44034 m
.6755 .44078 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6576 .46899 m
.65735 .47532 L
s
1 .73 0 r
.01 w
[ .05 .05 ] 0 setdash
.72212 .44069 m
.7215 .44043 L
s
.72212 .44069 Mdot
1 .735 0 r
.72676 .44069 Mdot
.72769 .44052 m
.72676 .44069 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72366 .44187 m
.72377 .44248 L
s
1 .735 0 r
.01 w
.72769 .44052 Mdot
[ .05 .05 ] 0 setdash
.72876 .44033 m
.72769 .44052 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77472 .51227 m
.77678 .51519 L
s
1 .73 0 r
.01 w
[ .05 .05 ] 0 setdash
.7215 .44043 m
.72081 .44014 L
s
.7215 .44043 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29177 .49282 m
.29277 .49817 L
s
1 .629 0 r
.01 w
[ .05 .05 ] 0 setdash
.42305 .44036 m
.42282 .43975 L
s
.42305 .44036 Mdot
1 .711 0 r
.67613 .44034 Mdot
.67657 .43998 m
.67613 .44034 L
s
1 .735 0 r
.72876 .44033 Mdot
.73001 .44011 m
.72876 .44033 L
s
0 0 0 r
.004 w
.81125 .44032 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71345 .48921 m
.71322 .49011 L
s
.72377 .44248 m
.72388 .44286 L
s
.72394 .44405 m
.72371 .4424 L
s
.72407 .44306 m
.72402 .44498 L
s
.72414 .44311 m
.72407 .44306 L
s
.45377 .52057 m
.45192 .51849 L
s
.71371 .48292 m
.71359 .48677 L
s
1 .73 0 r
.01 w
[ .05 .05 ] 0 setdash
.72081 .44014 m
.72006 .43985 L
s
.72081 .44014 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45013 .51556 m
.44834 .51231 L
s
.72413 .44315 m
.72414 .44311 L
s
1 .735 0 r
.01 w
.73001 .44011 Mdot
1 .736 0 r
[ .05 .05 ] 0 setdash
.73136 .43987 m
.73001 .44011 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72388 .44286 m
.72399 .44308 L
s
1 .718 0 r
.01 w
[ .05 .05 ] 0 setdash
.69443 .44005 m
.69385 .44004 L
s
.69443 .44005 Mdot
1 .719 0 r
.69492 .44004 m
.69443 .44005 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72408 .44321 m
.72413 .44315 L
s
1 .719 0 r
.01 w
.69492 .44004 Mdot
[ .05 .05 ] 0 setdash
.6953 .44001 m
.69492 .44004 L
s
1 .718 0 r
.69385 .44004 m
.69319 .43999 L
s
.69385 .44004 Mdot
1 .719 0 r
.6953 .44001 Mdot
.69559 .43996 m
.6953 .44001 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72399 .44308 m
.72408 .44321 L
s
1 .718 0 r
.01 w
[ .05 .05 ] 0 setdash
.69319 .43999 m
.69248 .43992 L
s
.69319 .43999 Mdot
1 .711 0 r
.67657 .43998 Mdot
.67685 .43971 m
.67657 .43998 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45192 .51849 m
.45013 .51556 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.69583 .44479 m
.69559 .43996 L
s
1 .719 0 r
.01 w
.69559 .43996 Mdot
[ .05 .05 ] 0 setdash
.69578 .43991 m
.69559 .43996 L
s
1 .718 0 r
.69248 .43992 m
.69176 .43984 L
s
.69248 .43992 Mdot
1 .727 0 r
.70811 .43992 m
.70708 .43992 L
s
.70811 .43992 Mdot
.70919 .43985 m
.70811 .43992 L
s
1 .726 0 r
.70708 .43992 m
.70601 .43991 L
s
.70708 .43992 Mdot
.70601 .43991 m
.70499 .43988 L
s
.70601 .43991 Mdot
1 .719 0 r
.69578 .43991 Mdot
.6959 .43985 m
.69578 .43991 L
s
1 .758 0 r
.79736 .43989 m
.79859 .4383 L
s
.79736 .43989 Mdot
1 .726 0 r
.70499 .43988 m
.70397 .43986 L
s
.70499 .43988 Mdot
1 .723 0 r
.69608 .43987 m
.69591 .43987 L
s
.69608 .43987 Mdot
.6963 .43986 m
.69608 .43987 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.73319 .46958 m
.73136 .43987 L
s
1 .736 0 r
.01 w
.73136 .43987 Mdot
[ .05 .05 ] 0 setdash
.73286 .43959 m
.73136 .43987 L
s
1 .723 0 r
.69591 .43987 m
.69578 .43984 L
s
.69591 .43987 Mdot
1 .726 0 r
.70397 .43986 m
.70297 .43984 L
s
.70397 .43986 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.69656 .44486 m
.6963 .43986 L
s
1 .723 0 r
.01 w
.6963 .43986 Mdot
[ .05 .05 ] 0 setdash
.69656 .43984 m
.6963 .43986 L
s
1 .73 0 r
.72006 .43985 m
.71931 .43962 L
s
.72006 .43985 Mdot
1 .719 0 r
.6959 .43985 Mdot
1 .72 0 r
.69597 .4398 m
.6959 .43985 L
s
1 .727 0 r
.70919 .43985 Mdot
.71023 .43972 m
.70919 .43985 L
s
1 .726 0 r
.70297 .43984 m
.70206 .43983 L
s
.70297 .43984 Mdot
1 .722 0 r
.69578 .43984 m
.6957 .43981 L
s
.69578 .43984 Mdot
1 .717 0 r
.69176 .43984 m
.69102 .43974 L
s
.69176 .43984 Mdot
1 .723 0 r
.69656 .43984 Mdot
1 .724 0 r
.69687 .43982 m
.69656 .43984 L
s
1 .725 0 r
.70206 .43983 m
.7012 .43983 L
s
.70206 .43983 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70203 .45564 m
.7012 .43983 L
s
1 .725 0 r
.01 w
[ .05 .05 ] 0 setdash
.7012 .43983 m
.70041 .43982 L
s
.7012 .43983 Mdot
.70041 .43982 m
.69971 .43981 L
s
.70041 .43982 Mdot
1 .724 0 r
.69687 .43982 Mdot
.69724 .4398 m
.69687 .43982 L
s
1 .722 0 r
.6957 .43981 m
.69565 .43978 L
s
.6957 .43981 Mdot
1 .725 0 r
.69971 .43981 m
.69908 .4398 L
s
.69971 .43981 Mdot
1 .72 0 r
.69597 .4398 Mdot
.69598 .43976 m
.69597 .4398 L
s
1 .725 0 r
.69908 .4398 m
.69855 .43978 L
s
.69908 .4398 Mdot
1 .724 0 r
.69724 .4398 Mdot
.69764 .43978 m
.69724 .4398 L
s
1 .722 0 r
.69565 .43978 m
.69563 .43976 L
s
.69565 .43978 Mdot
1 .724 0 r
.69855 .43978 m
.69807 .43977 L
s
.69855 .43978 Mdot
.69764 .43978 Mdot
.69807 .43977 m
.69764 .43978 L
s
.69807 .43977 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.69574 .44016 m
.69572 .43977 L
s
1 .721 0 r
.01 w
[ .05 .05 ] 0 setdash
.69572 .43977 m
.69576 .43976 L
s
.69572 .43977 Mdot
.69568 .43976 m
.69572 .43977 L
s
.69576 .43976 m
.6958 .43975 L
s
.69576 .43976 Mdot
1 .72 0 r
.69598 .43976 Mdot
.69596 .43974 m
.69598 .43976 L
s
1 .722 0 r
.69563 .43976 m
.69563 .43976 L
s
.69563 .43976 Mdot
1 .721 0 r
.69568 .43976 Mdot
.69565 .43976 m
.69568 .43976 L
s
.69565 .43976 Mdot
1 .722 0 r
.69563 .43976 m
.69565 .43976 L
s
.69563 .43976 Mdot
1 .721 0 r
.6958 .43975 m
.69585 .43974 L
s
.6958 .43975 Mdot
1 .714 0 r
.6788 .43975 m
.67811 .43974 L
s
.6788 .43975 Mdot
.67959 .43973 m
.6788 .43975 L
s
1 .628 0 r
.42282 .43975 m
.42261 .43919 L
s
.42282 .43975 Mdot
1 .714 0 r
.67811 .43974 m
.67751 .43971 L
s
.67811 .43974 Mdot
1 .72 0 r
.69585 .43974 m
.6959 .43973 L
s
.69585 .43974 Mdot
.69596 .43974 Mdot
.6959 .43973 m
.69596 .43974 L
s
1 .717 0 r
.69102 .43974 m
.69027 .43962 L
s
.69102 .43974 Mdot
1 .714 0 r
.67959 .43973 Mdot
1 .715 0 r
.68043 .4397 m
.67959 .43973 L
s
1 .72 0 r
.6959 .43973 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64906 .5216 m
.64795 .52222 L
s
1 .727 0 r
.01 w
.71023 .43972 Mdot
[ .05 .05 ] 0 setdash
.7112 .43955 m
.71023 .43972 L
s
1 .711 0 r
.67685 .43971 Mdot
.677 .4395 m
.67685 .43971 L
s
1 .714 0 r
.67751 .43971 m
.67705 .43966 L
s
.67751 .43971 Mdot
1 .715 0 r
.68043 .4397 Mdot
.68131 .43965 m
.68043 .4397 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69564 .43995 m
.69566 .44021 L
s
.69568 .44033 m
.69564 .43995 L
s
1 .713 0 r
.01 w
[ .05 .05 ] 0 setdash
.67705 .43966 m
.67671 .4396 L
s
.67705 .43966 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.68224 .4596 m
.68131 .43965 L
s
1 .715 0 r
.01 w
.68131 .43965 Mdot
[ .05 .05 ] 0 setdash
.68219 .4396 m
.68131 .43965 L
s
1 .73 0 r
.71931 .43962 m
.7185 .43939 L
s
.71931 .43962 Mdot
1 .717 0 r
.69027 .43962 m
.68952 .43951 L
s
.69027 .43962 Mdot
1 .715 0 r
.68219 .4396 Mdot
.68312 .43952 m
.68219 .4396 L
s
1 .713 0 r
.67671 .4396 m
.67652 .43953 L
s
.67671 .4396 Mdot
1 .736 0 r
.73286 .43959 Mdot
.73445 .43928 m
.73286 .43959 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69578 .4401 m
.69583 .44028 L
s
.69574 .44016 m
.69578 .4401 L
s
.69571 .44032 m
.69574 .44016 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71229 .45902 m
.7112 .43955 L
s
1 .727 0 r
.01 w
.7112 .43955 Mdot
1 .728 0 r
[ .05 .05 ] 0 setdash
.7121 .43936 m
.7112 .43955 L
s
1 .713 0 r
.67652 .43953 m
.67644 .43946 L
s
.67652 .43953 Mdot
1 .715 0 r
.68312 .43952 Mdot
.68398 .43945 m
.68312 .43952 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69566 .44021 m
.69568 .44037 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6903 .45525 m
.68952 .43951 L
s
1 .717 0 r
.01 w
[ .05 .05 ] 0 setdash
.68952 .43951 m
.68878 .43941 L
s
.68952 .43951 Mdot
1 .711 0 r
.677 .4395 Mdot
1 .712 0 r
.67702 .43937 m
.677 .4395 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69576 .44107 m
.69568 .44033 L
s
.69583 .44028 m
.69589 .44052 L
s
.71359 .48677 m
.71345 .48921 L
s
.69568 .44037 m
.69571 .44032 L
s
1 .713 0 r
.01 w
[ .05 .05 ] 0 setdash
.67644 .43946 m
.67644 .43938 L
s
.67644 .43946 Mdot
1 .992 0 r
.27177 .43945 Mdot
.27056 .43747 m
.27177 .43945 L
s
1 .715 0 r
.68398 .43945 Mdot
1 .716 0 r
.68488 .43937 m
.68398 .43945 L
s
1 .717 0 r
.68878 .43941 m
.68806 .43935 L
s
.68878 .43941 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71958 .45804 m
.7185 .43939 L
s
1 .729 0 r
.01 w
[ .05 .05 ] 0 setdash
.7185 .43939 m
.71773 .43921 L
s
.7185 .43939 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67652 .44104 m
.67644 .43938 L
s
1 .713 0 r
.01 w
[ .05 .05 ] 0 setdash
.67644 .43938 m
.67651 .43932 L
s
.67644 .43938 Mdot
1 .716 0 r
.68488 .43937 Mdot
.68574 .43932 m
.68488 .43937 L
s
1 .712 0 r
.67702 .43937 Mdot
.67693 .43929 m
.67702 .43937 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72428 .44593 m
.72394 .44405 L
s
1 .728 0 r
.01 w
.7121 .43936 Mdot
[ .05 .05 ] 0 setdash
.71291 .43917 m
.7121 .43936 L
s
1 .716 0 r
.68806 .43935 m
.68732 .43931 L
s
.68806 .43935 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69603 .44058 m
.69603 .44095 L
s
.696 .44065 m
.69603 .44058 L
s
.69589 .44052 m
.69595 .44067 L
s
1 .712 0 r
.01 w
[ .05 .05 ] 0 setdash
.67651 .43932 m
.67663 .43928 L
s
.67651 .43932 Mdot
1 .716 0 r
.68574 .43932 Mdot
.68655 .4393 m
.68574 .43932 L
s
.68732 .43931 m
.68655 .4393 L
s
.68732 .43931 Mdot
.68655 .4393 Mdot
1 .712 0 r
.67693 .43929 Mdot
.67679 .43927 m
.67693 .43929 L
s
1 .736 0 r
.73445 .43928 Mdot
.73596 .43899 m
.73445 .43928 L
s
1 .712 0 r
.67663 .43928 m
.67679 .43927 L
s
.67663 .43928 Mdot
.67679 .43927 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69595 .44067 m
.696 .44065 L
s
.43096 .47463 m
.43024 .4776 L
s
1 .729 0 r
.01 w
[ .05 .05 ] 0 setdash
.71773 .43921 m
.71698 .43907 L
s
.71773 .43921 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72402 .44498 m
.72393 .44798 L
s
.69603 .44095 m
.69601 .44194 L
s
1 .628 0 r
.01 w
[ .05 .05 ] 0 setdash
.42261 .43919 m
.42244 .4387 L
s
.42261 .43919 Mdot
1 .728 0 r
.71291 .43917 Mdot
.71363 .43903 m
.71291 .43917 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66122 .4712 m
.66025 .46777 L
s
.69589 .44194 m
.69576 .44107 L
s
0 0 0 r
.004 w
.81248 .43912 Mdot
1 .729 0 r
.01 w
[ .05 .05 ] 0 setdash
.71698 .43907 m
.71627 .43896 L
s
.71698 .43907 Mdot
1 .728 0 r
.71363 .43903 Mdot
.71428 .43893 m
.71363 .43903 L
s
1 .736 0 r
.73596 .43899 Mdot
1 .737 0 r
.73756 .43865 m
.73596 .43899 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29277 .49817 m
.29386 .50459 L
s
1 .729 0 r
.01 w
[ .05 .05 ] 0 setdash
.71627 .43896 m
.7156 .4389 L
s
.71627 .43896 Mdot
1 .728 0 r
.71428 .43893 Mdot
.71493 .43889 m
.71428 .43893 L
s
1 .729 0 r
.7156 .4389 m
.71493 .43889 L
s
.7156 .4389 Mdot
1 .728 0 r
.71493 .43889 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69601 .44194 m
.69595 .44325 L
s
.69606 .44286 m
.69589 .44194 L
s
1 .628 0 r
.01 w
[ .05 .05 ] 0 setdash
.42244 .4387 m
.42234 .4383 L
s
.42244 .4387 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6765 .44093 m
.67652 .44104 L
s
.67663 .44192 m
.6765 .44093 L
s
.28559 .49127 m
.28713 .4873 L
s
1 .737 0 r
.01 w
.73756 .43865 Mdot
[ .05 .05 ] 0 setdash
.73903 .43831 m
.73756 .43865 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42703 .43967 m
.42706 .4386 L
s
1 .625 0 r
.01 w
[ .05 .05 ] 0 setdash
.42706 .4386 m
.42699 .43858 L
s
.42706 .4386 Mdot
.42693 .43858 m
.42706 .4386 L
s
.42693 .43858 Mdot
.42662 .43854 m
.42693 .43858 L
s
1 .624 0 r
.42699 .43858 m
.4267 .43852 L
s
.42699 .43858 Mdot
1 .625 0 r
.42662 .43854 Mdot
.42618 .43847 m
.42662 .43854 L
s
1 .624 0 r
.4267 .43852 m
.42621 .43841 L
s
.4267 .43852 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67652 .44104 m
.67661 .44146 L
s
1 .625 0 r
.01 w
.42618 .43847 Mdot
[ .05 .05 ] 0 setdash
.42567 .43837 m
.42618 .43847 L
s
1 .624 0 r
.42621 .43841 m
.42552 .43824 L
s
.42621 .43841 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65735 .47532 m
.6571 .48253 L
s
.72475 .44813 m
.72428 .44593 L
s
1 .625 0 r
.01 w
.42567 .43837 Mdot
1 .626 0 r
[ .05 .05 ] 0 setdash
.42511 .43825 m
.42567 .43837 L
s
1 .737 0 r
.73903 .43831 Mdot
.74035 .43799 m
.73903 .43831 L
s
1 .757 0 r
.79859 .4383 m
.79969 .43682 L
s
.79859 .4383 Mdot
1 .628 0 r
.42234 .4383 m
.42229 .43798 L
s
.42234 .4383 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69628 .44382 m
.69606 .44286 L
s
.67691 .444 m
.67663 .44192 L
s
1 .626 0 r
.01 w
.42511 .43825 Mdot
[ .05 .05 ] 0 setdash
.42456 .43812 m
.42511 .43825 L
s
1 .624 0 r
.42552 .43824 m
.42466 .438 L
s
.42552 .43824 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67661 .44146 m
.67675 .44176 L
s
.67703 .44143 m
.67714 .44204 L
s
.6769 .44171 m
.67703 .44143 L
s
.69595 .44325 m
.69583 .44479 L
s
1 .626 0 r
.01 w
.42456 .43812 Mdot
[ .05 .05 ] 0 setdash
.42406 .43799 m
.42456 .43812 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42703 .43967 m
.42689 .44198 L
s
.4268 .44315 m
.42703 .43967 L
s
.29788 .51651 m
.29941 .51515 L
s
1 .624 0 r
.01 w
[ .05 .05 ] 0 setdash
.42466 .438 m
.42365 .43766 L
s
.42466 .438 Mdot
1 .737 0 r
.74035 .43799 Mdot
.74167 .43765 m
.74035 .43799 L
s
1 .626 0 r
.42406 .43799 Mdot
.42361 .43785 m
.42406 .43799 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67675 .44176 m
.6769 .44171 L
s
1 .628 0 r
.01 w
[ .05 .05 ] 0 setdash
.42229 .43798 m
.4223 .43776 L
s
.42229 .43798 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67714 .44204 m
.67722 .44439 L
s
0 0 0 r
.004 w
.8137 .43791 Mdot
1 .626 0 r
.01 w
.42361 .43785 Mdot
[ .05 .05 ] 0 setdash
.4232 .43773 m
.42361 .43785 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69656 .44486 m
.69628 .44382 L
s
1 .627 0 r
.01 w
[ .05 .05 ] 0 setdash
.4223 .43776 m
.42241 .43763 L
s
.4223 .43776 Mdot
1 .626 0 r
.4232 .43773 Mdot
1 .627 0 r
.42287 .43764 m
.4232 .43773 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65006 .52104 m
.64906 .5216 L
s
1 .623 0 r
.01 w
[ .05 .05 ] 0 setdash
.42365 .43766 m
.42261 .43729 L
s
.42365 .43766 Mdot
1 .737 0 r
.74167 .43765 Mdot
.7428 .43734 m
.74167 .43765 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42264 .44513 m
.42287 .43764 L
s
1 .627 0 r
.01 w
.42287 .43764 Mdot
[ .05 .05 ] 0 setdash
.4226 .4376 m
.42287 .43764 L
s
.42241 .43763 m
.4226 .4376 L
s
.42241 .43763 Mdot
.4226 .4376 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72393 .44798 m
.72375 .45119 L
s
1 .992 0 r
.01 w
.27056 .43747 Mdot
[ .05 .05 ] 0 setdash
.26968 .43558 m
.27056 .43747 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69583 .44479 m
.69564 .44659 L
s
1 .737 0 r
.01 w
.7428 .43734 Mdot
1 .738 0 r
[ .05 .05 ] 0 setdash
.74377 .43709 m
.7428 .43734 L
s
1 .623 0 r
.42261 .43729 m
.42136 .43675 L
s
.42261 .43729 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67737 .4467 m
.67691 .444 L
s
.77678 .51519 m
.77893 .51816 L
s
.69688 .44596 m
.69656 .44486 L
s
.72533 .45034 m
.72475 .44813 L
s
.29386 .50459 m
.29492 .51049 L
s
1 .738 0 r
.01 w
.74377 .43709 Mdot
[ .05 .05 ] 0 setdash
.7448 .43683 m
.74377 .43709 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67722 .44439 m
.67722 .4478 L
s
.66232 .47447 m
.66122 .4712 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.74606 .45607 m
.7448 .43683 L
s
1 .738 0 r
.01 w
.7448 .43683 Mdot
[ .05 .05 ] 0 setdash
.74578 .43662 m
.7448 .43683 L
s
1 .757 0 r
.79969 .43682 m
.80081 .43538 L
s
.79969 .43682 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42689 .44198 m
.42648 .44627 L
s
1 .623 0 r
.01 w
[ .05 .05 ] 0 setdash
.42136 .43675 m
.42009 .43614 L
s
.42136 .43675 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43024 .4776 m
.42954 .47947 L
s
0 0 0 r
.004 w
.81491 .43668 Mdot
.53 .8 .95 r
.006 w
.69723 .4468 m
.69688 .44596 L
s
1 .738 0 r
.01 w
.74578 .43662 Mdot
[ .05 .05 ] 0 setdash
.74673 .43645 m
.74578 .43662 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69564 .44659 m
.69536 .44864 L
s
1 .738 0 r
.01 w
.74673 .43645 Mdot
[ .05 .05 ] 0 setdash
.74766 .43633 m
.74673 .43645 L
s
.74766 .43633 Mdot
1 .739 0 r
.7486 .43624 m
.74766 .43633 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42233 .44013 m
.42246 .4423 L
s
.42216 .44249 m
.42233 .44013 L
s
1 .739 0 r
.01 w
.7486 .43624 Mdot
[ .05 .05 ] 0 setdash
.74962 .43618 m
.7486 .43624 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75909 .47302 m
.75654 .43619 L
s
1 .74 0 r
.01 w
[ .05 .05 ] 0 setdash
.75654 .43619 m
.7549 .43616 L
s
.75654 .43619 Mdot
.75852 .43618 m
.75654 .43619 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4264 .44597 m
.4268 .44315 L
s
1 .74 0 r
.01 w
.75852 .43618 Mdot
[ .05 .05 ] 0 setdash
.76052 .43617 m
.75852 .43618 L
s
1 .739 0 r
.74962 .43618 Mdot
.75072 .43614 m
.74962 .43618 L
s
1 .74 0 r
.76052 .43617 Mdot
1 .741 0 r
.76246 .43616 m
.76052 .43617 L
s
1 .74 0 r
.7549 .43616 m
.75329 .43615 L
s
.7549 .43616 Mdot
1 .741 0 r
.76246 .43616 Mdot
.76463 .43607 m
.76246 .43616 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69765 .44783 m
.69723 .4468 L
s
1 .739 0 r
.01 w
[ .05 .05 ] 0 setdash
.75329 .43615 m
.75194 .43613 L
s
.75329 .43615 Mdot
1 .623 0 r
.42009 .43614 m
.41871 .43538 L
s
.42009 .43614 Mdot
1 .739 0 r
.75072 .43614 Mdot
.75194 .43613 m
.75072 .43614 L
s
.75194 .43613 Mdot
1 .741 0 r
.76463 .43607 Mdot
.76655 .43604 m
.76463 .43607 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72602 .45275 m
.72533 .45034 L
s
1 .741 0 r
.01 w
.76655 .43604 Mdot
[ .05 .05 ] 0 setdash
.76855 .43597 m
.76655 .43604 L
s
.76855 .43597 Mdot
.77035 .43593 m
.76855 .43597 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67797 .44971 m
.67737 .4467 L
s
1 .743 0 r
.01 w
[ .05 .05 ] 0 setdash
.77778 .43595 m
.77764 .43591 L
s
.77778 .43595 Mdot
.77793 .43595 m
.77778 .43595 L
s
.77793 .43595 Mdot
1 .744 0 r
.77812 .43586 m
.77793 .43595 L
s
1 .741 0 r
.77035 .43593 Mdot
1 .742 0 r
.772 .43587 m
.77035 .43593 L
s
1 .743 0 r
.77764 .43591 m
.77741 .43584 L
s
.77764 .43591 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29629 .5145 m
.29788 .51651 L
s
1 .742 0 r
.01 w
.772 .43587 Mdot
[ .05 .05 ] 0 setdash
.77353 .4358 m
.772 .43587 L
s
1 .744 0 r
.77812 .43586 Mdot
.77838 .43567 m
.77812 .43586 L
s
1 .743 0 r
.77741 .43584 m
.77704 .43578 L
s
.77741 .43584 Mdot
1 .742 0 r
.77353 .4358 Mdot
.77475 .43576 m
.77353 .4358 L
s
1 .743 0 r
.77704 .43578 m
.7765 .43573 L
s
.77704 .43578 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72375 .45119 m
.72346 .45423 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.77662 .46086 m
.77475 .43576 L
s
1 .742 0 r
.01 w
.77475 .43576 Mdot
[ .05 .05 ] 0 setdash
.77578 .43572 m
.77475 .43576 L
s
.7765 .43573 m
.77578 .43572 L
s
.7765 .43573 Mdot
.77578 .43572 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6571 .48253 m
.65673 .48889 L
s
.65096 .51901 m
.65006 .52104 L
s
1 .744 0 r
.01 w
.77838 .43567 Mdot
[ .05 .05 ] 0 setdash
.77873 .43537 m
.77838 .43567 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29492 .51049 m
.29629 .5145 L
s
.6981 .44868 m
.69765 .44783 L
s
1 .992 0 r
.01 w
.26968 .43558 Mdot
[ .05 .05 ] 0 setdash
.2688 .43363 m
.26968 .43558 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69536 .44864 m
.69498 .45086 L
s
.67722 .4478 m
.67711 .4519 L
s
0 0 0 r
.004 w
.81612 .43544 Mdot
.53 .8 .95 r
.006 w
.28381 .4958 m
.28559 .49127 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.41741 .47642 m
.41871 .43538 L
s
1 .623 0 r
.01 w
[ .05 .05 ] 0 setdash
.41871 .43538 m
.41725 .43449 L
s
.41871 .43538 Mdot
1 .757 0 r
.80081 .43538 m
.80176 .43411 L
s
.80081 .43538 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.77963 .44733 m
.77873 .43537 L
s
1 .744 0 r
.01 w
.77873 .43537 Mdot
[ .05 .05 ] 0 setdash
.77916 .43497 m
.77873 .43537 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77803 .43716 m
.7779 .43753 L
s
.77838 .43919 m
.77803 .43716 L
s
.42202 .44682 m
.42216 .44249 L
s
.42246 .4423 m
.42264 .44513 L
s
.7779 .43753 m
.77783 .43836 L
s
.69857 .44936 m
.6981 .44868 L
s
1 .744 0 r
.01 w
.77916 .43497 Mdot
[ .05 .05 ] 0 setdash
.77975 .43447 m
.77916 .43497 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42954 .47947 m
.42877 .48028 L
s
.69908 .45006 m
.69857 .44936 L
s
.72686 .45543 m
.72602 .45275 L
s
.42591 .44799 m
.4264 .44597 L
s
.77783 .43836 m
.77774 .44023 L
s
.6635 .47689 m
.66232 .47447 L
s
1 .622 0 r
.01 w
[ .05 .05 ] 0 setdash
.41725 .43449 m
.4158 .4335 L
s
.41725 .43449 Mdot
1 .744 0 r
.77975 .43447 Mdot
1 .745 0 r
.78033 .43391 m
.77975 .43447 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67871 .4528 m
.67797 .44971 L
s
.42648 .44627 m
.42585 .45051 L
s
.65195 .51765 m
.65096 .51901 L
s
.69965 .45075 m
.69908 .45006 L
s
.69498 .45086 m
.69452 .45336 L
s
0 0 0 r
.004 w
.81732 .43419 Mdot
1 .757 0 r
.01 w
[ .05 .05 ] 0 setdash
.80176 .43411 m
.80263 .43293 L
s
.80176 .43411 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77893 .44287 m
.77838 .43919 L
s
.70034 .45206 m
.69965 .45075 L
s
.72346 .45423 m
.72307 .45684 L
s
1 .745 0 r
.01 w
.78033 .43391 Mdot
[ .05 .05 ] 0 setdash
.78117 .43324 m
.78033 .43391 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77893 .51816 m
.78091 .52114 L
s
.67711 .4519 m
.67686 .45656 L
s
.65673 .48889 m
.65626 .49491 L
s
.42264 .44513 m
.42291 .44739 L
s
1 .992 0 r
.01 w
.2688 .43363 Mdot
1 .993 0 r
[ .05 .05 ] 0 setdash
.26819 .43188 m
.2688 .43363 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77774 .44023 m
.77767 .44422 L
s
1 .622 0 r
.01 w
[ .05 .05 ] 0 setdash
.4158 .4335 m
.41439 .43246 L
s
.4158 .4335 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42534 .44934 m
.42591 .44799 L
s
.70114 .45371 m
.70034 .45206 L
s
.42194 .45132 m
.42202 .44682 L
s
.42877 .48028 m
.42797 .48036 L
s
1 .745 0 r
.01 w
.78117 .43324 Mdot
[ .05 .05 ] 0 setdash
.78217 .43248 m
.78117 .43324 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72782 .45828 m
.72686 .45543 L
s
.69452 .45336 m
.69395 .45517 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.806 .47362 m
.80263 .43293 L
s
1 .757 0 r
.01 w
[ .05 .05 ] 0 setdash
.80263 .43293 m
.80332 .43188 L
s
.80263 .43293 Mdot
0 0 0 r
.004 w
.81852 .43293 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67953 .45557 m
.67871 .4528 L
s
.65281 .51593 m
.65195 .51765 L
s
.42291 .44739 m
.42328 .44888 L
s
.42476 .44995 m
.42534 .44934 L
s
.66495 .47916 m
.6635 .47689 L
s
.70203 .45564 m
.70114 .45371 L
s
1 .745 0 r
.01 w
.78217 .43248 Mdot
[ .05 .05 ] 0 setdash
.78309 .43168 m
.78217 .43248 L
s
1 .622 0 r
.41439 .43246 m
.41298 .4313 L
s
.41439 .43246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71563 .45119 m
.71504 .45233 L
s
.71631 .45143 m
.71563 .45119 L
s
.71706 .45264 m
.71631 .45143 L
s
.72307 .45684 m
.72259 .459 L
s
.65626 .49491 m
.6557 .50105 L
s
.42797 .48036 m
.42716 .4798 L
s
.4242 .45023 m
.42476 .44995 L
s
.42328 .44888 m
.4237 .45004 L
s
.42585 .45051 m
.42504 .45465 L
s
.69395 .45517 m
.6933 .45634 L
s
.688 .45324 m
.68725 .45373 L
s
.68875 .45358 m
.688 .45324 L
s
.71504 .45233 m
.71446 .45373 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.80332 .43188 m
.8039 .43099 L
s
.80332 .43188 Mdot
1 .993 0 r
.26819 .43188 Mdot
.26785 .43011 m
.26819 .43188 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68952 .45456 m
.68875 .45358 L
s
.77963 .44733 m
.77893 .44287 L
s
.67686 .45656 m
.67644 .46162 L
s
.71786 .45445 m
.71706 .45264 L
s
.4237 .45004 m
.4242 .45023 L
s
.68725 .45373 m
.68649 .45487 L
s
1 .745 0 r
.01 w
.78309 .43168 Mdot
1 .746 0 r
[ .05 .05 ] 0 setdash
.78402 .43087 m
.78309 .43168 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28193 .50128 m
.28381 .4958 L
s
0 0 0 r
.004 w
.8197 .43165 Mdot
.53 .8 .95 r
.006 w
.6536 .51302 m
.65281 .51593 L
s
.70299 .45753 m
.70203 .45564 L
s
.6903 .45525 m
.68952 .45456 L
s
.72893 .461 m
.72782 .45828 L
s
.42193 .45549 m
.42194 .45132 L
s
.68039 .45724 m
.67953 .45557 L
s
.77767 .44422 m
.77752 .44925 L
s
.6933 .45634 m
.69262 .45715 L
s
.71446 .45373 m
.71382 .45541 L
s
1 .622 0 r
.01 w
[ .05 .05 ] 0 setdash
.41298 .4313 m
.41148 .42996 L
s
.41298 .4313 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6911 .45629 m
.6903 .45525 L
s
.42716 .4798 m
.42643 .478 L
s
.68649 .45487 m
.68569 .45632 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.8039 .43099 m
.80435 .43022 L
s
.8039 .43099 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71871 .45637 m
.71786 .45445 L
s
.42643 .478 m
.42571 .47638 L
s
.69188 .45695 m
.6911 .45629 L
s
1 .746 0 r
.01 w
.78402 .43087 Mdot
[ .05 .05 ] 0 setdash
.78524 .43007 m
.78402 .43087 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69262 .45715 m
.69188 .45695 L
s
.6557 .50105 m
.65512 .50556 L
s
.72259 .459 m
.72196 .45982 L
s
.65442 .50958 m
.6536 .51302 L
s
.71382 .45541 m
.71309 .45712 L
s
.42571 .47638 m
.42507 .47452 L
s
.68132 .45876 m
.68039 .45724 L
s
.70402 .45951 m
.70299 .45753 L
s
.66644 .4811 m
.66495 .47916 L
s
.78091 .52114 m
.783 .5231 L
s
.68569 .45632 m
.68485 .45772 L
s
.65512 .50556 m
.65442 .50958 L
s
.42507 .47452 m
.42453 .47271 L
s
0 0 0 r
.004 w
.82088 .43036 Mdot
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.80435 .43022 m
.80468 .42956 L
s
.80435 .43022 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71958 .45804 m
.71871 .45637 L
s
.42453 .47271 m
.42401 .47117 L
s
1 .993 0 r
.01 w
.26785 .43011 Mdot
[ .05 .05 ] 0 setdash
.26756 .42836 m
.26785 .43011 L
s
1 .746 0 r
.78524 .43007 Mdot
.78623 .42918 m
.78524 .43007 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71309 .45712 m
.71229 .45902 L
s
1 .621 0 r
.01 w
[ .05 .05 ] 0 setdash
.41148 .42996 m
.41028 .42886 L
s
.41148 .42996 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42202 .45877 m
.42193 .45549 L
s
.68485 .45772 m
.68403 .45881 L
s
.67644 .46162 m
.67593 .46685 L
s
.72196 .45982 m
.72122 .45972 L
s
.73018 .4637 m
.72893 .461 L
s
.42401 .47117 m
.42356 .4703 L
s
.68224 .4596 m
.68132 .45876 L
s
.42504 .45465 m
.42405 .45871 L
s
.72044 .4591 m
.71958 .45804 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.80468 .42956 m
.80487 .42903 L
s
.80468 .42956 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70509 .46081 m
.70402 .45951 L
s
.72122 .45972 m
.72044 .4591 L
s
.68403 .45881 m
.68314 .45973 L
s
.71229 .45902 m
.71138 .4604 L
s
.68314 .45973 m
.68224 .4596 L
s
1 .746 0 r
.01 w
.78623 .42918 Mdot
[ .05 .05 ] 0 setdash
.78721 .42845 m
.78623 .42918 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78047 .45227 m
.77963 .44733 L
s
0 0 0 r
.004 w
.82206 .42906 Mdot
.53 .8 .95 r
.006 w
.42356 .4703 m
.42319 .46894 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.80487 .42903 m
.80494 .42862 L
s
.80487 .42903 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42215 .46178 m
.42202 .45877 L
s
.70617 .46194 m
.70509 .46081 L
s
.71138 .4604 m
.71038 .46143 L
s
1 .621 0 r
.01 w
[ .05 .05 ] 0 setdash
.41028 .42886 m
.40893 .42756 L
s
.41028 .42886 Mdot
1 .755 0 r
.80494 .42862 m
.80489 .42833 L
s
.80494 .42862 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77752 .44925 m
.77723 .45518 L
s
.42319 .46894 m
.42285 .46743 L
s
.66795 .48175 m
.66644 .4811 L
s
.71038 .46143 m
.70932 .46207 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.78957 .45856 m
.78721 .42845 L
s
1 .746 0 r
.01 w
.78721 .42845 Mdot
[ .05 .05 ] 0 setdash
.78806 .42776 m
.78721 .42845 L
s
1 .993 0 r
.26756 .42836 Mdot
.26732 .4268 m
.26756 .42836 L
s
1 .755 0 r
.80489 .42833 m
.80474 .42813 L
s
.80489 .42833 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70723 .46254 m
.70617 .46194 L
s
.70932 .46207 m
.70831 .46242 L
s
.42285 .46743 m
.42257 .46605 L
s
.42234 .46392 m
.42215 .46178 L
s
1 .755 0 r
.01 w
[ .05 .05 ] 0 setdash
.80474 .42813 m
.80452 .42799 L
s
.80474 .42813 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70831 .46242 m
.70723 .46254 L
s
.73164 .46675 m
.73018 .4637 L
s
.42257 .46605 m
.42234 .46392 L
s
1 .755 0 r
.01 w
[ .05 .05 ] 0 setdash
.80452 .42799 m
.80424 .4279 L
s
.80452 .42799 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.80488 .43553 m
.80424 .4279 L
s
1 .755 0 r
.01 w
[ .05 .05 ] 0 setdash
.80424 .4279 m
.80394 .42784 L
s
.80424 .4279 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67593 .46685 m
.67518 .4712 L
s
1 .754 0 r
.01 w
[ .05 .05 ] 0 setdash
.80394 .42784 m
.80363 .42779 L
s
.80394 .42784 Mdot
.80363 .42779 m
.80332 .42775 L
s
.80363 .42779 Mdot
1 .746 0 r
.78806 .42776 Mdot
1 .747 0 r
.78885 .42717 m
.78806 .42776 L
s
1 .754 0 r
.80332 .42775 m
.80302 .4277 L
s
.80332 .42775 Mdot
0 0 0 r
.004 w
.82322 .42774 Mdot
1 .754 0 r
.01 w
.80302 .4277 m
.80272 .42766 L
s
.80302 .4277 Mdot
.80272 .42766 m
.80244 .42762 L
s
.80272 .42766 Mdot
1 .753 0 r
.80244 .42762 m
.80222 .42757 L
s
.80244 .42762 Mdot
.80222 .42757 m
.80205 .42751 L
s
.80222 .42757 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74785 .45334 m
.74694 .45422 L
s
.74881 .4536 m
.74785 .45334 L
s
1 .621 0 r
.01 w
[ .05 .05 ] 0 setdash
.40893 .42756 m
.40764 .42633 L
s
.40893 .42756 Mdot
1 .753 0 r
.80205 .42751 m
.80191 .42743 L
s
.80205 .42751 Mdot
.80191 .42743 m
.80176 .42733 L
s
.80191 .42743 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27979 .50644 m
.28193 .50128 L
s
.74694 .45422 m
.74606 .45607 L
s
.783 .5231 m
.78494 .52376 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.8022 .43267 m
.80176 .42733 L
s
1 .752 0 r
.01 w
[ .05 .05 ] 0 setdash
.80176 .42733 m
.80159 .42719 L
s
.80176 .42733 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66943 .48221 m
.66795 .48175 L
s
.74985 .45497 m
.74881 .4536 L
s
1 .752 0 r
.01 w
[ .05 .05 ] 0 setdash
.80159 .42719 m
.80137 .42702 L
s
.80159 .42719 Mdot
1 .747 0 r
.78885 .42717 Mdot
.78962 .42669 m
.78885 .42717 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42405 .45871 m
.4229 .46274 L
s
1 .752 0 r
.01 w
[ .05 .05 ] 0 setdash
.80137 .42702 m
.80109 .42683 L
s
.80137 .42702 Mdot
.80109 .42683 m
.80071 .42663 L
s
.80109 .42683 Mdot
1 .993 0 r
.26732 .4268 Mdot
1 .994 0 r
.26714 .42525 m
.26732 .4268 L
s
0 0 0 r
.004 w
.22491 .42674 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74606 .45607 m
.74519 .45873 L
s
1 .747 0 r
.01 w
.78962 .42669 Mdot
[ .05 .05 ] 0 setdash
.79027 .42634 m
.78962 .42669 L
s
1 .752 0 r
.80071 .42663 m
.80022 .42642 L
s
.80071 .42663 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67518 .4712 m
.67424 .47506 L
s
1 .751 0 r
.01 w
[ .05 .05 ] 0 setdash
.80022 .42642 m
.79961 .42621 L
s
.80022 .42642 Mdot
0 0 0 r
.004 w
.82438 .42641 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75102 .4571 m
.74985 .45497 L
s
1 .747 0 r
.01 w
.79027 .42634 Mdot
[ .05 .05 ] 0 setdash
.79078 .42609 m
.79027 .42634 L
s
1 .621 0 r
.40764 .42633 m
.40624 .42502 L
s
.40764 .42633 Mdot
1 .751 0 r
.79961 .42621 m
.79889 .42601 L
s
.79961 .42621 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73319 .46958 m
.73164 .46675 L
s
1 .747 0 r
.01 w
.79078 .42609 Mdot
[ .05 .05 ] 0 setdash
.79115 .42592 m
.79078 .42609 L
s
1 .751 0 r
.79889 .42601 m
.79806 .42582 L
s
.79889 .42601 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67073 .48173 m
.66943 .48221 L
s
1 .747 0 r
.01 w
.79115 .42592 Mdot
1 .748 0 r
[ .05 .05 ] 0 setdash
.7914 .42576 m
.79115 .42592 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78145 .45675 m
.78047 .45227 L
s
1 .751 0 r
.01 w
[ .05 .05 ] 0 setdash
.79806 .42582 m
.79718 .42564 L
s
.79806 .42582 Mdot
1 .748 0 r
.7914 .42576 Mdot
.79154 .42564 m
.7914 .42576 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74519 .45873 m
.74441 .46199 L
s
1 .748 0 r
.01 w
.79154 .42564 Mdot
[ .05 .05 ] 0 setdash
.7916 .42556 m
.79154 .42564 L
s
1 .751 0 r
.79718 .42564 m
.79632 .42551 L
s
.79718 .42564 Mdot
1 .748 0 r
.7916 .42556 Mdot
.79162 .42551 m
.7916 .42556 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.79176 .42726 m
.79162 .42551 L
s
1 .748 0 r
.01 w
.79162 .42551 Mdot
[ .05 .05 ] 0 setdash
.79164 .42546 m
.79162 .42551 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.79798 .44593 m
.79632 .42551 L
s
1 .75 0 r
.01 w
[ .05 .05 ] 0 setdash
.79632 .42551 m
.79543 .42541 L
s
.79632 .42551 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77723 .45518 m
.77662 .46086 L
s
1 .748 0 r
.01 w
.79164 .42546 Mdot
1 .749 0 r
[ .05 .05 ] 0 setdash
.79171 .42543 m
.79164 .42546 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67424 .47506 m
.67328 .47831 L
s
1 .749 0 r
.01 w
.79171 .42543 Mdot
[ .05 .05 ] 0 setdash
.79188 .4254 m
.79171 .42543 L
s
1 .75 0 r
.79543 .42541 m
.79461 .42537 L
s
.79543 .42541 Mdot
1 .749 0 r
.79188 .4254 Mdot
.79218 .42538 m
.79188 .4254 L
s
.79218 .42538 Mdot
.79263 .42537 m
.79218 .42538 L
s
.79263 .42537 Mdot
1 .75 0 r
.79319 .42536 m
.79263 .42537 L
s
.79461 .42537 m
.79383 .42534 L
s
.79461 .42537 Mdot
.79319 .42536 Mdot
.79383 .42534 m
.79319 .42536 L
s
.79383 .42534 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.26313 .47725 m
.26714 .42525 L
s
1 .994 0 r
.01 w
.26714 .42525 Mdot
[ .05 .05 ] 0 setdash
.26687 .42381 m
.26714 .42525 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80241 .43183 m
.80229 .43202 L
s
.80261 .43223 m
.80241 .43183 L
s
.67217 .48011 m
.67073 .48173 L
s
.75232 .45987 m
.75102 .4571 L
s
.80288 .43288 m
.80261 .43223 L
s
0 0 0 r
.004 w
.82553 .42506 Mdot
1 .621 0 r
.01 w
[ .05 .05 ] 0 setdash
.40624 .42502 m
.40491 .42382 L
s
.40624 .42502 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80229 .43202 m
.8022 .43267 L
s
.67328 .47831 m
.67217 .48011 L
s
.8032 .43345 m
.80288 .43288 L
s
.78494 .52376 m
.787 .52469 L
s
.80354 .43396 m
.8032 .43345 L
s
.79176 .42726 m
.79176 .42755 L
s
.79178 .42725 m
.79176 .42726 L
s
.79185 .42711 m
.79178 .42725 L
s
.79212 .42838 m
.79185 .42711 L
s
.8022 .43267 m
.80212 .43364 L
s
.79176 .42755 m
.79177 .42848 L
s
.4229 .46274 m
.42172 .46685 L
s
.80385 .43406 m
.80354 .43396 L
s
.80421 .43468 m
.80385 .43406 L
s
.74441 .46199 m
.74344 .46509 L
s
.73483 .47135 m
.73319 .46958 L
s
.80536 .43557 m
.80514 .43551 L
s
.80554 .43616 m
.80536 .43557 L
s
.80578 .43873 m
.80554 .43616 L
s
.80456 .43524 m
.80421 .43468 L
s
.79177 .42848 m
.7918 .43074 L
s
.80514 .43551 m
.80488 .43553 L
s
.80488 .43553 m
.80456 .43524 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.4031 .47454 m
.40491 .42382 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.40491 .42382 m
.40348 .42254 L
s
.40491 .42382 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79265 .43118 m
.79212 .42838 L
s
1 .994 0 r
.01 w
.26687 .42381 Mdot
[ .05 .05 ] 0 setdash
.2667 .42232 m
.26687 .42381 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80212 .43364 m
.80202 .43484 L
s
0 0 0 r
.004 w
.82667 .4237 Mdot
.53 .8 .95 r
.006 w
.75379 .46342 m
.75232 .45987 L
s
.80602 .44282 m
.80578 .43873 L
s
.74344 .46509 m
.74229 .46805 L
s
.7918 .43074 m
.79177 .43368 L
s
.73655 .47293 m
.73483 .47135 L
s
.80202 .43484 m
.8019 .43668 L
s
.27764 .51096 m
.27979 .50644 L
s
.78236 .46053 m
.78145 .45675 L
s
.77662 .46086 m
.77575 .46574 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.40348 .42254 m
.40201 .42123 L
s
.40348 .42254 Mdot
1 .994 0 r
.2667 .42232 Mdot
.26637 .42091 m
.2667 .42232 L
s
0 0 0 r
.004 w
.82781 .42232 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79336 .43458 m
.79265 .43118 L
s
.74229 .46805 m
.7411 .47076 L
s
.79177 .43368 m
.79171 .43771 L
s
.7554 .46706 m
.75379 .46342 L
s
.42172 .46685 m
.42031 .47079 L
s
.787 .52469 m
.78905 .52396 L
s
.80623 .44809 m
.80602 .44282 L
s
.73814 .47348 m
.73655 .47293 L
s
.8019 .43668 m
.80167 .43835 L
s
.7411 .47076 m
.73971 .4725 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.40201 .42123 m
.40072 .42012 L
s
.40201 .42123 Mdot
0 0 0 r
.004 w
.82894 .42093 Mdot
1 .994 0 r
.01 w
.26637 .42091 Mdot
.26601 .41948 m
.26637 .42091 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73971 .4725 m
.73814 .47348 L
s
.7942 .438 m
.79336 .43458 L
s
.80167 .43835 m
.80134 .44007 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.40072 .42012 m
.3993 .4189 L
s
.40072 .42012 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77575 .46574 m
.77449 .46965 L
s
.79171 .43771 m
.79149 .44173 L
s
.75724 .47011 m
.7554 .46706 L
s
.78348 .46347 m
.78236 .46053 L
s
.80634 .45401 m
.80623 .44809 L
s
.78905 .52396 m
.79058 .52187 L
s
0 0 0 r
.004 w
.83005 .41952 Mdot
1 .994 0 r
.01 w
.26601 .41948 Mdot
1 .995 0 r
[ .05 .05 ] 0 setdash
.26552 .41803 m
.26601 .41948 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80134 .44007 m
.80089 .44177 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.3993 .4189 m
.39787 .4177 L
s
.3993 .4189 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42031 .47079 m
.41892 .47378 L
s
0 0 0 r
.004 w
.21832 .41873 Mdot
.53 .8 .95 r
.006 w
.79507 .44072 m
.7942 .438 L
s
.27533 .51585 m
.27764 .51096 L
s
.75909 .47302 m
.75724 .47011 L
s
.79149 .44173 m
.79114 .44577 L
s
0 0 0 r
.004 w
.83116 .41809 Mdot
.53 .8 .95 r
.006 w
.77449 .46965 m
.77308 .47317 L
s
.79058 .52187 m
.79226 .51921 L
s
1 .995 0 r
.01 w
.26552 .41803 Mdot
[ .05 .05 ] 0 setdash
.26491 .41658 m
.26552 .41803 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80089 .44177 m
.8003 .44331 L
s
1 .619 0 r
.01 w
[ .05 .05 ] 0 setdash
.39787 .4177 m
.3964 .41647 L
s
.39787 .4177 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80636 .4605 m
.80634 .45401 L
s
.78471 .46549 m
.78348 .46347 L
s
.79609 .44366 m
.79507 .44072 L
s
1 .602 0 r
.01 w
[ .05 .05 ] 0 setdash
.28388 .41707 m
.28223 .41707 L
s
.28388 .41707 Mdot
.28579 .41696 m
.28388 .41707 L
s
.28223 .41707 m
.28061 .41702 L
s
.28223 .41707 Mdot
.28061 .41702 m
.27908 .41692 L
s
.28061 .41702 Mdot
.28579 .41696 Mdot
1 .603 0 r
.2876 .41687 m
.28579 .41696 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.27687 .44697 m
.27908 .41692 L
s
1 .602 0 r
.01 w
[ .05 .05 ] 0 setdash
.27908 .41692 m
.27761 .41671 L
s
.27908 .41692 Mdot
1 .603 0 r
.2876 .41687 Mdot
.28963 .41671 m
.2876 .41687 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8003 .44331 m
.7996 .44459 L
s
.76126 .47549 m
.75909 .47302 L
s
.79226 .51921 m
.79389 .51599 L
s
1 .601 0 r
.01 w
[ .05 .05 ] 0 setdash
.27761 .41671 m
.27627 .41642 L
s
.27761 .41671 Mdot
1 .603 0 r
.28963 .41671 Mdot
.29158 .41657 m
.28963 .41671 L
s
0 0 0 r
.004 w
.83226 .41665 Mdot
1 .995 0 r
.01 w
.26491 .41658 Mdot
.26422 .41516 m
.26491 .41658 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79114 .44577 m
.79066 .45007 L
s
1 .603 0 r
.01 w
.29158 .41657 Mdot
[ .05 .05 ] 0 setdash
.2936 .41638 m
.29158 .41657 L
s
1 .619 0 r
.3964 .41647 m
.3949 .41523 L
s
.3964 .41647 Mdot
1 .601 0 r
.27627 .41642 m
.27495 .41602 L
s
.27627 .41642 Mdot
1 .603 0 r
.2936 .41638 Mdot
.29554 .41623 m
.2936 .41638 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41892 .47378 m
.41741 .47642 L
s
.77308 .47317 m
.77139 .47503 L
s
1 .603 0 r
.01 w
.29554 .41623 Mdot
1 .604 0 r
[ .05 .05 ] 0 setdash
.29758 .41605 m
.29554 .41623 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29482 .45657 m
.29758 .41605 L
s
1 .604 0 r
.01 w
.29758 .41605 Mdot
[ .05 .05 ] 0 setdash
.29949 .41592 m
.29758 .41605 L
s
1 .601 0 r
.27495 .41602 m
.27371 .41553 L
s
.27495 .41602 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.33941 .44794 m
.34116 .41602 L
s
1 .574 0 r
.01 w
[ .05 .05 ] 0 setdash
.34116 .41602 m
.34289 .41594 L
s
.34116 .41602 Mdot
1 .575 0 r
.33957 .416 m
.34116 .41602 L
s
.33957 .416 Mdot
.33797 .41592 m
.33957 .416 L
s
1 .574 0 r
.34289 .41594 m
.34446 .41584 L
s
.34289 .41594 Mdot
1 .604 0 r
.29949 .41592 Mdot
.30149 .41579 m
.29949 .41592 L
s
1 .575 0 r
.33797 .41592 Mdot
.33641 .41573 m
.33797 .41592 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7996 .44459 m
.79884 .44601 L
s
1 .574 0 r
.01 w
[ .05 .05 ] 0 setdash
.34446 .41584 m
.34612 .41568 L
s
.34446 .41584 Mdot
1 .604 0 r
.30149 .41579 Mdot
.30352 .41569 m
.30149 .41579 L
s
1 .575 0 r
.33641 .41573 Mdot
.33489 .41544 m
.33641 .41573 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79389 .51599 m
.79549 .51386 L
s
1 .604 0 r
.01 w
.30352 .41569 Mdot
[ .05 .05 ] 0 setdash
.30546 .41563 m
.30352 .41569 L
s
1 .574 0 r
.34612 .41568 m
.34785 .41547 L
s
.34612 .41568 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79706 .44546 m
.79609 .44366 L
s
1 .604 0 r
.01 w
.30546 .41563 Mdot
1 .605 0 r
[ .05 .05 ] 0 setdash
.30755 .41555 m
.30546 .41563 L
s
.30755 .41555 Mdot
.30967 .41551 m
.30755 .41555 L
s
1 .601 0 r
.27371 .41553 m
.27253 .41498 L
s
.27371 .41553 Mdot
1 .605 0 r
.30967 .41551 Mdot
.3118 .41546 m
.30967 .41551 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76342 .4773 m
.76126 .47549 L
s
1 .573 0 r
.01 w
[ .05 .05 ] 0 setdash
.34785 .41547 m
.34943 .41526 L
s
.34785 .41547 Mdot
1 .605 0 r
.3118 .41546 Mdot
.31395 .41538 m
.3118 .41546 L
s
1 .575 0 r
.33489 .41544 Mdot
.33332 .41509 m
.33489 .41544 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77139 .47503 m
.7695 .47695 L
s
.80626 .46714 m
.80636 .4605 L
s
1 .605 0 r
.01 w
.31395 .41538 Mdot
1 .606 0 r
[ .05 .05 ] 0 setdash
.31615 .41529 m
.31395 .41538 L
s
.31615 .41529 Mdot
.31834 .41514 m
.31615 .41529 L
s
1 .573 0 r
.34943 .41526 m
.35107 .41501 L
s
.34943 .41526 Mdot
1 .619 0 r
.3949 .41523 m
.39341 .41402 L
s
.3949 .41523 Mdot
0 0 0 r
.004 w
.83335 .41519 Mdot
1 .995 0 r
.01 w
.26422 .41516 Mdot
.26335 .41362 m
.26422 .41516 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.31554 .46046 m
.31834 .41514 L
s
1 .606 0 r
.01 w
.31834 .41514 Mdot
[ .05 .05 ] 0 setdash
.3205 .41499 m
.31834 .41514 L
s
1 .575 0 r
.33332 .41509 Mdot
1 .576 0 r
.33165 .41459 m
.33332 .41509 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78581 .46695 m
.78471 .46549 L
s
.79066 .45007 m
.79017 .45454 L
s
1 .573 0 r
.01 w
[ .05 .05 ] 0 setdash
.35107 .41501 m
.35277 .41469 L
s
.35107 .41501 Mdot
1 .606 0 r
.3205 .41499 Mdot
.3228 .41474 m
.3205 .41499 L
s
1 .601 0 r
.27253 .41498 m
.27131 .41432 L
s
.27253 .41498 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79884 .44601 m
.79798 .44593 L
s
.79798 .44593 m
.79706 .44546 L
s
1 .606 0 r
.01 w
.3228 .41474 Mdot
[ .05 .05 ] 0 setdash
.32496 .41449 m
.3228 .41474 L
s
1 .573 0 r
.35277 .41469 m
.35422 .4144 L
s
.35277 .41469 Mdot
1 .576 0 r
.33165 .41459 Mdot
.32995 .41398 m
.33165 .41459 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76543 .47804 m
.76342 .4773 L
s
.7695 .47695 m
.76759 .47745 L
s
1 .606 0 r
.01 w
.32496 .41449 Mdot
1 .607 0 r
[ .05 .05 ] 0 setdash
.32732 .41413 m
.32496 .41449 L
s
1 .573 0 r
.35422 .4144 m
.35576 .41401 L
s
.35422 .4144 Mdot
1 .6 0 r
.27131 .41432 m
.27018 .41367 L
s
.27131 .41432 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76759 .47745 m
.76543 .47804 L
s
.79549 .51386 m
.79684 .51092 L
s
1 .607 0 r
.01 w
.32732 .41413 Mdot
[ .05 .05 ] 0 setdash
.32946 .41382 m
.32732 .41413 L
s
1 .619 0 r
.39341 .41402 m
.39185 .41273 L
s
.39341 .41402 Mdot
1 .572 0 r
.35576 .41401 m
.35701 .41362 L
s
.35576 .41401 Mdot
1 .576 0 r
.32995 .41398 Mdot
.32818 .4133 m
.32995 .41398 L
s
1 .607 0 r
.32946 .41382 Mdot
.33176 .4134 m
.32946 .41382 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41741 .47642 m
.41584 .47868 L
s
0 0 0 r
.004 w
.83444 .41372 Mdot
1 .6 0 r
.01 w
[ .05 .05 ] 0 setdash
.27018 .41367 m
.26902 .41294 L
s
.27018 .41367 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35552 .44343 m
.35701 .41362 L
s
1 .572 0 r
.01 w
[ .05 .05 ] 0 setdash
.35701 .41362 m
.35828 .41317 L
s
.35701 .41362 Mdot
1 .995 0 r
.26335 .41362 Mdot
.26236 .41212 m
.26335 .41362 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79017 .45454 m
.78957 .45856 L
s
.27312 .51856 m
.27533 .51585 L
s
1 .607 0 r
.01 w
.33176 .4134 Mdot
[ .05 .05 ] 0 setdash
.33387 .41299 m
.33176 .4134 L
s
1 .576 0 r
.32818 .4133 Mdot
.32629 .41242 m
.32818 .4133 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.806 .47362 m
.80626 .46714 L
s
1 .572 0 r
.01 w
[ .05 .05 ] 0 setdash
.35828 .41317 m
.35937 .41266 L
s
.35828 .41317 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79684 .51092 m
.7983 .5086 L
s
.78682 .46708 m
.78581 .46695 L
s
1 .607 0 r
.01 w
.33387 .41299 Mdot
[ .05 .05 ] 0 setdash
.33603 .41252 m
.33387 .41299 L
s
1 .6 0 r
.26902 .41294 m
.26779 .41214 L
s
.26902 .41294 Mdot
1 .619 0 r
.39185 .41273 m
.39029 .41144 L
s
.39185 .41273 Mdot
1 .572 0 r
.35937 .41266 m
.36033 .4121 L
s
.35937 .41266 Mdot
1 .607 0 r
.33603 .41252 Mdot
1 .608 0 r
.33794 .41207 m
.33603 .41252 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78957 .45856 m
.78882 .46239 L
s
0 0 0 r
.004 w
.21363 .41242 Mdot
1 .576 0 r
.01 w
.32629 .41242 Mdot
[ .05 .05 ] 0 setdash
.32445 .41152 m
.32629 .41242 L
s
0 0 0 r
.004 w
.83551 .41222 Mdot
1 .6 0 r
.01 w
.26779 .41214 m
.26666 .41142 L
s
.26779 .41214 Mdot
1 .995 0 r
.26236 .41212 Mdot
1 .996 0 r
.26132 .41073 m
.26236 .41212 L
s
1 .572 0 r
.36033 .4121 m
.3612 .41149 L
s
.36033 .4121 Mdot
1 .608 0 r
.33794 .41207 Mdot
.34005 .4115 m
.33794 .41207 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78797 .46516 m
.78682 .46708 L
s
.7983 .5086 m
.79981 .50748 L
s
.78882 .46239 m
.78797 .46516 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.32151 .46037 m
.32445 .41152 L
s
1 .576 0 r
.01 w
.32445 .41152 Mdot
1 .577 0 r
[ .05 .05 ] 0 setdash
.32256 .41046 m
.32445 .41152 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.33757 .45617 m
.34005 .4115 L
s
1 .608 0 r
.01 w
.34005 .4115 Mdot
[ .05 .05 ] 0 setdash
.34178 .411 m
.34005 .4115 L
s
1 .571 0 r
.3612 .41149 m
.362 .41085 L
s
.3612 .41149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80555 .47997 m
.806 .47362 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38819 .46341 m
.39029 .41144 L
s
1 .618 0 r
.01 w
[ .05 .05 ] 0 setdash
.39029 .41144 m
.38889 .41031 L
s
.39029 .41144 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.26395 .44643 m
.26666 .41142 L
s
1 .599 0 r
.01 w
[ .05 .05 ] 0 setdash
.26666 .41142 m
.26548 .41066 L
s
.26666 .41142 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41584 .47868 m
.41431 .47956 L
s
1 .608 0 r
.01 w
.34178 .411 Mdot
[ .05 .05 ] 0 setdash
.34383 .41036 m
.34178 .411 L
s
1 .571 0 r
.362 .41085 m
.36272 .41019 L
s
.362 .41085 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25699 .46552 m
.26132 .41073 L
s
1 .996 0 r
.01 w
.26132 .41073 Mdot
[ .05 .05 ] 0 setdash
.26004 .40927 m
.26132 .41073 L
s
0 0 0 r
.004 w
.83657 .41071 Mdot
1 .599 0 r
.01 w
.26548 .41066 m
.2643 .40986 L
s
.26548 .41066 Mdot
1 .577 0 r
.32256 .41046 Mdot
.32093 .40953 m
.32256 .41046 L
s
1 .608 0 r
.34383 .41036 Mdot
.34571 .40974 m
.34383 .41036 L
s
1 .618 0 r
.38889 .41031 m
.38738 .40907 L
s
.38889 .41031 Mdot
1 .571 0 r
.36272 .41019 m
.36343 .40953 L
s
.36272 .41019 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.805 .48626 m
.80555 .47997 L
s
1 .599 0 r
.01 w
[ .05 .05 ] 0 setdash
.2643 .40986 m
.26329 .40922 L
s
.2643 .40986 Mdot
1 .608 0 r
.34571 .40974 Mdot
1 .609 0 r
.34754 .40911 m
.34571 .40974 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79981 .50748 m
.80106 .50489 L
s
.27103 .51946 m
.27312 .51856 L
s
1 .571 0 r
.01 w
[ .05 .05 ] 0 setdash
.36343 .40953 m
.36407 .40885 L
s
.36343 .40953 Mdot
1 .577 0 r
.32093 .40953 Mdot
.31908 .40831 m
.32093 .40953 L
s
1 .996 0 r
.26004 .40927 Mdot
.25867 .40796 m
.26004 .40927 L
s
1 .599 0 r
.26329 .40922 m
.26229 .40858 L
s
.26329 .40922 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41431 .47956 m
.41282 .48021 L
s
0 0 0 r
.004 w
.83762 .40918 Mdot
1 .609 0 r
.01 w
.34754 .40911 Mdot
[ .05 .05 ] 0 setdash
.3493 .40846 m
.34754 .40911 L
s
1 .618 0 r
.38738 .40907 m
.38583 .40782 L
s
.38738 .40907 Mdot
1 .571 0 r
.36407 .40885 m
.36471 .40816 L
s
.36407 .40885 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80426 .49257 m
.805 .48626 L
s
1 .599 0 r
.01 w
[ .05 .05 ] 0 setdash
.26229 .40858 m
.26141 .40799 L
s
.26229 .40858 Mdot
1 .609 0 r
.3493 .40846 Mdot
.35091 .40782 m
.3493 .40846 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80106 .50489 m
.80237 .50149 L
s
1 .577 0 r
.01 w
.31908 .40831 Mdot
[ .05 .05 ] 0 setdash
.31756 .40724 m
.31908 .40831 L
s
1 .57 0 r
.36471 .40816 m
.36519 .40747 L
s
.36471 .40816 Mdot
1 .598 0 r
.26141 .40799 m
.26065 .4075 L
s
.26141 .40799 Mdot
1 .996 0 r
.25867 .40796 Mdot
.25714 .4067 m
.25867 .40796 L
s
1 .609 0 r
.35091 .40782 Mdot
.35284 .40703 m
.35091 .40782 L
s
1 .618 0 r
.38583 .40782 m
.38446 .40678 L
s
.38583 .40782 Mdot
0 0 0 r
.004 w
.83867 .40763 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80237 .50149 m
.80345 .49774 L
s
1 .598 0 r
.01 w
[ .05 .05 ] 0 setdash
.26065 .4075 m
.26006 .4071 L
s
.26065 .4075 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80345 .49774 m
.80426 .49257 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.3639 .43446 m
.36519 .40747 L
s
1 .57 0 r
.01 w
[ .05 .05 ] 0 setdash
.36519 .40747 m
.36568 .40676 L
s
.36519 .40747 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41282 .48021 m
.41135 .48022 L
s
1 .577 0 r
.01 w
.31756 .40724 Mdot
[ .05 .05 ] 0 setdash
.31633 .40632 m
.31756 .40724 L
s
1 .598 0 r
.26006 .4071 m
.25965 .40681 L
s
.26006 .4071 Mdot
1 .609 0 r
.35284 .40703 Mdot
1 .61 0 r
.35437 .40632 m
.35284 .40703 L
s
0 0 0 r
.004 w
.20992 .40701 Mdot
1 .598 0 r
.01 w
.25965 .40681 m
.25939 .40658 L
s
.25965 .40681 Mdot
1 .617 0 r
.38446 .40678 m
.38301 .40568 L
s
.38446 .40678 Mdot
1 .57 0 r
.36568 .40676 m
.36612 .40606 L
s
.36568 .40676 Mdot
1 .996 0 r
.25714 .4067 Mdot
.25561 .40562 m
.25714 .4067 L
s
1 .598 0 r
.25939 .40658 m
.25927 .40641 L
s
.25939 .40658 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25893 .41064 m
.25927 .40641 L
s
1 .597 0 r
.01 w
[ .05 .05 ] 0 setdash
.25927 .40641 m
.25923 .40627 L
s
.25927 .40641 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26919 .51826 m
.27103 .51946 L
s
1 .61 0 r
.01 w
.35437 .40632 Mdot
[ .05 .05 ] 0 setdash
.35599 .40553 m
.35437 .40632 L
s
1 .577 0 r
.31633 .40632 Mdot
1 .578 0 r
.31514 .40532 m
.31633 .40632 L
s
1 .597 0 r
.25923 .40627 m
.25926 .40614 L
s
.25923 .40627 Mdot
1 .586 0 r
.29775 .40619 m
.29851 .40619 L
s
.29775 .40619 Mdot
.29679 .40616 m
.29775 .40619 L
s
.29851 .40619 m
.29906 .40617 L
s
.29851 .40619 Mdot
.29906 .40617 m
.29945 .40613 L
s
.29906 .40617 Mdot
.29679 .40616 Mdot
1 .587 0 r
.29565 .40607 m
.29679 .40616 L
s
1 .597 0 r
.25926 .40614 m
.25935 .406 L
s
.25926 .40614 Mdot
1 .586 0 r
.29945 .40613 m
.29969 .4061 L
s
.29945 .40613 Mdot
1 .585 0 r
.29969 .4061 m
.2998 .40607 L
s
.29969 .4061 Mdot
1 .587 0 r
.29565 .40607 Mdot
.29425 .40595 m
.29565 .40607 L
s
1 .585 0 r
.2998 .40607 m
.29982 .40604 L
s
.2998 .40607 Mdot
1 .57 0 r
.36612 .40606 m
.36647 .40541 L
s
.36612 .40606 Mdot
0 0 0 r
.004 w
.8397 .40606 Mdot
1 .584 0 r
.01 w
.29925 .40605 m
.29927 .40605 L
s
.29925 .40605 Mdot
.29928 .40604 m
.29925 .40605 L
s
1 .583 0 r
.29927 .40605 m
.29935 .40602 L
s
.29927 .40605 Mdot
1 .584 0 r
.29928 .40604 Mdot
.29935 .40602 m
.29928 .40604 L
s
1 .585 0 r
.29982 .40604 m
.29977 .40602 L
s
.29982 .40604 Mdot
1 .584 0 r
.29935 .40602 Mdot
.29944 .40601 m
.29935 .40602 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29967 .40749 m
.29977 .40602 L
s
1 .585 0 r
.01 w
[ .05 .05 ] 0 setdash
.29977 .40602 m
.29967 .40601 L
s
.29977 .40602 Mdot
1 .583 0 r
.29935 .40602 m
.2995 .40597 L
s
.29935 .40602 Mdot
1 .585 0 r
.29967 .40601 m
.29956 .406 L
s
.29967 .40601 Mdot
1 .584 0 r
.29944 .40601 Mdot
.29956 .406 m
.29944 .40601 L
s
1 .597 0 r
.25935 .406 m
.2595 .40582 L
s
.25935 .406 Mdot
1 .584 0 r
.29956 .406 Mdot
1 .583 0 r
.2995 .40597 m
.29972 .4059 L
s
.2995 .40597 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29219 .43559 m
.29425 .40595 L
s
1 .587 0 r
.01 w
.29425 .40595 Mdot
[ .05 .05 ] 0 setdash
.29266 .40577 m
.29425 .40595 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29932 .41175 m
.29972 .4059 L
s
1 .583 0 r
.01 w
[ .05 .05 ] 0 setdash
.29972 .4059 m
.30001 .4058 L
s
.29972 .4059 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29922 .40646 m
.29922 .40676 L
s
.2992 .40722 m
.29922 .40646 L
s
1 .597 0 r
.01 w
[ .05 .05 ] 0 setdash
.2595 .40582 m
.25971 .40559 L
s
.2595 .40582 Mdot
1 .582 0 r
.30001 .4058 m
.30039 .40567 L
s
.30001 .4058 Mdot
1 .587 0 r
.29266 .40577 Mdot
.29099 .40554 m
.29266 .40577 L
s
1 .617 0 r
.38301 .40568 m
.38159 .40466 L
s
.38301 .40568 Mdot
1 .582 0 r
.30039 .40567 m
.30086 .40551 L
s
.30039 .40567 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29922 .40676 m
.29921 .40816 L
s
1 .996 0 r
.01 w
.25561 .40562 Mdot
1 .997 0 r
[ .05 .05 ] 0 setdash
.25397 .40461 m
.25561 .40562 L
s
1 .596 0 r
.25971 .40559 m
.25999 .4053 L
s
.25971 .40559 Mdot
1 .587 0 r
.29099 .40554 Mdot
1 .588 0 r
.28909 .40532 m
.29099 .40554 L
s
1 .61 0 r
.35599 .40553 Mdot
.35759 .4047 m
.35599 .40553 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29973 .40709 m
.29975 .40713 L
s
.29952 .40855 m
.29973 .40709 L
s
1 .582 0 r
.01 w
[ .05 .05 ] 0 setdash
.30086 .40551 m
.30145 .40531 L
s
.30086 .40551 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29975 .40713 m
.29967 .40749 L
s
.41135 .48022 m
.40978 .48042 L
s
1 .569 0 r
.01 w
[ .05 .05 ] 0 setdash
.36647 .40541 m
.36682 .40483 L
s
.36647 .40541 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29924 .40758 m
.2992 .40722 L
s
1 .588 0 r
.01 w
.28909 .40532 Mdot
[ .05 .05 ] 0 setdash
.28725 .40507 m
.28909 .40532 L
s
1 .578 0 r
.31514 .40532 Mdot
.3141 .4044 m
.31514 .40532 L
s
1 .582 0 r
.30145 .40531 m
.30214 .40508 L
s
.30145 .40531 Mdot
1 .596 0 r
.25999 .4053 m
.26033 .40496 L
s
.25999 .4053 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29967 .40749 m
.29957 .40756 L
s
.29934 .4076 m
.29924 .40758 L
s
.29957 .40756 m
.29945 .40754 L
s
.29945 .40754 m
.29934 .4076 L
s
1 .582 0 r
.01 w
[ .05 .05 ] 0 setdash
.30214 .40508 m
.30295 .4048 L
s
.30214 .40508 Mdot
1 .588 0 r
.28725 .40507 Mdot
.28529 .40473 m
.28725 .40507 L
s
1 .596 0 r
.26033 .40496 m
.26074 .40457 L
s
.26033 .40496 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29921 .40816 m
.29924 .40986 L
s
1 .569 0 r
.01 w
[ .05 .05 ] 0 setdash
.36682 .40483 m
.36715 .40431 L
s
.36682 .40483 Mdot
1 .581 0 r
.30295 .4048 m
.3038 .40451 L
s
.30295 .4048 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29912 .41103 m
.29952 .40855 L
s
1 .588 0 r
.01 w
.28529 .40473 Mdot
[ .05 .05 ] 0 setdash
.28346 .40446 m
.28529 .40473 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35545 .44722 m
.35759 .4047 L
s
1 .61 0 r
.01 w
.35759 .4047 Mdot
[ .05 .05 ] 0 setdash
.35892 .40394 m
.35759 .4047 L
s
1 .617 0 r
.38159 .40466 m
.38024 .4037 L
s
.38159 .40466 Mdot
1 .997 0 r
.25397 .40461 Mdot
.25239 .40376 m
.25397 .40461 L
s
1 .596 0 r
.26074 .40457 m
.26116 .40415 L
s
.26074 .40457 Mdot
1 .581 0 r
.3038 .40451 m
.30475 .40419 L
s
.3038 .40451 Mdot
0 0 0 r
.004 w
.84072 .40447 Mdot
1 .588 0 r
.01 w
.28346 .40446 Mdot
.28178 .40416 m
.28346 .40446 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25896 .40963 m
.25897 .40987 L
s
.25893 .41064 m
.25896 .40963 L
s
1 .578 0 r
.01 w
.3141 .4044 Mdot
[ .05 .05 ] 0 setdash
.31337 .40375 m
.3141 .4044 L
s
1 .569 0 r
.36715 .40431 m
.36746 .40387 L
s
.36715 .40431 Mdot
1 .581 0 r
.30475 .40419 m
.30569 .40387 L
s
.30475 .40419 Mdot
1 .588 0 r
.28178 .40416 Mdot
1 .589 0 r
.28019 .40395 m
.28178 .40416 L
s
1 .595 0 r
.26116 .40415 m
.26159 .40369 L
s
.26116 .40415 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25897 .40987 m
.25895 .41105 L
s
.25889 .41294 m
.25893 .41064 L
s
.26757 .51633 m
.26919 .51826 L
s
1 .589 0 r
.01 w
.28019 .40395 Mdot
[ .05 .05 ] 0 setdash
.27875 .40369 m
.28019 .40395 L
s
1 .61 0 r
.35892 .40394 Mdot
.36021 .40318 m
.35892 .40394 L
s
1 .569 0 r
.36746 .40387 m
.36773 .40353 L
s
.36746 .40387 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29924 .40986 m
.29932 .41175 L
s
1 .581 0 r
.01 w
[ .05 .05 ] 0 setdash
.30569 .40387 m
.30663 .40353 L
s
.30569 .40387 Mdot
1 .997 0 r
.25239 .40376 Mdot
.25082 .40302 m
.25239 .40376 L
s
1 .578 0 r
.31337 .40375 Mdot
.31264 .40306 m
.31337 .40375 L
s
1 .617 0 r
.38024 .4037 m
.37907 .40287 L
s
.38024 .4037 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25996 .42432 m
.26159 .40369 L
s
1 .595 0 r
.01 w
[ .05 .05 ] 0 setdash
.26159 .40369 m
.26201 .4032 L
s
.26159 .40369 Mdot
1 .589 0 r
.27875 .40369 Mdot
.27747 .40349 m
.27875 .40369 L
s
1 .569 0 r
.36773 .40353 m
.36798 .40327 L
s
.36773 .40353 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.30512 .42654 m
.30663 .40353 L
s
1 .581 0 r
.01 w
[ .05 .05 ] 0 setdash
.30663 .40353 m
.30752 .40318 L
s
.30663 .40353 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.27573 .42682 m
.27747 .40349 L
s
1 .589 0 r
.01 w
.27747 .40349 Mdot
[ .05 .05 ] 0 setdash
.27642 .40334 m
.27747 .40349 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29852 .41422 m
.29912 .41103 L
s
1 .56 0 r
.01 w
[ .05 .05 ] 0 setdash
.36963 .40348 m
.36954 .40345 L
s
.36963 .40348 Mdot
1 .561 0 r
.36971 .40348 m
.36963 .40348 L
s
.36971 .40348 Mdot
.36977 .40345 m
.36971 .40348 L
s
.36977 .40345 Mdot
.36981 .40342 m
.36977 .40345 L
s
1 .56 0 r
.36954 .40345 m
.36945 .40338 L
s
.36954 .40345 Mdot
1 .561 0 r
.36981 .40342 Mdot
.36982 .40339 m
.36981 .40342 L
s
.36982 .40339 Mdot
1 .562 0 r
.36981 .40335 m
.36982 .40339 L
s
1 .56 0 r
.36945 .40338 m
.36937 .40325 L
s
.36945 .40338 Mdot
1 .566 0 r
.36988 .40336 m
.36984 .40334 L
s
.36988 .40336 Mdot
.36991 .40335 m
.36988 .40336 L
s
1 .562 0 r
.36981 .40335 Mdot
.36979 .40333 m
.36981 .40335 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36988 .40395 m
.36991 .40335 L
s
1 .566 0 r
.01 w
.36991 .40335 Mdot
[ .05 .05 ] 0 setdash
.3699 .40331 m
.36991 .40335 L
s
1 .565 0 r
.36984 .40334 m
.3698 .40332 L
s
.36984 .40334 Mdot
1 .589 0 r
.27642 .40334 Mdot
.27556 .4032 m
.27642 .40334 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36976 .40381 m
.36979 .40333 L
s
1 .562 0 r
.01 w
.36979 .40333 Mdot
[ .05 .05 ] 0 setdash
.36977 .40331 m
.36979 .40333 L
s
1 .565 0 r
.3698 .40332 m
.36977 .40331 L
s
.3698 .40332 Mdot
1 .562 0 r
.36977 .40331 Mdot
.36976 .4033 m
.36977 .40331 L
s
1 .565 0 r
.36977 .40331 m
.36976 .4033 L
s
.36977 .40331 Mdot
1 .566 0 r
.3699 .40331 Mdot
.36985 .40324 m
.3699 .40331 L
s
1 .565 0 r
.36976 .4033 m
.36976 .4033 L
s
.36976 .4033 Mdot
1 .562 0 r
.36976 .4033 Mdot
.36976 .4033 m
.36976 .4033 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36976 .4033 m
.36976 .4033 L
s
1 .563 0 r
.01 w
.36976 .4033 Mdot
.36976 .4033 Mdot
.36976 .4033 Mdot
1 .564 0 r
.36976 .4033 Mdot
.36976 .4033 Mdot
1 .565 0 r
.36976 .4033 Mdot
1 .563 0 r
.36976 .4033 Mdot
1 .562 0 r
.36976 .4033 Mdot
1 .563 0 r
.36976 .4033 Mdot
1 .564 0 r
.36976 .4033 Mdot
.36976 .4033 Mdot
.36976 .4033 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36976 .40333 m
.36976 .4033 L
s
.36976 .4033 m
.36976 .40333 L
s
.36976 .40349 m
.36976 .40333 L
s
.36976 .40333 m
.36976 .4035 L
s
.25895 .41105 m
.25894 .41292 L
s
1 .568 0 r
.01 w
[ .05 .05 ] 0 setdash
.36798 .40327 m
.36821 .40307 L
s
.36798 .40327 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40978 .48042 m
.40855 .47978 L
s
1 .56 0 r
.01 w
[ .05 .05 ] 0 setdash
.36937 .40325 m
.36932 .40303 L
s
.36937 .40325 Mdot
1 .566 0 r
.36985 .40324 Mdot
1 .567 0 r
.36975 .40315 m
.36985 .40324 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36978 .40378 m
.36976 .40349 L
s
1 .589 0 r
.01 w
.27556 .4032 Mdot
1 .59 0 r
[ .05 .05 ] 0 setdash
.27483 .40309 m
.27556 .4032 L
s
1 .595 0 r
.26201 .4032 m
.26238 .40274 L
s
.26201 .4032 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36976 .4035 m
.36976 .40381 L
s
1 .61 0 r
.01 w
.36021 .40318 Mdot
1 .611 0 r
[ .05 .05 ] 0 setdash
.36141 .40246 m
.36021 .40318 L
s
1 .58 0 r
.30752 .40318 m
.30829 .40284 L
s
.30752 .40318 Mdot
1 .567 0 r
.36975 .40315 Mdot
.36961 .40305 m
.36975 .40315 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25888 .41646 m
.25889 .41294 L
s
1 .59 0 r
.01 w
.27483 .40309 Mdot
[ .05 .05 ] 0 setdash
.27421 .40298 m
.27483 .40309 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3698 .40409 m
.36978 .40378 L
s
1 .568 0 r
.01 w
[ .05 .05 ] 0 setdash
.36821 .40307 m
.3684 .40293 L
s
.36821 .40307 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36976 .40381 m
.36977 .40412 L
s
1 .578 0 r
.01 w
.31264 .40306 Mdot
[ .05 .05 ] 0 setdash
.31206 .40253 m
.31264 .40306 L
s
1 .567 0 r
.36961 .40305 Mdot
.36943 .40295 m
.36961 .40305 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36892 .41142 m
.36932 .40303 L
s
1 .56 0 r
.01 w
[ .05 .05 ] 0 setdash
.36932 .40303 m
.36928 .40271 L
s
.36932 .40303 Mdot
1 .997 0 r
.25082 .40302 Mdot
.24918 .40246 m
.25082 .40302 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36988 .40395 m
.36984 .40421 L
s
.36986 .40406 m
.36988 .40395 L
s
1 .59 0 r
.01 w
.27421 .40298 Mdot
[ .05 .05 ] 0 setdash
.27368 .40289 m
.27421 .40298 L
s
1 .567 0 r
.36943 .40295 Mdot
.36921 .40287 m
.36943 .40295 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36984 .40421 m
.3698 .40409 L
s
.36977 .40412 m
.36978 .40434 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.36814 .40859 m
.3684 .40293 L
s
1 .568 0 r
.01 w
[ .05 .05 ] 0 setdash
.3684 .40293 m
.36858 .40284 L
s
.3684 .40293 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36976 .40502 m
.36986 .40406 L
s
.36973 .40449 m
.36965 .40467 L
s
.36977 .40442 m
.36973 .40449 L
s
1 .59 0 r
.01 w
.27368 .40289 Mdot
[ .05 .05 ] 0 setdash
.27317 .40277 m
.27368 .40289 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36978 .40434 m
.36977 .40442 L
s
1 .617 0 r
.01 w
[ .05 .05 ] 0 setdash
.37907 .40287 m
.37806 .40213 L
s
.37907 .40287 Mdot
1 .567 0 r
.36921 .40287 Mdot
.36898 .40281 m
.36921 .40287 L
s
0 0 0 r
.004 w
.84172 .40286 Mdot
1 .568 0 r
.01 w
.36858 .40284 m
.36877 .4028 L
s
.36858 .40284 Mdot
1 .58 0 r
.30829 .40284 m
.30897 .40253 L
s
.30829 .40284 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36965 .40467 m
.36955 .40506 L
s
1 .567 0 r
.01 w
.36898 .40281 Mdot
1 .568 0 r
[ .05 .05 ] 0 setdash
.36877 .4028 m
.36898 .40281 L
s
.36877 .4028 Mdot
1 .59 0 r
.27317 .40277 Mdot
.27269 .40266 m
.27317 .40277 L
s
1 .595 0 r
.26238 .40274 m
.26276 .40229 L
s
.26238 .40274 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29932 .41175 m
.29947 .41377 L
s
1 .559 0 r
.01 w
[ .05 .05 ] 0 setdash
.36928 .40271 m
.3693 .40229 L
s
.36928 .40271 Mdot
1 .59 0 r
.27269 .40266 Mdot
1 .591 0 r
.27217 .40255 m
.27269 .40266 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36955 .40506 m
.36943 .40577 L
s
1 .591 0 r
.01 w
.27217 .40255 Mdot
[ .05 .05 ] 0 setdash
.27157 .40241 m
.27217 .40255 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.31107 .4181 m
.31206 .40253 L
s
1 .578 0 r
.01 w
.31206 .40253 Mdot
1 .579 0 r
[ .05 .05 ] 0 setdash
.31161 .40217 m
.31206 .40253 L
s
1 .58 0 r
.30897 .40253 m
.30957 .40224 L
s
.30897 .40253 Mdot
1 .611 0 r
.36141 .40246 Mdot
.36239 .40184 m
.36141 .40246 L
s
1 .997 0 r
.24918 .40246 Mdot
.24767 .40192 m
.24918 .40246 L
s
1 .591 0 r
.27157 .40241 Mdot
.27091 .40226 m
.27157 .40241 L
s
1 .595 0 r
.26276 .40229 m
.26308 .40192 L
s
.26276 .40229 Mdot
1 .559 0 r
.3693 .40229 m
.36939 .40174 L
s
.3693 .40229 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36962 .40612 m
.36976 .40502 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.26975 .41748 m
.27091 .40226 L
s
1 .591 0 r
.01 w
.27091 .40226 Mdot
[ .05 .05 ] 0 setdash
.27019 .40211 m
.27091 .40226 L
s
1 .58 0 r
.30957 .40224 m
.31005 .40204 L
s
.30957 .40224 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36943 .40577 m
.36928 .40693 L
s
0 0 0 r
.004 w
.20685 .40218 Mdot
1 .579 0 r
.01 w
.31161 .40217 Mdot
[ .05 .05 ] 0 setdash
.31123 .40195 m
.31161 .40217 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26626 .51265 m
.26757 .51633 L
s
1 .616 0 r
.01 w
[ .05 .05 ] 0 setdash
.37806 .40213 m
.37721 .40147 L
s
.37806 .40213 Mdot
1 .591 0 r
.27019 .40211 Mdot
.26942 .40195 m
.27019 .40211 L
s
1 .58 0 r
.31005 .40204 m
.31048 .4019 L
s
.31005 .40204 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25894 .41292 m
.25895 .41521 L
s
1 .591 0 r
.01 w
.26942 .40195 Mdot
1 .592 0 r
[ .05 .05 ] 0 setdash
.26863 .4018 m
.26942 .40195 L
s
1 .579 0 r
.31123 .40195 Mdot
.31086 .40186 m
.31123 .40195 L
s
1 .997 0 r
.24767 .40192 Mdot
1 .998 0 r
.24626 .40147 m
.24767 .40192 L
s
1 .594 0 r
.26308 .40192 m
.26338 .4016 L
s
.26308 .40192 Mdot
1 .579 0 r
.31048 .4019 m
.31086 .40186 L
s
.31048 .4019 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40855 .47978 m
.40716 .47868 L
s
1 .579 0 r
.01 w
.31086 .40186 Mdot
.53 .8 .95 r
.006 w
.27424 .44366 m
.27293 .44311 L
s
.27552 .44503 m
.27424 .44366 L
s
1 .611 0 r
.01 w
.36239 .40184 Mdot
[ .05 .05 ] 0 setdash
.36319 .40129 m
.36239 .40184 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29771 .41798 m
.29852 .41422 L
s
1 .592 0 r
.01 w
.26863 .4018 Mdot
[ .05 .05 ] 0 setdash
.26785 .40164 m
.26863 .4018 L
s
1 .559 0 r
.36939 .40174 m
.36956 .40106 L
s
.36939 .40174 Mdot
1 .592 0 r
.26785 .40164 Mdot
.26712 .40149 m
.26785 .40164 L
s
1 .594 0 r
.26338 .4016 m
.26366 .40134 L
s
.26338 .4016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25896 .42105 m
.25888 .41646 L
s
.27687 .44697 m
.27552 .44503 L
s
.36942 .40719 m
.36962 .40612 L
s
.27293 .44311 m
.27159 .44374 L
s
.29947 .41377 m
.2997 .41593 L
s
1 .592 0 r
.01 w
.26712 .40149 Mdot
[ .05 .05 ] 0 setdash
.26647 .40134 m
.26712 .40149 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24373 .43162 m
.24626 .40147 L
s
1 .998 0 r
.01 w
.24626 .40147 Mdot
[ .05 .05 ] 0 setdash
.24487 .40112 m
.24626 .40147 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37611 .42618 m
.37721 .40147 L
s
1 .616 0 r
.01 w
[ .05 .05 ] 0 setdash
.37721 .40147 m
.37652 .40092 L
s
.37721 .40147 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36928 .40693 m
.36911 .4088 L
s
1 .594 0 r
.01 w
[ .05 .05 ] 0 setdash
.26366 .40134 m
.26392 .40116 L
s
.26366 .40134 Mdot
1 .592 0 r
.26647 .40134 Mdot
1 .593 0 r
.26593 .4012 m
.26647 .40134 L
s
1 .611 0 r
.36319 .40129 Mdot
.36385 .4008 m
.36319 .40129 L
s
0 0 0 r
.004 w
.84272 .40123 Mdot
1 .593 0 r
.01 w
.26593 .4012 Mdot
.26547 .4011 m
.26593 .4012 L
s
1 .594 0 r
.26392 .40116 m
.26417 .40105 L
s
.26392 .40116 Mdot
1 .998 0 r
.24487 .40112 Mdot
.2437 .4008 m
.24487 .40112 L
s
1 .593 0 r
.26547 .4011 Mdot
.26508 .40102 m
.26547 .4011 L
s
1 .559 0 r
.36956 .40106 m
.36976 .40027 L
s
.36956 .40106 Mdot
1 .594 0 r
.26417 .40105 m
.26445 .401 L
s
.26417 .40105 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26523 .50789 m
.26626 .51265 L
s
1 .593 0 r
.01 w
.26508 .40102 Mdot
[ .05 .05 ] 0 setdash
.26475 .40099 m
.26508 .40102 L
s
.26445 .401 m
.26475 .40099 L
s
.26445 .401 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.26437 .40581 m
.26475 .40099 L
s
1 .593 0 r
.01 w
.26475 .40099 Mdot
1 .616 0 r
[ .05 .05 ] 0 setdash
.37652 .40092 m
.37596 .4005 L
s
.37652 .40092 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27824 .4494 m
.27687 .44697 L
s
.36919 .40811 m
.36942 .40719 L
s
1 .998 0 r
.01 w
.2437 .4008 Mdot
[ .05 .05 ] 0 setdash
.24265 .40053 m
.2437 .4008 L
s
1 .611 0 r
.36385 .4008 Mdot
.36429 .4004 m
.36385 .4008 L
s
1 .998 0 r
.24265 .40053 Mdot
1 .999 0 r
.24182 .40029 m
.24265 .40053 L
s
1 .616 0 r
.37596 .4005 m
.37541 .40016 L
s
.37596 .4005 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2645 .50368 m
.26523 .50789 L
s
.40716 .47868 m
.40584 .47789 L
s
.27159 .44374 m
.27032 .44425 L
s
1 .611 0 r
.01 w
.36429 .4004 Mdot
1 .612 0 r
[ .05 .05 ] 0 setdash
.36454 .40009 m
.36429 .4004 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25895 .41521 m
.25899 .41783 L
s
1 .999 0 r
.01 w
.24182 .40029 Mdot
[ .05 .05 ] 0 setdash
.24118 .40008 m
.24182 .40029 L
s
1 .559 0 r
.36976 .40027 m
.37002 .39934 L
s
.36976 .40027 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36911 .4088 m
.36892 .41142 L
s
.36893 .40868 m
.36919 .40811 L
s
1 .616 0 r
.01 w
[ .05 .05 ] 0 setdash
.37541 .40016 m
.37485 .3999 L
s
.37541 .40016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2997 .41593 m
.29999 .4184 L
s
1 .612 0 r
.01 w
.36454 .40009 Mdot
[ .05 .05 ] 0 setdash
.36463 .39988 m
.36454 .40009 L
s
1 .999 0 r
.24118 .40008 Mdot
.24072 .39991 m
.24118 .40008 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36833 .40816 m
.3685 .40851 L
s
.36814 .40859 m
.36833 .40816 L
s
1 .999 0 r
.01 w
.24072 .39991 Mdot
[ .05 .05 ] 0 setdash
.2404 .39974 m
.24072 .39991 L
s
1 .615 0 r
.37485 .3999 m
.37424 .39972 L
s
.37485 .3999 Mdot
1 .612 0 r
.36463 .39988 Mdot
.36464 .39974 m
.36463 .39988 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36787 .4103 m
.36814 .40859 L
s
.29667 .42204 m
.29771 .41798 L
s
1 .613 0 r
.01 w
[ .05 .05 ] 0 setdash
.36762 .39979 m
.36682 .39979 L
s
.36762 .39979 Mdot
1 .614 0 r
.36841 .39976 m
.36762 .39979 L
s
1 .613 0 r
.36682 .39979 m
.36607 .39976 L
s
.36682 .39979 Mdot
1 .614 0 r
.36841 .39976 Mdot
.36933 .39967 m
.36841 .39976 L
s
1 .613 0 r
.36607 .39976 m
.36545 .39972 L
s
.36607 .39976 Mdot
1 .999 0 r
.2404 .39974 Mdot
.24022 .3996 m
.2404 .39974 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.3645 .40272 m
.36464 .39974 L
s
1 .612 0 r
.01 w
.36464 .39974 Mdot
[ .05 .05 ] 0 setdash
.36467 .39968 m
.36464 .39974 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26379 .49934 m
.2645 .50368 L
s
1 .613 0 r
.01 w
[ .05 .05 ] 0 setdash
.36545 .39972 m
.36502 .39968 L
s
.36545 .39972 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3687 .40879 m
.36893 .40868 L
s
1 .615 0 r
.01 w
[ .05 .05 ] 0 setdash
.37424 .39972 m
.37355 .39961 L
s
.37424 .39972 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3685 .40851 m
.3687 .40879 L
s
.27967 .45229 m
.27824 .4494 L
s
1 .613 0 r
.01 w
[ .05 .05 ] 0 setdash
.36502 .39968 m
.36478 .39966 L
s
.36502 .39968 Mdot
1 .612 0 r
.36467 .39968 Mdot
.36478 .39966 m
.36467 .39968 L
s
1 .614 0 r
.36933 .39967 Mdot
.37009 .39963 m
.36933 .39967 L
s
1 .612 0 r
.36478 .39966 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36914 .42002 m
.37009 .39963 L
s
1 .614 0 r
.01 w
.37009 .39963 Mdot
[ .05 .05 ] 0 setdash
.371 .39958 m
.37009 .39963 L
s
1 .615 0 r
.37355 .39961 m
.37277 .39956 L
s
.37355 .39961 Mdot
1 .999 0 r
.24022 .3996 Mdot
1 1 0 r
.24015 .39949 m
.24022 .3996 L
s
1 .614 0 r
.371 .39958 Mdot
1 .615 0 r
.37191 .39956 m
.371 .39958 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2592 .42575 m
.25896 .42105 L
s
0 0 0 r
.004 w
.84371 .39957 Mdot
1 .615 0 r
.01 w
[ .05 .05 ] 0 setdash
.37277 .39956 m
.37191 .39956 L
s
.37277 .39956 Mdot
.37191 .39956 Mdot
1 1 0 r
.24015 .39949 Mdot
.24013 .39941 m
.24015 .39949 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33625 .44664 m
.33783 .44724 L
s
.33468 .4464 m
.33625 .44664 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.24 .40094 m
.24013 .39941 L
s
1 1 0 r
.01 w
.24013 .39941 Mdot
1 .558 0 r
[ .05 .05 ] 0 setdash
.37002 .39934 m
.37036 .39829 L
s
.37002 .39934 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33306 .44751 m
.33468 .4464 L
s
.27032 .44425 m
.26898 .44511 L
s
.33783 .44724 m
.33941 .44794 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.23977 .40107 m
.23993 .39923 L
s
.01 w
[ .05 .05 ] 0 setdash
.23981 .3991 m
.23993 .39923 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36754 .41272 m
.36787 .4103 L
s
1 0 0 r
.01 w
.23981 .3991 Mdot
[ .05 .05 ] 0 setdash
.23958 .39887 m
.23981 .3991 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36473 .40076 m
.36462 .4008 L
s
.36483 .4037 m
.36473 .40076 L
s
.36462 .4008 m
.3645 .40272 L
s
.40584 .47789 m
.40442 .47658 L
s
.26333 .49545 m
.26379 .49934 L
s
.33941 .44794 m
.34109 .44891 L
s
.26414 .40487 m
.26437 .40581 L
s
.26386 .40505 m
.26414 .40487 L
s
.26347 .40678 m
.26386 .40505 L
s
1 0 0 r
.01 w
.23958 .39887 Mdot
1 .001 0 r
[ .05 .05 ] 0 setdash
.23923 .39849 m
.23958 .39887 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31048 .40776 m
.3108 .40866 L
s
.30993 .41038 m
.31048 .40776 L
s
.24 .40094 m
.23984 .40309 L
s
.29999 .4184 m
.30041 .4207 L
s
.25899 .41783 m
.25913 .42014 L
s
1 .001 0 r
.01 w
.23923 .39849 Mdot
[ .05 .05 ] 0 setdash
.23872 .39794 m
.23923 .39849 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36892 .41142 m
.36873 .41462 L
s
.26437 .40581 m
.26458 .4074 L
s
.3108 .40866 m
.31094 .41272 L
s
.26323 .49039 m
.26333 .49545 L
s
1 .558 0 r
.01 w
[ .05 .05 ] 0 setdash
.37036 .39829 m
.37071 .3971 L
s
.37036 .39829 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34109 .44891 m
.34262 .44992 L
s
.35804 .43947 m
.35902 .43872 L
s
.35688 .44121 m
.35804 .43947 L
s
.33136 .44928 m
.33306 .44751 L
s
.23936 .40436 m
.23977 .40107 L
s
.28117 .45465 m
.27967 .45229 L
s
.26314 .48597 m
.26323 .49039 L
s
.36718 .41535 m
.36754 .41272 L
s
.3645 .40272 m
.36437 .40526 L
s
.35552 .44343 m
.35688 .44121 L
s
.263 .40963 m
.26347 .40678 L
s
.273 .41187 m
.27344 .41324 L
s
.27247 .41202 m
.273 .41187 L
s
1 .001 0 r
.01 w
.23872 .39794 Mdot
[ .05 .05 ] 0 setdash
.23806 .39724 m
.23872 .39794 L
s
0 0 0 r
.004 w
.84468 .3979 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26309 .48182 m
.26314 .48597 L
s
.26898 .44511 m
.2677 .4462 L
s
.35902 .43872 m
.35988 .43847 L
s
.27193 .41268 m
.27247 .41202 L
s
0 0 0 r
.004 w
.20423 .39774 Mdot
.53 .8 .95 r
.006 w
.25959 .43093 m
.2592 .42575 L
s
.29538 .42668 m
.29667 .42204 L
s
.35413 .44606 m
.35552 .44343 L
s
.40442 .47658 m
.4031 .47454 L
s
.26313 .47725 m
.26309 .48182 L
s
.26305 .47334 m
.26313 .47725 L
s
.34262 .44992 m
.34424 .45076 L
s
.26458 .4074 m
.26481 .40953 L
s
.23984 .40309 m
.23973 .40537 L
s
.36508 .40753 m
.36483 .4037 L
s
.26296 .47084 m
.26305 .47334 L
s
.27344 .41324 m
.27391 .4154 L
s
.30929 .41383 m
.30993 .41038 L
s
1 .001 0 r
.01 w
.23806 .39724 Mdot
[ .05 .05 ] 0 setdash
.2372 .39633 m
.23806 .39724 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27129 .41417 m
.27193 .41268 L
s
.36678 .4183 m
.36718 .41535 L
s
1 .558 0 r
.01 w
[ .05 .05 ] 0 setdash
.37071 .3971 m
.37111 .39583 L
s
.37071 .3971 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30041 .4207 m
.30093 .42312 L
s
.35988 .43847 m
.36067 .43812 L
s
.283 .45589 m
.28117 .45465 L
s
.36437 .40526 m
.3641 .40907 L
s
.34424 .45076 m
.34595 .45126 L
s
.26248 .41299 m
.263 .40963 L
s
.4031 .47454 m
.40167 .47257 L
s
.35249 .44826 m
.35413 .44606 L
s
.32953 .45138 m
.33136 .44928 L
s
.25913 .42014 m
.25934 .42215 L
s
.26481 .40953 m
.26508 .41218 L
s
.26265 .46899 m
.26296 .47084 L
s
.23973 .40537 m
.23974 .40752 L
s
.31094 .41272 m
.31107 .4181 L
s
.27391 .4154 m
.27442 .41841 L
s
1 .001 0 r
.01 w
.2372 .39633 Mdot
[ .05 .05 ] 0 setdash
.23616 .39526 m
.2372 .39633 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34595 .45126 m
.34752 .45161 L
s
.36873 .41462 m
.36854 .41865 L
s
.27056 .4157 m
.27129 .41417 L
s
.23873 .40874 m
.23936 .40436 L
s
.35094 .45033 m
.35249 .44826 L
s
.2677 .4462 m
.26641 .44689 L
s
0 0 0 r
.004 w
.84564 .3962 Mdot
.53 .8 .95 r
.006 w
.36067 .43812 m
.36138 .4379 L
s
.28476 .45679 m
.283 .45589 L
s
.36633 .42158 m
.36678 .4183 L
s
.40167 .47257 m
.40018 .47121 L
s
1 .558 0 r
.01 w
[ .05 .05 ] 0 setdash
.37111 .39583 m
.3715 .39438 L
s
.37111 .39583 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34752 .45161 m
.34919 .45124 L
s
.30861 .41713 m
.30929 .41383 L
s
.26017 .43548 m
.25959 .43093 L
s
.34919 .45124 m
.35094 .45033 L
s
.23974 .40752 m
.23988 .40976 L
s
.28676 .45734 m
.28476 .45679 L
s
.36549 .41187 m
.36508 .40753 L
s
.26194 .41641 m
.26248 .41299 L
s
.30093 .42312 m
.30159 .4252 L
s
.36138 .4379 m
.36206 .43773 L
s
.26222 .46843 m
.26265 .46899 L
s
1 .001 0 r
.01 w
.23616 .39526 Mdot
1 .002 0 r
[ .05 .05 ] 0 setdash
.23495 .39399 m
.23616 .39526 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26508 .41218 m
.26543 .41482 L
s
.3641 .40907 m
.36363 .41402 L
s
.26975 .41748 m
.27056 .4157 L
s
.29391 .43137 m
.29538 .42668 L
s
.25934 .42215 m
.25959 .42393 L
s
.27442 .41841 m
.27499 .4224 L
s
.2887 .45777 m
.28676 .45734 L
s
.36587 .42488 m
.36633 .42158 L
s
.3276 .45421 m
.32953 .45138 L
s
.26641 .44689 m
.26511 .44692 L
s
.40018 .47121 m
.39888 .46951 L
s
.23988 .40976 m
.24008 .41296 L
s
.29076 .45733 m
.2887 .45777 L
s
.29275 .45684 m
.29076 .45733 L
s
.29482 .45657 m
.29275 .45684 L
s
0 0 0 r
.004 w
.84658 .39447 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36919 .44441 m
.3715 .39438 L
s
1 .558 0 r
.01 w
[ .05 .05 ] 0 setdash
.3715 .39438 m
.3719 .39301 L
s
.3715 .39438 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29675 .45652 m
.29482 .45657 L
s
.36206 .43773 m
.36272 .43691 L
s
.2988 .45596 m
.29675 .45652 L
s
.30082 .45649 m
.2988 .45596 L
s
.30783 .42015 m
.30861 .41713 L
s
.31107 .4181 m
.31129 .42425 L
s
.26088 .43981 m
.26017 .43548 L
s
.2614 .41958 m
.26194 .41641 L
s
.26543 .41482 m
.26592 .41692 L
s
.26891 .41886 m
.26975 .41748 L
s
1 .002 0 r
.01 w
.23495 .39399 Mdot
[ .05 .05 ] 0 setdash
.23365 .39258 m
.23495 .39399 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36541 .4277 m
.36587 .42488 L
s
.37375 .41055 m
.373 .41171 L
s
.37435 .41109 m
.37375 .41055 L
s
.30273 .45728 m
.30082 .45649 L
s
.37482 .41336 m
.37435 .41109 L
s
.30159 .4252 m
.30234 .42652 L
s
.39888 .46951 m
.39745 .4681 L
s
.36272 .43691 m
.36339 .43581 L
s
0 0 0 r
.004 w
.20196 .39362 Mdot
.53 .8 .95 r
.006 w
.23789 .41407 m
.23873 .40874 L
s
.26511 .44692 m
.26395 .44643 L
s
.25959 .42393 m
.25996 .42432 L
s
.36854 .41865 m
.36841 .42269 L
s
.36496 .43037 m
.36541 .4277 L
s
.26167 .46767 m
.26222 .46843 L
s
.30483 .45739 m
.30273 .45728 L
s
.36339 .43581 m
.3639 .43446 L
s
.36605 .41601 m
.36549 .41187 L
s
.3069 .45853 m
.30483 .45739 L
s
.26592 .41692 m
.26656 .41834 L
s
.24008 .41296 m
.24045 .41634 L
s
.373 .41171 m
.37212 .41389 L
s
.26807 .41955 m
.26891 .41886 L
s
.27499 .4224 m
.27573 .42682 L
s
1 .557 0 r
.01 w
[ .05 .05 ] 0 setdash
.3719 .39301 m
.37224 .39152 L
s
.3719 .39301 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36363 .41402 m
.36294 .41955 L
s
.37522 .41694 m
.37482 .41336 L
s
.307 .42278 m
.30783 .42015 L
s
.36444 .43262 m
.36496 .43037 L
s
.26087 .42183 m
.2614 .41958 L
s
.3639 .43446 m
.36444 .43262 L
s
.2617 .44308 m
.26088 .43981 L
s
0 0 0 r
.004 w
.84751 .39272 Mdot
.53 .8 .95 r
.006 w
.39745 .4681 m
.39599 .46735 L
s
.30234 .42652 m
.30323 .42715 L
s
.26395 .44643 m
.26278 .44534 L
s
.26656 .41834 m
.26729 .41917 L
s
1 .002 0 r
.01 w
.23365 .39258 Mdot
[ .05 .05 ] 0 setdash
.23218 .39093 m
.23365 .39258 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25996 .42432 m
.2604 .42354 L
s
.30901 .45912 m
.3069 .45853 L
s
.26729 .41917 m
.26807 .41955 L
s
.29219 .43559 m
.29391 .43137 L
s
.2604 .42354 m
.26087 .42183 L
s
.32558 .45732 m
.3276 .45421 L
s
.31113 .45995 m
.30901 .45912 L
s
.3061 .42492 m
.307 .42278 L
s
.26278 .44534 m
.2617 .44308 L
s
.37212 .41389 m
.37114 .41636 L
s
.30323 .42715 m
.30416 .4272 L
s
.31129 .42425 m
.31164 .43098 L
s
.37561 .42139 m
.37522 .41694 L
s
.24045 .41634 m
.24099 .42005 L
s
1 .557 0 r
.01 w
[ .05 .05 ] 0 setdash
.37224 .39152 m
.37257 .39005 L
s
.37224 .39152 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26092 .46774 m
.26167 .46767 L
s
.31335 .46007 m
.31113 .45995 L
s
.30512 .42654 m
.3061 .42492 L
s
.31554 .46046 m
.31335 .46007 L
s
.30416 .4272 m
.30512 .42654 L
s
.39599 .46735 m
.39446 .46697 L
s
.3667 .41916 m
.36605 .41601 L
s
0 0 0 r
.004 w
.84843 .39095 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.2266 .45415 m
.23218 .39093 L
s
1 .002 0 r
.01 w
.23218 .39093 Mdot
[ .05 .05 ] 0 setdash
.23061 .38908 m
.23218 .39093 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27573 .42682 m
.27672 .43117 L
s
.31767 .46128 m
.31554 .46046 L
s
.36294 .41955 m
.36202 .42535 L
s
.37114 .41636 m
.37013 .41853 L
s
.36841 .42269 m
.36836 .4268 L
s
.31997 .46152 m
.31767 .46128 L
s
1 .557 0 r
.01 w
[ .05 .05 ] 0 setdash
.37257 .39005 m
.37284 .38853 L
s
.37257 .39005 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23683 .41994 m
.23789 .41407 L
s
.2903 .43957 m
.29219 .43559 L
s
.24099 .42005 m
.24171 .42433 L
s
.37611 .42618 m
.37561 .42139 L
s
0 0 0 r
.004 w
.19996 .38974 Mdot
.53 .8 .95 r
.006 w
.3235 .45929 m
.32558 .45732 L
s
.32213 .46166 m
.31997 .46152 L
s
.39446 .46697 m
.39292 .46619 L
s
.37013 .41853 m
.36914 .42002 L
s
.36742 .42072 m
.3667 .41916 L
s
.32448 .46201 m
.32213 .46166 L
s
.26012 .46764 m
.26092 .46774 L
s
0 0 0 r
.004 w
.84933 .38914 Mdot
1 .002 0 r
.01 w
.23061 .38908 Mdot
1 .003 0 r
[ .05 .05 ] 0 setdash
.2292 .38725 m
.23061 .38908 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31164 .43098 m
.31203 .43715 L
s
.27672 .43117 m
.27787 .43545 L
s
.36914 .42002 m
.36835 .42073 L
s
1 .557 0 r
.01 w
[ .05 .05 ] 0 setdash
.37284 .38853 m
.37295 .38708 L
s
.37284 .38853 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32661 .46244 m
.32448 .46201 L
s
.36835 .42073 m
.36742 .42072 L
s
.36202 .42535 m
.36095 .43137 L
s
.37675 .43178 m
.37611 .42618 L
s
.24171 .42433 m
.24259 .42815 L
s
.39292 .46619 m
.39139 .46557 L
s
.32896 .46179 m
.32661 .46244 L
s
.33116 .46042 m
.32896 .46179 L
s
.33338 .45935 m
.33116 .46042 L
s
.28839 .44255 m
.2903 .43957 L
s
.33757 .45617 m
.33535 .4582 L
s
.33936 .45509 m
.33757 .45617 L
s
.33535 .4582 m
.33338 .45935 L
s
0 0 0 r
.004 w
.85022 .38731 Mdot
.53 .8 .95 r
.006 w
.34148 .45358 m
.33936 .45509 L
s
1 .003 0 r
.01 w
.2292 .38725 Mdot
[ .05 .05 ] 0 setdash
.22749 .38502 m
.2292 .38725 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32151 .46037 m
.3235 .45929 L
s
.3434 .45289 m
.34148 .45358 L
s
.36836 .4268 m
.36833 .43096 L
s
1 .556 0 r
.01 w
[ .05 .05 ] 0 setdash
.37295 .38708 m
.37302 .38562 L
s
.37295 .38708 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2592 .46649 m
.26012 .46764 L
s
.27787 .43545 m
.27919 .43959 L
s
.31203 .43715 m
.31274 .44351 L
s
.34527 .45187 m
.3434 .45289 L
s
.24259 .42815 m
.24373 .43162 L
s
.39139 .46557 m
.38979 .46443 L
s
.34703 .45175 m
.34527 .45187 L
s
0 0 0 r
.004 w
.19819 .38607 Mdot
.53 .8 .95 r
.006 w
.37757 .43731 m
.37675 .43178 L
s
.23555 .42634 m
.23683 .41994 L
s
.36095 .43137 m
.35975 .43632 L
s
1 .556 0 r
.01 w
[ .05 .05 ] 0 setdash
.37302 .38562 m
.3729 .3841 L
s
.37302 .38562 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28629 .44482 m
.28839 .44255 L
s
0 0 0 r
.004 w
.85109 .38545 Mdot
.53 .8 .95 r
.006 w
.3195 .46095 m
.32151 .46037 L
s
.25809 .46629 m
.2592 .46649 L
s
.34863 .45146 m
.34703 .45175 L
s
.24373 .43162 m
.24493 .43474 L
s
1 .003 0 r
.01 w
.22749 .38502 Mdot
[ .05 .05 ] 0 setdash
.22607 .38299 m
.22749 .38502 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27919 .43959 m
.28069 .44265 L
s
.38979 .46443 m
.38819 .46341 L
s
.31274 .44351 m
.3136 .44982 L
s
.35059 .45067 m
.34863 .45146 L
s
.37855 .44275 m
.37757 .43731 L
s
.24493 .43474 m
.24625 .43785 L
s
.35975 .43632 m
.35835 .44079 L
s
1 .556 0 r
.01 w
[ .05 .05 ] 0 setdash
.3729 .3841 m
.37271 .38259 L
s
.3729 .3841 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28434 .44585 m
.28629 .44482 L
s
.28069 .44265 m
.28241 .4448 L
s
.36833 .43096 m
.36837 .4347 L
s
0 0 0 r
.004 w
.85194 .38357 Mdot
.53 .8 .95 r
.006 w
.38819 .46341 m
.38681 .46133 L
s
.35211 .45049 m
.35059 .45067 L
s
.31782 .4604 m
.3195 .46095 L
s
.24625 .43785 m
.24767 .44127 L
s
.28241 .4448 m
.28434 .44585 L
s
.25699 .46552 m
.25809 .46629 L
s
1 .003 0 r
.01 w
.22607 .38299 Mdot
[ .05 .05 ] 0 setdash
.22441 .38066 m
.22607 .38299 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38681 .46133 m
.38532 .45913 L
s
.3136 .44982 m
.31464 .45422 L
s
.35835 .44079 m
.35688 .44493 L
s
1 .556 0 r
.01 w
[ .05 .05 ] 0 setdash
.37271 .38259 m
.37258 .38121 L
s
.37271 .38259 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37977 .44708 m
.37855 .44275 L
s
0 0 0 r
.004 w
.19662 .38256 Mdot
.53 .8 .95 r
.006 w
.35379 .44895 m
.35211 .45049 L
s
.24767 .44127 m
.24905 .4445 L
s
.31604 .45769 m
.31782 .4604 L
s
.38532 .45913 m
.38377 .45716 L
s
.35545 .44722 m
.35379 .44895 L
s
.31464 .45422 m
.31604 .45769 L
s
.35688 .44493 m
.35545 .44722 L
s
.38108 .45087 m
.37977 .44708 L
s
.24905 .4445 m
.2504 .44851 L
s
0 0 0 r
.004 w
.85277 .38165 Mdot
.53 .8 .95 r
.006 w
.23408 .43232 m
.23555 .42634 L
s
.38246 .45431 m
.38108 .45087 L
s
.25578 .46276 m
.25699 .46552 L
s
1 .556 0 r
.01 w
[ .05 .05 ] 0 setdash
.37258 .38121 m
.37232 .37975 L
s
.37258 .38121 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38377 .45716 m
.38246 .45431 L
s
.2504 .44851 m
.25177 .45314 L
s
1 .003 0 r
.01 w
.22441 .38066 Mdot
[ .05 .05 ] 0 setdash
.22302 .37859 m
.22441 .38066 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2545 .46007 m
.25578 .46276 L
s
.36837 .4347 m
.3685 .4383 L
s
.25177 .45314 m
.25312 .45682 L
s
.25312 .45682 m
.2545 .46007 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.37007 .42855 m
.37232 .37975 L
s
1 .555 0 r
.01 w
[ .05 .05 ] 0 setdash
.37232 .37975 m
.37192 .37818 L
s
.37232 .37975 Mdot
0 0 0 r
.004 w
.85359 .37969 Mdot
.1952 .3792 Mdot
1 .003 0 r
.01 w
.22302 .37859 Mdot
1 .004 0 r
.22154 .37637 m
.22302 .37859 L
s
1 .555 0 r
.37192 .37818 m
.37145 .37657 L
s
.37192 .37818 Mdot
0 0 0 r
.004 w
.85439 .37771 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23242 .43826 m
.23408 .43232 L
s
1 .555 0 r
.01 w
[ .05 .05 ] 0 setdash
.37145 .37657 m
.37127 .3752 L
s
.37145 .37657 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3685 .4383 m
.36869 .44074 L
s
1 .004 0 r
.01 w
.22154 .37637 Mdot
[ .05 .05 ] 0 setdash
.22026 .3744 m
.22154 .37637 L
s
0 0 0 r
.004 w
.19393 .37596 Mdot
.85516 .37569 Mdot
1 .555 0 r
.01 w
.37127 .3752 m
.3709 .37367 L
s
.37127 .3752 Mdot
1 .004 0 r
.22026 .3744 Mdot
.21906 .37256 m
.22026 .3744 L
s
1 .555 0 r
.3709 .37367 m
.37047 .37206 L
s
.3709 .37367 Mdot
0 0 0 r
.004 w
.85592 .37363 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36869 .44074 m
.36893 .44285 L
s
0 0 0 r
.004 w
.19279 .37284 Mdot
1 .004 0 r
.01 w
.21906 .37256 Mdot
[ .05 .05 ] 0 setdash
.21802 .3709 m
.21906 .37256 L
s
1 .554 0 r
.37047 .37206 m
.37021 .37058 L
s
.37047 .37206 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23056 .44417 m
.23242 .43826 L
s
0 0 0 r
.004 w
.85665 .37154 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.2127 .42805 m
.21802 .3709 L
s
1 .004 0 r
.01 w
.21802 .3709 Mdot
[ .05 .05 ] 0 setdash
.21714 .36949 m
.21802 .3709 L
s
1 .554 0 r
.37021 .37058 m
.3699 .36903 L
s
.37021 .37058 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36893 .44285 m
.36919 .44441 L
s
0 0 0 r
.004 w
.19177 .36981 Mdot
1 .004 0 r
.01 w
.21714 .36949 Mdot
1 .005 0 r
[ .05 .05 ] 0 setdash
.21625 .36806 m
.21714 .36949 L
s
0 0 0 r
.004 w
.85736 .3694 Mdot
1 .554 0 r
.01 w
.3699 .36903 m
.36951 .36738 L
s
.3699 .36903 Mdot
1 .005 0 r
.21625 .36806 Mdot
.21558 .36688 m
.21625 .36806 L
s
1 .554 0 r
.36951 .36738 m
.36935 .36594 L
s
.36951 .36738 Mdot
0 0 0 r
.004 w
.85805 .36722 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36919 .44441 m
.36954 .44434 L
s
1 .005 0 r
.01 w
.21558 .36688 Mdot
[ .05 .05 ] 0 setdash
.21493 .36573 m
.21558 .36688 L
s
0 0 0 r
.004 w
.19084 .36687 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22862 .44982 m
.23056 .44417 L
s
1 .554 0 r
.01 w
[ .05 .05 ] 0 setdash
.36935 .36594 m
.36908 .3644 L
s
.36935 .36594 Mdot
1 .005 0 r
.21493 .36573 Mdot
.21439 .36468 m
.21493 .36573 L
s
0 0 0 r
.004 w
.85871 .365 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36954 .44434 m
.36986 .44337 L
s
1 .005 0 r
.01 w
.21439 .36468 Mdot
[ .05 .05 ] 0 setdash
.21395 .36366 m
.21439 .36468 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36679 .4127 m
.36908 .3644 L
s
1 .553 0 r
.01 w
[ .05 .05 ] 0 setdash
.36908 .3644 m
.36889 .36296 L
s
.36908 .3644 Mdot
0 0 0 r
.004 w
.19001 .36401 Mdot
1 .005 0 r
.01 w
.21395 .36366 Mdot
1 .006 0 r
.21359 .36263 m
.21395 .36366 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36986 .44337 m
.37019 .44178 L
s
1 .553 0 r
.01 w
[ .05 .05 ] 0 setdash
.36889 .36296 m
.36868 .36149 L
s
.36889 .36296 Mdot
0 0 0 r
.004 w
.85934 .36273 Mdot
1 .006 0 r
.01 w
.21359 .36263 Mdot
.2133 .36154 m
.21359 .36263 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37019 .44178 m
.37049 .43989 L
s
1 .006 0 r
.01 w
.2133 .36154 Mdot
[ .05 .05 ] 0 setdash
.21301 .36017 m
.2133 .36154 L
s
1 .553 0 r
.36868 .36149 m
.3686 .36017 L
s
.36868 .36149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2266 .45415 m
.22862 .44982 L
s
0 0 0 r
.004 w
.18926 .36123 Mdot
.85994 .36041 Mdot
.53 .8 .95 r
.006 w
.37049 .43989 m
.37066 .43689 L
s
1 .006 0 r
.01 w
.21301 .36017 Mdot
[ .05 .05 ] 0 setdash
.2128 .35866 m
.21301 .36017 L
s
1 .553 0 r
.3686 .36017 m
.36845 .35884 L
s
.3686 .36017 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37066 .43689 m
.37079 .43427 L
s
.37079 .43427 m
.37067 .43258 L
s
1 .553 0 r
.01 w
[ .05 .05 ] 0 setdash
.36845 .35884 m
.36834 .3576 L
s
.36845 .35884 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.20784 .41086 m
.2128 .35866 L
s
1 .006 0 r
.01 w
.2128 .35866 Mdot
[ .05 .05 ] 0 setdash
.21263 .35701 m
.2128 .35866 L
s
0 0 0 r
.004 w
.18859 .35851 Mdot
.86051 .35804 Mdot
1 .552 0 r
.01 w
.36834 .3576 m
.36819 .35638 L
s
.36834 .3576 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37067 .43258 m
.37049 .43109 L
s
1 .006 0 r
.01 w
.21263 .35701 Mdot
1 .007 0 r
[ .05 .05 ] 0 setdash
.21238 .35497 m
.21263 .35701 L
s
1 .552 0 r
.36819 .35638 m
.36803 .35517 L
s
.36819 .35638 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22455 .45724 m
.2266 .45415 L
s
.37049 .43109 m
.37036 .42962 L
s
0 0 0 r
.004 w
.188 .35585 Mdot
.86105 .35562 Mdot
1 .552 0 r
.01 w
[ .05 .05 ] 0 setdash
.36803 .35517 m
.36788 .35408 L
s
.36803 .35517 Mdot
1 .007 0 r
.21238 .35497 Mdot
.21216 .35274 m
.21238 .35497 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37036 .42962 m
.37007 .42855 L
s
1 .552 0 r
.01 w
[ .05 .05 ] 0 setdash
.36788 .35408 m
.3677 .35302 L
s
.36788 .35408 Mdot
0 0 0 r
.004 w
.18747 .35325 Mdot
.86155 .35313 Mdot
1 .551 0 r
.01 w
.3677 .35302 m
.3676 .35209 L
s
.3677 .35302 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37007 .42855 m
.36964 .42763 L
s
1 .007 0 r
.01 w
.21216 .35274 Mdot
[ .05 .05 ] 0 setdash
.21202 .35028 m
.21216 .35274 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.36613 .38258 m
.3676 .35209 L
s
1 .551 0 r
.01 w
[ .05 .05 ] 0 setdash
.3676 .35209 m
.36748 .35122 L
s
.3676 .35209 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22274 .45959 m
.22455 .45724 L
s
1 .551 0 r
.01 w
[ .05 .05 ] 0 setdash
.36748 .35122 m
.36742 .35047 L
s
.36748 .35122 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36964 .42763 m
.36909 .42725 L
s
0 0 0 r
.004 w
.187 .3507 Mdot
.86201 .35059 Mdot
1 .551 0 r
.01 w
[ .05 .05 ] 0 setdash
.36742 .35047 m
.3674 .34979 L
s
.36742 .35047 Mdot
1 .007 0 r
.21202 .35028 Mdot
.21174 .34787 m
.21202 .35028 L
s
1 .551 0 r
.3674 .34979 m
.36747 .34923 L
s
.3674 .34979 Mdot
1 .55 0 r
.36747 .34923 m
.36763 .34873 L
s
.36747 .34923 Mdot
.36763 .34873 m
.36788 .34831 L
s
.36763 .34873 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36909 .42725 m
.36889 .42625 L
s
1 .55 0 r
.01 w
[ .05 .05 ] 0 setdash
.36788 .34831 m
.36822 .34795 L
s
.36788 .34831 Mdot
0 0 0 r
.004 w
.1866 .34821 Mdot
.86243 .34797 Mdot
1 .55 0 r
.01 w
.36822 .34795 m
.36868 .34763 L
s
.36822 .34795 Mdot
1 .007 0 r
.21174 .34787 Mdot
1 .008 0 r
.21151 .34498 m
.21174 .34787 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21152 .39511 m
.21182 .39868 L
s
.2111 .39378 m
.21152 .39511 L
s
1 .55 0 r
.01 w
[ .05 .05 ] 0 setdash
.36868 .34763 m
.36925 .34735 L
s
.36868 .34763 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22068 .46067 m
.22274 .45959 L
s
1 .549 0 r
.01 w
[ .05 .05 ] 0 setdash
.36925 .34735 m
.36992 .34708 L
s
.36925 .34735 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21182 .39868 m
.21206 .40431 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.36912 .36387 m
.36992 .34708 L
s
1 .549 0 r
.01 w
[ .05 .05 ] 0 setdash
.36992 .34708 m
.37061 .34683 L
s
.36992 .34708 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36889 .42625 m
.36847 .42568 L
s
1 .549 0 r
.01 w
[ .05 .05 ] 0 setdash
.37061 .34683 m
.37139 .34658 L
s
.37061 .34683 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2105 .39534 m
.2111 .39378 L
s
1 .549 0 r
.01 w
[ .05 .05 ] 0 setdash
.37139 .34658 m
.37222 .34633 L
s
.37139 .34658 Mdot
.37222 .34633 m
.37302 .3461 L
s
.37222 .34633 Mdot
1 .548 0 r
.37302 .3461 m
.3738 .34585 L
s
.37302 .3461 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21206 .40431 m
.21221 .4111 L
s
1 .548 0 r
.01 w
[ .05 .05 ] 0 setdash
.3738 .34585 m
.37447 .34561 L
s
.3738 .34585 Mdot
0 0 0 r
.004 w
.18624 .34575 Mdot
1 .548 0 r
.01 w
.37447 .34561 m
.37507 .34534 L
s
.37447 .34561 Mdot
.37507 .34534 m
.37559 .34514 L
s
.37507 .34534 Mdot
0 0 0 r
.004 w
.86281 .34528 Mdot
1 .546 0 r
.01 w
.37625 .34517 m
.37627 .34515 L
s
.37625 .34517 Mdot
.37633 .34513 m
.37625 .34517 L
s
1 .545 0 r
.37627 .34515 m
.37643 .34504 L
s
.37627 .34515 Mdot
1 .547 0 r
.37559 .34514 m
.37602 .34499 L
s
.37559 .34514 Mdot
1 .546 0 r
.37633 .34513 Mdot
.37646 .34506 m
.37633 .34513 L
s
.37646 .34506 Mdot
.37658 .34497 m
.37646 .34506 L
s
1 .545 0 r
.37643 .34504 m
.37675 .34484 L
s
.37643 .34504 Mdot
1 .547 0 r
.37602 .34499 m
.37634 .34489 L
s
.37602 .34499 Mdot
1 .008 0 r
.21151 .34498 Mdot
.21117 .34225 m
.21151 .34498 L
s
1 .546 0 r
.37658 .34497 Mdot
.37666 .34489 m
.37658 .34497 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37612 .34961 m
.37634 .34489 L
s
1 .547 0 r
.01 w
[ .05 .05 ] 0 setdash
.37634 .34489 m
.37655 .34484 L
s
.37634 .34489 Mdot
1 .546 0 r
.37666 .34489 Mdot
1 .547 0 r
.37665 .34484 m
.37666 .34489 L
s
.37665 .34484 Mdot
.37655 .34484 m
.37665 .34484 L
s
.37655 .34484 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37631 .35468 m
.37675 .34484 L
s
1 .545 0 r
.01 w
[ .05 .05 ] 0 setdash
.37675 .34484 m
.37724 .34453 L
s
.37675 .34484 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36847 .42568 m
.36798 .42525 L
s
.37623 .3461 m
.37621 .34991 L
s
.37618 .34684 m
.37623 .3461 L
s
1 .545 0 r
.01 w
[ .05 .05 ] 0 setdash
.37724 .34453 m
.37788 .34413 L
s
.37724 .34453 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37662 .34559 m
.37658 .3465 L
s
.37645 .34718 m
.37662 .34559 L
s
.20973 .39917 m
.2105 .39534 L
s
.3762 .34814 m
.37618 .34684 L
s
1 .545 0 r
.01 w
[ .05 .05 ] 0 setdash
.37788 .34413 m
.37866 .34364 L
s
.37788 .34413 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21221 .4111 m
.2125 .41916 L
s
.37658 .3465 m
.37646 .34771 L
s
1 .544 0 r
.01 w
[ .05 .05 ] 0 setdash
.37866 .34364 m
.37958 .34306 L
s
.37866 .34364 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37612 .34961 m
.37645 .34718 L
s
.37631 .34835 m
.3762 .34814 L
s
.21898 .4615 m
.22068 .46067 L
s
.37646 .34771 m
.37631 .34835 L
s
0 0 0 r
.004 w
.18595 .34335 Mdot
1 .544 0 r
.01 w
[ .05 .05 ] 0 setdash
.37958 .34306 m
.3806 .34243 L
s
.37958 .34306 Mdot
0 0 0 r
.004 w
.86314 .34252 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36798 .42525 m
.36773 .42362 L
s
1 .544 0 r
.01 w
[ .05 .05 ] 0 setdash
.3806 .34243 m
.38174 .34174 L
s
.3806 .34243 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37621 .34991 m
.37631 .35468 L
s
1 .008 0 r
.01 w
.21117 .34225 Mdot
[ .05 .05 ] 0 setdash
.21101 .33942 m
.21117 .34225 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37568 .35248 m
.37612 .34961 L
s
.2125 .41916 m
.2127 .42805 L
s
1 .544 0 r
.01 w
[ .05 .05 ] 0 setdash
.38174 .34174 m
.38297 .341 L
s
.38174 .34174 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36729 .36049 m
.36764 .3601 L
s
.36696 .36255 m
.36729 .36049 L
s
.36773 .42362 m
.36742 .42183 L
s
.36764 .3601 m
.36805 .36077 L
s
1 .543 0 r
.01 w
[ .05 .05 ] 0 setdash
.38297 .341 m
.38426 .34022 L
s
.38297 .341 Mdot
0 0 0 r
.004 w
.1857 .34098 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36668 .36581 m
.36696 .36255 L
s
.37512 .35561 m
.37568 .35248 L
s
.20886 .40396 m
.20973 .39917 L
s
1 .543 0 r
.01 w
[ .05 .05 ] 0 setdash
.38426 .34022 m
.3856 .3394 L
s
.38426 .34022 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36805 .36077 m
.36854 .36219 L
s
.36644 .36977 m
.36668 .36581 L
s
.21725 .45937 m
.21898 .4615 L
s
0 0 0 r
.004 w
.86342 .33967 Mdot
.53 .8 .95 r
.006 w
.36742 .42183 m
.36706 .41945 L
s
1 .008 0 r
.01 w
.21101 .33942 Mdot
[ .05 .05 ] 0 setdash
.21072 .33664 m
.21101 .33942 L
s
1 .543 0 r
.3856 .3394 m
.38692 .33857 L
s
.3856 .3394 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37631 .35468 m
.37654 .35984 L
s
.37447 .35858 m
.37512 .35561 L
s
.2127 .42805 m
.21314 .43631 L
s
.36854 .36219 m
.36912 .36387 L
s
0 0 0 r
.004 w
.18549 .33865 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.38534 .376 m
.38692 .33857 L
s
1 .543 0 r
.01 w
[ .05 .05 ] 0 setdash
.38692 .33857 m
.38822 .33771 L
s
.38692 .33857 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3663 .37375 m
.36644 .36977 L
s
.36706 .41945 m
.36696 .41645 L
s
.37375 .36125 m
.37447 .35858 L
s
1 .543 0 r
.01 w
[ .05 .05 ] 0 setdash
.38822 .33771 m
.38948 .33684 L
s
.38822 .33771 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36696 .41645 m
.36679 .4127 L
s
.36912 .36387 m
.36974 .36544 L
s
.36679 .4127 m
.3667 .40929 L
s
.36618 .37814 m
.3663 .37375 L
s
.21585 .45699 m
.21725 .45937 L
s
.21314 .43631 m
.2138 .44425 L
s
.3667 .40929 m
.36656 .40622 L
s
1 .542 0 r
.01 w
[ .05 .05 ] 0 setdash
.38948 .33684 m
.39071 .33595 L
s
.38948 .33684 Mdot
0 0 0 r
.004 w
.86364 .33672 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37298 .36365 m
.37375 .36125 L
s
1 .008 0 r
.01 w
.21072 .33664 Mdot
[ .05 .05 ] 0 setdash
.21027 .33394 m
.21072 .33664 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36656 .40622 m
.36656 .40307 L
s
0 0 0 r
.004 w
.18534 .33636 Mdot
.53 .8 .95 r
.006 w
.36974 .36544 m
.37048 .36604 L
s
.36656 .40307 m
.36648 .40016 L
s
.36613 .38258 m
.36618 .37814 L
s
1 .542 0 r
.01 w
[ .05 .05 ] 0 setdash
.39071 .33595 m
.3919 .33505 L
s
.39071 .33595 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37654 .35984 m
.37694 .36495 L
s
.37213 .36526 m
.37298 .36365 L
s
.2138 .44425 m
.21466 .45116 L
s
.36648 .40016 m
.36641 .39802 L
s
.20784 .41086 m
.20886 .40396 L
s
.37048 .36604 m
.37131 .36589 L
s
.21466 .45116 m
.21585 .45699 L
s
.37131 .36589 m
.37213 .36526 L
s
1 .542 0 r
.01 w
[ .05 .05 ] 0 setdash
.3919 .33505 m
.3931 .33412 L
s
.3919 .33505 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36641 .39802 m
.36632 .39551 L
s
.36609 .38662 m
.36613 .38258 L
s
.36632 .39551 m
.36623 .3927 L
s
1 .542 0 r
.01 w
[ .05 .05 ] 0 setdash
.3931 .33412 m
.39431 .33316 L
s
.3931 .33412 Mdot
0 0 0 r
.004 w
.18522 .3341 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36617 .38989 m
.36609 .38662 L
s
.36623 .3927 m
.36617 .38989 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.20167 .4229 m
.21027 .33394 L
s
1 .008 0 r
.01 w
.21027 .33394 Mdot
1 .009 0 r
[ .05 .05 ] 0 setdash
.21008 .33129 m
.21027 .33394 L
s
0 0 0 r
.004 w
.86379 .33368 Mdot
1 .542 0 r
.01 w
.39431 .33316 m
.39555 .3322 L
s
.39431 .33316 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37694 .36495 m
.37749 .3698 L
s
1 .541 0 r
.01 w
[ .05 .05 ] 0 setdash
.39555 .3322 m
.3968 .33122 L
s
.39555 .3322 Mdot
0 0 0 r
.004 w
.18515 .33188 Mdot
1 .009 0 r
.01 w
.21008 .33129 Mdot
.20984 .32856 m
.21008 .33129 L
s
1 .541 0 r
.3968 .33122 m
.39807 .33023 L
s
.3968 .33122 Mdot
0 0 0 r
.004 w
.86388 .33052 Mdot
1 .541 0 r
.01 w
.39807 .33023 m
.39929 .32928 L
s
.39807 .33023 Mdot
0 0 0 r
.004 w
.18511 .32969 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20679 .41842 m
.20784 .41086 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.39772 .37004 m
.39929 .32928 L
s
1 .541 0 r
.01 w
[ .05 .05 ] 0 setdash
.39929 .32928 m
.40046 .3284 L
s
.39929 .32928 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37749 .3698 m
.37822 .37362 L
s
1 .009 0 r
.01 w
.20984 .32856 Mdot
[ .05 .05 ] 0 setdash
.2098 .32616 m
.20984 .32856 L
s
1 .541 0 r
.40046 .3284 m
.40154 .3276 L
s
.40046 .3284 Mdot
1 .54 0 r
.40154 .3276 m
.4025 .3269 L
s
.40154 .3276 Mdot
0 0 0 r
.004 w
.18511 .32752 Mdot
1 .534 0 r
.01 w
.41506 .32749 m
.41556 .32744 L
s
.41506 .32749 Mdot
.41445 .32746 m
.41506 .32749 L
s
.41445 .32746 Mdot
.41371 .3274 m
.41445 .32746 L
s
.41556 .32744 m
.41598 .3273 L
s
.41556 .32744 Mdot
.41371 .3274 Mdot
.41284 .3273 m
.41371 .3274 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.41216 .34703 m
.41284 .3273 L
s
1 .534 0 r
.01 w
.41284 .3273 Mdot
1 .535 0 r
[ .05 .05 ] 0 setdash
.41184 .32719 m
.41284 .3273 L
s
1 .533 0 r
.41598 .3273 m
.41636 .32703 L
s
.41598 .3273 Mdot
0 0 0 r
.004 w
.86388 .32723 Mdot
1 .535 0 r
.01 w
.41184 .32719 Mdot
.41077 .3271 m
.41184 .32719 L
s
1 .536 0 r
.40453 .32715 m
.40497 .32713 L
s
.40453 .32715 Mdot
1 .537 0 r
.40426 .32713 m
.40453 .32715 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.40419 .32903 m
.40426 .32713 L
s
1 .537 0 r
.01 w
.40426 .32713 Mdot
[ .05 .05 ] 0 setdash
.40416 .32707 m
.40426 .32713 L
s
1 .536 0 r
.40497 .32713 m
.4056 .32708 L
s
.40497 .32713 Mdot
1 .535 0 r
.41077 .3271 Mdot
.40962 .32703 m
.41077 .3271 L
s
1 .536 0 r
.4056 .32708 m
.40642 .32704 L
s
.4056 .32708 Mdot
1 .537 0 r
.40416 .32707 Mdot
.40418 .32698 m
.40416 .32707 L
s
1 .536 0 r
.40642 .32704 m
.40739 .32701 L
s
.40642 .32704 Mdot
1 .535 0 r
.40962 .32703 Mdot
.40847 .327 m
.40962 .32703 L
s
1 .533 0 r
.41636 .32703 m
.41671 .3266 L
s
.41636 .32703 Mdot
1 .536 0 r
.40739 .32701 m
.40847 .327 L
s
.40739 .32701 Mdot
1 .535 0 r
.40847 .327 Mdot
1 .537 0 r
.40418 .32698 Mdot
.40429 .32685 m
.40418 .32698 L
s
1 .54 0 r
.4025 .3269 m
.40331 .32631 L
s
.4025 .3269 Mdot
1 .537 0 r
.40429 .32685 Mdot
.40444 .32671 m
.40429 .32685 L
s
.40444 .32671 Mdot
1 .538 0 r
.40463 .32655 m
.40444 .32671 L
s
1 .533 0 r
.41671 .3266 m
.41708 .32599 L
s
.41671 .3266 Mdot
1 .538 0 r
.40463 .32655 Mdot
.40484 .32638 m
.40463 .32655 L
s
.40484 .32638 Mdot
.40506 .3262 m
.40484 .32638 L
s
1 .54 0 r
.40331 .32631 m
.40399 .32587 L
s
.40331 .32631 Mdot
1 .538 0 r
.40506 .3262 Mdot
.40527 .32601 m
.40506 .3262 L
s
1 .009 0 r
.2098 .32616 Mdot
.20959 .32351 m
.2098 .32616 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40419 .32903 m
.40432 .33266 L
s
.40408 .32913 m
.40419 .32903 L
s
1 .538 0 r
.01 w
.40527 .32601 Mdot
[ .05 .05 ] 0 setdash
.40542 .32581 m
.40527 .32601 L
s
1 .533 0 r
.41708 .32599 m
.41749 .32519 L
s
.41708 .32599 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40404 .33081 m
.40408 .32913 L
s
1 .54 0 r
.01 w
[ .05 .05 ] 0 setdash
.40399 .32587 m
.40454 .32556 L
s
.40399 .32587 Mdot
1 .538 0 r
.40542 .32581 Mdot
1 .539 0 r
.40549 .32563 m
.40542 .32581 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37822 .37362 m
.37908 .37677 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.40526 .33176 m
.40549 .32563 L
s
1 .539 0 r
.01 w
.40549 .32563 Mdot
[ .05 .05 ] 0 setdash
.40544 .32547 m
.40549 .32563 L
s
1 .54 0 r
.40454 .32556 m
.40497 .3254 L
s
.40454 .32556 Mdot
1 .539 0 r
.40544 .32547 Mdot
.40527 .32538 m
.40544 .32547 L
s
.40497 .3254 m
.40527 .32538 L
s
.40497 .3254 Mdot
0 0 0 r
.004 w
.18515 .32539 Mdot
1 .539 0 r
.01 w
.40527 .32538 Mdot
1 .533 0 r
.41749 .32519 m
.41796 .32424 L
s
.41749 .32519 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40409 .33219 m
.40404 .33081 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.41676 .36079 m
.41796 .32424 L
s
1 .532 0 r
.01 w
[ .05 .05 ] 0 setdash
.41796 .32424 m
.41852 .32315 L
s
.41796 .32424 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41536 .33325 m
.41576 .33384 L
s
.41478 .33577 m
.41536 .33325 L
s
.40432 .33266 m
.40462 .3369 L
s
0 0 0 r
.004 w
.8638 .32381 Mdot
.53 .8 .95 r
.006 w
.40422 .33282 m
.40409 .33219 L
s
.40516 .32851 m
.40528 .32979 L
s
.40476 .3312 m
.40516 .32851 L
s
.41576 .33384 m
.416 .33779 L
s
1 .009 0 r
.01 w
.20959 .32351 Mdot
[ .05 .05 ] 0 setdash
.20936 .32086 m
.20959 .32351 L
s
0 0 0 r
.004 w
.18522 .32329 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40439 .33317 m
.40422 .33282 L
s
1 .532 0 r
.01 w
[ .05 .05 ] 0 setdash
.41852 .32315 m
.41918 .322 L
s
.41852 .32315 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40528 .32979 m
.40526 .33176 L
s
.37908 .37677 m
.38011 .37895 L
s
.40459 .33299 m
.40439 .33317 L
s
.41405 .33943 m
.41478 .33577 L
s
.40481 .33316 m
.40459 .33299 L
s
.20566 .42541 m
.20679 .41842 L
s
.405 .33326 m
.40481 .33316 L
s
.40526 .33176 m
.40516 .33293 L
s
.40416 .33606 m
.40476 .3312 L
s
1 .532 0 r
.01 w
[ .05 .05 ] 0 setdash
.41918 .322 m
.4199 .32081 L
s
.41918 .322 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40516 .33293 m
.405 .33326 L
s
.40462 .3369 m
.40508 .34139 L
s
0 0 0 r
.004 w
.18532 .32121 Mdot
1 .009 0 r
.01 w
.20936 .32086 Mdot
1 .01 0 r
[ .05 .05 ] 0 setdash
.20932 .31848 m
.20936 .32086 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.416 .33779 m
.41615 .34353 L
s
1 .532 0 r
.01 w
[ .05 .05 ] 0 setdash
.4199 .32081 m
.4206 .31958 L
s
.4199 .32081 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41317 .34337 m
.41405 .33943 L
s
.38011 .37895 m
.38128 .37985 L
s
0 0 0 r
.004 w
.86361 .32023 Mdot
1 .532 0 r
.01 w
[ .05 .05 ] 0 setdash
.4206 .31958 m
.42124 .31836 L
s
.4206 .31958 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4034 .34175 m
.40416 .33606 L
s
0 0 0 r
.004 w
.18546 .31915 Mdot
.53 .8 .95 r
.006 w
.38128 .37985 m
.38259 .37917 L
s
.40508 .34139 m
.40575 .34549 L
s
1 .01 0 r
.01 w
.20932 .31848 Mdot
[ .05 .05 ] 0 setdash
.20909 .31584 m
.20932 .31848 L
s
1 .531 0 r
.42124 .31836 m
.42177 .31717 L
s
.42124 .31836 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41216 .34703 m
.41317 .34337 L
s
.38259 .37917 m
.38395 .37821 L
s
.38395 .37821 m
.38534 .376 L
s
1 .531 0 r
.01 w
[ .05 .05 ] 0 setdash
.42177 .31717 m
.42221 .31604 L
s
.42177 .31717 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38672 .37362 m
.38803 .37197 L
s
.38534 .376 m
.38672 .37362 L
s
0 0 0 r
.004 w
.18562 .31712 Mdot
.53 .8 .95 r
.006 w
.41615 .34353 m
.41629 .34965 L
s
.38803 .37197 m
.38928 .37092 L
s
.40251 .34786 m
.4034 .34175 L
s
0 0 0 r
.004 w
.86331 .31646 Mdot
.53 .8 .95 r
.006 w
.40575 .34549 m
.40659 .34911 L
s
1 .531 0 r
.01 w
[ .05 .05 ] 0 setdash
.42221 .31604 m
.42248 .31494 L
s
.42221 .31604 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41105 .35011 m
.41216 .34703 L
s
.38928 .37092 m
.39042 .37157 L
s
1 .01 0 r
.01 w
.20909 .31584 Mdot
[ .05 .05 ] 0 setdash
.20891 .31334 m
.20909 .31584 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20468 .43111 m
.20566 .42541 L
s
0 0 0 r
.004 w
.18582 .31512 Mdot
1 .531 0 r
.01 w
[ .05 .05 ] 0 setdash
.42248 .31494 m
.42265 .31396 L
s
.42248 .31494 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40659 .34911 m
.40759 .35163 L
s
.39042 .37157 m
.39156 .37239 L
s
.4099 .3518 m
.41105 .35011 L
s
1 .53 0 r
.01 w
[ .05 .05 ] 0 setdash
.42265 .31396 m
.42274 .31303 L
s
.42265 .31396 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40147 .35413 m
.40251 .34786 L
s
1 .01 0 r
.01 w
.20891 .31334 Mdot
[ .05 .05 ] 0 setdash
.20883 .31088 m
.20891 .31334 L
s
0 0 0 r
.004 w
.18604 .31314 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42187 .34042 m
.42274 .31303 L
s
1 .53 0 r
.01 w
[ .05 .05 ] 0 setdash
.42274 .31303 m
.42279 .31206 L
s
.42274 .31303 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40871 .35264 m
.4099 .3518 L
s
.40759 .35163 m
.40871 .35264 L
s
0 0 0 r
.004 w
.86287 .31248 Mdot
.53 .8 .95 r
.006 w
.41629 .34965 m
.41649 .35552 L
s
.39156 .37239 m
.39268 .37375 L
s
1 .53 0 r
.01 w
[ .05 .05 ] 0 setdash
.42279 .31206 m
.42287 .311 L
s
.42279 .31206 Mdot
0 0 0 r
.004 w
.1863 .31118 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40032 .35973 m
.40147 .35413 L
s
1 .53 0 r
.01 w
[ .05 .05 ] 0 setdash
.42287 .311 m
.42307 .3098 L
s
.42287 .311 Mdot
1 .01 0 r
.20883 .31088 Mdot
.20861 .3084 m
.20883 .31088 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39268 .37375 m
.39385 .37509 L
s
1 .53 0 r
.01 w
[ .05 .05 ] 0 setdash
.42307 .3098 m
.4234 .3084 L
s
.42307 .3098 Mdot
0 0 0 r
.004 w
.18658 .30924 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39904 .36555 m
.40032 .35973 L
s
.20389 .43535 m
.20468 .43111 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.20062 .39004 m
.20861 .3084 L
s
1 .01 0 r
.01 w
.20861 .3084 Mdot
1 .011 0 r
[ .05 .05 ] 0 setdash
.20841 .30596 m
.20861 .3084 L
s
1 .529 0 r
.4234 .3084 m
.42382 .30674 L
s
.4234 .3084 Mdot
0 0 0 r
.004 w
.86226 .30825 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41649 .35552 m
.41676 .36079 L
s
.39385 .37509 m
.39509 .37495 L
s
0 0 0 r
.004 w
.18688 .30732 Mdot
.53 .8 .95 r
.006 w
.39772 .37004 m
.39904 .36555 L
s
1 .529 0 r
.01 w
[ .05 .05 ] 0 setdash
.42382 .30674 m
.42423 .30476 L
s
.42382 .30674 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39509 .37495 m
.3964 .37302 L
s
1 .011 0 r
.01 w
.20841 .30596 Mdot
[ .05 .05 ] 0 setdash
.20805 .30328 m
.20841 .30596 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3964 .37302 m
.39772 .37004 L
s
0 0 0 r
.004 w
.18721 .30542 Mdot
1 .529 0 r
.01 w
[ .05 .05 ] 0 setdash
.42423 .30476 m
.42468 .3025 L
s
.42423 .30476 Mdot
0 0 0 r
.004 w
.86146 .30371 Mdot
.18757 .30354 Mdot
1 .011 0 r
.01 w
.20805 .30328 Mdot
.20787 .30081 m
.20805 .30328 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41676 .36079 m
.41716 .3645 L
s
1 .529 0 r
.01 w
[ .05 .05 ] 0 setdash
.42468 .3025 m
.42503 .2999 L
s
.42468 .3025 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20311 .43798 m
.20389 .43535 L
s
0 0 0 r
.004 w
.18795 .30168 Mdot
1 .011 0 r
.01 w
.20787 .30081 Mdot
[ .05 .05 ] 0 setdash
.20749 .2981 m
.20787 .30081 L
s
1 .529 0 r
.42503 .2999 m
.42568 .29759 L
s
.42503 .2999 Mdot
0 0 0 r
.004 w
.18836 .29984 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41716 .3645 m
.41772 .36697 L
s
0 0 0 r
.004 w
.86039 .29878 Mdot
1 .011 0 r
.01 w
.20749 .2981 Mdot
1 .012 0 r
[ .05 .05 ] 0 setdash
.2072 .29544 m
.20749 .2981 L
s
0 0 0 r
.004 w
.18878 .29801 Mdot
1 .528 0 r
.01 w
.42568 .29759 m
.42612 .295 L
s
.42568 .29759 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42174 .34295 m
.42187 .34042 L
s
.42148 .34671 m
.42174 .34295 L
s
.42187 .34042 m
.4219 .3402 L
s
.20269 .43687 m
.20311 .43798 L
s
.4211 .35097 m
.42148 .34671 L
s
0 0 0 r
.004 w
.18923 .2962 Mdot
.53 .8 .95 r
.006 w
.41772 .36697 m
.41843 .36644 L
s
.42053 .35609 m
.4211 .35097 L
s
.4219 .3402 m
.42188 .34272 L
s
1 .012 0 r
.01 w
.2072 .29544 Mdot
[ .05 .05 ] 0 setdash
.20692 .29275 m
.2072 .29544 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42359 .37763 m
.42612 .295 L
s
1 .528 0 r
.01 w
[ .05 .05 ] 0 setdash
.42612 .295 m
.42678 .29268 L
s
.42612 .295 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41989 .36072 m
.42053 .35609 L
s
0 0 0 r
.004 w
.1897 .29441 Mdot
.53 .8 .95 r
.006 w
.41843 .36644 m
.41916 .36425 L
s
.41916 .36425 m
.41989 .36072 L
s
0 0 0 r
.004 w
.859 .29334 Mdot
1 .012 0 r
.01 w
.20692 .29275 Mdot
[ .05 .05 ] 0 setdash
.20681 .29011 m
.20692 .29275 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20222 .43537 m
.20269 .43687 L
s
1 .528 0 r
.01 w
[ .05 .05 ] 0 setdash
.42678 .29268 m
.42733 .29053 L
s
.42678 .29268 Mdot
0 0 0 r
.004 w
.1902 .29264 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42188 .34272 m
.42188 .34781 L
s
0 0 0 r
.004 w
.19071 .29088 Mdot
1 .528 0 r
.01 w
[ .05 .05 ] 0 setdash
.42733 .29053 m
.4279 .28861 L
s
.42733 .29053 Mdot
1 .012 0 r
.20681 .29011 Mdot
.20662 .28732 m
.20681 .29011 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.202 .43306 m
.20222 .43537 L
s
0 0 0 r
.004 w
.19124 .28914 Mdot
1 .528 0 r
.01 w
[ .05 .05 ] 0 setdash
.4279 .28861 m
.42832 .28683 L
s
.4279 .28861 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42188 .34781 m
.42197 .3541 L
s
0 0 0 r
.004 w
.1918 .28741 Mdot
1 .012 0 r
.01 w
.20662 .28732 Mdot
[ .05 .05 ] 0 setdash
.20662 .28457 m
.20662 .28732 L
s
0 0 0 r
.004 w
.85712 .28718 Mdot
1 .527 0 r
.01 w
.42832 .28683 m
.42853 .28521 L
s
.42832 .28683 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20191 .42806 m
.202 .43306 L
s
0 0 0 r
.004 w
.19237 .2857 Mdot
1 .527 0 r
.01 w
[ .05 .05 ] 0 setdash
.42853 .28521 m
.42864 .28393 L
s
.42853 .28521 Mdot
1 .012 0 r
.20662 .28457 Mdot
1 .013 0 r
.20684 .28203 m
.20662 .28457 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20167 .4229 m
.20191 .42806 L
s
0 0 0 r
.004 w
.19296 .284 Mdot
1 .527 0 r
.01 w
[ .05 .05 ] 0 setdash
.42864 .28393 m
.42875 .28309 L
s
.42864 .28393 Mdot
1 .525 0 r
.429 .28331 m
.42922 .28329 L
s
.429 .28331 Mdot
.42886 .28329 m
.429 .28331 L
s
1 .524 0 r
.42922 .28329 m
.42954 .28319 L
s
.42922 .28329 Mdot
1 .525 0 r
.42886 .28329 Mdot
.42877 .28325 m
.42886 .28329 L
s
.42877 .28325 Mdot
.42872 .28322 m
.42877 .28325 L
s
.42872 .28322 Mdot
.42871 .28316 m
.42872 .28322 L
s
1 .524 0 r
.42954 .28319 m
.43003 .28296 L
s
.42954 .28319 Mdot
1 .525 0 r
.42871 .28316 Mdot
1 .526 0 r
.4287 .28295 m
.42871 .28316 L
s
1 .527 0 r
.42875 .28309 m
.42883 .28264 L
s
.42875 .28309 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42961 .29702 m
.43003 .28296 L
s
1 .524 0 r
.01 w
[ .05 .05 ] 0 setdash
.43003 .28296 m
.43076 .28256 L
s
.43003 .28296 Mdot
1 .526 0 r
.4287 .28295 Mdot
.42872 .28268 m
.4287 .28295 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42871 .28368 m
.42874 .28419 L
s
.42867 .28457 m
.42871 .28368 L
s
.20173 .4176 m
.20167 .4229 L
s
.42874 .28419 m
.4288 .2852 L
s
1 .526 0 r
.01 w
.42872 .28268 Mdot
[ .05 .05 ] 0 setdash
.42878 .2825 m
.42872 .28268 L
s
1 .527 0 r
.42883 .28264 m
.42884 .28247 L
s
.42883 .28264 Mdot
1 .524 0 r
.43076 .28256 m
.43178 .28195 L
s
.43076 .28256 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.42868 .286 m
.42878 .2825 L
s
1 .526 0 r
.01 w
.42878 .2825 Mdot
[ .05 .05 ] 0 setdash
.42884 .28247 m
.42878 .2825 L
s
.42884 .28247 Mdot
0 0 0 r
.004 w
.19357 .28232 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4286 .28615 m
.42867 .28457 L
s
.4288 .2852 m
.4289 .28681 L
s
.42882 .28308 m
.42868 .286 L
s
.42869 .28714 m
.42882 .28308 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.19821 .36896 m
.20684 .28203 L
s
1 .013 0 r
.01 w
.20684 .28203 Mdot
[ .05 .05 ] 0 setdash
.20713 .27924 m
.20684 .28203 L
s
1 .524 0 r
.43178 .28195 m
.43308 .28113 L
s
.43178 .28195 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20167 .41287 m
.20173 .4176 L
s
.42197 .3541 m
.4221 .36203 L
s
.4289 .28681 m
.42905 .28915 L
s
1 .523 0 r
.01 w
[ .05 .05 ] 0 setdash
.43308 .28113 m
.4347 .28012 L
s
.43308 .28113 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42859 .28701 m
.4286 .28615 L
s
0 0 0 r
.004 w
.1942 .28065 Mdot
.53 .8 .95 r
.006 w
.42868 .286 m
.42859 .28701 L
s
1 .523 0 r
.01 w
[ .05 .05 ] 0 setdash
.4347 .28012 m
.43662 .27891 L
s
.4347 .28012 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42839 .29502 m
.42869 .28714 L
s
.2018 .4087 m
.20167 .41287 L
s
0 0 0 r
.004 w
.85451 .27991 Mdot
.53 .8 .95 r
.006 w
.42905 .28915 m
.42927 .2924 L
s
1 .013 0 r
.01 w
.20713 .27924 Mdot
[ .05 .05 ] 0 setdash
.20765 .27661 m
.20713 .27924 L
s
0 0 0 r
.004 w
.19485 .27899 Mdot
1 .523 0 r
.01 w
.43662 .27891 m
.43881 .27755 L
s
.43662 .27891 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2018 .40373 m
.2018 .4087 L
s
.42927 .2924 m
.42961 .29702 L
s
1 .523 0 r
.01 w
[ .05 .05 ] 0 setdash
.43881 .27755 m
.44105 .27618 L
s
.43881 .27755 Mdot
0 0 0 r
.004 w
.19552 .27735 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20158 .40088 m
.2018 .40373 L
s
1 .013 0 r
.01 w
.20765 .27661 Mdot
[ .05 .05 ] 0 setdash
.20835 .27409 m
.20765 .27661 L
s
1 .523 0 r
.44105 .27618 m
.44341 .27475 L
s
.44105 .27618 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42797 .30649 m
.42839 .29502 L
s
0 0 0 r
.004 w
.1962 .27572 Mdot
1 .522 0 r
.01 w
[ .05 .05 ] 0 setdash
.44341 .27475 m
.4457 .27342 L
s
.44341 .27475 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42961 .29702 m
.43015 .3033 L
s
.20146 .39914 m
.20158 .40088 L
s
.4221 .36203 m
.42219 .3704 L
s
0 0 0 r
.004 w
.1969 .27411 Mdot
1 .013 0 r
.01 w
.20835 .27409 Mdot
[ .05 .05 ] 0 setdash
.20923 .27139 m
.20835 .27409 L
s
1 .522 0 r
.4457 .27342 m
.44805 .27206 L
s
.4457 .27342 Mdot
0 0 0 r
.004 w
.19762 .2725 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.44642 .33995 m
.44805 .27206 L
s
1 .522 0 r
.01 w
[ .05 .05 ] 0 setdash
.44805 .27206 m
.4507 .27058 L
s
.44805 .27206 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20126 .39619 m
.20146 .39914 L
s
1 .013 0 r
.01 w
.20923 .27139 Mdot
1 .014 0 r
[ .05 .05 ] 0 setdash
.21029 .26881 m
.20923 .27139 L
s
0 0 0 r
.004 w
.19835 .27091 Mdot
1 .522 0 r
.01 w
.4507 .27058 m
.4532 .26915 L
s
.4507 .27058 Mdot
0 0 0 r
.004 w
.85046 .27051 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42746 .32071 m
.42797 .30649 L
s
.43015 .3033 m
.43091 .31179 L
s
0 0 0 r
.004 w
.1991 .26933 Mdot
1 .521 0 r
.01 w
[ .05 .05 ] 0 setdash
.4532 .26915 m
.45587 .26767 L
s
.4532 .26915 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20102 .39409 m
.20126 .39619 L
s
1 .014 0 r
.01 w
.21029 .26881 Mdot
[ .05 .05 ] 0 setdash
.21148 .26626 m
.21029 .26881 L
s
0 0 0 r
.004 w
.19987 .26777 Mdot
1 .521 0 r
.01 w
.45587 .26767 m
.45869 .26612 L
s
.45587 .26767 Mdot
1 .014 0 r
.21148 .26626 Mdot
.21284 .26371 m
.21148 .26626 L
s
0 0 0 r
.004 w
.20065 .26621 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20085 .39256 m
.20102 .39409 L
s
.42219 .3704 m
.42236 .37739 L
s
1 .521 0 r
.01 w
[ .05 .05 ] 0 setdash
.45869 .26612 m
.46165 .26452 L
s
.45869 .26612 Mdot
0 0 0 r
.004 w
.20145 .26467 Mdot
1 .521 0 r
.01 w
.46165 .26452 m
.46468 .26288 L
s
.46165 .26452 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43091 .31179 m
.43197 .32004 L
s
.42685 .33561 m
.42746 .32071 L
s
1 .014 0 r
.01 w
.21284 .26371 Mdot
[ .05 .05 ] 0 setdash
.21424 .26128 m
.21284 .26371 L
s
0 0 0 r
.004 w
.20226 .26313 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20062 .39004 m
.20085 .39256 L
s
1 .521 0 r
.01 w
[ .05 .05 ] 0 setdash
.46468 .26288 m
.46742 .26134 L
s
.46468 .26288 Mdot
0 0 0 r
.004 w
.20309 .26161 Mdot
1 .52 0 r
.01 w
.46742 .26134 m
.47013 .25981 L
s
.46742 .26134 Mdot
1 .014 0 r
.21424 .26128 Mdot
.21585 .25877 m
.21424 .26128 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20051 .38656 m
.20062 .39004 L
s
0 0 0 r
.004 w
.20393 .2601 Mdot
1 .52 0 r
.01 w
[ .05 .05 ] 0 setdash
.47013 .25981 m
.47267 .25833 L
s
.47013 .25981 Mdot
1 .014 0 r
.21585 .25877 Mdot
1 .015 0 r
.21743 .25634 m
.21585 .25877 L
s
0 0 0 r
.004 w
.20479 .25861 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20014 .38389 m
.20051 .38656 L
s
.42236 .37739 m
.42251 .38147 L
s
1 .52 0 r
.01 w
[ .05 .05 ] 0 setdash
.47267 .25833 m
.47496 .25697 L
s
.47267 .25833 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43197 .32004 m
.43335 .32824 L
s
.42608 .34924 m
.42685 .33561 L
s
0 0 0 r
.004 w
.20566 .25712 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.47388 .32623 m
.47496 .25697 L
s
1 .52 0 r
.01 w
[ .05 .05 ] 0 setdash
.47496 .25697 m
.47687 .25576 L
s
.47496 .25697 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.20928 .34057 m
.21743 .25634 L
s
1 .015 0 r
.01 w
.21743 .25634 Mdot
[ .05 .05 ] 0 setdash
.2192 .25392 m
.21743 .25634 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19986 .38227 m
.20014 .38389 L
s
1 .52 0 r
.01 w
[ .05 .05 ] 0 setdash
.47687 .25576 m
.47868 .25458 L
s
.47687 .25576 Mdot
0 0 0 r
.004 w
.20654 .25564 Mdot
1 .519 0 r
.01 w
.47868 .25458 m
.48043 .25344 L
s
.47868 .25458 Mdot
0 0 0 r
.004 w
.20745 .25417 Mdot
1 .015 0 r
.01 w
.2192 .25392 Mdot
.22097 .25146 m
.2192 .25392 L
s
1 .519 0 r
.48043 .25344 m
.48205 .25239 L
s
.48043 .25344 Mdot
0 0 0 r
.004 w
.20836 .25272 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19948 .37939 m
.19986 .38227 L
s
.4252 .36109 m
.42608 .34924 L
s
1 .519 0 r
.01 w
[ .05 .05 ] 0 setdash
.48205 .25239 m
.48338 .25153 L
s
.48205 .25239 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42251 .38147 m
.4231 .38142 L
s
1 .519 0 r
.01 w
[ .05 .05 ] 0 setdash
.48338 .25153 m
.48438 .25089 L
s
.48338 .25153 Mdot
1 .015 0 r
.22097 .25146 Mdot
.22276 .24896 m
.22097 .25146 L
s
0 0 0 r
.004 w
.20929 .25127 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43335 .32824 m
.43506 .33562 L
s
1 .519 0 r
.01 w
[ .05 .05 ] 0 setdash
.48438 .25089 m
.4851 .25043 L
s
.48438 .25089 Mdot
1 .518 0 r
.4851 .25043 m
.48562 .25011 L
s
.4851 .25043 Mdot
.48562 .25011 m
.48609 .24986 L
s
.48562 .25011 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19905 .37796 m
.19948 .37939 L
s
1 .518 0 r
.01 w
[ .05 .05 ] 0 setdash
.48609 .24986 m
.48669 .24958 L
s
.48609 .24986 Mdot
0 0 0 r
.004 w
.21023 .24984 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.48647 .26794 m
.48669 .24958 L
s
1 .518 0 r
.01 w
[ .05 .05 ] 0 setdash
.48669 .24958 m
.48748 .2492 L
s
.48669 .24958 Mdot
.48748 .2492 m
.48849 .24865 L
s
.48748 .2492 Mdot
1 .015 0 r
.22276 .24896 Mdot
1 .016 0 r
.22451 .24648 m
.22276 .24896 L
s
1 .517 0 r
.48849 .24865 m
.49 .24779 L
s
.48849 .24865 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42439 .37119 m
.4252 .36109 L
s
0 0 0 r
.004 w
.21119 .24841 Mdot
.83769 .24823 Mdot
.83769 .24823 Mdot
.53 .8 .95 r
.006 w
.4231 .38142 m
.42359 .37763 L
s
1 .517 0 r
.01 w
[ .05 .05 ] 0 setdash
.49 .24779 m
.49187 .24667 L
s
.49 .24779 Mdot
0 0 0 r
.004 w
.21215 .24699 Mdot
1 .517 0 r
.01 w
.49187 .24667 m
.49418 .24525 L
s
.49187 .24667 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19862 .37671 m
.19905 .37796 L
s
1 .016 0 r
.01 w
.22451 .24648 Mdot
[ .05 .05 ] 0 setdash
.22646 .24377 m
.22451 .24648 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.42359 .37763 m
.42439 .37119 L
s
0 0 0 r
.004 w
.21314 .24559 Mdot
1 .517 0 r
.01 w
[ .05 .05 ] 0 setdash
.49418 .24525 m
.49709 .24349 L
s
.49418 .24525 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43506 .33562 m
.43709 .34153 L
s
.48551 .25911 m
.48595 .26186 L
s
.48498 .26012 m
.48551 .25911 L
s
.4842 .26485 m
.48498 .26012 L
s
0 0 0 r
.004 w
.21413 .24419 Mdot
1 .016 0 r
.01 w
.22646 .24377 Mdot
[ .05 .05 ] 0 setdash
.22811 .24124 m
.22646 .24377 L
s
1 .516 0 r
.49709 .24349 m
.50079 .24133 L
s
.49709 .24349 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19831 .37598 m
.19862 .37671 L
s
0 0 0 r
.004 w
.21514 .2428 Mdot
.53 .8 .95 r
.006 w
.48595 .26186 m
.48647 .26794 L
s
.4831 .27284 m
.4842 .26485 L
s
0 0 0 r
.004 w
.21616 .24143 Mdot
1 .516 0 r
.01 w
[ .05 .05 ] 0 setdash
.50079 .24133 m
.50512 .23887 L
s
.50079 .24133 Mdot
1 .016 0 r
.22811 .24124 Mdot
.23002 .23854 m
.22811 .24124 L
s
0 0 0 r
.004 w
.21719 .24006 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.43709 .34153 m
.43925 .34541 L
s
.19806 .37371 m
.19831 .37598 L
s
1 .516 0 r
.01 w
[ .05 .05 ] 0 setdash
.50512 .23887 m
.51015 .2361 L
s
.50512 .23887 Mdot
0 0 0 r
.004 w
.21824 .2387 Mdot
1 .016 0 r
.01 w
.23002 .23854 Mdot
.23191 .23585 m
.23002 .23854 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48163 .28364 m
.4831 .27284 L
s
.48647 .26794 m
.48716 .27647 L
s
0 0 0 r
.004 w
.2193 .23735 Mdot
1 .516 0 r
.01 w
[ .05 .05 ] 0 setdash
.51015 .2361 m
.5154 .23323 L
s
.51015 .2361 Mdot
0 0 0 r
.004 w
.22037 .23601 Mdot
1 .016 0 r
.01 w
.23191 .23585 Mdot
1 .017 0 r
.23353 .23338 m
.23191 .23585 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19804 .37098 m
.19806 .37371 L
s
0 0 0 r
.004 w
.22145 .23468 Mdot
.53 .8 .95 r
.006 w
.43925 .34541 m
.44158 .34688 L
s
1 .017 0 r
.01 w
.23353 .23338 Mdot
[ .05 .05 ] 0 setdash
.23557 .23063 m
.23353 .23338 L
s
0 0 0 r
.004 w
.22254 .23335 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.51503 .36112 m
.5154 .23323 L
s
1 .516 0 r
.01 w
[ .05 .05 ] 0 setdash
.5154 .23323 m
.51969 .23072 L
s
.5154 .23323 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47984 .29612 m
.48163 .28364 L
s
.19821 .36896 m
.19804 .37098 L
s
.48716 .27647 m
.48809 .28441 L
s
0 0 0 r
.004 w
.22365 .23204 Mdot
.53 .8 .95 r
.006 w
.44158 .34688 m
.44396 .34393 L
s
.44642 .33995 m
.44914 .33821 L
s
.44396 .34393 m
.44642 .33995 L
s
0 0 0 r
.004 w
.22477 .23073 Mdot
1 .515 0 r
.01 w
[ .05 .05 ] 0 setdash
.51969 .23072 m
.52387 .22832 L
s
.51969 .23072 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.22741 .31957 m
.23557 .23063 L
s
1 .017 0 r
.01 w
.23557 .23063 Mdot
[ .05 .05 ] 0 setdash
.23728 .22813 m
.23557 .23063 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19863 .3649 m
.19821 .36896 L
s
.44914 .33821 m
.4517 .3362 L
s
0 0 0 r
.004 w
.2259 .22944 Mdot
.53 .8 .95 r
.006 w
.4517 .3362 m
.45442 .33465 L
s
1 .515 0 r
.01 w
[ .05 .05 ] 0 setdash
.52387 .22832 m
.52783 .22609 L
s
.52387 .22832 Mdot
0 0 0 r
.004 w
.22704 .22815 Mdot
1 .017 0 r
.01 w
.23728 .22813 Mdot
.23924 .22552 m
.23728 .22813 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19923 .36157 m
.19863 .3649 L
s
.4779 .30825 m
.47984 .29612 L
s
.45442 .33465 m
.4573 .3335 L
s
0 0 0 r
.004 w
.22819 .22687 Mdot
.82069 .22675 Mdot
.53 .8 .95 r
.006 w
.48809 .28441 m
.4895 .29382 L
s
1 .515 0 r
.01 w
[ .05 .05 ] 0 setdash
.52783 .22609 m
.53148 .22402 L
s
.52783 .22609 Mdot
0 0 0 r
.004 w
.22936 .2256 Mdot
1 .017 0 r
.01 w
.23924 .22552 Mdot
.24106 .22299 m
.23924 .22552 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2 .35844 m
.19923 .36157 L
s
.4573 .3335 m
.4603 .33295 L
s
0 0 0 r
.004 w
.23053 .22433 Mdot
1 .515 0 r
.01 w
[ .05 .05 ] 0 setdash
.53148 .22402 m
.53531 .22195 L
s
.53148 .22402 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20092 .3555 m
.2 .35844 L
s
0 0 0 r
.004 w
.23172 .22308 Mdot
1 .017 0 r
.01 w
.24106 .22299 Mdot
1 .018 0 r
[ .05 .05 ] 0 setdash
.24283 .22057 m
.24106 .22299 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4603 .33295 m
.46336 .3332 L
s
1 .515 0 r
.01 w
[ .05 .05 ] 0 setdash
.53531 .22195 m
.53916 .21996 L
s
.53531 .22195 Mdot
0 0 0 r
.004 w
.23292 .22183 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47593 .31856 m
.4779 .30825 L
s
0 0 0 r
.004 w
.23412 .22059 Mdot
1 .018 0 r
.01 w
.24283 .22057 Mdot
[ .05 .05 ] 0 setdash
.24467 .21803 m
.24283 .22057 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20205 .35238 m
.20092 .3555 L
s
.46336 .3332 m
.46612 .3336 L
s
1 .514 0 r
.01 w
[ .05 .05 ] 0 setdash
.53916 .21996 m
.54209 .21844 L
s
.53916 .21996 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4895 .29382 m
.4913 .30196 L
s
0 0 0 r
.004 w
.23534 .21936 Mdot
1 .514 0 r
.01 w
[ .05 .05 ] 0 setdash
.54209 .21844 m
.5437 .21756 L
s
.54209 .21844 Mdot
0 0 0 r
.004 w
.81242 .21814 Mdot
.23658 .21814 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20327 .34987 m
.20205 .35238 L
s
1 .018 0 r
.01 w
.24467 .21803 Mdot
[ .05 .05 ] 0 setdash
.24627 .21567 m
.24467 .21803 L
s
1 .513 0 r
.54359 .21766 m
.54406 .21748 L
s
.54359 .21766 Mdot
.54353 .21764 m
.54359 .21766 L
s
.54353 .21764 Mdot
.54398 .2174 m
.54353 .21764 L
s
1 .514 0 r
.5437 .21756 m
.54434 .21718 L
s
.5437 .21756 Mdot
1 .512 0 r
.54406 .21748 m
.54482 .21719 L
s
.54406 .21748 Mdot
1 .513 0 r
.54398 .2174 Mdot
.54438 .21718 m
.54398 .2174 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47388 .32623 m
.47593 .31856 L
s
.46612 .3336 m
.46888 .33272 L
s
1 .512 0 r
.01 w
[ .05 .05 ] 0 setdash
.54482 .21719 m
.54586 .21684 L
s
.54482 .21719 Mdot
1 .514 0 r
.54434 .21718 m
.54449 .2171 L
s
.54434 .21718 Mdot
1 .513 0 r
.54438 .21718 Mdot
1 .514 0 r
.54449 .2171 m
.54438 .21718 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.54452 .22236 m
.54449 .2171 L
s
1 .514 0 r
.01 w
.54449 .2171 Mdot
0 0 0 r
.004 w
.23782 .21693 Mdot
1 .512 0 r
.01 w
[ .05 .05 ] 0 setdash
.54586 .21684 m
.54722 .21644 L
s
.54586 .21684 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54435 .21791 m
.54452 .22236 L
s
.54378 .23033 m
.54435 .21791 L
s
1 .512 0 r
.01 w
[ .05 .05 ] 0 setdash
.54722 .21644 m
.5489 .216 L
s
.54722 .21644 Mdot
.5489 .216 m
.5509 .21551 L
s
.5489 .216 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54355 .22059 m
.54365 .22651 L
s
.54401 .22154 m
.54355 .22059 L
s
0 0 0 r
.004 w
.23907 .21572 Mdot
1 .018 0 r
.01 w
.24627 .21567 Mdot
[ .05 .05 ] 0 setdash
.24828 .21311 m
.24627 .21567 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55128 .26038 m
.5509 .21551 L
s
1 .511 0 r
.01 w
[ .05 .05 ] 0 setdash
.5509 .21551 m
.55321 .21498 L
s
.5509 .21551 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20466 .34721 m
.20327 .34987 L
s
.46888 .33272 m
.47151 .33003 L
s
1 .511 0 r
.01 w
[ .05 .05 ] 0 setdash
.55321 .21498 m
.55577 .2144 L
s
.55321 .21498 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54442 .22406 m
.54401 .22154 L
s
.47151 .33003 m
.47388 .32623 L
s
0 0 0 r
.004 w
.24033 .21452 Mdot
1 .511 0 r
.01 w
[ .05 .05 ] 0 setdash
.55577 .2144 m
.55851 .21379 L
s
.55577 .2144 Mdot
.55851 .21379 m
.56126 .21321 L
s
.55851 .21379 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54452 .22236 m
.54442 .22406 L
s
0 0 0 r
.004 w
.2416 .21333 Mdot
1 .511 0 r
.01 w
[ .05 .05 ] 0 setdash
.56126 .21321 m
.56396 .21264 L
s
.56126 .21321 Mdot
1 .018 0 r
.24828 .21311 Mdot
.24995 .21074 m
.24828 .21311 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20603 .34541 m
.20466 .34721 L
s
1 .51 0 r
.01 w
[ .05 .05 ] 0 setdash
.56396 .21264 m
.5665 .21213 L
s
.56396 .21264 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4913 .30196 m
.49355 .31071 L
s
0 0 0 r
.004 w
.24289 .21215 Mdot
1 .51 0 r
.01 w
[ .05 .05 ] 0 setdash
.5665 .21213 m
.56886 .21168 L
s
.5665 .21213 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54365 .22651 m
.54415 .23157 L
s
0 0 0 r
.004 w
.80559 .21168 Mdot
1 .51 0 r
.01 w
[ .05 .05 ] 0 setdash
.56886 .21168 m
.57098 .2113 L
s
.56886 .21168 Mdot
.57098 .2113 m
.57282 .21101 L
s
.57098 .2113 Mdot
.57282 .21101 m
.57435 .21079 L
s
.57282 .21101 Mdot
0 0 0 r
.004 w
.24418 .21097 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57476 .23657 m
.57435 .21079 L
s
1 .509 0 r
.01 w
[ .05 .05 ] 0 setdash
.57435 .21079 m
.57561 .2106 L
s
.57435 .21079 Mdot
1 .018 0 r
.24995 .21074 Mdot
1 .019 0 r
.25197 .20824 m
.24995 .21074 L
s
1 .509 0 r
.57561 .2106 m
.57663 .2104 L
s
.57561 .2106 Mdot
.57663 .2104 m
.57744 .21016 L
s
.57663 .2104 Mdot
.57744 .21016 m
.57807 .20986 L
s
.57744 .21016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20768 .34286 m
.20603 .34541 L
s
1 .508 0 r
.01 w
[ .05 .05 ] 0 setdash
.57807 .20986 m
.5786 .20946 L
s
.57807 .20986 Mdot
0 0 0 r
.004 w
.24549 .20981 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54227 .25088 m
.54378 .23033 L
s
1 .508 0 r
.01 w
[ .05 .05 ] 0 setdash
.5786 .20946 m
.57911 .20895 L
s
.5786 .20946 Mdot
.57911 .20895 m
.5797 .20829 L
s
.57911 .20895 Mdot
0 0 0 r
.004 w
.2468 .20865 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54415 .23157 m
.54494 .23647 L
s
1 .508 0 r
.01 w
[ .05 .05 ] 0 setdash
.5797 .20829 m
.58043 .20747 L
s
.5797 .20829 Mdot
1 .019 0 r
.25197 .20824 Mdot
.25375 .20594 m
.25197 .20824 L
s
0 0 0 r
.004 w
.24813 .2075 Mdot
1 .508 0 r
.01 w
.58043 .20747 m
.58127 .20648 L
s
.58043 .20747 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20928 .34057 m
.20768 .34286 L
s
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.58127 .20648 m
.58222 .20537 L
s
.58127 .20648 Mdot
0 0 0 r
.004 w
.24946 .20635 Mdot
.79951 .20633 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24664 .28798 m
.25375 .20594 L
s
1 .019 0 r
.01 w
.25375 .20594 Mdot
[ .05 .05 ] 0 setdash
.25563 .20357 m
.25375 .20594 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58302 .24891 m
.58222 .20537 L
s
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.58222 .20537 m
.5833 .20408 L
s
.58222 .20537 Mdot
0 0 0 r
.004 w
.25081 .20522 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54494 .23647 m
.54603 .24167 L
s
.49355 .31071 m
.49642 .32107 L
s
.21093 .3399 m
.20928 .34057 L
s
0 0 0 r
.004 w
.25216 .20409 Mdot
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.5833 .20408 m
.58453 .20264 L
s
.5833 .20408 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57761 .22015 m
.57825 .21983 L
s
.57685 .22359 m
.57761 .22015 L
s
1 .019 0 r
.01 w
.25563 .20357 Mdot
[ .05 .05 ] 0 setdash
.25764 .20128 m
.25563 .20357 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57825 .21983 m
.57883 .22244 L
s
0 0 0 r
.004 w
.25353 .20297 Mdot
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.58453 .20264 m
.58583 .2011 L
s
.58453 .20264 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57592 .22937 m
.57685 .22359 L
s
0 0 0 r
.004 w
.2549 .20185 Mdot
.7939 .2017 Mdot
1 .019 0 r
.01 w
.25764 .20128 Mdot
[ .05 .05 ] 0 setdash
.25983 .199 m
.25764 .20128 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57883 .22244 m
.57943 .22719 L
s
.21263 .33856 m
.21093 .3399 L
s
.54603 .24167 m
.54745 .24734 L
s
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.58583 .2011 m
.58715 .19948 L
s
.58583 .2011 Mdot
0 0 0 r
.004 w
.25629 .20075 Mdot
.25768 .19965 Mdot
1 .506 0 r
.01 w
.58715 .19948 m
.58849 .19786 L
s
.58715 .19948 Mdot
1 .019 0 r
.25983 .199 Mdot
1 .02 0 r
.26184 .19696 m
.25983 .199 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57476 .23657 m
.57592 .22937 L
s
0 0 0 r
.004 w
.25909 .19856 Mdot
.53 .8 .95 r
.006 w
.53943 .27817 m
.54227 .25088 L
s
.2143 .33779 m
.21263 .33856 L
s
1 .506 0 r
.01 w
[ .05 .05 ] 0 setdash
.58849 .19786 m
.58984 .19618 L
s
.58849 .19786 Mdot
0 0 0 r
.004 w
.78864 .19758 Mdot
.2605 .19747 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57943 .22719 m
.58013 .23264 L
s
1 .02 0 r
.01 w
.26184 .19696 Mdot
[ .05 .05 ] 0 setdash
.26429 .19484 m
.26184 .19696 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54745 .24734 m
.54921 .25463 L
s
0 0 0 r
.004 w
.26192 .1964 Mdot
1 .506 0 r
.01 w
[ .05 .05 ] 0 setdash
.58984 .19618 m
.59119 .19448 L
s
.58984 .19618 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49642 .32107 m
.5001 .33402 L
s
0 0 0 r
.004 w
.26336 .19533 Mdot
1 .02 0 r
.01 w
.26429 .19484 Mdot
[ .05 .05 ] 0 setdash
.2665 .19304 m
.26429 .19484 L
s
1 .506 0 r
.59119 .19448 m
.5926 .19279 L
s
.59119 .19448 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57333 .24431 m
.57476 .23657 L
s
0 0 0 r
.004 w
.2648 .19427 Mdot
.53 .8 .95 r
.006 w
.21603 .33595 m
.2143 .33779 L
s
0 0 0 r
.004 w
.78363 .19385 Mdot
.26625 .19321 Mdot
1 .02 0 r
.01 w
.2665 .19304 Mdot
[ .05 .05 ] 0 setdash
.26921 .19115 m
.2665 .19304 L
s
1 .506 0 r
.5926 .19279 m
.59404 .19109 L
s
.5926 .19279 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58013 .23264 m
.58098 .23823 L
s
0 0 0 r
.004 w
.26771 .19216 Mdot
.53 .8 .95 r
.006 w
.54921 .25463 m
.55128 .26038 L
s
.21795 .33403 m
.21603 .33595 L
s
1 .02 0 r
.01 w
.26921 .19115 Mdot
1 .021 0 r
[ .05 .05 ] 0 setdash
.27178 .18951 m
.26921 .19115 L
s
0 0 0 r
.004 w
.26919 .19112 Mdot
1 .505 0 r
.01 w
.59404 .19109 m
.59555 .1894 L
s
.59404 .19109 Mdot
0 0 0 r
.004 w
.77883 .19044 Mdot
.27067 .19009 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57157 .25098 m
.57333 .24431 L
s
1 .021 0 r
.01 w
.27178 .18951 Mdot
[ .05 .05 ] 0 setdash
.27459 .18796 m
.27178 .18951 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59681 .24434 m
.59555 .1894 L
s
1 .505 0 r
.01 w
[ .05 .05 ] 0 setdash
.59555 .1894 m
.59714 .18768 L
s
.59555 .1894 Mdot
0 0 0 r
.004 w
.27216 .18907 Mdot
.27366 .18805 Mdot
1 .021 0 r
.01 w
.27459 .18796 Mdot
.27755 .18653 m
.27459 .18796 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2196 .332 m
.21795 .33403 L
s
.58098 .23823 m
.58194 .24361 L
s
1 .505 0 r
.01 w
[ .05 .05 ] 0 setdash
.59714 .18768 m
.59877 .18593 L
s
.59714 .18768 Mdot
0 0 0 r
.004 w
.77419 .18728 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55128 .26038 m
.55367 .26525 L
s
0 0 0 r
.004 w
.27516 .18704 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.27196 .25683 m
.27755 .18653 L
s
1 .021 0 r
.01 w
.27755 .18653 Mdot
[ .05 .05 ] 0 setdash
.28031 .18531 m
.27755 .18653 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56952 .25807 m
.57157 .25098 L
s
0 0 0 r
.004 w
.27668 .18603 Mdot
1 .505 0 r
.01 w
[ .05 .05 ] 0 setdash
.59877 .18593 m
.60046 .18416 L
s
.59877 .18593 Mdot
1 .021 0 r
.28031 .18531 Mdot
.28354 .18405 m
.28031 .18531 L
s
0 0 0 r
.004 w
.27821 .18503 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22167 .32814 m
.2196 .332 L
s
0 0 0 r
.004 w
.7697 .18434 Mdot
1 .505 0 r
.01 w
[ .05 .05 ] 0 setdash
.60046 .18416 m
.60218 .18237 L
s
.60046 .18416 Mdot
1 .021 0 r
.28354 .18405 Mdot
1 .022 0 r
.28654 .18299 m
.28354 .18405 L
s
0 0 0 r
.004 w
.27974 .18405 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5001 .33402 m
.50446 .34691 L
s
.5356 .30557 m
.53943 .27817 L
s
.55367 .26525 m
.55631 .26863 L
s
0 0 0 r
.004 w
.28129 .18306 Mdot
1 .022 0 r
.01 w
.28654 .18299 Mdot
[ .05 .05 ] 0 setdash
.28935 .18206 m
.28654 .18299 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22356 .32586 m
.22167 .32814 L
s
.58194 .24361 m
.58302 .24891 L
s
1 .504 0 r
.01 w
[ .05 .05 ] 0 setdash
.60218 .18237 m
.60381 .18059 L
s
.60218 .18237 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5672 .26415 m
.56952 .25807 L
s
0 0 0 r
.004 w
.28284 .18209 Mdot
1 .022 0 r
.01 w
.28935 .18206 Mdot
[ .05 .05 ] 0 setdash
.29211 .18118 m
.28935 .18206 L
s
0 0 0 r
.004 w
.76533 .18158 Mdot
1 .022 0 r
.01 w
.29211 .18118 Mdot
.29449 .18046 m
.29211 .18118 L
s
1 .241 0 r
.72873 .18115 m
.72866 .18114 L
s
.72873 .18115 Mdot
.72876 .18111 m
.72873 .18115 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.7288 .18331 m
.72866 .18114 L
s
1 .241 0 r
.01 w
[ .05 .05 ] 0 setdash
.72866 .18114 m
.72854 .18106 L
s
.72866 .18114 Mdot
0 0 0 r
.004 w
.2844 .18112 Mdot
1 .241 0 r
.01 w
.72876 .18111 Mdot
1 .242 0 r
.72874 .18101 m
.72876 .18111 L
s
1 .241 0 r
.72854 .18106 m
.72839 .18093 L
s
.72854 .18106 Mdot
1 .242 0 r
.72874 .18101 Mdot
.72868 .18087 m
.72874 .18101 L
s
1 .241 0 r
.72839 .18093 m
.72823 .18077 L
s
.72839 .18093 Mdot
1 .242 0 r
.72868 .18087 Mdot
.7286 .1807 m
.72868 .18087 L
s
1 .24 0 r
.72823 .18077 m
.72807 .18059 L
s
.72823 .18077 Mdot
1 .242 0 r
.7286 .1807 Mdot
.72847 .1805 m
.7286 .1807 L
s
1 .24 0 r
.72807 .18059 m
.72794 .1804 L
s
.72807 .18059 Mdot
1 .504 0 r
.60381 .18059 m
.60537 .17883 L
s
.60381 .18059 Mdot
1 .242 0 r
.72847 .1805 Mdot
1 .243 0 r
.72833 .18031 m
.72847 .1805 L
s
1 .022 0 r
.29449 .18046 Mdot
.29679 .17975 m
.29449 .18046 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72881 .1823 m
.7288 .18331 L
s
.7289 .18332 m
.72881 .1823 L
s
1 .24 0 r
.01 w
[ .05 .05 ] 0 setdash
.72794 .1804 m
.72783 .1802 L
s
.72794 .1804 Mdot
1 .243 0 r
.72833 .18031 Mdot
.72815 .18011 m
.72833 .18031 L
s
1 .24 0 r
.72783 .1802 m
.72772 .17999 L
s
.72783 .1802 Mdot
0 0 0 r
.004 w
.28598 .18016 Mdot
1 .243 0 r
.01 w
.72815 .18011 Mdot
.72794 .17993 m
.72815 .18011 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55631 .26863 m
.55913 .27013 L
s
1 .24 0 r
.01 w
[ .05 .05 ] 0 setdash
.72772 .17999 m
.7276 .17979 L
s
.72772 .17999 Mdot
1 .243 0 r
.72794 .17993 Mdot
.72769 .17975 m
.72794 .17993 L
s
1 .239 0 r
.7276 .17979 m
.7275 .17962 L
s
.7276 .17979 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22521 .32357 m
.22356 .32586 L
s
1 .022 0 r
.01 w
.29679 .17975 Mdot
1 .023 0 r
[ .05 .05 ] 0 setdash
.29877 .17913 m
.29679 .17975 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72818 .18711 m
.72769 .17975 L
s
1 .243 0 r
.01 w
.72769 .17975 Mdot
[ .05 .05 ] 0 setdash
.7274 .17958 m
.72769 .17975 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7288 .18331 m
.72878 .18478 L
s
.72898 .18471 m
.7289 .18332 L
s
1 .239 0 r
.01 w
[ .05 .05 ] 0 setdash
.7275 .17962 m
.7274 .17949 L
s
.7275 .17962 Mdot
1 .243 0 r
.7274 .17958 Mdot
1 .244 0 r
.72709 .17942 m
.7274 .17958 L
s
1 .238 0 r
.72683 .17954 m
.72661 .17952 L
s
.72683 .17954 Mdot
.72698 .17951 m
.72683 .17954 L
s
1 .237 0 r
.72661 .17952 m
.72627 .17942 L
s
.72661 .17952 Mdot
1 .238 0 r
.72698 .17951 Mdot
.72708 .17945 m
.72698 .17951 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72761 .18273 m
.7274 .17949 L
s
1 .239 0 r
.01 w
[ .05 .05 ] 0 setdash
.7274 .17949 m
.72731 .17941 L
s
.7274 .17949 Mdot
1 .238 0 r
.72708 .17945 Mdot
.72715 .1794 m
.72708 .17945 L
s
1 .244 0 r
.72709 .17942 Mdot
.72677 .17928 m
.72709 .17942 L
s
1 .237 0 r
.72627 .17942 m
.72579 .17921 L
s
.72627 .17942 Mdot
1 .239 0 r
.72731 .17941 m
.72722 .17938 L
s
.72731 .17941 Mdot
1 .238 0 r
.72715 .1794 Mdot
1 .239 0 r
.72722 .17938 m
.72715 .1794 L
s
.72722 .17938 Mdot
1 .244 0 r
.72677 .17928 Mdot
.72645 .17916 m
.72677 .17928 L
s
1 .237 0 r
.72579 .17921 m
.72513 .17891 L
s
.72579 .17921 Mdot
0 0 0 r
.004 w
.28756 .1792 Mdot
1 .244 0 r
.01 w
.72645 .17916 Mdot
.72615 .17906 m
.72645 .17916 L
s
1 .023 0 r
.29877 .17913 Mdot
.30034 .17861 m
.29877 .17913 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56467 .26868 m
.5672 .26415 L
s
1 .244 0 r
.01 w
.72615 .17906 Mdot
[ .05 .05 ] 0 setdash
.72588 .17898 m
.72615 .17906 L
s
0 0 0 r
.004 w
.76107 .17898 Mdot
1 .244 0 r
.01 w
.72588 .17898 Mdot
1 .245 0 r
.72565 .17892 m
.72588 .17898 L
s
1 .248 0 r
.72514 .17896 m
.72523 .17895 L
s
.72514 .17896 Mdot
.72498 .17894 m
.72514 .17896 L
s
.72523 .17895 m
.72527 .17893 L
s
.72523 .17895 Mdot
.72498 .17894 Mdot
1 .249 0 r
.72475 .17889 m
.72498 .17894 L
s
1 .248 0 r
.72527 .17893 m
.72526 .17891 L
s
.72527 .17893 Mdot
1 .245 0 r
.72565 .17892 Mdot
.72545 .17888 m
.72565 .17892 L
s
1 .248 0 r
.72526 .17891 m
.72523 .17888 L
s
.72526 .17891 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72626 .19635 m
.72513 .17891 L
s
1 .237 0 r
.01 w
[ .05 .05 ] 0 setdash
.72513 .17891 m
.7243 .1785 L
s
.72513 .17891 Mdot
1 .249 0 r
.72475 .17889 Mdot
.72443 .1788 m
.72475 .17889 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72529 .17978 m
.72523 .17888 L
s
1 .247 0 r
.01 w
[ .05 .05 ] 0 setdash
.72523 .17888 m
.72518 .17885 L
s
.72523 .17888 Mdot
1 .245 0 r
.72545 .17888 Mdot
.7253 .17885 m
.72545 .17888 L
s
1 .247 0 r
.72518 .17885 m
.72513 .17883 L
s
.72518 .17885 Mdot
1 .245 0 r
.7253 .17885 Mdot
.72519 .17884 m
.7253 .17885 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72532 .18096 m
.72519 .17884 L
s
1 .245 0 r
.01 w
.72519 .17884 Mdot
[ .05 .05 ] 0 setdash
.72509 .17883 m
.72519 .17884 L
s
1 .247 0 r
.72513 .17883 m
.72507 .17882 L
s
.72513 .17883 Mdot
1 .504 0 r
.60537 .17883 m
.60678 .1772 L
s
.60537 .17883 Mdot
1 .245 0 r
.72509 .17883 Mdot
1 .246 0 r
.72502 .17882 m
.72509 .17883 L
s
1 .247 0 r
.72507 .17882 m
.72502 .17882 L
s
.72507 .17882 Mdot
1 .246 0 r
.72502 .17882 Mdot
.72497 .17881 m
.72502 .17882 L
s
.72502 .17882 m
.72498 .17881 L
s
.72502 .17882 Mdot
.72498 .17881 m
.72496 .17881 L
s
.72498 .17881 Mdot
.72497 .17881 Mdot
.72496 .17881 m
.72497 .17881 L
s
.72496 .17881 Mdot
1 .249 0 r
.72443 .1788 Mdot
.72404 .17866 m
.72443 .1788 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72498 .17887 m
.72506 .17954 L
s
.72499 .1792 m
.72498 .17887 L
s
1 .249 0 r
.01 w
.72404 .17866 Mdot
[ .05 .05 ] 0 setdash
.72358 .17847 m
.72404 .17866 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7273 .18049 m
.72727 .18123 L
s
.72742 .18114 m
.7273 .18049 L
s
.72878 .18478 m
.72872 .186 L
s
1 .023 0 r
.01 w
.30034 .17861 Mdot
[ .05 .05 ] 0 setdash
.30172 .17813 m
.30034 .17861 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.729 .18574 m
.72898 .18471 L
s
.72502 .17941 m
.72499 .1792 L
s
1 .237 0 r
.01 w
[ .05 .05 ] 0 setdash
.7243 .1785 m
.72322 .17796 L
s
.7243 .1785 Mdot
1 .249 0 r
.72358 .17847 Mdot
.72308 .17825 m
.72358 .17847 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72511 .17938 m
.72506 .17942 L
s
.72517 .17941 m
.72511 .17938 L
s
.72523 .17957 m
.72517 .17941 L
s
.72528 .17972 m
.72532 .17972 L
s
.72524 .18045 m
.72528 .17972 L
s
.72506 .17942 m
.72502 .17941 L
s
.72532 .17972 m
.72532 .17983 L
s
.72529 .17978 m
.72523 .17957 L
s
.72506 .17954 m
.72518 .18028 L
s
.72532 .17983 m
.72529 .17978 L
s
.72761 .18273 m
.72742 .18114 L
s
0 0 0 r
.004 w
.28915 .17826 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72392 .19135 m
.72308 .17825 L
s
1 .249 0 r
.01 w
.72308 .17825 Mdot
1 .25 0 r
[ .05 .05 ] 0 setdash
.72254 .17798 m
.72308 .17825 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72727 .18123 m
.72724 .182 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.29996 .20253 m
.30172 .17813 L
s
1 .023 0 r
.01 w
.30172 .17813 Mdot
[ .05 .05 ] 0 setdash
.30274 .17777 m
.30172 .17813 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55913 .27013 m
.56192 .26978 L
s
1 .025 0 r
.01 w
[ .05 .05 ] 0 setdash
.30159 .17799 m
.30162 .17799 L
s
.30159 .17799 Mdot
1 .026 0 r
.30183 .17796 m
.30159 .17799 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.30121 .18378 m
.30162 .17799 L
s
1 .025 0 r
.01 w
[ .05 .05 ] 0 setdash
.30162 .17799 m
.30189 .17793 L
s
.30162 .17799 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72517 .18182 m
.72524 .18045 L
s
1 .25 0 r
.01 w
.72254 .17798 Mdot
[ .05 .05 ] 0 setdash
.72199 .17769 m
.72254 .17798 L
s
1 .236 0 r
.72322 .17796 m
.72187 .17729 L
s
.72322 .17796 Mdot
1 .026 0 r
.30183 .17796 Mdot
.30237 .17787 m
.30183 .17796 L
s
1 .025 0 r
.30189 .17793 m
.30233 .17782 L
s
.30189 .17793 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72518 .18028 m
.72532 .18096 L
s
1 .026 0 r
.01 w
.30237 .17787 Mdot
[ .05 .05 ] 0 setdash
.30318 .17776 m
.30237 .17787 L
s
1 .025 0 r
.30233 .17782 m
.30284 .17768 L
s
.30233 .17782 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72724 .182 m
.72717 .18252 L
s
1 .023 0 r
.01 w
.30274 .17777 Mdot
[ .05 .05 ] 0 setdash
.30344 .17752 m
.30274 .17777 L
s
1 .026 0 r
.30318 .17776 Mdot
.30419 .17765 m
.30318 .17776 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72895 .18605 m
.729 .18574 L
s
1 .25 0 r
.01 w
.72199 .17769 Mdot
[ .05 .05 ] 0 setdash
.72145 .17739 m
.72199 .17769 L
s
1 .025 0 r
.30284 .17768 m
.30332 .17754 L
s
.30284 .17768 Mdot
1 .026 0 r
.30419 .17765 Mdot
.30548 .17751 m
.30419 .17765 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72872 .186 m
.72863 .18689 L
s
.58302 .24891 m
.58421 .25248 L
s
.72717 .18252 m
.72708 .18334 L
s
1 .024 0 r
.01 w
[ .05 .05 ] 0 setdash
.30332 .17754 m
.30369 .17743 L
s
.30332 .17754 Mdot
1 .023 0 r
.30344 .17752 Mdot
1 .024 0 r
.30382 .17739 m
.30344 .17752 L
s
1 .026 0 r
.30548 .17751 Mdot
1 .027 0 r
.30695 .17738 m
.30548 .17751 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72532 .18096 m
.72548 .1816 L
s
1 .024 0 r
.01 w
[ .05 .05 ] 0 setdash
.30369 .17743 m
.30388 .17737 L
s
.30369 .17743 Mdot
.30382 .17739 Mdot
.30388 .17737 m
.30382 .17739 L
s
1 .25 0 r
.72145 .17739 Mdot
.72095 .1771 m
.72145 .17739 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72782 .18446 m
.72761 .18273 L
s
1 .027 0 r
.01 w
.30695 .17738 Mdot
[ .05 .05 ] 0 setdash
.30859 .17724 m
.30695 .17738 L
s
1 .024 0 r
.30388 .17737 Mdot
0 0 0 r
.004 w
.29075 .17732 Mdot
1 .236 0 r
.01 w
.72187 .17729 m
.72019 .17644 L
s
.72187 .17729 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56192 .26978 m
.56467 .26868 L
s
1 .027 0 r
.01 w
.30859 .17724 Mdot
[ .05 .05 ] 0 setdash
.31059 .17698 m
.30859 .17724 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72887 .18661 m
.72895 .18605 L
s
1 .504 0 r
.01 w
[ .05 .05 ] 0 setdash
.60678 .1772 m
.60805 .17561 L
s
.60678 .1772 Mdot
1 .25 0 r
.72095 .1771 Mdot
.7205 .17682 m
.72095 .1771 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30149 .1794 m
.30121 .18378 L
s
.30153 .18212 m
.30149 .1794 L
s
.72505 .18357 m
.72517 .18182 L
s
.72708 .18334 m
.72698 .18522 L
s
.22741 .31957 m
.22521 .32357 L
s
.72548 .1816 m
.72568 .18234 L
s
1 .027 0 r
.01 w
.31059 .17698 Mdot
[ .05 .05 ] 0 setdash
.31275 .17664 m
.31059 .17698 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30383 .17811 m
.30349 .182 L
s
.30332 .18259 m
.30383 .17811 L
s
1 .25 0 r
.01 w
.7205 .17682 Mdot
1 .251 0 r
[ .05 .05 ] 0 setdash
.72011 .17656 m
.7205 .17682 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72863 .18689 m
.72852 .18743 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.30981 .21949 m
.31275 .17664 L
s
1 .027 0 r
.01 w
.31275 .17664 Mdot
[ .05 .05 ] 0 setdash
.31488 .17624 m
.31275 .17664 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72568 .18234 m
.72593 .18322 L
s
1 .251 0 r
.01 w
.72011 .17656 Mdot
[ .05 .05 ] 0 setdash
.71979 .17633 m
.72011 .17656 L
s
0 0 0 r
.004 w
.7569 .17653 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72875 .18678 m
.72887 .18661 L
s
.72801 .18603 m
.72782 .18446 L
s
1 .236 0 r
.01 w
[ .05 .05 ] 0 setdash
.72019 .17644 m
.71828 .17555 L
s
.72019 .17644 Mdot
0 0 0 r
.004 w
.29235 .17638 Mdot
1 .251 0 r
.01 w
.71979 .17633 Mdot
.71956 .17615 m
.71979 .17633 L
s
1 .258 0 r
.72005 .17625 m
.71994 .17622 L
s
.72005 .17625 Mdot
.72008 .17623 m
.72005 .17625 L
s
1 .027 0 r
.31488 .17624 Mdot
1 .028 0 r
.31721 .1757 m
.31488 .17624 L
s
1 .258 0 r
.72008 .17623 Mdot
1 .259 0 r
.72 .17615 m
.72008 .17623 L
s
1 .258 0 r
.71994 .17622 m
.71979 .17616 L
s
.71994 .17622 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71997 .179 m
.71979 .17616 L
s
1 .258 0 r
.01 w
[ .05 .05 ] 0 setdash
.71979 .17616 m
.71965 .17607 L
s
.71979 .17616 Mdot
1 .259 0 r
.72 .17615 Mdot
.71978 .17601 m
.72 .17615 L
s
1 .251 0 r
.71956 .17615 Mdot
.71941 .17601 m
.71956 .17615 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72852 .18743 m
.72841 .18763 L
s
.72593 .18322 m
.72622 .18418 L
s
1 .253 0 r
.01 w
[ .05 .05 ] 0 setdash
.71959 .1761 m
.71959 .17609 L
s
.71959 .1761 Mdot
1 .254 0 r
.71959 .17609 m
.71959 .1761 L
s
1 .253 0 r
.71959 .17609 m
.71956 .17606 L
s
.71959 .17609 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.7196 .17637 m
.71959 .17609 L
s
1 .254 0 r
.01 w
.71959 .17609 Mdot
[ .05 .05 ] 0 setdash
.71957 .17606 m
.71959 .17609 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72861 .18698 m
.72875 .18678 L
s
1 .258 0 r
.01 w
[ .05 .05 ] 0 setdash
.71965 .17607 m
.71952 .17596 L
s
.71965 .17607 Mdot
1 .254 0 r
.71957 .17606 Mdot
.71953 .17602 m
.71957 .17606 L
s
1 .253 0 r
.71956 .17606 m
.71952 .17601 L
s
.71956 .17606 Mdot
1 .254 0 r
.71953 .17602 Mdot
.71948 .17595 m
.71953 .17602 L
s
1 .259 0 r
.71978 .17601 Mdot
.71937 .17581 m
.71978 .17601 L
s
1 .251 0 r
.71941 .17601 Mdot
1 .252 0 r
.71933 .17591 m
.71941 .17601 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7196 .17623 m
.71962 .1766 L
s
.7196 .17637 m
.7196 .17623 L
s
1 .253 0 r
.01 w
[ .05 .05 ] 0 setdash
.71952 .17601 m
.71947 .17595 L
s
.71952 .17601 Mdot
1 .257 0 r
.71952 .17596 m
.71941 .17585 L
s
.71952 .17596 Mdot
1 .254 0 r
.71948 .17595 Mdot
.71942 .17588 m
.71948 .17595 L
s
1 .253 0 r
.71947 .17595 m
.71941 .17591 L
s
.71947 .17595 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71942 .17731 m
.71933 .17591 L
s
1 .252 0 r
.01 w
.71933 .17591 Mdot
[ .05 .05 ] 0 setdash
.7193 .17587 m
.71933 .17591 L
s
.71941 .17591 m
.71936 .17587 L
s
.71941 .17591 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71961 .17679 m
.7196 .17637 L
s
1 .254 0 r
.01 w
.71942 .17588 Mdot
1 .255 0 r
[ .05 .05 ] 0 setdash
.71936 .1758 m
.71942 .17588 L
s
1 .252 0 r
.71936 .17587 m
.71932 .17586 L
s
.71936 .17587 Mdot
.7193 .17587 Mdot
.71932 .17586 m
.7193 .17587 L
s
.71932 .17586 Mdot
1 .257 0 r
.71941 .17585 m
.71932 .17574 L
s
.71941 .17585 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72487 .18559 m
.72505 .18357 L
s
1 .259 0 r
.01 w
.71937 .17581 Mdot
[ .05 .05 ] 0 setdash
.71872 .17552 m
.71937 .17581 L
s
1 .255 0 r
.71936 .1758 Mdot
.71929 .17571 m
.71936 .1758 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72698 .18522 m
.72687 .18859 L
s
.71962 .1766 m
.71962 .17695 L
s
1 .257 0 r
.01 w
[ .05 .05 ] 0 setdash
.71932 .17574 m
.71925 .17566 L
s
.71932 .17574 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72819 .18719 m
.72801 .18603 L
s
1 .255 0 r
.01 w
.71929 .17571 Mdot
[ .05 .05 ] 0 setdash
.71923 .17564 m
.71929 .17571 L
s
1 .028 0 r
.31721 .1757 Mdot
.3194 .1751 m
.31721 .1757 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72841 .18763 m
.72833 .18783 L
s
1 .257 0 r
.01 w
[ .05 .05 ] 0 setdash
.71925 .17566 m
.7192 .17559 L
s
.71925 .17566 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72014 .17713 m
.72016 .17795 L
s
.72017 .17881 m
.72014 .17713 L
s
1 .255 0 r
.01 w
.71923 .17564 Mdot
[ .05 .05 ] 0 setdash
.71919 .17558 m
.71923 .17564 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7284 .18688 m
.72861 .18698 L
s
.71933 .17622 m
.71942 .17731 L
s
.71938 .17683 m
.71933 .17622 L
s
1 .503 0 r
.01 w
[ .05 .05 ] 0 setdash
.60805 .17561 m
.60916 .17407 L
s
.60805 .17561 Mdot
1 .257 0 r
.7192 .17559 m
.71916 .17554 L
s
.7192 .17559 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71961 .17726 m
.71961 .17679 L
s
.72622 .18418 m
.72656 .18538 L
s
1 .255 0 r
.01 w
.71919 .17558 Mdot
1 .256 0 r
[ .05 .05 ] 0 setdash
.71915 .17553 m
.71919 .17558 L
s
1 .236 0 r
.71828 .17555 m
.71589 .17432 L
s
.71828 .17555 Mdot
1 .256 0 r
.71916 .17554 m
.71913 .17551 L
s
.71916 .17554 Mdot
.71915 .17553 Mdot
.71913 .1755 m
.71915 .17553 L
s
1 .259 0 r
.71872 .17552 Mdot
.71783 .17517 m
.71872 .17552 L
s
1 .256 0 r
.71913 .17551 m
.71912 .17549 L
s
.71913 .17551 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71919 .17642 m
.71913 .1755 L
s
1 .256 0 r
.01 w
.71913 .1755 Mdot
[ .05 .05 ] 0 setdash
.71912 .17549 m
.71913 .1755 L
s
.71912 .17549 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71962 .17695 m
.7196 .17723 L
s
0 0 0 r
.004 w
.29397 .17546 Mdot
.53 .8 .95 r
.006 w
.71913 .17561 m
.71919 .17642 L
s
.7192 .17661 m
.71913 .17561 L
s
.72818 .18711 m
.7284 .18688 L
s
.72833 .18783 m
.72819 .18719 L
s
.30163 .18827 m
.30153 .18212 L
s
.71945 .17727 m
.71938 .17683 L
s
.7196 .17723 m
.71956 .1774 L
s
.7196 .17779 m
.71961 .17726 L
s
1 .259 0 r
.01 w
.71783 .17517 Mdot
1 .26 0 r
[ .05 .05 ] 0 setdash
.71671 .17471 m
.71783 .17517 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72016 .17795 m
.72009 .17867 L
s
1 .028 0 r
.01 w
.3194 .1751 Mdot
[ .05 .05 ] 0 setdash
.3214 .17449 m
.3194 .1751 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71942 .17731 m
.7196 .17902 L
s
.71956 .1774 m
.71951 .17743 L
s
.22924 .31619 m
.22741 .31957 L
s
.71951 .17743 m
.71945 .17727 L
s
.7279 .18721 m
.72818 .18711 L
s
.72656 .18538 m
.72691 .18618 L
s
.71919 .17642 m
.71926 .17734 L
s
.71929 .17754 m
.7192 .17661 L
s
.71958 .17833 m
.7196 .17779 L
s
1 .26 0 r
.01 w
.71671 .17471 Mdot
[ .05 .05 ] 0 setdash
.71533 .17417 m
.71671 .17471 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72009 .17867 m
.71997 .179 L
s
.72759 .18711 m
.7279 .18721 L
s
.72691 .18618 m
.72726 .18676 L
s
0 0 0 r
.004 w
.29559 .17454 Mdot
1 .028 0 r
.01 w
.3214 .17449 Mdot
[ .05 .05 ] 0 setdash
.32312 .1739 m
.3214 .17449 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72014 .1817 m
.72017 .17881 L
s
.72726 .18676 m
.72759 .18711 L
s
.30349 .182 m
.30268 .1883 L
s
.72462 .18772 m
.72487 .18559 L
s
.71926 .17734 m
.71934 .17807 L
s
1 .236 0 r
.01 w
[ .05 .05 ] 0 setdash
.71589 .17432 m
.71339 .17327 L
s
.71589 .17432 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71997 .179 m
.71985 .1792 L
s
.71954 .17873 m
.71958 .17833 L
s
.71937 .1783 m
.71929 .17754 L
s
0 0 0 r
.004 w
.75281 .17421 Mdot
.53 .8 .95 r
.006 w
.30121 .18378 m
.30122 .18722 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71732 .20634 m
.71533 .17417 L
s
1 .26 0 r
.01 w
.71533 .17417 Mdot
[ .05 .05 ] 0 setdash
.71384 .17355 m
.71533 .17417 L
s
1 .503 0 r
.60916 .17407 m
.61011 .17259 L
s
.60916 .17407 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3027 .18616 m
.30332 .18259 L
s
.7196 .17902 m
.7199 .1815 L
s
.71985 .1792 m
.71973 .1793 L
s
.71934 .17807 m
.71943 .17873 L
s
1 .028 0 r
.01 w
.32312 .1739 Mdot
1 .029 0 r
[ .05 .05 ] 0 setdash
.32503 .17318 m
.32312 .1739 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71949 .17888 m
.71954 .17873 L
s
.71944 .17861 m
.71937 .1783 L
s
.71973 .1793 m
.71962 .17919 L
s
.71952 .17895 m
.71944 .17861 L
s
.71962 .17919 m
.71952 .17895 L
s
.71943 .17873 m
.71949 .17888 L
s
0 0 0 r
.004 w
.29723 .17363 Mdot
1 .26 0 r
.01 w
.71384 .17355 Mdot
[ .05 .05 ] 0 setdash
.71217 .17292 m
.71384 .17355 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72687 .18859 m
.72662 .1921 L
s
1 .235 0 r
.01 w
[ .05 .05 ] 0 setdash
.71339 .17327 m
.71039 .17195 L
s
.71339 .17327 Mdot
1 .029 0 r
.32503 .17318 Mdot
.32654 .17255 m
.32503 .17318 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58421 .25248 m
.58555 .25566 L
s
1 .26 0 r
.01 w
.71217 .17292 Mdot
1 .261 0 r
[ .05 .05 ] 0 setdash
.71032 .17215 m
.71217 .17292 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23127 .31336 m
.22924 .31619 L
s
.7243 .18965 m
.72462 .18772 L
s
0 0 0 r
.004 w
.29887 .17272 Mdot
.53 .8 .95 r
.006 w
.7199 .1815 m
.72028 .18403 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61123 .213 m
.61011 .17259 L
s
1 .503 0 r
.01 w
[ .05 .05 ] 0 setdash
.61011 .17259 m
.61091 .1712 L
s
.61011 .17259 Mdot
1 .029 0 r
.32654 .17255 Mdot
.32793 .17195 m
.32654 .17255 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71998 .18547 m
.72014 .1817 L
s
1 .261 0 r
.01 w
.71032 .17215 Mdot
[ .05 .05 ] 0 setdash
.70853 .17144 m
.71032 .17215 L
s
0 0 0 r
.004 w
.7488 .172 Mdot
1 .029 0 r
.01 w
.32793 .17195 Mdot
.3292 .1716 m
.32793 .17195 L
s
1 .235 0 r
.71039 .17195 m
.70727 .17062 L
s
.71039 .17195 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30207 .18834 m
.3027 .18616 L
s
.30122 .18722 m
.30154 .18875 L
s
0 0 0 r
.004 w
.30052 .17182 Mdot
.53 .8 .95 r
.006 w
.50446 .34691 m
.5096 .35634 L
s
1 .029 0 r
.01 w
.3292 .1716 Mdot
[ .05 .05 ] 0 setdash
.33036 .17115 m
.3292 .1716 L
s
1 .261 0 r
.70853 .17144 Mdot
.70671 .17072 m
.70853 .17144 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72028 .18403 m
.72074 .18657 L
s
1 .503 0 r
.01 w
[ .05 .05 ] 0 setdash
.61091 .1712 m
.61155 .16988 L
s
.61091 .1712 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72392 .19135 m
.7243 .18965 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.32893 .19381 m
.33036 .17115 L
s
1 .029 0 r
.01 w
.33036 .17115 Mdot
1 .03 0 r
[ .05 .05 ] 0 setdash
.33133 .17082 m
.33036 .17115 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30197 .19473 m
.30163 .18827 L
s
0 0 0 r
.004 w
.30218 .17093 Mdot
1 .03 0 r
.01 w
.33133 .17082 Mdot
[ .05 .05 ] 0 setdash
.33209 .1706 m
.33133 .17082 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72662 .1921 m
.72626 .19635 L
s
1 .261 0 r
.01 w
.70671 .17072 Mdot
[ .05 .05 ] 0 setdash
.70506 .17008 m
.70671 .17072 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30154 .18875 m
.30207 .18834 L
s
1 .031 0 r
.01 w
[ .05 .05 ] 0 setdash
.33331 .17063 m
.33339 .17062 L
s
.33331 .17063 Mdot
.3332 .17053 m
.33331 .17063 L
s
1 .235 0 r
.70727 .17062 m
.70379 .16921 L
s
.70727 .17062 Mdot
1 .031 0 r
.33339 .17062 m
.3334 .17055 L
s
.33339 .17062 Mdot
1 .03 0 r
.33209 .1706 Mdot
.33264 .17047 m
.33209 .1706 L
s
1 .031 0 r
.3334 .17055 m
.33329 .17047 L
s
.3334 .17055 Mdot
.3332 .17053 Mdot
.33305 .17034 m
.3332 .17053 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30268 .1883 m
.3015 .19515 L
s
1 .03 0 r
.01 w
[ .05 .05 ] 0 setdash
.33329 .17047 m
.33304 .17044 L
s
.33329 .17047 Mdot
.33264 .17047 Mdot
.33304 .17044 m
.33264 .17047 L
s
.33304 .17044 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.33254 .17859 m
.33305 .17034 L
s
1 .031 0 r
.01 w
.33305 .17034 Mdot
1 .032 0 r
[ .05 .05 ] 0 setdash
.33289 .17006 m
.33305 .17034 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23324 .30966 m
.23127 .31336 L
s
1 .261 0 r
.01 w
.70506 .17008 Mdot
[ .05 .05 ] 0 setdash
.70354 .16945 m
.70506 .17008 L
s
1 .032 0 r
.33289 .17006 Mdot
.3327 .16969 m
.33289 .17006 L
s
0 0 0 r
.004 w
.30385 .17005 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72074 .18657 m
.72126 .18888 L
s
.33325 .17171 m
.33325 .17294 L
s
.33291 .17509 m
.33325 .17171 L
s
0 0 0 r
.004 w
.74486 .1699 Mdot
1 .503 0 r
.01 w
[ .05 .05 ] 0 setdash
.61155 .16988 m
.61202 .16857 L
s
.61155 .16988 Mdot
1 .032 0 r
.3327 .16969 Mdot
.33246 .16923 m
.3327 .16969 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72344 .19215 m
.72392 .19135 L
s
.71965 .19023 m
.71998 .18547 L
s
1 .261 0 r
.01 w
.70354 .16945 Mdot
1 .262 0 r
[ .05 .05 ] 0 setdash
.70227 .16894 m
.70354 .16945 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53171 .32638 m
.5356 .30557 L
s
1 .032 0 r
.01 w
.33246 .16923 Mdot
[ .05 .05 ] 0 setdash
.33218 .16869 m
.33246 .16923 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70865 .2529 m
.70379 .16921 L
s
1 .235 0 r
.01 w
[ .05 .05 ] 0 setdash
.70379 .16921 m
.69997 .16757 L
s
.70379 .16921 Mdot
0 0 0 r
.004 w
.30552 .16917 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33325 .17294 m
.33313 .17489 L
s
1 .262 0 r
.01 w
.70227 .16894 Mdot
[ .05 .05 ] 0 setdash
.70113 .16846 m
.70227 .16894 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72126 .18888 m
.72183 .19105 L
s
.72294 .19259 m
.72344 .19215 L
s
1 .032 0 r
.01 w
.33218 .16869 Mdot
[ .05 .05 ] 0 setdash
.33192 .16812 m
.33218 .16869 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58555 .25566 m
.5869 .25563 L
s
1 .502 0 r
.01 w
[ .05 .05 ] 0 setdash
.61202 .16857 m
.61233 .16725 L
s
.61202 .16857 Mdot
1 .262 0 r
.70113 .16846 Mdot
.70027 .16807 m
.70113 .16846 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23523 .30529 m
.23324 .30966 L
s
0 0 0 r
.004 w
.30721 .1683 Mdot
1 .032 0 r
.01 w
.33192 .16812 Mdot
1 .033 0 r
[ .05 .05 ] 0 setdash
.33174 .16755 m
.33192 .16812 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70115 .18339 m
.70027 .16807 L
s
1 .262 0 r
.01 w
.70027 .16807 Mdot
[ .05 .05 ] 0 setdash
.69968 .16779 m
.70027 .16807 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72183 .19105 m
.72239 .19217 L
s
.72239 .19217 m
.72294 .19259 L
s
0 0 0 r
.004 w
.74097 .16789 Mdot
1 .262 0 r
.01 w
.69968 .16779 Mdot
[ .05 .05 ] 0 setdash
.69931 .1676 m
.69968 .16779 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33313 .17489 m
.33296 .17577 L
s
1 .265 0 r
.01 w
[ .05 .05 ] 0 setdash
.69817 .16767 m
.6983 .16767 L
s
.69817 .16767 Mdot
.69806 .16765 m
.69817 .16767 L
s
.6983 .16767 m
.69845 .16764 L
s
.6983 .16767 Mdot
.69806 .16765 Mdot
.69797 .16762 m
.69806 .16765 L
s
.69845 .16764 m
.69859 .1676 L
s
.69845 .16764 Mdot
.69797 .16762 Mdot
1 .266 0 r
.69795 .16759 m
.69797 .16762 L
s
1 .264 0 r
.69859 .1676 m
.69872 .16756 L
s
.69859 .1676 Mdot
1 .262 0 r
.69931 .1676 Mdot
1 .263 0 r
.6991 .16746 m
.69931 .1676 L
s
1 .266 0 r
.69795 .16759 Mdot
.69798 .16755 m
.69795 .16759 L
s
1 .235 0 r
.69997 .16757 m
.69628 .16626 L
s
.69997 .16757 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.69892 .17113 m
.69872 .16756 L
s
1 .264 0 r
.01 w
[ .05 .05 ] 0 setdash
.69872 .16756 m
.69882 .16752 L
s
.69872 .16756 Mdot
1 .266 0 r
.69798 .16755 Mdot
.69801 .16751 m
.69798 .16755 L
s
1 .033 0 r
.33174 .16755 Mdot
.3317 .16699 m
.33174 .16755 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33254 .17859 m
.33291 .17509 L
s
1 .264 0 r
.01 w
[ .05 .05 ] 0 setdash
.69882 .16752 m
.69889 .16746 L
s
.69882 .16752 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72626 .19635 m
.72577 .20133 L
s
1 .266 0 r
.01 w
.69801 .16751 Mdot
[ .05 .05 ] 0 setdash
.698 .16746 m
.69801 .16751 L
s
1 .263 0 r
.6991 .16746 Mdot
.699 .16739 m
.6991 .16746 L
s
1 .264 0 r
.69889 .16746 m
.69893 .16742 L
s
.69889 .16746 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.69815 .17004 m
.698 .16746 L
s
1 .266 0 r
.01 w
.698 .16746 Mdot
[ .05 .05 ] 0 setdash
.69789 .16738 m
.698 .16746 L
s
0 0 0 r
.004 w
.3089 .16744 Mdot
1 .263 0 r
.01 w
.69893 .16742 m
.69896 .16738 L
s
.69893 .16742 Mdot
.699 .16739 Mdot
.69897 .16736 m
.699 .16739 L
s
1 .266 0 r
.69789 .16738 Mdot
1 .267 0 r
.69765 .16728 m
.69789 .16738 L
s
1 .263 0 r
.69896 .16738 m
.69897 .16736 L
s
.69896 .16738 Mdot
.69897 .16736 Mdot
1 .267 0 r
.69765 .16728 Mdot
.69717 .1671 m
.69765 .16728 L
s
1 .502 0 r
.61233 .16725 m
.61251 .16592 L
s
.61233 .16725 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2372 .30182 m
.23523 .30529 L
s
.69903 .16782 m
.69922 .16961 L
s
.69901 .168 m
.69903 .16782 L
s
1 .267 0 r
.01 w
.69717 .1671 Mdot
[ .05 .05 ] 0 setdash
.6964 .16681 m
.69717 .1671 L
s
1 .033 0 r
.3317 .16699 Mdot
.3318 .16645 m
.3317 .16699 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33296 .17577 m
.33266 .1765 L
s
.699 .16821 m
.69901 .168 L
s
.699 .16851 m
.699 .16821 L
s
1 .267 0 r
.01 w
.6964 .16681 Mdot
[ .05 .05 ] 0 setdash
.6953 .1664 m
.6964 .16681 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69802 .16886 m
.69805 .16899 L
s
.69807 .16925 m
.69802 .16886 L
s
.69805 .16899 m
.69816 .16951 L
s
.699 .16934 m
.699 .16851 L
s
.30254 .20082 m
.30197 .19473 L
s
0 0 0 r
.004 w
.31061 .16659 Mdot
1 .033 0 r
.01 w
.3318 .16645 Mdot
[ .05 .05 ] 0 setdash
.33207 .16591 m
.3318 .16645 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33266 .1765 m
.33214 .1786 L
s
.69812 .16937 m
.69807 .16925 L
s
.69816 .16951 m
.69831 .17006 L
s
.3015 .19515 m
.29996 .20253 L
s
1 .267 0 r
.01 w
.6953 .1664 Mdot
[ .05 .05 ] 0 setdash
.69384 .16589 m
.6953 .1664 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69815 .17004 m
.69812 .16937 L
s
1 .234 0 r
.01 w
[ .05 .05 ] 0 setdash
.69628 .16626 m
.69217 .1646 L
s
.69628 .16626 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69899 .1704 m
.699 .16934 L
s
.5869 .25563 m
.58825 .25432 L
s
.69831 .17006 m
.69847 .17066 L
s
.69922 .16961 m
.69961 .17296 L
s
0 0 0 r
.004 w
.73715 .16597 Mdot
1 .502 0 r
.01 w
[ .05 .05 ] 0 setdash
.61251 .16592 m
.61261 .16459 L
s
.61251 .16592 Mdot
1 .033 0 r
.33207 .16591 Mdot
1 .034 0 r
.33251 .16538 m
.33207 .16591 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71912 .19573 m
.71965 .19023 L
s
1 .267 0 r
.01 w
.69384 .16589 Mdot
1 .268 0 r
[ .05 .05 ] 0 setdash
.69202 .16524 m
.69384 .16589 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69813 .17149 m
.69815 .17004 L
s
0 0 0 r
.004 w
.31232 .16574 Mdot
.53 .8 .95 r
.006 w
.69847 .17066 m
.69864 .17103 L
s
.69892 .17113 m
.69899 .1704 L
s
.69864 .17103 m
.6988 .17135 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.33152 .18131 m
.33251 .16538 L
s
1 .034 0 r
.01 w
.33251 .16538 Mdot
[ .05 .05 ] 0 setdash
.3331 .16488 m
.33251 .16538 L
s
1 .268 0 r
.69202 .16524 Mdot
.68995 .16451 m
.69202 .16524 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6988 .17135 m
.69892 .17113 L
s
.33214 .1786 m
.33136 .18236 L
s
.2389 .29869 m
.2372 .30182 L
s
.33217 .18162 m
.33254 .17859 L
s
0 0 0 r
.004 w
.31404 .1649 Mdot
1 .034 0 r
.01 w
.3331 .16488 Mdot
[ .05 .05 ] 0 setdash
.3338 .16442 m
.3331 .16488 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69803 .17404 m
.69813 .17149 L
s
1 .234 0 r
.01 w
[ .05 .05 ] 0 setdash
.69217 .1646 m
.68807 .16302 L
s
.69217 .1646 Mdot
1 .502 0 r
.61261 .16459 m
.61265 .1632 L
s
.61261 .16459 Mdot
1 .268 0 r
.68995 .16451 Mdot
.6874 .16355 m
.68995 .16451 L
s
1 .034 0 r
.3338 .16442 Mdot
.33454 .16401 m
.3338 .16442 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58825 .25432 m
.58959 .25136 L
s
0 0 0 r
.004 w
.73337 .16413 Mdot
.31576 .16406 Mdot
.53 .8 .95 r
.006 w
.69961 .17296 m
.70024 .17766 L
s
1 .034 0 r
.01 w
.33454 .16401 Mdot
[ .05 .05 ] 0 setdash
.33533 .16364 m
.33454 .16401 L
s
.33533 .16364 Mdot
1 .035 0 r
.33607 .16332 m
.33533 .16364 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72577 .20133 m
.72509 .20718 L
s
1 .268 0 r
.01 w
.6874 .16355 Mdot
[ .05 .05 ] 0 setdash
.68442 .16242 m
.6874 .16355 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58959 .25136 m
.59093 .2482 L
s
1 .035 0 r
.01 w
.33607 .16332 Mdot
[ .05 .05 ] 0 setdash
.33665 .1631 m
.33607 .16332 L
s
0 0 0 r
.004 w
.3175 .16323 Mdot
1 .502 0 r
.01 w
.61265 .1632 m
.6127 .16175 L
s
.61265 .1632 Mdot
1 .035 0 r
.33665 .1631 Mdot
.33707 .16295 m
.33665 .1631 L
s
1 .036 0 r
.3374 .16308 m
.33739 .16304 L
s
.3374 .16308 Mdot
.33757 .16305 m
.3374 .16308 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2411 .29457 m
.2389 .29869 L
s
1 .036 0 r
.01 w
.33757 .16305 Mdot
1 .037 0 r
[ .05 .05 ] 0 setdash
.338 .16291 m
.33757 .16305 L
s
1 .036 0 r
.33739 .16304 m
.33744 .16297 L
s
.33739 .16304 Mdot
1 .234 0 r
.68807 .16302 m
.68429 .16176 L
s
.68807 .16302 Mdot
1 .036 0 r
.33744 .16297 m
.33748 .16292 L
s
.33744 .16297 Mdot
1 .035 0 r
.33707 .16295 Mdot
.33732 .16289 m
.33707 .16295 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.33727 .1665 m
.33748 .16292 L
s
1 .036 0 r
.01 w
[ .05 .05 ] 0 setdash
.33748 .16292 m
.33745 .16288 L
s
.33748 .16292 Mdot
1 .037 0 r
.338 .16291 Mdot
.3387 .16264 m
.338 .16291 L
s
1 .035 0 r
.33732 .16289 Mdot
.33745 .16288 m
.33732 .16289 L
s
.33745 .16288 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33136 .18236 m
.33028 .18772 L
s
.6978 .17841 m
.69803 .17404 L
s
.59093 .2482 m
.5923 .24657 L
s
1 .037 0 r
.01 w
.3387 .16264 Mdot
[ .05 .05 ] 0 setdash
.33966 .16224 m
.3387 .16264 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30347 .20592 m
.30254 .20082 L
s
.33182 .18381 m
.33217 .18162 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6879 .22961 m
.68442 .16242 L
s
1 .268 0 r
.01 w
.68442 .16242 Mdot
[ .05 .05 ] 0 setdash
.68125 .16124 m
.68442 .16242 L
s
0 0 0 r
.004 w
.31924 .16241 Mdot
.72965 .16236 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3374 .16374 m
.33699 .16829 L
s
.33727 .1665 m
.3374 .16374 L
s
1 .037 0 r
.01 w
.33966 .16224 Mdot
[ .05 .05 ] 0 setdash
.34082 .16171 m
.33966 .16224 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3375 .16434 m
.33717 .16691 L
s
.3375 .17118 m
.3375 .16434 L
s
.29996 .20253 m
.29804 .21046 L
s
1 .234 0 r
.01 w
[ .05 .05 ] 0 setdash
.68429 .16176 m
.68023 .16023 L
s
.68429 .16176 Mdot
1 .501 0 r
.6127 .16175 m
.61277 .16028 L
s
.6127 .16175 Mdot
1 .037 0 r
.34082 .16171 Mdot
1 .038 0 r
.34241 .16099 m
.34082 .16171 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71836 .2013 m
.71912 .19573 L
s
0 0 0 r
.004 w
.321 .1616 Mdot
.53 .8 .95 r
.006 w
.24287 .29149 m
.2411 .29457 L
s
.70024 .17766 m
.70115 .18339 L
s
1 .268 0 r
.01 w
.68125 .16124 Mdot
1 .269 0 r
[ .05 .05 ] 0 setdash
.67812 .16012 m
.68125 .16124 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5096 .35634 m
.51503 .36112 L
s
1 .038 0 r
.01 w
.34241 .16099 Mdot
[ .05 .05 ] 0 setdash
.34406 .1602 m
.34241 .16099 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5923 .24657 m
.59373 .24463 L
s
0 0 0 r
.004 w
.32276 .16079 Mdot
.72596 .16067 Mdot
1 .468 0 r
.01 w
[ .05 .05 ] 0 setdash
.65962 .16065 m
.65951 .1606 L
s
.65962 .16065 Mdot
.65965 .16065 m
.65962 .16065 L
s
.65965 .16065 Mdot
.65961 .16058 m
.65965 .16065 L
s
.65951 .1606 m
.65934 .16047 L
s
.65951 .1606 Mdot
.65961 .16058 Mdot
1 .469 0 r
.6595 .16046 m
.65961 .16058 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33708 .16894 m
.33727 .1665 L
s
.33717 .16691 m
.33701 .16914 L
s
1 .468 0 r
.01 w
[ .05 .05 ] 0 setdash
.65934 .16047 m
.65911 .16028 L
s
.65934 .16047 Mdot
1 .469 0 r
.6595 .16046 Mdot
.6593 .16028 m
.6595 .16046 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3315 .18463 m
.33182 .18381 L
s
.65967 .16113 m
.65973 .16308 L
s
.65971 .16272 m
.65967 .16113 L
s
1 .501 0 r
.01 w
[ .05 .05 ] 0 setdash
.61277 .16028 m
.61288 .15885 L
s
.61277 .16028 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65945 .16803 m
.65911 .16028 L
s
1 .467 0 r
.01 w
[ .05 .05 ] 0 setdash
.65911 .16028 m
.65883 .16003 L
s
.65911 .16028 Mdot
1 .469 0 r
.6593 .16028 Mdot
.65904 .16003 m
.6593 .16028 L
s
1 .233 0 r
.68023 .16023 m
.67595 .15849 L
s
.68023 .16023 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.34137 .20603 m
.34406 .1602 L
s
1 .038 0 r
.01 w
.34406 .1602 Mdot
[ .05 .05 ] 0 setdash
.34597 .15928 m
.34406 .1602 L
s
1 .269 0 r
.67812 .16012 Mdot
.67431 .15856 m
.67812 .16012 L
s
1 .469 0 r
.65904 .16003 Mdot
.65871 .15971 m
.65904 .16003 L
s
1 .467 0 r
.65883 .16003 m
.65852 .15974 L
s
.65883 .16003 Mdot
0 0 0 r
.004 w
.32453 .16 Mdot
1 .467 0 r
.01 w
.65852 .15974 m
.65818 .15945 L
s
.65852 .15974 Mdot
1 .469 0 r
.65871 .15971 Mdot
1 .47 0 r
.6583 .15932 m
.65871 .15971 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33028 .18772 m
.32893 .19381 L
s
.69736 .18411 m
.6978 .17841 L
s
.52795 .3409 m
.53171 .32638 L
s
1 .467 0 r
.01 w
[ .05 .05 ] 0 setdash
.65818 .15945 m
.65782 .15917 L
s
.65818 .15945 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24489 .28943 m
.24287 .29149 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65896 .17443 m
.6583 .15932 L
s
1 .47 0 r
.01 w
.6583 .15932 Mdot
[ .05 .05 ] 0 setdash
.65778 .15883 m
.6583 .15932 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59373 .24463 m
.59522 .24389 L
s
.33699 .16829 m
.33642 .17374 L
s
1 .038 0 r
.01 w
.34597 .15928 Mdot
[ .05 .05 ] 0 setdash
.34786 .15836 m
.34597 .15928 L
s
0 0 0 r
.004 w
.32631 .1592 Mdot
1 .467 0 r
.01 w
.65782 .15917 m
.65745 .15891 L
s
.65782 .15917 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6597 .16499 m
.65971 .16272 L
s
.33118 .18471 m
.3315 .18463 L
s
.65973 .16308 m
.65972 .16519 L
s
0 0 0 r
.004 w
.72233 .15904 Mdot
.53 .8 .95 r
.006 w
.33701 .16914 m
.33708 .16894 L
s
.30459 .21095 m
.30347 .20592 L
s
1 .466 0 r
.01 w
[ .05 .05 ] 0 setdash
.65745 .15891 m
.65703 .15866 L
s
.65745 .15891 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72509 .20718 m
.72415 .21311 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61406 .20005 m
.61288 .15885 L
s
1 .501 0 r
.01 w
[ .05 .05 ] 0 setdash
.61288 .15885 m
.61297 .15749 L
s
.61288 .15885 Mdot
1 .47 0 r
.65778 .15883 Mdot
.65718 .15828 m
.65778 .15883 L
s
1 .466 0 r
.65703 .15866 m
.65655 .15839 L
s
.65703 .15866 Mdot
1 .269 0 r
.67431 .15856 Mdot
.67057 .1571 m
.67431 .15856 L
s
1 .233 0 r
.67595 .15849 m
.67217 .15719 L
s
.67595 .15849 Mdot
0 0 0 r
.004 w
.32809 .15842 Mdot
1 .466 0 r
.01 w
.65655 .15839 m
.65599 .15811 L
s
.65655 .15839 Mdot
1 .038 0 r
.34786 .15836 Mdot
.34978 .15743 m
.34786 .15836 L
s
1 .47 0 r
.65718 .15828 Mdot
.65651 .1577 m
.65718 .15828 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33092 .18411 m
.33118 .18471 L
s
1 .466 0 r
.01 w
[ .05 .05 ] 0 setdash
.65599 .15811 m
.65535 .15778 L
s
.65599 .15811 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70115 .18339 m
.70234 .18971 L
s
.29804 .21046 m
.29588 .21875 L
s
1 .466 0 r
.01 w
[ .05 .05 ] 0 setdash
.65535 .15778 m
.6547 .15743 L
s
.65535 .15778 Mdot
1 .47 0 r
.65651 .1577 Mdot
.65583 .15714 m
.65651 .1577 L
s
0 0 0 r
.004 w
.32989 .15764 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33077 .18307 m
.33092 .18411 L
s
.65972 .16519 m
.65961 .16675 L
s
1 .501 0 r
.01 w
[ .05 .05 ] 0 setdash
.61297 .15749 m
.61306 .15626 L
s
.61297 .15749 Mdot
0 0 0 r
.004 w
.71873 .15748 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65961 .16732 m
.6597 .16499 L
s
.33769 .17945 m
.3375 .17118 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65539 .17383 m
.6547 .15743 L
s
1 .465 0 r
.01 w
[ .05 .05 ] 0 setdash
.6547 .15743 m
.65395 .15703 L
s
.6547 .15743 Mdot
1 .038 0 r
.34978 .15743 Mdot
1 .039 0 r
.35151 .15656 m
.34978 .15743 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37365 .15901 m
.37373 .15735 L
s
1 .187 0 r
.01 w
[ .05 .05 ] 0 setdash
.37373 .15735 m
.37379 .15734 L
s
.37373 .15735 Mdot
.37373 .15722 m
.37373 .15735 L
s
1 .186 0 r
.37379 .15734 m
.37388 .15721 L
s
.37379 .15734 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33076 .18191 m
.33077 .18307 L
s
.71732 .20634 m
.71836 .2013 L
s
1 .187 0 r
.01 w
.37373 .15722 Mdot
[ .05 .05 ] 0 setdash
.3738 .15696 m
.37373 .15722 L
s
1 .186 0 r
.37388 .15721 m
.37399 .15695 L
s
.37388 .15721 Mdot
1 .233 0 r
.67217 .15719 m
.66817 .15563 L
s
.67217 .15719 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33089 .18101 m
.33076 .18191 L
s
1 .47 0 r
.01 w
.65583 .15714 Mdot
1 .471 0 r
[ .05 .05 ] 0 setdash
.65511 .15656 m
.65583 .15714 L
s
1 .269 0 r
.67057 .1571 Mdot
.66723 .15581 m
.67057 .1571 L
s
1 .465 0 r
.65395 .15703 m
.65309 .15657 L
s
.65395 .15703 Mdot
1 .187 0 r
.3738 .15696 Mdot
.37395 .15657 m
.3738 .15696 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59522 .24389 m
.59681 .24434 L
s
1 .186 0 r
.01 w
[ .05 .05 ] 0 setdash
.37399 .15695 m
.37415 .1566 L
s
.37399 .15695 Mdot
0 0 0 r
.004 w
.33169 .15687 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33116 .18045 m
.33089 .18101 L
s
1 .186 0 r
.01 w
[ .05 .05 ] 0 setdash
.37415 .1566 m
.37435 .1562 L
s
.37415 .1566 Mdot
1 .465 0 r
.65309 .15657 m
.65222 .15603 L
s
.65309 .15657 Mdot
1 .187 0 r
.37395 .15657 Mdot
.37419 .1561 m
.37395 .15657 L
s
1 .471 0 r
.65511 .15656 Mdot
.65443 .15605 m
.65511 .15656 L
s
1 .039 0 r
.35151 .15656 Mdot
.35307 .15574 m
.35151 .15656 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24664 .28798 m
.24489 .28943 L
s
.33152 .18131 m
.33116 .18045 L
s
.65961 .16675 m
.65945 .16803 L
s
1 .501 0 r
.01 w
[ .05 .05 ] 0 setdash
.61306 .15626 m
.61313 .15514 L
s
.61306 .15626 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32893 .19381 m
.32742 .19974 L
s
.37365 .15901 m
.37358 .16162 L
s
.37355 .16086 m
.37365 .15901 L
s
1 .185 0 r
.01 w
[ .05 .05 ] 0 setdash
.37435 .1562 m
.37464 .15576 L
s
.37435 .1562 Mdot
0 0 0 r
.004 w
.3335 .15611 Mdot
1 .187 0 r
.01 w
.37419 .1561 Mdot
1 .188 0 r
.37448 .15557 m
.37419 .1561 L
s
1 .471 0 r
.65443 .15605 Mdot
.65381 .1556 m
.65443 .15605 L
s
1 .465 0 r
.65222 .15603 m
.65128 .15545 L
s
.65222 .15603 Mdot
0 0 0 r
.004 w
.71517 .15597 Mdot
1 .269 0 r
.01 w
.66723 .15581 Mdot
1 .27 0 r
.66307 .15412 m
.66723 .15581 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33642 .17374 m
.3357 .17869 L
s
1 .185 0 r
.01 w
[ .05 .05 ] 0 setdash
.37464 .15576 m
.37508 .15527 L
s
.37464 .15576 Mdot
1 .039 0 r
.35307 .15574 Mdot
.35432 .15505 m
.35307 .15574 L
s
1 .233 0 r
.66817 .15563 m
.66429 .15424 L
s
.66817 .15563 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65947 .16977 m
.65961 .16732 L
s
1 .471 0 r
.01 w
.65381 .1556 Mdot
[ .05 .05 ] 0 setdash
.65324 .15522 m
.65381 .1556 L
s
1 .188 0 r
.37448 .15557 Mdot
.37481 .15505 m
.37448 .15557 L
s
1 .464 0 r
.65128 .15545 m
.65033 .15492 L
s
.65128 .15545 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.306 .21444 m
.30459 .21095 L
s
.69665 .19084 m
.69736 .18411 L
s
0 0 0 r
.004 w
.33532 .15535 Mdot
1 .185 0 r
.01 w
[ .05 .05 ] 0 setdash
.37508 .15527 m
.37574 .15471 L
s
.37508 .15527 Mdot
1 .471 0 r
.65324 .15522 Mdot
.65271 .15487 m
.65324 .15522 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65945 .16803 m
.65922 .1689 L
s
1 .5 0 r
.01 w
[ .05 .05 ] 0 setdash
.61313 .15514 m
.61322 .1542 L
s
.61313 .15514 Mdot
1 .188 0 r
.37481 .15505 Mdot
.37515 .15453 m
.37481 .15505 L
s
1 .039 0 r
.35432 .15505 Mdot
.35541 .15443 m
.35432 .15505 L
s
1 .464 0 r
.65033 .15492 m
.64936 .15437 L
s
.65033 .15492 Mdot
1 .471 0 r
.65271 .15487 Mdot
1 .472 0 r
.65226 .15457 m
.65271 .15487 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33199 .18277 m
.33152 .18131 L
s
.37344 .16441 m
.37355 .16086 L
s
1 .185 0 r
.01 w
[ .05 .05 ] 0 setdash
.37574 .15471 m
.3767 .15408 L
s
.37574 .15471 Mdot
0 0 0 r
.004 w
.33715 .1546 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6527 .16515 m
.65226 .15457 L
s
1 .472 0 r
.01 w
.65226 .15457 Mdot
[ .05 .05 ] 0 setdash
.65189 .15434 m
.65226 .15457 L
s
1 .188 0 r
.37515 .15453 Mdot
.37552 .15402 m
.37515 .15453 L
s
0 0 0 r
.004 w
.71164 .15452 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37358 .16162 m
.37353 .1642 L
s
.70234 .18971 m
.70384 .19631 L
s
1 .039 0 r
.01 w
.35541 .15443 Mdot
[ .05 .05 ] 0 setdash
.35624 .15394 m
.35541 .15443 L
s
1 .464 0 r
.64936 .15437 m
.64833 .15378 L
s
.64936 .15437 Mdot
1 .472 0 r
.65189 .15434 Mdot
.65161 .15417 m
.65189 .15434 L
s
1 .043 0 r
.35466 .1543 m
.35486 .15424 L
s
.35466 .1543 Mdot
.35471 .15426 m
.35466 .1543 L
s
.35471 .15426 Mdot
.35509 .15411 m
.35471 .15426 L
s
1 .473 0 r
.65144 .15425 m
.6515 .15421 L
s
.65144 .15425 Mdot
.65123 .15424 m
.65144 .15425 L
s
.65123 .15424 Mdot
1 .474 0 r
.65079 .15418 m
.65123 .15424 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.66814 .2389 m
.66429 .15424 L
s
1 .233 0 r
.01 w
[ .05 .05 ] 0 setdash
.66429 .15424 m
.66042 .15282 L
s
.66429 .15424 Mdot
1 .043 0 r
.35486 .15424 m
.35519 .15412 L
s
.35486 .15424 Mdot
1 .473 0 r
.6515 .15421 m
.65149 .15414 L
s
.6515 .15421 Mdot
1 .5 0 r
.61322 .1542 m
.61329 .15342 L
s
.61322 .1542 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65113 .16257 m
.65079 .15418 L
s
1 .474 0 r
.01 w
.65079 .15418 Mdot
[ .05 .05 ] 0 setdash
.65004 .15406 m
.65079 .15418 L
s
1 .472 0 r
.65161 .15417 Mdot
.65144 .15408 m
.65161 .15417 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65922 .1689 m
.65894 .16935 L
s
1 .473 0 r
.01 w
[ .05 .05 ] 0 setdash
.65149 .15414 m
.65144 .15408 L
s
.65149 .15414 Mdot
1 .043 0 r
.35519 .15412 m
.35558 .15399 L
s
.35519 .15412 Mdot
1 .27 0 r
.66307 .15412 Mdot
.65948 .15263 m
.66307 .15412 L
s
1 .043 0 r
.35509 .15411 Mdot
1 .044 0 r
.35581 .15386 m
.35509 .15411 L
s
1 .472 0 r
.65144 .15408 Mdot
.6514 .15406 m
.65144 .15408 L
s
1 .185 0 r
.3767 .15408 m
.37797 .15338 L
s
.3767 .15408 Mdot
1 .473 0 r
.65144 .15408 m
.6514 .15406 L
s
.65144 .15408 Mdot
1 .089 0 r
.62469 .15406 m
.62782 .15405 L
s
.62469 .15406 Mdot
.62138 .154 m
.62469 .15406 L
s
1 .474 0 r
.65004 .15406 Mdot
.64902 .15388 m
.65004 .15406 L
s
1 .472 0 r
.6514 .15406 Mdot
1 .088 0 r
.62782 .15405 m
.6308 .15394 L
s
.62782 .15405 Mdot
1 .188 0 r
.37552 .15402 Mdot
.37588 .1535 m
.37552 .15402 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35469 .15462 m
.35438 .15939 L
s
.35472 .16091 m
.35469 .15462 L
s
1 .089 0 r
.01 w
.62138 .154 Mdot
[ .05 .05 ] 0 setdash
.61827 .15369 m
.62138 .154 L
s
1 .042 0 r
.35558 .15399 m
.35599 .15384 L
s
.35558 .15399 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52384 .35182 m
.52795 .3409 L
s
1 .039 0 r
.01 w
.35624 .15394 Mdot
1 .04 0 r
[ .05 .05 ] 0 setdash
.35682 .15358 m
.35624 .15394 L
s
1 .088 0 r
.6308 .15394 m
.6335 .15374 L
s
.6308 .15394 Mdot
1 .474 0 r
.64902 .15388 Mdot
.64772 .15367 m
.64902 .15388 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72415 .21311 m
.7229 .21937 L
s
1 .044 0 r
.01 w
.35581 .15386 Mdot
[ .05 .05 ] 0 setdash
.35683 .15351 m
.35581 .15386 L
s
0 0 0 r
.004 w
.33898 .15386 Mdot
1 .042 0 r
.01 w
.35599 .15384 m
.35638 .15371 L
s
.35599 .15384 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59681 .24434 m
.59847 .24484 L
s
1 .464 0 r
.01 w
[ .05 .05 ] 0 setdash
.64833 .15378 m
.64738 .15326 L
s
.64833 .15378 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63532 .20509 m
.6335 .15374 L
s
1 .088 0 r
.01 w
[ .05 .05 ] 0 setdash
.6335 .15374 m
.63594 .15351 L
s
.6335 .15374 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35608 .15921 m
.35638 .15371 L
s
1 .042 0 r
.01 w
[ .05 .05 ] 0 setdash
.35638 .15371 m
.35668 .1536 L
s
.35638 .15371 Mdot
1 .089 0 r
.61827 .15369 Mdot
.61499 .15333 m
.61827 .15369 L
s
1 .474 0 r
.64772 .15367 Mdot
1 .475 0 r
.64625 .15342 m
.64772 .15367 L
s
1 .042 0 r
.35668 .1536 m
.35689 .15353 L
s
.35668 .1536 Mdot
1 .04 0 r
.35682 .15358 Mdot
.35718 .15335 m
.35682 .15358 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65926 .17233 m
.65947 .16977 L
s
.24859 .28539 m
.24664 .28798 L
s
1 .042 0 r
.01 w
[ .05 .05 ] 0 setdash
.35689 .15353 m
.35707 .15346 L
s
.35689 .15353 Mdot
1 .088 0 r
.63594 .15351 m
.6384 .15314 L
s
.63594 .15351 Mdot
1 .044 0 r
.35683 .15351 Mdot
.35831 .15302 m
.35683 .15351 L
s
1 .188 0 r
.37588 .1535 Mdot
1 .189 0 r
.37623 .15299 m
.37588 .1535 L
s
1 .041 0 r
.35707 .15346 m
.35722 .1534 L
s
.35707 .15346 Mdot
1 .5 0 r
.61329 .15342 m
.61335 .15283 L
s
.61329 .15342 Mdot
1 .475 0 r
.64625 .15342 Mdot
.64455 .15305 m
.64625 .15342 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65149 .1555 m
.65159 .15623 L
s
.65139 .15805 m
.65149 .1555 L
s
1 .041 0 r
.01 w
[ .05 .05 ] 0 setdash
.35722 .1534 m
.35734 .15333 L
s
.35722 .1534 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37642 .18583 m
.37797 .15338 L
s
1 .184 0 r
.01 w
[ .05 .05 ] 0 setdash
.37797 .15338 m
.37952 .15262 L
s
.37797 .15338 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65894 .16935 m
.65862 .16956 L
s
.51503 .36112 m
.51949 .3584 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.3569 .15861 m
.35718 .15335 L
s
1 .04 0 r
.01 w
.35718 .15335 Mdot
[ .05 .05 ] 0 setdash
.35738 .15323 m
.35718 .15335 L
s
1 .089 0 r
.61499 .15333 Mdot
.61192 .15273 m
.61499 .15333 L
s
1 .041 0 r
.35734 .15333 m
.35743 .15325 L
s
.35734 .15333 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65145 .15518 m
.65155 .15676 L
s
.65153 .15615 m
.65145 .15518 L
s
1 .464 0 r
.01 w
[ .05 .05 ] 0 setdash
.64738 .15326 m
.64642 .15272 L
s
.64738 .15326 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29588 .21875 m
.29336 .22636 L
s
1 .041 0 r
.01 w
[ .05 .05 ] 0 setdash
.35743 .15325 m
.35748 .1532 L
s
.35743 .15325 Mdot
1 .04 0 r
.35738 .15323 Mdot
.35746 .15319 m
.35738 .15323 L
s
.35748 .1532 m
.35746 .15319 L
s
.35748 .1532 Mdot
.35746 .15319 Mdot
1 .088 0 r
.6384 .15314 m
.64027 .15283 L
s
.6384 .15314 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32742 .19974 m
.32584 .20486 L
s
0 0 0 r
.004 w
.34083 .15312 Mdot
.70815 .15311 Mdot
.53 .8 .95 r
.006 w
.71613 .21107 m
.71732 .20634 L
s
.33258 .18414 m
.33199 .18277 L
s
1 .475 0 r
.01 w
.64455 .15305 Mdot
[ .05 .05 ] 0 setdash
.64245 .15277 m
.64455 .15305 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35654 .18566 m
.35831 .15302 L
s
1 .044 0 r
.01 w
.35831 .15302 Mdot
[ .05 .05 ] 0 setdash
.35998 .15246 m
.35831 .15302 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37551 .16773 m
.37623 .15299 L
s
1 .189 0 r
.01 w
.37623 .15299 Mdot
[ .05 .05 ] 0 setdash
.37653 .15253 m
.37623 .15299 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30779 .21742 m
.306 .21444 L
s
.65159 .15623 m
.6516 .15676 L
s
.35743 .15371 m
.35726 .15535 L
s
.3574 .15467 m
.35743 .15371 L
s
1 .087 0 r
.01 w
[ .05 .05 ] 0 setdash
.64027 .15283 m
.64178 .15254 L
s
.64027 .15283 Mdot
1 .5 0 r
.61335 .15283 m
.61341 .15239 L
s
.61335 .15283 Mdot
1 .232 0 r
.66042 .15282 m
.65635 .15131 L
s
.66042 .15282 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3357 .17869 m
.33489 .18262 L
s
1 .475 0 r
.01 w
.64245 .15277 Mdot
[ .05 .05 ] 0 setdash
.64025 .15241 m
.64245 .15277 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65862 .16956 m
.65828 .16974 L
s
1 .089 0 r
.01 w
.61192 .15273 Mdot
1 .09 0 r
[ .05 .05 ] 0 setdash
.60906 .15209 m
.61192 .15273 L
s
1 .463 0 r
.64642 .15272 m
.64558 .15224 L
s
.64642 .15272 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6516 .15676 m
.65153 .15615 L
s
1 .27 0 r
.01 w
.65948 .15263 Mdot
[ .05 .05 ] 0 setdash
.65596 .15131 m
.65948 .15263 L
s
1 .184 0 r
.37952 .15262 m
.3814 .15181 L
s
.37952 .15262 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37353 .1642 m
.37355 .166 L
s
1 .087 0 r
.01 w
[ .05 .05 ] 0 setdash
.64178 .15254 m
.64311 .1522 L
s
.64178 .15254 Mdot
1 .189 0 r
.37653 .15253 Mdot
.37676 .15211 m
.37653 .15253 L
s
1 .044 0 r
.35998 .15246 Mdot
.36186 .15185 m
.35998 .15246 L
s
1 .475 0 r
.64025 .15241 Mdot
.63788 .15197 m
.64025 .15241 L
s
0 0 0 r
.004 w
.34268 .1524 Mdot
1 .499 0 r
.01 w
.61341 .15239 m
.61354 .15208 L
s
.61341 .15239 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65155 .15676 m
.65183 .15955 L
s
.35712 .15513 m
.35723 .15527 L
s
.35697 .15534 m
.35712 .15513 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.64638 .17261 m
.64558 .15224 L
s
1 .463 0 r
.01 w
[ .05 .05 ] 0 setdash
.64558 .15224 m
.64484 .15178 L
s
.64558 .15224 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35732 .15525 m
.3574 .15467 L
s
.35676 .15606 m
.35697 .15534 L
s
1 .087 0 r
.01 w
[ .05 .05 ] 0 setdash
.64311 .1522 m
.64403 .15188 L
s
.64311 .1522 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65828 .16974 m
.65795 .1704 L
s
1 .189 0 r
.01 w
.37676 .15211 Mdot
[ .05 .05 ] 0 setdash
.3769 .15175 m
.37676 .15211 L
s
1 .09 0 r
.60906 .15209 Mdot
.60626 .15116 m
.60906 .15209 L
s
1 .499 0 r
.61354 .15208 m
.61378 .15186 L
s
.61354 .15208 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35723 .15527 m
.35732 .15525 L
s
.37339 .16791 m
.37344 .16441 L
s
1 .475 0 r
.01 w
.63788 .15197 Mdot
1 .476 0 r
[ .05 .05 ] 0 setdash
.63547 .15147 m
.63788 .15197 L
s
1 .087 0 r
.64403 .15188 m
.64464 .15156 L
s
.64403 .15188 Mdot
1 .499 0 r
.61378 .15186 m
.61415 .15167 L
s
.61378 .15186 Mdot
1 .044 0 r
.36186 .15185 Mdot
1 .045 0 r
.3643 .15103 m
.36186 .15185 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35647 .1573 m
.35676 .15606 L
s
.35726 .15535 m
.3569 .15861 L
s
1 .184 0 r
.01 w
[ .05 .05 ] 0 setdash
.3814 .15181 m
.38348 .15101 L
s
.3814 .15181 Mdot
1 .463 0 r
.64484 .15178 m
.64423 .15142 L
s
.64484 .15178 Mdot
0 0 0 r
.004 w
.70469 .15176 Mdot
1 .189 0 r
.01 w
.3769 .15175 Mdot
.37694 .15145 m
.3769 .15175 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65113 .16257 m
.65139 .15805 L
s
0 0 0 r
.004 w
.34454 .15167 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61439 .15963 m
.61415 .15167 L
s
1 .499 0 r
.01 w
[ .05 .05 ] 0 setdash
.61415 .15167 m
.6147 .1515 L
s
.61415 .15167 Mdot
1 .087 0 r
.64464 .15156 m
.645 .15124 L
s
.64464 .15156 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33812 .18785 m
.33769 .17945 L
s
1 .499 0 r
.01 w
[ .05 .05 ] 0 setdash
.6147 .1515 m
.61543 .15128 L
s
.6147 .1515 Mdot
1 .476 0 r
.63547 .15147 Mdot
.63299 .15092 m
.63547 .15147 L
s
1 .189 0 r
.37694 .15145 Mdot
1 .19 0 r
.37685 .15117 m
.37694 .15145 L
s
1 .463 0 r
.64423 .15142 m
.64371 .15109 L
s
.64423 .15142 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33325 .1848 m
.33258 .18414 L
s
.65896 .17443 m
.65926 .17233 L
s
1 .27 0 r
.01 w
.65596 .15131 Mdot
[ .05 .05 ] 0 setdash
.65263 .14996 m
.65596 .15131 L
s
1 .232 0 r
.65635 .15131 m
.65251 .14998 L
s
.65635 .15131 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65795 .1704 m
.65756 .17078 L
s
1 .498 0 r
.01 w
[ .05 .05 ] 0 setdash
.61543 .15128 m
.61633 .15099 L
s
.61543 .15128 Mdot
1 .086 0 r
.645 .15124 m
.64514 .15092 L
s
.645 .15124 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25076 .28169 m
.24859 .28539 L
s
1 .19 0 r
.01 w
.37685 .15117 Mdot
[ .05 .05 ] 0 setdash
.37665 .15089 m
.37685 .15117 L
s
1 .09 0 r
.60626 .15116 Mdot
.60369 .15013 m
.60626 .15116 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35608 .15921 m
.35647 .1573 L
s
1 .463 0 r
.01 w
[ .05 .05 ] 0 setdash
.64371 .15109 m
.64333 .15089 L
s
.64371 .15109 Mdot
1 .045 0 r
.3643 .15103 Mdot
.36674 .15021 m
.3643 .15103 L
s
1 .184 0 r
.38348 .15101 m
.38603 .15014 L
s
.38348 .15101 Mdot
1 .498 0 r
.61633 .15099 m
.61736 .1506 L
s
.61633 .15099 Mdot
1 .46 0 r
.6424 .15098 m
.64242 .15098 L
s
.6424 .15098 Mdot
.6424 .15098 m
.6424 .15098 L
s
.6424 .15098 Mdot
.64242 .15097 m
.6424 .15098 L
s
1 .459 0 r
.64242 .15098 m
.64245 .15097 L
s
.64242 .15098 Mdot
.64245 .15097 m
.64251 .15096 L
s
.64245 .15097 Mdot
1 .46 0 r
.64242 .15097 Mdot
.64246 .15096 m
.64242 .15097 L
s
0 0 0 r
.004 w
.34641 .15096 Mdot
1 .46 0 r
.01 w
.64246 .15096 Mdot
.64249 .15093 m
.64246 .15096 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64259 .15312 m
.64251 .15096 L
s
1 .459 0 r
.01 w
[ .05 .05 ] 0 setdash
.64251 .15096 m
.64259 .15093 L
s
.64251 .15096 Mdot
.64259 .15093 m
.6427 .15091 L
s
.64259 .15093 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37355 .166 m
.37363 .16723 L
s
1 .46 0 r
.01 w
.64249 .15093 Mdot
1 .461 0 r
[ .05 .05 ] 0 setdash
.64252 .15089 m
.64249 .15093 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70384 .19631 m
.70546 .20252 L
s
1 .086 0 r
.01 w
[ .05 .05 ] 0 setdash
.64514 .15092 m
.64508 .1506 L
s
.64514 .15092 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63474 .20056 m
.63299 .15092 L
s
1 .476 0 r
.01 w
.63299 .15092 Mdot
[ .05 .05 ] 0 setdash
.63081 .15028 m
.63299 .15092 L
s
1 .459 0 r
.6427 .15091 m
.64282 .15088 L
s
.6427 .15091 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35438 .15939 m
.35443 .16202 L
s
1 .19 0 r
.01 w
.37665 .15089 Mdot
[ .05 .05 ] 0 setdash
.37635 .15061 m
.37665 .15089 L
s
1 .461 0 r
.64252 .15089 Mdot
.64254 .15083 m
.64252 .15089 L
s
1 .462 0 r
.64333 .15089 m
.64304 .15071 L
s
.64333 .15089 Mdot
1 .458 0 r
.64282 .15088 m
.64292 .15085 L
s
.64282 .15088 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51949 .3584 m
.52384 .35182 L
s
1 .458 0 r
.01 w
[ .05 .05 ] 0 setdash
.64292 .15085 m
.64299 .15082 L
s
.64292 .15085 Mdot
1 .461 0 r
.64254 .15083 Mdot
.64258 .15077 m
.64254 .15083 L
s
1 .456 0 r
.64255 .15083 m
.64256 .15082 L
s
.64255 .15083 Mdot
.64256 .15082 m
.64255 .15083 L
s
1 .458 0 r
.64299 .15082 m
.64301 .1508 L
s
.64299 .15082 Mdot
1 .456 0 r
.64256 .15082 Mdot
.64259 .15081 m
.64256 .15082 L
s
.64256 .15082 m
.64261 .15081 L
s
.64256 .15082 Mdot
.64259 .15081 Mdot
1 .457 0 r
.64264 .15081 m
.64259 .15081 L
s
1 .455 0 r
.64261 .15081 m
.64269 .15079 L
s
.64261 .15081 Mdot
1 .457 0 r
.64264 .15081 Mdot
.6427 .1508 m
.64264 .15081 L
s
1 .458 0 r
.64301 .1508 m
.64299 .15079 L
s
.64301 .1508 Mdot
1 .457 0 r
.6427 .1508 Mdot
.64277 .15079 m
.6427 .1508 L
s
1 .455 0 r
.64269 .15079 m
.64282 .15077 L
s
.64269 .15079 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64283 .15232 m
.64277 .15079 L
s
1 .457 0 r
.01 w
.64277 .15079 Mdot
[ .05 .05 ] 0 setdash
.64285 .15079 m
.64277 .15079 L
s
1 .458 0 r
.64299 .15079 m
.64293 .15078 L
s
.64299 .15079 Mdot
1 .457 0 r
.64285 .15079 Mdot
.64293 .15078 m
.64285 .15079 L
s
.64293 .15078 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64264 .15239 m
.64258 .15077 L
s
1 .461 0 r
.01 w
.64258 .15077 Mdot
[ .05 .05 ] 0 setdash
.64262 .15072 m
.64258 .15077 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64241 .15129 m
.64245 .15195 L
s
.64242 .15141 m
.64241 .15129 L
s
1 .455 0 r
.01 w
[ .05 .05 ] 0 setdash
.64282 .15077 m
.64298 .15074 L
s
.64282 .15077 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64311 .15432 m
.64298 .15074 L
s
1 .455 0 r
.01 w
[ .05 .05 ] 0 setdash
.64298 .15074 m
.64316 .1507 L
s
.64298 .15074 Mdot
1 .461 0 r
.64262 .15072 Mdot
1 .462 0 r
.64268 .15066 m
.64262 .15072 L
s
.64304 .15071 m
.64286 .15063 L
s
.64304 .15071 Mdot
1 .455 0 r
.64316 .1507 m
.64336 .15066 L
s
.64316 .1507 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64246 .15209 m
.64242 .15141 L
s
.64256 .15106 m
.64258 .15149 L
s
.64259 .15155 m
.64256 .15106 L
s
1 .462 0 r
.01 w
.64268 .15066 Mdot
[ .05 .05 ] 0 setdash
.64275 .15063 m
.64268 .15066 L
s
1 .454 0 r
.64336 .15066 m
.64355 .15061 L
s
.64336 .15066 Mdot
1 .462 0 r
.64286 .15063 m
.64275 .15063 L
s
.64286 .15063 Mdot
.64275 .15063 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59847 .24484 m
.60021 .24611 L
s
1 .19 0 r
.01 w
.37635 .15061 Mdot
[ .05 .05 ] 0 setdash
.376 .15034 m
.37635 .15061 L
s
1 .454 0 r
.64355 .15061 m
.64374 .15056 L
s
.64355 .15061 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65756 .17078 m
.6571 .17131 L
s
1 .498 0 r
.01 w
[ .05 .05 ] 0 setdash
.61736 .1506 m
.61848 .1501 L
s
.61736 .1506 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64547 .16055 m
.64508 .1506 L
s
1 .086 0 r
.01 w
[ .05 .05 ] 0 setdash
.64508 .1506 m
.64486 .15024 L
s
.64508 .1506 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65183 .15955 m
.65222 .16238 L
s
.64302 .15113 m
.64303 .15181 L
s
.64301 .15157 m
.64302 .15113 L
s
1 .454 0 r
.01 w
[ .05 .05 ] 0 setdash
.64374 .15056 m
.6439 .15052 L
s
.64374 .15056 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33489 .18262 m
.33408 .18393 L
s
.30981 .21949 m
.30779 .21742 L
s
1 .454 0 r
.01 w
[ .05 .05 ] 0 setdash
.6439 .15052 m
.64403 .15047 L
s
.6439 .15052 Mdot
.64403 .15047 m
.64414 .15042 L
s
.64403 .15047 Mdot
0 0 0 r
.004 w
.70126 .15046 Mdot
1 .453 0 r
.01 w
.64414 .15042 m
.64423 .15038 L
s
.64414 .15042 Mdot
1 .451 0 r
.64449 .15042 m
.64448 .15042 L
s
.64449 .15042 Mdot
.64448 .15041 m
.64449 .15042 L
s
.64448 .15042 m
.64442 .15039 L
s
.64448 .15042 Mdot
.64448 .15041 Mdot
.64444 .15039 m
.64448 .15041 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64447 .15153 m
.64442 .15039 L
s
1 .451 0 r
.01 w
[ .05 .05 ] 0 setdash
.64442 .15039 m
.64431 .15034 L
s
.64442 .15039 Mdot
.64444 .15039 Mdot
1 .452 0 r
.64441 .15036 m
.64444 .15039 L
s
1 .453 0 r
.64423 .15038 m
.64431 .15035 L
s
.64423 .15038 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64258 .15149 m
.64266 .15226 L
s
1 .452 0 r
.01 w
.64441 .15036 Mdot
[ .05 .05 ] 0 setdash
.6444 .15034 m
.64441 .15036 L
s
1 .453 0 r
.64431 .15035 m
.64437 .15033 L
s
.64431 .15035 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32584 .20486 m
.32423 .20871 L
s
1 .45 0 r
.01 w
[ .05 .05 ] 0 setdash
.64431 .15034 m
.64414 .15025 L
s
.64431 .15034 Mdot
1 .19 0 r
.376 .15034 Mdot
1 .191 0 r
.37559 .15001 m
.376 .15034 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64262 .1517 m
.64259 .15155 L
s
1 .452 0 r
.01 w
.6444 .15034 Mdot
[ .05 .05 ] 0 setdash
.64441 .15032 m
.6444 .15034 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64439 .15084 m
.64437 .15033 L
s
1 .453 0 r
.01 w
[ .05 .05 ] 0 setdash
.64437 .15033 m
.6444 .15032 L
s
.64437 .15033 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64449 .15055 m
.64447 .15153 L
s
.64452 .15098 m
.64449 .15055 L
s
.64245 .15195 m
.64252 .15269 L
s
.64298 .15245 m
.64301 .15157 L
s
1 .452 0 r
.01 w
.64441 .15032 Mdot
[ .05 .05 ] 0 setdash
.64441 .15032 m
.64441 .15032 L
s
1 .453 0 r
.6444 .15032 m
.64441 .15032 L
s
.6444 .15032 Mdot
1 .452 0 r
.64441 .15032 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6444 .15035 m
.64442 .1506 L
s
.64439 .15084 m
.6444 .15035 L
s
.69561 .19822 m
.69665 .19084 L
s
1 .476 0 r
.01 w
.63081 .15028 Mdot
[ .05 .05 ] 0 setdash
.62832 .14965 m
.63081 .15028 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33408 .18393 m
.33325 .1848 L
s
0 0 0 r
.004 w
.34828 .15025 Mdot
1 .45 0 r
.01 w
[ .05 .05 ] 0 setdash
.64414 .15025 m
.64391 .15013 L
s
.64414 .15025 Mdot
1 .086 0 r
.64486 .15024 m
.64449 .14985 L
s
.64486 .15024 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64268 .15193 m
.64262 .1517 L
s
.64251 .15249 m
.64246 .15209 L
s
1 .045 0 r
.01 w
.36674 .15021 Mdot
[ .05 .05 ] 0 setdash
.36932 .14934 m
.36674 .15021 L
s
1 .184 0 r
.38603 .15014 m
.38862 .14934 L
s
.38603 .15014 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60513 .20611 m
.60369 .15013 L
s
1 .09 0 r
.01 w
.60369 .15013 Mdot
[ .05 .05 ] 0 setdash
.60136 .14905 m
.60369 .15013 L
s
1 .45 0 r
.64391 .15013 m
.64364 .15 L
s
.64391 .15013 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64442 .1506 m
.64442 .15071 L
s
.64278 .15138 m
.64272 .15177 L
s
.64292 .15208 m
.64278 .15138 L
s
.64441 .15066 m
.64443 .15081 L
s
.64442 .15071 m
.64441 .15066 L
s
.64303 .15181 m
.64298 .15227 L
s
1 .498 0 r
.01 w
[ .05 .05 ] 0 setdash
.61848 .1501 m
.61966 .1495 L
s
.61848 .1501 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64443 .15081 m
.64447 .15115 L
s
.64275 .15214 m
.64268 .15193 L
s
.64451 .15127 m
.64452 .15098 L
s
.35559 .16123 m
.35608 .15921 L
s
1 .191 0 r
.01 w
.37559 .15001 Mdot
[ .05 .05 ] 0 setdash
.3752 .14966 m
.37559 .15001 L
s
1 .45 0 r
.64364 .15 m
.64335 .14985 L
s
.64364 .15 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64435 .15144 m
.64439 .15084 L
s
1 .232 0 r
.01 w
[ .05 .05 ] 0 setdash
.65251 .14998 m
.64854 .14861 L
s
.65251 .14998 Mdot
1 .27 0 r
.65263 .14996 Mdot
.64954 .14894 m
.65263 .14996 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64256 .15279 m
.64251 .15249 L
s
.64272 .15177 m
.64268 .15214 L
s
.64283 .15232 m
.64275 .15214 L
s
.64447 .15115 m
.64451 .15127 L
s
.3569 .15861 m
.35629 .16334 L
s
1 .45 0 r
.01 w
[ .05 .05 ] 0 setdash
.64335 .14985 m
.64304 .14969 L
s
.64335 .14985 Mdot
1 .086 0 r
.64449 .14985 m
.64373 .14947 L
s
.64449 .14985 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64266 .15226 m
.64278 .15306 L
s
.64252 .15269 m
.64259 .15312 L
s
.6571 .17131 m
.65658 .17189 L
s
.64298 .15227 m
.64291 .15241 L
s
.64291 .15312 m
.64298 .15245 L
s
.64291 .15241 m
.64283 .15232 L
s
.64268 .15214 m
.64264 .15239 L
s
.25305 .27882 m
.25076 .28169 L
s
.64264 .15239 m
.64261 .15261 L
s
1 .449 0 r
.01 w
[ .05 .05 ] 0 setdash
.64304 .14969 m
.64273 .14954 L
s
.64304 .14969 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64259 .15279 m
.64256 .15279 L
s
.64318 .15421 m
.64292 .15208 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.37452 .16351 m
.3752 .14966 L
s
1 .191 0 r
.01 w
.3752 .14966 Mdot
[ .05 .05 ] 0 setdash
.37483 .14929 m
.3752 .14966 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64261 .15261 m
.64259 .15279 L
s
1 .476 0 r
.01 w
.62832 .14965 Mdot
[ .05 .05 ] 0 setdash
.62616 .14907 m
.62832 .14965 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64447 .15153 m
.64441 .15282 L
s
.6443 .15204 m
.64435 .15144 L
s
.35499 .16886 m
.35472 .16091 L
s
0 0 0 r
.004 w
.35017 .14956 Mdot
.53 .8 .95 r
.006 w
.37363 .16723 m
.37376 .16828 L
s
1 .449 0 r
.01 w
[ .05 .05 ] 0 setdash
.64273 .14954 m
.64243 .14939 L
s
.64273 .14954 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64259 .15312 m
.64269 .15339 L
s
1 .498 0 r
.01 w
[ .05 .05 ] 0 setdash
.61966 .1495 m
.62086 .14885 L
s
.61966 .1495 Mdot
1 .085 0 r
.64373 .14947 m
.64312 .14896 L
s
.64373 .14947 Mdot
1 .449 0 r
.64243 .14939 m
.64213 .14924 L
s
.64243 .14939 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6428 .15343 m
.64291 .15312 L
s
1 .183 0 r
.01 w
[ .05 .05 ] 0 setdash
.38862 .14934 m
.39178 .14847 L
s
.38862 .14934 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29336 .22636 m
.29049 .23438 L
s
1 .045 0 r
.01 w
.36932 .14934 Mdot
[ .05 .05 ] 0 setdash
.37194 .14844 m
.36932 .14934 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64269 .15339 m
.6428 .15343 L
s
.65855 .17659 m
.65896 .17443 L
s
1 .191 0 r
.01 w
.37483 .14929 Mdot
[ .05 .05 ] 0 setdash
.37451 .14894 m
.37483 .14929 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64278 .15306 m
.64293 .15378 L
s
.64423 .1526 m
.6443 .15204 L
s
1 .449 0 r
.01 w
[ .05 .05 ] 0 setdash
.64213 .14924 m
.64186 .14911 L
s
.64213 .14924 Mdot
0 0 0 r
.004 w
.69785 .1492 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64209 .15504 m
.64186 .14911 L
s
1 .449 0 r
.01 w
[ .05 .05 ] 0 setdash
.64186 .14911 m
.64162 .149 L
s
.64186 .14911 Mdot
1 .476 0 r
.62616 .14907 Mdot
1 .477 0 r
.62421 .1484 m
.62616 .14907 L
s
1 .09 0 r
.60136 .14905 Mdot
1 .091 0 r
.59915 .14787 m
.60136 .14905 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35443 .16202 m
.35471 .16285 L
s
.37346 .17103 m
.37339 .16791 L
s
1 .448 0 r
.01 w
[ .05 .05 ] 0 setdash
.64162 .149 m
.64141 .14891 L
s
.64162 .149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65222 .16238 m
.6527 .16515 L
s
.64414 .15314 m
.64423 .1526 L
s
1 .085 0 r
.01 w
[ .05 .05 ] 0 setdash
.64312 .14896 m
.64245 .14834 L
s
.64312 .14896 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65658 .17189 m
.656 .17311 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65237 .21837 m
.64954 .14894 L
s
1 .27 0 r
.01 w
.64954 .14894 Mdot
1 .271 0 r
[ .05 .05 ] 0 setdash
.64605 .14767 m
.64954 .14894 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71469 .21451 m
.71613 .21107 L
s
1 .191 0 r
.01 w
.37451 .14894 Mdot
[ .05 .05 ] 0 setdash
.37419 .14858 m
.37451 .14894 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35511 .16264 m
.35559 .16123 L
s
1 .448 0 r
.01 w
[ .05 .05 ] 0 setdash
.64141 .14891 m
.64126 .14885 L
s
.64141 .14891 Mdot
0 0 0 r
.004 w
.35206 .14886 Mdot
1 .447 0 r
.01 w
.64136 .14886 m
.64148 .14886 L
s
.64136 .14886 Mdot
.64125 .14884 m
.64136 .14886 L
s
.64148 .14886 m
.64162 .14884 L
s
.64148 .14886 Mdot
1 .448 0 r
.64126 .14885 m
.64117 .14882 L
s
.64126 .14885 Mdot
1 .497 0 r
.62086 .14885 m
.62205 .14818 L
s
.62086 .14885 Mdot
1 .447 0 r
.64125 .14884 Mdot
.64116 .14883 m
.64125 .14884 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64171 .15128 m
.64162 .14884 L
s
1 .446 0 r
.01 w
[ .05 .05 ] 0 setdash
.64162 .14884 m
.64179 .14882 L
s
.64162 .14884 Mdot
1 .447 0 r
.64116 .14883 Mdot
.64113 .14882 m
.64116 .14883 L
s
1 .448 0 r
.64117 .14882 m
.64113 .14882 L
s
.64117 .14882 Mdot
1 .446 0 r
.64179 .14882 m
.642 .14879 L
s
.64179 .14882 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32423 .20871 m
.32249 .21249 L
s
1 .447 0 r
.01 w
.64113 .14882 Mdot
1 .446 0 r
[ .05 .05 ] 0 setdash
.642 .14879 m
.64222 .14875 L
s
.642 .14879 Mdot
.64222 .14875 m
.6424 .14871 L
s
.64222 .14875 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64293 .15378 m
.64311 .15432 L
s
1 .446 0 r
.01 w
[ .05 .05 ] 0 setdash
.6424 .14871 m
.64254 .14865 L
s
.6424 .14871 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64402 .15368 m
.64414 .15314 L
s
.64441 .15282 m
.64429 .15431 L
s
1 .445 0 r
.01 w
[ .05 .05 ] 0 setdash
.64254 .14865 m
.64261 .14857 L
s
.64254 .14865 Mdot
1 .232 0 r
.64854 .14861 m
.64436 .14712 L
s
.64854 .14861 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31194 .21974 m
.30981 .21949 L
s
.65062 .16811 m
.65113 .16257 L
s
1 .191 0 r
.01 w
.37419 .14858 Mdot
1 .192 0 r
[ .05 .05 ] 0 setdash
.37392 .14827 m
.37419 .14858 L
s
1 .445 0 r
.64261 .14857 m
.64259 .14848 L
s
.64261 .14857 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64118 .14923 m
.64116 .14955 L
s
.64132 .15031 m
.64118 .14923 L
s
.6137 .15741 m
.61394 .15754 L
s
.61363 .15994 m
.6137 .15741 L
s
1 .445 0 r
.01 w
[ .05 .05 ] 0 setdash
.64259 .14848 m
.64247 .14838 L
s
.64259 .14848 Mdot
1 .183 0 r
.39178 .14847 m
.39474 .14779 L
s
.39178 .14847 Mdot
1 .045 0 r
.37194 .14844 Mdot
.37443 .14758 m
.37194 .14844 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64388 .15418 m
.64402 .15368 L
s
1 .477 0 r
.01 w
.62421 .1484 Mdot
[ .05 .05 ] 0 setdash
.62255 .14783 m
.62421 .1484 L
s
1 .445 0 r
.64247 .14838 m
.64223 .14828 L
s
.64247 .14838 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64358 .15734 m
.64318 .15421 L
s
.7229 .21937 m
.72146 .22619 L
s
.64311 .15432 m
.64331 .1546 L
s
1 .085 0 r
.01 w
[ .05 .05 ] 0 setdash
.64245 .14834 m
.64168 .14762 L
s
.64245 .14834 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64116 .14955 m
.64121 .15001 L
s
.35471 .16285 m
.35511 .16264 L
s
1 .445 0 r
.01 w
[ .05 .05 ] 0 setdash
.64223 .14828 m
.6419 .14817 L
s
.64223 .14828 Mdot
1 .192 0 r
.37392 .14827 Mdot
.37369 .14801 m
.37392 .14827 L
s
1 .497 0 r
.62205 .14818 m
.62322 .14752 L
s
.62205 .14818 Mdot
0 0 0 r
.004 w
.35396 .14818 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6422 .15599 m
.6419 .14817 L
s
1 .444 0 r
.01 w
[ .05 .05 ] 0 setdash
.6419 .14817 m
.64151 .14806 L
s
.6419 .14817 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37376 .16828 m
.37395 .16996 L
s
.6437 .15439 m
.64388 .15418 L
s
.64331 .1546 m
.64351 .15461 L
s
.64351 .15461 m
.6437 .15439 L
s
1 .444 0 r
.01 w
[ .05 .05 ] 0 setdash
.64151 .14806 m
.64109 .14796 L
s
.64151 .14806 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61394 .15754 m
.61439 .15963 L
s
.64121 .15001 m
.6413 .15025 L
s
1 .192 0 r
.01 w
.37369 .14801 Mdot
[ .05 .05 ] 0 setdash
.37352 .14782 m
.37369 .14801 L
s
0 0 0 r
.004 w
.69448 .14798 Mdot
1 .444 0 r
.01 w
.64109 .14796 m
.64064 .14787 L
s
.64109 .14796 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6413 .15025 m
.64142 .15045 L
s
.64152 .15169 m
.64132 .15031 L
s
1 .091 0 r
.01 w
.59915 .14787 Mdot
[ .05 .05 ] 0 setdash
.59727 .14676 m
.59915 .14787 L
s
1 .444 0 r
.64064 .14787 m
.64022 .14779 L
s
.64064 .14787 Mdot
1 .193 0 r
.37299 .14785 m
.37297 .14782 L
s
.37299 .14785 Mdot
1 .194 0 r
.3731 .14785 m
.37299 .14785 L
s
.3731 .14785 Mdot
.37331 .14779 m
.3731 .14785 L
s
1 .477 0 r
.62255 .14783 Mdot
.62108 .14723 m
.62255 .14783 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37668 .15686 m
.37659 .15814 L
s
.37655 .15758 m
.37668 .15686 L
s
1 .192 0 r
.01 w
.37352 .14782 Mdot
[ .05 .05 ] 0 setdash
.3734 .14769 m
.37352 .14782 L
s
1 .193 0 r
.37297 .14782 m
.373 .14776 L
s
.37297 .14782 Mdot
1 .194 0 r
.37331 .14779 Mdot
.37369 .14766 m
.37331 .14779 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64142 .15045 m
.64156 .15079 L
s
1 .183 0 r
.01 w
[ .05 .05 ] 0 setdash
.39474 .14779 m
.39805 .14709 L
s
.39474 .14779 Mdot
1 .444 0 r
.64022 .14779 m
.63981 .14771 L
s
.64022 .14779 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31427 .2195 m
.31194 .21974 L
s
1 .193 0 r
.01 w
[ .05 .05 ] 0 setdash
.373 .14776 m
.37308 .1477 L
s
.373 .14776 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25518 .27593 m
.25305 .27882 L
s
1 .443 0 r
.01 w
[ .05 .05 ] 0 setdash
.63981 .14771 m
.6394 .14765 L
s
.63981 .14771 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37299 .14955 m
.37308 .1477 L
s
1 .193 0 r
.01 w
[ .05 .05 ] 0 setdash
.37308 .1477 m
.37318 .14764 L
s
.37308 .1477 Mdot
1 .192 0 r
.3734 .14769 Mdot
.37329 .14763 m
.3734 .14769 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70546 .20252 m
.70731 .20851 L
s
1 .271 0 r
.01 w
.64605 .14767 Mdot
[ .05 .05 ] 0 setdash
.64314 .14669 m
.64605 .14767 L
s
1 .194 0 r
.37369 .14766 Mdot
.37427 .14746 m
.37369 .14766 L
s
1 .443 0 r
.6394 .14765 m
.63904 .14761 L
s
.6394 .14765 Mdot
1 .193 0 r
.37318 .14764 m
.37329 .14763 L
s
.37318 .14764 Mdot
1 .192 0 r
.37329 .14763 Mdot
1 .085 0 r
.64168 .14762 m
.6408 .14689 L
s
.64168 .14762 Mdot
1 .443 0 r
.63904 .14761 m
.63877 .14759 L
s
.63904 .14761 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.656 .17311 m
.65539 .17383 L
s
1 .443 0 r
.01 w
[ .05 .05 ] 0 setdash
.63877 .14759 m
.63859 .14757 L
s
.63877 .14759 Mdot
1 .045 0 r
.37443 .14758 Mdot
1 .046 0 r
.37702 .14667 m
.37443 .14758 L
s
1 .442 0 r
.63859 .14757 m
.63849 .14756 L
s
.63859 .14757 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64156 .15079 m
.64171 .15128 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6385 .14783 m
.63849 .14756 L
s
1 .442 0 r
.01 w
[ .05 .05 ] 0 setdash
.63849 .14756 m
.63843 .14754 L
s
.63849 .14756 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64429 .15431 m
.64413 .15573 L
s
1 .442 0 r
.01 w
[ .05 .05 ] 0 setdash
.63843 .14754 m
.63838 .14748 L
s
.63843 .14754 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6527 .16515 m
.65325 .16785 L
s
1 .497 0 r
.01 w
[ .05 .05 ] 0 setdash
.62322 .14752 m
.62433 .14691 L
s
.62322 .14752 Mdot
0 0 0 r
.004 w
.35587 .1475 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37659 .15814 m
.37633 .16104 L
s
1 .442 0 r
.01 w
[ .05 .05 ] 0 setdash
.63838 .14748 m
.63832 .14737 L
s
.63838 .14748 Mdot
1 .194 0 r
.37427 .14746 Mdot
1 .195 0 r
.37503 .14719 m
.37427 .14746 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37296 .14849 m
.37289 .14947 L
s
.37303 .14927 m
.37296 .14849 L
s
.6385 .14783 m
.63844 .1479 L
s
.63863 .14872 m
.6385 .14783 L
s
.32249 .21249 m
.32045 .21497 L
s
1 .442 0 r
.01 w
[ .05 .05 ] 0 setdash
.63832 .14737 m
.63821 .14721 L
s
.63832 .14737 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61369 .1646 m
.61363 .15994 L
s
.63844 .1479 m
.63844 .14908 L
s
1 .477 0 r
.01 w
.62108 .14723 Mdot
[ .05 .05 ] 0 setdash
.61993 .1467 m
.62108 .14723 L
s
1 .14 0 r
.63673 .14722 m
.63674 .14721 L
s
.63673 .14722 Mdot
.63656 .14715 m
.63673 .14722 L
s
.63674 .14721 m
.63663 .14714 L
s
.63674 .14721 Mdot
1 .441 0 r
.63821 .14721 m
.63799 .14698 L
s
.63821 .14721 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64171 .15128 m
.64191 .15192 L
s
1 .195 0 r
.01 w
.37503 .14719 Mdot
[ .05 .05 ] 0 setdash
.37595 .14687 m
.37503 .14719 L
s
1 .14 0 r
.63656 .14715 Mdot
.63622 .14699 m
.63656 .14715 L
s
1 .139 0 r
.63663 .14714 m
.6364 .14702 L
s
.63663 .14714 Mdot
1 .232 0 r
.64436 .14712 m
.64016 .14576 L
s
.64436 .14712 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37325 .14843 m
.37329 .1498 L
s
.37312 .14886 m
.37325 .14843 L
s
1 .183 0 r
.01 w
[ .05 .05 ] 0 setdash
.39805 .14709 m
.40157 .14634 L
s
.39805 .14709 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35629 .16334 m
.35539 .16945 L
s
.64178 .15335 m
.64152 .15169 L
s
.65804 .17826 m
.65855 .17659 L
s
1 .139 0 r
.01 w
[ .05 .05 ] 0 setdash
.6364 .14702 m
.63609 .14686 L
s
.6364 .14702 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31651 .2187 m
.31427 .2195 L
s
1 .14 0 r
.01 w
.63622 .14699 Mdot
[ .05 .05 ] 0 setdash
.63573 .14675 m
.63622 .14699 L
s
1 .441 0 r
.63799 .14698 m
.63766 .14669 L
s
.63799 .14698 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32045 .21497 m
.31859 .21722 L
s
.61253 .20474 m
.61298 .20246 L
s
.61195 .20863 m
.61253 .20474 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62518 .17288 m
.62433 .14691 L
s
1 .497 0 r
.01 w
[ .05 .05 ] 0 setdash
.62433 .14691 m
.62537 .14638 L
s
.62433 .14691 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37312 .15178 m
.37303 .14927 L
s
1 .084 0 r
.01 w
[ .05 .05 ] 0 setdash
.6408 .14689 m
.63976 .14609 L
s
.6408 .14689 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37625 .15914 m
.37655 .15758 L
s
1 .195 0 r
.01 w
.37595 .14687 Mdot
[ .05 .05 ] 0 setdash
.377 .14651 m
.37595 .14687 L
s
1 .139 0 r
.63609 .14686 m
.63571 .14667 L
s
.63609 .14686 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60021 .24611 m
.60197 .2458 L
s
.64269 .1509 m
.64261 .15218 L
s
.64271 .15121 m
.64269 .1509 L
s
.37299 .14955 m
.37312 .14886 L
s
0 0 0 r
.004 w
.35779 .14683 Mdot
.53 .8 .95 r
.006 w
.64267 .15215 m
.64271 .15121 L
s
0 0 0 r
.004 w
.69113 .14681 Mdot
.53 .8 .95 r
.006 w
.63887 .15034 m
.63863 .14872 L
s
1 .091 0 r
.01 w
.59727 .14676 Mdot
[ .05 .05 ] 0 setdash
.59557 .1456 m
.59727 .14676 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63615 .15826 m
.63573 .14675 L
s
1 .14 0 r
.01 w
.63573 .14675 Mdot
1 .141 0 r
[ .05 .05 ] 0 setdash
.63509 .14646 m
.63573 .14675 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64191 .15192 m
.64215 .15258 L
s
.37289 .14947 m
.3729 .1498 L
s
1 .477 0 r
.01 w
.61993 .1467 Mdot
[ .05 .05 ] 0 setdash
.61903 .14625 m
.61993 .1467 L
s
1 .271 0 r
.64314 .14669 Mdot
.6399 .1456 m
.64314 .14669 L
s
1 .441 0 r
.63766 .14669 m
.63719 .14633 L
s
.63766 .14669 Mdot
1 .046 0 r
.37702 .14667 Mdot
.37924 .1459 m
.37702 .14667 L
s
1 .139 0 r
.63571 .14667 m
.63529 .14644 L
s
.63571 .14667 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61123 .213 m
.61195 .20863 L
s
.64409 .16093 m
.64358 .15734 L
s
1 .494 0 r
.01 w
[ .05 .05 ] 0 setdash
.6327 .14656 m
.63284 .14654 L
s
.6327 .14656 Mdot
.63248 .14656 m
.6327 .14656 L
s
.63248 .14656 Mdot
.63218 .14651 m
.63248 .14656 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31859 .21722 m
.31651 .2187 L
s
.65539 .17383 m
.6547 .17483 L
s
1 .493 0 r
.01 w
[ .05 .05 ] 0 setdash
.63284 .14654 m
.63289 .14648 L
s
.63284 .14654 Mdot
1 .494 0 r
.63218 .14651 Mdot
.63192 .14648 m
.63218 .14651 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37577 .1721 m
.377 .14651 L
s
1 .195 0 r
.01 w
.377 .14651 Mdot
[ .05 .05 ] 0 setdash
.37834 .14604 m
.377 .14651 L
s
1 .494 0 r
.63192 .14648 Mdot
.63148 .14632 m
.63192 .14648 L
s
1 .493 0 r
.63289 .14648 m
.63286 .14639 L
s
.63289 .14648 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63677 .14834 m
.63681 .149 L
s
.63671 .15138 m
.63677 .14834 L
s
.3729 .1498 m
.37299 .14955 L
s
1 .141 0 r
.01 w
.63509 .14646 Mdot
[ .05 .05 ] 0 setdash
.63433 .14611 m
.63509 .14646 L
s
1 .139 0 r
.63529 .14644 m
.63481 .14617 L
s
.63529 .14644 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64529 .15844 m
.64546 .15901 L
s
.64499 .16051 m
.64529 .15844 L
s
.63844 .14908 m
.63846 .15102 L
s
.64413 .15573 m
.64391 .15689 L
s
1 .493 0 r
.01 w
[ .05 .05 ] 0 setdash
.63286 .14639 m
.63275 .14629 L
s
.63286 .14639 Mdot
1 .497 0 r
.62537 .14638 m
.6263 .14595 L
s
.62537 .14638 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61439 .15963 m
.61503 .16277 L
s
1 .183 0 r
.01 w
[ .05 .05 ] 0 setdash
.40157 .14634 m
.4049 .14573 L
s
.40157 .14634 Mdot
1 .441 0 r
.63719 .14633 m
.63657 .14589 L
s
.63719 .14633 Mdot
1 .494 0 r
.63148 .14632 Mdot
1 .495 0 r
.63104 .14614 m
.63148 .14632 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37395 .16996 m
.37423 .17273 L
s
.64256 .15285 m
.64267 .15215 L
s
1 .493 0 r
.01 w
[ .05 .05 ] 0 setdash
.63275 .14629 m
.63261 .1462 L
s
.63275 .14629 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37329 .1498 m
.37333 .15183 L
s
.64215 .15258 m
.64238 .15288 L
s
1 .477 0 r
.01 w
.61903 .14625 Mdot
1 .478 0 r
[ .05 .05 ] 0 setdash
.6183 .1458 m
.61903 .14625 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61298 .20246 m
.61331 .20168 L
s
.65325 .16785 m
.65388 .17056 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.63272 .14941 m
.63261 .1462 L
s
1 .493 0 r
.01 w
[ .05 .05 ] 0 setdash
.63261 .1462 m
.63249 .14613 L
s
.63261 .1462 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63528 .15923 m
.63481 .14617 L
s
1 .138 0 r
.01 w
[ .05 .05 ] 0 setdash
.63481 .14617 m
.6343 .14589 L
s
.63481 .14617 Mdot
0 0 0 r
.004 w
.35971 .14617 Mdot
1 .49 0 r
.01 w
.63238 .14617 m
.63234 .14616 L
s
.63238 .14617 Mdot
.6324 .14616 m
.63238 .14617 L
s
.63234 .14616 m
.63224 .14614 L
s
.63234 .14616 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63242 .14689 m
.6324 .14616 L
s
1 .49 0 r
.01 w
.6324 .14616 Mdot
1 .491 0 r
[ .05 .05 ] 0 setdash
.63239 .14615 m
.6324 .14616 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37362 .17328 m
.37346 .17103 L
s
.37633 .16104 m
.37595 .16447 L
s
1 .491 0 r
.01 w
.63239 .14615 Mdot
[ .05 .05 ] 0 setdash
.63235 .14612 m
.63239 .14615 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25789 .27146 m
.25518 .27593 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.63145 .158 m
.63104 .14614 L
s
1 .495 0 r
.01 w
.63104 .14614 Mdot
[ .05 .05 ] 0 setdash
.6306 .14595 m
.63104 .14614 L
s
1 .49 0 r
.63224 .14614 m
.63206 .14608 L
s
.63224 .14614 Mdot
1 .492 0 r
.63249 .14613 m
.63236 .14608 L
s
.63249 .14613 Mdot
1 .491 0 r
.63235 .14612 Mdot
.63228 .14608 m
.63235 .14612 L
s
1 .141 0 r
.63433 .14611 Mdot
.63343 .14567 m
.63433 .14611 L
s
1 .084 0 r
.63976 .14609 m
.63859 .14526 L
s
.63976 .14609 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64209 .15504 m
.64178 .15335 L
s
1 .491 0 r
.01 w
.63228 .14608 Mdot
[ .05 .05 ] 0 setdash
.63222 .14605 m
.63228 .14608 L
s
1 .492 0 r
.63236 .14608 m
.63226 .14604 L
s
.63236 .14608 Mdot
1 .49 0 r
.63206 .14608 m
.63179 .14596 L
s
.63206 .14608 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6104 .21912 m
.61123 .213 L
s
1 .491 0 r
.01 w
.63222 .14605 Mdot
1 .492 0 r
[ .05 .05 ] 0 setdash
.63218 .14602 m
.63222 .14605 L
s
1 .195 0 r
.37834 .14604 Mdot
.37976 .14555 m
.37834 .14604 L
s
1 .492 0 r
.63226 .14604 m
.63219 .14602 L
s
.63226 .14604 Mdot
.63218 .14602 Mdot
.63219 .14602 m
.63218 .14602 L
s
.63219 .14602 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63681 .149 m
.63678 .15128 L
s
.63239 .14642 m
.63238 .14746 L
s
.63242 .14689 m
.63239 .14642 L
s
.64238 .15288 m
.64256 .15285 L
s
1 .489 0 r
.01 w
[ .05 .05 ] 0 setdash
.63179 .14596 m
.63142 .14577 L
s
.63179 .14596 Mdot
1 .496 0 r
.6263 .14595 m
.62713 .14564 L
s
.6263 .14595 Mdot
1 .495 0 r
.6306 .14595 Mdot
.63016 .14575 m
.6306 .14595 L
s
1 .046 0 r
.37924 .1459 Mdot
.38117 .14523 m
.37924 .1459 L
s
1 .441 0 r
.63657 .14589 m
.63583 .14543 L
s
.63657 .14589 Mdot
1 .138 0 r
.6343 .14589 m
.63375 .14557 L
s
.6343 .14589 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64261 .15218 m
.64245 .15415 L
s
1 .478 0 r
.01 w
.6183 .1458 Mdot
[ .05 .05 ] 0 setdash
.61774 .14547 m
.6183 .1458 L
s
1 .489 0 r
.63142 .14577 m
.63095 .1455 L
s
.63142 .14577 Mdot
1 .231 0 r
.64016 .14576 m
.63584 .14424 L
s
.64016 .14576 Mdot
1 .495 0 r
.63016 .14575 Mdot
.6297 .14558 m
.63016 .14575 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63221 .14642 m
.63219 .14652 L
s
.63231 .14735 m
.63221 .14642 L
s
.63922 .15243 m
.63887 .15034 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.40235 .21104 m
.4049 .14573 L
s
1 .182 0 r
.01 w
[ .05 .05 ] 0 setdash
.4049 .14573 m
.408 .14524 L
s
.4049 .14573 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63219 .14652 m
.63226 .14717 L
s
1 .141 0 r
.01 w
.63343 .14567 Mdot
[ .05 .05 ] 0 setdash
.63246 .14522 m
.63343 .14567 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63243 .14733 m
.63242 .14689 L
s
0 0 0 r
.004 w
.68781 .14567 Mdot
1 .496 0 r
.01 w
[ .05 .05 ] 0 setdash
.62713 .14564 m
.62788 .14546 L
s
.62713 .14564 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71293 .21558 m
.71469 .21451 L
s
1 .091 0 r
.01 w
.59557 .1456 Mdot
[ .05 .05 ] 0 setdash
.594 .14434 m
.59557 .1456 L
s
1 .271 0 r
.6399 .1456 Mdot
.63694 .14467 m
.6399 .1456 L
s
1 .495 0 r
.6297 .14558 Mdot
.62917 .14546 m
.6297 .14558 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64458 .16596 m
.64499 .16051 L
s
1 .138 0 r
.01 w
[ .05 .05 ] 0 setdash
.63375 .14557 m
.63311 .14521 L
s
.63375 .14557 Mdot
1 .195 0 r
.37976 .14555 Mdot
1 .196 0 r
.38119 .14506 m
.37976 .14555 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64546 .15901 m
.64547 .16055 L
s
0 0 0 r
.004 w
.36165 .14551 Mdot
1 .489 0 r
.01 w
[ .05 .05 ] 0 setdash
.63095 .1455 m
.63038 .14514 L
s
.63095 .1455 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6181 .15722 m
.61774 .14547 L
s
1 .478 0 r
.01 w
.61774 .14547 Mdot
[ .05 .05 ] 0 setdash
.61732 .14525 m
.61774 .14547 L
s
1 .496 0 r
.62788 .14546 m
.62856 .14541 L
s
.62788 .14546 Mdot
1 .495 0 r
.62917 .14546 Mdot
1 .496 0 r
.62856 .14541 m
.62917 .14546 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26032 .26758 m
.25789 .27146 L
s
1 .44 0 r
.01 w
[ .05 .05 ] 0 setdash
.63583 .14543 m
.63493 .1449 L
s
.63583 .14543 Mdot
1 .496 0 r
.62856 .14541 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64391 .15689 m
.64365 .15767 L
s
.37586 .16085 m
.37625 .15914 L
s
.6324 .14758 m
.63243 .14733 L
s
.63226 .14717 m
.63234 .14756 L
s
.63238 .14746 m
.63234 .14904 L
s
.3388 .19568 m
.33812 .18785 L
s
.29049 .23438 m
.28767 .24036 L
s
1 .084 0 r
.01 w
[ .05 .05 ] 0 setdash
.63859 .14526 m
.63745 .14453 L
s
.63859 .14526 Mdot
1 .478 0 r
.61732 .14525 Mdot
.61702 .14511 m
.61732 .14525 L
s
1 .182 0 r
.408 .14524 m
.41115 .14474 L
s
.408 .14524 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37942 .18262 m
.38117 .14523 L
s
1 .046 0 r
.01 w
.38117 .14523 Mdot
[ .05 .05 ] 0 setdash
.38278 .14466 m
.38117 .14523 L
s
1 .141 0 r
.63246 .14522 Mdot
.63147 .14474 m
.63246 .14522 L
s
1 .138 0 r
.63311 .14521 m
.63236 .1448 L
s
.63311 .14521 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6547 .17483 m
.65391 .17618 L
s
.63244 .1483 m
.63231 .14735 L
s
1 .489 0 r
.01 w
[ .05 .05 ] 0 setdash
.63038 .14514 m
.62976 .1447 L
s
.63038 .14514 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64241 .15654 m
.64209 .15504 L
s
.63234 .14756 m
.6324 .14758 L
s
.37333 .15183 m
.37339 .15417 L
s
.37332 .15517 m
.37312 .15178 L
s
1 .478 0 r
.01 w
.61702 .14511 Mdot
1 .479 0 r
[ .05 .05 ] 0 setdash
.61679 .14503 m
.61702 .14511 L
s
1 .196 0 r
.38119 .14506 Mdot
.38268 .14454 m
.38119 .14506 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63292 .14876 m
.63299 .14929 L
s
.6328 .14938 m
.63292 .14876 L
s
1 .479 0 r
.01 w
.61679 .14503 Mdot
[ .05 .05 ] 0 setdash
.6166 .14499 m
.61679 .14503 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65743 .17913 m
.65804 .17826 L
s
.65388 .17056 m
.65456 .17345 L
s
1 .479 0 r
.01 w
.6166 .14499 Mdot
[ .05 .05 ] 0 setdash
.61644 .14497 m
.6166 .14499 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61379 .17066 m
.61369 .1646 L
s
1 .479 0 r
.01 w
.61644 .14497 Mdot
[ .05 .05 ] 0 setdash
.61631 .14493 m
.61644 .14497 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63846 .15102 m
.63844 .15357 L
s
1 .479 0 r
.01 w
.61631 .14493 Mdot
[ .05 .05 ] 0 setdash
.61618 .14484 m
.61631 .14493 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26324 .26396 m
.26032 .26758 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.63582 .16962 m
.63493 .1449 L
s
1 .44 0 r
.01 w
[ .05 .05 ] 0 setdash
.63493 .1449 m
.63382 .14428 L
s
.63493 .1449 Mdot
0 0 0 r
.004 w
.36359 .14487 Mdot
1 .479 0 r
.01 w
.61618 .14484 Mdot
1 .48 0 r
.61605 .1447 m
.61618 .14484 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70731 .20851 m
.70919 .21264 L
s
1 .137 0 r
.01 w
[ .05 .05 ] 0 setdash
.63236 .1448 m
.63153 .14438 L
s
.63236 .1448 Mdot
1 .141 0 r
.63147 .14474 Mdot
1 .142 0 r
.63038 .14417 m
.63147 .14474 L
s
1 .182 0 r
.41115 .14474 m
.41412 .14428 L
s
.41115 .14474 Mdot
1 .48 0 r
.61605 .1447 Mdot
.6159 .14451 m
.61605 .1447 L
s
1 .489 0 r
.62976 .1447 m
.62901 .14418 L
s
.62976 .1447 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64983 .17403 m
.65062 .16811 L
s
1 .271 0 r
.01 w
.63694 .14467 Mdot
[ .05 .05 ] 0 setdash
.63387 .14364 m
.63694 .14467 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63264 .15106 m
.6328 .14938 L
s
1 .046 0 r
.01 w
.38278 .14466 Mdot
1 .047 0 r
[ .05 .05 ] 0 setdash
.384 .14422 m
.38278 .14466 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64365 .15767 m
.64336 .15804 L
s
.63259 .14912 m
.63244 .1483 L
s
.63299 .14929 m
.63298 .14987 L
s
0 0 0 r
.004 w
.68451 .14457 Mdot
.53 .8 .95 r
.006 w
.37595 .16447 m
.37551 .16773 L
s
.69423 .20597 m
.69561 .19822 L
s
.61331 .20168 m
.61354 .20226 L
s
1 .196 0 r
.01 w
.38268 .14454 Mdot
[ .05 .05 ] 0 setdash
.38415 .14403 m
.38268 .14454 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6094 .22532 m
.6104 .21912 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.63874 .17942 m
.63745 .14453 L
s
1 .084 0 r
.01 w
[ .05 .05 ] 0 setdash
.63745 .14453 m
.63612 .14374 L
s
.63745 .14453 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64476 .16502 m
.64409 .16093 L
s
1 .48 0 r
.01 w
.6159 .14451 Mdot
[ .05 .05 ] 0 setdash
.61572 .14427 m
.6159 .14451 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63966 .1546 m
.63922 .15243 L
s
1 .137 0 r
.01 w
[ .05 .05 ] 0 setdash
.63153 .14438 m
.63055 .1439 L
s
.63153 .14438 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63678 .15128 m
.63662 .15326 L
s
.64275 .15765 m
.64241 .15654 L
s
.64245 .15415 m
.6422 .15599 L
s
1 .091 0 r
.01 w
.594 .14434 Mdot
[ .05 .05 ] 0 setdash
.59275 .14331 m
.594 .14434 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63651 .15476 m
.63671 .15138 L
s
1 .44 0 r
.01 w
[ .05 .05 ] 0 setdash
.63382 .14428 m
.6326 .1437 L
s
.63382 .14428 Mdot
1 .182 0 r
.41412 .14428 m
.41693 .14384 L
s
.41412 .14428 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61601 .15402 m
.61572 .14427 L
s
1 .48 0 r
.01 w
.61572 .14427 Mdot
[ .05 .05 ] 0 setdash
.61552 .14396 m
.61572 .14427 L
s
1 .231 0 r
.63584 .14424 m
.63163 .14292 L
s
.63584 .14424 Mdot
0 0 0 r
.004 w
.36554 .14423 Mdot
1 .047 0 r
.01 w
.384 .14422 Mdot
.38487 .14388 m
.384 .14422 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63234 .14904 m
.63224 .151 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62974 .16561 m
.62901 .14418 L
s
1 .488 0 r
.01 w
[ .05 .05 ] 0 setdash
.62901 .14418 m
.62816 .14358 L
s
.62901 .14418 Mdot
1 .142 0 r
.63038 .14417 Mdot
.62934 .14361 m
.63038 .14417 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63272 .14941 m
.63259 .14912 L
s
.64336 .15804 m
.64307 .15827 L
s
.60197 .2458 m
.60371 .24381 L
s
.26591 .26165 m
.26324 .26396 L
s
.63298 .14987 m
.63289 .15003 L
s
.63289 .15003 m
.63272 .14941 L
s
1 .196 0 r
.01 w
.38415 .14403 Mdot
[ .05 .05 ] 0 setdash
.38546 .14358 m
.38415 .14403 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61503 .16277 m
.61589 .16676 L
s
1 .48 0 r
.01 w
.61552 .14396 Mdot
[ .05 .05 ] 0 setdash
.61529 .1436 m
.61552 .14396 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64547 .16055 m
.64532 .16206 L
s
1 .137 0 r
.01 w
[ .05 .05 ] 0 setdash
.63055 .1439 m
.6294 .14338 L
s
.63055 .1439 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37339 .15417 m
.37351 .15662 L
s
1 .047 0 r
.01 w
.38487 .14388 Mdot
[ .05 .05 ] 0 setdash
.3855 .14359 m
.38487 .14388 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35553 .17744 m
.35499 .16886 L
s
.64307 .15827 m
.64275 .15765 L
s
1 .182 0 r
.01 w
[ .05 .05 ] 0 setdash
.41693 .14384 m
.4196 .14342 L
s
.41693 .14384 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37387 .17434 m
.37362 .17328 L
s
.37541 .16241 m
.37586 .16085 L
s
1 .084 0 r
.01 w
[ .05 .05 ] 0 setdash
.63612 .14374 m
.63475 .14307 L
s
.63612 .14374 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65456 .17345 m
.65526 .17564 L
s
1 .44 0 r
.01 w
[ .05 .05 ] 0 setdash
.6326 .1437 m
.63122 .14303 L
s
.6326 .1437 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37423 .17273 m
.3747 .17635 L
s
1 .271 0 r
.01 w
.63387 .14364 Mdot
1 .272 0 r
[ .05 .05 ] 0 setdash
.63077 .14265 m
.63387 .14364 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71112 .21496 m
.71293 .21558 L
s
1 .142 0 r
.01 w
.62934 .14361 Mdot
[ .05 .05 ] 0 setdash
.62835 .14311 m
.62934 .14361 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35539 .16945 m
.3542 .17639 L
s
1 .48 0 r
.01 w
.61529 .1436 Mdot
1 .481 0 r
[ .05 .05 ] 0 setdash
.61504 .14318 m
.61529 .1436 L
s
1 .047 0 r
.3855 .14359 Mdot
.3859 .14337 m
.3855 .14359 L
s
0 0 0 r
.004 w
.36749 .14359 Mdot
1 .196 0 r
.01 w
.38546 .14358 Mdot
.38661 .14318 m
.38546 .14358 L
s
1 .488 0 r
.62816 .14358 m
.62726 .14296 L
s
.62816 .14358 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6324 .15274 m
.63264 .15106 L
s
.65391 .17618 m
.65312 .17775 L
s
0 0 0 r
.004 w
.68124 .14351 Mdot
.53 .8 .95 r
.006 w
.65676 .17891 m
.65743 .17913 L
s
1 .181 0 r
.01 w
[ .05 .05 ] 0 setdash
.4196 .14342 m
.42215 .14298 L
s
.4196 .14342 Mdot
1 .137 0 r
.6294 .14338 m
.62804 .14279 L
s
.6294 .14338 Mdot
1 .047 0 r
.3859 .14337 Mdot
.38616 .1432 m
.3859 .14337 L
s
1 .091 0 r
.59275 .14331 Mdot
1 .092 0 r
.59154 .14219 m
.59275 .14331 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61652 .14756 m
.61669 .14793 L
s
.61638 .14747 m
.61652 .14756 L
s
.61629 .14855 m
.61638 .14747 L
s
1 .047 0 r
.01 w
.38616 .1432 Mdot
1 .048 0 r
[ .05 .05 ] 0 setdash
.38641 .14304 m
.38616 .1432 L
s
1 .196 0 r
.38661 .14318 Mdot
1 .197 0 r
.38772 .14279 m
.38661 .14318 L
s
1 .481 0 r
.61504 .14318 Mdot
.61479 .14274 m
.61504 .14318 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37551 .16773 m
.37506 .17047 L
s
.70919 .21264 m
.71112 .21496 L
s
1 .142 0 r
.01 w
.62835 .14311 Mdot
[ .05 .05 ] 0 setdash
.62734 .14253 m
.62835 .14311 L
s
1 .083 0 r
.63475 .14307 m
.63323 .14243 L
s
.63475 .14307 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60823 .23156 m
.6094 .22532 L
s
1 .048 0 r
.01 w
.38641 .14304 Mdot
[ .05 .05 ] 0 setdash
.38676 .14289 m
.38641 .14304 L
s
1 .44 0 r
.63122 .14303 m
.62964 .14232 L
s
.63122 .14303 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61669 .14793 m
.61689 .14834 L
s
.65526 .17564 m
.65599 .17737 L
s
.64014 .15646 m
.63966 .1546 L
s
1 .181 0 r
.01 w
[ .05 .05 ] 0 setdash
.42215 .14298 m
.42465 .14243 L
s
.42215 .14298 Mdot
0 0 0 r
.004 w
.36946 .14297 Mdot
1 .488 0 r
.01 w
.62726 .14296 m
.62633 .14232 L
s
.62726 .14296 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63844 .15357 m
.63834 .15636 L
s
.6422 .15599 m
.64187 .15735 L
s
1 .231 0 r
.01 w
[ .05 .05 ] 0 setdash
.63163 .14292 m
.62699 .14133 L
s
.63163 .14292 Mdot
1 .048 0 r
.38676 .14289 Mdot
.38735 .14272 m
.38676 .14289 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63662 .15326 m
.63638 .15498 L
s
.26892 .25852 m
.26591 .26165 L
s
.61689 .14834 m
.61716 .14985 L
s
1 .137 0 r
.01 w
[ .05 .05 ] 0 setdash
.62804 .14279 m
.62659 .14218 L
s
.62804 .14279 Mdot
1 .197 0 r
.38772 .14279 Mdot
.38862 .14248 m
.38772 .14279 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63224 .151 m
.63204 .15326 L
s
1 .481 0 r
.01 w
.61479 .14274 Mdot
[ .05 .05 ] 0 setdash
.61455 .14229 m
.61479 .14274 L
s
1 .048 0 r
.38735 .14272 Mdot
.38824 .14252 m
.38735 .14272 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65599 .17737 m
.65676 .17891 L
s
.37351 .15662 m
.37368 .15899 L
s
1 .272 0 r
.01 w
.63077 .14265 Mdot
[ .05 .05 ] 0 setdash
.62786 .14169 m
.63077 .14265 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37369 .15926 m
.37332 .15517 L
s
.28767 .24036 m
.28457 .24518 L
s
1 .142 0 r
.01 w
.62734 .14253 Mdot
1 .143 0 r
[ .05 .05 ] 0 setdash
.62644 .14202 m
.62734 .14253 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.38753 .15847 m
.38824 .14252 L
s
1 .048 0 r
.01 w
.38824 .14252 Mdot
[ .05 .05 ] 0 setdash
.38943 .14231 m
.38824 .14252 L
s
0 0 0 r
.004 w
.67798 .14248 Mdot
1 .197 0 r
.01 w
.38862 .14248 Mdot
.38933 .14223 m
.38862 .14248 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64391 .17305 m
.64458 .16596 L
s
1 .181 0 r
.01 w
[ .05 .05 ] 0 setdash
.42465 .14243 m
.42699 .14184 L
s
.42465 .14243 Mdot
1 .083 0 r
.63323 .14243 m
.63163 .14181 L
s
.63323 .14243 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72146 .22619 m
.71953 .23322 L
s
.60371 .24381 m
.60534 .24056 L
s
.61622 .15031 m
.61629 .14855 L
s
0 0 0 r
.004 w
.37143 .14235 Mdot
.53 .8 .95 r
.006 w
.64551 .16903 m
.64476 .16502 L
s
.64532 .16206 m
.64503 .16381 L
s
.63225 .15579 m
.6324 .15274 L
s
1 .439 0 r
.01 w
[ .05 .05 ] 0 setdash
.62964 .14232 m
.62797 .14162 L
s
.62964 .14232 Mdot
1 .488 0 r
.62633 .14232 m
.62535 .14164 L
s
.62633 .14232 Mdot
1 .048 0 r
.38943 .14231 Mdot
1 .049 0 r
.39106 .14203 m
.38943 .14231 L
s
1 .481 0 r
.61455 .14229 Mdot
.61432 .14186 m
.61455 .14229 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37495 .1632 m
.37541 .16241 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38884 .1533 m
.38933 .14223 L
s
1 .197 0 r
.01 w
.38933 .14223 Mdot
[ .05 .05 ] 0 setdash
.38984 .14205 m
.38933 .14223 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27196 .25683 m
.26892 .25852 L
s
.3742 .17397 m
.37387 .17434 L
s
1 .092 0 r
.01 w
.59154 .14219 Mdot
[ .05 .05 ] 0 setdash
.59056 .14133 m
.59154 .14219 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37506 .17047 m
.37462 .17252 L
s
1 .136 0 r
.01 w
[ .05 .05 ] 0 setdash
.62659 .14218 m
.62488 .14149 L
s
.62659 .14218 Mdot
1 .199 0 r
.38977 .14207 m
.3898 .14206 L
s
.38977 .14207 Mdot
1 .2 0 r
.38978 .14207 m
.38977 .14207 L
s
.38978 .14207 Mdot
.38984 .14205 m
.38978 .14207 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.38975 .1431 m
.3898 .14206 L
s
1 .199 0 r
.01 w
[ .05 .05 ] 0 setdash
.3898 .14206 m
.38988 .14203 L
s
.3898 .14206 Mdot
1 .197 0 r
.38984 .14205 Mdot
.39016 .14194 m
.38984 .14205 L
s
1 .2 0 r
.38984 .14205 Mdot
.38993 .14202 m
.38984 .14205 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38978 .14212 m
.38974 .14277 L
s
.3898 .14292 m
.38978 .14212 L
s
1 .199 0 r
.01 w
[ .05 .05 ] 0 setdash
.38988 .14203 m
.39001 .14199 L
s
.38988 .14203 Mdot
1 .049 0 r
.39106 .14203 Mdot
.39294 .14172 m
.39106 .14203 L
s
1 .2 0 r
.38993 .14202 Mdot
.39006 .14197 m
.38993 .14202 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62712 .16253 m
.62644 .14202 L
s
1 .143 0 r
.01 w
.62644 .14202 Mdot
[ .05 .05 ] 0 setdash
.62563 .14158 m
.62644 .14202 L
s
1 .199 0 r
.39001 .14199 m
.39015 .14194 L
s
.39001 .14199 Mdot
1 .2 0 r
.39006 .14197 Mdot
.39022 .14192 m
.39006 .14197 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61354 .20226 m
.61372 .20357 L
s
1 .198 0 r
.01 w
[ .05 .05 ] 0 setdash
.39015 .14194 m
.39027 .1419 L
s
.39015 .14194 Mdot
1 .197 0 r
.39016 .14194 Mdot
1 .198 0 r
.39032 .14188 m
.39016 .14194 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6139 .17759 m
.61379 .17066 L
s
.61716 .14985 m
.61756 .15296 L
s
1 .2 0 r
.01 w
.39022 .14192 Mdot
1 .201 0 r
[ .05 .05 ] 0 setdash
.39042 .14185 m
.39022 .14192 L
s
1 .198 0 r
.39027 .1419 m
.39035 .14187 L
s
.39027 .1419 Mdot
.39032 .14188 Mdot
.39038 .14186 m
.39032 .14188 L
s
.39035 .14187 m
.39038 .14186 L
s
.39035 .14187 Mdot
1 .481 0 r
.61432 .14186 Mdot
.61409 .14148 m
.61432 .14186 L
s
1 .198 0 r
.39038 .14186 Mdot
1 .201 0 r
.39042 .14185 Mdot
.39067 .14176 m
.39042 .14185 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64059 .15775 m
.64014 .15646 L
s
.64187 .15735 m
.64148 .15809 L
s
1 .181 0 r
.01 w
[ .05 .05 ] 0 setdash
.42699 .14184 m
.42946 .14112 L
s
.42699 .14184 Mdot
1 .083 0 r
.63163 .14181 m
.63007 .14131 L
s
.63163 .14181 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63615 .15826 m
.63651 .15476 L
s
1 .201 0 r
.01 w
.39067 .14176 Mdot
[ .05 .05 ] 0 setdash
.39099 .14165 m
.39067 .14176 L
s
0 0 0 r
.004 w
.37341 .14174 Mdot
1 .049 0 r
.01 w
.39294 .14172 Mdot
.39503 .14139 m
.39294 .14172 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37462 .17252 m
.3742 .17397 L
s
1 .272 0 r
.01 w
.62786 .14169 Mdot
[ .05 .05 ] 0 setdash
.62472 .14064 m
.62786 .14169 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60689 .23725 m
.60823 .23156 L
s
1 .201 0 r
.01 w
.39099 .14165 Mdot
[ .05 .05 ] 0 setdash
.39139 .14151 m
.39099 .14165 L
s
1 .488 0 r
.62535 .14164 m
.62438 .14098 L
s
.62535 .14164 Mdot
1 .439 0 r
.62797 .14162 m
.62615 .14084 L
s
.62797 .14162 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38974 .14277 m
.38975 .1431 L
s
.37368 .15899 m
.37392 .1611 L
s
1 .143 0 r
.01 w
.62563 .14158 Mdot
[ .05 .05 ] 0 setdash
.62494 .14123 m
.62563 .14158 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65312 .17775 m
.65226 .17926 L
s
.39036 .14232 m
.39027 .14313 L
s
.39029 .14335 m
.39036 .14232 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.39099 .15054 m
.39139 .14151 L
s
1 .201 0 r
.01 w
.39139 .14151 Mdot
[ .05 .05 ] 0 setdash
.39191 .14133 m
.39139 .14151 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62614 .1801 m
.62488 .14149 L
s
1 .136 0 r
.01 w
[ .05 .05 ] 0 setdash
.62488 .14149 m
.62309 .14075 L
s
.62488 .14149 Mdot
0 0 0 r
.004 w
.67475 .14149 Mdot
1 .481 0 r
.01 w
.61409 .14148 Mdot
1 .482 0 r
.61385 .14116 m
.61409 .14148 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60534 .24056 m
.60689 .23725 L
s
.38985 .14392 m
.3898 .14292 L
s
.63638 .15498 m
.63607 .15643 L
s
1 .049 0 r
.01 w
.39503 .14139 Mdot
[ .05 .05 ] 0 setdash
.39767 .1409 m
.39503 .14139 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38975 .1431 m
.38983 .14334 L
s
1 .092 0 r
.01 w
.59056 .14133 Mdot
[ .05 .05 ] 0 setdash
.58942 .1403 m
.59056 .14133 L
s
1 .231 0 r
.62699 .14133 m
.62278 .14002 L
s
.62699 .14133 Mdot
1 .201 0 r
.39191 .14133 Mdot
1 .202 0 r
.39254 .14111 m
.39191 .14133 L
s
1 .083 0 r
.63007 .14131 m
.62849 .14085 L
s
.63007 .14131 Mdot
1 .143 0 r
.62494 .14123 Mdot
.62435 .14093 m
.62494 .14123 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37452 .16351 m
.37495 .1632 L
s
.64148 .15809 m
.64104 .15841 L
s
1 .482 0 r
.01 w
.61385 .14116 Mdot
[ .05 .05 ] 0 setdash
.61361 .14089 m
.61385 .14116 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38983 .14334 m
.38994 .14361 L
s
0 0 0 r
.004 w
.3754 .14114 Mdot
1 .18 0 r
.01 w
[ .05 .05 ] 0 setdash
.42946 .14112 m
.43193 .14033 L
s
.42946 .14112 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64104 .15841 m
.64059 .15775 L
s
1 .202 0 r
.01 w
.39254 .14111 Mdot
[ .05 .05 ] 0 setdash
.39326 .14086 m
.39254 .14111 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63204 .15326 m
.63176 .1557 L
s
.39027 .14313 m
.39 .14562 L
s
1 .487 0 r
.01 w
[ .05 .05 ] 0 setdash
.62438 .14098 m
.62343 .14037 L
s
.62438 .14098 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28457 .24518 m
.28146 .24921 L
s
.61589 .16676 m
.61692 .17078 L
s
.61613 .15226 m
.61622 .15031 L
s
1 .143 0 r
.01 w
.62435 .14093 Mdot
[ .05 .05 ] 0 setdash
.62387 .14072 m
.62435 .14093 L
s
1 .049 0 r
.39767 .1409 Mdot
.40045 .14043 m
.39767 .1409 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27482 .25517 m
.27196 .25683 L
s
.38994 .14361 m
.39007 .14378 L
s
1 .482 0 r
.01 w
.61361 .14089 Mdot
[ .05 .05 ] 0 setdash
.61339 .14068 m
.61361 .14089 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39019 .14377 m
.39029 .14335 L
s
1 .202 0 r
.01 w
.39326 .14086 Mdot
[ .05 .05 ] 0 setdash
.39404 .14058 m
.39326 .14086 L
s
1 .083 0 r
.62849 .14085 m
.62695 .14042 L
s
.62849 .14085 Mdot
1 .439 0 r
.62615 .14084 m
.62423 .14015 L
s
.62615 .14084 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37392 .1611 m
.37417 .16286 L
s
1 .136 0 r
.01 w
[ .05 .05 ] 0 setdash
.62309 .14075 m
.62101 .1399 L
s
.62309 .14075 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38993 .1449 m
.38985 .14392 L
s
1 .146 0 r
.01 w
[ .05 .05 ] 0 setdash
.62237 .14073 m
.62233 .14071 L
s
.62237 .14073 Mdot
.62245 .14073 m
.62237 .14073 L
s
.62245 .14073 Mdot
.62256 .14069 m
.62245 .14073 L
s
1 .143 0 r
.62387 .14072 Mdot
1 .144 0 r
.62351 .14058 m
.62387 .14072 L
s
1 .145 0 r
.62233 .14071 m
.62233 .14065 L
s
.62233 .14071 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39007 .14378 m
.39019 .14377 L
s
1 .146 0 r
.01 w
.62256 .14069 Mdot
[ .05 .05 ] 0 setdash
.62267 .14065 m
.62256 .14069 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63834 .15636 m
.63812 .15924 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61358 .14699 m
.61339 .14068 L
s
1 .482 0 r
.01 w
.61339 .14068 Mdot
[ .05 .05 ] 0 setdash
.61322 .14051 m
.61339 .14068 L
s
1 .145 0 r
.62233 .14065 m
.62238 .14059 L
s
.62233 .14065 Mdot
1 .146 0 r
.62267 .14065 Mdot
1 .147 0 r
.6228 .14061 m
.62267 .14065 L
s
1 .272 0 r
.62472 .14064 Mdot
.62132 .1396 m
.62472 .14064 L
s
1 .147 0 r
.6228 .14061 Mdot
.62294 .14059 m
.6228 .14061 L
s
1 .152 0 r
.62444 .14061 m
.62461 .1406 L
s
.62444 .14061 Mdot
.62405 .14057 m
.62444 .14061 L
s
1 .151 0 r
.62461 .1406 m
.62463 .14057 L
s
.62461 .1406 Mdot
1 .145 0 r
.62238 .14059 m
.62247 .14054 L
s
.62238 .14059 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62303 .14344 m
.62294 .14059 L
s
1 .147 0 r
.01 w
.62294 .14059 Mdot
[ .05 .05 ] 0 setdash
.62307 .14058 m
.62294 .14059 L
s
1 .202 0 r
.39404 .14058 Mdot
.39485 .1403 m
.39404 .14058 L
s
1 .144 0 r
.62351 .14058 Mdot
.62323 .1405 m
.62351 .14058 L
s
1 .147 0 r
.62307 .14058 Mdot
.6232 .14057 m
.62307 .14058 L
s
.62334 .14057 m
.6232 .14057 L
s
.62334 .14057 Mdot
1 .148 0 r
.62347 .14057 m
.62334 .14057 L
s
1 .147 0 r
.6232 .14057 Mdot
1 .148 0 r
.62347 .14057 Mdot
.62359 .14055 m
.62347 .14057 L
s
1 .151 0 r
.62463 .14057 m
.62456 .14053 L
s
.62463 .14057 Mdot
1 .152 0 r
.62405 .14057 Mdot
.6234 .14044 m
.62405 .14057 L
s
1 .148 0 r
.62359 .14055 Mdot
.62369 .14053 m
.62359 .14055 L
s
0 0 0 r
.004 w
.3774 .14054 Mdot
1 .145 0 r
.01 w
.62247 .14054 m
.62259 .14049 L
s
.62247 .14054 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62462 .1424 m
.62456 .14053 L
s
1 .151 0 r
.01 w
[ .05 .05 ] 0 setdash
.62456 .14053 m
.62444 .14048 L
s
.62456 .14053 Mdot
1 .15 0 r
.62403 .14053 m
.62398 .14052 L
s
.62403 .14053 Mdot
.62408 .14052 m
.62403 .14053 L
s
1 .148 0 r
.62369 .14053 Mdot
.62376 .14049 m
.62369 .14053 L
s
1 .149 0 r
.62398 .14052 m
.62394 .14051 L
s
.62398 .14052 Mdot
0 0 0 r
.004 w
.67154 .14052 Mdot
1 .15 0 r
.01 w
.62408 .14052 Mdot
.62416 .1405 m
.62408 .14052 L
s
1 .482 0 r
.61322 .14051 Mdot
.61311 .14038 m
.61322 .14051 L
s
1 .149 0 r
.62394 .14051 m
.62391 .1405 L
s
.62394 .14051 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64503 .16381 m
.64437 .16594 L
s
1 .15 0 r
.01 w
.62416 .1405 Mdot
[ .05 .05 ] 0 setdash
.62424 .14047 m
.62416 .1405 L
s
1 .149 0 r
.62391 .1405 m
.6239 .14046 L
s
.62391 .1405 Mdot
1 .144 0 r
.62323 .1405 Mdot
.62302 .14045 m
.62323 .1405 L
s
1 .148 0 r
.62376 .14049 Mdot
.62382 .14046 m
.62376 .14049 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62268 .14316 m
.62259 .14049 L
s
1 .145 0 r
.01 w
[ .05 .05 ] 0 setdash
.62259 .14049 m
.62272 .14046 L
s
.62259 .14049 Mdot
1 .151 0 r
.62444 .14048 m
.62433 .14045 L
s
.62444 .14048 Mdot
1 .15 0 r
.62424 .14047 Mdot
.62433 .14045 m
.62424 .14047 L
s
1 .148 0 r
.62382 .14046 Mdot
1 .149 0 r
.62386 .14045 m
.62382 .14046 L
s
1 .144 0 r
.62272 .14046 m
.62286 .14044 L
s
.62272 .14046 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62391 .14089 m
.6239 .14046 L
s
1 .149 0 r
.01 w
[ .05 .05 ] 0 setdash
.6239 .14046 m
.62386 .14045 L
s
.6239 .14046 Mdot
1 .15 0 r
.62433 .14045 Mdot
1 .144 0 r
.62302 .14045 Mdot
.62286 .14044 m
.62302 .14045 L
s
1 .149 0 r
.62386 .14045 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64877 .1799 m
.64983 .17403 L
s
1 .144 0 r
.01 w
.62286 .14044 Mdot
1 .152 0 r
.6234 .14044 Mdot
[ .05 .05 ] 0 setdash
.62247 .14021 m
.6234 .14044 L
s
1 .049 0 r
.40045 .14043 Mdot
1 .05 0 r
.40333 .13993 m
.40045 .14043 L
s
1 .082 0 r
.62695 .14042 m
.62546 .14004 L
s
.62695 .14042 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37417 .16286 m
.37452 .16351 L
s
1 .482 0 r
.01 w
.61311 .14038 Mdot
1 .483 0 r
[ .05 .05 ] 0 setdash
.61311 .14025 m
.61311 .14038 L
s
1 .487 0 r
.62343 .14037 m
.62255 .13983 L
s
.62343 .14037 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43033 .19308 m
.43193 .14033 L
s
1 .18 0 r
.01 w
[ .05 .05 ] 0 setdash
.43193 .14033 m
.43453 .13946 L
s
.43193 .14033 Mdot
1 .202 0 r
.39485 .1403 Mdot
.39566 .14003 m
.39485 .1403 L
s
1 .092 0 r
.58942 .1403 Mdot
.58823 .13932 m
.58942 .1403 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3747 .17635 m
.37541 .18093 L
s
.62462 .14105 m
.62468 .14198 L
s
.62454 .14372 m
.62462 .14105 L
s
.64638 .17261 m
.64551 .16903 L
s
1 .483 0 r
.01 w
.61311 .14025 Mdot
[ .05 .05 ] 0 setdash
.61323 .14011 m
.61311 .14025 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63186 .15707 m
.63225 .15579 L
s
1 .152 0 r
.01 w
.62247 .14021 Mdot
[ .05 .05 ] 0 setdash
.62126 .13986 m
.62247 .14021 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62235 .14149 m
.62238 .14218 L
s
.6224 .14157 m
.62235 .14149 L
s
.62251 .14237 m
.6224 .14157 L
s
.62391 .14089 m
.62388 .14098 L
s
.62393 .14121 m
.62391 .14089 L
s
1 .439 0 r
.01 w
[ .05 .05 ] 0 setdash
.62423 .14015 m
.62225 .1394 L
s
.62423 .14015 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63607 .15643 m
.63569 .1577 L
s
1 .483 0 r
.01 w
.61323 .14011 Mdot
[ .05 .05 ] 0 setdash
.61347 .13997 m
.61323 .14011 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62388 .14098 m
.62384 .14131 L
s
.61756 .15296 m
.6181 .15722 L
s
1 .082 0 r
.01 w
[ .05 .05 ] 0 setdash
.62546 .14004 m
.624 .13968 L
s
.62546 .14004 Mdot
1 .202 0 r
.39566 .14003 Mdot
1 .203 0 r
.39647 .13974 m
.39566 .14003 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62584 .23499 m
.62278 .14002 L
s
1 .231 0 r
.01 w
[ .05 .05 ] 0 setdash
.62278 .14002 m
.61829 .13855 L
s
.62278 .14002 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62397 .14143 m
.62393 .14121 L
s
.39004 .14589 m
.38993 .1449 L
s
1 .483 0 r
.01 w
.61347 .13997 Mdot
[ .05 .05 ] 0 setdash
.61382 .13982 m
.61347 .13997 L
s
0 0 0 r
.004 w
.3794 .13995 Mdot
1 .05 0 r
.01 w
.40333 .13993 Mdot
.40634 .13937 m
.40333 .13993 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27824 .25234 m
.27482 .25517 L
s
.62411 .14144 m
.62406 .14154 L
s
.62419 .14142 m
.62411 .14144 L
s
1 .136 0 r
.01 w
[ .05 .05 ] 0 setdash
.62101 .1399 m
.6188 .139 L
s
.62101 .1399 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62401 .14156 m
.62397 .14143 L
s
.62384 .14131 m
.6238 .14167 L
s
.28146 .24921 m
.27824 .25234 L
s
.3862 .14775 m
.38591 .14875 L
s
.3865 .14886 m
.3862 .14775 L
s
.62428 .14149 m
.62419 .14142 L
s
1 .152 0 r
.01 w
.62126 .13986 Mdot
1 .153 0 r
[ .05 .05 ] 0 setdash
.61972 .13941 m
.62126 .13986 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62406 .14154 m
.62401 .14156 L
s
1 .487 0 r
.01 w
[ .05 .05 ] 0 setdash
.62255 .13983 m
.62173 .13934 L
s
.62255 .13983 Mdot
1 .483 0 r
.61382 .13982 Mdot
1 .484 0 r
.61426 .13968 m
.61382 .13982 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3542 .17639 m
.35273 .18376 L
s
.62437 .14153 m
.62428 .14149 L
s
1 .203 0 r
.01 w
.39647 .13974 Mdot
[ .05 .05 ] 0 setdash
.39726 .13947 m
.39647 .13974 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62449 .14189 m
.62437 .14153 L
s
.6238 .14167 m
.62374 .14201 L
s
1 .082 0 r
.01 w
[ .05 .05 ] 0 setdash
.624 .13968 m
.62257 .13931 L
s
.624 .13968 Mdot
1 .484 0 r
.61426 .13968 Mdot
.61475 .13954 m
.61426 .13968 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62238 .14218 m
.62245 .14271 L
s
.62263 .14299 m
.62251 .14237 L
s
.62468 .14198 m
.62462 .1424 L
s
.65226 .17926 m
.65136 .18009 L
s
1 .272 0 r
.01 w
.62132 .1396 Mdot
[ .05 .05 ] 0 setdash
.61808 .1387 m
.62132 .1396 L
s
0 0 0 r
.004 w
.66836 .13959 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37422 .16366 m
.37369 .15926 L
s
1 .484 0 r
.01 w
.61475 .13954 Mdot
[ .05 .05 ] 0 setdash
.61525 .13941 m
.61475 .13954 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62374 .14201 m
.62365 .14253 L
s
.62462 .1424 m
.62449 .14189 L
s
1 .203 0 r
.01 w
.39726 .13947 Mdot
[ .05 .05 ] 0 setdash
.39796 .13923 m
.39726 .13947 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38591 .14875 m
.38554 .15116 L
s
.39 .14562 m
.38954 .14904 L
s
1 .18 0 r
.01 w
[ .05 .05 ] 0 setdash
.43453 .13946 m
.43735 .13851 L
s
.43453 .13946 Mdot
1 .153 0 r
.61972 .13941 Mdot
.61794 .13893 m
.61972 .13941 L
s
1 .484 0 r
.61525 .13941 Mdot
.61575 .13925 m
.61525 .13941 L
s
1 .438 0 r
.62225 .1394 m
.62017 .13864 L
s
.62225 .1394 Mdot
0 0 0 r
.004 w
.38142 .13937 Mdot
1 .05 0 r
.01 w
.40634 .13937 Mdot
.40956 .13868 m
.40634 .13937 L
s
1 .487 0 r
.62173 .13934 m
.621 .13891 L
s
.62173 .13934 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58887 .16997 m
.58823 .13932 L
s
1 .092 0 r
.01 w
.58823 .13932 Mdot
[ .05 .05 ] 0 setdash
.58701 .13844 m
.58823 .13932 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61601 .15402 m
.61613 .15226 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62346 .16722 m
.62257 .13931 L
s
1 .082 0 r
.01 w
[ .05 .05 ] 0 setdash
.62257 .13931 m
.62121 .13895 L
s
.62257 .13931 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61611 .15107 m
.61575 .13925 L
s
1 .484 0 r
.01 w
.61575 .13925 Mdot
[ .05 .05 ] 0 setdash
.61624 .13907 m
.61575 .13925 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3902 .14691 m
.39004 .14589 L
s
1 .203 0 r
.01 w
.39796 .13923 Mdot
[ .05 .05 ] 0 setdash
.39854 .13903 m
.39796 .13923 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62365 .14253 m
.62355 .1429 L
s
.33998 .20206 m
.3388 .19568 L
s
.62245 .14271 m
.62255 .14301 L
s
.62276 .14333 m
.62263 .14299 L
s
.62888 .15478 m
.6295 .15529 L
s
.62824 .15594 m
.62888 .15478 L
s
.63176 .1557 m
.63139 .15824 L
s
.63145 .158 m
.63186 .15707 L
s
1 .484 0 r
.01 w
.61624 .13907 Mdot
1 .485 0 r
[ .05 .05 ] 0 setdash
.61672 .13887 m
.61624 .13907 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63564 .16168 m
.63615 .15826 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.39798 .15261 m
.39854 .13903 L
s
1 .203 0 r
.01 w
.39854 .13903 Mdot
1 .204 0 r
[ .05 .05 ] 0 setdash
.39905 .13885 m
.39854 .13903 L
s
1 .136 0 r
.6188 .139 m
.61645 .13813 L
s
.6188 .139 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62355 .1429 m
.62342 .14311 L
s
1 .082 0 r
.01 w
[ .05 .05 ] 0 setdash
.62121 .13895 m
.61982 .13857 L
s
.62121 .13895 Mdot
1 .153 0 r
.61794 .13893 Mdot
.61599 .13842 m
.61794 .13893 L
s
1 .486 0 r
.621 .13891 m
.62038 .13859 L
s
.621 .13891 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63569 .1577 m
.63528 .15923 L
s
.38691 .15261 m
.3865 .14886 L
s
.62255 .14301 m
.62268 .14316 L
s
1 .485 0 r
.01 w
.61672 .13887 Mdot
[ .05 .05 ] 0 setdash
.61719 .13867 m
.61672 .13887 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62342 .14311 m
.62328 .14315 L
s
.6295 .15529 m
.63007 .15634 L
s
1 .204 0 r
.01 w
.39905 .13885 Mdot
[ .05 .05 ] 0 setdash
.39948 .1387 m
.39905 .13885 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62289 .14344 m
.62276 .14333 L
s
.62328 .14315 m
.62316 .14341 L
s
.61372 .20357 m
.61384 .20485 L
s
0 0 0 r
.004 w
.38344 .1388 Mdot
.53 .8 .95 r
.006 w
.62303 .14344 m
.62289 .14344 L
s
1 .204 0 r
.01 w
.39948 .1387 Mdot
[ .05 .05 ] 0 setdash
.39986 .13857 m
.39948 .1387 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6202 .20802 m
.61808 .1387 L
s
1 .272 0 r
.01 w
.61808 .1387 Mdot
1 .273 0 r
[ .05 .05 ] 0 setdash
.61481 .13753 m
.61808 .1387 L
s
0 0 0 r
.004 w
.66519 .13869 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62268 .14316 m
.62281 .14329 L
s
1 .05 0 r
.01 w
.40956 .13868 Mdot
[ .05 .05 ] 0 setdash
.41262 .1381 m
.40956 .13868 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62316 .14341 m
.62303 .14344 L
s
1 .485 0 r
.01 w
.61719 .13867 Mdot
[ .05 .05 ] 0 setdash
.6176 .1385 m
.61719 .13867 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64733 .17561 m
.64638 .17261 L
s
1 .438 0 r
.01 w
[ .05 .05 ] 0 setdash
.62017 .13864 m
.61815 .13793 L
s
.62017 .13864 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61397 .18441 m
.6139 .17759 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.62079 .15154 m
.62038 .13859 L
s
1 .486 0 r
.01 w
[ .05 .05 ] 0 setdash
.62038 .13859 m
.61984 .13835 L
s
.62038 .13859 Mdot
1 .081 0 r
.61982 .13857 m
.61842 .13817 L
s
.61982 .13857 Mdot
1 .204 0 r
.39986 .13857 Mdot
.4002 .13845 m
.39986 .13857 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62281 .14329 m
.62296 .14353 L
s
1 .23 0 r
.01 w
[ .05 .05 ] 0 setdash
.61829 .13855 m
.6135 .13682 L
s
.61829 .13855 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62428 .14772 m
.62454 .14372 L
s
1 .18 0 r
.01 w
[ .05 .05 ] 0 setdash
.43735 .13851 m
.4403 .13755 L
s
.43735 .13851 Mdot
1 .485 0 r
.6176 .1385 Mdot
.61807 .13833 m
.6176 .1385 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64437 .16594 m
.64386 .16805 L
s
1 .204 0 r
.01 w
.4002 .13845 Mdot
[ .05 .05 ] 0 setdash
.40049 .13835 m
.4002 .13845 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39039 .14802 m
.3902 .14691 L
s
1 .092 0 r
.01 w
.58701 .13844 Mdot
1 .093 0 r
[ .05 .05 ] 0 setdash
.58569 .13768 m
.58701 .13844 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62758 .15911 m
.62824 .15594 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61735 .18395 m
.61599 .13842 L
s
1 .153 0 r
.01 w
.61599 .13842 Mdot
[ .05 .05 ] 0 setdash
.61377 .13768 m
.61599 .13842 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63007 .15634 m
.63057 .15768 L
s
.62296 .14353 m
.62314 .14425 L
s
1 .486 0 r
.01 w
[ .05 .05 ] 0 setdash
.61984 .13835 m
.61935 .13821 L
s
.61984 .13835 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69263 .21444 m
.69423 .20597 L
s
1 .204 0 r
.01 w
.40049 .13835 Mdot
1 .205 0 r
[ .05 .05 ] 0 setdash
.40077 .13825 m
.40049 .13835 L
s
1 .485 0 r
.61807 .13833 Mdot
.61849 .13822 m
.61807 .13833 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64285 .18042 m
.64391 .17305 L
s
.63812 .15924 m
.63776 .1617 L
s
1 .205 0 r
.01 w
.40077 .13825 Mdot
[ .05 .05 ] 0 setdash
.40106 .13815 m
.40077 .13825 L
s
0 0 0 r
.004 w
.38547 .13823 Mdot
1 .485 0 r
.01 w
.61849 .13822 Mdot
1 .486 0 r
.61891 .13817 m
.61849 .13822 L
s
.61935 .13821 m
.61891 .13817 L
s
.61935 .13821 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63102 .15814 m
.63145 .158 L
s
1 .486 0 r
.01 w
.61891 .13817 Mdot
1 .081 0 r
[ .05 .05 ] 0 setdash
.61842 .13817 m
.61696 .13772 L
s
.61842 .13817 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65136 .18009 m
.65043 .18064 L
s
.6132 .14337 m
.61323 .14432 L
s
.61334 .14378 m
.6132 .14337 L
s
1 .205 0 r
.01 w
.40106 .13815 Mdot
[ .05 .05 ] 0 setdash
.40138 .13804 m
.40106 .13815 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38554 .15116 m
.38498 .15506 L
s
1 .135 0 r
.01 w
[ .05 .05 ] 0 setdash
.61645 .13813 m
.61407 .13727 L
s
.61645 .13813 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.41037 .19969 m
.41262 .1381 L
s
1 .05 0 r
.01 w
.41262 .1381 Mdot
1 .051 0 r
[ .05 .05 ] 0 setdash
.41592 .13741 m
.41262 .1381 L
s
1 .205 0 r
.40138 .13804 Mdot
.40174 .13791 m
.40138 .13804 L
s
1 .125 0 r
.59029 .13794 m
.59007 .13786 L
s
.59029 .13794 Mdot
.59049 .13788 m
.59029 .13794 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61949 .1817 m
.61815 .13793 L
s
1 .438 0 r
.01 w
[ .05 .05 ] 0 setdash
.61815 .13793 m
.61618 .13725 L
s
.61815 .13793 Mdot
1 .205 0 r
.40174 .13791 Mdot
.40213 .13777 m
.40174 .13791 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62314 .14425 m
.62338 .14531 L
s
1 .125 0 r
.01 w
.59049 .13788 Mdot
1 .126 0 r
[ .05 .05 ] 0 setdash
.59066 .13768 m
.59049 .13788 L
s
1 .125 0 r
.59007 .13786 m
.58979 .13763 L
s
.59007 .13786 Mdot
0 0 0 r
.004 w
.66204 .13782 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.40173 .148 m
.40213 .13777 L
s
1 .205 0 r
.01 w
.40213 .13777 Mdot
1 .206 0 r
[ .05 .05 ] 0 setdash
.40252 .13764 m
.40213 .13777 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63057 .15768 m
.63102 .15814 L
s
.61692 .17078 m
.61809 .17477 L
s
1 .081 0 r
.01 w
[ .05 .05 ] 0 setdash
.61696 .13772 m
.61553 .13729 L
s
.61696 .13772 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61323 .14432 m
.61337 .14564 L
s
.61586 .15536 m
.61601 .15402 L
s
1 .093 0 r
.01 w
.58569 .13768 Mdot
[ .05 .05 ] 0 setdash
.58422 .13698 m
.58569 .13768 L
s
1 .126 0 r
.59066 .13768 Mdot
.59091 .13733 m
.59066 .13768 L
s
1 .153 0 r
.61377 .13768 Mdot
.61119 .13683 m
.61377 .13768 L
s
0 0 0 r
.004 w
.3875 .13767 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61363 .14541 m
.61334 .14378 L
s
1 .206 0 r
.01 w
.40252 .13764 Mdot
[ .05 .05 ] 0 setdash
.40295 .13749 m
.40252 .13764 L
s
1 .125 0 r
.58979 .13763 m
.58942 .13726 L
s
.58979 .13763 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6181 .15722 m
.6188 .16209 L
s
.35654 .18566 m
.35553 .17744 L
s
1 .18 0 r
.01 w
[ .05 .05 ] 0 setdash
.4403 .13755 m
.44333 .13662 L
s
.4403 .13755 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39065 .14934 m
.39039 .14802 L
s
1 .273 0 r
.01 w
.61481 .13753 Mdot
[ .05 .05 ] 0 setdash
.61162 .13658 m
.61481 .13753 L
s
1 .206 0 r
.40295 .13749 Mdot
.40339 .13734 m
.40295 .13749 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64839 .17854 m
.64733 .17561 L
s
.63528 .15923 m
.63481 .16021 L
s
1 .051 0 r
.01 w
.41592 .13741 Mdot
[ .05 .05 ] 0 setdash
.41893 .13679 m
.41592 .13741 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38954 .14904 m
.38884 .1533 L
s
1 .206 0 r
.01 w
.40339 .13734 Mdot
[ .05 .05 ] 0 setdash
.40383 .13719 m
.40339 .13734 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59116 .14893 m
.59091 .13733 L
s
1 .126 0 r
.01 w
.59091 .13733 Mdot
[ .05 .05 ] 0 setdash
.59119 .13686 m
.59091 .13733 L
s
1 .081 0 r
.61553 .13729 m
.61412 .13682 L
s
.61553 .13729 Mdot
1 .135 0 r
.61407 .13727 m
.61171 .13635 L
s
.61407 .13727 Mdot
1 .125 0 r
.58942 .13726 m
.58894 .13682 L
s
.58942 .13726 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62338 .14531 m
.62371 .14695 L
s
1 .438 0 r
.01 w
[ .05 .05 ] 0 setdash
.61618 .13725 m
.6143 .1366 L
s
.61618 .13725 Mdot
1 .206 0 r
.40383 .13719 Mdot
.40423 .13705 m
.40383 .13719 L
s
0 0 0 r
.004 w
.38955 .13712 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61337 .14564 m
.61358 .14699 L
s
1 .206 0 r
.01 w
.40423 .13705 Mdot
1 .207 0 r
[ .05 .05 ] 0 setdash
.40458 .13693 m
.40423 .13705 L
s
0 0 0 r
.004 w
.65891 .13698 Mdot
1 .093 0 r
.01 w
.58422 .13698 Mdot
.58242 .13614 m
.58422 .13698 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63139 .15824 m
.63094 .16123 L
s
1 .207 0 r
.01 w
.40458 .13693 Mdot
[ .05 .05 ] 0 setdash
.40484 .13684 m
.40458 .13693 L
s
1 .215 0 r
.40471 .13688 m
.40474 .13688 L
s
.40471 .13688 Mdot
.4047 .13687 m
.40471 .13688 L
s
1 .214 0 r
.40474 .13688 m
.40478 .13686 L
s
.40474 .13688 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65043 .18064 m
.6494 .18042 L
s
1 .215 0 r
.01 w
.4047 .13687 Mdot
[ .05 .05 ] 0 setdash
.40471 .13684 m
.4047 .13687 L
s
1 .214 0 r
.40478 .13686 m
.40483 .13684 L
s
.40478 .13686 Mdot
1 .126 0 r
.59119 .13686 Mdot
.5915 .13631 m
.59119 .13686 L
s
1 .214 0 r
.40483 .13684 m
.40487 .13683 L
s
.40483 .13684 Mdot
1 .215 0 r
.40471 .13684 Mdot
.40476 .13679 m
.40471 .13684 L
s
1 .207 0 r
.40484 .13684 Mdot
.40502 .13678 m
.40484 .13684 L
s
1 .153 0 r
.61119 .13683 Mdot
1 .154 0 r
.60873 .13602 m
.61119 .13683 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.40486 .13704 m
.40487 .13683 L
s
1 .214 0 r
.01 w
[ .05 .05 ] 0 setdash
.40487 .13683 m
.40489 .13682 L
s
.40487 .13683 Mdot
.40489 .13682 m
.40489 .13682 L
s
.40489 .13682 Mdot
1 .08 0 r
.61412 .13682 m
.61279 .13635 L
s
.61412 .13682 Mdot
1 .23 0 r
.6135 .13682 m
.6093 .13556 L
s
.6135 .13682 Mdot
1 .211 0 r
.40489 .13682 m
.40489 .13682 L
s
.40489 .13682 Mdot
1 .209 0 r
.40489 .13682 Mdot
.40489 .13682 Mdot
1 .21 0 r
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
1 .211 0 r
.40489 .13682 Mdot
1 .209 0 r
.40489 .13682 Mdot
1 .21 0 r
.40489 .13682 Mdot
1 .211 0 r
.40489 .13682 Mdot
.40489 .13682 Mdot
1 .212 0 r
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
1 .213 0 r
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
.40489 .13682 Mdot
1 .209 0 r
.40489 .13682 m
.4049 .13682 L
s
.40489 .13682 Mdot
1 .21 0 r
.40489 .13682 Mdot
1 .211 0 r
.40489 .13682 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40489 .13682 m
.40489 .13686 L
s
.40489 .13686 m
.40489 .13682 L
s
1 .209 0 r
.01 w
[ .05 .05 ] 0 setdash
.4049 .13682 m
.40492 .13682 L
s
.4049 .13682 Mdot
1 .124 0 r
.58894 .13682 m
.58828 .13629 L
s
.58894 .13682 Mdot
1 .208 0 r
.40492 .13682 m
.40497 .1368 L
s
.40492 .13682 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40486 .13704 m
.40489 .13686 L
s
1 .208 0 r
.01 w
[ .05 .05 ] 0 setdash
.40497 .1368 m
.40504 .13677 L
s
.40497 .1368 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40489 .13686 m
.40491 .13706 L
s
1 .051 0 r
.01 w
.41893 .13679 Mdot
[ .05 .05 ] 0 setdash
.42191 .13616 m
.41893 .13679 L
s
1 .215 0 r
.40476 .13679 Mdot
.40486 .13673 m
.40476 .13679 L
s
1 .207 0 r
.40502 .13678 Mdot
.40512 .13675 m
.40502 .13678 L
s
1 .208 0 r
.40504 .13677 m
.40511 .13675 L
s
.40504 .13677 Mdot
.40511 .13675 m
.40514 .13674 L
s
.40511 .13675 Mdot
1 .207 0 r
.40512 .13675 Mdot
1 .208 0 r
.40514 .13674 m
.40512 .13675 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.40511 .13754 m
.40514 .13674 L
s
1 .208 0 r
.01 w
.40514 .13674 Mdot
1 .215 0 r
.40486 .13673 Mdot
1 .216 0 r
[ .05 .05 ] 0 setdash
.405 .13667 m
.40486 .13673 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40481 .13736 m
.40486 .13704 L
s
.40469 .13717 m
.40468 .13759 L
s
.40469 .13749 m
.40469 .13717 L
s
1 .216 0 r
.01 w
.405 .13667 Mdot
[ .05 .05 ] 0 setdash
.4052 .13661 m
.405 .13667 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40491 .13706 m
.40494 .13747 L
s
.40511 .13692 m
.40496 .13846 L
s
.40511 .13754 m
.40511 .13692 L
s
1 .179 0 r
.01 w
[ .05 .05 ] 0 setdash
.44333 .13662 m
.44696 .13557 L
s
.44333 .13662 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.405 .14155 m
.4052 .13661 L
s
1 .216 0 r
.01 w
.4052 .13661 Mdot
[ .05 .05 ] 0 setdash
.40545 .13654 m
.4052 .13661 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62689 .16362 m
.62758 .15911 L
s
1 .438 0 r
.01 w
[ .05 .05 ] 0 setdash
.6143 .1366 m
.61253 .13597 L
s
.6143 .1366 Mdot
1 .273 0 r
.61162 .13658 Mdot
.60841 .1354 m
.61162 .13658 L
s
0 0 0 r
.004 w
.3916 .13658 Mdot
1 .216 0 r
.01 w
.40545 .13654 Mdot
.4058 .13647 m
.40545 .13654 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40475 .13767 m
.40481 .13736 L
s
.39099 .15054 m
.39065 .14934 L
s
1 .216 0 r
.01 w
.4058 .13647 Mdot
1 .217 0 r
[ .05 .05 ] 0 setdash
.40626 .13638 m
.4058 .13647 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61358 .14699 m
.61383 .14849 L
s
.40468 .13759 m
.4047 .13779 L
s
.4047 .13838 m
.40469 .13749 L
s
.6494 .18042 m
.64839 .17854 L
s
1 .217 0 r
.01 w
.40626 .13638 Mdot
[ .05 .05 ] 0 setdash
.40689 .13629 m
.40626 .13638 L
s
1 .135 0 r
.61171 .13635 m
.60937 .13548 L
s
.61171 .13635 Mdot
1 .08 0 r
.61279 .13635 m
.61155 .13587 L
s
.61279 .13635 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40494 .13747 m
.405 .13787 L
s
.4047 .13779 m
.40475 .13767 L
s
1 .126 0 r
.01 w
.5915 .13631 Mdot
[ .05 .05 ] 0 setdash
.59183 .13568 m
.5915 .13631 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61566 .15575 m
.61586 .15536 L
s
.61404 .14739 m
.61363 .14541 L
s
1 .124 0 r
.01 w
[ .05 .05 ] 0 setdash
.58828 .13629 m
.5874 .13567 L
s
.58828 .13629 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62371 .14695 m
.62415 .14917 L
s
1 .217 0 r
.01 w
.40689 .13629 Mdot
[ .05 .05 ] 0 setdash
.4077 .13618 m
.40689 .13629 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63481 .16021 m
.6343 .16109 L
s
.635 .16472 m
.63564 .16168 L
s
.37541 .18093 m
.37642 .18583 L
s
.40506 .13796 m
.40511 .13754 L
s
.64753 .18558 m
.64877 .1799 L
s
.64386 .16805 m
.64329 .17015 L
s
1 .217 0 r
.01 w
.4077 .13618 Mdot
[ .05 .05 ] 0 setdash
.40867 .13605 m
.4077 .13618 L
s
0 0 0 r
.004 w
.65579 .13617 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37492 .16804 m
.37422 .16366 L
s
1 .051 0 r
.01 w
.42191 .13616 Mdot
[ .05 .05 ] 0 setdash
.4246 .1356 m
.42191 .13616 L
s
1 .093 0 r
.58242 .13614 Mdot
.58046 .13535 m
.58242 .13614 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40036 .14162 m
.40003 .14247 L
s
.40063 .14187 m
.40036 .14162 L
s
.38753 .15847 m
.38691 .15261 L
s
1 .217 0 r
.01 w
.40867 .13605 Mdot
[ .05 .05 ] 0 setdash
.4098 .13592 m
.40867 .13605 L
s
0 0 0 r
.004 w
.39366 .13605 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.405 .13787 m
.40506 .13796 L
s
1 .154 0 r
.01 w
.60873 .13602 Mdot
[ .05 .05 ] 0 setdash
.60608 .13518 m
.60873 .13602 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63776 .1617 m
.63724 .16424 L
s
1 .437 0 r
.01 w
[ .05 .05 ] 0 setdash
.61253 .13597 m
.61102 .13544 L
s
.61253 .13597 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35273 .18376 m
.35109 .19132 L
s
1 .217 0 r
.01 w
.4098 .13592 Mdot
1 .218 0 r
[ .05 .05 ] 0 setdash
.41109 .13575 m
.4098 .13592 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38498 .15506 m
.38411 .16052 L
s
1 .08 0 r
.01 w
[ .05 .05 ] 0 setdash
.61155 .13587 m
.61044 .13544 L
s
.61155 .13587 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40086 .14311 m
.40063 .14187 L
s
.61383 .14849 m
.61412 .15056 L
s
1 .218 0 r
.01 w
.41109 .13575 Mdot
[ .05 .05 ] 0 setdash
.41257 .13559 m
.41109 .13575 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6238 .15277 m
.62428 .14772 L
s
.40003 .14247 m
.39963 .14428 L
s
.40476 .1394 m
.4047 .13838 L
s
.71953 .23322 m
.71742 .2392 L
s
1 .126 0 r
.01 w
.59183 .13568 Mdot
1 .127 0 r
[ .05 .05 ] 0 setdash
.59213 .13504 m
.59183 .13568 L
s
1 .124 0 r
.5874 .13567 m
.58636 .135 L
s
.5874 .13567 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61384 .20485 m
.61393 .20465 L
s
.61405 .19042 m
.61397 .18441 L
s
.40496 .13846 m
.4047 .14043 L
s
1 .051 0 r
.01 w
.4246 .1356 Mdot
[ .05 .05 ] 0 setdash
.42732 .13502 m
.4246 .1356 L
s
1 .218 0 r
.41257 .13559 Mdot
.4142 .13543 m
.41257 .13559 L
s
1 .179 0 r
.44696 .13557 m
.45013 .1348 L
s
.44696 .13557 Mdot
1 .23 0 r
.6093 .13556 m
.60487 .13406 L
s
.6093 .13556 Mdot
0 0 0 r
.004 w
.39573 .13552 Mdot
1 .135 0 r
.01 w
.60937 .13548 m
.60699 .13453 L
s
.60937 .13548 Mdot
1 .437 0 r
.61102 .13544 m
.60959 .13493 L
s
.61102 .13544 Mdot
1 .08 0 r
.61044 .13544 m
.60946 .13503 L
s
.61044 .13544 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39143 .15233 m
.39099 .15054 L
s
.61542 .15605 m
.61566 .15575 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.41299 .16891 m
.4142 .13543 L
s
1 .218 0 r
.01 w
.4142 .13543 Mdot
[ .05 .05 ] 0 setdash
.41614 .13525 m
.4142 .13543 L
s
1 .273 0 r
.60841 .1354 Mdot
.60542 .13444 m
.60841 .1354 L
s
0 0 0 r
.004 w
.6527 .13538 Mdot
1 .093 0 r
.01 w
.58046 .13535 Mdot
.57842 .13464 m
.58046 .13535 L
s
1 .218 0 r
.41614 .13525 Mdot
.41825 .13508 m
.41614 .13525 L
s
1 .154 0 r
.60608 .13518 Mdot
.60356 .13428 m
.60608 .13518 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6343 .16109 m
.63371 .16203 L
s
.59038 .1421 m
.59022 .14499 L
s
.59058 .14209 m
.59038 .1421 L
s
1 .218 0 r
.01 w
.41825 .13508 Mdot
1 .219 0 r
[ .05 .05 ] 0 setdash
.4207 .13486 m
.41825 .13508 L
s
1 .127 0 r
.59213 .13504 Mdot
.5924 .13442 m
.59213 .13504 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59083 .14533 m
.59058 .14209 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61 .15423 m
.60946 .13503 L
s
1 .08 0 r
.01 w
[ .05 .05 ] 0 setdash
.60946 .13503 m
.60863 .13467 L
s
.60946 .13503 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62415 .14917 m
.62471 .152 L
s
1 .051 0 r
.01 w
.42732 .13502 Mdot
1 .052 0 r
[ .05 .05 ] 0 setdash
.42991 .1345 m
.42732 .13502 L
s
0 0 0 r
.004 w
.39781 .135 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58693 .16327 m
.58636 .135 L
s
1 .124 0 r
.01 w
[ .05 .05 ] 0 setdash
.58636 .135 m
.58513 .13425 L
s
.58636 .135 Mdot
1 .437 0 r
.60959 .13493 m
.60853 .13458 L
s
.60959 .13493 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40486 .14043 m
.40476 .1394 L
s
.6188 .16209 m
.61968 .16704 L
s
1 .219 0 r
.01 w
.4207 .13486 Mdot
[ .05 .05 ] 0 setdash
.42333 .13463 m
.4207 .13486 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61412 .15056 m
.61441 .15237 L
s
1 .179 0 r
.01 w
[ .05 .05 ] 0 setdash
.45013 .1348 m
.45386 .13397 L
s
.45013 .1348 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40111 .14492 m
.40086 .14311 L
s
.38884 .1533 m
.38793 .15803 L
s
.61454 .14925 m
.61404 .14739 L
s
.39963 .14428 m
.39915 .1468 L
s
1 .079 0 r
.01 w
[ .05 .05 ] 0 setdash
.60863 .13467 m
.60797 .13438 L
s
.60863 .13467 Mdot
1 .093 0 r
.57842 .13464 Mdot
1 .094 0 r
.57634 .13405 m
.57842 .13464 L
s
1 .219 0 r
.42333 .13463 Mdot
.42614 .13441 m
.42333 .13463 L
s
0 0 0 r
.004 w
.64962 .13462 Mdot
1 .437 0 r
.01 w
.60853 .13458 m
.60764 .13428 L
s
.60853 .13458 Mdot
1 .135 0 r
.60699 .13453 m
.60506 .13381 L
s
.60699 .13453 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61518 .15591 m
.61542 .15605 L
s
1 .052 0 r
.01 w
.42991 .1345 Mdot
[ .05 .05 ] 0 setdash
.43244 .13404 m
.42991 .1345 L
s
0 0 0 r
.004 w
.39989 .13449 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61809 .17477 m
.61933 .17793 L
s
1 .273 0 r
.01 w
.60542 .13444 Mdot
1 .274 0 r
[ .05 .05 ] 0 setdash
.60235 .13334 m
.60542 .13444 L
s
1 .127 0 r
.5924 .13442 Mdot
.59268 .13384 m
.5924 .13442 L
s
1 .219 0 r
.42614 .13441 Mdot
.4292 .13415 m
.42614 .13441 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4047 .14043 m
.40435 .14263 L
s
1 .079 0 r
.01 w
[ .05 .05 ] 0 setdash
.60797 .13438 m
.60743 .13415 L
s
.60797 .13438 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63094 .16123 m
.63041 .16356 L
s
1 .437 0 r
.01 w
[ .05 .05 ] 0 setdash
.60764 .13428 m
.60692 .13405 L
s
.60764 .13428 Mdot
1 .154 0 r
.60356 .13428 Mdot
.60119 .13345 m
.60356 .13428 L
s
1 .123 0 r
.58513 .13425 m
.58373 .13347 L
s
.58513 .13425 Mdot
1 .079 0 r
.60743 .13415 m
.60699 .13399 L
s
.60743 .13415 Mdot
1 .219 0 r
.4292 .13415 Mdot
.4322 .13393 m
.4292 .13415 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61441 .15237 m
.61468 .15401 L
s
.405 .14155 m
.40486 .14043 L
s
.62609 .1684 m
.62689 .16362 L
s
1 .077 0 r
.01 w
[ .05 .05 ] 0 setdash
.60706 .13407 m
.60691 .13404 L
s
.60706 .13407 Mdot
.60698 .13403 m
.60706 .13407 L
s
1 .23 0 r
.60487 .13406 m
.60039 .13247 L
s
.60487 .13406 Mdot
1 .094 0 r
.57634 .13405 Mdot
.57397 .13327 m
.57634 .13405 L
s
1 .436 0 r
.60692 .13405 m
.60639 .13389 L
s
.60692 .13405 Mdot
1 .052 0 r
.43244 .13404 Mdot
.43514 .13357 m
.43244 .13404 L
s
1 .077 0 r
.60691 .13404 m
.60643 .13394 L
s
.60691 .13404 Mdot
.60698 .13403 Mdot
.60678 .13398 m
.60698 .13403 L
s
1 .433 0 r
.60667 .13399 m
.60638 .13397 L
s
.60667 .13399 Mdot
.60679 .13399 m
.60667 .13399 L
s
.60679 .13399 Mdot
.60679 .13397 m
.60679 .13399 L
s
0 0 0 r
.004 w
.40199 .13399 Mdot
1 .079 0 r
.01 w
.60699 .13399 m
.60664 .13388 L
s
.60699 .13399 Mdot
1 .077 0 r
.60678 .13398 Mdot
1 .078 0 r
.60653 .13392 m
.60678 .13398 L
s
1 .179 0 r
.45386 .13397 m
.45786 .13322 L
s
.45386 .13397 Mdot
1 .433 0 r
.60679 .13397 Mdot
.60672 .13394 m
.60679 .13397 L
s
1 .432 0 r
.60638 .13397 m
.60586 .13391 L
s
.60638 .13397 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64158 .18746 m
.64285 .18042 L
s
1 .433 0 r
.01 w
.60672 .13394 Mdot
[ .05 .05 ] 0 setdash
.6066 .13392 m
.60672 .13394 L
s
1 .077 0 r
.60643 .13394 m
.6056 .13374 L
s
.60643 .13394 Mdot
1 .219 0 r
.4322 .13393 Mdot
1 .22 0 r
.43568 .13361 m
.4322 .13393 L
s
1 .433 0 r
.6066 .13392 Mdot
1 .434 0 r
.60648 .13392 m
.6066 .13392 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63371 .16203 m
.63302 .16361 L
s
.39198 .15419 m
.39143 .15233 L
s
1 .434 0 r
.01 w
.60648 .13392 Mdot
[ .05 .05 ] 0 setdash
.6064 .13391 m
.60648 .13392 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60663 .13785 m
.60653 .13392 L
s
1 .078 0 r
.01 w
.60653 .13392 Mdot
[ .05 .05 ] 0 setdash
.60632 .13385 m
.60653 .13392 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60642 .13452 m
.6064 .13391 L
s
1 .434 0 r
.01 w
.6064 .13391 Mdot
[ .05 .05 ] 0 setdash
.60636 .13391 m
.6064 .13391 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6191 .14448 m
.61869 .1446 L
s
.61958 .14562 m
.6191 .14448 L
s
.61869 .1446 m
.61829 .14547 L
s
1 .434 0 r
.01 w
.60636 .13391 Mdot
[ .05 .05 ] 0 setdash
.60632 .1339 m
.60636 .13391 L
s
1 .432 0 r
.60586 .13391 m
.60507 .1338 L
s
.60586 .13391 Mdot
1 .434 0 r
.60632 .1339 Mdot
1 .435 0 r
.60626 .13388 m
.60632 .1339 L
s
1 .436 0 r
.60639 .13389 m
.60605 .13379 L
s
.60639 .13389 Mdot
1 .435 0 r
.60626 .13388 Mdot
.60616 .13385 m
.60626 .13388 L
s
0 0 0 r
.004 w
.64656 .13388 Mdot
1 .079 0 r
.01 w
.60664 .13388 m
.6064 .13382 L
s
.60664 .13388 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61493 .15523 m
.61518 .15591 L
s
1 .435 0 r
.01 w
.60616 .13385 Mdot
[ .05 .05 ] 0 setdash
.60603 .13381 m
.60616 .13385 L
s
1 .078 0 r
.60632 .13385 Mdot
.60623 .13381 m
.60632 .13385 L
s
1 .127 0 r
.59268 .13384 Mdot
.59296 .13326 m
.59268 .13384 L
s
1 .078 0 r
.6064 .13382 m
.60625 .1338 L
s
.6064 .13382 Mdot
1 .435 0 r
.60603 .13381 Mdot
.60592 .13378 m
.60603 .13381 L
s
1 .134 0 r
.60506 .13381 m
.60313 .13308 L
s
.60506 .13381 Mdot
1 .078 0 r
.60623 .13381 Mdot
.60625 .1338 m
.60623 .13381 L
s
.60625 .1338 Mdot
1 .432 0 r
.60507 .1338 m
.60399 .13359 L
s
.60507 .1338 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60613 .13705 m
.60605 .13379 L
s
1 .436 0 r
.01 w
[ .05 .05 ] 0 setdash
.60605 .13379 m
.60586 .13375 L
s
.60605 .13379 Mdot
1 .435 0 r
.60592 .13378 Mdot
.60583 .13375 m
.60592 .13378 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34137 .20603 m
.33998 .20206 L
s
1 .435 0 r
.01 w
.60583 .13375 Mdot
1 .436 0 r
[ .05 .05 ] 0 setdash
.6058 .13374 m
.60583 .13375 L
s
.60586 .13375 m
.6058 .13374 L
s
.60586 .13375 Mdot
1 .076 0 r
.6056 .13374 m
.6044 .13343 L
s
.6056 .13374 Mdot
1 .436 0 r
.6058 .13374 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64329 .17015 m
.64263 .17233 L
s
.61468 .15401 m
.61493 .15523 L
s
.60708 .13468 m
.60701 .13791 L
s
.60707 .13732 m
.60708 .13468 L
s
.60633 .13428 m
.60637 .13437 L
s
.60627 .13442 m
.60633 .13428 L
s
.6068 .13452 m
.60674 .13662 L
s
.60681 .13486 m
.6068 .13452 L
s
.63419 .16713 m
.635 .16472 L
s
1 .22 0 r
.01 w
.43568 .13361 Mdot
[ .05 .05 ] 0 setdash
.4391 .13336 m
.43568 .13361 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60637 .13437 m
.60642 .13452 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.60457 .15562 m
.60399 .13359 L
s
1 .432 0 r
.01 w
[ .05 .05 ] 0 setdash
.60399 .13359 m
.60259 .1333 L
s
.60399 .13359 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63724 .16424 m
.63662 .16714 L
s
1 .052 0 r
.01 w
.43514 .13357 Mdot
[ .05 .05 ] 0 setdash
.43782 .13317 m
.43514 .13357 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61406 .19537 m
.61405 .19042 L
s
.60619 .13495 m
.60627 .13442 L
s
.60642 .13452 m
.6065 .13484 L
s
.61829 .14547 m
.61785 .14686 L
s
0 0 0 r
.004 w
.40409 .13349 Mdot
1 .061 0 r
.01 w
[ .05 .05 ] 0 setdash
.48996 .13349 m
.48995 .13346 L
s
.48996 .13349 Mdot
.48998 .13348 m
.48996 .13349 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62471 .152 m
.62541 .15563 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.48997 .13381 m
.48998 .13348 L
s
1 .061 0 r
.01 w
.48998 .13348 Mdot
[ .05 .05 ] 0 setdash
.49002 .13342 m
.48998 .13348 L
s
1 .123 0 r
.58373 .13347 m
.58229 .13261 L
s
.58373 .13347 Mdot
1 .06 0 r
.48995 .13346 m
.48995 .13338 L
s
.48995 .13346 Mdot
1 .154 0 r
.60119 .13345 Mdot
.59896 .13254 m
.60119 .13345 L
s
1 .076 0 r
.6044 .13343 m
.60286 .13301 L
s
.6044 .13343 Mdot
1 .061 0 r
.49002 .13342 Mdot
.49011 .13332 m
.49002 .13342 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60624 .1344 m
.60639 .13626 L
s
.60629 .13524 m
.60624 .1344 L
s
.40139 .14668 m
.40111 .14492 L
s
1 .06 0 r
.01 w
[ .05 .05 ] 0 setdash
.48995 .13338 m
.48994 .13329 L
s
.48995 .13338 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60676 .13541 m
.60681 .13486 L
s
1 .22 0 r
.01 w
.4391 .13336 Mdot
[ .05 .05 ] 0 setdash
.44289 .13303 m
.4391 .13336 L
s
1 .274 0 r
.60235 .13334 Mdot
.5996 .13239 m
.60235 .13334 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61393 .20465 m
.614 .20315 L
s
1 .061 0 r
.01 w
.49011 .13332 Mdot
[ .05 .05 ] 0 setdash
.49023 .13317 m
.49011 .13332 L
s
1 .432 0 r
.60259 .1333 m
.60081 .13292 L
s
.60259 .1333 Mdot
1 .06 0 r
.48994 .13329 m
.4899 .13319 L
s
.48994 .13329 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6065 .13484 m
.60663 .13529 L
s
.60588 .13444 m
.60583 .13477 L
s
.60613 .13705 m
.60588 .13444 L
s
1 .094 0 r
.01 w
.57397 .13327 Mdot
[ .05 .05 ] 0 setdash
.57159 .13259 m
.57397 .13327 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40521 .14288 m
.405 .14155 L
s
.48997 .13381 m
.48995 .13417 L
s
.49001 .13487 m
.48997 .13381 L
s
1 .127 0 r
.01 w
.59296 .13326 Mdot
[ .05 .05 ] 0 setdash
.59324 .13276 m
.59296 .13326 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39915 .1468 m
.3986 .1497 L
s
1 .179 0 r
.01 w
[ .05 .05 ] 0 setdash
.45786 .13322 m
.46244 .13232 L
s
.45786 .13322 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61508 .15069 m
.61454 .14925 L
s
.62014 .14811 m
.61958 .14562 L
s
1 .06 0 r
.01 w
[ .05 .05 ] 0 setdash
.4899 .13319 m
.48984 .13309 L
s
.4899 .13319 Mdot
1 .061 0 r
.49023 .13317 Mdot
1 .062 0 r
.49038 .133 m
.49023 .13317 L
s
0 0 0 r
.004 w
.64351 .13317 Mdot
1 .052 0 r
.01 w
.43782 .13317 Mdot
.44077 .13277 m
.43782 .13317 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60608 .1355 m
.60619 .13495 L
s
1 .06 0 r
.01 w
[ .05 .05 ] 0 setdash
.48984 .13309 m
.48976 .13299 L
s
.48984 .13309 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6041 .17059 m
.60313 .13308 L
s
1 .134 0 r
.01 w
[ .05 .05 ] 0 setdash
.60313 .13308 m
.60146 .13246 L
s
.60313 .13308 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40435 .14263 m
.40393 .14478 L
s
.59022 .14499 m
.59002 .14815 L
s
.60583 .13477 m
.60588 .13562 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.44101 .20354 m
.44289 .13303 L
s
1 .22 0 r
.01 w
.44289 .13303 Mdot
[ .05 .05 ] 0 setdash
.44665 .13273 m
.44289 .13303 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48995 .13417 m
.48994 .13476 L
s
0 0 0 r
.004 w
.4062 .13301 Mdot
1 .076 0 r
.01 w
[ .05 .05 ] 0 setdash
.60286 .13301 m
.60089 .13243 L
s
.60286 .13301 Mdot
1 .062 0 r
.49038 .133 Mdot
.49057 .13281 m
.49038 .133 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60663 .13529 m
.60676 .13541 L
s
1 .059 0 r
.01 w
[ .05 .05 ] 0 setdash
.48976 .13299 m
.48967 .13289 L
s
.48976 .13299 Mdot
1 .431 0 r
.60081 .13292 m
.59878 .13245 L
s
.60081 .13292 Mdot
1 .059 0 r
.48967 .13289 m
.48958 .13278 L
s
.48967 .13289 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61785 .14686 m
.61747 .14819 L
s
.60649 .13719 m
.60629 .13524 L
s
1 .062 0 r
.01 w
.49057 .13281 Mdot
[ .05 .05 ] 0 setdash
.49078 .13261 m
.49057 .13281 L
s
1 .059 0 r
.48958 .13278 m
.4895 .13268 L
s
.48958 .13278 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.43923 .18883 m
.44077 .13277 L
s
1 .052 0 r
.01 w
.44077 .13277 Mdot
1 .053 0 r
[ .05 .05 ] 0 setdash
.44379 .13245 m
.44077 .13277 L
s
1 .127 0 r
.59324 .13276 Mdot
1 .128 0 r
.5935 .13236 m
.59324 .13276 L
s
1 .22 0 r
.44665 .13273 Mdot
.45066 .13244 m
.44665 .13273 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38411 .16052 m
.38292 .16778 L
s
.37577 .1721 m
.37492 .16804 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.48945 .13632 m
.4895 .13268 L
s
1 .059 0 r
.01 w
[ .05 .05 ] 0 setdash
.4895 .13268 m
.48941 .13258 L
s
.4895 .13268 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60597 .1358 m
.60608 .1355 L
s
1 .123 0 r
.01 w
[ .05 .05 ] 0 setdash
.58229 .13261 m
.58065 .13173 L
s
.58229 .13261 Mdot
1 .062 0 r
.49078 .13261 Mdot
.491 .1324 m
.49078 .13261 L
s
1 .094 0 r
.57159 .13259 Mdot
.5692 .13191 m
.57159 .13259 L
s
1 .058 0 r
.48941 .13258 m
.48934 .13249 L
s
.48941 .13258 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48994 .13476 m
.48993 .13515 L
s
1 .154 0 r
.01 w
.59896 .13254 Mdot
1 .155 0 r
[ .05 .05 ] 0 setdash
.59706 .1318 m
.59896 .13254 L
s
0 0 0 r
.004 w
.40831 .13253 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59116 .14893 m
.59083 .14533 L
s
1 .058 0 r
.01 w
[ .05 .05 ] 0 setdash
.48934 .13249 m
.4893 .13241 L
s
.48934 .13249 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60588 .13562 m
.60597 .1358 L
s
0 0 0 r
.004 w
.64048 .13248 Mdot
1 .23 0 r
.01 w
[ .05 .05 ] 0 setdash
.60039 .13247 m
.59622 .13122 L
s
.60039 .13247 Mdot
1 .134 0 r
.60146 .13246 m
.59986 .1319 L
s
.60146 .13246 Mdot
1 .431 0 r
.59878 .13245 m
.59693 .13202 L
s
.59878 .13245 Mdot
1 .053 0 r
.44379 .13245 Mdot
.44696 .13215 m
.44379 .13245 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49007 .13615 m
.49001 .13487 L
s
1 .22 0 r
.01 w
.45066 .13244 Mdot
1 .221 0 r
[ .05 .05 ] 0 setdash
.45485 .13211 m
.45066 .13244 L
s
1 .076 0 r
.60089 .13243 m
.59846 .1317 L
s
.60089 .13243 Mdot
1 .058 0 r
.4893 .13241 m
.48933 .13235 L
s
.4893 .13241 Mdot
1 .062 0 r
.491 .1324 Mdot
.49121 .13219 m
.491 .1324 L
s
1 .274 0 r
.5996 .13239 Mdot
.59714 .13153 m
.5996 .13239 L
s
1 .056 0 r
.48911 .13237 m
.48839 .13234 L
s
.48911 .13237 Mdot
.48957 .13236 m
.48911 .13237 L
s
.48957 .13236 Mdot
1 .057 0 r
.48981 .13234 m
.48957 .13236 L
s
1 .128 0 r
.5935 .13236 Mdot
.59371 .13205 m
.5935 .13236 L
s
1 .058 0 r
.48933 .13235 m
.48942 .13231 L
s
.48933 .13235 Mdot
1 .056 0 r
.48839 .13234 m
.48735 .13229 L
s
.48839 .13234 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.48979 .13407 m
.48981 .13234 L
s
1 .057 0 r
.01 w
.48981 .13234 Mdot
[ .05 .05 ] 0 setdash
.48988 .13231 m
.48981 .13234 L
s
1 .178 0 r
.46244 .13232 m
.46636 .13187 L
s
.46244 .13232 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61406 .20005 m
.61406 .19537 L
s
1 .058 0 r
.01 w
[ .05 .05 ] 0 setdash
.48942 .13231 m
.48954 .13228 L
s
.48942 .13231 Mdot
1 .057 0 r
.48988 .13231 Mdot
.48982 .13228 m
.48988 .13231 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61968 .16704 m
.62071 .17184 L
s
1 .056 0 r
.01 w
[ .05 .05 ] 0 setdash
.48735 .13229 m
.48595 .13222 L
s
.48735 .13229 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39262 .15593 m
.39198 .15419 L
s
1 .057 0 r
.01 w
[ .05 .05 ] 0 setdash
.48954 .13228 m
.48969 .13227 L
s
.48954 .13228 Mdot
.48982 .13228 Mdot
.48969 .13227 m
.48982 .13228 L
s
.48969 .13227 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40549 .14452 m
.40521 .14288 L
s
.61747 .14819 m
.61704 .1494 L
s
1 .056 0 r
.01 w
[ .05 .05 ] 0 setdash
.48595 .13222 m
.48427 .13211 L
s
.48595 .13222 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60639 .13626 m
.60663 .13785 L
s
.60674 .13662 m
.60654 .13991 L
s
1 .062 0 r
.01 w
.49121 .13219 Mdot
1 .063 0 r
[ .05 .05 ] 0 setdash
.49143 .13199 m
.49121 .13219 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48993 .13515 m
.48991 .1355 L
s
.63302 .16361 m
.63225 .16508 L
s
1 .053 0 r
.01 w
.44696 .13215 Mdot
[ .05 .05 ] 0 setdash
.45021 .13192 m
.44696 .13215 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62306 .15867 m
.6238 .15277 L
s
1 .055 0 r
.01 w
[ .05 .05 ] 0 setdash
.48427 .13211 m
.48216 .13202 L
s
.48427 .13211 Mdot
1 .221 0 r
.45485 .13211 Mdot
.45902 .13185 m
.45485 .13211 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35109 .19132 m
.34918 .19791 L
s
0 0 0 r
.004 w
.41044 .13206 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59385 .13836 m
.59371 .13205 L
s
1 .128 0 r
.01 w
.59371 .13205 Mdot
[ .05 .05 ] 0 setdash
.59387 .13183 m
.59371 .13205 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63041 .16356 m
.62974 .16561 L
s
.6156 .15139 m
.61508 .15069 L
s
1 .055 0 r
.01 w
[ .05 .05 ] 0 setdash
.48216 .13202 m
.47979 .13188 L
s
.48216 .13202 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38793 .15803 m
.38682 .16296 L
s
1 .431 0 r
.01 w
[ .05 .05 ] 0 setdash
.59693 .13202 m
.59464 .13146 L
s
.59693 .13202 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40173 .148 m
.40139 .14668 L
s
.64601 .19059 m
.64753 .18558 L
s
1 .063 0 r
.01 w
.49143 .13199 Mdot
[ .05 .05 ] 0 setdash
.49163 .13179 m
.49143 .13199 L
s
1 .053 0 r
.45021 .13192 Mdot
.45356 .1318 m
.45021 .13192 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56992 .18094 m
.5692 .13191 L
s
1 .094 0 r
.01 w
.5692 .13191 Mdot
1 .095 0 r
[ .05 .05 ] 0 setdash
.56684 .13126 m
.5692 .13191 L
s
1 .134 0 r
.59986 .1319 m
.59861 .1315 L
s
.59986 .1319 Mdot
1 .055 0 r
.47979 .13188 m
.47699 .13176 L
s
.47979 .13188 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.46475 .21641 m
.46636 .13187 L
s
1 .178 0 r
.01 w
[ .05 .05 ] 0 setdash
.46636 .13187 m
.47101 .13128 L
s
.46636 .13187 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.614 .20315 m
.61406 .20005 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.59383 .13227 m
.59382 .13186 L
s
1 .13 0 r
.01 w
[ .05 .05 ] 0 setdash
.59382 .13186 m
.59386 .13185 L
s
.59382 .13186 Mdot
.59376 .13185 m
.59382 .13186 L
s
.59386 .13185 m
.59388 .13183 L
s
.59386 .13185 Mdot
1 .221 0 r
.45902 .13185 Mdot
.46359 .13146 m
.45902 .13185 L
s
1 .13 0 r
.59376 .13185 Mdot
.59368 .13182 m
.59376 .13185 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40393 .14478 m
.40346 .14661 L
s
1 .128 0 r
.01 w
.59387 .13183 Mdot
[ .05 .05 ] 0 setdash
.59396 .1317 m
.59387 .13183 L
s
1 .13 0 r
.59388 .13183 m
.59391 .13178 L
s
.59388 .13183 Mdot
.59368 .13182 Mdot
1 .131 0 r
.59362 .13179 m
.59368 .13182 L
s
0 0 0 r
.004 w
.63747 .13182 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60689 .13832 m
.60707 .13732 L
s
1 .155 0 r
.01 w
.59706 .1318 Mdot
[ .05 .05 ] 0 setdash
.59547 .1311 m
.59706 .1318 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38839 .16584 m
.38753 .15847 L
s
.48991 .1355 m
.48987 .13586 L
s
1 .053 0 r
.01 w
.45356 .1318 Mdot
[ .05 .05 ] 0 setdash
.45682 .13172 m
.45356 .1318 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.49156 .13849 m
.49163 .13179 L
s
1 .063 0 r
.01 w
.49163 .13179 Mdot
[ .05 .05 ] 0 setdash
.49182 .13161 m
.49163 .13179 L
s
1 .131 0 r
.59362 .13179 Mdot
.59359 .13174 m
.59362 .13179 L
s
1 .129 0 r
.59391 .13178 m
.59395 .13172 L
s
.59391 .13178 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61704 .1494 m
.61658 .15041 L
s
.62079 .15154 m
.62014 .14811 L
s
1 .055 0 r
.01 w
[ .05 .05 ] 0 setdash
.47699 .13176 m
.47403 .13174 L
s
.47699 .13176 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37642 .18583 m
.3777 .19119 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.47302 .19251 m
.47403 .13174 L
s
1 .054 0 r
.01 w
[ .05 .05 ] 0 setdash
.47403 .13174 m
.47072 .13158 L
s
.47403 .13174 Mdot
1 .131 0 r
.59359 .13174 Mdot
.5936 .13168 m
.59359 .13174 L
s
1 .123 0 r
.58065 .13173 m
.57895 .13089 L
s
.58065 .13173 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59386 .13204 m
.59389 .13213 L
s
.59383 .13227 m
.59386 .13204 L
s
1 .129 0 r
.01 w
[ .05 .05 ] 0 setdash
.59395 .13172 m
.59399 .13167 L
s
.59395 .13172 Mdot
1 .053 0 r
.45682 .13172 Mdot
1 .054 0 r
.46041 .13164 m
.45682 .13172 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59972 .18378 m
.59846 .1317 L
s
1 .075 0 r
.01 w
[ .05 .05 ] 0 setdash
.59846 .1317 m
.59594 .13102 L
s
.59846 .1317 Mdot
1 .128 0 r
.59396 .1317 Mdot
.594 .13164 m
.59396 .1317 L
s
1 .131 0 r
.5936 .13168 Mdot
.59364 .13159 m
.5936 .13168 L
s
1 .129 0 r
.59399 .13167 m
.59401 .13164 L
s
.59399 .13167 Mdot
1 .054 0 r
.46735 .13166 m
.46392 .13164 L
s
.46735 .13166 Mdot
.47072 .13158 m
.46735 .13166 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48932 .13338 m
.4894 .1338 L
s
.48928 .13415 m
.48932 .13338 L
s
1 .128 0 r
.01 w
.594 .13164 Mdot
1 .129 0 r
[ .05 .05 ] 0 setdash
.59401 .13164 m
.594 .13164 L
s
1 .054 0 r
.46392 .13164 m
.46041 .13164 L
s
.46392 .13164 Mdot
1 .129 0 r
.59401 .13164 Mdot
1 .054 0 r
.46041 .13164 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48987 .1333 m
.48979 .13407 L
s
.4898 .13448 m
.48987 .1333 L
s
.62518 .17288 m
.62609 .1684 L
s
.59389 .13213 m
.59392 .13246 L
s
1 .063 0 r
.01 w
.49182 .13161 Mdot
[ .05 .05 ] 0 setdash
.49198 .13146 m
.49182 .13161 L
s
1 .131 0 r
.59364 .13159 Mdot
.5937 .13149 m
.59364 .13159 L
s
0 0 0 r
.004 w
.41257 .13159 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60657 .1406 m
.60613 .13705 L
s
1 .054 0 r
.01 w
.47072 .13158 Mdot
.53 .8 .95 r
.006 w
.59377 .13256 m
.59383 .13227 L
s
.60679 .1395 m
.60649 .13719 L
s
.62541 .15563 m
.62621 .15912 L
s
.3986 .1497 m
.39798 .15261 L
s
1 .274 0 r
.01 w
.59714 .13153 Mdot
[ .05 .05 ] 0 setdash
.5948 .13079 m
.59714 .13153 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69052 .22262 m
.69263 .21444 L
s
.59401 .13186 m
.59399 .13314 L
s
.59403 .13245 m
.59401 .13186 L
s
1 .134 0 r
.01 w
[ .05 .05 ] 0 setdash
.59861 .1315 m
.59751 .13118 L
s
.59861 .1315 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61933 .17793 m
.62059 .1796 L
s
1 .131 0 r
.01 w
.5937 .13149 Mdot
1 .132 0 r
[ .05 .05 ] 0 setdash
.59379 .13137 m
.5937 .13149 L
s
1 .063 0 r
.49198 .13146 Mdot
1 .064 0 r
.4921 .13134 m
.49198 .13146 L
s
1 .431 0 r
.59464 .13146 m
.5923 .13094 L
s
.59464 .13146 Mdot
1 .221 0 r
.46359 .13146 Mdot
.46842 .13112 m
.46359 .13146 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60701 .13791 m
.6067 .14389 L
s
.61658 .15041 m
.61611 .15107 L
s
1 .066 0 r
.01 w
[ .05 .05 ] 0 setdash
.4921 .13141 m
.49215 .1314 L
s
.4921 .13141 Mdot
.49201 .1314 m
.4921 .13141 L
s
.49201 .1314 Mdot
.4919 .13137 m
.49201 .1314 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49018 .13748 m
.49007 .13615 L
s
1 .066 0 r
.01 w
[ .05 .05 ] 0 setdash
.49215 .1314 m
.49217 .13137 L
s
.49215 .1314 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48987 .13586 m
.4898 .13622 L
s
1 .066 0 r
.01 w
[ .05 .05 ] 0 setdash
.49217 .13137 m
.49217 .13135 L
s
.49217 .13137 Mdot
.4919 .13137 Mdot
1 .067 0 r
.49179 .13131 m
.4919 .13137 L
s
1 .132 0 r
.59379 .13137 Mdot
.59393 .13124 m
.59379 .13137 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59371 .13298 m
.59377 .13256 L
s
1 .065 0 r
.01 w
[ .05 .05 ] 0 setdash
.49217 .13135 m
.49215 .13133 L
s
.49217 .13135 Mdot
1 .064 0 r
.4921 .13134 Mdot
.49218 .13126 m
.4921 .13134 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61611 .15107 m
.6156 .15139 L
s
1 .065 0 r
.01 w
[ .05 .05 ] 0 setdash
.49215 .13133 m
.49214 .13131 L
s
.49215 .13133 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59392 .13246 m
.59398 .13275 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.49214 .13149 m
.49214 .13131 L
s
1 .065 0 r
.01 w
[ .05 .05 ] 0 setdash
.49214 .13131 m
.49216 .13129 L
s
.49214 .13131 Mdot
1 .067 0 r
.49179 .13131 Mdot
.49171 .13123 m
.49179 .13131 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4894 .1338 m
.48952 .13447 L
s
1 .065 0 r
.01 w
[ .05 .05 ] 0 setdash
.49216 .13129 m
.49219 .13125 L
s
.49216 .13129 Mdot
1 .178 0 r
.47101 .13128 m
.47563 .13082 L
s
.47101 .13128 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63331 .16939 m
.63419 .16713 L
s
1 .064 0 r
.01 w
.49218 .13126 Mdot
[ .05 .05 ] 0 setdash
.49223 .13122 m
.49218 .13126 L
s
1 .095 0 r
.56684 .13126 Mdot
.56461 .13071 m
.56684 .13126 L
s
1 .065 0 r
.49219 .13125 m
.49222 .13122 L
s
.49219 .13125 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60663 .13785 m
.60689 .13832 L
s
.35777 .1937 m
.35654 .18566 L
s
1 .132 0 r
.01 w
.59393 .13124 Mdot
[ .05 .05 ] 0 setdash
.59412 .13111 m
.59393 .13124 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48931 .13509 m
.48928 .13415 L
s
1 .067 0 r
.01 w
.49171 .13123 Mdot
[ .05 .05 ] 0 setdash
.49165 .13113 m
.49171 .13123 L
s
1 .064 0 r
.49222 .13122 m
.49224 .13121 L
s
.49222 .13122 Mdot
1 .229 0 r
.59622 .13122 m
.59222 .12991 L
s
.59622 .13122 Mdot
1 .064 0 r
.49223 .13122 Mdot
.49224 .13121 m
.49223 .13122 L
s
.49224 .13121 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49214 .13149 m
.49215 .13182 L
s
.49215 .13154 m
.49214 .13149 L
s
.49216 .13175 m
.49215 .13154 L
s
1 .133 0 r
.01 w
[ .05 .05 ] 0 setdash
.59751 .13118 m
.59656 .13097 L
s
.59751 .13118 Mdot
0 0 0 r
.004 w
.63447 .13118 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48979 .13407 m
.48951 .13757 L
s
.49223 .13133 m
.49217 .13248 L
s
.49223 .13182 m
.49223 .13133 L
s
0 0 0 r
.004 w
.41471 .13114 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.49162 .13429 m
.49165 .13113 L
s
1 .067 0 r
.01 w
.49165 .13113 Mdot
[ .05 .05 ] 0 setdash
.49164 .13103 m
.49165 .13113 L
s
1 .221 0 r
.46842 .13112 Mdot
1 .222 0 r
.47326 .13077 m
.46842 .13112 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59424 .13673 m
.59412 .13111 L
s
1 .132 0 r
.01 w
.59412 .13111 Mdot
[ .05 .05 ] 0 setdash
.59436 .13099 m
.59412 .13111 L
s
1 .155 0 r
.59547 .1311 Mdot
.5941 .13048 m
.59547 .1311 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59402 .13278 m
.59403 .13245 L
s
.49217 .13189 m
.49216 .13175 L
s
.64263 .17233 m
.64186 .17481 L
s
.59365 .13314 m
.59371 .13298 L
s
1 .067 0 r
.01 w
.49164 .13103 Mdot
[ .05 .05 ] 0 setdash
.49169 .13093 m
.49164 .13103 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40588 .14621 m
.40549 .14452 L
s
.59398 .13275 m
.59402 .13278 L
s
.49215 .132 m
.49217 .13189 L
s
1 .075 0 r
.01 w
[ .05 .05 ] 0 setdash
.59594 .13102 m
.59283 .13036 L
s
.59594 .13102 Mdot
1 .132 0 r
.59436 .13099 Mdot
.59469 .1309 m
.59436 .13099 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49209 .13222 m
.49215 .132 L
s
.4898 .13622 m
.48972 .13649 L
s
1 .133 0 r
.01 w
[ .05 .05 ] 0 setdash
.59656 .13097 m
.59579 .13086 L
s
.59656 .13097 Mdot
1 .431 0 r
.5923 .13094 m
.58978 .1303 L
s
.5923 .13094 Mdot
1 .067 0 r
.49169 .13093 Mdot
1 .068 0 r
.49179 .13084 m
.49169 .13093 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49215 .13182 m
.49218 .13209 L
s
1 .132 0 r
.01 w
.59469 .1309 Mdot
1 .133 0 r
[ .05 .05 ] 0 setdash
.59517 .13085 m
.59469 .1309 L
s
1 .123 0 r
.57895 .13089 m
.57721 .13003 L
s
.57895 .13089 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59362 .13318 m
.59365 .13314 L
s
.40207 .14882 m
.40173 .148 L
s
1 .133 0 r
.01 w
[ .05 .05 ] 0 setdash
.59579 .13086 m
.59517 .13085 L
s
.59579 .13086 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49199 .13268 m
.49209 .13222 L
s
.63662 .16714 m
.63582 .16962 L
s
1 .133 0 r
.01 w
.59517 .13085 Mdot
1 .068 0 r
.49179 .13084 Mdot
[ .05 .05 ] 0 setdash
.49194 .13075 m
.49179 .13084 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40346 .14661 m
.40297 .14793 L
s
1 .178 0 r
.01 w
[ .05 .05 ] 0 setdash
.47563 .13082 m
.48035 .13034 L
s
.47563 .13082 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49221 .13214 m
.49223 .13182 L
s
.48952 .13447 m
.48966 .13479 L
s
1 .274 0 r
.01 w
.5948 .13079 Mdot
[ .05 .05 ] 0 setdash
.59278 .13016 m
.5948 .13079 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48966 .13479 m
.4898 .13448 L
s
1 .222 0 r
.01 w
.47326 .13077 Mdot
[ .05 .05 ] 0 setdash
.47776 .13056 m
.47326 .13077 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59363 .13334 m
.59362 .13318 L
s
1 .068 0 r
.01 w
.49194 .13075 Mdot
[ .05 .05 ] 0 setdash
.49211 .13063 m
.49194 .13075 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48937 .1358 m
.48931 .13509 L
s
.59399 .13314 m
.59395 .13539 L
s
1 .095 0 r
.01 w
.56461 .13071 Mdot
[ .05 .05 ] 0 setdash
.56245 .13011 m
.56461 .13071 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39333 .15732 m
.39262 .15593 L
s
0 0 0 r
.004 w
.41686 .13069 Mdot
.53 .8 .95 r
.006 w
.49218 .13209 m
.49221 .13214 L
s
1 .068 0 r
.01 w
.49211 .13063 Mdot
[ .05 .05 ] 0 setdash
.49234 .13049 m
.49211 .13063 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48972 .13649 m
.48963 .13657 L
s
1 .222 0 r
.01 w
.47776 .13056 Mdot
[ .05 .05 ] 0 setdash
.48306 .13007 m
.47776 .13056 L
s
0 0 0 r
.004 w
.63149 .13056 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59369 .13386 m
.59363 .13334 L
s
.49188 .13324 m
.49199 .13268 L
s
.59002 .14815 m
.58973 .15141 L
s
1 .068 0 r
.01 w
.49234 .13049 Mdot
1 .069 0 r
[ .05 .05 ] 0 setdash
.49268 .13034 m
.49234 .13049 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59469 .1565 m
.5941 .13048 L
s
1 .155 0 r
.01 w
.5941 .13048 Mdot
[ .05 .05 ] 0 setdash
.59304 .12998 m
.5941 .13048 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63225 .16508 m
.63135 .16691 L
s
.49217 .13248 m
.49207 .13395 L
s
.48945 .13632 m
.48937 .1358 L
s
.48963 .13657 m
.48954 .13666 L
s
1 .075 0 r
.01 w
[ .05 .05 ] 0 setdash
.59283 .13036 m
.58969 .12965 L
s
.59283 .13036 Mdot
1 .178 0 r
.48035 .13034 m
.48496 .13008 L
s
.48035 .13034 Mdot
1 .069 0 r
.49268 .13034 Mdot
.49314 .13016 m
.49268 .13034 L
s
1 .43 0 r
.58978 .1303 m
.58693 .12963 L
s
.58978 .1303 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49032 .13873 m
.49018 .13748 L
s
0 0 0 r
.004 w
.41902 .13025 Mdot
.53 .8 .95 r
.006 w
.48954 .13666 m
.48945 .13632 L
s
.40297 .14793 m
.40251 .1485 L
s
1 .274 0 r
.01 w
.59278 .13016 Mdot
1 .275 0 r
[ .05 .05 ] 0 setdash
.591 .12959 m
.59278 .13016 L
s
1 .069 0 r
.49314 .13016 Mdot
.49376 .12995 m
.49314 .13016 L
s
1 .095 0 r
.56245 .13011 Mdot
.56051 .12964 m
.56245 .13011 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49177 .13373 m
.49188 .13324 L
s
.40251 .1485 m
.40207 .14882 L
s
1 .177 0 r
.01 w
[ .05 .05 ] 0 setdash
.48496 .13008 m
.48956 .1297 L
s
.48496 .13008 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60721 .14205 m
.60679 .1395 L
s
1 .222 0 r
.01 w
.48306 .13007 Mdot
[ .05 .05 ] 0 setdash
.4879 .12976 m
.48306 .13007 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59377 .1346 m
.59369 .13386 L
s
1 .122 0 r
.01 w
[ .05 .05 ] 0 setdash
.57721 .13003 m
.57546 .12919 L
s
.57721 .13003 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71742 .2392 m
.71474 .24437 L
s
1 .155 0 r
.01 w
.59304 .12998 Mdot
1 .156 0 r
[ .05 .05 ] 0 setdash
.59223 .12959 m
.59304 .12998 L
s
0 0 0 r
.004 w
.62852 .12996 Mdot
1 .069 0 r
.01 w
.49376 .12995 Mdot
.49458 .12972 m
.49376 .12995 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60654 .13991 m
.60613 .14428 L
s
1 .229 0 r
.01 w
[ .05 .05 ] 0 setdash
.59222 .12991 m
.5884 .12884 L
s
.59222 .12991 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39798 .15261 m
.39729 .15537 L
s
.62071 .17184 m
.62201 .17695 L
s
.62151 .15532 m
.62079 .15154 L
s
0 0 0 r
.004 w
.42118 .12982 Mdot
.53 .8 .95 r
.006 w
.34314 .20809 m
.34137 .20603 L
s
.62621 .15912 m
.62712 .16253 L
s
.62974 .16561 m
.62896 .16729 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.48673 .22645 m
.4879 .12976 L
s
1 .222 0 r
.01 w
.4879 .12976 Mdot
[ .05 .05 ] 0 setdash
.49297 .12936 m
.4879 .12976 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40641 .14881 m
.40588 .14621 L
s
.63992 .19412 m
.64158 .18746 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.49441 .14683 m
.49458 .12972 L
s
1 .069 0 r
.01 w
.49458 .12972 Mdot
[ .05 .05 ] 0 setdash
.49565 .12947 m
.49458 .12972 L
s
1 .177 0 r
.48956 .1297 m
.49406 .12947 L
s
.48956 .1297 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49168 .13409 m
.49177 .13373 L
s
1 .075 0 r
.01 w
[ .05 .05 ] 0 setdash
.58969 .12965 m
.58604 .12886 L
s
.58969 .12965 Mdot
1 .095 0 r
.56051 .12964 Mdot
.55877 .12917 m
.56051 .12964 L
s
1 .43 0 r
.58693 .12963 m
.58462 .12897 L
s
.58693 .12963 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59172 .16268 m
.591 .12959 L
s
1 .275 0 r
.01 w
.591 .12959 Mdot
[ .05 .05 ] 0 setdash
.5895 .12914 m
.591 .12959 L
s
1 .156 0 r
.59223 .12959 Mdot
.59169 .12931 m
.59223 .12959 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49207 .13395 m
.49193 .13555 L
s
1 .104 0 r
.01 w
[ .05 .05 ] 0 setdash
.55373 .12954 m
.55374 .12952 L
s
.55373 .12954 Mdot
1 .105 0 r
.55368 .1295 m
.55373 .12954 L
s
1 .104 0 r
.55374 .12952 m
.5537 .12945 L
s
.55374 .12952 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62416 .17683 m
.62518 .17288 L
s
1 .105 0 r
.01 w
.55368 .1295 Mdot
[ .05 .05 ] 0 setdash
.55361 .12939 m
.55368 .1295 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59152 .1522 m
.59116 .14893 L
s
1 .069 0 r
.01 w
.49565 .12947 Mdot
1 .07 0 r
[ .05 .05 ] 0 setdash
.49703 .12922 m
.49565 .12947 L
s
1 .177 0 r
.49406 .12947 m
.49792 .12932 L
s
.49406 .12947 Mdot
1 .104 0 r
.5537 .12945 m
.5536 .12935 L
s
.5537 .12945 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59395 .13539 m
.59385 .13836 L
s
0 0 0 r
.004 w
.42335 .1294 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55363 .13174 m
.55361 .12939 L
s
1 .105 0 r
.01 w
.55361 .12939 Mdot
[ .05 .05 ] 0 setdash
.55356 .12924 m
.55361 .12939 L
s
0 0 0 r
.004 w
.62556 .12938 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59389 .13535 m
.59377 .1346 L
s
.62059 .1796 m
.62183 .18002 L
s
1 .222 0 r
.01 w
.49297 .12936 Mdot
1 .223 0 r
[ .05 .05 ] 0 setdash
.49802 .129 m
.49297 .12936 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37695 .17513 m
.37577 .1721 L
s
1 .104 0 r
.01 w
[ .05 .05 ] 0 setdash
.5536 .12935 m
.55344 .12923 L
s
.5536 .12935 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60721 .14497 m
.60657 .1406 L
s
1 .168 0 r
.01 w
[ .05 .05 ] 0 setdash
.5395 .12933 m
.54271 .12931 L
s
.5395 .12933 Mdot
.53656 .12932 m
.5395 .12933 L
s
1 .177 0 r
.49792 .12932 m
.5018 .12913 L
s
.49792 .12932 Mdot
1 .168 0 r
.53656 .12932 Mdot
.53391 .12923 m
.53656 .12932 L
s
1 .156 0 r
.59169 .12931 Mdot
.59135 .12913 m
.59169 .12931 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39409 .15817 m
.39333 .15732 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.54307 .19086 m
.54271 .12931 L
s
1 .168 0 r
.01 w
[ .05 .05 ] 0 setdash
.54271 .12931 m
.54599 .12921 L
s
.54271 .12931 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49162 .13429 m
.49168 .13409 L
s
1 .105 0 r
.01 w
.55356 .12924 Mdot
[ .05 .05 ] 0 setdash
.55355 .12907 m
.55356 .12924 L
s
1 .104 0 r
.55344 .12923 m
.55322 .1291 L
s
.55344 .12923 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38682 .16296 m
.3855 .16794 L
s
1 .168 0 r
.01 w
.53391 .12923 Mdot
1 .169 0 r
[ .05 .05 ] 0 setdash
.53141 .12917 m
.53391 .12923 L
s
1 .07 0 r
.49703 .12922 Mdot
.49878 .12898 m
.49703 .12922 L
s
1 .167 0 r
.54599 .12921 m
.54952 .12911 L
s
.54599 .12921 Mdot
1 .158 0 r
.59081 .12921 m
.59115 .12919 L
s
.59081 .12921 Mdot
1 .159 0 r
.59038 .1292 m
.59081 .12921 L
s
.59038 .1292 Mdot
.58986 .12916 m
.59038 .1292 L
s
1 .122 0 r
.57546 .12919 m
.57381 .12842 L
s
.57546 .12919 Mdot
1 .158 0 r
.59115 .12919 m
.59138 .12914 L
s
.59115 .12919 Mdot
1 .169 0 r
.53141 .12917 Mdot
.5292 .129 m
.53141 .12917 L
s
1 .095 0 r
.55877 .12917 Mdot
1 .096 0 r
.55724 .12882 m
.55877 .12917 L
s
1 .159 0 r
.58986 .12916 Mdot
.58926 .12909 m
.58986 .12916 L
s
1 .158 0 r
.59138 .12914 m
.59153 .12907 L
s
.59138 .12914 Mdot
1 .275 0 r
.5895 .12914 Mdot
.58827 .12878 m
.5895 .12914 L
s
1 .176 0 r
.5018 .12913 m
.50545 .12898 L
s
.5018 .12913 Mdot
1 .156 0 r
.59135 .12913 Mdot
.59117 .12899 m
.59135 .12913 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4905 .13976 m
.49032 .13873 L
s
1 .167 0 r
.01 w
[ .05 .05 ] 0 setdash
.54952 .12911 m
.55288 .12896 L
s
.54952 .12911 Mdot
1 .103 0 r
.55322 .1291 m
.55295 .12897 L
s
.55322 .1291 Mdot
1 .159 0 r
.58926 .12909 Mdot
.58861 .12901 m
.58926 .12909 L
s
1 .158 0 r
.59153 .12907 m
.59159 .12899 L
s
.59153 .12907 Mdot
1 .105 0 r
.55355 .12907 Mdot
.5536 .12888 m
.55355 .12907 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34918 .19791 m
.34715 .20365 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.5889 .14258 m
.58861 .12901 L
s
1 .159 0 r
.01 w
.58861 .12901 Mdot
1 .16 0 r
[ .05 .05 ] 0 setdash
.58792 .12891 m
.58861 .12901 L
s
1 .169 0 r
.5292 .129 Mdot
.52736 .12886 m
.5292 .129 L
s
1 .223 0 r
.49802 .129 Mdot
.50275 .12872 m
.49802 .129 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49161 .13436 m
.49162 .13429 L
s
.63238 .17089 m
.63331 .16939 L
s
1 .156 0 r
.01 w
.59117 .12899 Mdot
[ .05 .05 ] 0 setdash
.59111 .12889 m
.59117 .12899 L
s
1 .158 0 r
.59159 .12899 m
.59157 .12891 L
s
.59159 .12899 Mdot
0 0 0 r
.004 w
.42553 .12899 Mdot
1 .176 0 r
.01 w
.50545 .12898 m
.50848 .12885 L
s
.50545 .12898 Mdot
1 .07 0 r
.49878 .12898 Mdot
.50086 .12876 m
.49878 .12898 L
s
1 .43 0 r
.58462 .12897 m
.58238 .12837 L
s
.58462 .12897 Mdot
1 .103 0 r
.55295 .12897 m
.55265 .12882 L
s
.55295 .12897 Mdot
1 .167 0 r
.55288 .12896 m
.55632 .12877 L
s
.55288 .12896 Mdot
1 .16 0 r
.58792 .12891 Mdot
.58719 .1288 m
.58792 .12891 L
s
1 .157 0 r
.59157 .12891 m
.59149 .12884 L
s
.59157 .12891 Mdot
1 .156 0 r
.59111 .12889 Mdot
1 .157 0 r
.59115 .12884 m
.59111 .12889 L
s
1 .105 0 r
.5536 .12888 Mdot
1 .106 0 r
.55375 .12868 m
.5536 .12888 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55374 .13054 m
.55375 .13067 L
s
.55369 .13096 m
.55374 .13054 L
s
1 .169 0 r
.01 w
.52736 .12886 Mdot
[ .05 .05 ] 0 setdash
.52568 .12866 m
.52736 .12886 L
s
1 .075 0 r
.58604 .12886 m
.58198 .12782 L
s
.58604 .12886 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.50821 .18183 m
.50848 .12885 L
s
1 .176 0 r
.01 w
[ .05 .05 ] 0 setdash
.50848 .12885 m
.51102 .1288 L
s
.50848 .12885 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.51844 .12959 m
.51844 .12884 L
s
1 .174 0 r
.01 w
[ .05 .05 ] 0 setdash
.51844 .12884 m
.51838 .12884 L
s
.51844 .12884 Mdot
.51847 .12883 m
.51844 .12884 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.59153 .13062 m
.59149 .12884 L
s
1 .157 0 r
.01 w
[ .05 .05 ] 0 setdash
.59149 .12884 m
.59137 .12881 L
s
.59149 .12884 Mdot
1 .174 0 r
.51838 .12884 m
.51834 .12882 L
s
.51838 .12884 Mdot
1 .157 0 r
.59115 .12884 Mdot
.59125 .12881 m
.59115 .12884 L
s
1 .229 0 r
.5884 .12884 m
.5846 .12778 L
s
.5884 .12884 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48951 .13757 m
.489 .142 L
s
0 0 0 r
.004 w
.62262 .12883 Mdot
1 .174 0 r
.01 w
.51847 .12883 Mdot
[ .05 .05 ] 0 setdash
.51845 .1288 m
.51847 .12883 L
s
1 .103 0 r
.55265 .12882 m
.55233 .12867 L
s
.55265 .12882 Mdot
1 .174 0 r
.51834 .12882 m
.51835 .12878 L
s
.51834 .12882 Mdot
1 .096 0 r
.55724 .12882 Mdot
.55587 .12851 m
.55724 .12882 L
s
1 .157 0 r
.59137 .12881 m
.59125 .12881 L
s
.59137 .12881 Mdot
.59125 .12881 Mdot
1 .176 0 r
.51102 .1288 m
.51333 .12872 L
s
.51102 .1288 Mdot
1 .16 0 r
.58719 .1288 Mdot
.58644 .12868 m
.58719 .1288 L
s
1 .174 0 r
.51845 .1288 Mdot
1 .175 0 r
.51833 .12876 m
.51845 .1288 L
s
1 .275 0 r
.58827 .12878 Mdot
.58719 .12849 m
.58827 .12878 L
s
1 .173 0 r
.51835 .12878 m
.51838 .12873 L
s
.51835 .12878 Mdot
1 .167 0 r
.55632 .12877 m
.55984 .12853 L
s
.55632 .12877 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49165 .1345 m
.49161 .13436 L
s
1 .07 0 r
.01 w
.50086 .12876 Mdot
[ .05 .05 ] 0 setdash
.50345 .1285 m
.50086 .12876 L
s
1 .175 0 r
.51833 .12876 Mdot
.51802 .12872 m
.51833 .12876 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55375 .13067 m
.55372 .13125 L
s
1 .173 0 r
.01 w
[ .05 .05 ] 0 setdash
.51838 .12873 m
.51844 .12868 L
s
.51838 .12873 Mdot
1 .223 0 r
.50275 .12872 Mdot
.50775 .1283 m
.50275 .12872 L
s
1 .176 0 r
.51333 .12872 m
.51508 .1287 L
s
.51333 .12872 Mdot
1 .175 0 r
.51802 .12872 Mdot
.51744 .12869 m
.51802 .12872 L
s
.51508 .1287 m
.51646 .12868 L
s
.51508 .1287 Mdot
.51744 .12869 Mdot
.51646 .12868 m
.51744 .12869 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49193 .13555 m
.49176 .13712 L
s
1 .106 0 r
.01 w
.55375 .12868 Mdot
[ .05 .05 ] 0 setdash
.55401 .12849 m
.55375 .12868 L
s
1 .175 0 r
.51646 .12868 Mdot
1 .16 0 r
.58644 .12868 Mdot
.5857 .12856 m
.58644 .12868 L
s
1 .173 0 r
.51844 .12868 m
.51853 .12864 L
s
.51844 .12868 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55241 .13691 m
.55233 .12867 L
s
1 .103 0 r
.01 w
[ .05 .05 ] 0 setdash
.55233 .12867 m
.55202 .12852 L
s
.55233 .12867 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59404 .136 m
.59389 .13535 L
s
1 .169 0 r
.01 w
.52568 .12866 Mdot
[ .05 .05 ] 0 setdash
.52432 .12846 m
.52568 .12866 L
s
1 .173 0 r
.51853 .12864 m
.51864 .12859 L
s
.51853 .12864 Mdot
.51864 .12859 m
.51878 .12853 L
s
.51864 .12859 Mdot
0 0 0 r
.004 w
.42772 .12858 Mdot
1 .16 0 r
.01 w
.5857 .12856 Mdot
.585 .12845 m
.5857 .12856 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51847 .12926 m
.51844 .12959 L
s
.51845 .12982 m
.51847 .12926 L
s
1 .172 0 r
.01 w
[ .05 .05 ] 0 setdash
.51878 .12853 m
.51895 .12846 L
s
.51878 .12853 Mdot
1 .167 0 r
.55984 .12853 m
.56282 .12836 L
s
.55984 .12853 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60772 .14477 m
.60721 .14205 L
s
1 .102 0 r
.01 w
[ .05 .05 ] 0 setdash
.55202 .12852 m
.5517 .12837 L
s
.55202 .12852 Mdot
1 .096 0 r
.55587 .12851 Mdot
.55475 .12825 m
.55587 .12851 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49174 .13508 m
.49165 .1345 L
s
1 .07 0 r
.01 w
.50345 .1285 Mdot
[ .05 .05 ] 0 setdash
.50635 .12826 m
.50345 .1285 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55363 .13174 m
.55369 .13096 L
s
1 .275 0 r
.01 w
.58719 .12849 Mdot
[ .05 .05 ] 0 setdash
.58635 .12828 m
.58719 .12849 L
s
1 .106 0 r
.55401 .12849 Mdot
.55438 .12829 m
.55401 .12849 L
s
1 .172 0 r
.51895 .12846 m
.51915 .12838 L
s
.51895 .12846 Mdot
1 .169 0 r
.52432 .12846 Mdot
1 .17 0 r
.52321 .1283 m
.52432 .12846 L
s
1 .16 0 r
.585 .12845 Mdot
1 .161 0 r
.58437 .12836 m
.585 .12845 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63135 .16691 m
.6303 .16963 L
s
1 .122 0 r
.01 w
[ .05 .05 ] 0 setdash
.57381 .12842 m
.57218 .12771 L
s
.57381 .12842 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38292 .16778 m
.38137 .17512 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.51914 .13295 m
.51915 .12838 L
s
1 .172 0 r
.01 w
[ .05 .05 ] 0 setdash
.51915 .12838 m
.51938 .1283 L
s
.51915 .12838 Mdot
1 .102 0 r
.5517 .12837 m
.5514 .12823 L
s
.5517 .12837 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58325 .17421 m
.58238 .12837 L
s
1 .43 0 r
.01 w
[ .05 .05 ] 0 setdash
.58238 .12837 m
.58001 .12768 L
s
.58238 .12837 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51838 .12955 m
.51834 .12972 L
s
.51844 .12959 m
.51838 .12955 L
s
1 .166 0 r
.01 w
[ .05 .05 ] 0 setdash
.56282 .12836 m
.56572 .12815 L
s
.56282 .12836 Mdot
1 .161 0 r
.58437 .12836 Mdot
.58381 .12829 m
.58437 .12836 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39729 .15537 m
.39653 .1569 L
s
1 .162 0 r
.01 w
[ .05 .05 ] 0 setdash
.58224 .12833 m
.58243 .12831 L
s
.58224 .12833 Mdot
.582 .12832 m
.58224 .12833 L
s
.582 .12832 Mdot
.5817 .12829 m
.582 .12832 L
s
.58243 .12831 m
.58261 .12828 L
s
.58243 .12831 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63582 .16962 m
.63482 .17234 L
s
1 .172 0 r
.01 w
[ .05 .05 ] 0 setdash
.51938 .1283 m
.51961 .12822 L
s
.51938 .1283 Mdot
1 .17 0 r
.52321 .1283 Mdot
.52235 .12817 m
.52321 .1283 L
s
1 .223 0 r
.50775 .1283 Mdot
.51263 .12798 m
.50775 .1283 L
s
0 0 0 r
.004 w
.6197 .12829 Mdot
1 .106 0 r
.01 w
.55438 .12829 Mdot
.55487 .12809 m
.55438 .12829 L
s
1 .162 0 r
.5817 .12829 Mdot
1 .163 0 r
.58137 .12822 m
.5817 .12829 L
s
1 .161 0 r
.58381 .12829 Mdot
.58337 .12825 m
.58381 .12829 L
s
1 .275 0 r
.58635 .12828 Mdot
1 .276 0 r
.58568 .12816 m
.58635 .12828 L
s
1 .162 0 r
.58261 .12828 m
.5828 .12826 L
s
.58261 .12828 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39488 .15838 m
.39409 .15817 L
s
1 .07 0 r
.01 w
.50635 .12826 Mdot
1 .071 0 r
[ .05 .05 ] 0 setdash
.50987 .12795 m
.50635 .12826 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58287 .13215 m
.5828 .12826 L
s
1 .161 0 r
.01 w
[ .05 .05 ] 0 setdash
.5828 .12826 m
.58304 .12824 L
s
.5828 .12826 Mdot
.58337 .12825 Mdot
.58304 .12824 m
.58337 .12825 L
s
1 .096 0 r
.55475 .12825 Mdot
.55385 .12802 m
.55475 .12825 L
s
1 .161 0 r
.58304 .12824 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55372 .13125 m
.55363 .13226 L
s
1 .102 0 r
.01 w
[ .05 .05 ] 0 setdash
.5514 .12823 m
.55111 .12809 L
s
.5514 .12823 Mdot
1 .171 0 r
.51961 .12822 m
.51983 .12814 L
s
.51961 .12822 Mdot
1 .163 0 r
.58137 .12822 Mdot
.581 .12814 m
.58137 .12822 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62712 .16253 m
.62812 .16575 L
s
.51834 .12972 m
.51835 .12998 L
s
0 0 0 r
.004 w
.42992 .12818 Mdot
.53 .8 .95 r
.006 w
.64186 .17481 m
.64091 .17672 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.52234 .14165 m
.52235 .12817 L
s
1 .17 0 r
.01 w
.52235 .12817 Mdot
[ .05 .05 ] 0 setdash
.5217 .12808 m
.52235 .12817 L
s
1 .276 0 r
.58568 .12816 Mdot
.58517 .1281 m
.58568 .12816 L
s
1 .166 0 r
.56572 .12815 m
.56829 .12798 L
s
.56572 .12815 Mdot
1 .171 0 r
.51983 .12814 m
.52006 .12807 L
s
.51983 .12814 Mdot
1 .163 0 r
.581 .12814 Mdot
.58065 .12804 m
.581 .12814 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51832 .13187 m
.51845 .12982 L
s
1 .276 0 r
.01 w
.58517 .1281 Mdot
[ .05 .05 ] 0 setdash
.58475 .12806 m
.58517 .1281 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49069 .14047 m
.4905 .13976 L
s
1 .106 0 r
.01 w
.55487 .12809 Mdot
[ .05 .05 ] 0 setdash
.55549 .12787 m
.55487 .12809 L
s
1 .102 0 r
.55111 .12809 m
.55086 .12797 L
s
.55111 .12809 Mdot
1 .17 0 r
.5217 .12808 Mdot
.5212 .12802 m
.5217 .12808 L
s
1 .171 0 r
.52006 .12807 m
.52029 .12802 L
s
.52006 .12807 Mdot
1 .276 0 r
.58475 .12806 Mdot
.58437 .12802 m
.58475 .12806 L
s
1 .163 0 r
.58065 .12804 Mdot
.58034 .12794 m
.58065 .12804 L
s
1 .096 0 r
.55385 .12802 Mdot
.55315 .12782 m
.55385 .12802 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64408 .19508 m
.64601 .19059 L
s
1 .276 0 r
.01 w
.58437 .12802 Mdot
[ .05 .05 ] 0 setdash
.58394 .12797 m
.58437 .12802 L
s
1 .17 0 r
.5212 .12802 Mdot
.52083 .12799 m
.5212 .12802 L
s
1 .171 0 r
.52029 .12802 m
.52054 .12799 L
s
.52029 .12802 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59424 .13673 m
.59404 .136 L
s
.62183 .18002 m
.62304 .17947 L
s
1 .17 0 r
.01 w
.52083 .12799 Mdot
1 .171 0 r
[ .05 .05 ] 0 setdash
.52054 .12799 m
.52083 .12799 L
s
.52054 .12799 Mdot
1 .223 0 r
.51263 .12798 Mdot
.51735 .12762 m
.51263 .12798 L
s
1 .166 0 r
.56829 .12798 m
.57056 .12782 L
s
.56829 .12798 Mdot
1 .102 0 r
.55086 .12797 m
.55064 .12788 L
s
.55086 .12797 Mdot
1 .276 0 r
.58394 .12797 Mdot
1 .277 0 r
.58345 .1279 m
.58394 .12797 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51835 .12998 m
.51838 .13032 L
s
.49188 .13556 m
.49174 .13508 L
s
1 .071 0 r
.01 w
.50987 .12795 Mdot
[ .05 .05 ] 0 setdash
.5136 .12771 m
.50987 .12795 L
s
1 .163 0 r
.58034 .12794 Mdot
.58008 .12783 m
.58034 .12794 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58362 .1366 m
.58345 .1279 L
s
1 .277 0 r
.01 w
.58345 .1279 Mdot
[ .05 .05 ] 0 setdash
.58287 .1278 m
.58345 .1279 L
s
1 .101 0 r
.55064 .12788 m
.55048 .12782 L
s
.55064 .12788 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62304 .17947 m
.62416 .17683 L
s
.49176 .13712 m
.49156 .13849 L
s
1 .106 0 r
.01 w
.55549 .12787 Mdot
1 .107 0 r
[ .05 .05 ] 0 setdash
.55618 .12763 m
.55549 .12787 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62235 .1586 m
.62151 .15532 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.58023 .13602 m
.58008 .12783 L
s
1 .163 0 r
.01 w
.58008 .12783 Mdot
1 .164 0 r
[ .05 .05 ] 0 setdash
.57981 .12771 m
.58008 .12783 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55326 .14 m
.55315 .12782 L
s
1 .096 0 r
.01 w
.55315 .12782 Mdot
1 .097 0 r
[ .05 .05 ] 0 setdash
.55264 .12765 m
.55315 .12782 L
s
1 .074 0 r
.58198 .12782 m
.57822 .12722 L
s
.58198 .12782 Mdot
1 .166 0 r
.57056 .12782 m
.57257 .12767 L
s
.57056 .12782 Mdot
1 .101 0 r
.55048 .12782 m
.55038 .12779 L
s
.55048 .12782 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40709 .15191 m
.40641 .14881 L
s
1 .1 0 r
.01 w
[ .05 .05 ] 0 setdash
.55056 .1278 m
.55068 .12779 L
s
.55056 .1278 Mdot
.55045 .1278 m
.55056 .1278 L
s
1 .277 0 r
.58287 .1278 Mdot
.58219 .12768 m
.58287 .1278 L
s
1 .1 0 r
.55045 .1278 Mdot
1 .101 0 r
.55037 .12779 m
.55045 .1278 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55359 .13266 m
.55363 .13174 L
s
0 0 0 r
.004 w
.43212 .12779 Mdot
1 .1 0 r
.01 w
[ .05 .05 ] 0 setdash
.55068 .12779 m
.55081 .12777 L
s
.55068 .12779 Mdot
1 .101 0 r
.55038 .12779 m
.55035 .12778 L
s
.55038 .12779 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55038 .12876 m
.55037 .12779 L
s
1 .101 0 r
.01 w
.55037 .12779 Mdot
[ .05 .05 ] 0 setdash
.55035 .12778 m
.55037 .12779 L
s
.55035 .12778 Mdot
0 0 0 r
.004 w
.61678 .12778 Mdot
1 .229 0 r
.01 w
.5846 .12778 m
.58129 .12708 L
s
.5846 .12778 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62206 .16514 m
.62306 .15867 L
s
1 .1 0 r
.01 w
[ .05 .05 ] 0 setdash
.55081 .12777 m
.55094 .12772 L
s
.55081 .12777 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59385 .13836 m
.59371 .14175 L
s
1 .1 0 r
.01 w
[ .05 .05 ] 0 setdash
.55094 .12772 m
.55108 .12768 L
s
.55094 .12772 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39653 .1569 m
.39572 .15767 L
s
1 .122 0 r
.01 w
[ .05 .05 ] 0 setdash
.57218 .12771 m
.57064 .12703 L
s
.57218 .12771 Mdot
1 .164 0 r
.57981 .12771 Mdot
.57951 .12761 m
.57981 .12771 L
s
1 .071 0 r
.5136 .12771 Mdot
.51762 .12742 m
.5136 .12771 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58973 .15141 m
.58931 .15412 L
s
.59161 .13068 m
.59153 .13062 L
s
.59163 .13088 m
.59161 .13068 L
s
.59158 .1314 m
.59163 .13088 L
s
1 .429 0 r
.01 w
[ .05 .05 ] 0 setdash
.58001 .12768 m
.57798 .12709 L
s
.58001 .12768 Mdot
1 .277 0 r
.58219 .12768 Mdot
.58139 .12756 m
.58219 .12768 L
s
1 .099 0 r
.55108 .12768 m
.55123 .12762 L
s
.55108 .12768 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57309 .16093 m
.57257 .12767 L
s
1 .166 0 r
.01 w
[ .05 .05 ] 0 setdash
.57257 .12767 m
.57417 .12754 L
s
.57257 .12767 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39572 .15767 m
.39488 .15838 L
s
1 .097 0 r
.01 w
.55264 .12765 Mdot
[ .05 .05 ] 0 setdash
.55228 .12752 m
.55264 .12765 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51838 .13032 m
.51844 .1308 L
s
.62896 .16729 m
.62812 .16853 L
s
.59153 .13062 m
.59141 .13061 L
s
1 .107 0 r
.01 w
.55618 .12763 Mdot
[ .05 .05 ] 0 setdash
.55693 .1274 m
.55618 .12763 L
s
1 .099 0 r
.55123 .12762 m
.55136 .12757 L
s
.55123 .12762 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59119 .13063 m
.59116 .13089 L
s
.59129 .13065 m
.59119 .13063 L
s
1 .223 0 r
.01 w
.51735 .12762 Mdot
1 .224 0 r
[ .05 .05 ] 0 setdash
.52182 .12733 m
.51735 .12762 L
s
1 .164 0 r
.57951 .12761 Mdot
.57917 .12752 m
.57951 .12761 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59141 .13061 m
.59129 .13065 L
s
1 .099 0 r
.01 w
[ .05 .05 ] 0 setdash
.55136 .12757 m
.55147 .1275 L
s
.55136 .12757 Mdot
1 .277 0 r
.58139 .12756 Mdot
1 .278 0 r
.58051 .12744 m
.58139 .12756 L
s
1 .165 0 r
.57417 .12754 m
.57549 .12746 L
s
.57417 .12754 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59116 .13089 m
.59125 .13244 L
s
1 .164 0 r
.01 w
.57917 .12752 Mdot
[ .05 .05 ] 0 setdash
.57875 .12746 m
.57917 .12752 L
s
1 .097 0 r
.55228 .12752 Mdot
.55204 .12741 m
.55228 .12752 L
s
1 .099 0 r
.55147 .1275 m
.55157 .12743 L
s
.55147 .1275 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59146 .13245 m
.59158 .1314 L
s
.55039 .12825 m
.55035 .12833 L
s
.55049 .12931 m
.55039 .12825 L
s
.49205 .13652 m
.49188 .13556 L
s
1 .165 0 r
.01 w
[ .05 .05 ] 0 setdash
.57549 .12746 m
.57661 .12741 L
s
.57549 .12746 Mdot
1 .164 0 r
.57875 .12746 Mdot
1 .165 0 r
.57821 .12742 m
.57875 .12746 L
s
1 .278 0 r
.58051 .12744 Mdot
.57955 .12729 m
.58051 .12744 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55159 .13018 m
.55157 .12743 L
s
1 .099 0 r
.01 w
[ .05 .05 ] 0 setdash
.55157 .12743 m
.55165 .12736 L
s
.55157 .12743 Mdot
1 .071 0 r
.51762 .12742 Mdot
.52136 .12724 m
.51762 .12742 L
s
1 .165 0 r
.57821 .12742 Mdot
.57751 .1274 m
.57821 .12742 L
s
0 0 0 r
.004 w
.43434 .12741 Mdot
1 .165 0 r
.01 w
.57661 .12741 m
.57751 .1274 L
s
.57661 .12741 Mdot
1 .097 0 r
.55204 .12741 Mdot
.5519 .12734 m
.55204 .12741 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55035 .12833 m
.55038 .12876 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.5571 .14357 m
.55693 .1274 L
s
1 .107 0 r
.01 w
.55693 .1274 Mdot
[ .05 .05 ] 0 setdash
.55772 .12719 m
.55693 .1274 L
s
1 .165 0 r
.57751 .1274 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55363 .13226 m
.55349 .13354 L
s
1 .098 0 r
.01 w
[ .05 .05 ] 0 setdash
.55165 .12736 m
.55171 .12731 L
s
.55165 .12736 Mdot
1 .097 0 r
.5519 .12734 Mdot
.55182 .12729 m
.5519 .12734 L
s
1 .224 0 r
.52182 .12733 Mdot
.5262 .12697 m
.52182 .12733 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62201 .17695 m
.62365 .18235 L
s
1 .098 0 r
.01 w
[ .05 .05 ] 0 setdash
.55171 .12731 m
.55175 .12728 L
s
.55171 .12731 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59451 .13756 m
.59424 .13673 L
s
1 .278 0 r
.01 w
.57955 .12729 Mdot
[ .05 .05 ] 0 setdash
.57855 .12713 m
.57955 .12729 L
s
1 .097 0 r
.55182 .12729 Mdot
1 .098 0 r
.55178 .12727 m
.55182 .12729 L
s
0 0 0 r
.004 w
.61388 .12728 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4909 .14075 m
.49069 .14047 L
s
1 .098 0 r
.01 w
[ .05 .05 ] 0 setdash
.55175 .12728 m
.55178 .12727 L
s
.55175 .12728 Mdot
.55178 .12727 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49156 .13849 m
.49135 .13953 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.52127 .21182 m
.52136 .12724 L
s
1 .071 0 r
.01 w
.52136 .12724 Mdot
[ .05 .05 ] 0 setdash
.52613 .12694 m
.52136 .12724 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51844 .1308 m
.51853 .13127 L
s
1 .074 0 r
.01 w
[ .05 .05 ] 0 setdash
.57822 .12722 m
.5742 .12675 L
s
.57822 .12722 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6067 .14389 m
.60606 .15095 L
s
1 .107 0 r
.01 w
.55772 .12719 Mdot
[ .05 .05 ] 0 setdash
.5585 .127 m
.55772 .12719 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63131 .17096 m
.63238 .17089 L
s
.55178 .12743 m
.55183 .12832 L
s
.55176 .12792 m
.55178 .12743 L
s
1 .278 0 r
.01 w
.57855 .12713 Mdot
[ .05 .05 ] 0 setdash
.57744 .127 m
.57855 .12713 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55038 .12876 m
.55046 .12903 L
s
1 .429 0 r
.01 w
[ .05 .05 ] 0 setdash
.57798 .12709 m
.57633 .12664 L
s
.57798 .12709 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58252 .19305 m
.58129 .12708 L
s
1 .228 0 r
.01 w
[ .05 .05 ] 0 setdash
.58129 .12708 m
.57792 .12641 L
s
.58129 .12708 Mdot
0 0 0 r
.004 w
.43656 .12704 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5711 .15725 m
.57064 .12703 L
s
1 .122 0 r
.01 w
[ .05 .05 ] 0 setdash
.57064 .12703 m
.5693 .12656 L
s
.57064 .12703 Mdot
1 .107 0 r
.5585 .127 Mdot
1 .108 0 r
.55925 .12687 m
.5585 .127 L
s
1 .278 0 r
.57744 .127 Mdot
.57635 .12689 m
.57744 .127 L
s
1 .224 0 r
.5262 .12697 Mdot
.52984 .12675 m
.5262 .12697 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60833 .14776 m
.60772 .14477 L
s
.55046 .12903 m
.55057 .12932 L
s
1 .071 0 r
.01 w
.52613 .12694 Mdot
1 .072 0 r
[ .05 .05 ] 0 setdash
.53038 .12673 m
.52613 .12694 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55359 .13362 m
.55359 .13266 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56133 .12848 m
.56131 .12691 L
s
1 .337 0 r
.01 w
[ .05 .05 ] 0 setdash
.56131 .12691 m
.56142 .12691 L
s
.56131 .12691 Mdot
1 .338 0 r
.56129 .12689 m
.56131 .12691 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62812 .16575 m
.62921 .16847 L
s
1 .337 0 r
.01 w
[ .05 .05 ] 0 setdash
.56142 .12691 m
.5616 .12688 L
s
.56142 .12691 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34503 .20765 m
.34314 .20809 L
s
.59125 .13398 m
.59146 .13245 L
s
1 .338 0 r
.01 w
.56129 .12689 Mdot
[ .05 .05 ] 0 setdash
.56137 .12684 m
.56129 .12689 L
s
1 .278 0 r
.57635 .12689 Mdot
1 .279 0 r
.57527 .12671 m
.57635 .12689 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3777 .19119 m
.37931 .19668 L
s
.60613 .14428 m
.60549 .14948 L
s
1 .337 0 r
.01 w
[ .05 .05 ] 0 setdash
.5616 .12688 m
.56183 .12683 L
s
.5616 .12688 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49135 .13953 m
.49112 .14015 L
s
1 .108 0 r
.01 w
.55925 .12687 Mdot
[ .05 .05 ] 0 setdash
.55996 .12676 m
.55925 .12687 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51853 .13127 m
.51864 .13173 L
s
1 .338 0 r
.01 w
.56137 .12684 Mdot
[ .05 .05 ] 0 setdash
.56155 .12676 m
.56137 .12684 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55173 .12877 m
.55176 .12792 L
s
1 .337 0 r
.01 w
[ .05 .05 ] 0 setdash
.56183 .12683 m
.56209 .12676 L
s
.56183 .12683 Mdot
0 0 0 r
.004 w
.611 .12681 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55067 .13075 m
.55049 .12931 L
s
.49112 .14015 m
.4909 .14075 L
s
.55057 .12932 m
.5507 .12974 L
s
1 .338 0 r
.01 w
.56155 .12676 Mdot
[ .05 .05 ] 0 setdash
.56184 .12666 m
.56155 .12676 L
s
1 .108 0 r
.55996 .12676 Mdot
.56064 .12668 m
.55996 .12676 L
s
1 .337 0 r
.56209 .12676 m
.56237 .12668 L
s
.56209 .12676 Mdot
1 .224 0 r
.52984 .12675 Mdot
.53397 .12633 m
.52984 .12675 L
s
1 .074 0 r
.5742 .12675 m
.57056 .12614 L
s
.5742 .12675 Mdot
1 .072 0 r
.53038 .12673 Mdot
.53445 .12653 m
.53038 .12673 L
s
1 .279 0 r
.57527 .12671 Mdot
.57411 .12656 m
.57527 .12671 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34715 .20365 m
.34503 .20765 L
s
1 .108 0 r
.01 w
.56064 .12668 Mdot
[ .05 .05 ] 0 setdash
.56123 .12662 m
.56064 .12668 L
s
0 0 0 r
.004 w
.43879 .12668 Mdot
1 .336 0 r
.01 w
.56237 .12668 m
.56264 .12659 L
s
.56237 .12668 Mdot
1 .338 0 r
.56184 .12666 Mdot
1 .339 0 r
.56221 .12654 m
.56184 .12666 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60806 .14993 m
.60721 .14497 L
s
1 .429 0 r
.01 w
[ .05 .05 ] 0 setdash
.57633 .12664 m
.57484 .12622 L
s
.57633 .12664 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59125 .13244 m
.59148 .1352 L
s
.51801 .13526 m
.51832 .13187 L
s
.49226 .13754 m
.49205 .13652 L
s
1 .108 0 r
.01 w
.56123 .12662 Mdot
[ .05 .05 ] 0 setdash
.56172 .12657 m
.56123 .12662 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55183 .12832 m
.55192 .12958 L
s
1 .336 0 r
.01 w
[ .05 .05 ] 0 setdash
.56264 .12659 m
.56289 .12649 L
s
.56264 .12659 Mdot
1 .332 0 r
.56479 .12658 m
.56476 .12657 L
s
.56479 .12658 Mdot
1 .333 0 r
.56479 .12656 m
.56479 .12658 L
s
1 .108 0 r
.56172 .12657 Mdot
1 .109 0 r
.56209 .12653 m
.56172 .12657 L
s
1 .332 0 r
.56476 .12657 m
.56469 .12653 L
s
.56476 .12657 Mdot
1 .333 0 r
.56479 .12656 Mdot
.56474 .12652 m
.56479 .12656 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57445 .14726 m
.57411 .12656 L
s
1 .279 0 r
.01 w
.57411 .12656 Mdot
[ .05 .05 ] 0 setdash
.57303 .1264 m
.57411 .12656 L
s
1 .121 0 r
.5693 .12656 m
.56806 .12616 L
s
.5693 .12656 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58248 .13091 m
.58266 .13127 L
s
.58229 .13108 m
.58248 .13091 L
s
1 .339 0 r
.01 w
.56221 .12654 Mdot
[ .05 .05 ] 0 setdash
.56262 .1264 m
.56221 .12654 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37824 .1778 m
.37695 .17513 L
s
.59486 .13846 m
.59451 .13756 L
s
1 .072 0 r
.01 w
.53445 .12653 Mdot
[ .05 .05 ] 0 setdash
.53925 .12621 m
.53445 .12653 L
s
1 .332 0 r
.56469 .12653 m
.56461 .12648 L
s
.56469 .12653 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3855 .16794 m
.38414 .17267 L
s
1 .109 0 r
.01 w
.56209 .12653 Mdot
[ .05 .05 ] 0 setdash
.56235 .12648 m
.56209 .12653 L
s
1 .333 0 r
.56474 .12652 Mdot
.56466 .12646 m
.56474 .12652 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5613 .12746 m
.56133 .12848 L
s
.5614 .1297 m
.5613 .12746 L
s
.5919 .15448 m
.59152 .1522 L
s
1 .336 0 r
.01 w
[ .05 .05 ] 0 setdash
.56289 .12649 m
.56311 .1264 L
s
.56289 .12649 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38968 .17371 m
.38839 .16584 L
s
1 .332 0 r
.01 w
[ .05 .05 ] 0 setdash
.56461 .12648 m
.56451 .12641 L
s
.56461 .12648 Mdot
1 .109 0 r
.56235 .12648 Mdot
.56249 .12642 m
.56235 .12648 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5507 .12974 m
.55083 .13023 L
s
1 .333 0 r
.01 w
.56466 .12646 Mdot
[ .05 .05 ] 0 setdash
.56455 .12638 m
.56466 .12646 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51864 .13173 m
.51877 .13236 L
s
1 .118 0 r
.01 w
[ .05 .05 ] 0 setdash
.56204 .12646 m
.56208 .12645 L
s
.56204 .12646 Mdot
.56202 .12645 m
.56204 .12646 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58207 .13193 m
.58229 .13108 L
s
1 .118 0 r
.01 w
[ .05 .05 ] 0 setdash
.56208 .12645 m
.56213 .12644 L
s
.56208 .12645 Mdot
.56202 .12645 Mdot
1 .119 0 r
.56204 .12642 m
.56202 .12645 L
s
1 .118 0 r
.56213 .12644 m
.56218 .12642 L
s
.56213 .12644 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56251 .12784 m
.56249 .12642 L
s
1 .109 0 r
.01 w
.56249 .12642 Mdot
[ .05 .05 ] 0 setdash
.56254 .12637 m
.56249 .12642 L
s
1 .118 0 r
.56218 .12642 m
.56222 .12641 L
s
.56218 .12642 Mdot
1 .119 0 r
.56204 .12642 Mdot
.56211 .12637 m
.56204 .12642 L
s
1 .332 0 r
.56451 .12641 m
.56441 .12633 L
s
.56451 .12641 Mdot
1 .228 0 r
.57792 .12641 m
.57469 .12586 L
s
.57792 .12641 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56222 .12661 m
.56222 .12641 L
s
1 .117 0 r
.01 w
[ .05 .05 ] 0 setdash
.56222 .12641 m
.56223 .1264 L
s
.56222 .12641 Mdot
1 .279 0 r
.57303 .1264 Mdot
.57206 .12625 m
.57303 .1264 L
s
1 .117 0 r
.56223 .1264 m
.56224 .1264 L
s
.56223 .1264 Mdot
1 .111 0 r
.56224 .1264 m
.56224 .1264 L
s
.56224 .1264 Mdot
.56224 .1264 m
.56224 .1264 L
s
.56224 .1264 Mdot
1 .114 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .115 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .116 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .117 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .111 0 r
.56224 .1264 Mdot
1 .112 0 r
.56224 .1264 Mdot
1 .113 0 r
.56224 .1264 Mdot
1 .112 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .113 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .114 0 r
.56224 .1264 Mdot
1 .115 0 r
.56224 .1264 Mdot
.56224 .1264 Mdot
.56224 .1264 Mdot
1 .116 0 r
.56224 .1264 Mdot
1 .111 0 r
.56224 .1264 Mdot
1 .117 0 r
.56224 .1264 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56223 .12644 m
.56224 .1264 L
s
.56224 .1264 m
.56224 .12644 L
s
1 .11 0 r
.01 w
[ .05 .05 ] 0 setdash
.56224 .1264 m
.56226 .12639 L
s
.56224 .1264 Mdot
1 .339 0 r
.56262 .1264 Mdot
.56304 .12625 m
.56262 .1264 L
s
1 .336 0 r
.56311 .1264 m
.5633 .1263 L
s
.56311 .1264 Mdot
1 .11 0 r
.56226 .12639 m
.56231 .12637 L
s
.56226 .12639 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5646 .12993 m
.56455 .12638 L
s
1 .333 0 r
.01 w
.56455 .12638 Mdot
[ .05 .05 ] 0 setdash
.56445 .12629 m
.56455 .12638 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56222 .12661 m
.56223 .12644 L
s
1 .11 0 r
.01 w
[ .05 .05 ] 0 setdash
.56231 .12637 m
.56239 .12635 L
s
.56231 .12637 Mdot
1 .109 0 r
.56254 .12637 Mdot
.56252 .12634 m
.56254 .12637 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56224 .12644 m
.56227 .12664 L
s
1 .119 0 r
.01 w
.56211 .12637 Mdot
[ .05 .05 ] 0 setdash
.56225 .12629 m
.56211 .12637 L
s
1 .11 0 r
.56239 .12635 m
.56246 .12634 L
s
.56239 .12635 Mdot
0 0 0 r
.004 w
.60812 .12635 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62327 .16213 m
.62235 .1586 L
s
1 .109 0 r
.01 w
.56252 .12634 Mdot
1 .11 0 r
[ .05 .05 ] 0 setdash
.56246 .12634 m
.56252 .12634 L
s
.56246 .12634 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.53419 .19607 m
.53397 .12633 L
s
1 .224 0 r
.01 w
.53397 .12633 Mdot
[ .05 .05 ] 0 setdash
.53732 .12606 m
.53397 .12633 L
s
1 .331 0 r
.56441 .12633 m
.56433 .12625 L
s
.56441 .12633 Mdot
0 0 0 r
.004 w
.44102 .12633 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55167 .12955 m
.55173 .12877 L
s
1 .336 0 r
.01 w
[ .05 .05 ] 0 setdash
.5633 .1263 m
.56346 .12621 L
s
.5633 .1263 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55349 .13354 m
.55328 .13483 L
s
1 .333 0 r
.01 w
.56445 .12629 Mdot
1 .334 0 r
[ .05 .05 ] 0 setdash
.56435 .12621 m
.56445 .12629 L
s
1 .119 0 r
.56225 .12629 Mdot
.56246 .12617 m
.56225 .12629 L
s
1 .315 0 r
.56352 .12628 m
.56355 .12626 L
s
.56352 .12628 Mdot
.5635 .12628 m
.56352 .12628 L
s
.5635 .12628 Mdot
1 .316 0 r
.56351 .12626 m
.5635 .12628 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56218 .12692 m
.56222 .12661 L
s
1 .315 0 r
.01 w
[ .05 .05 ] 0 setdash
.56355 .12626 m
.56361 .12623 L
s
.56355 .12626 Mdot
1 .316 0 r
.56351 .12626 Mdot
.56353 .12622 m
.56351 .12626 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56352 .12631 m
.56356 .1274 L
s
.56351 .12704 m
.56352 .12631 L
s
.58266 .13127 m
.58287 .13215 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56435 .12838 m
.56433 .12625 L
s
1 .331 0 r
.01 w
[ .05 .05 ] 0 setdash
.56433 .12625 m
.56426 .12618 L
s
.56433 .12625 Mdot
1 .279 0 r
.57206 .12625 Mdot
.57117 .12611 m
.57206 .12625 L
s
1 .339 0 r
.56304 .12625 Mdot
.56344 .12609 m
.56304 .12625 L
s
1 .315 0 r
.56361 .12623 m
.5637 .12617 L
s
.56361 .12623 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56227 .12664 m
.56232 .12702 L
s
1 .316 0 r
.01 w
.56353 .12622 Mdot
[ .05 .05 ] 0 setdash
.56357 .12617 m
.56353 .12622 L
s
1 .429 0 r
.57484 .12622 m
.57357 .12583 L
s
.57484 .12622 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5635 .12905 m
.56346 .12621 L
s
1 .335 0 r
.01 w
[ .05 .05 ] 0 setdash
.56346 .12621 m
.56359 .12614 L
s
.56346 .12621 Mdot
1 .072 0 r
.53925 .12621 Mdot
.54359 .126 m
.53925 .12621 L
s
1 .334 0 r
.56435 .12621 Mdot
.56426 .12613 m
.56435 .12621 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63025 .17014 m
.63131 .17096 L
s
1 .289 0 r
.01 w
[ .05 .05 ] 0 setdash
.5643 .12618 m
.56437 .12618 L
s
.5643 .12618 Mdot
1 .29 0 r
.56425 .12617 m
.5643 .12618 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56439 .12808 m
.56437 .12618 L
s
1 .289 0 r
.01 w
[ .05 .05 ] 0 setdash
.56437 .12618 m
.56442 .12616 L
s
.56437 .12618 Mdot
1 .331 0 r
.56426 .12618 m
.56421 .12611 L
s
.56426 .12618 Mdot
1 .315 0 r
.5637 .12617 m
.5638 .12611 L
s
.5637 .12617 Mdot
1 .119 0 r
.56246 .12617 Mdot
.56274 .12603 m
.56246 .12617 L
s
1 .316 0 r
.56357 .12617 Mdot
.5636 .12611 m
.56357 .12617 L
s
1 .29 0 r
.56425 .12617 Mdot
.56426 .12615 m
.56425 .12617 L
s
1 .289 0 r
.56442 .12616 m
.56444 .12614 L
s
.56442 .12616 Mdot
1 .121 0 r
.56806 .12616 m
.56696 .12585 L
s
.56806 .12616 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56203 .12688 m
.56205 .12718 L
s
.56205 .12698 m
.56203 .12688 L
s
1 .29 0 r
.01 w
.56426 .12615 Mdot
[ .05 .05 ] 0 setdash
.56434 .12612 m
.56426 .12615 L
s
1 .289 0 r
.56444 .12614 m
.56441 .12612 L
s
.56444 .12614 Mdot
1 .074 0 r
.57056 .12614 m
.5667 .12581 L
s
.57056 .12614 Mdot
1 .335 0 r
.56359 .12614 m
.56371 .12607 L
s
.56359 .12614 Mdot
1 .334 0 r
.56426 .12613 Mdot
.56416 .12607 m
.56426 .12613 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56614 .1294 m
.5661 .12613 L
s
1 .352 0 r
.01 w
[ .05 .05 ] 0 setdash
.5661 .12613 m
.56595 .12612 L
s
.5661 .12613 Mdot
.5662 .12612 m
.5661 .12613 L
s
.5662 .12612 Mdot
1 .353 0 r
.56627 .12612 m
.5662 .12612 L
s
1 .289 0 r
.56441 .12612 m
.56436 .12611 L
s
.56441 .12612 Mdot
1 .29 0 r
.56434 .12612 Mdot
.56446 .1261 m
.56434 .12612 L
s
1 .352 0 r
.56595 .12612 m
.56579 .1261 L
s
.56595 .12612 Mdot
1 .353 0 r
.56627 .12612 Mdot
.56631 .12611 m
.56627 .12612 L
s
1 .331 0 r
.56421 .12611 m
.56418 .12607 L
s
.56421 .12611 Mdot
1 .353 0 r
.56631 .12611 Mdot
.56635 .12611 m
.56631 .12611 L
s
1 .316 0 r
.5636 .12611 Mdot
.56362 .12605 m
.5636 .12611 L
s
1 .279 0 r
.57117 .12611 Mdot
1 .28 0 r
.5704 .12598 m
.57117 .12611 L
s
1 .288 0 r
.56436 .12611 m
.56428 .12609 L
s
.56436 .12611 Mdot
1 .353 0 r
.56635 .12611 Mdot
.56637 .1261 m
.56635 .12611 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56385 .12999 m
.5638 .12611 L
s
1 .314 0 r
.01 w
[ .05 .05 ] 0 setdash
.5638 .12611 m
.56395 .12602 L
s
.5638 .12611 Mdot
1 .352 0 r
.56579 .1261 m
.56562 .12607 L
s
.56579 .1261 Mdot
1 .353 0 r
.56637 .1261 Mdot
.56636 .12609 m
.56637 .1261 L
s
1 .29 0 r
.56446 .1261 Mdot
1 .291 0 r
.56462 .12606 m
.56446 .1261 L
s
1 .339 0 r
.56344 .12609 Mdot
.56383 .12595 m
.56344 .12609 L
s
1 .288 0 r
.56428 .12609 m
.56423 .12608 L
s
.56428 .12609 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55083 .13023 m
.55097 .13069 L
s
1 .353 0 r
.01 w
.56636 .12609 Mdot
1 .354 0 r
[ .05 .05 ] 0 setdash
.56633 .12608 m
.56636 .12609 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5648 .1273 m
.56478 .12816 L
s
.5648 .12728 m
.5648 .1273 L
s
.56214 .12719 m
.56218 .12692 L
s
1 .288 0 r
.01 w
[ .05 .05 ] 0 setdash
.56423 .12608 m
.56419 .12607 L
s
.56423 .12608 Mdot
1 .354 0 r
.56633 .12608 Mdot
.56629 .12606 m
.56633 .12608 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56477 .12821 m
.5648 .12728 L
s
1 .334 0 r
.01 w
.56416 .12607 Mdot
[ .05 .05 ] 0 setdash
.56405 .12603 m
.56416 .12607 L
s
1 .335 0 r
.56371 .12607 m
.56382 .12602 L
s
.56371 .12607 Mdot
1 .288 0 r
.56419 .12607 m
.56416 .12606 L
s
.56419 .12607 Mdot
1 .351 0 r
.56562 .12607 m
.56546 .12602 L
s
.56562 .12607 Mdot
1 .331 0 r
.56418 .12607 m
.56413 .12603 L
s
.56418 .12607 Mdot
1 .354 0 r
.56629 .12606 Mdot
.56621 .12605 m
.56629 .12606 L
s
1 .291 0 r
.56462 .12606 Mdot
.56482 .12602 m
.56462 .12606 L
s
1 .288 0 r
.56416 .12606 m
.56418 .12605 L
s
.56416 .12606 Mdot
1 .224 0 r
.53732 .12606 Mdot
1 .225 0 r
.54027 .12584 m
.53732 .12606 L
s
1 .345 0 r
.56443 .12606 m
.5645 .12606 L
s
.56443 .12606 Mdot
1 .346 0 r
.56439 .12603 m
.56443 .12606 L
s
1 .345 0 r
.5645 .12606 m
.56459 .12604 L
s
.5645 .12606 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62921 .16847 m
.63025 .17014 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56364 .12761 m
.56362 .12605 L
s
1 .316 0 r
.01 w
.56362 .12605 Mdot
1 .317 0 r
[ .05 .05 ] 0 setdash
.56363 .126 m
.56362 .12605 L
s
1 .287 0 r
.56418 .12605 m
.56427 .12604 L
s
.56418 .12605 Mdot
1 .354 0 r
.56621 .12605 Mdot
.56614 .12603 m
.56621 .12605 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5643 .12846 m
.56427 .12604 L
s
1 .287 0 r
.01 w
[ .05 .05 ] 0 setdash
.56427 .12604 m
.56442 .12603 L
s
.56427 .12604 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56213 .12798 m
.56205 .12698 L
s
1 .345 0 r
.01 w
[ .05 .05 ] 0 setdash
.56459 .12604 m
.56469 .126 L
s
.56459 .12604 Mdot
1 .346 0 r
.56439 .12603 Mdot
.56438 .12599 m
.56439 .12603 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56615 .12682 m
.56614 .12603 L
s
1 .354 0 r
.01 w
.56614 .12603 Mdot
[ .05 .05 ] 0 setdash
.56605 .12601 m
.56614 .12603 L
s
1 .33 0 r
.56413 .12603 m
.56406 .12601 L
s
.56413 .12603 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56282 .13272 m
.56274 .12603 L
s
1 .119 0 r
.01 w
.56274 .12603 Mdot
1 .12 0 r
[ .05 .05 ] 0 setdash
.56309 .12588 m
.56274 .12603 L
s
1 .334 0 r
.56405 .12603 Mdot
1 .335 0 r
.56394 .12601 m
.56405 .12603 L
s
1 .287 0 r
.56442 .12603 m
.56464 .12601 L
s
.56442 .12603 Mdot
1 .291 0 r
.56482 .12602 Mdot
.56503 .12599 m
.56482 .12602 L
s
1 .335 0 r
.56382 .12602 m
.56394 .12601 L
s
.56382 .12602 Mdot
1 .351 0 r
.56546 .12602 m
.56532 .12596 L
s
.56546 .12602 Mdot
1 .286 0 r
.56602 .12602 m
.56637 .12601 L
s
.56602 .12602 Mdot
.56563 .12601 m
.56602 .12602 L
s
1 .314 0 r
.56395 .12602 m
.56411 .12591 L
s
.56395 .12602 Mdot
1 .287 0 r
.56464 .12601 m
.56492 .12601 L
s
.56464 .12601 Mdot
1 .286 0 r
.56563 .12601 Mdot
.56526 .12601 m
.56563 .12601 L
s
1 .287 0 r
.56492 .12601 m
.56526 .12601 L
s
.56492 .12601 Mdot
1 .286 0 r
.56526 .12601 Mdot
1 .335 0 r
.56394 .12601 Mdot
1 .286 0 r
.56637 .12601 m
.56669 .126 L
s
.56637 .12601 Mdot
1 .354 0 r
.56605 .12601 Mdot
1 .355 0 r
.56597 .12597 m
.56605 .12601 L
s
1 .33 0 r
.56406 .12601 m
.56397 .12599 L
s
.56406 .12601 Mdot
1 .294 0 r
.56723 .12601 m
.5671 .126 L
s
.56723 .12601 Mdot
.5673 .12599 m
.56723 .12601 L
s
.5671 .126 m
.56696 .12599 L
s
.5671 .126 Mdot
1 .285 0 r
.56669 .126 m
.56696 .12599 L
s
.56669 .126 Mdot
1 .317 0 r
.56363 .126 Mdot
.56365 .12596 m
.56363 .126 L
s
1 .345 0 r
.56469 .126 m
.56478 .12594 L
s
.56469 .126 Mdot
1 .072 0 r
.54359 .126 Mdot
1 .073 0 r
.54762 .12583 m
.54359 .126 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56439 .12742 m
.56438 .12599 L
s
1 .346 0 r
.01 w
.56438 .12599 Mdot
[ .05 .05 ] 0 setdash
.56439 .12594 m
.56438 .12599 L
s
1 .294 0 r
.5673 .12599 Mdot
1 .295 0 r
.56729 .12596 m
.5673 .12599 L
s
1 .285 0 r
.56696 .12599 m
.56717 .12597 L
s
.56696 .12599 Mdot
1 .294 0 r
.56696 .12599 m
.56684 .12597 L
s
.56696 .12599 Mdot
1 .33 0 r
.56397 .12599 m
.5639 .12598 L
s
.56397 .12599 Mdot
1 .291 0 r
.56503 .12599 Mdot
.56525 .12596 m
.56503 .12599 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59371 .14175 m
.59352 .14521 L
s
0 0 0 r
.004 w
.44327 .12598 Mdot
1 .33 0 r
.01 w
[ .05 .05 ] 0 setdash
.5639 .12598 m
.56383 .12597 L
s
.5639 .12598 Mdot
1 .28 0 r
.5704 .12598 Mdot
.56971 .12585 m
.5704 .12598 L
s
1 .355 0 r
.56597 .12597 Mdot
.56587 .12593 m
.56597 .12597 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56721 .12878 m
.56717 .12597 L
s
1 .285 0 r
.01 w
[ .05 .05 ] 0 setdash
.56717 .12597 m
.56732 .12595 L
s
.56717 .12597 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55366 .13455 m
.55359 .13362 L
s
1 .329 0 r
.01 w
[ .05 .05 ] 0 setdash
.56383 .12597 m
.56377 .12595 L
s
.56383 .12597 Mdot
1 .294 0 r
.56684 .12597 m
.56675 .12594 L
s
.56684 .12597 Mdot
1 .295 0 r
.56729 .12596 Mdot
.5672 .12592 m
.56729 .12596 L
s
1 .351 0 r
.56532 .12596 m
.56519 .12588 L
s
.56532 .12596 Mdot
1 .291 0 r
.56525 .12596 Mdot
.56546 .12593 m
.56525 .12596 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56205 .12718 m
.56209 .12729 L
s
1 .317 0 r
.01 w
.56365 .12596 Mdot
[ .05 .05 ] 0 setdash
.56367 .12592 m
.56365 .12596 L
s
1 .285 0 r
.56732 .12595 m
.56741 .12594 L
s
.56732 .12595 Mdot
1 .329 0 r
.56377 .12595 m
.56373 .12594 L
s
.56377 .12595 Mdot
1 .339 0 r
.56383 .12595 Mdot
1 .34 0 r
.56419 .1258 m
.56383 .12595 L
s
1 .425 0 r
.56363 .12595 m
.56351 .12593 L
s
.56363 .12595 Mdot
.56386 .1259 m
.56363 .12595 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56679 .12842 m
.56675 .12594 L
s
1 .293 0 r
.01 w
[ .05 .05 ] 0 setdash
.56675 .12594 m
.56668 .12592 L
s
.56675 .12594 Mdot
1 .345 0 r
.56478 .12594 m
.56486 .12587 L
s
.56478 .12594 Mdot
1 .424 0 r
.56351 .12594 m
.56361 .12592 L
s
.56351 .12594 Mdot
.56351 .12593 m
.56351 .12594 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56374 .12657 m
.56373 .12594 L
s
1 .329 0 r
.01 w
[ .05 .05 ] 0 setdash
.56373 .12594 m
.56371 .12593 L
s
.56373 .12594 Mdot
1 .346 0 r
.56439 .12594 Mdot
.56442 .12587 m
.56439 .12594 L
s
1 .285 0 r
.56741 .12594 m
.56745 .12592 L
s
.56741 .12594 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59095 .1358 m
.59125 .13398 L
s
1 .424 0 r
.01 w
.56351 .12593 Mdot
.53 .8 .95 r
.006 w
.56255 .12701 m
.56251 .12784 L
s
.56253 .12731 m
.56255 .12701 L
s
.56232 .12702 m
.5624 .12738 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56553 .13093 m
.56546 .12593 L
s
1 .291 0 r
.01 w
.56546 .12593 Mdot
1 .292 0 r
[ .05 .05 ] 0 setdash
.56568 .1259 m
.56546 .12593 L
s
1 .329 0 r
.56371 .12593 m
.5637 .12592 L
s
.56371 .12593 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5509 .13237 m
.55067 .13075 L
s
1 .355 0 r
.01 w
.56587 .12593 Mdot
[ .05 .05 ] 0 setdash
.5658 .12587 m
.56587 .12593 L
s
1 .424 0 r
.56361 .12592 m
.56381 .12587 L
s
.56361 .12592 Mdot
1 .284 0 r
.56745 .12592 m
.56745 .12592 L
s
.56745 .12592 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51877 .13236 m
.51894 .13272 L
s
1 .329 0 r
.01 w
[ .05 .05 ] 0 setdash
.5637 .12592 m
.56368 .12591 L
s
.5637 .12592 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56209 .12729 m
.56214 .12719 L
s
1 .293 0 r
.01 w
[ .05 .05 ] 0 setdash
.56668 .12592 m
.56662 .1259 L
s
.56668 .12592 Mdot
1 .317 0 r
.56367 .12592 Mdot
.56369 .1259 m
.56367 .12592 L
s
1 .284 0 r
.56726 .12592 m
.56715 .12591 L
s
.56726 .12592 Mdot
.56734 .12592 m
.56726 .12592 L
s
.56745 .12592 m
.56741 .12592 L
s
.56745 .12592 Mdot
.56734 .12592 Mdot
.56741 .12592 m
.56734 .12592 L
s
1 .295 0 r
.5672 .12592 Mdot
.56704 .12586 m
.5672 .12592 L
s
1 .284 0 r
.56741 .12592 Mdot
1 .32 0 r
.56366 .12592 m
.56366 .12592 L
s
.56366 .12592 Mdot
1 .325 0 r
.56366 .12592 Mdot
1 .326 0 r
.56366 .12592 Mdot
1 .327 0 r
.56366 .12592 Mdot
.56366 .12591 m
.56366 .12592 L
s
1 .319 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .325 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .327 0 r
.56366 .12592 Mdot
1 .321 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .322 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .323 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .324 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .325 0 r
.56366 .12592 Mdot
1 .326 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .319 0 r
.56366 .12592 m
.56366 .12591 L
s
.56366 .12592 Mdot
1 .32 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .321 0 r
.56366 .12592 Mdot
.56366 .12592 Mdot
1 .32 0 r
.56366 .12592 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12594 m
.56366 .12592 L
s
.56366 .12592 m
.56366 .12593 L
s
1 .328 0 r
.01 w
[ .05 .05 ] 0 setdash
.56368 .12591 m
.56366 .12591 L
s
.56368 .12591 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56366 .12594 m
.56366 .12591 L
s
1 .327 0 r
.01 w
.56366 .12591 Mdot
[ .05 .05 ] 0 setdash
.56365 .12591 m
.56366 .12591 L
s
1 .319 0 r
.56366 .12591 m
.56366 .12591 L
s
.56366 .12591 Mdot
1 .314 0 r
.56411 .12591 m
.56429 .12581 L
s
.56411 .12591 Mdot
1 .327 0 r
.56365 .12591 Mdot
.56364 .12591 m
.56365 .12591 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56366 .12599 m
.56366 .12591 L
s
1 .319 0 r
.01 w
[ .05 .05 ] 0 setdash
.56366 .12591 m
.56366 .12591 L
s
.56366 .12591 Mdot
1 .283 0 r
.56715 .12591 m
.56703 .12589 L
s
.56715 .12591 Mdot
0 0 0 r
.004 w
.60526 .12591 Mdot
1 .328 0 r
.01 w
.56366 .12591 m
.56365 .12591 L
s
.56366 .12591 Mdot
1 .327 0 r
.56364 .12591 Mdot
1 .328 0 r
.56364 .12591 m
.56364 .12591 L
s
.56364 .12591 Mdot
.56364 .12591 m
.56364 .12591 L
s
.56365 .12591 m
.56364 .12591 L
s
.56365 .12591 Mdot
.56364 .12591 Mdot
1 .318 0 r
.56366 .12591 m
.56366 .1259 L
s
.56366 .12591 Mdot
1 .292 0 r
.56568 .1259 Mdot
.56589 .12588 m
.56568 .1259 L
s
1 .293 0 r
.56662 .1259 m
.56657 .12589 L
s
.56662 .1259 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12593 m
.56366 .12599 L
s
.56366 .12601 m
.56366 .12594 L
s
1 .425 0 r
.01 w
.56386 .1259 Mdot
[ .05 .05 ] 0 setdash
.56418 .12584 m
.56386 .1259 L
s
1 .318 0 r
.56366 .1259 m
.56368 .12589 L
s
.56366 .1259 Mdot
1 .317 0 r
.56369 .1259 Mdot
1 .318 0 r
.5637 .12589 m
.56369 .1259 L
s
1 .283 0 r
.56703 .12589 m
.56691 .12586 L
s
.56703 .12589 Mdot
1 .318 0 r
.56368 .12589 m
.5637 .12589 L
s
.56368 .12589 Mdot
.5637 .12589 Mdot
.5637 .12589 m
.5637 .12589 L
s
.5637 .12589 Mdot
1 .293 0 r
.56657 .12589 m
.5665 .12587 L
s
.56657 .12589 Mdot
1 .292 0 r
.56589 .12588 Mdot
.56606 .12587 m
.56589 .12588 L
s
1 .351 0 r
.56519 .12588 m
.56509 .12579 L
s
.56519 .12588 Mdot
1 .12 0 r
.56309 .12588 Mdot
.5635 .12573 m
.56309 .12588 L
s
1 .292 0 r
.56606 .12587 Mdot
.56623 .12586 m
.56606 .12587 L
s
1 .293 0 r
.5665 .12587 m
.56638 .12586 L
s
.5665 .12587 Mdot
1 .344 0 r
.56486 .12587 m
.56492 .1258 L
s
.56486 .12587 Mdot
1 .424 0 r
.56381 .12587 m
.56406 .12579 L
s
.56381 .12587 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56364 .12596 m
.56364 .12606 L
s
.56365 .12597 m
.56364 .12596 L
s
.5818 .13322 m
.58207 .13193 L
s
.55159 .13018 m
.55167 .12955 L
s
1 .346 0 r
.01 w
.56442 .12587 Mdot
[ .05 .05 ] 0 setdash
.56447 .1258 m
.56442 .12587 L
s
1 .355 0 r
.5658 .12587 Mdot
.56572 .1258 m
.5658 .12587 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12611 m
.56365 .12597 L
s
1 .292 0 r
.01 w
[ .05 .05 ] 0 setdash
.56638 .12586 m
.56623 .12586 L
s
.56638 .12586 Mdot
.56623 .12586 Mdot
1 .228 0 r
.57469 .12586 m
.57173 .12555 L
s
.57469 .12586 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56694 .12801 m
.56691 .12586 L
s
1 .283 0 r
.01 w
[ .05 .05 ] 0 setdash
.56691 .12586 m
.56682 .12582 L
s
.56691 .12586 Mdot
1 .295 0 r
.56704 .12586 Mdot
.56683 .1258 m
.56704 .12586 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12599 m
.56366 .12603 L
s
.56745 .12602 m
.56746 .12633 L
s
.56742 .1267 m
.56745 .12602 L
s
.56365 .12607 m
.56366 .12601 L
s
1 .121 0 r
.01 w
[ .05 .05 ] 0 setdash
.56696 .12585 m
.56605 .12564 L
s
.56696 .12585 Mdot
1 .28 0 r
.56971 .12585 Mdot
.56912 .12574 m
.56971 .12585 L
s
1 .425 0 r
.56418 .12584 Mdot
.56461 .12577 m
.56418 .12584 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56133 .12848 m
.56146 .13024 L
s
1 .225 0 r
.01 w
.54027 .12584 Mdot
[ .05 .05 ] 0 setdash
.54302 .12562 m
.54027 .12584 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.489 .142 m
.48821 .14736 L
s
1 .073 0 r
.01 w
.54762 .12583 Mdot
[ .05 .05 ] 0 setdash
.55174 .1256 m
.54762 .12583 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56444 .1266 m
.56443 .12753 L
s
.56443 .12723 m
.56444 .1266 L
s
1 .429 0 r
.01 w
[ .05 .05 ] 0 setdash
.57357 .12583 m
.5726 .12553 L
s
.57357 .12583 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12603 m
.56367 .12606 L
s
1 .283 0 r
.01 w
[ .05 .05 ] 0 setdash
.56682 .12582 m
.56674 .12577 L
s
.56682 .12582 Mdot
1 .074 0 r
.5667 .12581 m
.56305 .12552 L
s
.5667 .12581 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55192 .12958 m
.55208 .13133 L
s
1 .314 0 r
.01 w
[ .05 .05 ] 0 setdash
.56429 .12581 m
.56445 .12571 L
s
.56429 .12581 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56364 .12606 m
.56365 .12607 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56429 .13299 m
.56419 .1258 L
s
1 .34 0 r
.01 w
.56419 .1258 Mdot
[ .05 .05 ] 0 setdash
.56451 .12567 m
.56419 .1258 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63763 .19994 m
.63992 .19412 L
s
1 .344 0 r
.01 w
[ .05 .05 ] 0 setdash
.56492 .1258 m
.56498 .12573 L
s
.56492 .1258 Mdot
1 .295 0 r
.56683 .1258 Mdot
1 .296 0 r
.56659 .12574 m
.56683 .1258 L
s
1 .355 0 r
.56572 .1258 Mdot
.56564 .12572 m
.56572 .1258 L
s
1 .346 0 r
.56447 .1258 Mdot
1 .347 0 r
.56454 .12573 m
.56447 .1258 L
s
1 .424 0 r
.56406 .12579 m
.56432 .1257 L
s
.56406 .12579 Mdot
1 .351 0 r
.56509 .12579 m
.56501 .1257 L
s
.56509 .12579 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56367 .12606 m
.56369 .12616 L
s
.56635 .12658 m
.56632 .12694 L
s
.56638 .12685 m
.56635 .12658 L
s
.5637 .12605 m
.56369 .12609 L
s
.5637 .12617 m
.5637 .12605 L
s
.56368 .12627 m
.56366 .12611 L
s
1 .283 0 r
.01 w
[ .05 .05 ] 0 setdash
.56674 .12577 m
.56669 .12571 L
s
.56674 .12577 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59538 .14022 m
.59486 .13846 L
s
1 .425 0 r
.01 w
.56461 .12577 Mdot
[ .05 .05 ] 0 setdash
.56516 .12567 m
.56461 .12577 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56369 .12609 m
.56368 .12646 L
s
.62812 .16853 m
.62723 .16939 L
s
.56353 .12762 m
.56351 .12704 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56666 .13113 m
.56659 .12574 L
s
1 .296 0 r
.01 w
.56659 .12574 Mdot
[ .05 .05 ] 0 setdash
.56634 .12569 m
.56659 .12574 L
s
1 .28 0 r
.56912 .12574 Mdot
.56861 .12564 m
.56912 .12574 L
s
1 .344 0 r
.56498 .12573 m
.565 .12567 L
s
.56498 .12573 Mdot
1 .12 0 r
.5635 .12573 Mdot
.56399 .12561 m
.5635 .12573 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6303 .16963 m
.62906 .17275 L
s
1 .347 0 r
.01 w
.56454 .12573 Mdot
[ .05 .05 ] 0 setdash
.56462 .12566 m
.56454 .12573 L
s
1 .355 0 r
.56564 .12572 Mdot
1 .356 0 r
.56555 .12564 m
.56564 .12572 L
s
1 .282 0 r
.56669 .12571 m
.56665 .12564 L
s
.56669 .12571 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56369 .12616 m
.5637 .12617 L
s
1 .362 0 r
.01 w
[ .05 .05 ] 0 setdash
.56521 .12571 m
.56513 .12569 L
s
.56521 .12571 Mdot
.56531 .1257 m
.56521 .12571 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49259 .13921 m
.49226 .13754 L
s
.55097 .13069 m
.55111 .13101 L
s
1 .314 0 r
.01 w
[ .05 .05 ] 0 setdash
.56445 .12571 m
.56461 .12561 L
s
.56445 .12571 Mdot
1 .362 0 r
.56531 .1257 Mdot
.56543 .12568 m
.56531 .1257 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56439 .13138 m
.56432 .1257 L
s
1 .423 0 r
.01 w
[ .05 .05 ] 0 setdash
.56432 .1257 m
.56459 .12561 L
s
.56432 .1257 Mdot
1 .35 0 r
.56501 .1257 m
.56497 .12561 L
s
.56501 .1257 Mdot
1 .296 0 r
.56634 .12569 Mdot
.56609 .12564 m
.56634 .12569 L
s
1 .361 0 r
.56513 .12569 m
.56509 .12564 L
s
.56513 .12569 Mdot
1 .362 0 r
.56543 .12568 Mdot
.56558 .12565 m
.56543 .12568 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56248 .12752 m
.56253 .12731 L
s
1 .34 0 r
.01 w
.56451 .12567 Mdot
[ .05 .05 ] 0 setdash
.56476 .12556 m
.56451 .12567 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5637 .12639 m
.56368 .12627 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56503 .12774 m
.565 .12567 L
s
1 .344 0 r
.01 w
[ .05 .05 ] 0 setdash
.565 .12567 m
.56504 .1256 L
s
.565 .12567 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56533 .13829 m
.56516 .12567 L
s
1 .425 0 r
.01 w
.56516 .12567 Mdot
1 .426 0 r
[ .05 .05 ] 0 setdash
.56581 .12554 m
.56516 .12567 L
s
1 .347 0 r
.56462 .12566 Mdot
.56471 .12559 m
.56462 .12566 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5624 .12738 m
.56248 .12752 L
s
1 .362 0 r
.01 w
.56558 .12565 Mdot
[ .05 .05 ] 0 setdash
.56572 .12559 m
.56558 .12565 L
s
1 .361 0 r
.56509 .12564 m
.56506 .12559 L
s
.56509 .12564 Mdot
0 0 0 r
.004 w
.44552 .12564 Mdot
1 .282 0 r
.01 w
.56665 .12564 m
.56666 .12556 L
s
.56665 .12564 Mdot
1 .121 0 r
.56605 .12564 m
.56525 .12554 L
s
.56605 .12564 Mdot
1 .296 0 r
.56609 .12564 Mdot
.56584 .12559 m
.56609 .12564 L
s
1 .28 0 r
.56861 .12564 Mdot
.56817 .12555 m
.56861 .12564 L
s
1 .356 0 r
.56555 .12564 Mdot
.56545 .12556 m
.56555 .12564 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56746 .12633 m
.56742 .1268 L
s
1 .225 0 r
.01 w
.54302 .12562 Mdot
[ .05 .05 ] 0 setdash
.54524 .12556 m
.54302 .12562 L
s
1 .12 0 r
.56399 .12561 Mdot
.56457 .12554 m
.56399 .12561 L
s
1 .313 0 r
.56461 .12561 m
.56476 .12554 L
s
.56461 .12561 Mdot
1 .35 0 r
.56497 .12561 m
.56497 .12553 L
s
.56497 .12561 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58287 .13215 m
.58315 .13382 L
s
1 .423 0 r
.01 w
[ .05 .05 ] 0 setdash
.56459 .12561 m
.56485 .12551 L
s
.56459 .12561 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56372 .12645 m
.5637 .12639 L
s
1 .344 0 r
.01 w
[ .05 .05 ] 0 setdash
.56504 .1256 m
.56507 .12554 L
s
.56504 .1256 Mdot
1 .073 0 r
.55174 .1256 Mdot
.55529 .12552 m
.55174 .1256 L
s
1 .362 0 r
.56572 .12559 Mdot
1 .363 0 r
.56584 .12554 m
.56572 .12559 L
s
1 .347 0 r
.56471 .12559 Mdot
.56479 .12554 m
.56471 .12559 L
s
1 .296 0 r
.56584 .12559 Mdot
.56562 .12555 m
.56584 .12559 L
s
1 .361 0 r
.56506 .12559 m
.56505 .12553 L
s
.56506 .12559 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56638 .12742 m
.56638 .12685 L
s
.56374 .12657 m
.56372 .12645 L
s
1 .34 0 r
.01 w
.56476 .12556 Mdot
[ .05 .05 ] 0 setdash
.56495 .12548 m
.56476 .12556 L
s
1 .282 0 r
.56666 .12556 m
.5667 .12549 L
s
.56666 .12556 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51894 .13272 m
.51914 .13295 L
s
1 .225 0 r
.01 w
.54524 .12556 Mdot
[ .05 .05 ] 0 setdash
.54763 .12545 m
.54524 .12556 L
s
1 .356 0 r
.56545 .12556 Mdot
.56536 .12549 m
.56545 .12556 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64091 .17672 m
.63982 .17829 L
s
.5515 .13073 m
.55159 .13018 L
s
.56368 .12646 m
.56366 .12689 L
s
1 .228 0 r
.01 w
[ .05 .05 ] 0 setdash
.57173 .12555 m
.56883 .12534 L
s
.57173 .12555 Mdot
1 .28 0 r
.56817 .12555 Mdot
1 .281 0 r
.56779 .12547 m
.56817 .12555 L
s
1 .296 0 r
.56562 .12555 Mdot
1 .297 0 r
.56542 .1255 m
.56562 .12555 L
s
1 .121 0 r
.56525 .12554 m
.56457 .12554 L
s
.56525 .12554 Mdot
1 .12 0 r
.56457 .12554 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56632 .12694 m
.56629 .12774 L
s
1 .426 0 r
.01 w
.56581 .12554 Mdot
[ .05 .05 ] 0 setdash
.56649 .1254 m
.56581 .12554 L
s
1 .343 0 r
.56507 .12554 m
.5651 .12549 L
s
.56507 .12554 Mdot
1 .313 0 r
.56476 .12554 m
.56487 .12548 L
s
.56476 .12554 Mdot
1 .347 0 r
.56479 .12554 Mdot
1 .348 0 r
.56487 .12549 m
.56479 .12554 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.40794 .15523 m
.40709 .15191 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56589 .12923 m
.56584 .12554 L
s
1 .363 0 r
.01 w
.56584 .12554 Mdot
[ .05 .05 ] 0 setdash
.56598 .12546 m
.56584 .12554 L
s
1 .361 0 r
.56505 .12553 m
.56506 .12548 L
s
.56505 .12553 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56499 .12724 m
.56497 .12553 L
s
1 .35 0 r
.01 w
[ .05 .05 ] 0 setdash
.56497 .12553 m
.56499 .12547 L
s
.56497 .12553 Mdot
1 .428 0 r
.5726 .12553 m
.57187 .12533 L
s
.5726 .12553 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56419 .12683 m
.5643 .12846 L
s
.56418 .12691 m
.56419 .12683 L
s
1 .073 0 r
.01 w
.55529 .12552 Mdot
[ .05 .05 ] 0 setdash
.55921 .12547 m
.55529 .12552 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56391 .19366 m
.56305 .12552 L
s
1 .073 0 r
.01 w
[ .05 .05 ] 0 setdash
.56305 .12552 m
.55921 .12547 L
s
.56305 .12552 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56378 .1268 m
.56374 .12657 L
s
1 .423 0 r
.01 w
[ .05 .05 ] 0 setdash
.56485 .12551 m
.56505 .12544 L
s
.56485 .12551 Mdot
1 .297 0 r
.56542 .1255 Mdot
.56525 .12547 m
.56542 .1255 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56435 .12703 m
.56428 .1275 L
s
.5645 .12865 m
.56435 .12703 L
s
1 .356 0 r
.01 w
.56536 .12549 Mdot
[ .05 .05 ] 0 setdash
.56527 .12545 m
.56536 .12549 L
s
1 .282 0 r
.5667 .12549 m
.56679 .12544 L
s
.5667 .12549 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56615 .12682 m
.56622 .12688 L
s
.56607 .1272 m
.56615 .12682 L
s
1 .343 0 r
.01 w
[ .05 .05 ] 0 setdash
.5651 .12549 m
.56511 .12545 L
s
.5651 .12549 Mdot
0 0 0 r
.004 w
.60241 .12549 Mdot
1 .348 0 r
.01 w
.56487 .12549 Mdot
.56495 .12545 m
.56487 .12549 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56356 .1274 m
.56363 .12838 L
s
.56622 .12688 m
.5663 .12712 L
s
.56421 .12796 m
.56418 .12691 L
s
1 .313 0 r
.01 w
[ .05 .05 ] 0 setdash
.56487 .12548 m
.56497 .12544 L
s
.56487 .12548 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56478 .12816 m
.56473 .12899 L
s
1 .34 0 r
.01 w
.56495 .12548 Mdot
[ .05 .05 ] 0 setdash
.56509 .12541 m
.56495 .12548 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56508 .1264 m
.56506 .12548 L
s
1 .361 0 r
.01 w
[ .05 .05 ] 0 setdash
.56506 .12548 m
.56508 .12543 L
s
.56506 .12548 Mdot
1 .281 0 r
.56779 .12547 Mdot
.56746 .12543 m
.56779 .12547 L
s
1 .073 0 r
.55921 .12547 Mdot
1 .35 0 r
.56499 .12547 m
.56503 .12542 L
s
.56499 .12547 Mdot
1 .297 0 r
.56525 .12547 Mdot
.56511 .12544 m
.56525 .12547 L
s
1 .416 0 r
.56509 .12547 m
.56507 .12547 L
s
.56509 .12547 Mdot
.56511 .12546 m
.56509 .12547 L
s
.56507 .12547 m
.56506 .12546 L
s
.56507 .12547 Mdot
1 .363 0 r
.56598 .12546 Mdot
.56609 .12539 m
.56598 .12546 L
s
1 .416 0 r
.56511 .12546 Mdot
1 .417 0 r
.56514 .12546 m
.56511 .12546 L
s
1 .416 0 r
.56506 .12546 m
.56506 .12545 L
s
.56506 .12546 Mdot
1 .417 0 r
.56514 .12546 Mdot
.56516 .12545 m
.56514 .12546 L
s
1 .416 0 r
.56506 .12545 m
.56506 .12545 L
s
.56506 .12545 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56251 .12784 m
.56238 .12948 L
s
1 .395 0 r
.01 w
[ .05 .05 ] 0 setdash
.56503 .12545 m
.56506 .12544 L
s
.56503 .12545 Mdot
.56503 .12545 m
.56503 .12545 L
s
.56503 .12545 Mdot
.56505 .12545 m
.56503 .12545 L
s
1 .343 0 r
.56511 .12545 m
.56512 .12543 L
s
.56511 .12545 Mdot
1 .225 0 r
.54763 .12545 Mdot
1 .226 0 r
.5498 .12539 m
.54763 .12545 L
s
1 .348 0 r
.56495 .12545 Mdot
.56503 .12542 m
.56495 .12545 L
s
1 .417 0 r
.56516 .12545 Mdot
.56516 .12545 m
.56516 .12545 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5653 .12747 m
.56527 .12545 L
s
1 .356 0 r
.01 w
.56527 .12545 Mdot
1 .357 0 r
[ .05 .05 ] 0 setdash
.56518 .12542 m
.56527 .12545 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56517 .12586 m
.56516 .12545 L
s
1 .417 0 r
.01 w
.56516 .12545 Mdot
[ .05 .05 ] 0 setdash
.56518 .12544 m
.56516 .12545 L
s
1 .415 0 r
.56506 .12545 m
.56507 .12544 L
s
.56506 .12545 Mdot
1 .395 0 r
.56505 .12545 Mdot
1 .396 0 r
.56507 .12544 m
.56505 .12545 L
s
1 .395 0 r
.56506 .12544 m
.5651 .12543 L
s
.56506 .12544 Mdot
1 .417 0 r
.56518 .12544 Mdot
1 .418 0 r
.56519 .12544 m
.56518 .12544 L
s
1 .281 0 r
.56679 .12544 m
.56695 .1254 L
s
.56679 .12544 Mdot
1 .396 0 r
.56507 .12544 Mdot
.56508 .12543 m
.56507 .12544 L
s
1 .42 0 r
.56507 .12544 m
.56508 .12543 L
s
.56507 .12544 Mdot
.56507 .12544 m
.56507 .12544 L
s
.56507 .12544 Mdot
.56508 .12544 m
.56507 .12544 L
s
1 .423 0 r
.56505 .12544 m
.56516 .1254 L
s
.56505 .12544 Mdot
1 .297 0 r
.56511 .12544 Mdot
.56502 .12542 m
.56511 .12544 L
s
1 .418 0 r
.56519 .12544 Mdot
.56519 .12543 m
.56519 .12544 L
s
1 .415 0 r
.56507 .12544 m
.56508 .12543 L
s
.56507 .12544 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56439 .12808 m
.56443 .12723 L
s
1 .42 0 r
.01 w
.56508 .12544 Mdot
1 .421 0 r
[ .05 .05 ] 0 setdash
.56509 .12543 m
.56508 .12544 L
s
1 .313 0 r
.56497 .12544 m
.56506 .12541 L
s
.56497 .12544 Mdot
1 .42 0 r
.56508 .12543 m
.56508 .12543 L
s
.56508 .12543 Mdot
1 .396 0 r
.56508 .12543 Mdot
.56509 .12543 m
.56508 .12543 L
s
1 .421 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
1 .36 0 r
.56508 .12543 m
.56509 .12541 L
s
.56508 .12543 Mdot
1 .396 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
1 .421 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56509 .12543 m
.56509 .12543 L
s
1 .299 0 r
.01 w
.56509 .12543 Mdot
1 .358 0 r
[ .05 .05 ] 0 setdash
.56509 .12543 m
.56509 .12543 L
s
.56509 .12543 Mdot
1 .397 0 r
.56509 .12543 Mdot
1 .309 0 r
.56509 .12543 Mdot
1 .397 0 r
.56509 .12543 Mdot
1 .398 0 r
.56509 .12543 Mdot
1 .412 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .299 0 r
.56509 .12543 m
.56509 .12543 L
s
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .3 0 r
.56509 .12543 Mdot
1 .301 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .302 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .303 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .304 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .305 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .306 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .307 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .308 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .309 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .31 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .359 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
1 .396 0 r
.56509 .12543 Mdot
1 .397 0 r
.56509 .12543 Mdot
1 .398 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .399 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .4 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .401 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .402 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .403 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .404 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .405 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .406 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .407 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .408 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .409 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .41 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .411 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .412 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .413 0 r
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .414 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12543 m
.56509 .12545 L
s
1 .3 0 r
.01 w
.56509 .12543 Mdot
.56509 .12543 Mdot
.56509 .12543 Mdot
1 .301 0 r
.56509 .12543 Mdot
1 .311 0 r
.56509 .12543 Mdot
[ .05 .05 ] 0 setdash
.56509 .12543 m
.56509 .12543 L
s
1 .397 0 r
.56509 .12543 Mdot
1 .411 0 r
.56509 .12543 Mdot
1 .414 0 r
.56509 .12543 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12544 m
.56509 .12543 L
s
1 .3 0 r
.01 w
.56509 .12543 Mdot
1 .396 0 r
.56509 .12543 Mdot
.53 .8 .95 r
.006 w
.56509 .12543 m
.56509 .12546 L
s
.56509 .12544 m
.56509 .12543 L
s
1 .397 0 r
.01 w
.56509 .12543 Mdot
.53 .8 .95 r
.006 w
.56509 .12543 m
.56509 .12544 L
s
.56509 .12545 m
.56509 .12543 L
s
1 .414 0 r
.01 w
.56509 .12543 Mdot
[ .05 .05 ] 0 setdash
.5651 .12543 m
.56509 .12543 L
s
1 .358 0 r
.56509 .12543 m
.56508 .12543 L
s
.56509 .12543 Mdot
1 .418 0 r
.56519 .12543 Mdot
.5652 .12542 m
.56519 .12543 L
s
1 .299 0 r
.56509 .12543 m
.56508 .12543 L
s
.56509 .12543 Mdot
1 .311 0 r
.56509 .12543 Mdot
.5651 .12543 m
.56509 .12543 L
s
1 .421 0 r
.56509 .12543 Mdot
.5651 .12543 m
.56509 .12543 L
s
1 .359 0 r
.56509 .12543 Mdot
.56509 .12543 m
.56509 .12543 L
s
1 .414 0 r
.5651 .12543 Mdot
.5651 .12543 m
.5651 .12543 L
s
1 .394 0 r
.5651 .12543 m
.56516 .12541 L
s
.5651 .12543 Mdot
1 .42 0 r
.56508 .12543 m
.5651 .12542 L
s
.56508 .12543 Mdot
1 .358 0 r
.56508 .12543 m
.56506 .12542 L
s
.56508 .12543 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56754 .13144 m
.56746 .12543 L
s
1 .281 0 r
.01 w
.56746 .12543 Mdot
[ .05 .05 ] 0 setdash
.56717 .1254 m
.56746 .12543 L
s
1 .298 0 r
.56508 .12543 m
.56505 .12542 L
s
.56508 .12543 Mdot
1 .311 0 r
.5651 .12543 Mdot
.56512 .12542 m
.5651 .12543 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56508 .12554 m
.56508 .12543 L
s
1 .415 0 r
.01 w
[ .05 .05 ] 0 setdash
.56508 .12543 m
.56509 .12542 L
s
.56508 .12543 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63482 .17234 m
.63369 .17452 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56511 .12555 m
.5651 .12543 L
s
1 .421 0 r
.01 w
.5651 .12543 Mdot
1 .422 0 r
[ .05 .05 ] 0 setdash
.56513 .12542 m
.5651 .12543 L
s
1 .414 0 r
.5651 .12543 Mdot
1 .415 0 r
.56509 .12542 m
.5651 .12543 L
s
1 .359 0 r
.56509 .12543 Mdot
.56508 .12542 m
.56509 .12543 L
s
1 .343 0 r
.56512 .12543 m
.56512 .12541 L
s
.56512 .12543 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12544 m
.56509 .12548 L
s
.56509 .12545 m
.56509 .12544 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56505 .12659 m
.56503 .12542 L
s
1 .348 0 r
.01 w
.56503 .12542 Mdot
[ .05 .05 ] 0 setdash
.56509 .12541 m
.56503 .12542 L
s
1 .35 0 r
.56503 .12542 m
.56507 .1254 L
s
.56503 .12542 Mdot
1 .415 0 r
.56509 .12542 m
.56509 .12542 L
s
.56509 .12542 Mdot
.56509 .12542 Mdot
1 .418 0 r
.5652 .12542 Mdot
.5652 .12542 m
.5652 .12542 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12544 m
.56508 .12551 L
s
1 .358 0 r
.01 w
[ .05 .05 ] 0 setdash
.56506 .12542 m
.56503 .12541 L
s
.56506 .12542 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5651 .12548 m
.56509 .12544 L
s
1 .298 0 r
.01 w
[ .05 .05 ] 0 setdash
.56505 .12542 m
.56501 .12541 L
s
.56505 .12542 Mdot
1 .311 0 r
.56512 .12542 Mdot
.56514 .12541 m
.56512 .12542 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .1255 m
.56509 .12544 L
s
1 .419 0 r
.01 w
[ .05 .05 ] 0 setdash
.5651 .12542 m
.56512 .12541 L
s
.5651 .12542 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5651 .12553 m
.56509 .12545 L
s
1 .422 0 r
.01 w
.56513 .12542 Mdot
[ .05 .05 ] 0 setdash
.56517 .1254 m
.56513 .12542 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12545 m
.56508 .12555 L
s
1 .418 0 r
.01 w
.5652 .12542 Mdot
[ .05 .05 ] 0 setdash
.56519 .12541 m
.5652 .12542 L
s
1 .359 0 r
.56508 .12542 Mdot
.56508 .12541 m
.56508 .12542 L
s
1 .357 0 r
.56518 .12542 Mdot
.5651 .1254 m
.56518 .12542 L
s
1 .297 0 r
.56502 .12542 Mdot
.56497 .12541 m
.56502 .12542 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56511 .12555 m
.56509 .12545 L
s
1 .358 0 r
.01 w
[ .05 .05 ] 0 setdash
.56503 .12541 m
.565 .12541 L
s
.56503 .12541 Mdot
1 .34 0 r
.56509 .12541 Mdot
1 .341 0 r
.56518 .12538 m
.56509 .12541 L
s
1 .298 0 r
.56501 .12541 m
.56498 .12541 L
s
.56501 .12541 Mdot
1 .311 0 r
.56514 .12541 Mdot
1 .312 0 r
.56517 .12541 m
.56514 .12541 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12546 m
.56508 .12558 L
s
.56734 .12764 m
.56742 .1267 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.56513 .12585 m
.56512 .12541 L
s
1 .419 0 r
.01 w
[ .05 .05 ] 0 setdash
.56512 .12541 m
.56515 .12541 L
s
.56512 .12541 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .12547 m
.56509 .12559 L
s
.56507 .12549 m
.56508 .12547 L
s
1 .418 0 r
.01 w
.56519 .12541 Mdot
1 .419 0 r
[ .05 .05 ] 0 setdash
.56518 .12541 m
.56519 .12541 L
s
1 .342 0 r
.56512 .12541 m
.56511 .1254 L
s
.56512 .12541 Mdot
1 .394 0 r
.56516 .12541 m
.56523 .12539 L
s
.56516 .12541 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55111 .13101 m
.55126 .13112 L
s
1 .357 0 r
.01 w
[ .05 .05 ] 0 setdash
.565 .12541 m
.56501 .1254 L
s
.565 .12541 Mdot
1 .313 0 r
.56506 .12541 m
.56513 .1254 L
s
.56506 .12541 Mdot
1 .36 0 r
.56509 .12541 m
.56509 .1254 L
s
.56509 .12541 Mdot
1 .419 0 r
.56515 .12541 m
.56517 .1254 L
s
.56515 .12541 Mdot
1 .298 0 r
.56498 .12541 m
.56496 .1254 L
s
.56498 .12541 Mdot
1 .419 0 r
.56518 .12541 Mdot
.56517 .1254 m
.56518 .12541 L
s
1 .312 0 r
.56517 .12541 Mdot
.56518 .1254 m
.56517 .12541 L
s
1 .359 0 r
.56508 .12541 Mdot
1 .36 0 r
.56509 .1254 m
.56508 .12541 L
s
1 .348 0 r
.56509 .12541 Mdot
.56514 .12539 m
.56509 .12541 L
s
1 .297 0 r
.56497 .12541 Mdot
1 .298 0 r
.56496 .1254 m
.56497 .12541 L
s
1 .281 0 r
.56695 .1254 m
.56717 .1254 L
s
.56695 .1254 Mdot
.56717 .1254 Mdot
1 .422 0 r
.56517 .1254 Mdot
.56521 .12539 m
.56517 .1254 L
s
1 .419 0 r
.56517 .1254 Mdot
1 .426 0 r
.56649 .1254 Mdot
.56715 .12527 m
.56649 .1254 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56497 .1258 m
.56496 .1254 L
s
1 .298 0 r
.01 w
.56496 .1254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .12554 m
.56507 .12549 L
s
1 .342 0 r
.01 w
[ .05 .05 ] 0 setdash
.56511 .1254 m
.56509 .1254 L
s
.56511 .1254 Mdot
.5651 .1254 m
.56513 .1254 L
s
.5651 .1254 Mdot
.56509 .1254 m
.5651 .1254 L
s
1 .357 0 r
.56501 .1254 m
.56504 .1254 L
s
.56501 .1254 Mdot
.5651 .1254 Mdot
.56504 .1254 m
.5651 .1254 L
s
1 .342 0 r
.56509 .1254 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56514 .1259 m
.56513 .1254 L
s
1 .342 0 r
.01 w
[ .05 .05 ] 0 setdash
.56513 .1254 m
.56519 .12539 L
s
.56513 .1254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56509 .12548 m
.56508 .12553 L
s
1 .312 0 r
.01 w
.56518 .1254 Mdot
[ .05 .05 ] 0 setdash
.56517 .12539 m
.56518 .1254 L
s
1 .423 0 r
.56516 .1254 m
.56521 .12538 L
s
.56516 .1254 Mdot
1 .36 0 r
.56509 .1254 Mdot
.56509 .1254 m
.56509 .1254 L
s
1 .357 0 r
.56504 .1254 Mdot
1 .36 0 r
.56509 .1254 Mdot
1 .349 0 r
.56507 .1254 m
.56511 .12538 L
s
.56507 .1254 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56514 .12587 m
.56513 .1254 L
s
1 .312 0 r
.01 w
[ .05 .05 ] 0 setdash
.56513 .1254 m
.56517 .12539 L
s
.56513 .1254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5651 .12549 m
.5651 .12548 L
s
1 .312 0 r
.01 w
.56517 .12539 Mdot
1 .341 0 r
[ .05 .05 ] 0 setdash
.56519 .12539 m
.56523 .12538 L
s
.56519 .12539 Mdot
1 .226 0 r
.5498 .12539 Mdot
.55174 .12537 m
.5498 .12539 L
s
1 .422 0 r
.56521 .12539 Mdot
.56523 .12538 m
.56521 .12539 L
s
1 .348 0 r
.56514 .12539 Mdot
1 .349 0 r
.56516 .12538 m
.56514 .12539 L
s
1 .363 0 r
.56609 .12539 Mdot
.56623 .12529 m
.56609 .12539 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56525 .12683 m
.56523 .12539 L
s
1 .394 0 r
.01 w
[ .05 .05 ] 0 setdash
.56523 .12539 m
.56529 .12536 L
s
.56523 .12539 Mdot
1 .422 0 r
.56521 .12538 m
.56523 .12538 L
s
.56521 .12538 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .12551 m
.56507 .12562 L
s
1 .422 0 r
.01 w
.56523 .12538 Mdot
1 .349 0 r
[ .05 .05 ] 0 setdash
.56511 .12538 m
.56515 .12538 L
s
.56511 .12538 Mdot
.56516 .12538 Mdot
.56516 .12538 m
.56516 .12538 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5651 .12549 m
.5651 .12549 L
s
.56509 .12549 m
.5651 .12549 L
s
1 .341 0 r
.01 w
[ .05 .05 ] 0 setdash
.56523 .12538 m
.56524 .12537 L
s
.56523 .12538 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .12554 m
.56509 .12549 L
s
1 .341 0 r
.01 w
.56518 .12538 Mdot
[ .05 .05 ] 0 setdash
.56523 .12536 m
.56518 .12538 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56385 .12708 m
.56378 .1268 L
s
1 .349 0 r
.01 w
.56516 .12538 Mdot
[ .05 .05 ] 0 setdash
.56515 .12538 m
.56516 .12538 L
s
.56515 .12538 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56352 .12675 m
.56355 .12912 L
s
.56366 .12791 m
.56352 .12675 L
s
.5647 .12916 m
.56477 .12821 L
s
.56508 .1256 m
.56509 .1255 L
s
.56508 .12553 m
.56508 .12554 L
s
1 .341 0 r
.01 w
[ .05 .05 ] 0 setdash
.56524 .12537 m
.56523 .12536 L
s
.56524 .12537 Mdot
1 .226 0 r
.55174 .12537 Mdot
.55352 .12535 m
.55174 .12537 L
s
1 .341 0 r
.56523 .12536 Mdot
1 .394 0 r
.56529 .12536 m
.56535 .12534 L
s
.56529 .12536 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56512 .12567 m
.5651 .12553 L
s
.56498 .12548 m
.56503 .12622 L
s
.56497 .1258 m
.56498 .12548 L
s
.56507 .12564 m
.56508 .12554 L
s
1 .226 0 r
.01 w
.55352 .12535 Mdot
[ .05 .05 ] 0 setdash
.55516 .12533 m
.55352 .12535 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .12555 m
.56506 .12572 L
s
1 .392 0 r
.01 w
[ .05 .05 ] 0 setdash
.56533 .12534 m
.56534 .12534 L
s
.56533 .12534 Mdot
.56533 .12534 m
.56533 .12534 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56534 .12635 m
.56533 .12534 L
s
1 .392 0 r
.01 w
.56533 .12534 Mdot
[ .05 .05 ] 0 setdash
.56533 .12534 m
.56533 .12534 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5663 .12712 m
.56635 .12753 L
s
.56516 .12544 m
.56514 .12561 L
s
.56517 .12554 m
.56516 .12544 L
s
1 .392 0 r
.01 w
[ .05 .05 ] 0 setdash
.56533 .12534 m
.56533 .12534 L
s
.56533 .12534 Mdot
1 .393 0 r
.56536 .12534 m
.56533 .12534 L
s
1 .392 0 r
.56533 .12534 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56503 .12562 m
.56506 .12569 L
s
.56504 .1258 m
.56503 .12562 L
s
.56521 .12545 m
.56523 .12587 L
s
.56517 .12607 m
.56521 .12545 L
s
1 .392 0 r
.01 w
[ .05 .05 ] 0 setdash
.56534 .12534 m
.56538 .12533 L
s
.56534 .12534 Mdot
1 .394 0 r
.56535 .12534 m
.5654 .12532 L
s
.56535 .12534 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56514 .12575 m
.56511 .12555 L
s
1 .228 0 r
.01 w
[ .05 .05 ] 0 setdash
.56883 .12534 m
.56635 .12514 L
s
.56883 .12534 Mdot
1 .393 0 r
.56536 .12534 Mdot
.56538 .12533 m
.56536 .12534 L
s
1 .391 0 r
.56538 .12533 m
.56544 .12531 L
s
.56538 .12533 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56356 .1279 m
.56353 .12762 L
s
1 .226 0 r
.01 w
.55516 .12533 Mdot
[ .05 .05 ] 0 setdash
.55673 .12528 m
.55516 .12533 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56731 .12697 m
.56726 .12823 L
s
.56731 .12726 m
.56731 .12697 L
s
.56508 .12558 m
.56505 .12578 L
s
1 .393 0 r
.01 w
.56538 .12533 Mdot
[ .05 .05 ] 0 setdash
.56541 .12532 m
.56538 .12533 L
s
1 .428 0 r
.57187 .12533 m
.57125 .12514 L
s
.57187 .12533 Mdot
1 .393 0 r
.5654 .12532 m
.56542 .12532 L
s
.5654 .12532 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56366 .12689 m
.56365 .12729 L
s
1 .393 0 r
.01 w
.56541 .12532 Mdot
[ .05 .05 ] 0 setdash
.56542 .12532 m
.56541 .12532 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60907 .1506 m
.60833 .14776 L
s
1 .393 0 r
.01 w
.56542 .12532 Mdot
0 0 0 r
.004 w
.44778 .12532 Mdot
.53 .8 .95 r
.006 w
.56509 .12554 m
.5651 .12555 L
s
.56509 .1259 m
.56509 .12554 L
s
.56509 .12559 m
.56511 .12574 L
s
.56507 .12562 m
.56505 .12575 L
s
.56742 .1268 m
.56736 .12724 L
s
.56518 .12552 m
.56519 .12576 L
s
.56514 .12587 m
.56518 .12552 L
s
1 .391 0 r
.01 w
[ .05 .05 ] 0 setdash
.56544 .12531 m
.56554 .12528 L
s
.56544 .12531 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56508 .1257 m
.56507 .12573 L
s
.5651 .12575 m
.56508 .1257 L
s
.55139 .13115 m
.5515 .13073 L
s
.56511 .12555 m
.56509 .12556 L
s
.56512 .12564 m
.56511 .12555 L
s
.56507 .12574 m
.56507 .12564 L
s
.5651 .12555 m
.56509 .12562 L
s
.56508 .12565 m
.56508 .1256 L
s
.56509 .12556 m
.5651 .12569 L
s
1 .363 0 r
.01 w
.56623 .12529 Mdot
[ .05 .05 ] 0 setdash
.56634 .12519 m
.56623 .12529 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55706 .15566 m
.55673 .12528 L
s
1 .226 0 r
.01 w
.55673 .12528 Mdot
1 .227 0 r
[ .05 .05 ] 0 setdash
.55841 .12523 m
.55673 .12528 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56507 .12573 m
.56506 .12576 L
s
.56506 .12569 m
.56511 .12614 L
s
1 .391 0 r
.01 w
[ .05 .05 ] 0 setdash
.56554 .12528 m
.56566 .12524 L
s
.56554 .12528 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56229 .12939 m
.56213 .12798 L
s
.56512 .12584 m
.5651 .12575 L
s
.56501 .12559 m
.56505 .12576 L
s
.56501 .12585 m
.56501 .12559 L
s
.51914 .13295 m
.51937 .13307 L
s
.5652 .12565 m
.5652 .12573 L
s
.5652 .12565 m
.5652 .12565 L
s
1 .426 0 r
.01 w
.56715 .12527 Mdot
[ .05 .05 ] 0 setdash
.56773 .12516 m
.56715 .12527 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56515 .12565 m
.56517 .12554 L
s
.5652 .12572 m
.5652 .12565 L
s
.56515 .12579 m
.56512 .12567 L
s
.56512 .12581 m
.56512 .12564 L
s
.56506 .12576 m
.56507 .12574 L
s
.55126 .13112 m
.55139 .13115 L
s
.56509 .12562 m
.56508 .12565 L
s
.56523 .12554 m
.56519 .12624 L
s
.56525 .12585 m
.56523 .12554 L
s
.56514 .12561 m
.5651 .12603 L
s
.56505 .12575 m
.56504 .1258 L
s
1 .391 0 r
.01 w
[ .05 .05 ] 0 setdash
.56566 .12524 m
.5658 .12519 L
s
.56566 .12524 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56423 .1274 m
.5642 .12761 L
s
.56429 .12793 m
.56423 .1274 L
s
.56651 .12681 m
.56639 .12704 L
s
.56659 .12686 m
.56651 .12681 L
s
1 .227 0 r
.01 w
.55841 .12523 Mdot
[ .05 .05 ] 0 setdash
.56019 .1251 m
.55841 .12523 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5652 .12573 m
.56519 .12583 L
s
.56664 .1269 m
.56659 .12686 L
s
.5667 .1276 m
.56664 .1269 L
s
.56506 .12572 m
.56503 .12587 L
s
.56441 .12723 m
.56446 .12764 L
s
.56439 .12742 m
.56441 .12723 L
s
.56428 .1275 m
.56428 .12827 L
s
.55328 .13483 m
.55302 .13591 L
s
.56392 .12735 m
.56385 .12708 L
s
.56511 .12574 m
.56513 .12585 L
s
.5651 .12569 m
.56514 .1259 L
s
.56514 .12593 m
.56512 .12584 L
s
.56519 .12582 m
.5652 .12572 L
s
.56518 .12596 m
.56514 .12575 L
s
.56599 .12758 m
.56607 .1272 L
s
1 .39 0 r
.01 w
[ .05 .05 ] 0 setdash
.5658 .12519 m
.56595 .12514 L
s
.5658 .12519 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56512 .12572 m
.56515 .12565 L
s
1 .363 0 r
.01 w
.56634 .12519 Mdot
1 .364 0 r
[ .05 .05 ] 0 setdash
.56644 .12509 m
.56634 .12519 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56539 .12553 m
.56537 .12604 L
s
.56542 .12574 m
.56539 .12553 L
s
.56505 .12578 m
.56502 .12596 L
s
.56635 .12753 m
.56638 .12742 L
s
.56443 .12753 m
.56439 .12841 L
s
.56512 .12612 m
.56512 .12581 L
s
.56517 .12586 m
.56517 .12612 L
s
.56519 .12591 m
.56517 .12586 L
s
1 .426 0 r
.01 w
.56773 .12516 Mdot
1 .427 0 r
[ .05 .05 ] 0 setdash
.56836 .12505 m
.56773 .12516 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56519 .12583 m
.56519 .12591 L
s
.56519 .12576 m
.56517 .12584 L
s
.56508 .12584 m
.56512 .12572 L
s
.56517 .12584 m
.56515 .12579 L
s
.56505 .12576 m
.56511 .12632 L
s
1 .428 0 r
.01 w
[ .05 .05 ] 0 setdash
.57125 .12514 m
.5708 .12503 L
s
.57125 .12514 Mdot
1 .227 0 r
.56635 .12514 m
.56407 .12509 L
s
.56635 .12514 Mdot
1 .39 0 r
.56595 .12514 m
.56612 .12508 L
s
.56595 .12514 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56517 .12612 m
.56514 .12593 L
s
.56499 .126 m
.56497 .1258 L
s
.58931 .15412 m
.58871 .15682 L
s
.56365 .12729 m
.56364 .12761 L
s
.56517 .12589 m
.56519 .12582 L
s
.56534 .12567 m
.56539 .12661 L
s
.56533 .12582 m
.56534 .12567 L
s
.56508 .1264 m
.56509 .1259 L
s
.56513 .12585 m
.56515 .12591 L
s
.56503 .12587 m
.56501 .12585 L
s
1 .227 0 r
.01 w
.56019 .1251 Mdot
[ .05 .05 ] 0 setdash
.56207 .12506 m
.56019 .1251 L
s
.56407 .12509 m
.56207 .12506 L
s
.56407 .12509 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56504 .12616 m
.56508 .12584 L
s
1 .364 0 r
.01 w
.56644 .12509 Mdot
[ .05 .05 ] 0 setdash
.56652 .12501 m
.56644 .12509 L
s
0 0 0 r
.004 w
.59957 .12509 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56399 .12732 m
.56392 .12735 L
s
.56408 .12765 m
.56399 .12732 L
s
1 .39 0 r
.01 w
[ .05 .05 ] 0 setdash
.56612 .12508 m
.56628 .12503 L
s
.56612 .12508 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56724 .12864 m
.56731 .12726 L
s
.56359 .12792 m
.56356 .1279 L
s
.56508 .12651 m
.56514 .12587 L
s
.56515 .12591 m
.56517 .12589 L
s
.56639 .12704 m
.56625 .12729 L
s
1 .227 0 r
.01 w
.56207 .12506 Mdot
.53 .8 .95 r
.006 w
.56514 .1259 m
.5652 .12607 L
s
.51937 .13307 m
.5196 .13304 L
s
.56523 .12587 m
.56522 .12605 L
s
1 .427 0 r
.01 w
.56836 .12505 Mdot
[ .05 .05 ] 0 setdash
.5689 .12497 m
.56836 .12505 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56502 .12596 m
.56499 .126 L
s
.56524 .12608 m
.56525 .12585 L
s
1 .428 0 r
.01 w
[ .05 .05 ] 0 setdash
.5708 .12503 m
.5704 .12495 L
s
.5708 .12503 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56631 .12754 m
.56628 .12503 L
s
1 .39 0 r
.01 w
[ .05 .05 ] 0 setdash
.56628 .12503 m
.5664 .12499 L
s
.56628 .12503 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56543 .12619 m
.56542 .12574 L
s
.56522 .12605 m
.56518 .12596 L
s
.55382 .13548 m
.55366 .13455 L
s
.56534 .12635 m
.56533 .12582 L
s
.56441 .12776 m
.56439 .12742 L
s
.56736 .12724 m
.56728 .12758 L
s
.56629 .12774 m
.56624 .1286 L
s
.5642 .12761 m
.56415 .12764 L
s
1 .364 0 r
.01 w
.56652 .12501 Mdot
[ .05 .05 ] 0 setdash
.56657 .12495 m
.56652 .12501 L
s
0 0 0 r
.004 w
.45005 .125 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59148 .1352 m
.5919 .13885 L
s
.56511 .12653 m
.56512 .12612 L
s
.56364 .12761 m
.56362 .12783 L
s
1 .39 0 r
.01 w
[ .05 .05 ] 0 setdash
.5664 .12499 m
.56649 .12496 L
s
.5664 .12499 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5651 .12603 m
.56505 .12659 L
s
.56435 .12838 m
.56429 .12793 L
s
.55116 .13399 m
.5509 .13237 L
s
.56446 .12764 m
.56453 .12793 L
s
.56362 .12783 m
.56359 .12792 L
s
1 .427 0 r
.01 w
.5689 .12497 Mdot
[ .05 .05 ] 0 setdash
.56933 .12491 m
.5689 .12497 L
s
1 .389 0 r
.56649 .12496 m
.56655 .12494 L
s
.56649 .12496 Mdot
1 .364 0 r
.56657 .12495 Mdot
.56659 .12491 m
.56657 .12495 L
s
1 .366 0 r
.56652 .12495 m
.56652 .12495 L
s
.56652 .12495 Mdot
.56652 .12495 m
.56652 .12495 L
s
1 .367 0 r
.56652 .12495 m
.56652 .12495 L
s
.56652 .12495 Mdot
1 .368 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .385 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .386 0 r
.56652 .12495 Mdot
1 .387 0 r
.56652 .12495 Mdot
1 .366 0 r
.56652 .12495 Mdot
1 .367 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .368 0 r
.56652 .12495 Mdot
1 .367 0 r
.56652 .12495 Mdot
1 .368 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .369 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .37 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .371 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .372 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .373 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .374 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .375 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .376 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .377 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .378 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .379 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .38 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .381 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .382 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .383 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .384 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .385 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .386 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .387 0 r
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
.56652 .12495 Mdot
1 .366 0 r
.56652 .12495 Mdot
1 .367 0 r
.56652 .12495 Mdot
1 .388 0 r
.56652 .12495 Mdot
.56652 .12495 m
.56652 .12495 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56652 .12495 m
.56652 .12495 L
s
.56652 .12497 m
.56652 .12495 L
s
1 .366 0 r
.01 w
[ .05 .05 ] 0 setdash
.56652 .12495 m
.56651 .12494 L
s
.56652 .12495 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56652 .12497 m
.56652 .12495 L
s
1 .388 0 r
.01 w
.56652 .12495 Mdot
[ .05 .05 ] 0 setdash
.56653 .12494 m
.56652 .12495 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56652 .12495 m
.56652 .12495 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.57049 .13069 m
.5704 .12495 L
s
1 .428 0 r
.01 w
[ .05 .05 ] 0 setdash
.5704 .12495 m
.57004 .1249 L
s
.5704 .12495 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56511 .12614 m
.56518 .12654 L
s
.56652 .12495 m
.56651 .125 L
s
1 .366 0 r
.01 w
[ .05 .05 ] 0 setdash
.56651 .12494 m
.56651 .12494 L
s
.56651 .12494 Mdot
1 .388 0 r
.56653 .12494 Mdot
.56655 .12494 m
.56653 .12494 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35928 .20045 m
.35777 .1937 L
s
.5196 .13304 m
.51983 .13288 L
s
.56507 .12718 m
.56517 .12607 L
s
1 .388 0 r
.01 w
.56655 .12494 Mdot
[ .05 .05 ] 0 setdash
.56657 .12493 m
.56655 .12494 L
s
1 .389 0 r
.56655 .12494 m
.56659 .12492 L
s
.56655 .12494 Mdot
1 .365 0 r
.56651 .12494 m
.56652 .12492 L
s
.56651 .12494 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56653 .12505 m
.56652 .12497 L
s
.56415 .12764 m
.56408 .12765 L
s
.58149 .13466 m
.5818 .13322 L
s
.5652 .12607 m
.56524 .12608 L
s
1 .388 0 r
.01 w
.56657 .12493 Mdot
1 .389 0 r
[ .05 .05 ] 0 setdash
.56659 .12492 m
.56657 .12493 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51983 .13288 m
.52005 .13274 L
s
1 .389 0 r
.01 w
[ .05 .05 ] 0 setdash
.56659 .12492 m
.5666 .12492 L
s
.56659 .12492 Mdot
.56659 .12492 Mdot
.5666 .12492 m
.56659 .12492 L
s
1 .365 0 r
.56652 .12492 m
.56654 .12491 L
s
.56652 .12492 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56501 .12667 m
.56504 .12616 L
s
1 .389 0 r
.01 w
.5666 .12492 Mdot
1 .427 0 r
.56933 .12491 Mdot
[ .05 .05 ] 0 setdash
.5697 .12489 m
.56933 .12491 L
s
1 .364 0 r
.56659 .12491 Mdot
.56659 .1249 m
.56659 .12491 L
s
1 .365 0 r
.56654 .12491 m
.56657 .1249 L
s
.56654 .12491 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56651 .125 m
.56651 .12509 L
s
1 .427 0 r
.01 w
[ .05 .05 ] 0 setdash
.57004 .1249 m
.5697 .12489 L
s
.57004 .1249 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56658 .12532 m
.56657 .1249 L
s
1 .365 0 r
.01 w
[ .05 .05 ] 0 setdash
.56657 .1249 m
.56659 .1249 L
s
.56657 .1249 Mdot
1 .364 0 r
.56659 .1249 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56659 .12497 m
.5666 .1252 L
s
.56656 .12548 m
.56659 .12497 L
s
.52005 .13274 m
.52028 .133 L
s
.56162 .13193 m
.5614 .1297 L
s
.56625 .12729 m
.56609 .12803 L
s
1 .427 0 r
.01 w
.5697 .12489 Mdot
.53 .8 .95 r
.006 w
.56433 .1286 m
.56439 .12808 L
s
.56591 .12831 m
.56599 .12758 L
s
.56655 .12519 m
.56653 .12505 L
s
.56503 .12622 m
.56514 .12714 L
s
.56473 .12899 m
.56465 .12936 L
s
.56537 .12604 m
.56535 .12647 L
s
.56507 .12688 m
.56508 .1264 L
s
.56651 .12509 m
.56652 .12518 L
s
.56721 .12878 m
.56734 .12764 L
s
.56445 .12901 m
.56435 .12838 L
s
.62424 .16525 m
.62327 .16213 L
s
.56519 .12624 m
.56512 .12732 L
s
.56509 .12697 m
.56511 .12653 L
s
.56728 .12758 m
.56717 .12781 L
s
.56426 .1285 m
.56421 .12796 L
s
.56453 .12793 m
.56462 .12795 L
s
.56511 .12632 m
.5652 .12692 L
s
.56679 .12842 m
.5667 .1276 L
s
.56658 .12531 m
.56655 .12519 L
s
.56363 .12838 m
.56374 .12912 L
s
.56652 .12518 m
.56655 .12528 L
s
.55208 .13133 m
.55233 .13367 L
s
.56428 .12827 m
.56433 .1286 L
s
.59056 .13755 m
.59095 .1358 L
s
.56462 .12795 m
.56471 .12813 L
s
.5666 .1252 m
.5666 .12534 L
s
.56542 .12666 m
.56543 .12619 L
s
.62365 .18235 m
.62546 .1869 L
s
.56385 .12797 m
.56396 .12809 L
s
.56374 .12827 m
.56385 .12797 L
s
0 0 0 r
.004 w
.59675 .1247 Mdot
.53 .8 .95 r
.006 w
.56445 .12807 m
.56441 .12776 L
s
0 0 0 r
.004 w
.45233 .12469 Mdot
.53 .8 .95 r
.006 w
.56659 .12524 m
.56658 .12584 L
s
.56659 .12521 m
.56659 .12524 L
s
.56658 .12532 m
.56659 .12521 L
s
.5666 .12534 m
.56658 .12531 L
s
.56535 .12656 m
.56534 .12635 L
s
.56655 .12528 m
.56658 .12532 L
s
.565 .12716 m
.56508 .12651 L
s
.56499 .12724 m
.56501 .12667 L
s
.56518 .12654 m
.56525 .12683 L
s
.56146 .13024 m
.56166 .13156 L
s
.56505 .12659 m
.56497 .12713 L
s
.52028 .133 m
.52053 .13337 L
s
.5646 .12993 m
.5647 .12916 L
s
.56717 .12781 m
.56706 .12795 L
s
.56508 .12723 m
.56507 .12688 L
s
.56392 .13073 m
.56366 .12791 L
s
.56396 .12809 m
.56408 .1286 L
s
.56535 .12647 m
.56535 .12656 L
s
.56363 .12871 m
.56374 .12827 L
s
.56506 .12739 m
.56509 .12697 L
s
.5665 .12611 m
.56656 .12548 L
s
.56431 .12834 m
.56426 .1285 L
s
.56439 .12841 m
.56431 .12834 L
s
.64199 .1984 m
.64408 .19508 L
s
.56523 .12742 m
.56516 .12744 L
s
.56533 .12746 m
.56523 .12742 L
s
.56471 .12813 m
.56481 .12819 L
s
.56465 .12936 m
.56455 .12922 L
s
.56546 .12793 m
.56533 .12746 L
s
.56455 .12922 m
.56445 .12901 L
s
.56516 .12744 m
.56511 .12741 L
s
.56726 .12823 m
.56715 .12922 L
s
.56706 .12795 m
.56694 .12801 L
s
.59606 .14278 m
.59538 .14022 L
s
.6879 .22961 m
.69052 .22262 L
s
.56511 .12741 m
.56508 .12723 L
s
.56539 .12661 m
.56547 .12751 L
s
.56671 .12757 m
.56668 .12751 L
s
.56677 .12777 m
.56671 .12757 L
s
.58315 .13382 m
.58352 .13577 L
s
.56238 .12948 m
.56215 .13155 L
s
.56624 .1286 m
.56614 .1294 L
s
.56537 .12692 m
.56542 .12666 L
s
.56685 .12822 m
.56677 .12777 L
s
.56481 .12819 m
.56489 .12826 L
s
.56525 .12683 m
.56531 .12697 L
s
.56609 .12803 m
.56593 .12891 L
s
.56694 .12801 m
.56685 .12822 L
s
.5652 .12692 m
.5653 .12747 L
s
0 0 0 r
.004 w
.45462 .12439 Mdot
.53 .8 .95 r
.006 w
.5643 .12846 m
.56448 .13015 L
s
.71474 .24437 m
.71192 .24919 L
s
.5635 .12905 m
.56363 .12871 L
s
.56503 .12774 m
.56506 .12739 L
s
.56668 .12751 m
.56669 .12769 L
s
.56499 .12778 m
.56499 .12724 L
s
.56451 .12832 m
.56445 .12807 L
s
.56468 .12992 m
.5645 .12865 L
s
.56658 .12584 m
.56654 .12669 L
s
0 0 0 r
.004 w
.59394 .12433 Mdot
.53 .8 .95 r
.006 w
.59352 .14521 m
.59331 .14854 L
s
.52053 .13337 m
.52082 .13426 L
s
.49302 .14109 m
.49259 .13921 L
s
.56497 .12713 m
.5649 .12753 L
s
.56584 .12874 m
.56591 .12831 L
s
.56334 .12977 m
.5635 .12905 L
s
.56514 .12714 m
.56528 .12814 L
s
.56501 .12787 m
.56503 .12774 L
s
.56495 .12813 m
.56501 .12787 L
s
.56408 .1286 m
.5642 .12916 L
s
.56531 .12697 m
.56537 .12692 L
s
.51741 .14008 m
.51801 .13526 L
s
.5649 .12778 m
.565 .12716 L
s
.56489 .12872 m
.56507 .12718 L
s
.55302 .13591 m
.55272 .13663 L
s
.56689 .12912 m
.56679 .12842 L
s
.56489 .12826 m
.56495 .12813 L
s
.38137 .17512 m
.37942 .18262 L
s
.56252 .13103 m
.56229 .12939 L
s
.56642 .12679 m
.5665 .12611 L
s
.56374 .12912 m
.56385 .12999 L
s
.56562 .12866 m
.56546 .12793 L
s
.56505 .12832 m
.56499 .12778 L
s
.56512 .12732 m
.56499 .12864 L
s
.56669 .12769 m
.56673 .12787 L
s
.62723 .16939 m
.62625 .16882 L
s
0 0 0 r
.004 w
.45691 .12409 Mdot
.53 .8 .95 r
.006 w
.5649 .12753 m
.56482 .12781 L
s
.56458 .12845 m
.56451 .12832 L
s
.55146 .13542 m
.55116 .13399 L
s
.5653 .12747 m
.56539 .12792 L
s
.56702 .12998 m
.56721 .12878 L
s
.55409 .13654 m
.55382 .13548 L
s
.5671 .12982 m
.56724 .12864 L
s
.59226 .15522 m
.5919 .15448 L
s
.38414 .17267 m
.38268 .176 L
s
.56482 .12781 m
.56474 .12804 L
s
0 0 0 r
.004 w
.59114 .12398 Mdot
.53 .8 .95 r
.006 w
.5642 .12916 m
.5643 .12963 L
s
.5645 .13029 m
.5646 .12993 L
s
.56316 .1307 m
.56334 .12977 L
s
.56474 .12804 m
.56466 .12822 L
s
.56513 .12886 m
.56505 .12832 L
s
.37959 .17914 m
.37824 .1778 L
s
.56466 .12822 m
.56458 .12845 L
s
.56479 .12846 m
.5649 .12778 L
s
.56577 .12903 m
.56584 .12874 L
s
.56614 .1294 m
.566 .12968 L
s
.61 .15423 m
.60907 .1506 L
s
.56673 .12787 m
.56683 .1284 L
s
.56654 .12669 m
.56648 .12759 L
s
.58114 .13602 m
.58149 .13466 L
s
.56539 .12792 m
.56549 .12832 L
s
.56701 .12953 m
.56689 .12912 L
s
.56593 .12891 m
.56574 .12993 L
s
0 0 0 r
.004 w
.45921 .12381 Mdot
.53 .8 .95 r
.006 w
.56715 .12922 m
.56701 .12953 L
s
.56547 .12751 m
.56558 .12825 L
s
.56355 .12912 m
.56367 .13092 L
s
.56631 .12754 m
.56642 .12679 L
s
.5643 .12963 m
.5644 .13 L
s
.52082 .13426 m
.52119 .13587 L
s
.56523 .12911 m
.56513 .12886 L
s
.566 .12968 m
.56584 .12974 L
s
.6091 .1553 m
.60806 .14993 L
s
.56166 .13156 m
.5619 .13264 L
s
.56549 .12832 m
.56559 .12868 L
s
.56537 .12963 m
.56523 .12911 L
s
.56528 .12814 m
.56546 .1291 L
s
0 0 0 r
.004 w
.58835 .12364 Mdot
.53 .8 .95 r
.006 w
.5644 .13 m
.5645 .13029 L
s
.56584 .12974 m
.56567 .12972 L
s
.62525 .1676 m
.62424 .16525 L
s
.56568 .12887 m
.56577 .12903 L
s
.56576 .12912 m
.56562 .12866 L
s
.56567 .12972 m
.56552 .12984 L
s
.56559 .12868 m
.56568 .12887 L
s
.56466 .12918 m
.56479 .12846 L
s
0 0 0 r
.004 w
.46153 .12354 Mdot
.53 .8 .95 r
.006 w
.59008 .13946 m
.59056 .13755 L
s
.55272 .13663 m
.55241 .13691 L
s
.56296 .13176 m
.56316 .1307 L
s
.56385 .12999 m
.564 .13041 L
s
.56552 .12984 m
.56537 .12963 L
s
.5649 .13142 m
.56468 .12992 L
s
.5845 .13477 m
.5849 .13548 L
s
.58408 .13524 m
.5845 .13477 L
s
.56683 .1284 m
.56701 .12938 L
s
.56648 .12759 m
.56639 .12839 L
s
.62625 .16882 m
.62525 .1676 L
s
.55178 .13649 m
.55146 .13542 L
s
.55233 .13367 m
.55272 .1366 L
s
.56465 .13029 m
.56489 .12872 L
s
0 0 0 r
.004 w
.58557 .12332 Mdot
.53 .8 .95 r
.006 w
.56499 .12864 m
.56482 .13009 L
s
.56617 .12831 m
.56631 .12754 L
s
0 0 0 r
.004 w
.46384 .12327 Mdot
.53 .8 .95 r
.006 w
.56676 .13116 m
.56702 .12998 L
s
.56558 .12825 m
.56571 .12874 L
s
.56192 .1336 m
.56162 .13193 L
s
.56448 .13015 m
.56472 .13173 L
s
.56589 .12923 m
.56576 .12912 L
s
.56451 .12987 m
.56466 .12918 L
s
.60549 .14948 m
.60457 .15562 L
s
.56574 .12993 m
.56553 .13093 L
s
.56689 .13064 m
.5671 .12982 L
s
.58352 .13577 m
.584 .13788 L
s
.57928 .13401 m
.57964 .13454 L
s
.57887 .13419 m
.57928 .13401 L
s
.56215 .13155 m
.56181 .1339 L
s
.63982 .17829 m
.63874 .17942 L
s
.40895 .15859 m
.40794 .15523 L
s
.55241 .13691 m
.5521 .13712 L
s
.56546 .1291 m
.56567 .12992 L
s
.564 .13041 m
.56417 .13046 L
s
0 0 0 r
.004 w
.46617 .12302 Mdot
.5828 .12302 Mdot
.53 .8 .95 r
.006 w
.56603 .1294 m
.56589 .12923 L
s
.58362 .1366 m
.58408 .13524 L
s
.5849 .13548 m
.58535 .13688 L
s
.55448 .13787 m
.55409 .13654 L
s
.56639 .12839 m
.56628 .12898 L
s
.63369 .17452 m
.6324 .17664 L
s
.59331 .14854 m
.59307 .15156 L
s
.56271 .13244 m
.56296 .13176 L
s
.57964 .13454 m
.57995 .13525 L
s
.56601 .12891 m
.56617 .12831 L
s
.57835 .13557 m
.57887 .13419 L
s
.5619 .13264 m
.56217 .13296 L
s
.56434 .13019 m
.56451 .12987 L
s
.56282 .13272 m
.56252 .13103 L
s
.56571 .12874 m
.56585 .12911 L
s
.5521 .13712 m
.55178 .13649 L
s
.5919 .13885 m
.59255 .14359 L
s
.62072 .1716 m
.62206 .16514 L
s
.56417 .13046 m
.56434 .13019 L
s
.56614 .12939 m
.56603 .1294 L
s
0 0 0 r
.004 w
.46851 .12277 Mdot
.53 .8 .95 r
.006 w
.59692 .14614 m
.59606 .14278 L
s
.58081 .13686 m
.58114 .13602 L
s
.56628 .12898 m
.56614 .12939 L
s
0 0 0 r
.004 w
.58005 .12273 Mdot
.53 .8 .95 r
.006 w
.49363 .14367 m
.49302 .14109 L
s
.56701 .12938 m
.56724 .13026 L
s
.52119 .13587 m
.52169 .13852 L
s
.62906 .17275 m
.62774 .17652 L
s
.62546 .1869 m
.62757 .19158 L
s
.56429 .13389 m
.56392 .13073 L
s
.56245 .1329 m
.56271 .13244 L
s
.57995 .13525 m
.58023 .13602 L
s
.56585 .12911 m
.56601 .12891 L
s
.63532 .20509 m
.63763 .19994 L
s
.56567 .12992 m
.56591 .13057 L
s
.38268 .176 m
.38113 .17807 L
s
0 0 0 r
.004 w
.47085 .12254 Mdot
.53 .8 .95 r
.006 w
.56217 .13296 m
.56245 .1329 L
s
.56553 .13093 m
.56533 .13193 L
s
.56367 .13092 m
.56389 .13184 L
s
.56666 .13113 m
.56689 .13064 L
s
.56646 .13222 m
.56676 .13116 L
s
.56482 .13009 m
.56458 .13156 L
s
.59258 .15522 m
.59226 .15522 L
s
0 0 0 r
.004 w
.5773 .12246 Mdot
.53 .8 .95 r
.006 w
.58871 .15682 m
.5879 .15978 L
s
.56439 .13138 m
.56465 .13029 L
s
.56511 .13203 m
.5649 .13142 L
s
0 0 0 r
.004 w
.4732 .12231 Mdot
.53 .8 .95 r
.006 w
.58023 .13602 m
.58051 .13688 L
s
0 0 0 r
.004 w
.57457 .1222 Mdot
.53 .8 .95 r
.006 w
.56591 .13057 m
.56616 .13098 L
s
.38113 .17807 m
.37959 .17914 L
s
.48821 .14736 m
.48709 .1536 L
s
.58952 .14118 m
.59008 .13946 L
s
.58535 .13688 m
.58591 .13925 L
s
.56472 .13173 m
.56501 .13318 L
s
0 0 0 r
.004 w
.47556 .1221 Mdot
.53 .8 .95 r
.006 w
.56724 .13026 m
.56754 .13144 L
s
.60606 .15095 m
.60506 .15884 L
s
.56642 .13134 m
.56666 .13113 L
s
.58051 .13688 m
.58081 .13686 L
s
.61107 .15786 m
.61 .15423 L
s
.56616 .13098 m
.56642 .13134 L
s
.58308 .13865 m
.58362 .1366 L
s
0 0 0 r
.004 w
.57185 .12196 Mdot
.53 .8 .95 r
.006 w
.56231 .13496 m
.56192 .1336 L
s
0 0 0 r
.004 w
.47793 .12189 Mdot
.53 .8 .95 r
.006 w
.56533 .13193 m
.56511 .13203 L
s
.5777 .13833 m
.57835 .13557 L
s
.37931 .19668 m
.38113 .20221 L
s
.56414 .13189 m
.56439 .13138 L
s
.59307 .15156 m
.59284 .15406 L
s
.56389 .13184 m
.56414 .13189 L
s
.56611 .13288 m
.56646 .13222 L
s
.55498 .13911 m
.55448 .13787 L
s
.584 .13788 m
.58459 .13983 L
s
0 0 0 r
.004 w
.56914 .12173 Mdot
.53 .8 .95 r
.006 w
.63968 .20087 m
.64199 .1984 L
s
0 0 0 r
.004 w
.48031 .12169 Mdot
.53 .8 .95 r
.006 w
.56458 .13156 m
.56429 .13299 L
s
.62636 .16734 m
.62489 .16699 L
s
.62789 .1684 m
.62636 .16734 L
s
.56181 .1339 m
.56135 .13631 L
s
.55272 .1366 m
.55326 .14 L
s
.62948 .16971 m
.62789 .1684 L
s
0 0 0 r
.004 w
.56644 .12151 Mdot
.48269 .1215 Mdot
.53 .8 .95 r
.006 w
.5632 .1343 m
.56282 .13272 L
s
.63114 .17234 m
.62948 .16971 L
s
.59284 .15406 m
.59258 .15522 L
s
.56574 .13358 m
.56611 .13288 L
s
0 0 0 r
.004 w
.48509 .12133 Mdot
.53 .8 .95 r
.006 w
.56754 .13144 m
.56789 .13289 L
s
0 0 0 r
.004 w
.56375 .12131 Mdot
.53 .8 .95 r
.006 w
.62489 .16699 m
.62346 .16722 L
s
.57012 .13025 m
.56978 .13063 L
s
.57049 .13069 m
.57012 .13025 L
s
0 0 0 r
.004 w
.48749 .12116 Mdot
.56107 .12113 Mdot
.53 .8 .95 r
.006 w
.56501 .13318 m
.56536 .13371 L
s
.63874 .17942 m
.63744 .17985 L
s
.57091 .13214 m
.57049 .13069 L
s
0 0 0 r
.004 w
.4899 .121 Mdot
.53 .8 .95 r
.006 w
.52169 .13852 m
.52234 .14165 L
s
.56978 .13063 m
.56943 .1317 L
s
0 0 0 r
.004 w
.55839 .12096 Mdot
.53 .8 .95 r
.006 w
.51641 .1467 m
.51741 .14008 L
s
.56429 .13299 m
.56393 .13427 L
s
.5889 .14258 m
.58952 .14118 L
s
0 0 0 r
.004 w
.49232 .12085 Mdot
.53 .8 .95 r
.006 w
.56536 .13371 m
.56574 .13358 L
s
0 0 0 r
.004 w
.55574 .1208 Mdot
.53 .8 .95 r
.006 w
.56274 .13572 m
.56231 .13496 L
s
0 0 0 r
.004 w
.49475 .12072 Mdot
.53 .8 .95 r
.006 w
.3912 .18226 m
.38968 .17371 L
s
.59797 .15026 m
.59692 .14614 L
s
0 0 0 r
.004 w
.55309 .12066 Mdot
.53 .8 .95 r
.006 w
.49441 .14683 m
.49363 .14367 L
s
.62757 .19158 m
.62986 .19517 L
s
.58591 .13925 m
.58664 .1425 L
s
.55562 .14085 m
.55498 .13911 L
s
0 0 0 r
.004 w
.49719 .12059 Mdot
.53 .8 .95 r
.006 w
.41014 .16141 m
.40895 .15859 L
s
.61032 .16082 m
.6091 .1553 L
s
.58459 .13983 m
.58527 .14169 L
s
0 0 0 r
.004 w
.55045 .12052 Mdot
.53 .8 .95 r
.006 w
.62346 .16722 m
.62212 .16787 L
s
0 0 0 r
.004 w
.49963 .12047 Mdot
.53 .8 .95 r
.006 w
.6324 .17664 m
.63088 .17833 L
s
.6328 .17513 m
.63114 .17234 L
s
.56789 .13289 m
.56829 .13399 L
s
.58244 .14103 m
.58308 .13865 L
s
0 0 0 r
.004 w
.54782 .12041 Mdot
.50209 .12037 Mdot
.53 .8 .95 r
.006 w
.56475 .13649 m
.56429 .13389 L
s
0 0 0 r
.004 w
.5452 .1203 Mdot
.53 .8 .95 r
.006 w
.56943 .1317 m
.56902 .13331 L
s
0 0 0 r
.004 w
.50455 .12027 Mdot
.53 .8 .95 r
.006 w
.56393 .13427 m
.56356 .13544 L
s
.61227 .1612 m
.61107 .15786 L
s
0 0 0 r
.004 w
.54258 .12021 Mdot
.50702 .12019 Mdot
.53 .8 .95 r
.006 w
.57139 .13429 m
.57091 .13214 L
s
.37942 .18262 m
.37712 .19065 L
s
0 0 0 r
.004 w
.53998 .12013 Mdot
.53 .8 .95 r
.006 w
.56363 .13564 m
.5632 .1343 L
s
0 0 0 r
.004 w
.5095 .12012 Mdot
.53 .8 .95 r
.006 w
.59255 .14359 m
.59349 .1499 L
s
0 0 0 r
.004 w
.53739 .12006 Mdot
.51199 .12006 Mdot
.53 .8 .95 r
.006 w
.56316 .13586 m
.56274 .13572 L
s
.56135 .13631 m
.56078 .13862 L
s
0 0 0 r
.004 w
.53481 .12001 Mdot
.51449 .12 Mdot
.53224 .11997 Mdot
.517 .11996 Mdot
.53 .8 .95 r
.006 w
.57687 .14251 m
.5777 .13833 L
s
0 0 0 r
.004 w
.52968 .11994 Mdot
.51952 .11994 Mdot
.52712 .11992 Mdot
.52204 .11992 Mdot
.52458 .11991 Mdot
.53 .8 .95 r
.006 w
.56829 .13399 m
.56874 .13509 L
s
.58822 .14341 m
.5889 .14258 L
s
.56356 .13544 m
.56316 .13586 L
s
.55326 .14 m
.554 .14424 L
s
.63272 .20958 m
.63532 .20509 L
s
.63744 .17985 m
.63604 .17897 L
s
.58527 .14169 m
.58599 .14281 L
s
.62212 .16787 m
.62077 .16892 L
s
.36149 .20479 m
.35928 .20045 L
s
.63447 .17741 m
.6328 .17513 L
s
.5879 .15978 m
.58693 .16327 L
s
.63728 .20136 m
.63968 .20087 L
s
.59008 .17148 m
.59127 .1745 L
s
.58887 .16997 m
.59008 .17148 L
s
.56902 .13331 m
.5685 .13509 L
s
.62986 .19517 m
.63248 .19848 L
s
.56874 .13509 m
.56927 .13628 L
s
.62774 .17652 m
.62614 .1801 L
s
.58749 .14351 m
.58822 .14341 L
s
.55634 .14244 m
.55562 .14085 L
s
.59127 .1745 m
.59231 .17756 L
s
.52234 .14165 m
.5232 .14557 L
s
.56413 .13642 m
.56363 .13564 L
s
.71192 .24919 m
.70865 .2529 L
s
.63604 .17897 m
.63447 .17741 L
s
.57207 .1379 m
.57139 .13429 L
s
.58599 .14281 m
.58674 .14343 L
s
.58674 .14343 m
.58749 .14351 L
s
.61358 .16379 m
.61227 .1612 L
s
.60457 .15562 m
.60332 .16168 L
s
.58766 .17025 m
.58887 .16997 L
s
.58664 .1425 m
.58757 .14669 L
s
.58168 .14324 m
.58244 .14103 L
s
.56927 .13628 m
.56989 .13759 L
s
.56078 .13862 m
.56012 .14067 L
s
.56533 .13829 m
.56475 .13649 L
s
.41149 .16495 m
.41014 .16141 L
s
.59231 .17756 m
.59363 .18246 L
s
.56473 .13757 m
.56413 .13642 L
s
.59918 .15496 m
.59797 .15026 L
s
.5685 .13509 m
.5679 .13715 L
s
.63474 .20056 m
.63728 .20136 L
s
.62077 .16892 m
.61936 .16885 L
s
.63088 .17833 m
.62928 .18036 L
s
.49544 .1509 m
.49441 .14683 L
s
.63248 .19848 m
.63474 .20056 L
s
.68504 .23573 m
.6879 .22961 L
s
.56989 .13759 m
.57061 .1395 L
s
.48709 .1536 m
.48559 .16052 L
s
.61498 .16616 m
.61358 .16379 L
s
.61914 .17792 m
.62072 .1716 L
s
.5571 .14357 m
.55634 .14244 L
s
.61936 .16885 m
.61789 .16827 L
s
.61189 .16628 m
.61032 .16082 L
s
.56544 .13909 m
.56473 .13757 L
s
.56012 .14067 m
.55943 .14254 L
s
.57583 .14793 m
.57687 .14251 L
s
.61789 .16827 m
.61643 .16745 L
s
.566 .13951 m
.56533 .13829 L
s
.61643 .16745 m
.61498 .16616 L
s
.59363 .18246 m
.59496 .18681 L
s
.5679 .13715 m
.56734 .13868 L
s
.554 .14424 m
.55495 .1484 L
s
.58637 .17169 m
.58766 .17025 L
s
.58084 .14543 m
.58168 .14324 L
s
.62976 .21184 m
.63272 .20958 L
s
.38113 .20221 m
.38347 .20676 L
s
.57061 .1395 m
.57141 .14133 L
s
.57286 .14185 m
.57207 .1379 L
s
.5232 .14557 m
.52432 .15024 L
s
.59349 .1499 m
.59469 .1565 L
s
.515 .15461 m
.51641 .1467 L
s
.5579 .14375 m
.5571 .14357 L
s
.56626 .14128 m
.56544 .13909 L
s
.60506 .15884 m
.60374 .16728 L
s
.55943 .14254 m
.55869 .14349 L
s
.56734 .13868 m
.56669 .13963 L
s
.58757 .14669 m
.58875 .15172 L
s
.56669 .13963 m
.566 .13951 L
s
.55869 .14349 m
.5579 .14375 L
s
.37712 .19065 m
.37459 .19716 L
s
.58693 .16327 m
.58576 .16629 L
s
.59496 .18681 m
.59663 .19149 L
s
.41299 .16891 m
.41149 .16495 L
s
.57141 .14133 m
.57233 .14344 L
s
.60055 .16001 m
.59918 .15496 L
s
.62663 .21364 m
.62976 .21184 L
s
.62928 .18036 m
.6275 .18159 L
s
.62614 .1801 m
.62448 .18403 L
s
.5799 .14703 m
.58084 .14543 L
s
.36379 .20758 m
.36149 .20479 L
s
.56721 .144 m
.56626 .14128 L
s
.49679 .15565 m
.49544 .1509 L
s
.59663 .19149 m
.59844 .19629 L
s
.58494 .17369 m
.58637 .17169 L
s
.61355 .17126 m
.61189 .16628 L
s
.55495 .1484 m
.55612 .15272 L
s
.57233 .14344 m
.57334 .14566 L
s
.39298 .18995 m
.3912 .18226 L
s
.5739 .1463 m
.57286 .14185 L
s
.62328 .21432 m
.62663 .21364 L
s
.70865 .2529 m
.70492 .25466 L
s
.60332 .16168 m
.60169 .16776 L
s
.57892 .14831 m
.5799 .14703 L
s
.62014 .2148 m
.62328 .21432 L
s
.52432 .15024 m
.52569 .15575 L
s
.59844 .19629 m
.60043 .20027 L
s
.57461 .15415 m
.57583 .14793 L
s
.56837 .14794 m
.56721 .144 L
s
.6275 .18159 m
.62562 .18275 L
s
.57334 .14566 m
.57445 .14726 L
s
.58875 .15172 m
.5901 .15722 L
s
.61361 .21225 m
.61677 .21379 L
s
.61068 .21103 m
.61361 .21225 L
s
.48559 .16052 m
.4838 .16808 L
s
.61677 .21379 m
.62014 .2148 L
s
.60228 .16519 m
.60055 .16001 L
s
.37459 .19716 m
.37173 .20272 L
s
.59469 .1565 m
.59622 .16344 L
s
.60043 .20027 m
.60273 .20347 L
s
.41481 .17272 m
.41299 .16891 L
s
.6078 .2089 m
.61068 .21103 L
s
.60513 .20611 m
.6078 .2089 L
s
.60273 .20347 m
.60513 .20611 L
s
.57782 .14906 m
.57892 .14831 L
s
.61735 .18395 m
.61914 .17792 L
s
.58576 .16629 m
.58442 .16918 L
s
.57445 .14726 m
.57563 .14834 L
s
.38347 .20676 m
.3859 .21071 L
s
.58317 .17592 m
.58494 .17369 L
s
.61545 .17594 m
.61355 .17126 L
s
.55612 .15272 m
.55754 .15712 L
s
.57673 .14884 m
.57782 .14906 L
s
.57563 .14834 m
.57673 .14884 L
s
.68215 .24089 m
.68504 .23573 L
s
.57527 .1524 m
.5739 .1463 L
s
.36632 .20858 m
.36379 .20758 L
s
.62448 .18403 m
.6225 .18701 L
s
.62562 .18275 m
.62365 .18335 L
s
.56968 .15251 m
.56837 .14794 L
s
.4985 .162 m
.49679 .15565 L
s
.5132 .16307 m
.515 .15461 L
s
.42055 .19083 m
.4231 .18999 L
s
.41792 .19245 m
.42055 .19083 L
s
.37173 .20272 m
.36906 .20632 L
s
.41511 .19571 m
.41792 .19245 L
s
.4231 .18999 m
.42546 .18988 L
s
.6041 .17059 m
.60228 .16519 L
s
.52569 .15575 m
.5274 .16163 L
s
.70492 .25466 m
.70125 .25546 L
s
.5901 .15722 m
.59172 .16268 L
s
.61744 .17948 m
.61545 .17594 L
s
.41679 .17699 m
.41481 .17272 L
s
.60374 .16728 m
.60197 .17547 L
s
.62365 .18335 m
.62157 .1833 L
s
.36906 .20632 m
.36632 .20858 L
s
.55754 .15712 m
.55914 .1619 L
s
.42546 .18988 m
.42791 .19101 L
s
.57309 .16093 m
.57461 .15415 L
s
.60169 .16776 m
.59977 .17339 L
s
.58442 .16918 m
.58303 .17156 L
s
.58124 .17791 m
.58317 .17592 L
s
.59622 .16344 m
.59799 .17064 L
s
.41214 .19933 m
.41511 .19571 L
s
.5711 .15725 m
.56968 .15251 L
s
.61949 .1817 m
.61744 .17948 L
s
.39539 .19581 m
.39298 .18995 L
s
.62157 .1833 m
.61949 .1817 L
s
.57688 .15881 m
.57527 .1524 L
s
.3859 .21071 m
.38895 .21395 L
s
.6225 .18701 m
.62035 .18938 L
s
.4838 .16808 m
.48156 .17559 L
s
.61526 .18886 m
.61735 .18395 L
s
.60618 .17657 m
.6041 .17059 L
s
.42791 .19101 m
.43033 .19308 L
s
.70125 .25546 m
.69713 .25587 L
s
.40898 .20329 m
.41214 .19933 L
s
.59172 .16268 m
.59365 .16938 L
s
.55914 .1619 m
.56095 .16662 L
s
.41911 .18187 m
.41679 .17699 L
s
.5274 .16163 m
.52926 .16781 L
s
.67839 .24247 m
.68215 .24089 L
s
.57923 .18053 m
.58124 .17791 L
s
.50055 .16947 m
.4985 .162 L
s
.57272 .16194 m
.5711 .15725 L
s
.58303 .17156 m
.5814 .17251 L
s
.59799 .17064 m
.60006 .17759 L
s
.40565 .20721 m
.40898 .20329 L
s
.51082 .17227 m
.5132 .16307 L
s
.55546 .15484 m
.5538 .155 L
s
.55706 .15566 m
.55546 .15484 L
s
.5538 .155 m
.55202 .15635 L
s
.57116 .16785 m
.57309 .16093 L
s
.62035 .18938 m
.61804 .19115 L
s
.60828 .18212 m
.60618 .17657 L
s
.43033 .19308 m
.43286 .19611 L
s
.57864 .16455 m
.57688 .15881 L
s
.59977 .17339 m
.59801 .17727 L
s
.38895 .21395 m
.39191 .21486 L
s
.55877 .15741 m
.55706 .15566 L
s
.56095 .16662 m
.56296 .17067 L
s
.57442 .16593 m
.57272 .16194 L
s
.69713 .25587 m
.69294 .25467 L
s
.55202 .15635 m
.55008 .15917 L
s
.5814 .17251 m
.5797 .17278 L
s
.39803 .20016 m
.39539 .19581 L
s
.64562 .21068 m
.64865 .21335 L
s
.64228 .20871 m
.64562 .21068 L
s
.64865 .21335 m
.65237 .21837 L
s
.40235 .21104 m
.40565 .20721 L
s
.57716 .18266 m
.57923 .18053 L
s
.59365 .16938 m
.59585 .17637 L
s
.56059 .15938 m
.55877 .15741 L
s
.63926 .20795 m
.64228 .20871 L
s
.60197 .17547 m
.59972 .18378 L
s
.61274 .19135 m
.61526 .18886 L
s
.42162 .18615 m
.41911 .18187 L
s
.57613 .16963 m
.57442 .16593 L
s
.39191 .21486 m
.39526 .2147 L
s
.67465 .24302 m
.67839 .24247 L
s
.52926 .16781 m
.53151 .17386 L
s
.56296 .17067 m
.56519 .1746 L
s
.65237 .21837 m
.65568 .22308 L
s
.48156 .17559 m
.47906 .18184 L
s
.5797 .17278 m
.57793 .17177 L
s
.69294 .25467 m
.68899 .25235 L
s
.55008 .15917 m
.54792 .16365 L
s
.61804 .19115 m
.61565 .19129 L
s
.61079 .18643 m
.60828 .18212 L
s
.63613 .20684 m
.63926 .20795 L
s
.60006 .17759 m
.60245 .18369 L
s
.39886 .21367 m
.40235 .21104 L
s
.39526 .2147 m
.39886 .21367 L
s
.68899 .25235 m
.68476 .24984 L
s
.56254 .16275 m
.56059 .15938 L
s
.57793 .17177 m
.57613 .16963 L
s
.58077 .16943 m
.57864 .16455 L
s
.59801 .17727 m
.59578 .18078 L
s
.43286 .19611 m
.43563 .19864 L
s
.63301 .20702 m
.63613 .20684 L
s
.57477 .18278 m
.57716 .18266 L
s
.50311 .17736 m
.50055 .16947 L
s
.65568 .22308 m
.65925 .22814 L
s
.61323 .18948 m
.61079 .18643 L
s
.56519 .1746 m
.56748 .17794 L
s
.68476 .24984 m
.68032 .24736 L
s
.61565 .19129 m
.61323 .18948 L
s
.42571 .18564 m
.42289 .18799 L
s
.42836 .1845 m
.42571 .18564 L
s
.43092 .18449 m
.42836 .1845 L
s
.56896 .17453 m
.57116 .16785 L
s
.40083 .2031 m
.39803 .20016 L
s
.42289 .18799 m
.42009 .19024 L
s
.65925 .22814 m
.66303 .23347 L
s
.61028 .19241 m
.61274 .19135 L
s
.67125 .24234 m
.67465 .24302 L
s
.43361 .18565 m
.43092 .18449 L
s
.59585 .17637 m
.59836 .18273 L
s
.42436 .1897 m
.42162 .18615 L
s
.57235 .1822 m
.57477 .18278 L
s
.42009 .19024 m
.41696 .19383 L
s
.56748 .17794 m
.56992 .18094 L
s
.68032 .24736 m
.67634 .24402 L
s
.67634 .24402 m
.67214 .24078 L
s
.60245 .18369 m
.60496 .18856 L
s
.54792 .16365 m
.54555 .16962 L
s
.63009 .20792 m
.63301 .20702 L
s
.56461 .16674 m
.56254 .16275 L
s
.58325 .17421 m
.58077 .16943 L
s
.50821 .18183 m
.51082 .17227 L
s
.67214 .24078 m
.66814 .2389 L
s
.56992 .18094 m
.57235 .1822 L
s
.53151 .17386 m
.53406 .17896 L
s
.66303 .23347 m
.66686 .23814 L
s
.43628 .18748 m
.43361 .18565 L
s
.41696 .19383 m
.41382 .19659 L
s
.66686 .23814 m
.67125 .24234 L
s
.59578 .18078 m
.59344 .18217 L
s
.47906 .18184 m
.47613 .18732 L
s
.43563 .19864 m
.43854 .20133 L
s
.6076 .19181 m
.61028 .19241 L
s
.66814 .2389 m
.66416 .23736 L
s
.60496 .18856 m
.6076 .19181 L
s
.41382 .19659 m
.41037 .19969 L
s
.40388 .20303 m
.40083 .2031 L
s
.5856 .17852 m
.58325 .17421 L
s
.62693 .20813 m
.63009 .20792 L
s
.42735 .19329 m
.42436 .1897 L
s
.59836 .18273 m
.60099 .18918 L
s
.56698 .17047 m
.56461 .16674 L
s
.41037 .19969 m
.40719 .20177 L
s
.40719 .20177 m
.40388 .20303 L
s
.66416 .23736 m
.66001 .23644 L
s
.59972 .18378 m
.59734 .19103 L
s
.43923 .18883 m
.43628 .18748 L
s
.56644 .18117 m
.56896 .17453 L
s
.59344 .18217 m
.5909 .18267 L
s
.54555 .16962 m
.54332 .17549 L
s
.53406 .17896 m
.53677 .18345 L
s
.58799 .18139 m
.5856 .17852 L
s
.506 .18671 m
.50311 .17736 L
s
.62348 .20764 m
.62693 .20813 L
s
.44226 .19035 m
.43923 .18883 L
s
.5909 .18267 m
.58799 .18139 L
s
.43854 .20133 m
.44154 .20402 L
s
.66001 .23644 m
.65614 .23692 L
s
.56954 .17472 m
.56698 .17047 L
s
.43032 .19631 m
.42735 .19329 L
s
.47613 .18732 m
.47302 .19251 L
s
.60099 .18918 m
.60392 .19495 L
s
.6202 .20802 m
.62348 .20764 L
s
.44544 .19215 m
.44226 .19035 L
s
.50506 .19115 m
.50821 .18183 L
s
.53677 .18345 m
.53978 .18758 L
s
.56354 .18612 m
.56644 .18117 L
s
.61686 .20695 m
.6202 .20802 L
s
.65614 .23692 m
.65211 .23682 L
s
.43379 .19867 m
.43032 .19631 L
s
.57256 .17883 m
.56954 .17472 L
s
.54332 .17549 m
.54056 .18293 L
s
.60392 .19495 m
.60716 .20025 L
s
.44872 .19321 m
.44544 .19215 L
s
.44154 .20402 m
.44514 .20716 L
s
.61359 .20568 m
.61686 .20695 L
s
.47302 .19251 m
.46959 .19554 L
s
.4521 .19459 m
.44872 .19321 L
s
.59734 .19103 m
.59435 .19782 L
s
.60716 .20025 m
.61027 .20319 L
s
.61027 .20319 m
.61359 .20568 L
s
.53978 .18758 m
.54307 .19086 L
s
.65211 .23682 m
.6479 .23758 L
s
.43721 .20075 m
.43379 .19867 L
s
.57563 .18316 m
.57256 .17883 L
s
.45539 .19649 m
.4521 .19459 L
s
.56055 .18979 m
.56354 .18612 L
s
.50954 .19533 m
.506 .18671 L
s
.46959 .19554 m
.46613 .19716 L
s
.45903 .19727 m
.45539 .19649 L
s
.44101 .20354 m
.43721 .20075 L
s
.54307 .19086 m
.54643 .19252 L
s
.46613 .19716 m
.46261 .1977 L
s
.44514 .20716 m
.44832 .2089 L
s
.46261 .1977 m
.45903 .19727 L
s
.54056 .18293 m
.53759 .18914 L
s
.55699 .19236 m
.56055 .18979 L
s
.579 .18751 m
.57563 .18316 L
s
.50127 .1993 m
.50506 .19115 L
s
.6479 .23758 m
.6436 .23689 L
s
.54643 .19252 m
.55006 .19413 L
s
.55348 .1937 m
.55699 .19236 L
s
.44479 .2058 m
.44101 .20354 L
s
.55006 .19413 m
.55348 .1937 L
s
.58252 .19305 m
.579 .18751 L
s
.44832 .2089 m
.45208 .21072 L
s
.6436 .23689 m
.63922 .23726 L
s
.59435 .19782 m
.59124 .20212 L
s
.44882 .20864 m
.44479 .2058 L
s
.53759 .18914 m
.53419 .19607 L
s
.58602 .19973 m
.58252 .19305 L
s
.51334 .20234 m
.50954 .19533 L
s
.45208 .21072 m
.45613 .21251 L
s
.63922 .23726 m
.6349 .23637 L
s
.49725 .20641 m
.50127 .1993 L
s
.45304 .21174 m
.44882 .20864 L
s
.59124 .20212 m
.58759 .20527 L
s
.6349 .23637 m
.63015 .23551 L
s
.45613 .21251 m
.46076 .215 L
s
.56391 .19366 m
.56 .19406 L
s
.56767 .19586 m
.56391 .19366 L
s
.53419 .19607 m
.52998 .20293 L
s
.59002 .20628 m
.58602 .19973 L
s
.56 .19406 m
.556 .1955 L
s
.45722 .21548 m
.45304 .21174 L
s
.57165 .19809 m
.56767 .19586 L
s
.63015 .23551 m
.62584 .23499 L
s
.556 .1955 m
.55238 .19735 L
s
.57542 .20154 m
.57165 .19809 L
s
.49323 .2128 m
.49725 .20641 L
s
.51743 .20835 m
.51334 .20234 L
s
.58759 .20527 m
.58346 .20601 L
s
.55238 .19735 m
.54818 .20009 L
s
.46076 .215 m
.46475 .21641 L
s
.59406 .21284 m
.59002 .20628 L
s
.62584 .23499 m
.62122 .23391 L
s
.57958 .20439 m
.57542 .20154 L
s
.54818 .20009 m
.54407 .20346 L
s
.46186 .21814 m
.45722 .21548 L
s
.52998 .20293 m
.52624 .20745 L
s
.58346 .20601 m
.57958 .20439 L
s
.46475 .21641 m
.46949 .21792 L
s
.62122 .23391 m
.6163 .23314 L
s
.5983 .21962 m
.59406 .21284 L
s
.54407 .20346 m
.53964 .20654 L
s
.48857 .21613 m
.49323 .2128 L
s
.46679 .21997 m
.46186 .21814 L
s
.46949 .21792 m
.47421 .2197 L
s
.52127 .21182 m
.51743 .20835 L
s
.52624 .20745 m
.52174 .21034 L
s
.6163 .23314 m
.61194 .23067 L
s
.53964 .20654 m
.53473 .21009 L
s
.61194 .23067 m
.60733 .22778 L
s
.60266 .2239 m
.5983 .21962 L
s
.48381 .21855 m
.48857 .21613 L
s
.47172 .22231 m
.46679 .21997 L
s
.52174 .21034 m
.51714 .21386 L
s
.60733 .22778 m
.60266 .2239 L
s
.47421 .2197 m
.47906 .21945 L
s
.47906 .21945 m
.48381 .21855 L
s
.52618 .21252 m
.52127 .21182 L
s
.53473 .21009 m
.53055 .21149 L
s
.53055 .21149 m
.52618 .21252 L
s
.51714 .21386 m
.51229 .2168 L
s
.47632 .22507 m
.47172 .22231 L
s
.51229 .2168 m
.50725 .21915 L
s
.50725 .21915 m
.50209 .22232 L
s
.48176 .22599 m
.47632 .22507 L
s
.50209 .22232 m
.49718 .22516 L
s
.48673 .22645 m
.48176 .22599 L
s
.49197 .22681 m
.48673 .22645 L
s
.49718 .22516 m
.49197 .22681 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{426, 307.938},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Z0001<a000`40O003h00OogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003IOol;
0036Ool00<Qooa4000]oo`l00;Moo`00`7oo200077oo2WcP1GfP00=oo`0000001P00[Woo002jOol6
000FOol:O40=O>02@ch4OJ03O>000gd0O>1oo`03Ool00`00Ool00003002XOol00;Aoo`H00004Ooml
87ooO>05Ool00gbPOomoo`02Ool3O>001GbPO>1lh7cPO:000gcP2ga000=lh7a0O>002gcP14<n0gfP
0gcP00Em07cPO@1m07b000Moo`<00003Ool000000:9oo`00[goo1P0000=oog`POol00Woo2g`P1WcP
00IlX7cPO>1lh7bPO>08O4000gcPO41l@004O407O>02@ch2O>06@ch2OJ03O>0017d0@ci3?WbP17b0
00=l@7ooOol01goo0`0000=oo`00Ool0W7oo002[Ool50003O<06O>0;O207O>000gbPO>1lh002O:03
O>05O4000gcPO413?P02@ch00g`0O:1lX002O005O:03@ch00g`0@ci3?P05@ch01GbP@ci3?T<nO@00
0T<n00=m07b0O@000Wb000Al@4<nO41mX0]oo`<009Yoo`00Ygoo100000=oogc0O<001Gc01GcP3G`P
1GcP00AlX7cPO:1lh09lX093?P04O41oogooOol2O002Ool3@ch00g`0Oomoo`02O002Ool2O0001Goo
@ci3?T<nO0003d<n0Wd00Wb00d<n00AmX7a0OL1m`0]oo`04001oo`00002FOol00:Aoo`<0009oo`Yl
`0Ilh0El8003O>1lX7cP00=lX004OomlX7`0O006Ool01G`0@ci3?T<nO0000goo0W`00Woo14<n0Woo
0W`01Goo54<n00=l07a0@ch00T<n00=l@7fPOJ000Wg017a02goo0P0000=oo`00Ool0TGoo002QOol3
00000gooO21l8006O<02@ch5O<0017cPO21l87`P0gbP0g`00gbP1Goo0W`01Woo00El04<n@ci3?W`0
00=oo`9l009oo`E3?P03Ooml07`000Iooa=3?P9l00=3?P03OJ1l@7fP009m`003ON1l@7a000Al@0ao
o`<008moo`00WWoo0`0000Aoog`PO<1l`09l8004@cil`7c0O<04@ch017`PO01l07`027bP0g`02goo
0W`00goo00El04<n@ci3?W`000=oo`9l009oo`A3?PIoo`9l009ooa=3?P9l00A3?P03OJ1m`4<n009m
h0Ml@003O@1oogoo00aoo`8008aoo`00Vgoo0`0000=oog`POol00gc00W`P00=l`4<n@ch00Wc01D<n
00=lX7`0O0001GbP00=l07bPOol00g`02Goo00Al07ooO01l00=oo`03O013?T<n0093?P=oo`9l009o
o`A3?PIoo`9l009ooa=3?P9l00=3?P03O013?T<n00A3?PIl@0=m00ioo`03001oo`0008Uoo`00Ugoo
100000=oog`POol00g`P00El`7`PO<1l`7`P00A3?P03O:13?T<n00A3?P9l00AlX004Ooml07`0Ool3
O008Ool5O003Ool6@ch6Ool5@ch00gooO01l0002Ool2O002Ool4@ch2O00>@ch00g`0@ci3?P07@ch0
1GcPOL1l@7a0O@000Wa00gd000=lh7d0O@003Woo0P00Qgoo002EOol30002Ool6O2001Wc0@ci3?W`P
O<1l00Y3?P=l00Eoo`9l0003Ooml07`000Uoo`9l0003Ooml07`000=oo`93?P03Oom3?T<n00Moo`93
?P04O013?T<nOol2O002Ool2O003Ool2@ch3O007@ch00g`0@ci3?P0?@ch00ggP@cim0002O002O402
O@000gcPO@1m0002O@000gcPOomoo`0<Ool20024Ool009=oo`<0009oo`9l8003O01l87`P00Al8093
?P=l00Y3?P=l00Eoo`9l0003Ooml07`000Uoo`9l0003Ooml07`000=oo`93?P04Oom3?T<n@ch2Ool2
O002Ool2@ch017`0@ci3?Woo0W`00Woo0W`00goo0T<n0g`000=ood<n@ch00d<n0W`01T<n00=l04<n
@ch03d<n00=m07cPO>000Wd000Alh7d0O>1m009lh0eoo`03001oo`00085oo`00T7oo0`0017oo0g`P
0T<n17`P00=ood<n@ch00W`01d<n00Aoog`0@ci3?P9l00Ioo`9l009oo`9l00Qoo`9l0003Ooml07`0
00=oo`93?P9oo`93?P9oo`9l0005Oom3?T<n@cil0003@ch2O006Ool4@ch2O0000goo@ci3?P03@ch2
O006@ch00ga0@ci3?P0@@ch00gd0O01lh002O>000gd0O>1m0002O>000gd0Oomoo`0=Ool00`00Ool0
001nOol008ioo`8000Aoo`El80=3?P05O21oogooOomlX003@ch00g`0@ci3?P05@ch2Ool3@ch2O009
Ool2O007Ool3O006Ool2@ch2Ool2@ch2Ool2O0000goo@ci3?P02Ool3@ch2O006Ool5@ch00g`0Oom3
?P04@ch2O00I@ch2O0000ggPO>1m0003O@02O>001Gd0O>1lh7d0O>003Woo00<007ooOol0Ngoo002<
Ool20004Ool7O203@ch00g`0Oomoo`02Ool3@ch00g`0@ci3?P05@ch3Ool2@ch3O007Ool3O008Ool0
0g`0Oomoo`04Ool2@ch00g`0Oomoo`02@ch2Ool2O0000goo@ci3?P03Ool2@ch2O002Ool2O0000goo
@ci3?P05@ch00goo@ci3?P04@ch00goo@ci3?P03@ch00g`0@ci3?P0A@ch3O002ON000g`0O>1lh003
O@02O>000gd0O>1m0002O>0<Ool00`00Ool0001jOol008Yoo`8000Aoo`9l8003O01l87`P00Al80=3
?P03O01oogoo009oo`=3?P03O013?T<n0093?PAoo`9l00=3?P03O01oogoo00=oo`9l0004Ooml07`0
O00:Ool2O003Ool2@ch00g`0Oomoo`03@ch00gooO01l0003@ch2O00017oo@ci3?T<n0goo0W`000Ao
od<n@cioo`E3?P03O013?T<n0093?P9l01a3?P04ON1m`7`0O002Ool4O>000gd0O>1lh002O>02O@0=
Ool00`00Oomoo`1gOol008Qoo`8000Ioo`9l8093?P03O21l07`P009oo`=3?P03O01oogoo009oo`=3
?P03O013?T<n00=3?P=oo`9l00A3?PEoo`9l0004Ooml07`0O00:Ool2O003Ool2@ch00g`0Oomoo`03
@ch00gooO01l0002@ch00gooO01l0002Ool2@ch3Ool2O00017oo@cioogoo1D<n00=ood<n@ch00T<n
0W`07T<n1Goo0Wd000=lh7d0O@0017cP00Am07cPO@1m00aoo`8007Ioo`00QWoo0P001goo00=l07`P
O2000T<n00=l87`0O0000Woo0d<n1Goo24<n17oo0W`000Aood<n@cil00Eoo`9l0004Ooml07`0O007
Ool2O0000gooO01l0003Ool3@ch3Ool2@ch3Ool2@ch00gooO01l0002Ool3@ch017`0Ooml07`00T<n
0goo:D<n00=oog`0Ool01Goo00=m07cPO>000Wd000=lh7d0O>000Wd00WcP3Goo00<007ooOol0LWoo
0024Ool20005Ool00g`0Oomoo`02O002O202@ch00gooO01l0002Ool4@ch4Ool3@ch00goo@ci3?P02
@ch4Ool2O00017oo@ci3?T<n1Goo0W`000=oog`0O00027oo0W`000=oog`0O0000goo0T<n00Al07oo
Oomoo`=3?P9oo`93?P03Ooml07`000=oo`93?P05O01oog`0O013?P05OolO@ch00g`0@ci3?P07@ch2
O005Ool2O00017d0Oomlh7d00T<n0Wd01GcP37oo00<007ooOol0L7oo0022Ool200000gooO01oo`03
Ool8O003@ch4Ool3@ch5Ool3@ch00g`0@ci3?P02@ch4Ool2O0000goo@ci3?P02@ch4Ool2O0000goo
O01l0008Ool2O0000gooO01l0003Ool2@ch5Ool2@ch01G`0@ci3?T<nOol00W`00goo0T<n00=l07oo
O0000T<n1Goo00=l04<n@ch044<n00=n04<n@ch04T<n00=oog`0O0001Goo0W`017oo0T<n00El07d0
O>1lh7d0009lh09m00]oo`03001oogoo06moo`00PGoo00<007`0Ool03W`00d<n00=oog`0Ool00Woo
0T<n1Goo2D<n1Woo0W`00T<n17oo0W`00Woo0W`01goo0W`000=oog`0O0000Woo0d<n1Goo0T<n00=l
04<n@ch00Woo0W`00goo0d<n00Aood<n@ci3?PEoo`03O013?T<n0093?P03Oom3?T<n00]3?P03OP13
?T<n0193?P03Ooml07`000]oo`=3?P04O01lh7d0O@02O>03O@000gcPOomoo`09Ool00`00Oomoo`1]
Ool007moo`8000Al0093?PUl00E3?P=l0003Oom3?T<n0093?PAoo`U3?PAoo`06O01oog`0O01ood<n
27oo0W`01goo0W`01Goo0T<n0W`017oo1D<n27oo0T<n00=ood<n@ch01Woo0W`014<n00=ood<n@ch0
7d<n00=oog`0O0002goo0d<n0Woo0gd00T<n0Wd00gcP2Woo00<007ooOol0K7oo001mOol00g`0001l
0004O003@ch6O003Ool6@ch00g`0Oomoo`03@ch5Ool5@ch2Ool2@ch3Ool5O0000goo@ci3?P06Ool3
O007Ool2O005Ool2@ch2O005Ool4@ch8Ool5@ch8Ool7@ch00goo@ci3?P0L@ch017ooO01l07`01Goo
0W`00goo0d<n17oo00=l04<n@ch00Wd000=3?WcPO>0037oo00<007ooOol0JWoo001jOol017`0Ool0
00001W`00d<n0Woo0W`01Goo1D<n0W`00Woo0d<n1Woo14<n0Woo0d<n0Woo0W`000Aoog`0O01oo`A3
?P9l0003Oom3?W`0009l00Yoo`9l0004Oom3?T<n@ch2O005Ool4@ch2Ool2O005Ool4@ch7Ool7@ch2
O008@ch00g`0@ci3?P07@ch00g`0@ci3?P09@ch2Ool00g`0Oomoo`04Ool2O003Ool3@ch01G`0Oomo
ogooO0001T<n00=lh7ooOol037oo00<007ooOol0J7oo001hOol2O0020007O0000goo@ci3?P02@ch7
Ool00g`0@ci3?P03@ch2O002Ool4@ch5Ool3@ch4Ool2@ch2Ool2O005Ool8@ch2O00:Ool2O00017oo
@ci3?Woo0W`01Goo0d<n0goo0W`017oo0W`00T<n00=l07ooOol017oo0d<n00=ood<n@ch00T<n0W`0
4T<n0W`00Woo14<n3Goo0W`00Woo14<n00El07ooOomoog`000I3?P03O>1oogoo00ioo`03001oogoo
06Ioo`00Mgoo2G`017oo14<n1goo00=l04<n@ch00d<n0W`00Woo14<n1Goo0d<n17oo0T<n0Woo0W`0
0Woo00=l07ooOol02T<n1goo0W`000=oog`0O0000d<n00=oog`0O0001Goo0d<n0goo0W`017oo0W`0
0d<n1Woo0T<n17oo0d<n00Al07ooOomn00i3?P04Ooml07`0Ool5@ch00g`0Oomoo`0:Ool2O002Ool4
@ch01G`0OomoogooO0001T<n00=l07ooOol03goo00<007ooOol0IGoo001fOol8O006Ool3@ch00goo
O01l0005Ool017`0@ci3?Woo0T<n00Al07ooOomoo`A3?PEoo`=3?PAoo`=3?P=l0004Ooml07`0O006
@ch2Ool4@ch00goo@cioo`03Ool2O0000gooO013?P02@ch2Ool2O005Ool3@ch3Ool2O004Ool00g`0
@ci3?P03@ch2Ool00d<nOom3?P02@ch5Ool3@ch2Ool00gh0@ci3?P0=@ch3O002@ch017oo@cil07`0
17oo0W`01Woo0W`00Woo1D<n0goo00=l04<n@ch014<nNWoo001eOol8O007Ool3@ch00gooO01l0005
Ool017`0@ci3?Woo0T<n0goo1T<n17oo0d<n17oo0T<n0Woo00=l07ooOol00W`024<n00=ood<n@ch0
1D<n0goo0W`000Aood<n@ci3?PYoo`A3?P9oo`9l00Aoo`04O013?T<nO00;@ch4Ool3@ch2OP0<@ch0
17`0@ci3?T<n0W`014<n0W`017oo0W`01Woo0W`00Woo1D<n17oo1D<n5Goo00<007ooOol0Hgoo001d
Ool5O002Ool2O007Ool3@ch00gooO01l0005Ool3@ch017oo@ci3?W`00Woo0T<n00=ood<n@ch01Goo
0d<n17oo0d<n17oo00=l04<n@ch00T<n0Woo14<n00=oog`0@ch01D<n0Woo0W`00d<n2goo1D<n00=o
og`0O00017oo00=l04<nOol00Woo2d<n0goo00=l04<n@ch00Wh02T<n00Aoog`0O01oo`=3?P03O013
?T<n0093?P9l00Aoo`9l00Yoo`93?P03Oom3?T<n00Aoo`E3?QMoo`03001oogoo065oo`00Lgoo1G`0
0Woo0g`01goo0d<n00=oog`0O0001Goo0T<n0Woo0T<n00Al07ooOom3?P9oo`93?PAoo`E3?P=oo`A3
?P=oo`A3?P=oo`E3?P9l00=oo`Q3?PEoo`9l00Eoo`93?P03Oom3?T<n00Moo`93?PAoo`I3?P9oo`=3
?P=oo`93?P9n00U3?P04Ooml07`0O002Ool6@ch00gooO01l0004Ool2O00:Ool6@ch2Ool017`0@ci3
?Woo0T<nNgoo001bOol00`00O01l0002O004Ool00g`0Oomoo`06Ool3@ch00gooO01l0004Ool2@ch3
Ool2@ch017`0Oom3?T<n0Woo0T<n17oo0T<n00=ood<n@ch01Goo0d<n00=ood<n@ch00T<n17oo1d<n
0goo1d<n1Woo0W`017oo0d<n00=ood<n@ch01Woo0T<n17oo14<n1Woo0d<n0Woo1D<n00=l04<n@ch0
1D<n00=oog`0O00017oo14<n0Woo0W`017oo0W`01Woo0W`00Woo0T<n0Woo0T<n0Woo00Al04<n@cio
o`93?QUoo`03001oogoo05moo`00LGoo1W`03Goo0d<n00=oog`0O00017oo0T<n0goo0d<n00=ood<n
Ool00Woo0d<n0Woo0d<n0Woo00=3?WooOol017oo1T<n2Goo14<n3goo0W`017oo0T<n0Woo0d<n0W`0
0Woo0d<n0goo0d<n2Goo14<n00=n04<n@ch00T<n00=l07oo@ch01D<n00=oog`0O00017oo00Al04<n
@ci3?PQoo`9l00Ioo`9l009oo`93?P9oo`93?P9oo`04O013?T<nOol2@cikOol0071oo`El00moo`=3
?PMoo`=3?P9oo`E3?PAoo`I3?P=oo`93?PEoo`E3?P]oo`E3?Peoo`9l00=oo`93?PAoo`=3?P03O01o
od<n0093?P=oo`=3?PUoo`03OP1ood<n00M3?P03O01oogoo00I3?PAl009oo`05O013?T<nOom3?P02
Ool00g`0Oomoo`0:Ool2O00017oo@ci3?T<n0Woo0T<n0Woo00Al04<n@cioo`93?Qaoo`03001oogoo
05aoo`00Kgoo00<007`0O0000W`01Woo0W`027oo0d<n0Woo00Al07ooOomoo`=3?PAoo`04O013?T<n
@ch5Ool4@ch4Ool3@ch4Ool00g`0@ci3?P02@ch<Ool5@ch3Ool2O007Ool2O002Ool3@ch5Ool6@ch2
Ool4@ch5Ool017h0Oomoogoo17h01d<n00Al07ooOoml0153?P=l00]oo`9l0003Oom3?T<n00=oo`93
?P9oo`93?P03Oom3?T<n07aoo`00KWoo00<007`0O0000g`01Woo0W`01goo14<n00Aoog`0O01l009o
o`93?PMoo`03@cioogoo00Aoo`=3?PIoo`=3?P=oo`A3?Pioo`I3?P03Ooml07`000Moo`9l0004Oom3
?T<n@ch7Ool4@ch00goo@ci3?P03@ch5Ool;OP000g`0Oomoo`02@ch4OolB@ch2O003Ool2O006Ool2
O0000goo@ci3?P03Ool3@ch017oo@ci3?Woo0T<n7goo00<007ooOol0FWoo001/Ool20004O008Ool2
O007Ool5@ch2O003Ool3@chGOol2@ch00goo@ci3?P02@ch@Ool7@ch2O008Ool4@ch7Ool9@ch2Ool?
OP02O002Ool3@ch3Ool<@ch4Ool3@ch017`0Oomoogoo0W`01Woo0W`000=ood<n@ch00goo00=l04<n
@ch00d<n00=ood<n@ch0O7oo001[Ool20006O007Ool2O007Ool2@ch01Woo@ci3?T<nO01oo`A3?QQo
o`I3?QAoo`I3?P03Oom3?Woo00Aoo`A3?PMoo`Q3?P=oo`mn00Ioo`93?PAoo`Y3?PIoo`=3?P=oo`9l
00Uoo`=3?P9oo`9l00=3?P9oo`93?R9oo`03001oogoo05Moo`00JWoo0P0000=oog`0O0001G`01Woo
0W`01Woo0d<n0Woo1d<n6Goo14<n67oo24<n00=ood<n@ch00T<n1goo14<n1goo2gh017oo0W`01Woo
00=l04<n@ch00goo0T<n0Woo0d<n00=l07ooOol01goo0d<n0Woo0W`01goo00Al07oo@ci3?PEoo`=3
?P9oo`93?Waoo`00JGoo0P0000=oog`0O0001G`01goo0W`01Woo0T<n0goo1T<n>7oo2T<n00=l07oo
Ool00goo1D<n1goo0gh00T<n00=n07`0OP0027oo00=l04<n@ch00W`00goo00=l04<n@ch00T<n00=o
od<n@ch047oo0T<n0Woo0W`01Woo0g`00T<n2Woo0T<nO7oo001XOol200000gooO01l0002O002Ool2
O00?Ool2@ch3Ool4@chlOol6@ch00gooO013?P03Ool5@ch5Ool7OP03@ch2O009Ool3@ch017`0Oomo
ogoo0W`01T<n4Goo00=3?WooOol00W`01goo00Al04<n@ci3?P=oo`9l00Eoo`93?Waoo`00Igoo0P00
00=oog`0O0000g`00Woo0W`03Woo0d<nAGoo3D<n1Woo27h014<n2Woo0d<n00Al07ooOomoo`9l009o
o`=3?PEoo`9l00]oo`93?PYoo`03O013?T<n00Aoo`9l00Aoo`=3?REoo`03001oogoo05Aoo`00IWoo
0P000Woo17`00Woo0g`01Woo0W`01Woo0T<nAgoo2T<n1goo27h000Aood<n@ci3?PYoo`05O013?T<n
@cil0003Ool2O003Ool3@ch4Ool2O00;Ool3@ch9Ool00g`0@ci3?P04Ool2O004Ool2@cimOol006Io
o`03001oogoo00El00=oo`03O01oogoo00Eoo`9l00Ioo`93?Tioo`03@cioogoo00Eoo`Mn00Aoo`=3
?P9l00Qoo`A3?P03O01oogoo00Ioo`E3?P04Oom3?W`0O00<Ool3@ch2O006Ool3@ch4Ool2O004Ool2
@cimOol006Eoo`03001oogoo00El00aoo`9l00Ioo`93?UAoo`Mn00Ioo`=3?P9l00Qoo`A3?PUoo`U3
?P=oo`03@cioogoo00Moo`=3?P03O01oogoo00=oo`=3?PEoo`9l00=oo`=3?Weoo`00I7oo0P000Woo
17`03Goo0W`01Goo0d<nDGoo27h027oo0d<n0W`027oo14<n17oo0W`00goo0T<n00=ood<n@ch02D<n
1Woo1T<n17oo0d<n1Woo0W`00goo0T<nOWoo001SOol20002Ool5O004Ool2O007Ool2O005Ool2@ciA
Ool6OP000g`0OP1oo`08Ool3@ch2O008Ool4@ch017`0Oomoogoo0W`00Woo0T<n1Woo54<n0goo0T<n
37oo0T<nOWoo001SOol00`00Oomoo`06O004Ool2O007Ool2O004Ool3@ci@Ool7OP02O009Ool3@ch2
O008Ool5@ch3Ool017`0@cioogoo0d<n2Woo2D<n00=ood<n@ch024<n2goo0d<nOWoo001ROol00`00
Oomoo`07O004Ool2O00<Ool3@ci@Ool6OP02Ool2O009Ool3@ch2O008Ool2@ch00goo@ci3?P03Ool6
@chHOol6@ch9Ool2O0000goo@ci3?P1oOol0065oo`04001oogooOol4O007Ool2O008Ool00g`0Oomo
o`03@ci>Ool7OP0?Ool4@ch8Ool3@ch00goo@ci3?P02Ool6@chIOol6@ch9Ool2O0000goo@cioo`0_
Ool00`00Oomoo`1=Ool0065oo`03001oogoo00El00Moo`9l00Moo`=l0003Oom3?T<n04eoo`Mn015o
o`E3?PMoo`93?P9oo`93?P03Oom3?T<n00A3?Qioo`=3?PQoo`9l0093?X1oo`00H7oo00<007ooOol0
17`00Woo0W`01Goo0W`01goo0W`000Aood<n@ci3?Taoo`Qn00Ioo`9l00Uoo`93?P03Oom3?T<n00Io
o`93?P=oo`93?P03Oom3?T<n02=oo`A3?PIoo`04O013?T<n@cj0Ool005moo`800003Ooml07`000=l
009oo`9l00ioo`9l00=3?T]oo`Qn00Qoo`9l00Uoo`93?P03Oom3?T<n00Ioo`93?P=oo`E3?RAoo`E3
?P=oo`A3?X5oo`00Ggoo00<007ooOol017`00goo0W`03Goo1D<nBWoo27h02Woo0W`02Goo0T<n00Ao
od<n@ci3?PEoo`93?P=oo`A3?RMoo`U3?X9oo`00GWoo0P0000=oog`0O0000g`00goo0W`017oo0W`0
1Woo1D<nBWoo1gh00T<n00=l07ooOol01goo0W`02Goo0T<n00=ood<n@ch01Woo0T<n17oo0d<n:7oo
1T<nQ7oo001NOol00`00Oomoo`04O004Ool2O004Ool2O005Ool4@ci;Ool7OP0017oo@ci3?W`02Goo
0W`02Goo0T<n00=ood<n@ch01Woo0T<n^Goo001MOol00`00Oomoo`05O004Ool2O004Ool2O004Ool3
@ci9Ool00gh0Oomn0005OP02O002Ool2@ch00g`0Oomoo`07Ool2O009Ool2@ch017oo@ci3?T<n1Goo
00=3?WooOol0^7oo001MOol00`00Ooml0004O00;Ool2O004Ool2@ci9Ool8OP000gooO01l0002Ool3
@chDOol2@ch2Ool3@ch3Ool2@cjjOol005aoo`04001oogooOol3O007Ool00g`0Oomoo`02Ool2O003
Ool3@ci8Ool8OP02Ool2O002Ool3@chDOol2@ch3Ool3@ch017oo@ci3?T<nKgoo00<007ooOol0B7oo
001LOol00`00Oomoo`05O005Ool3O003Ool2O002Ool3@ci7Ool7OP09Ool3@ch9Ool2O009Ool2@ch4
Ool5@cjkOol005]oo`03001oogoo00Il00Eoo`9l00Qoo`93?TIoo`Mn00Yoo`A3?PUoo`9l00Uoo`93
?PAoo`A3?[aoo`00Fgoo00@007ooOomoo`El00Eoo`9l00Eoo`03O01ood<n0093?TEoo`Mn00Qoo`9l
0003Oom3?T<n0093?PUoo`9l00Uoo`93?/Aoo`00FWoo0P000Woo1W`01Goo0W`017oo0W`00d<nA7oo
1Wh00W`02Goo0W`000=ood<n@ch00T<n2Goo0W`02Goo0T<nNgoo00<007ooOol0AWoo001JOol01000
Oomoogoo1W`017oo0g`017oo00Al04<n@ci3?TAoo`Mn009l00Uoo`9l0003Oom3?T<n0093?PUoo`9l
00Qoo`93?/Eoo`00FWoo00@007ooOomoo`Il00Eoo`03O01oogoo00=oo`03O013?T<n04Aoo`In009o
o`9l00Uoo`9l0003Oom3?T<n0093?PUoo`9l00Qoo`93?/Eoo`00FGoo00@007ooOomoo`El00eoo`=3
?TAoo`03OP13?T<n009n00ioo`9l0003Oom3?T<n00=3?Q9oo`93?Weoo`03001oogoo04Eoo`00FGoo
00@007ooOomoo`El00Moo`03O01oogoo009oo`=3?TAoo`9n0093?P03OP1oogoo00eoo`9l0003Oom3
?T<n00=3?Q9oo`93?/Eoo`00FGoo00<007ooOol00Woo1G`01Goo0g`00Woo0d<nAWoo00=n04<n@ch0
1Goo0W`037oo0T<n00=ood<n@ch027oo0W`027oo0T<nOGoo00<007ooOol0AGoo001HOol20004Ool5
O005Ool2O003Ool3@ci5Ool2OP02@ch5Ool2O00<Ool2@ch017oo@ci3?T<n1goo0W`01goo0T<naWoo
001HOol00`00Oomoo`03Ool5O005Ool2O002Ool3@ci6Ool2OP03@ch4Ool2O009Ool2O003@ch2Ool2
@ch7Ool2O007Ool2@cioOol00`00Oomoo`14Ool005Qoo`03001oogoo00=oo`El00Eoo`9l0004Oom3
?T<n@ci6Ool3OP02@ch5Ool2O009Ool2O002@ch3Ool2@ch7Ool2O007Ool2@ck6Ool005Qoo`03001o
ogoo00=oo`El00Aoo`=l0003Oom3?T<n04Qoo`04OP1l04<n@ch5Ool2O009Ool2O002@ch3Ool3@ch6
Ool2O007Ool2@cioOol00`00Oomoo`14Ool005Qoo`03001oogoo00=oo`El00Eoo`03O01oogoo0093
?TQoo`9n00=3?PAoo`9l00Uoo`9l0093?P=oo`93?PMoo`9l00Moo`93?/Ioo`00Egoo00<007ooOol0
17oo17`02Goo00=3?WooOol0AWoo0Wh014<n3goo0W`00T<n0goo0T<n3goo0T<nPGoo00<007ooOol0
@goo001GOol00`00Oomoo`03Ool6O007Ool2@ci8Ool00gh0O013?P03@ch?Ool017`0@ci3?T<n0goo
0T<n3goo0T<nagoo001GOol00`00Oomoo`04Ool6O003Ool2O003@ci7Ool2OP000g`0@ci3?P03@ch3
Ool2O00:Ool2@ch4Ool2@ch7Ool2O006Ool2@cj1Ool00`00Oomoo`13Ool005Moo`03001oogoo00Eo
o`Al00Aoo`04O013?T<n@ci9Ool00gh0O013?P03@ch4Ool2O00:Ool2@ch4Ool3@ch6Ool2O006Ool2
@cj1Ool00`00Oomoo`13Ool005Moo`03001oogoo00Aoo`El00Aoo`=3?TUoo`03OR1n07`000A3?PAo
o`9l00Uoo`03O013?T<n00Ioo`03@cioogoo00Aoo`9l00Ioo`93?/Moo`00Egoo00<007ooOol00goo
1W`017oo0T<nBWoo00=n07`0O00014<n17oo0W`02Goo0d<n1Woo0T<n1Goo0W`01Woo0T<nPGoo00<0
07ooOol0@goo001GOol00`00Oomoo`03Ool6O004Ool2@ci9Ool2OR02O005@ch3Ool2O009Ool2@ch8
Ool2@ch4Ool2O006Ool2@cj1Ool00`00Oomoo`13Ool005Moo`03001oogoo00=oo`Il00=oo`=3?T=o
o`Qn809l00E3?P=oo`9l00Uoo`93?PQoo`93?PAoo`9l00Ioo`93?/Moo`00Egoo00<007ooOol00goo
1W`00Woo0d<n@goo2ghP0T<n00=ood<n@ch03Woo0T<n27oo0T<n2goo0d<nPGoo00<007ooOol0@goo
001GOol00`00Oomoo`03Ool6O00017oo@ci3?T<n@goo0ghP0T<n1WhP00Al04<n@cioo`=3?Peoo`93
?PQoo`93?P]oo`93?X9oo`03001oogoo04=oo`00Egoo00<007ooOol00goo1W`000Aood<n@ci3?T9o
o`An8093?P=n80Al0093?P03Oom3?T<n00=oo`9l009oo`03@cioogoo00=oo`=3?PQoo`93?PAoo`9l
00Eoo`93?X9oo`03001oogoo04=oo`00Egoo00<007ooOol01Goo17`00d<n@Goo17hP00Al07hP@ci3
?P9oo`=3?P9l0093?P03Oom3?T<n00=oo`9l0003Oom3?T<n00M3?PUoo`=3?P=oo`9l00Aoo`=3?/Qo
o`00Egoo00<007ooOol01Woo0W`00d<n@Goo1WhP00Eood<n@cioog`000=3?P9l0093?P03Oom3?T<n
00=oo`9l00U3?P]oo`93?P=oo`9l00Aoo`93?X=oo`03001oogoo04=oo`00Egoo00<007ooOol00Woo
0W`00Woo00Al04<n@ci3?T1oo`Mn809oo`93?P03Ooml04<n0093?P9l0093?P04Oom3?T<n@ch2Ool0
17`0@ci3?T<n4Woo0T<n0goo0W`017oo0T<nPgoo00<007ooOol0@goo001GOol00`00Oomoo`02Ool4
O004@chnOol8OR000gooO01l0003@ch00g`0@ci3?P02@ch00g`0@ci3?P03Ool00d<nOomoo`03@chC
Ool3@ch2Ool2O003Ool3@cj3Ool00`00Oomoo`13Ool005Moo`03001oogoo009oo`=l00=3?P03O01o
ogoo03Yoo`Un80=oo`9l00=3?P03O013?T<n00E3?P=oo`E3?QEoo`93?P9oo`9l00=oo`93?XAoo`03
001oogoo04=oo`00Egoo00<007ooOol00Woo0W`00d<n0g`0>Woo17hP00A3?WhPOR1n809l00=oo`9l
00]3?P=oo`A3?QIoo`=3?PIoo`03@cioogoo08=oo`03001oogoo04=oo`00Egoo00<007ooOol00Woo
0W`00T<n17`0>Woo17hP0T<n00An87ooO01l00=oo`03O013?T<n00Y3?P=oo`=3?QQoo`93?PEoo`93
?XEoo`03001oogoo04=oo`00F7oo00D007ooOomoog`00093?PEl03Yoo`An8093?P9oo`9l00=oo`03
O013?T<n00Y3?Qmoo`05@cioog`0O01oo`03@cj4Ool00`00Oomoo`14Ool005Qoo`03001oogoo009o
o`=3?PAl03Yoo`04OR1l07`0OR03@ch00gooO01l0003Ool00g`0@ci3?P0:@chOOol2@ch2O0000goo
@ci3?P25Ool00`00Oomoo`14Ool005Qoo`04001oogooOol3@ch5O00jOol3O003@ch2Ool2O004Ool2
@ch017oo@ci3?Woo1T<n7goo0d<n00Al07oo@ci3?XEoo`03001oogoo04Aoo`00F7oo00@007ooOomo
o`93?PIl03Yoo`=l00=3?P9oo`9l00=oo`93?PEoo`I3?R1oo`I3?XEoo`03001oogoo04Aoo`00FGoo
00<007ooOol00d<n1W`0>Goo1T<n1goo0T<n00=l07ooOol00Woo1T<n8Goo14<nQGoo00<007ooOol0
AGoo001KOol3@ch7O00iOol6@ch3Ool017`0Oomoogoo0T<n1Goo1D<n8Woo00=l04<nOol0QWoo00<0
07ooOol0AGoo001IOol01000Oom3?T<n2G`0>7oo1T<n0Woo0g`00Woo0T<n1Goo1D<nZgoo00<007oo
Ool0AGoo001IOol01000Oom3?T<n0W`00Woo1G`0>7oo1T<n0Woo0W`000=3?WooOol00T<n1Goo1D<n
ZWoo0P00Agoo001JOol00`00@ci3?P02O0000gooO01l0005O00gOol2@ch00g`0OR13?P02@ch00goo
O013?P04@ch00g`0Oomoo`05Ool3@cjZOol00`00Oomoo`16Ool005Yoo`030013?T<n00=l0003Ooml
07oo00Al03Moo`93?P03O01n87hP0093?P03Oom3?T<n00A3?PQoo`=3?ZYoo`03001oogoo04Ioo`00
Fgoo0T<n00=oog`0O0000goo17`0=goo0T<n00=l07hPOR002D<n27oo0d<nZGoo00<007ooOol0Agoo
001KOol3@ch2O003Ool6O00eOol2@ch3OR04@ch2Ool2@ch9Ool4@cjXOol00`00Oomoo`17Ool005]o
o`=3?PAl0003Ooml07`000El03Aoo`93?P03O01n87hP00A3?Peoo`=3?ZUoo`03001oogoo04Moo`00
G7oo0T<n17`000Aoog`0O01oo`Al03Aoo`93?P9l009n811oo`93?ZUoo`03001oogoo04Qoo`00G7oo
0T<n17`000Aoog`0O01oo`Al03Aoo`93?P9l009n8;Yoo`8004Yoo`00G7oo0T<n0Woo1G`00Woo17`0
<goo0T<n0W`00WhP^Woo00<007ooOol0BGoo001LOol2@ch01WooO01l04<nOoml00Aoo`El035oo`93
?P9l009n8;Uoo`8004]oo`00G7oo0T<n0g`000=3?WooOol01Goo1G`0<7oo0T<n00=l07hPOR00^Woo
00<007ooOol0BWoo001LOol2@ch2O003@ch6Ool6O00^Ool00giP@ci3?P03OR02OV2gOol2001<Ool0
05aoo`93?P9l00=3?P03O01oogoo00Aoo`El00=oh0=oo`9n@003O01n@7i0009n@0]oo`An@15oo`9n
H093?P9l0004OR1nH7iPOV2fOol00`00Oomoo`1;Ool005aoo`=3?P05O013?T<n@cil0007Ool3O000
0d<nOn1oh003On000giPOT1n@00;OT02Ool7OT0?Ool3OV03@ch2O0000ghPOV1nH002OV2dOol00`00
Oomoo`1<Ool005aoo`M3?P03O01oogoo009oo`9l0004Oom3?T<n@ch6On0017iP@ci3?W`05Wi02Goo
00=nH7ooOV000giP0d<n0W`01GiP]7oo00<007ooOol0C7oo001MOol6@ch00g`0Oomoo`02Ool2O000
17oo@ci3?T<n0W`017oP00AnH4<n@ci3?Q1n@093?PEn@0Aoo`03OV1oogoo00MnH0=3?PAl00AnH;9o
o`03001oogoo04eoo`00GGoo1T<n00=l07ooOol00Woo0W`000Aood<n@ci3?P9l0003Oomoh7oP00E3
?P9l0003Ooml07`000In@093?P03OT1l07`00093?PMn@003OomnH7iP00InH003O01nH7iP00=3?P9l
0003@cil07oo00InH:ioo`03001oogoo04ioo`00GGoo1T<n00=l07ooOol00Woo0W`000Aood<n@ci3
?P9l00=oo`Q3?P03OV1oogoo00=oo`9l0093?P=oo`=3?PIn@0YnH09n@0=3?P9l0093?P9oo`EnH:io
o`03001oogoo04ioo`00GGoo1T<n1Goo0W`000Aood<n@ci3?P9l00=oo`Q3?PInH09l0093?P9nH0=3
?P9nH0En@0MnH0En@0I3?PAoo`EnH:aoo`03001oogoo04moo`00GGoo1T<n00=oo`00Ool00Woo0W`0
00Aood<n@ci3?PEoo`Q3?P03O01nH7iP00=nH09l00=3?P04O013?T<n@ch3OV0017`0OT1n@7i00WiP
0W`01Gi00W`000=n@4<n@ch00T<n00=l04<nO0000goo00=l07iPOV001GiPZ7oo00<007ooOol0D7oo
001MOol6@ch7Ool4@ch00gooO01oo`02Ool9@ch5OV02O007@ch3OV02O00017ooOT1n@7i00W`01Gi0
0W`000Aood<n@ci3?P=l0004@cioogooOol2O0000gooOV1nH004OV2VOol00`00Oomoo`1AOol005eo
o`I3?PMoo`A3?P=l009oo`Y3?P=nH09oo`Q3?P03Ooml07`0009l00Eoo`9l00Aoo`9l0004Oom3?T<n
@ch2O002@ch3Ool2O002Ool6OV2FOol4O^0:Ool2001COol005eoo`I3?PAoo`9l0003Oom3?T<n0093
?P9l00=oo`A3?P03O01oh7oP0093?P03O01oogoo00=oo`Q3?P03Ooml07`0009l00Eoo`9l00Aoo`9l
00E3?P03O013?T<n00=oo`9l00=oo`InH9=oo`Mnh0=o00Ioo`03001oogoo059oo`00GGoo1T<n17oo
0W`000=ood<n@ch00d<n00Al07ooOomoo`=3?P9l009oh093?P03O01oogoo009oo`03O013?T<n00I3
?PUoo`=l00Aoo`9l00E3?P03O013?T<n00=oo`9l00Aoo`InH95oo`=nh093?P=nh0=o00Eoo`03001o
ogoo05=oo`00GGoo0d<n00=ood<n@ch017oo0W`000Aood<n@cioo`93?P04O01oogooOol3@ch2O002
On02@ch00g`0Oomoo`02Ool017`0@ci3?Woo1D<n2Goo0g`017oo0W`024<n2Goo0W`01GiPSgoo17kP
0T<n0gkP0gl017oo00<007ooOol0E7oo001MOol6@ch4Ool2O002@ch2Ool3@ch4Ool2@ch2O002On03
@ch4Ool00g`0@cil0004Ool2@ch2O0000gooO01l0004Ool3O006Ool8@ch9Ool2O007OV1nOol00gkP
Oomoo`0;Ool5O^03@ch01Gl0@ci3?W`0O`000goo00<007ooOol0EGoo001MOol3@ch00goo@ci3?P04
Ool2O002@ch2Ool4@ch3Ool2@ch2O002On04@ch3Ool2@ch00g`0Oomoo`02Ool2@ch2O0000gooO01l
0004Ool2O005Ool2O008@ch3Ool2O004Ool2O0000gooOV1nH006OV1gOol017kPOomoogoo4WkP0W`0
1d<n00Ao07ooOol005Qoo`00GGoo0T<n0Woo0T<n17oo0W`00T<n0goo0T<n0goo00=l04<n@ch00g`0
0WoP0T<n00=l07ooOol00T<n0W`017oo0d<n00Al07ooO01l00Aoo`9l00Eoo`03O013?T<n00M3?P=o
o`9l00Aoo`9l00=oo`MnH61oo`Un`2=nh09l00=3?P04O013?T<n@ch2Ool00`00Oomoo`1GOol005eo
o`93?P9oo`93?PIoo`93?P=oo`=3?P9oo`03O013?T<n009l00=oh0=3?P9oo`=3?P03O01oogoo009o
o`=3?P04O01oog`0O004Ool2O005Ool00g`0@ci3?P08@ch2Ool2O00:Ool00giPO01nH003OV1NOol:
O/02@chNO^04@ch2O003@ch00g`0@ci3?P02@ch00`00Oomoo`1HOol0065oo`93?PEoo`03O013?T<n
00Aoo`93?P9oo`03O013?T<n009l00=oh0M3?PMoo`93?P04O01oog`0O004Ool2O005Ool4@ch01Goo
@ci3?T<nOol00T<n0Woo0W`02goo14<n00=nH7ooOol0Fgoo0gk00T<n1Wk00T<n2WkP00=3?WkPO^00
1GkP2goo00El04<n@ci3?Woo009l00U3?UYoo`00HGoo0d<n0goo0W`000=3?WooOol00Woo00<004<n
@ch00Woo00=l04<n@ch01T<n00=l04<n@ch00T<n27oo0d<n00=oog`0O0000goo00=3?W`0@ch01Goo
0d<n0Woo0T<n0Woo0T<n0Woo0W`017oo0W`01Goo14<n00=nP7ooOol0F7oo1Wk00T<n0gk000=l07k0
O0000T<n1GkP0goo00=nh4<n@ch00gkP17oo00Al07ooOomoo`9l00Eoo`04O013?T<n@ch3Ool5@ch0
0g`0@ci3?P1KOol0065oo`=3?P=oo`03O013?T<n00Eoo`=3?P03Ooml04<n00]3?P9oo`9l00Eoo`93
?PIoo`E3?P=oo`A3?P9oo`93?P9oo`93?P9oo`9l00Aoo`9l00Aoo`03O013?T<n00=3?UQoo`Qn`0=3
?P=oo`9l00=3?P03O01oogoo009oo`=o@093?P03Ooml07`000=oo`=l009oo`9l00Ioo`=3?P9oo`03
O`13?T<n00=3?P03O013?T<n05]oo`00HWoo0T<n0goo00=l04<nOol01Woo0T<n00=oog`0O00014<n
00=l04<n@ch00d<n0WoP00=oog`0O0001Goo0T<n0g`00Woo1d<n00=ood<n@ch00T<n1goo0d<n1goo
0W`017oo00=l04<n@ch00T<n17j0EGoo00=n`4<nO/0017k000=ood<n@ch00T<n0Woo0W`014<n0Woo
0W`000=o@4<nO0000d<n0W`017oo0W`00Woo0W`01Woo0d<n00=oogl0@ch01D<n00=l04<n@ch0Fgoo
001ROol3@ch2Ool2@ch7Ool2@ch2Ool01G`0Ooml07`0Ool00W`000Aood<n@ci3?P=oh09l00Eoo`93
?P=l0006Oom3?T<n@cioog`01d<n2Goo0T<n1goo0W`017oo00=l04<n@ch00T<n17j0E7oo00In`4<n
@cin`7`0O/03Ool3@ch017`0Oomoog`01D<n0Woo00=l04<n@ch01T<n00=l07ooOol00Woo0W`000A3
?WooO01l00Ioo`=3?P9o0093?P05Ool00000Ooml0002@ciKOol0069oo`93?P9oo`93?P03O01oogoo
00Eoo`=3?PEl0004Ooml07`0Ool3@ch3On02O002Ool00d<nOomoo`03@ch2O0001Goo@ci3?T<nOol0
1d<n2Woo0d<n0W`017oo0W`017oo00El04<n@ci3?W`000InP55oo`9n`0=3?P9l00=oo`a3?P9oo`03
O013?T<n00E3?PAoH09oo`A3?P9l00Ioo`A3?P04O`13?T<n0003Ool00g`0@ci3?P1KOol0069oo`=3
?P04Oom3?T<n@ch7Ool4@ch01G`0Ooml07`0Ool00W`000=ood<n@ch02T<n00=ood<n@ch02d<n3Woo
14<n00=l07ooOol00Woo0W`00goo0W`00d<n0W`00T<n17j0D7oo0gk00T<n0W`00goo2D<n00Iood<n
@ci3?WooO007@ch00gmPO01oH003Of05@ch00g`0Oomoo`04Ool4@ch00gl0@ci3?P05Ool2@ciKOol0
069oo`I3?PYoo`=3?P04Ooml07`0Ool2O002OolG@chAOol3@ch00g`0Oomoo`08Ool00g`0@ci3?P02
@ch00g`0@ci3?P06OX1=Ool2O/0017`0O/13?T<n0W`00goo2D<n00Eood<n@ci3?Wm000U3?P9l009o
H0E3?PMoo`03O`13?T<n0093?P030013?T<n00Eoo`93?U]oo`00Hgoo14<n2goo0T<n00=l07ooOol0
0Woo0W`01Goo00=l07oPOn000goP3T<n4Goo14<n2goo0d<n0W`00T<n27j0Bgoo0Wk00W`00T<n0W`0
0goo1D<n1Woo3D<n00=l04<nOf000T<n00AoH4<n@ci3?P9l009oH003Oomo07l000Q3?PAoo`93?U]o
o`00Hgoo0d<n37oo14<n2Woo0W`000=oogoPOn001GoP00=ood<n@ch014<n5Woo0d<n00=ood<nOol0
0W`01Goo0T<n0Woo0d<n00=oogj0OX001Wj0BGoo0gk00W`00d<n17oo0T<n2Goo3D<n00=l04<n@ch0
0d<n00=oH4<n@ch00W`00WmP0gl00T<n00=o04<n@ch00T<n00El07ooOomoog`00093?U]oo`00LWoo
1D<n0goo00=l07ooOol00goo0W`00Woo27oP6goo1T<n0W`00goo0W`00T<n0Woo0d<n00=oog`0O000
27j0AWoo1Gk000=ood<n@ch00T<n0goo0T<n2goo00=3?W`0@ch03T<n00EoH4<n@ci3?W`0009oH0=o
00=3?P05Oom3?T<n@cil0004Ool2@ciKOol007=oo`E3?P04Ooml07`0O009Ool9On0JOol6@ch017`0
Oomoogoo0W`00d<n00El04<n@ci3?Woo009l0003OomnP7j000QnP49oo`En`003Ooml04<n0093?P9l
009oo`93?P]oo`03@cil04<n0093?P9oo`U3?P03OomoH4<n00=3?P04O01oH4<nO`03@ch2Ool2@ch2
O004Ool2@ciKOol007Eoo`93?P9oo`9l009oo`03001oogoo00Eoo`9l0003On13?T<n00Eoh1aoo`A3
?P=oo`03O013?T<n0093?P03O013?T<n0093?P9l00Aoo`YnP3moo`En`09l00=3?P9l009oo`=3?PYo
o`A3?P03Od1oogoo00U3?P9l0003O`13?T<n00M3?PEoo`9l00Aoo`93?U]oo`00MGoo0T<n0Woo0W`0
17oo0W`017oo0W`00d<n1WoP6goo1D<n0Woo00=l04<n@ch00T<n00=l04<n@ch00d<n1Woo00=nP7`0
OX002Wj0>Woo0gk00W`00Woo1D<n00=l07oo@ch00T<n2goo14<n0Wm000=o84<n@ch024<n00Al07l0
@cil00M3?P03O01oogoo009oo`9l00Aoo`93?P03O01oogoo05Qoo`00MGoo0T<n0Woo0W`017oo0W`0
1Woo0d<n00=l07oPO0000goP7Goo0d<n0Woo2T<n1goo0W`03Wj0=goo0gk00W`00Woo1T<n00=ood<n
@ch037oo14<n0gm00WlP2D<n00=o04<n@ch01T<n00=l07ooOol00goo0W`017oo0T<nFgoo001eOol2
@ch017ooO01l07`017oo0W`000<007ooOol00goo0d<n0W`01GoP77oo1d<n00=ood<n@ch00T<n00Eo
od<n@ci3?W`000Eoo`9l00=oo`inP3Aoo`=n`09l009oo`93?P9oo`E3?Paoo`A3?P9o@093?P9o8093
?P=o80]3?P03O01oogoo00Uoo`93?Uaoo`00MGoo0T<n0Woo00=l07ooOol00goo00=l04<nOol00Woo
00<007`0O0000d<n0W`000=oogoPOn000goP77oo1T<n0Woo0d<n00Eood<n@ci3?W`000Eoo`9l00Io
o`03OX1l07j000]nP31oo`An`09l009oo`93?P03O01ood<n00A3?Paoo`A3?P05Oomo@4<n@cil0005
Ob02Oh02@ch00gn0@ci3?P05@ch8Ool017`0Oomoogoo0T<nG7oo001eOol2@ch8Ool3@ch3Ool2O004
@ch00g`0Oomoo`07On0VOol3@ch=Ool2O002Ool;OX0_Ool4O/02O002Ool2@ch2Ool4@ch>Ool3@ch2
Ool3@ch2Od02O002@ch00gn0@ci3?P08@ch2O005Ool3O002Ool2@ciLOol007Eoo`93?PMoo`E3?P9o
o`9l00A3?P03O01oogoo009oo`Eoh2Ioo`=3?Peoo`9l00Eoo`QnP2moo`04O/1l07`0O/04Ool2@chD
Ool3@ch00gooOh13?P03@ch00gm0O01l0002@ch00gooO013?P07@ch00gooO01l0006Ool2O002Ool2
@ciLOol007Eoo`93?P03Ooml07`000Aoo`A3?P=oo`9l00A3?PEoo`03O01oh7oP00Eoh2Aoo`93?PAo
o`9l00Moo`9l00Moo`03O01nP7j00093?P03OX1oogoo02aoo`An`0Eoo`93?QAoo`A3?P06Oh13?T<n
@cil04<n0W`00T<n00=oog`0@ch01T<n0Woo0W`01Woo0W`00Woo0T<nG7oo001eOol2@ch00gooO01l
0004Ool4@ch3Ool00g`0@ci3?P04@ch4Ool2O008On0ROol2@ch4Ool2O007Ool2O009Ool00gj0@ci3
?P02OX0]Ool4O/000gooO01l0002Ool2@chCOol017n0@ci3?T<n0Wn01D<n0W`00T<n00=oog`0@ch0
1d<n00=oog`0O0001Woo0W`00Woo0T<nG7oo001eOol2@ch00gooO01l0003Ool6@ch2Ool017`0@ci3
?Woo0T<n0Woo0P0000=oog`0O0000Woo1WoP8Woo0d<n0goo0W`01goo0W`02Woo0T<n0gj0:Woo17k0
0W`000=oog`0O0000Woo0T<n4Woo0Wn00T<n00=l07n0Oh001D<n0W`00d<n00=l04<n@ch01T<n00=o
og`0O0001Woo0g`000=ood<n@ch0G7oo001eOol2@ch00gooO01l0003Ool2@ch2Ool2@ch3Ool2@ch0
0goo@ci3?P05Ool2O003Ool8On0OOol4@ch2Ool2O00@Ool2O0000goo@ci3?P04OX0VOol7O/02O000
0gooO01l0002Ool2@ch>Ool00gn0OomoP003Oh02@ch017`0Oh1oP7`014<n00Il04<n@ci3?WooO008
@ch00gooO01l0007Ool00g`0Oomoo`02@ciLOol007Eoo`93?P03Ooml07`000=oo`93?P9oo`93?P9o
o`=3?P03Oom3?T<n00Eoo`9l0003Ool007oo009oo`Moh0Qoo`Ao`1=oo`93?P=oo`9l011oo`9l0003
Oom3?T<n00AnP003OZ1oogoo029oo`03OZ13?Wk000=n`0Al0003Ooml07`0009oo`93?Paoo`QoP093
?P04O00007ooO007@ch2Ool3@ch00goo@ci3?P04@ch<Ool2@ciLOol007Eoo`93?P03Ooml07`0009o
o`=3?P9oo`93?P04Ooml04<n@ch2Ool2@ch9Ool01000Oomoogoo27oP1Goo0go000A3?Wo0Ol1o`15o
o`93?P=oo`9l00Moo`9l00Moo`9l00=3?PAnP0=nX29oo`03OZ13?Wk000=n`0Al0003Ooml07`0009o
o`93?P]oo`UoP093?P03O01oogoo009l00I3?P9oo`93?PAoo`E3?PYoo`93?Ueoo`00MGoo0d<n00Ao
og`0Oomoo`93?P=oo`93?P04Ooml04<n@ch2Ool2@ch6Ool00g`0Oomoo`02Ool200000gooOn1oh007
On02Ool4Ol000d<nOl1o`004Ol0>Ool3@ch;Ool2O007Ool2O003@ch017ooOX1nP7j01GjP87oo00An
X4<n@cinX0Il0003Ooml07`0009oo`93?PIoo`03Oh1oogoo00QoP003O00007oo00=3?P9oo`U3?P04
Oom3?T<nO003Ool2@ch01Goo@ci3?T<nO0001Goo0W`000Aood<n@ci3?Uaoo`00MGoo14<n0W`000Ao
od<n@ci3?P9oo`=3?P03O013?T<n009oo`93?PEoo`=l00Ioo`9l0003Oomoh7oP009oh003@cioh7o0
00=o`003O013?T<n00Mo`0ioo`93?P]oo`9l00Moo`9l00=3?P03Ooml07`000UnX1aoo`9nX093?P03
Ooml07`000Al00Eoo`93?PAoo`]oP003001l07`000=oo`93?P9oo`Q3?P03Oom3?T<n009l00=oo`93
?P03Oom3?T<n009l00Eoo`9l00=3?Ueoo`00MWoo0T<n0W`000Aood<n@ci3?PAoo`93?P03O013?T<n
009oo`93?PEoo`9l00Moo`9l00800003On13?T<n0093?PAo`093?PYo`0aoo`93?P9oo`9l00Moo`9l
00Moo`9l00=3?P04Ooml07`0Ool:OZ0JOol2OZ03@ch2O0000d<nO01oo`05Ool2@ch2Ool00gn0Oomo
P009Oh03Ool2O003Ool2@ch017`0Oom3?T<n0W`00d<n0Woo0d<n00=l07ooOol00d<n00Eood<n@ci3
?W`000Eoo`04O013?T<n@ciNOol007Ioo`93?P9l0003Oom3?T<n00Eoo`E3?P9oo`93?PEoo`9l00Mo
o`9l009oo`03O013?T<n00=3?P=o`093?P9l009oo`Qo`0Yoo`=3?P03Ooml07`000Moo`9l00Uoo`=3
?P03Ooml07`0009l009oo`YnX1Moo`9nX0M3?P=oo`9l0004Oom3?T<nOol:Oh000`00Oomoo`03Ool2
O003Ool2@ch017`0Oom3?T<n0W`01d<n0W`00Woo0T<n0Woo14<n1Goo00=l04<n@ch0Ggoo001fOol3
@ch00g`0Oom3?P06Ool4@ch3Ool2@ch5Ool2O007Ool2O002Ool6@ch2O0000goo@ci3?P02O003Ool7
Ol0:Ool4@ch2O007Ool2O009Ool3@ch01GooO013?T<nO0000goo37jP57oo00=nX7`0@ch01D<n00Ao
og`0O01oo`9l0004Oh13?T<n@ch7Oh000`00Oomoo`06Ool2O003Ool2@ch017`0@ci3?Woo0W`01T<n
00Eoog`0O01l07oo00=3?P=oo`=3?PAoo`03O013?Woo05moo`00Mgoo1D<n1Woo14<n0goo0T<n17oo
0g`01goo0W`00Woo1T<n0W`000<004<n@ch00W`01Goo2Go027oo0d<n00Al07ooOom3?Peoo`9l00A3
?P04O013?T<nO006Ool=OZ0@Ool00gjPO013?P06@ch2O0000gooO01l0003@ch5Oh02O00:Ool2O003
Ool5@ch00gooO01l0006@ch2Ool00g`0Oomoo`02@ch4Ool017`0@ci3?T<n0goo0T<nH7oo001hOol3
@ch8Ool2@ch4Ool3@ch4Ool00g`0Oomoo`06Ool2O002Ool8@ch01Goo@ci3?W`0Ool00`0000Aoog`0
O01oo`eo`0=oo`M3?Paoo`04O013?T<nOol2@ch017`0@ci3?T<n27oo3gjP17oo00InX7ooOomoognP
Ool3OZ000g`0@ci3?P05@ch2O0000d<nO01l0003@ch3Oh02Ool2O00@Ool5@ch2O002@ch2Ool00d<n
Oomoo`04Ool2@ch6Ool2@ch2Ool3@ciPOol007Qoo`=3?Pioo`=3?Q5oo`a3?PAoo`04001l07`00002
Ool7Ol02@ch5Ol09@ch00gooO01l0007Ool017`0@ci3?Woo1d<n0Woo0W`01Goo00=l07jPOZ0067jP
14<n00AoX4<n@cil00M3?PEoo`9l011oo`A3?P03Ooml07`00093?P9oo`93?PAoo`=3?PIoo`I3?V5o
o`00RWoo0T<n4Goo34<n00=l07ooOol00Woo0W`000Ioo`00000007o00003Ol03@ch6Ol000d<nOl1o
`002Oj04@ch2O007Ool00g`0@ci3?P07@ch3Ool2O005Ool2O002Ool00gjPOomnX00BOZ02O002@ch3
Oj0:@ch5Ool2O00:Ool2O004Ool3@ch4Ool3@ch017oo@ci3?Woo0W`000=ood<n@ch027oo14<nHWoo
002:Ool3@ch2Ool2O007Ool2O002Ool3@ch5Ool5@ch00g`0Oomoo`02Ool2O006Ool00g`0Ol13?P03
@ch5Ol03@ch00go0Oj1oX005@ch00g`0Oj1oX002Oj03Ool3@ch00goo@ci3?P04@ch3Ool2O004Ool8
Oj000g`0OZ1oX005OZ03@ch7OZ0014<nO013?T<n0gnP14<n00=l04<n@ch00T<n1Woo0W`02Woo0W`0
2Woo00=l04<n@ch00Woo0T<n00Aoog`0O01oo`93?PQoo`A3?V9oo`00RWoo0T<n0goo0W`01goo0W`0
0Woo0T<n1Woo1T<n17oo0W`01Woo0W`014<n00D007o0001o`7`000A3?PEoX0A3?PEoX0=3?P9oX0I3
?P=oX09l00EoX0=3?PUoX003OZ1oX7`000=3?P9nX0AoX003O013?W`00093?P=oo`A3?P04O013?T<n
@chCOol2O009Ool2O002@ch2Ool3@ch2O0000goo@ci3?P1^Ool008Yoo`93?P=oo`9l00Moo`9l009o
o`93?PIoo`M3?P=oo`9l00Ioo`9l00E3?PAoo`=3?P8000EoX0A3?P=oX0=3?P=oX0I3?P=oX09l00Eo
X09l0003@cioX7nP00MoX003001oX7`000=3?P9l00Eoo`04@cil04<n@ch4Ool3@ch00g`0@ci3?P02
@ch7Ool00g`0Oomoo`08Ool2O00:Ool3@ch2Ool4@ch017`0@ci3?T<nKWoo002:Ool2@ch3Ool2O007
Ool2O0000goo@ci3?P07Ool8@ch:Ool2O004@ch5Ool2@ch3Ool2O0000gooOj1oo`09@ch4Oj07@ch2
Oj02O005Oj02O002@ch017`0000000000W`017oo00Al04<n@ci3?P9l00Eoo`04@cil04<n@ch4Ool4
@ch017`0@ci3?W`01Woo0g`02Goo0W`02Woo0T<n1Goo1D<nKgoo002:Ool3@ch2Ool2O007Ool2O000
0goo@ci3?P08Ool2@ch00goo@ci3?P02@ch:Ool2O005@ch017ooO01l07oo0d<n0Woo0W`01Goo1T<n
1GnP1d<n0gnP1Woo0W`000=3?WooOol00goo0W`01Goo14<n1Goo00=l04<nO0000T<n1Goo0T<n0W`0
0T<n00=l07ooOol01Goo0W`02Goo0W`02Woo0T<n1Goo14<nL7oo002;Ool2@ch2Ool2O007Ool2O000
0goo@ci3?P0<Ool4@ch00gooO01l0006Ool2O005@ch017ooO01l07oo0d<n3Goo0W`01Woo0d<n00=l
04<n@ch01Woo0W`000Aoog`0O013?PEoo`9l00Eoo`=3?PIoo`03O013?W`00093?PUoo`=3?PMoo`9l
01Eoo`=3?WQoo`00Rgoo0T<n3Goo0T<n3goo0T<n00=oog`0O00027oo0T<n00Aood<n@cioo`9l0004
Oom3?T<n@ch=Ool2O006Ool2@ch00gooO013?P02@ch00gooO01l0002Ool2O00017ooO01l04<n0W`0
0goo0W`017oo00Al04<n@ci3?P9l00Aoo`E3?PQoo`04O013?T<n@ch7Ool2O00:Ool00g`0Oomoo`08
Ool2@ciiOol008]oo`=3?Paoo`93?Pmoo`93?P03Ooml07`000Moo`93?P9oo`=3?P9l0004Oom3?T<n
@ch2Ool2O00DOol2O002@ch00gooO01l0002Ool2O00017ooO01l04<n0W`00goo0W`017oo00=l04<n
@ch00T<n00=l07ooOol00Woo1D<n1goo0W`014<n1Woo0g`027oo0g`02Goo0T<nNGoo002<Ool3@ch2
O007Ool2O002@ch?Ool2@ch00gooO01l0006Ool00g`0@ci3?P02Ool2@ch017ooO01l07oo0d<n0Woo
0W`057oo0W`014<n00=l07ooOol00W`000Aood<n@ci3?P9l00=oo`9l00Aoo`03O013?T<n00=3?PAo
o`93?P03O013?T<n00Qoo`03O013?T<n00=3?PIoo`03O01oogoo00Qoo`9l00Qoo`=3?WUoo`00SGoo
0d<n00=l07ooOol01Goo0W`00T<n3goo0d<n0W`01Woo00=l04<n@ch00Woo0T<n17oo14<n00=oog`0
O0002Goo0W`02Goo0W`01D<n00Eood<nO01l07oo00=3?P9l00Uoo`03O013?T<n00=3?PAoo`E3?PQo
o`93?P03Oom3?T<n019oo`9l00Qoo`93?WYoo`00SWoo0d<n1goo0W`000=3?WooOol03goo0T<n0W`0
1Woo00=l04<n@ch00Woo0T<n0goo1D<n00=oog`0O0002Goo0W`037oo1d<n00El07ooO01l04<n009l
00Uoo`93?P03O013?T<n0093?P=oo`A3?P03O01oogoo00Ioo`93?P03Oom3?T<n019oo`9l00Qoo`93
?WYoo`00Sgoo0T<n1goo00=l04<n@ch04Goo0T<n27oo00=l04<n@ch00Woo0d<n0W`00T<n00Aood<n
@cioo`9l00Uoo`9l00ioo`M3?P9l0093?P04O01oogooOol2O004Ool2@ch017`0Oom3?T<n17oo14<n
00=l07ooOol01Woo0T<n00Al04<n@ci3?PEoo`9l00Yoo`=l00Ioo`=3?WYoo`00Sgoo0T<n1goo0d<n
4Goo0d<n00=l07ooOol017oo00=l04<nOol00goo0T<n0W`00T<n00Aood<n@cioo`9l00Uoo`9l00Uo
o`9l00Ioo`A3?P9l00=3?P=oo`9l00Aoo`93?P03O01ood<n0093?P9oo`E3?P03O01oogoo00Ioo`93
?P=oo`03@cioogoo00=oo`9l00]oo`03O01oogoo00Eoo`93?W]oo`00Sgoo0d<n1Goo0d<n4Woo0d<n
0W`01Goo0T<n17oo0T<n0W`00T<n00Aood<n@ci3?P]oo`9l00Uoo`9l00Ioo`E3?P04O013?T<n@ch3
Ool2O003Ool3@ch00g`0Oom3?P09@ch00g`0Oomoo`06Ool00d<nOomoo`02Ool2@ch4Ool2O00COol2
@cikOol008moo`A3?PAoo`93?QAoo`93?P03O01oogoo00Aoo`03@cioogoo00=oo`93?P04O013?T<n
@ch2Ool2@chFOol2O007Ool2O006@ch3Ool7@ch5Ool8@ch00g`0Oomoo`05Ool2@ch5Ool00d<nOomo
o`02Ool2O00BOol3@cikOol0095oo`=3?P9oo`=3?QAoo`=3?PEoo`93?PEoo`E3?P=oo`93?P9l01Ao
o`9l00Moo`03O013?T<n00i3?PIoo`A3?P03Oom3?T<n0093?PIoo`93?PIoo`93?P=oo`9l00Yoo`9l
00Ioo`93?Waoo`00TWoo1T<n5Goo0T<n00=l07ooOol00Woo0T<n1goo0d<n17oo0d<n00=l07ooOol0
1goo0W`02Goo0W`01goo0d<n0Woo24<n1Goo0W`00goo0d<n0goo0T<n1goo0T<n1goo00A3?WooOomo
o`9l00Yoo`9l00Eoo`=3?Waoo`00TWoo1D<n5Woo0T<n00=l07ooOol00Woo0T<n1goo0d<n17oo14<n
2Goo0W`02Goo0W`01goo0T<n17oo0T<n2Woo0W`02goo00=l07ooOol017oo0d<n1Woo0T<n3Woo0W`0
17oo0d<nOGoo002]Ool3@ch4Ool2@ch@Ool2@ch9Ool2O00BOol2@ch4Ool2@ch:Ool2O00:Ool3O004
Ool3@ch8Ool00d<nOomoo`02O006Ool014<nOomoogoo0W`00goo0d<nOWoo002^Ool3@ch3Ool2@ch@
Ool00g`0@cioo`08Ool2O00BOol2@ch4Ool3@ch9Ool2O00;Ool2O003Ool3@ch9Ool2@ch00gooO01l
0005Ool<@cioOol00:moo`=3?P04Oom3?T<n@ch@Ool00g`0@ci3?P08Ool2O009Ool2O007Ool00d<n
Oomoo`04Ool3@ch8Ool2O00;Ool2O002Ool3@ch:Ool3@ch2O003Ool=@cj0Ool00;1oo`E3?Q9oo`=3
?PMoo`9l00Ioo`03@ciood<n009l00Ioo`93?PMoo`93?PQoo`9l00Yoo`04@cil07`0Ool3@ch<Ool3
@ch00g`0Oom3?P04@cj:Ool00;5oo`=3?QAoo`=3?Peoo`E3?P03O01oogoo00Aoo`03@cioogoo00Io
o`93?Q9oo`Q3?Pioo`Q3?X]oo`00/Woo00=3?WooOol057oo0T<n37oo1d<n1Goo0T<n27oo0d<n47oo
24<n3goo1D<nSWoo003:Ool00d<nOomoo`04Ool2O003Ool3@ch3Ool4@ch00goo@ci3?P02@ch9Ool3
@ch6Ool2O006Ool4@cjWOol00<Yoo`93?PEoo`9l0003Oom3?T<n0093?PAoo`03O013?T<n00E3?P]o
o`93?PIoo`9l00=oo`E3?ZUoo`00bWoo0d<n17oo0W`014<n1Woo1T<n37oo14<n17oo0W`00Woo1D<n
ZWoo003;Ool3@ch3Ool017`0@ci3?T<n2goo00=3?WooOol03Goo14<n0goo0W`000=ood<n@ch00T<n
[7oo003<Ool3@ch2Ool3@chNOol:@cj^Ool00<eoo`I3?Qmoo`U3?Zmoo`00cGoo1D<nf7oo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[
Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00ogooZgoo003oOon[Ool00?mooj]oo`00
ogooZgoo003oOon[Ool00?mooj]oo`00W7oo1`000goo0`000Woo0`0017oo1@001Goo0`0000=oo`00
00000goo1@0017oo1P0017oo1`001Goo0`001Goo0`000Woo0`0027oo1`000goo1`00WGoo002MOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo0P001Goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol01Goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo09ioo`00WGoo00<007ooOol00Woo00<007ooOol00goo00@007ooOol000Aoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo09ioo`00WGoo00@007ooOol000Qoo`8000Eoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`D000Moo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo09io
o`00WGoo10001goo00@007ooOol000Aoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo09ioo`00WGoo00@007oo
Ool000Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`8000=oo`03001oogoo009o
o`03001oogoo00=oo`<000Eoo`03001oogoo009oo`8000Ioo`03001oogoo00Eoo`05001oogooOol0
0005Ool20003Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`2NOol009eoo`03001oogoo
009oo`04001oogooOol30002Ool30004Ool4000017oo001oogoo0P000goo0P0017oo0P000Woo0`00
0goo100000=oo`00Ool00goo0`0027oo0`001Goo0P0000Aoo`00000000eoo`03001oogoo00Moo`03
001oogoo09ioo`00WGoo00<007ooOol00Woo00<007ooOol0FWoo00<007ooOol01goo00<007ooOol0
WWoo002LOol7001IOol200000goo001oo`05Ool200000goo001oo`2OOol00=]oo`03001oogoo021o
o`8000Qoo`800:1oo`00fgoo00<007ooOol0c7oo0000\
\>"],
  ImageRangeCache->{{{99.875, 524.875}, {385.063, 78.125}} -> {-0.273187, \
0.29386, 0.00240043, 0.00240043}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(See[PhasePlot[exc[\([1, 10]\)]], 
      PlotLabel -> StyleForm[\ "\<Excursion 10\>", FontSize -> 16], 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .69072 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.249e-016 1.04872 -0.128064 1.04872 [
[.5 .70322 -59.375 0 ]
[.5 .70322 59.375 14.75 ]
[ 0 0 0 0 ]
[ 1 .69072 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .70322 -120.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.75 translate 1 -1 scale
63.000 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Excursion) show
158.625 15.000 moveto
(10) show
177.750 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .69072 L
0 .69072 L
closepath
clip
newpath
0 0 0 r
.004 w
.5243 .53765 Mdot
.52634 .53765 Mdot
.52224 .53765 Mdot
.52838 .53764 Mdot
.52018 .53763 Mdot
.53042 .53762 Mdot
.51811 .53762 Mdot
.53244 .53759 Mdot
.51603 .53759 Mdot
.53446 .53756 Mdot
.51394 .53755 Mdot
.53647 .53752 Mdot
.51185 .53751 Mdot
.53848 .53747 Mdot
.50975 .53746 Mdot
.54048 .53742 Mdot
.50764 .5374 Mdot
.54247 .53736 Mdot
.50552 .53733 Mdot
.54445 .53729 Mdot
.50339 .53726 Mdot
.54643 .53722 Mdot
.50125 .53718 Mdot
.5484 .53714 Mdot
.49911 .53708 Mdot
.55037 .53705 Mdot
.49696 .53698 Mdot
.55233 .53695 Mdot
.49479 .53687 Mdot
.55428 .53685 Mdot
.49262 .53675 Mdot
.55623 .53675 Mdot
.55817 .53663 Mdot
.49044 .53663 Mdot
.56011 .53651 Mdot
.48825 .53649 Mdot
.56204 .53639 Mdot
.48604 .53634 Mdot
.56396 .53625 Mdot
.48383 .53619 Mdot
.56588 .53611 Mdot
.48161 .53602 Mdot
.56779 .53597 Mdot
.47938 .53585 Mdot
.5697 .53582 Mdot
.47714 .53566 Mdot
.5716 .53566 Mdot
.5735 .5355 Mdot
.47488 .53546 Mdot
.57539 .53533 Mdot
.47262 .53526 Mdot
.57727 .53515 Mdot
.47034 .53504 Mdot
.57915 .53497 Mdot
.46805 .53482 Mdot
.58102 .53478 Mdot
.58289 .53459 Mdot
.46576 .53458 Mdot
.58476 .53439 Mdot
.46344 .53433 Mdot
.58662 .53418 Mdot
.46112 .53407 Mdot
.58847 .53397 Mdot
.45878 .5338 Mdot
.59032 .53375 Mdot
.59216 .53353 Mdot
.45643 .53351 Mdot
1 .848 0 r
.01 w
[ .05 .05 ] 0 setdash
.51161 .53337 m
.5138 .53337 L
s
.51161 .53337 Mdot
1 .849 0 r
.50966 .53336 m
.51161 .53337 L
s
1 .848 0 r
.5138 .53337 m
.51609 .53335 L
s
.5138 .53337 Mdot
1 .849 0 r
.50966 .53336 Mdot
.5078 .53333 m
.50966 .53336 L
s
1 .847 0 r
.51609 .53335 m
.51855 .53331 L
s
.51609 .53335 Mdot
1 .849 0 r
.5078 .53333 Mdot
1 .85 0 r
.5061 .53332 m
.5078 .53333 L
s
.5061 .53332 Mdot
1 .851 0 r
.50469 .53328 m
.5061 .53332 L
s
1 .846 0 r
.51855 .53331 m
.52106 .53327 L
s
.51855 .53331 Mdot
0 0 0 r
.004 w
.594 .5333 Mdot
1 .857 0 r
.01 w
.50134 .53329 m
.50103 .53327 L
s
.50134 .53329 Mdot
.50154 .53329 m
.50134 .53329 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.50151 .53754 m
.50154 .53329 L
s
1 .857 0 r
.01 w
.50154 .53329 Mdot
1 .858 0 r
[ .05 .05 ] 0 setdash
.50154 .53323 m
.50154 .53329 L
s
1 .851 0 r
.50469 .53328 Mdot
.50337 .53325 m
.50469 .53328 L
s
1 .856 0 r
.50103 .53327 m
.5007 .53324 L
s
.50103 .53327 Mdot
1 .846 0 r
.52106 .53327 m
.5238 .53309 L
s
.52106 .53327 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.50321 .55943 m
.50337 .53325 L
s
1 .851 0 r
.01 w
.50337 .53325 Mdot
1 .852 0 r
[ .05 .05 ] 0 setdash
.50228 .53321 m
.50337 .53325 L
s
1 .856 0 r
.5007 .53324 m
.50046 .5332 L
s
.5007 .53324 Mdot
1 .858 0 r
.50154 .53323 Mdot
1 .859 0 r
.50129 .53312 m
.50154 .53323 L
s
0 0 0 r
.004 w
.45407 .53322 Mdot
1 .852 0 r
.01 w
.50228 .53321 Mdot
1 .853 0 r
.50143 .53316 m
.50228 .53321 L
s
1 .855 0 r
.50046 .5332 m
.50036 .53316 L
s
.50046 .5332 Mdot
1 .853 0 r
.50143 .53316 Mdot
.50083 .53315 m
.50143 .53316 L
s
1 .854 0 r
.50036 .53316 m
.50048 .53315 L
s
.50036 .53316 Mdot
1 .853 0 r
.50083 .53315 Mdot
1 .854 0 r
.50048 .53315 m
.50083 .53315 L
s
.50048 .53315 Mdot
1 .859 0 r
.50129 .53312 Mdot
.50075 .53297 m
.50129 .53312 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5238 .58931 m
.5238 .53309 L
s
1 .845 0 r
.01 w
[ .05 .05 ] 0 setdash
.5238 .53309 m
.52654 .53297 L
s
.5238 .53309 Mdot
0 0 0 r
.004 w
.59583 .53306 Mdot
1 .859 0 r
.01 w
.50075 .53297 Mdot
1 .86 0 r
.4999 .53279 m
.50075 .53297 L
s
1 .845 0 r
.52654 .53297 m
.52915 .53287 L
s
.52654 .53297 Mdot
0 0 0 r
.004 w
.4517 .53291 Mdot
1 .844 0 r
.01 w
.52915 .53287 m
.532 .53271 L
s
.52915 .53287 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50036 .53379 m
.50044 .53798 L
s
.50043 .53737 m
.50036 .53379 L
s
0 0 0 r
.004 w
.59766 .53282 Mdot
1 .86 0 r
.01 w
.4999 .53279 Mdot
1 .861 0 r
[ .05 .05 ] 0 setdash
.49871 .53259 m
.4999 .53279 L
s
1 .843 0 r
.532 .53271 m
.53513 .53248 L
s
.532 .53271 Mdot
1 .861 0 r
.49871 .53259 Mdot
.49714 .5323 m
.49871 .53259 L
s
0 0 0 r
.004 w
.44931 .53259 Mdot
.59949 .53258 Mdot
1 .843 0 r
.01 w
.53513 .53248 m
.53793 .53235 L
s
.53513 .53248 Mdot
1 .842 0 r
.53793 .53235 m
.54116 .53209 L
s
.53793 .53235 Mdot
0 0 0 r
.004 w
.60131 .53232 Mdot
1 .861 0 r
.01 w
.49714 .5323 Mdot
1 .862 0 r
.49523 .53201 m
.49714 .5323 L
s
0 0 0 r
.004 w
.4469 .53225 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50152 .5353 m
.50151 .53754 L
s
.50124 .54005 m
.50152 .5353 L
s
1 .841 0 r
.01 w
[ .05 .05 ] 0 setdash
.54116 .53209 m
.54413 .5319 L
s
.54116 .53209 Mdot
0 0 0 r
.004 w
.60312 .53207 Mdot
1 .862 0 r
.01 w
.49523 .53201 Mdot
.49298 .53171 m
.49523 .53201 L
s
0 0 0 r
.004 w
.44448 .5319 Mdot
1 .841 0 r
.01 w
.54413 .5319 m
.54724 .53164 L
s
.54413 .5319 Mdot
0 0 0 r
.004 w
.60493 .5318 Mdot
1 .862 0 r
.01 w
.49298 .53171 Mdot
1 .863 0 r
.49052 .53135 m
.49298 .53171 L
s
1 .84 0 r
.54724 .53164 m
.55033 .53138 L
s
.54724 .53164 Mdot
0 0 0 r
.004 w
.44205 .53154 Mdot
.60674 .53153 Mdot
1 .84 0 r
.01 w
.55033 .53138 m
.55335 .53113 L
s
.55033 .53138 Mdot
1 .863 0 r
.49052 .53135 Mdot
1 .864 0 r
.48771 .531 m
.49052 .53135 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50151 .53754 m
.50129 .54055 L
s
0 0 0 r
.004 w
.60854 .53126 Mdot
.53 .8 .95 r
.006 w
.50066 .54 m
.50043 .53737 L
s
0 0 0 r
.004 w
.4396 .53117 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55388 .59515 m
.55335 .53113 L
s
1 .839 0 r
.01 w
[ .05 .05 ] 0 setdash
.55335 .53113 m
.55633 .53088 L
s
.55335 .53113 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.48704 .59535 m
.48771 .531 L
s
1 .864 0 r
.01 w
.48771 .531 Mdot
[ .05 .05 ] 0 setdash
.48476 .5306 m
.48771 .531 L
s
0 0 0 r
.004 w
.61033 .53098 Mdot
1 .838 0 r
.01 w
.55633 .53088 m
.55932 .53061 L
s
.55633 .53088 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50044 .53798 m
.50076 .5436 L
s
0 0 0 r
.004 w
.43714 .53078 Mdot
.61212 .53069 Mdot
1 .838 0 r
.01 w
[ .05 .05 ] 0 setdash
.55932 .53061 m
.56234 .53035 L
s
.55932 .53061 Mdot
1 .864 0 r
.48476 .5306 Mdot
1 .865 0 r
.4814 .53013 m
.48476 .5306 L
s
0 0 0 r
.004 w
.61391 .5304 Mdot
.43466 .53038 Mdot
1 .837 0 r
.01 w
.56234 .53035 m
.56526 .5301 L
s
.56234 .53035 Mdot
1 .865 0 r
.4814 .53013 Mdot
1 .866 0 r
.47814 .52972 m
.4814 .53013 L
s
0 0 0 r
.004 w
.61569 .53011 Mdot
1 .837 0 r
.01 w
.56526 .5301 m
.56824 .52983 L
s
.56526 .5301 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50098 .54133 m
.50066 .54 L
s
0 0 0 r
.004 w
.43216 .52996 Mdot
.53 .8 .95 r
.006 w
.50129 .54055 m
.50098 .54133 L
s
1 .836 0 r
.01 w
[ .05 .05 ] 0 setdash
.56824 .52983 m
.57132 .52953 L
s
.56824 .52983 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50066 .54681 m
.50124 .54005 L
s
0 0 0 r
.004 w
.61747 .5298 Mdot
1 .866 0 r
.01 w
.47814 .52972 Mdot
[ .05 .05 ] 0 setdash
.47461 .52921 m
.47814 .52972 L
s
1 .835 0 r
.57132 .52953 m
.5742 .52932 L
s
.57132 .52953 Mdot
0 0 0 r
.004 w
.42964 .52952 Mdot
.61924 .5295 Mdot
1 .835 0 r
.01 w
.5742 .52932 m
.57723 .52902 L
s
.5742 .52932 Mdot
1 .866 0 r
.47461 .52921 Mdot
1 .867 0 r
.47115 .52872 m
.47461 .52921 L
s
0 0 0 r
.004 w
.62101 .52918 Mdot
.42711 .52908 Mdot
1 .834 0 r
.01 w
.57723 .52902 m
.58031 .52876 L
s
.57723 .52902 Mdot
0 0 0 r
.004 w
.62278 .52886 Mdot
1 .833 0 r
.01 w
.58031 .52876 m
.58328 .52847 L
s
.58031 .52876 Mdot
1 .867 0 r
.47115 .52872 Mdot
.46763 .5283 m
.47115 .52872 L
s
0 0 0 r
.004 w
.42456 .52861 Mdot
.62454 .52854 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58439 .59391 m
.58328 .52847 L
s
1 .833 0 r
.01 w
[ .05 .05 ] 0 setdash
.58328 .52847 m
.58633 .52818 L
s
.58328 .52847 Mdot
1 .867 0 r
.46763 .5283 Mdot
1 .868 0 r
.46412 .52776 m
.46763 .5283 L
s
0 0 0 r
.004 w
.6263 .52821 Mdot
1 .832 0 r
.01 w
.58633 .52818 m
.58942 .52788 L
s
.58633 .52818 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50076 .5436 m
.50132 .54958 L
s
0 0 0 r
.004 w
.42199 .52813 Mdot
1 .832 0 r
.01 w
[ .05 .05 ] 0 setdash
.58942 .52788 m
.59251 .5276 L
s
.58942 .52788 Mdot
0 0 0 r
.004 w
.62805 .52787 Mdot
1 .868 0 r
.01 w
.46412 .52776 Mdot
1 .869 0 r
.46046 .52725 m
.46412 .52776 L
s
0 0 0 r
.004 w
.4194 .52763 Mdot
1 .831 0 r
.01 w
.59251 .5276 m
.5956 .52732 L
s
.59251 .5276 Mdot
0 0 0 r
.004 w
.6298 .52753 Mdot
1 .83 0 r
.01 w
.5956 .52732 m
.59859 .52704 L
s
.5956 .52732 Mdot
1 .869 0 r
.46046 .52725 Mdot
.4569 .52672 m
.46046 .52725 L
s
0 0 0 r
.004 w
.63154 .52719 Mdot
.41679 .52711 Mdot
1 .83 0 r
.01 w
.59859 .52704 m
.60156 .52671 L
s
.59859 .52704 Mdot
0 0 0 r
.004 w
.63328 .52683 Mdot
1 .869 0 r
.01 w
.4569 .52672 Mdot
1 .87 0 r
.45334 .52617 m
.4569 .52672 L
s
1 .829 0 r
.60156 .52671 m
.60452 .52639 L
s
.60156 .52671 Mdot
0 0 0 r
.004 w
.41416 .52657 Mdot
.63501 .52648 Mdot
1 .829 0 r
.01 w
.60452 .52639 m
.60751 .52609 L
s
.60452 .52639 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49975 .55453 m
.50066 .54681 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.4517 .60636 m
.45334 .52617 L
s
1 .87 0 r
.01 w
.45334 .52617 Mdot
[ .05 .05 ] 0 setdash
.44964 .5256 m
.45334 .52617 L
s
0 0 0 r
.004 w
.63675 .52611 Mdot
1 .828 0 r
.01 w
.60751 .52609 m
.61048 .52576 L
s
.60751 .52609 Mdot
0 0 0 r
.004 w
.41151 .52602 Mdot
1 .827 0 r
.01 w
.61048 .52576 m
.61322 .5255 L
s
.61048 .52576 Mdot
0 0 0 r
.004 w
.63847 .52575 Mdot
1 .87 0 r
.01 w
.44964 .5256 Mdot
1 .871 0 r
.44606 .52503 m
.44964 .5256 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61475 .58546 m
.61322 .5255 L
s
1 .827 0 r
.01 w
[ .05 .05 ] 0 setdash
.61322 .5255 m
.61595 .52523 L
s
.61322 .5255 Mdot
0 0 0 r
.004 w
.40884 .52544 Mdot
.6402 .52537 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50132 .54958 m
.50214 .55475 L
s
1 .826 0 r
.01 w
[ .05 .05 ] 0 setdash
.61595 .52523 m
.61875 .52495 L
s
.61595 .52523 Mdot
1 .871 0 r
.44606 .52503 Mdot
1 .872 0 r
.44249 .52449 m
.44606 .52503 L
s
0 0 0 r
.004 w
.64191 .52499 Mdot
1 .825 0 r
.01 w
.61875 .52495 m
.62145 .52468 L
s
.61875 .52495 Mdot
0 0 0 r
.004 w
.40614 .52485 Mdot
1 .825 0 r
.01 w
.62145 .52468 m
.62406 .52443 L
s
.62145 .52468 Mdot
0 0 0 r
.004 w
.64363 .52461 Mdot
1 .872 0 r
.01 w
.44249 .52449 Mdot
.439 .52388 m
.44249 .52449 L
s
1 .824 0 r
.62406 .52443 m
.62671 .52415 L
s
.62406 .52443 Mdot
0 0 0 r
.004 w
.40343 .52423 Mdot
.64534 .52422 Mdot
1 .824 0 r
.01 w
.62671 .52415 m
.62925 .52388 L
s
.62671 .52415 Mdot
1 .872 0 r
.439 .52388 Mdot
1 .873 0 r
.43544 .52337 m
.439 .52388 L
s
1 .823 0 r
.62925 .52388 m
.63182 .52359 L
s
.62925 .52388 Mdot
0 0 0 r
.004 w
.64705 .52382 Mdot
1 .822 0 r
.01 w
.63182 .52359 m
.6343 .52328 L
s
.63182 .52359 Mdot
0 0 0 r
.004 w
.40068 .52359 Mdot
.64875 .52342 Mdot
1 .873 0 r
.01 w
.43544 .52337 Mdot
1 .874 0 r
.43202 .5228 m
.43544 .52337 L
s
1 .822 0 r
.6343 .52328 m
.63681 .52292 L
s
.6343 .52328 Mdot
0 0 0 r
.004 w
.65045 .52302 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50214 .55475 m
.50321 .55943 L
s
0 0 0 r
.004 w
.39791 .52293 Mdot
1 .821 0 r
.01 w
[ .05 .05 ] 0 setdash
.63681 .52292 m
.63921 .52254 L
s
.63681 .52292 Mdot
1 .874 0 r
.43202 .5228 Mdot
.42872 .52232 m
.43202 .5228 L
s
0 0 0 r
.004 w
.65214 .52261 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.64092 .57458 m
.63921 .52254 L
s
1 .82 0 r
.01 w
[ .05 .05 ] 0 setdash
.63921 .52254 m
.64148 .52214 L
s
.63921 .52254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49849 .56292 m
.49975 .55453 L
s
1 .874 0 r
.01 w
.42872 .52232 Mdot
1 .875 0 r
[ .05 .05 ] 0 setdash
.42527 .52169 m
.42872 .52232 L
s
0 0 0 r
.004 w
.39511 .52225 Mdot
.65384 .52219 Mdot
1 .82 0 r
.01 w
.64148 .52214 m
.64371 .5217 L
s
.64148 .52214 Mdot
0 0 0 r
.004 w
.65552 .52177 Mdot
1 .819 0 r
.01 w
.64371 .5217 m
.64584 .52123 L
s
.64371 .5217 Mdot
1 .875 0 r
.42527 .52169 Mdot
.42197 .52107 m
.42527 .52169 L
s
0 0 0 r
.004 w
.39229 .52154 Mdot
.65721 .52134 Mdot
1 .819 0 r
.01 w
.64584 .52123 m
.64774 .52079 L
s
.64584 .52123 Mdot
1 .875 0 r
.42197 .52107 Mdot
1 .876 0 r
.41859 .52049 m
.42197 .52107 L
s
0 0 0 r
.004 w
.65889 .52091 Mdot
.38944 .5208 Mdot
1 .818 0 r
.01 w
.64774 .52079 m
.64953 .52032 L
s
.64774 .52079 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50321 .55943 m
.50451 .56371 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.41638 .5931 m
.41859 .52049 L
s
1 .876 0 r
.01 w
.41859 .52049 Mdot
1 .877 0 r
[ .05 .05 ] 0 setdash
.41545 .51986 m
.41859 .52049 L
s
0 0 0 r
.004 w
.66056 .52047 Mdot
1 .817 0 r
.01 w
.64953 .52032 m
.65106 .51988 L
s
.64953 .52032 Mdot
0 0 0 r
.004 w
.38655 .52004 Mdot
.66223 .52002 Mdot
1 .817 0 r
.01 w
.65106 .51988 m
.65243 .51945 L
s
.65106 .51988 Mdot
1 .877 0 r
.41545 .51986 Mdot
.41209 .51921 m
.41545 .51986 L
s
0 0 0 r
.004 w
.6639 .51958 Mdot
1 .816 0 r
.01 w
.65243 .51945 m
.6536 .51903 L
s
.65243 .51945 Mdot
0 0 0 r
.004 w
.38364 .51925 Mdot
1 .877 0 r
.01 w
.41209 .51921 Mdot
1 .878 0 r
.40883 .51853 m
.41209 .51921 L
s
0 0 0 r
.004 w
.66557 .51912 Mdot
1 .816 0 r
.01 w
.6536 .51903 m
.65454 .51867 L
s
.6536 .51903 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.50451 .56371 m
.50592 .56796 L
s
1 .815 0 r
.01 w
[ .05 .05 ] 0 setdash
.65454 .51867 m
.65531 .51836 L
s
.65454 .51867 Mdot
0 0 0 r
.004 w
.66723 .51866 Mdot
1 .878 0 r
.01 w
.40883 .51853 Mdot
.40567 .51792 m
.40883 .51853 L
s
0 0 0 r
.004 w
.38069 .51843 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65593 .53471 m
.65531 .51836 L
s
1 .814 0 r
.01 w
[ .05 .05 ] 0 setdash
.65531 .51836 m
.6559 .51811 L
s
.65531 .51836 Mdot
0 0 0 r
.004 w
.66888 .51819 Mdot
1 .795 0 r
.01 w
.6553 .51818 m
.6552 .51816 L
s
.6553 .51818 Mdot
1 .796 0 r
.65542 .51818 m
.6553 .51818 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65545 .51893 m
.65542 .51818 L
s
1 .796 0 r
.01 w
.65542 .51818 Mdot
[ .05 .05 ] 0 setdash
.65555 .51816 m
.65542 .51818 L
s
1 .795 0 r
.6552 .51816 m
.65512 .51813 L
s
.6552 .51816 Mdot
1 .796 0 r
.65555 .51816 Mdot
1 .797 0 r
.65567 .51812 m
.65555 .51816 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.49683 .57089 m
.49849 .56292 L
s
1 .794 0 r
.01 w
[ .05 .05 ] 0 setdash
.65512 .51813 m
.65505 .51809 L
s
.65512 .51813 Mdot
1 .797 0 r
.65567 .51812 Mdot
1 .798 0 r
.65577 .51807 m
.65567 .51812 L
s
1 .814 0 r
.6559 .51811 m
.6563 .51793 L
s
.6559 .51811 Mdot
1 .793 0 r
.65505 .51809 m
.65499 .51806 L
s
.65505 .51809 Mdot
1 .798 0 r
.65577 .51807 Mdot
.65589 .51801 m
.65577 .51807 L
s
1 .793 0 r
.65499 .51806 m
.65497 .51803 L
s
.65499 .51806 Mdot
1 .792 0 r
.65497 .51803 m
.655 .518 L
s
.65497 .51803 Mdot
1 .798 0 r
.65589 .51801 Mdot
1 .799 0 r
.65605 .51794 m
.65589 .51801 L
s
1 .791 0 r
.655 .518 m
.65514 .51793 L
s
.655 .518 Mdot
1 .799 0 r
.65605 .51794 Mdot
1 .8 0 r
.65626 .51787 m
.65605 .51794 L
s
1 .813 0 r
.6563 .51793 m
.65655 .51781 L
s
.6563 .51793 Mdot
1 .791 0 r
.65514 .51793 m
.65543 .51781 L
s
.65514 .51793 Mdot
1 .878 0 r
.40567 .51792 Mdot
1 .879 0 r
.40253 .51722 m
.40567 .51792 L
s
1 .8 0 r
.65626 .51787 Mdot
.65651 .51778 m
.65626 .51787 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65545 .51893 m
.65535 .51955 L
s
.65558 .51901 m
.65545 .51893 L
s
1 .79 0 r
.01 w
[ .05 .05 ] 0 setdash
.65543 .51781 m
.65591 .51764 L
s
.65543 .51781 Mdot
1 .812 0 r
.65655 .51781 m
.65669 .51774 L
s
.65655 .51781 Mdot
1 .8 0 r
.65651 .51778 Mdot
1 .801 0 r
.65676 .5177 m
.65651 .51778 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65571 .51933 m
.65558 .51901 L
s
1 .812 0 r
.01 w
[ .05 .05 ] 0 setdash
.65669 .51774 m
.65676 .5177 L
s
.65669 .51774 Mdot
0 0 0 r
.004 w
.67054 .51772 Mdot
1 .811 0 r
.01 w
.65676 .5177 m
.6568 .51768 L
s
.65676 .5177 Mdot
1 .801 0 r
.65676 .5177 Mdot
.65701 .51761 m
.65676 .5177 L
s
1 .811 0 r
.6568 .51768 m
.65682 .51766 L
s
.6568 .51768 Mdot
1 .81 0 r
.65682 .51766 m
.65685 .51764 L
s
.65682 .51766 Mdot
1 .809 0 r
.65685 .51764 m
.65689 .51762 L
s
.65685 .51764 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65645 .53172 m
.65591 .51764 L
s
1 .79 0 r
.01 w
[ .05 .05 ] 0 setdash
.65591 .51764 m
.65658 .5174 L
s
.65591 .51764 Mdot
1 .809 0 r
.65689 .51762 m
.65696 .51758 L
s
.65689 .51762 Mdot
1 .801 0 r
.65701 .51761 Mdot
1 .802 0 r
.65724 .51753 m
.65701 .51761 L
s
0 0 0 r
.004 w
.37771 .51759 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.65705 .51994 m
.65696 .51758 L
s
1 .808 0 r
.01 w
[ .05 .05 ] 0 setdash
.65696 .51758 m
.65706 .51754 L
s
.65696 .51758 Mdot
.65706 .51754 m
.65719 .5175 L
s
.65706 .51754 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65584 .51993 m
.65571 .51933 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65749 .52409 m
.65724 .51753 L
s
1 .802 0 r
.01 w
.65724 .51753 Mdot
1 .803 0 r
[ .05 .05 ] 0 setdash
.65744 .51745 m
.65724 .51753 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65535 .51955 m
.65528 .52023 L
s
1 .807 0 r
.01 w
[ .05 .05 ] 0 setdash
.65719 .5175 m
.65732 .51745 L
s
.65719 .5175 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65684 .51807 m
.65689 .5186 L
s
.65682 .51817 m
.65684 .51807 L
s
1 .803 0 r
.01 w
.65744 .51745 Mdot
[ .05 .05 ] 0 setdash
.65758 .5174 m
.65744 .51745 L
s
1 .806 0 r
.65732 .51745 m
.65745 .51741 L
s
.65732 .51745 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65679 .51831 m
.65682 .51817 L
s
1 .806 0 r
.01 w
[ .05 .05 ] 0 setdash
.65745 .51741 m
.65756 .51738 L
s
.65745 .51741 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65675 .51925 m
.65679 .51831 L
s
1 .789 0 r
.01 w
[ .05 .05 ] 0 setdash
.65658 .5174 m
.65751 .51709 L
s
.65658 .5174 Mdot
1 .803 0 r
.65758 .5174 Mdot
1 .804 0 r
.65764 .51737 m
.65758 .5174 L
s
1 .805 0 r
.65756 .51738 m
.65763 .51736 L
s
.65756 .51738 Mdot
1 .804 0 r
.65764 .51737 Mdot
.65763 .51736 m
.65764 .51737 L
s
.65763 .51736 Mdot
0 0 0 r
.004 w
.67219 .51725 Mdot
1 .879 0 r
.01 w
.40253 .51722 Mdot
1 .88 0 r
.39949 .51656 m
.40253 .51722 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65599 .52081 m
.65584 .51993 L
s
.65689 .5186 m
.65696 .51946 L
s
.65528 .52023 m
.65522 .52079 L
s
1 .788 0 r
.01 w
[ .05 .05 ] 0 setdash
.65751 .51709 m
.65867 .51673 L
s
.65751 .51709 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65504 .52011 m
.65509 .52046 L
s
.6551 .52084 m
.65504 .52011 L
s
.6567 .52179 m
.65675 .51925 L
s
.65768 .5182 m
.65769 .52031 L
s
.65769 .51881 m
.65768 .5182 L
s
.65522 .52079 m
.65517 .52114 L
s
.50592 .56796 m
.50761 .57181 L
s
.65509 .52046 m
.65533 .52311 L
s
0 0 0 r
.004 w
.67383 .51676 Mdot
1 .788 0 r
.01 w
[ .05 .05 ] 0 setdash
.65867 .51673 m
.66013 .51628 L
s
.65867 .51673 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65696 .51946 m
.65705 .51994 L
s
.65517 .52114 m
.6551 .52084 L
s
0 0 0 r
.004 w
.37469 .5167 Mdot
.53 .8 .95 r
.006 w
.65768 .52058 m
.65769 .51881 L
s
.65622 .52242 m
.65599 .52081 L
s
1 .88 0 r
.01 w
.39949 .51656 Mdot
[ .05 .05 ] 0 setdash
.39654 .51597 m
.39949 .51656 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65705 .51994 m
.65719 .5209 L
s
1 .787 0 r
.01 w
[ .05 .05 ] 0 setdash
.66013 .51628 m
.66183 .51577 L
s
.66013 .51628 Mdot
0 0 0 r
.004 w
.67547 .51628 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65769 .52031 m
.65763 .5224 L
s
1 .88 0 r
.01 w
.39654 .51597 Mdot
1 .881 0 r
[ .05 .05 ] 0 setdash
.39363 .51536 m
.39654 .51597 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65719 .5209 m
.65735 .52168 L
s
.65659 .52543 m
.6567 .52179 L
s
.65761 .5215 m
.65768 .52058 L
s
0 0 0 r
.004 w
.37163 .51579 Mdot
.67711 .51578 Mdot
.53 .8 .95 r
.006 w
.65649 .5239 m
.65622 .52242 L
s
1 .787 0 r
.01 w
[ .05 .05 ] 0 setdash
.66183 .51577 m
.66373 .51517 L
s
.66183 .51577 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65735 .52168 m
.6575 .52202 L
s
.6575 .52202 m
.65761 .5215 L
s
.65533 .52311 m
.65578 .52699 L
s
1 .881 0 r
.01 w
.39363 .51536 Mdot
1 .882 0 r
[ .05 .05 ] 0 setdash
.39098 .51478 m
.39363 .51536 L
s
0 0 0 r
.004 w
.67875 .51529 Mdot
1 .786 0 r
.01 w
.66373 .51517 m
.66593 .51446 L
s
.66373 .51517 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65763 .5224 m
.65749 .52409 L
s
.50761 .57181 m
.50948 .57535 L
s
.65679 .52519 m
.65649 .5239 L
s
0 0 0 r
.004 w
.36853 .51484 Mdot
.68038 .51478 Mdot
1 .882 0 r
.01 w
.39098 .51478 Mdot
[ .05 .05 ] 0 setdash
.3883 .5143 m
.39098 .51478 L
s
1 .785 0 r
.66593 .51446 m
.66832 .51365 L
s
.66593 .51446 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65749 .52409 m
.6573 .52519 L
s
.65635 .52993 m
.65659 .52543 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38613 .56966 m
.3883 .5143 L
s
1 .882 0 r
.01 w
.3883 .5143 Mdot
1 .883 0 r
[ .05 .05 ] 0 setdash
.38579 .51388 m
.3883 .5143 L
s
0 0 0 r
.004 w
.68201 .51427 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65706 .52545 m
.65679 .52519 L
s
.6573 .52519 m
.65706 .52545 L
s
.49484 .57836 m
.49683 .57089 L
s
1 .883 0 r
.01 w
.38579 .51388 Mdot
[ .05 .05 ] 0 setdash
.38363 .51348 m
.38579 .51388 L
s
0 0 0 r
.004 w
.36538 .51385 Mdot
.68363 .51376 Mdot
1 .785 0 r
.01 w
.66832 .51365 m
.67088 .51271 L
s
.66832 .51365 Mdot
1 .883 0 r
.38363 .51348 Mdot
1 .884 0 r
.38166 .51317 m
.38363 .51348 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65578 .52699 m
.65645 .53172 L
s
.50948 .57535 m
.51145 .57794 L
s
0 0 0 r
.004 w
.68525 .51324 Mdot
1 .884 0 r
.01 w
.38166 .51317 Mdot
1 .885 0 r
[ .05 .05 ] 0 setdash
.37992 .51289 m
.38166 .51317 L
s
.37992 .51289 Mdot
.37836 .51269 m
.37992 .51289 L
s
0 0 0 r
.004 w
.3622 .51282 Mdot
1 .784 0 r
.01 w
.67088 .51271 m
.67356 .51168 L
s
.67088 .51271 Mdot
0 0 0 r
.004 w
.68687 .51271 Mdot
1 .885 0 r
.01 w
.37836 .51269 Mdot
1 .886 0 r
.37702 .5125 m
.37836 .51269 L
s
.37702 .5125 Mdot
.37579 .51232 m
.37702 .5125 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65593 .53471 m
.65635 .52993 L
s
1 .886 0 r
.01 w
.37579 .51232 Mdot
1 .887 0 r
[ .05 .05 ] 0 setdash
.37476 .51217 m
.37579 .51232 L
s
1 .902 0 r
.37232 .51228 m
.37231 .51227 L
s
.37232 .51228 Mdot
1 .903 0 r
.37232 .51228 m
.37232 .51228 L
s
.37232 .51228 Mdot
.3723 .51226 m
.37232 .51228 L
s
1 .901 0 r
.37231 .51227 m
.37228 .51224 L
s
.37231 .51227 Mdot
1 .903 0 r
.3723 .51226 Mdot
1 .904 0 r
.37226 .51222 m
.3723 .51226 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.3722 .51395 m
.37228 .51224 L
s
1 .901 0 r
.01 w
[ .05 .05 ] 0 setdash
.37228 .51224 m
.37224 .5122 L
s
.37228 .51224 Mdot
1 .904 0 r
.37226 .51222 Mdot
.3722 .51217 m
.37226 .51222 L
s
1 .9 0 r
.37224 .5122 m
.3722 .51216 L
s
.37224 .5122 Mdot
0 0 0 r
.004 w
.68848 .51218 Mdot
1 .887 0 r
.01 w
.37476 .51217 Mdot
1 .888 0 r
.37389 .51204 m
.37476 .51217 L
s
1 .904 0 r
.3722 .51217 Mdot
1 .905 0 r
.37212 .51209 m
.3722 .51217 L
s
1 .899 0 r
.3722 .51216 m
.37214 .5121 L
s
.3722 .51216 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3723 .51254 m
.37228 .51309 L
s
.37228 .51265 m
.3723 .51254 L
s
.51145 .57794 m
.51366 .58067 L
s
1 .899 0 r
.01 w
[ .05 .05 ] 0 setdash
.37214 .5121 m
.37207 .51204 L
s
.37214 .5121 Mdot
1 .905 0 r
.37212 .51209 Mdot
1 .906 0 r
.37202 .51199 m
.37212 .51209 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3722 .51352 m
.37228 .51265 L
s
1 .898 0 r
.01 w
[ .05 .05 ] 0 setdash
.37207 .51204 m
.37201 .51198 L
s
.37207 .51204 Mdot
1 .888 0 r
.37389 .51204 Mdot
.37318 .51192 m
.37389 .51204 L
s
1 .906 0 r
.37202 .51199 Mdot
.3719 .51187 m
.37202 .51199 L
s
1 .898 0 r
.37201 .51198 m
.37193 .51191 L
s
.37201 .51198 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37256 .52605 m
.37318 .51192 L
s
1 .888 0 r
.01 w
.37318 .51192 Mdot
1 .889 0 r
[ .05 .05 ] 0 setdash
.37261 .51182 m
.37318 .51192 L
s
1 .897 0 r
.37193 .51191 m
.37185 .51184 L
s
.37193 .51191 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37228 .51309 m
.37225 .51354 L
s
1 .906 0 r
.01 w
.3719 .51187 Mdot
1 .907 0 r
[ .05 .05 ] 0 setdash
.37175 .51173 m
.3719 .51187 L
s
1 .896 0 r
.37185 .51184 m
.37176 .51177 L
s
.37185 .51184 Mdot
1 .889 0 r
.37261 .51182 Mdot
1 .89 0 r
.37217 .51173 m
.37261 .51182 L
s
1 .896 0 r
.37176 .51177 m
.37167 .51172 L
s
.37176 .51177 Mdot
0 0 0 r
.004 w
.35896 .51175 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37146 .51843 m
.37175 .51173 L
s
1 .907 0 r
.01 w
.37175 .51173 Mdot
[ .05 .05 ] 0 setdash
.3716 .51158 m
.37175 .51173 L
s
1 .89 0 r
.37217 .51173 Mdot
.37183 .51166 m
.37217 .51173 L
s
1 .895 0 r
.37167 .51172 m
.37157 .51166 L
s
.37167 .51172 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67662 .58278 m
.67356 .51168 L
s
1 .783 0 r
.01 w
[ .05 .05 ] 0 setdash
.67356 .51168 m
.67638 .51052 L
s
.67356 .51168 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37143 .51495 m
.37157 .51166 L
s
1 .895 0 r
.01 w
[ .05 .05 ] 0 setdash
.37157 .51166 m
.37148 .51163 L
s
.37157 .51166 Mdot
1 .89 0 r
.37183 .51166 Mdot
1 .891 0 r
.37158 .5116 m
.37183 .51166 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37225 .51354 m
.3722 .51395 L
s
0 0 0 r
.004 w
.69009 .51164 Mdot
1 .894 0 r
.01 w
[ .05 .05 ] 0 setdash
.37148 .51163 m
.37141 .5116 L
s
.37148 .51163 Mdot
1 .891 0 r
.37158 .5116 Mdot
.37143 .51156 m
.37158 .5116 L
s
1 .893 0 r
.37141 .5116 m
.37136 .51157 L
s
.37141 .5116 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37209 .51478 m
.3722 .51352 L
s
1 .907 0 r
.01 w
.3716 .51158 Mdot
1 .908 0 r
[ .05 .05 ] 0 setdash
.37147 .51144 m
.3716 .51158 L
s
1 .893 0 r
.37136 .51157 m
.37136 .51156 L
s
.37136 .51157 Mdot
1 .891 0 r
.37143 .51156 Mdot
1 .892 0 r
.37136 .51156 m
.37143 .51156 L
s
.37136 .51156 Mdot
1 .908 0 r
.37147 .51144 Mdot
1 .909 0 r
.37138 .51133 m
.37147 .51144 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3722 .51395 m
.37214 .51456 L
s
.37201 .51347 m
.37194 .51354 L
s
.37206 .5138 m
.37201 .51347 L
s
1 .909 0 r
.01 w
.37138 .51133 Mdot
[ .05 .05 ] 0 setdash
.37131 .51124 m
.37138 .51133 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37133 .51211 m
.37133 .5124 L
s
.37131 .51392 m
.37133 .51211 L
s
.37209 .51453 m
.37206 .5138 L
s
1 .909 0 r
.01 w
.37131 .51124 Mdot
1 .91 0 r
[ .05 .05 ] 0 setdash
.37126 .51115 m
.37131 .51124 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37194 .51354 m
.37184 .514 L
s
1 .91 0 r
.01 w
.37126 .51115 Mdot
1 .911 0 r
[ .05 .05 ] 0 setdash
.37121 .51108 m
.37126 .51115 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37133 .5124 m
.37131 .51434 L
s
0 0 0 r
.004 w
.69169 .5111 Mdot
1 .911 0 r
.01 w
.37121 .51108 Mdot
[ .05 .05 ] 0 setdash
.37113 .51099 m
.37121 .51108 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37214 .51456 m
.37209 .51453 L
s
1 .911 0 r
.01 w
.37113 .51099 Mdot
1 .912 0 r
[ .05 .05 ] 0 setdash
.371 .51088 m
.37113 .51099 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37194 .51627 m
.37209 .51478 L
s
.37184 .514 m
.37173 .51456 L
s
1 .912 0 r
.01 w
.371 .51088 Mdot
[ .05 .05 ] 0 setdash
.37081 .51074 m
.371 .51088 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.51366 .58067 m
.51597 .58275 L
s
.65645 .53172 m
.65734 .53735 L
s
1 .912 0 r
.01 w
.37081 .51074 Mdot
1 .913 0 r
[ .05 .05 ] 0 setdash
.37053 .51055 m
.37081 .51074 L
s
0 0 0 r
.004 w
.35567 .51063 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.37013 .5195 m
.37053 .51055 L
s
1 .913 0 r
.01 w
.37053 .51055 Mdot
1 .914 0 r
[ .05 .05 ] 0 setdash
.37015 .51032 m
.37053 .51055 L
s
0 0 0 r
.004 w
.6933 .51055 Mdot
1 .783 0 r
.01 w
.67638 .51052 m
.67929 .50929 L
s
.67638 .51052 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37173 .51456 m
.3716 .51543 L
s
.37136 .51442 m
.37131 .51392 L
s
.65534 .53995 m
.65593 .53471 L
s
1 .914 0 r
.01 w
.37015 .51032 Mdot
[ .05 .05 ] 0 setdash
.36964 .51002 m
.37015 .51032 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37143 .51495 m
.37136 .51442 L
s
.37131 .51434 m
.37138 .51632 L
s
.3715 .51556 m
.37143 .51495 L
s
.37177 .51764 m
.37194 .51627 L
s
1 .914 0 r
.01 w
.36964 .51002 Mdot
1 .915 0 r
[ .05 .05 ] 0 setdash
.369 .50964 m
.36964 .51002 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3716 .51543 m
.3715 .51556 L
s
0 0 0 r
.004 w
.69489 .50999 Mdot
.53 .8 .95 r
.006 w
.3711 .51348 m
.37114 .51386 L
s
.371 .51381 m
.3711 .51348 L
s
.4925 .58483 m
.49484 .57836 L
s
.37114 .51386 m
.37116 .51471 L
s
.51597 .58275 m
.51846 .58457 L
s
1 .915 0 r
.01 w
.369 .50964 Mdot
[ .05 .05 ] 0 setdash
.36822 .50919 m
.369 .50964 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37082 .51498 m
.371 .51381 L
s
.37116 .51471 m
.37118 .51586 L
s
0 0 0 r
.004 w
.35233 .50947 Mdot
.69649 .50943 Mdot
.53 .8 .95 r
.006 w
.37138 .51632 m
.37151 .5187 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.67929 .50929 m
.68214 .50805 L
s
.67929 .50929 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37162 .51817 m
.37177 .51764 L
s
1 .915 0 r
.01 w
.36822 .50919 Mdot
1 .916 0 r
[ .05 .05 ] 0 setdash
.36726 .50861 m
.36822 .50919 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37118 .51586 m
.3712 .51749 L
s
.37053 .51696 m
.37082 .51498 L
s
.51846 .58457 m
.52101 .58689 L
s
0 0 0 r
.004 w
.69808 .50887 Mdot
.53 .8 .95 r
.006 w
.37146 .51843 m
.37162 .51817 L
s
1 .916 0 r
.01 w
.36726 .50861 Mdot
1 .917 0 r
[ .05 .05 ] 0 setdash
.36614 .50795 m
.36726 .50861 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3712 .51749 m
.3713 .51845 L
s
.3713 .51845 m
.37146 .51843 L
s
.65457 .5451 m
.65534 .53995 L
s
0 0 0 r
.004 w
.69967 .50829 Mdot
.34893 .50825 Mdot
.53 .8 .95 r
.006 w
.37151 .5187 m
.37177 .52082 L
s
1 .782 0 r
.01 w
[ .05 .05 ] 0 setdash
.68214 .50805 m
.68523 .50673 L
s
.68214 .50805 Mdot
1 .917 0 r
.36614 .50795 Mdot
.36483 .50716 m
.36614 .50795 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65734 .53735 m
.65851 .543 L
s
0 0 0 r
.004 w
.70125 .50772 Mdot
.53 .8 .95 r
.006 w
.52101 .58689 m
.5238 .58931 L
s
.37013 .5195 m
.37053 .51696 L
s
.37177 .52082 m
.37211 .52317 L
s
1 .917 0 r
.01 w
.36483 .50716 Mdot
1 .918 0 r
[ .05 .05 ] 0 setdash
.36345 .50633 m
.36483 .50716 L
s
0 0 0 r
.004 w
.70283 .50713 Mdot
.34546 .50697 Mdot
1 .781 0 r
.01 w
.68523 .50673 m
.68811 .50546 L
s
.68523 .50673 Mdot
0 0 0 r
.004 w
.70441 .50655 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65355 .5498 m
.65457 .5451 L
s
.48994 .59111 m
.4925 .58483 L
s
1 .918 0 r
.01 w
.36345 .50633 Mdot
1 .919 0 r
[ .05 .05 ] 0 setdash
.36195 .50543 m
.36345 .50633 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37211 .52317 m
.37256 .52605 L
s
.5238 .58931 m
.52658 .59218 L
s
.36961 .52252 m
.37013 .5195 L
s
0 0 0 r
.004 w
.70598 .50595 Mdot
.34192 .50564 Mdot
1 .78 0 r
.01 w
[ .05 .05 ] 0 setdash
.68811 .50546 m
.69132 .50409 L
s
.68811 .50546 Mdot
1 .919 0 r
.36195 .50543 Mdot
.36046 .50456 m
.36195 .50543 L
s
0 0 0 r
.004 w
.70755 .50535 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.37256 .52605 m
.37315 .52915 L
s
.65233 .55473 m
.65355 .5498 L
s
.52658 .59218 m
.52923 .59395 L
s
0 0 0 r
.004 w
.70912 .50474 Mdot
.53 .8 .95 r
.006 w
.65851 .543 m
.65989 .54831 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.35828 .55056 m
.36046 .50456 L
s
1 .919 0 r
.01 w
.36046 .50456 Mdot
1 .92 0 r
[ .05 .05 ] 0 setdash
.35907 .50377 m
.36046 .50456 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36894 .52584 m
.36961 .52252 L
s
0 0 0 r
.004 w
.33831 .50424 Mdot
.71068 .50413 Mdot
1 .78 0 r
.01 w
[ .05 .05 ] 0 setdash
.69132 .50409 m
.6943 .5028 L
s
.69132 .50409 Mdot
1 .92 0 r
.35907 .50377 Mdot
.35761 .50291 m
.35907 .50377 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.52923 .59395 m
.53214 .59578 L
s
.37315 .52915 m
.37389 .53241 L
s
0 0 0 r
.004 w
.71224 .50351 Mdot
.53 .8 .95 r
.006 w
.65094 .55961 m
.65233 .55473 L
s
1 .92 0 r
.01 w
.35761 .50291 Mdot
1 .921 0 r
[ .05 .05 ] 0 setdash
.35641 .50226 m
.35761 .50291 L
s
0 0 0 r
.004 w
.71379 .50289 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.48704 .59535 m
.48994 .59111 L
s
1 .779 0 r
.01 w
[ .05 .05 ] 0 setdash
.6943 .5028 m
.69751 .50143 L
s
.6943 .5028 Mdot
0 0 0 r
.004 w
.33462 .50277 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53214 .59578 m
.53533 .59774 L
s
.37389 .53241 m
.37477 .53619 L
s
.36809 .52997 m
.36894 .52584 L
s
0 0 0 r
.004 w
.71535 .50226 Mdot
1 .921 0 r
.01 w
.35641 .50226 Mdot
1 .922 0 r
[ .05 .05 ] 0 setdash
.35522 .50156 m
.35641 .50226 L
s
0 0 0 r
.004 w
.71689 .50162 Mdot
1 .922 0 r
.01 w
.35522 .50156 Mdot
.35419 .50097 m
.35522 .50156 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65989 .54831 m
.66158 .55338 L
s
1 .779 0 r
.01 w
[ .05 .05 ] 0 setdash
.69751 .50143 m
.70049 .50016 L
s
.69751 .50143 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64925 .56345 m
.65094 .55961 L
s
.53533 .59774 m
.53818 .59844 L
s
0 0 0 r
.004 w
.33084 .50121 Mdot
.71844 .50098 Mdot
1 .922 0 r
.01 w
.35419 .50097 Mdot
1 .923 0 r
[ .05 .05 ] 0 setdash
.35335 .5005 m
.35419 .50097 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.53818 .59844 m
.54148 .59826 L
s
.37477 .53619 m
.37587 .53965 L
s
.55388 .59515 m
.55691 .59488 L
s
.55081 .59652 m
.55388 .59515 L
s
.54148 .59826 m
.54451 .59815 L
s
1 .923 0 r
.01 w
.35335 .5005 Mdot
1 .924 0 r
[ .05 .05 ] 0 setdash
.35266 .50012 m
.35335 .5005 L
s
0 0 0 r
.004 w
.71998 .50033 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55691 .59488 m
.55996 .59442 L
s
.54451 .59815 m
.54767 .59735 L
s
.54767 .59735 m
.55081 .59652 L
s
.48398 .59895 m
.48704 .59535 L
s
.64742 .56663 m
.64925 .56345 L
s
1 .778 0 r
.01 w
[ .05 .05 ] 0 setdash
.70049 .50016 m
.70375 .49881 L
s
.70049 .50016 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56303 .59359 m
.566 .59363 L
s
.55996 .59442 m
.56303 .59359 L
s
1 .924 0 r
.01 w
.35266 .50012 Mdot
[ .05 .05 ] 0 setdash
.35215 .49986 m
.35266 .50012 L
s
1 .93 0 r
.35208 .50005 m
.35202 .50005 L
s
.35208 .50005 Mdot
.35208 .5 m
.35208 .50005 L
s
1 .929 0 r
.35202 .50005 m
.35191 .5 L
s
.35202 .50005 Mdot
1 .93 0 r
.35208 .5 Mdot
1 .931 0 r
.35199 .49987 m
.35208 .5 L
s
1 .928 0 r
.35191 .5 m
.35177 .4999 L
s
.35191 .5 Mdot
.35177 .4999 m
.35164 .49978 L
s
.35177 .4999 Mdot
1 .931 0 r
.35199 .49987 Mdot
1 .932 0 r
.35181 .49968 m
.35199 .49987 L
s
1 .924 0 r
.35215 .49986 Mdot
1 .925 0 r
.3518 .4997 m
.35215 .49986 L
s
1 .927 0 r
.35164 .49978 m
.35154 .49968 L
s
.35164 .49978 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36708 .5346 m
.36809 .52997 L
s
.566 .59363 m
.56904 .5935 L
s
1 .925 0 r
.01 w
.3518 .4997 Mdot
[ .05 .05 ] 0 setdash
.35159 .49962 m
.3518 .4997 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.35142 .50735 m
.35181 .49968 L
s
1 .932 0 r
.01 w
.35181 .49968 Mdot
[ .05 .05 ] 0 setdash
.35152 .49942 m
.35181 .49968 L
s
0 0 0 r
.004 w
.72152 .49968 Mdot
1 .927 0 r
.01 w
.35154 .49968 m
.35152 .49962 L
s
.35154 .49968 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.3515 .50149 m
.35159 .49962 L
s
1 .925 0 r
.01 w
.35159 .49962 Mdot
1 .926 0 r
[ .05 .05 ] 0 setdash
.35152 .49962 m
.35159 .49962 L
s
.35152 .49962 Mdot
0 0 0 r
.004 w
.32696 .49957 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35203 .50105 m
.35191 .50221 L
s
.352 .50158 m
.35203 .50105 L
s
1 .932 0 r
.01 w
.35152 .49942 Mdot
1 .933 0 r
[ .05 .05 ] 0 setdash
.35113 .49909 m
.35152 .49942 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.56904 .5935 m
.57218 .59365 L
s
.64536 .56979 m
.64742 .56663 L
s
.37587 .53965 m
.37704 .54381 L
s
.35178 .5042 m
.352 .50158 L
s
1 .933 0 r
.01 w
.35113 .49909 Mdot
[ .05 .05 ] 0 setdash
.35062 .49871 m
.35113 .49909 L
s
0 0 0 r
.004 w
.72305 .49902 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35191 .50221 m
.35176 .503 L
s
.35144 .50112 m
.3515 .50149 L
s
.3514 .50239 m
.35144 .50112 L
s
.57218 .59365 m
.57511 .59326 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.70788 .57841 m
.70375 .49881 L
s
1 .777 0 r
.01 w
[ .05 .05 ] 0 setdash
.70375 .49881 m
.70695 .49751 L
s
.70375 .49881 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.57511 .59326 m
.5782 .5934 L
s
1 .933 0 r
.01 w
.35062 .49871 Mdot
1 .934 0 r
[ .05 .05 ] 0 setdash
.35002 .49829 m
.35062 .49871 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3515 .50149 m
.35154 .50481 L
s
.64319 .57268 m
.64536 .56979 L
s
.35176 .503 m
.3516 .5034 L
s
0 0 0 r
.004 w
.72458 .49835 Mdot
.53 .8 .95 r
.006 w
.35146 .50323 m
.3514 .50239 L
s
.66158 .55338 m
.66352 .55851 L
s
1 .934 0 r
.01 w
.35002 .49829 Mdot
1 .935 0 r
[ .05 .05 ] 0 setdash
.34929 .4978 m
.35002 .49829 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5782 .5934 m
.58136 .59428 L
s
.3516 .5034 m
.35146 .50323 L
s
.48052 .60155 m
.48398 .59895 L
s
0 0 0 r
.004 w
.32297 .49784 Mdot
.53 .8 .95 r
.006 w
.64092 .57458 m
.64319 .57268 L
s
1 .935 0 r
.01 w
.34929 .4978 Mdot
[ .05 .05 ] 0 setdash
.34848 .49727 m
.34929 .4978 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62832 .57908 m
.63089 .57827 L
s
.62567 .58046 m
.62832 .57908 L
s
.35142 .50735 m
.35178 .5042 L
s
.63089 .57827 m
.6335 .57783 L
s
0 0 0 r
.004 w
.72611 .49768 Mdot
.53 .8 .95 r
.006 w
.63851 .5755 m
.64092 .57458 L
s
.63599 .57689 m
.63851 .5755 L
s
.37704 .54381 m
.37846 .54805 L
s
.6335 .57783 m
.63599 .57689 L
s
.62304 .58169 m
.62567 .58046 L
s
1 .777 0 r
.01 w
[ .05 .05 ] 0 setdash
.70695 .49751 m
.71016 .49622 L
s
.70695 .49751 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58136 .59428 m
.58439 .59391 L
s
.6203 .58232 m
.62304 .58169 L
s
.61749 .58373 m
.6203 .58232 L
s
1 .935 0 r
.01 w
.34848 .49727 Mdot
1 .936 0 r
[ .05 .05 ] 0 setdash
.34761 .49673 m
.34848 .49727 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35154 .50481 m
.35167 .50949 L
s
.58439 .59391 m
.5875 .5937 L
s
.61475 .58546 m
.61749 .58373 L
s
0 0 0 r
.004 w
.72763 .497 Mdot
.53 .8 .95 r
.006 w
.36588 .539 m
.36708 .5346 L
s
.5875 .5937 m
.59065 .5938 L
s
1 .936 0 r
.01 w
.34761 .49673 Mdot
[ .05 .05 ] 0 setdash
.34671 .4962 m
.34761 .49673 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61199 .58689 m
.61475 .58546 L
s
.60899 .588 m
.61199 .58689 L
s
.60599 .59001 m
.60899 .588 L
s
0 0 0 r
.004 w
.72915 .49632 Mdot
.53 .8 .95 r
.006 w
.59065 .5938 m
.5938 .59359 L
s
1 .776 0 r
.01 w
[ .05 .05 ] 0 setdash
.71016 .49622 m
.71341 .49495 L
s
.71016 .49622 Mdot
1 .936 0 r
.34671 .4962 Mdot
1 .937 0 r
.34586 .49573 m
.34671 .4962 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47716 .60364 m
.48052 .60155 L
s
0 0 0 r
.004 w
.31885 .49599 Mdot
.53 .8 .95 r
.006 w
.5938 .59359 m
.59694 .5928 L
s
.59694 .5928 m
.59998 .59234 L
s
.35095 .51078 m
.35142 .50735 L
s
.603 .59134 m
.60599 .59001 L
s
.37846 .54805 m
.38002 .5529 L
s
.59998 .59234 m
.603 .59134 L
s
1 .937 0 r
.01 w
.34586 .49573 Mdot
1 .938 0 r
[ .05 .05 ] 0 setdash
.34506 .49531 m
.34586 .49573 L
s
0 0 0 r
.004 w
.73067 .49563 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.34389 .51773 m
.34506 .49531 L
s
1 .938 0 r
.01 w
.34506 .49531 Mdot
[ .05 .05 ] 0 setdash
.34435 .49495 m
.34506 .49531 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35167 .50949 m
.35192 .51505 L
s
.66352 .55851 m
.66569 .56404 L
s
1 .938 0 r
.01 w
.34435 .49495 Mdot
1 .939 0 r
[ .05 .05 ] 0 setdash
.34374 .49466 m
.34435 .49495 L
s
1 .775 0 r
.71341 .49495 m
.71635 .49378 L
s
.71341 .49495 Mdot
0 0 0 r
.004 w
.73218 .49493 Mdot
1 .939 0 r
.01 w
.34374 .49466 Mdot
1 .94 0 r
.34319 .4944 m
.34374 .49466 L
s
.34319 .4944 Mdot
.34268 .49414 m
.34319 .4944 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.47354 .6041 m
.47716 .60364 L
s
0 0 0 r
.004 w
.73369 .49423 Mdot
1 .94 0 r
.01 w
.34268 .49414 Mdot
1 .941 0 r
[ .05 .05 ] 0 setdash
.34219 .49386 m
.34268 .49414 L
s
0 0 0 r
.004 w
.31459 .49402 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38002 .5529 m
.38179 .55879 L
s
1 .941 0 r
.01 w
.34219 .49386 Mdot
[ .05 .05 ] 0 setdash
.34169 .49353 m
.34219 .49386 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35036 .51433 m
.35095 .51078 L
s
.36453 .54321 m
.36588 .539 L
s
1 .775 0 r
.01 w
[ .05 .05 ] 0 setdash
.71635 .49378 m
.71949 .49254 L
s
.71635 .49378 Mdot
1 .941 0 r
.34169 .49353 Mdot
1 .942 0 r
.34113 .49312 m
.34169 .49353 L
s
0 0 0 r
.004 w
.73519 .49352 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46999 .60454 m
.47354 .6041 L
s
1 .942 0 r
.01 w
.34113 .49312 Mdot
1 .943 0 r
[ .05 .05 ] 0 setdash
.34049 .49261 m
.34113 .49312 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35192 .51505 m
.35232 .52119 L
s
0 0 0 r
.004 w
.73669 .4928 Mdot
1 .943 0 r
.01 w
.34049 .49261 Mdot
[ .05 .05 ] 0 setdash
.33974 .49198 m
.34049 .49261 L
s
1 .774 0 r
.71949 .49254 m
.72246 .49134 L
s
.71949 .49254 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.46638 .60537 m
.46999 .60454 L
s
0 0 0 r
.004 w
.73819 .49208 Mdot
1 .943 0 r
.01 w
.33974 .49198 Mdot
1 .944 0 r
[ .05 .05 ] 0 setdash
.3389 .49128 m
.33974 .49198 L
s
0 0 0 r
.004 w
.31017 .4919 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34967 .51774 m
.35036 .51433 L
s
.38179 .55879 m
.38378 .56408 L
s
.66569 .56404 m
.66817 .56944 L
s
.46278 .60554 m
.46638 .60537 L
s
0 0 0 r
.004 w
.73968 .49135 Mdot
1 .774 0 r
.01 w
[ .05 .05 ] 0 setdash
.72246 .49134 m
.72551 .49009 L
s
.72246 .49134 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.33707 .52532 m
.3389 .49128 L
s
1 .944 0 r
.01 w
.3389 .49128 Mdot
[ .05 .05 ] 0 setdash
.33793 .49051 m
.3389 .49128 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36299 .54717 m
.36453 .54321 L
s
0 0 0 r
.004 w
.74117 .49061 Mdot
1 .944 0 r
.01 w
.33793 .49051 Mdot
1 .945 0 r
[ .05 .05 ] 0 setdash
.3366 .48949 m
.33793 .49051 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45903 .6053 m
.46278 .60554 L
s
.35232 .52119 m
.35287 .52772 L
s
1 .773 0 r
.01 w
[ .05 .05 ] 0 setdash
.72551 .49009 m
.72837 .48892 L
s
.72551 .49009 Mdot
0 0 0 r
.004 w
.74266 .48987 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.45537 .60562 m
.45903 .6053 L
s
0 0 0 r
.004 w
.30556 .48962 Mdot
.53 .8 .95 r
.006 w
.38378 .56408 m
.38613 .56966 L
s
1 .945 0 r
.01 w
.3366 .48949 Mdot
1 .946 0 r
[ .05 .05 ] 0 setdash
.33516 .48844 m
.3366 .48949 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34889 .52076 m
.34967 .51774 L
s
0 0 0 r
.004 w
.74414 .48912 Mdot
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.72837 .48892 m
.73131 .48768 L
s
.72837 .48892 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.4517 .60636 m
.45537 .60562 L
s
.34209 .50544 m
.34253 .50704 L
s
.34158 .50544 m
.34209 .50544 L
s
1 .946 0 r
.01 w
.33516 .48844 Mdot
[ .05 .05 ] 0 setdash
.33356 .48735 m
.33516 .48844 L
s
0 0 0 r
.004 w
.74562 .48836 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34253 .50704 m
.34293 .51015 L
s
.34096 .50724 m
.34158 .50544 L
s
.35287 .52772 m
.35363 .53389 L
s
.66817 .56944 m
.67082 .57403 L
s
.44792 .60547 m
.4517 .60636 L
s
1 .772 0 r
.01 w
[ .05 .05 ] 0 setdash
.73131 .48768 m
.73384 .48653 L
s
.73131 .48768 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.36142 .5501 m
.36299 .54717 L
s
0 0 0 r
.004 w
.7471 .4876 Mdot
.53 .8 .95 r
.006 w
.38613 .56966 m
.38868 .57463 L
s
1 .946 0 r
.01 w
.33356 .48735 Mdot
1 .947 0 r
[ .05 .05 ] 0 setdash
.33154 .48597 m
.33356 .48735 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.44427 .60449 m
.44792 .60547 L
s
.34804 .5226 m
.34889 .52076 L
s
0 0 0 r
.004 w
.30073 .48713 Mdot
.53 .8 .95 r
.006 w
.34293 .51015 m
.34337 .51381 L
s
.4335 .59898 m
.4371 .60128 L
s
.43004 .59731 m
.4335 .59898 L
s
.42668 .5965 m
.43004 .59731 L
s
.44063 .60355 m
.44427 .60449 L
s
0 0 0 r
.004 w
.74857 .48683 Mdot
.53 .8 .95 r
.006 w
.3402 .51066 m
.34096 .50724 L
s
.4371 .60128 m
.44063 .60355 L
s
.4232 .59454 m
.42668 .5965 L
s
.41983 .59372 m
.4232 .59454 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73793 .55371 m
.73384 .48653 L
s
1 .771 0 r
.01 w
[ .05 .05 ] 0 setdash
.73384 .48653 m
.73651 .48534 L
s
.73384 .48653 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.41638 .5931 m
.41983 .59372 L
s
0 0 0 r
.004 w
.75003 .48605 Mdot
1 .947 0 r
.01 w
.33154 .48597 Mdot
1 .948 0 r
[ .05 .05 ] 0 setdash
.32949 .48464 m
.33154 .48597 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.38868 .57463 m
.39124 .57888 L
s
.35363 .53389 m
.35459 .53973 L
s
.34337 .51381 m
.34389 .51773 L
s
.34711 .52419 m
.34804 .5226 L
s
.41316 .59284 m
.41638 .5931 L
s
1 .771 0 r
.01 w
[ .05 .05 ] 0 setdash
.73651 .48534 m
.73903 .48419 L
s
.73651 .48534 Mdot
0 0 0 r
.004 w
.7515 .48527 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.35982 .55077 m
.36142 .5501 L
s
.40975 .59174 m
.41316 .59284 L
s
1 .948 0 r
.01 w
.32949 .48464 Mdot
[ .05 .05 ] 0 setdash
.32723 .48316 m
.32949 .48464 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.39124 .57888 m
.3941 .58207 L
s
0 0 0 r
.004 w
.75296 .48448 Mdot
.53 .8 .95 r
.006 w
.33929 .51503 m
.3402 .51066 L
s
0 0 0 r
.004 w
.29562 .4844 Mdot
.53 .8 .95 r
.006 w
.67082 .57403 m
.67368 .57903 L
s
.34389 .51773 m
.34453 .52137 L
s
.40644 .59011 m
.40975 .59174 L
s
1 .77 0 r
.01 w
[ .05 .05 ] 0 setdash
.73903 .48419 m
.74167 .48301 L
s
.73903 .48419 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34616 .52487 m
.34711 .52419 L
s
.3941 .58207 m
.39703 .58488 L
s
.40322 .58948 m
.40644 .59011 L
s
.35459 .53973 m
.35561 .54453 L
s
0 0 0 r
.004 w
.75441 .48368 Mdot
.53 .8 .95 r
.006 w
.39703 .58488 m
.40006 .58771 L
s
.40006 .58771 m
.40322 .58948 L
s
.35828 .55056 m
.35982 .55077 L
s
1 .948 0 r
.01 w
.32723 .48316 Mdot
1 .949 0 r
[ .05 .05 ] 0 setdash
.32487 .48159 m
.32723 .48316 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34453 .52137 m
.34527 .52429 L
s
1 .769 0 r
.01 w
[ .05 .05 ] 0 setdash
.74167 .48301 m
.74381 .48198 L
s
.74167 .48301 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.34527 .52429 m
.34616 .52487 L
s
0 0 0 r
.004 w
.75587 .48288 Mdot
.53 .8 .95 r
.006 w
.35561 .54453 m
.35693 .54855 L
s
.35693 .54855 m
.35828 .55056 L
s
0 0 0 r
.004 w
.75731 .48206 Mdot
1 .769 0 r
.01 w
[ .05 .05 ] 0 setdash
.74381 .48198 m
.74594 .48099 L
s
.74381 .48198 Mdot
1 .949 0 r
.32487 .48159 Mdot
.32272 .4802 m
.32487 .48159 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33825 .51982 m
.33929 .51503 L
s
0 0 0 r
.004 w
.29016 .48136 Mdot
.75876 .48125 Mdot
1 .768 0 r
.01 w
[ .05 .05 ] 0 setdash
.74594 .48099 m
.74805 .48004 L
s
.74594 .48099 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67368 .57903 m
.67662 .58278 L
s
0 0 0 r
.004 w
.7602 .48042 Mdot
1 .949 0 r
.01 w
.32272 .4802 Mdot
1 .95 0 r
[ .05 .05 ] 0 setdash
.32016 .47844 m
.32272 .4802 L
s
1 .767 0 r
.74805 .48004 m
.75005 .47915 L
s
.74805 .48004 Mdot
0 0 0 r
.004 w
.76164 .47959 Mdot
1 .767 0 r
.01 w
.75005 .47915 m
.75199 .47831 L
s
.75005 .47915 Mdot
0 0 0 r
.004 w
.76307 .47875 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.3157 .55337 m
.32016 .47844 L
s
1 .95 0 r
.01 w
.32016 .47844 Mdot
1 .951 0 r
[ .05 .05 ] 0 setdash
.31797 .47683 m
.32016 .47844 L
s
1 .766 0 r
.75199 .47831 m
.75398 .47747 L
s
.75199 .47831 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33707 .52532 m
.33825 .51982 L
s
0 0 0 r
.004 w
.28425 .47791 Mdot
.7645 .4779 Mdot
1 .766 0 r
.01 w
[ .05 .05 ] 0 setdash
.75398 .47747 m
.75571 .47671 L
s
.75398 .47747 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67662 .58278 m
.67965 .58503 L
s
0 0 0 r
.004 w
.76592 .47704 Mdot
1 .951 0 r
.01 w
.31797 .47683 Mdot
[ .05 .05 ] 0 setdash
.31558 .47525 m
.31797 .47683 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.75862 .51982 m
.75571 .47671 L
s
1 .765 0 r
.01 w
[ .05 .05 ] 0 setdash
.75571 .47671 m
.75734 .47598 L
s
.75571 .47671 Mdot
0 0 0 r
.004 w
.76734 .47618 Mdot
1 .764 0 r
.01 w
.75734 .47598 m
.75895 .47523 L
s
.75734 .47598 Mdot
0 0 0 r
.004 w
.76876 .47531 Mdot
1 .951 0 r
.01 w
.31558 .47525 Mdot
1 .952 0 r
.31309 .47358 m
.31558 .47525 L
s
1 .764 0 r
.75895 .47523 m
.76049 .47446 L
s
.75895 .47523 Mdot
1 .763 0 r
.76049 .47446 m
.762 .47365 L
s
.76049 .47446 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33575 .53082 m
.33707 .52532 L
s
0 0 0 r
.004 w
.77017 .47443 Mdot
.53 .8 .95 r
.006 w
.67965 .58503 m
.68275 .58653 L
s
0 0 0 r
.004 w
.2777 .4739 Mdot
1 .762 0 r
.01 w
[ .05 .05 ] 0 setdash
.762 .47365 m
.76334 .47284 L
s
.762 .47365 Mdot
1 .952 0 r
.31309 .47358 Mdot
.31067 .47195 m
.31309 .47358 L
s
0 0 0 r
.004 w
.77158 .47354 Mdot
1 .762 0 r
.01 w
.76334 .47284 m
.76471 .47197 L
s
.76334 .47284 Mdot
0 0 0 r
.004 w
.77298 .47265 Mdot
1 .761 0 r
.01 w
.76471 .47197 m
.76611 .47104 L
s
.76471 .47197 Mdot
1 .952 0 r
.31067 .47195 Mdot
1 .953 0 r
.30826 .47028 m
.31067 .47195 L
s
0 0 0 r
.004 w
.77438 .47175 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68275 .58653 m
.68575 .5873 L
s
1 .761 0 r
.01 w
[ .05 .05 ] 0 setdash
.76611 .47104 m
.76757 .47004 L
s
.76611 .47104 Mdot
0 0 0 r
.004 w
.77578 .47084 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33409 .53564 m
.33575 .53082 L
s
1 .953 0 r
.01 w
.30826 .47028 Mdot
1 .954 0 r
[ .05 .05 ] 0 setdash
.30565 .46839 m
.30826 .47028 L
s
1 .76 0 r
.76757 .47004 m
.7691 .46892 L
s
.76757 .47004 Mdot
0 0 0 r
.004 w
.77717 .46992 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68575 .5873 m
.68895 .5869 L
s
0 0 0 r
.004 w
.77855 .46899 Mdot
.27016 .46899 Mdot
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.7691 .46892 m
.77065 .46771 L
s
.7691 .46892 Mdot
1 .954 0 r
.30565 .46839 Mdot
.30336 .46678 m
.30565 .46839 L
s
0 0 0 r
.004 w
.77994 .46806 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.77466 .52342 m
.77065 .46771 L
s
1 .759 0 r
.01 w
[ .05 .05 ] 0 setdash
.77065 .46771 m
.77234 .46642 L
s
.77065 .46771 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68895 .5869 m
.69187 .58501 L
s
0 0 0 r
.004 w
.78131 .46711 Mdot
1 .954 0 r
.01 w
.30336 .46678 Mdot
1 .955 0 r
[ .05 .05 ] 0 setdash
.30064 .46477 m
.30336 .46678 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3323 .54044 m
.33409 .53564 L
s
.69187 .58501 m
.69519 .58427 L
s
1 .758 0 r
.01 w
[ .05 .05 ] 0 setdash
.77234 .46642 m
.77398 .46503 L
s
.77234 .46642 Mdot
0 0 0 r
.004 w
.78269 .46616 Mdot
.78405 .4652 Mdot
1 .758 0 r
.01 w
.77398 .46503 m
.77579 .46352 L
s
.77398 .46503 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69519 .58427 m
.69823 .58281 L
s
1 .955 0 r
.01 w
.30064 .46477 Mdot
1 .956 0 r
[ .05 .05 ] 0 setdash
.29836 .46313 m
.30064 .46477 L
s
0 0 0 r
.004 w
.78542 .46423 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69823 .58281 m
.70153 .58169 L
s
1 .757 0 r
.01 w
[ .05 .05 ] 0 setdash
.77579 .46352 m
.77753 .46196 L
s
.77579 .46352 Mdot
0 0 0 r
.004 w
.78678 .46326 Mdot
1 .956 0 r
.01 w
.29836 .46313 Mdot
.29572 .46118 m
.29836 .46313 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33035 .54522 m
.3323 .54044 L
s
0 0 0 r
.004 w
.26072 .46236 Mdot
.78813 .46227 Mdot
.53 .8 .95 r
.006 w
.70153 .58169 m
.70455 .57979 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.77753 .46196 m
.77929 .4604 L
s
.77753 .46196 Mdot
0 0 0 r
.004 w
.78948 .46127 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29026 .54275 m
.29572 .46118 L
s
1 .956 0 r
.01 w
.29572 .46118 Mdot
1 .957 0 r
[ .05 .05 ] 0 setdash
.29323 .45938 m
.29572 .46118 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70455 .57979 m
.70788 .57841 L
s
1 .756 0 r
.01 w
[ .05 .05 ] 0 setdash
.77929 .4604 m
.78098 .45876 L
s
.77929 .4604 Mdot
0 0 0 r
.004 w
.79083 .46027 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70788 .57841 m
.71119 .57779 L
s
1 .957 0 r
.01 w
.29323 .45938 Mdot
[ .05 .05 ] 0 setdash
.29096 .45778 m
.29323 .45938 L
s
0 0 0 r
.004 w
.79217 .45926 Mdot
1 .755 0 r
.01 w
.78098 .45876 m
.78275 .45714 L
s
.78098 .45876 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.328 .54918 m
.33035 .54522 L
s
0 0 0 r
.004 w
.79351 .45823 Mdot
.53 .8 .95 r
.006 w
.71119 .57779 m
.71445 .57592 L
s
1 .957 0 r
.01 w
.29096 .45778 Mdot
1 .958 0 r
[ .05 .05 ] 0 setdash
.28838 .45594 m
.29096 .45778 L
s
0 0 0 r
.004 w
.79484 .4572 Mdot
1 .754 0 r
.01 w
.78275 .45714 m
.7844 .45556 L
s
.78275 .45714 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71445 .57592 m
.71776 .57445 L
s
0 0 0 r
.004 w
.79616 .45616 Mdot
1 .958 0 r
.01 w
.28838 .45594 Mdot
1 .959 0 r
[ .05 .05 ] 0 setdash
.28616 .45444 m
.28838 .45594 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71776 .57445 m
.72076 .573 L
s
.76162 .51423 m
.76313 .5129 L
s
.76009 .51653 m
.76162 .51423 L
s
.75862 .51982 m
.76009 .51653 L
s
1 .754 0 r
.01 w
[ .05 .05 ] 0 setdash
.7844 .45556 m
.7861 .45385 L
s
.7844 .45556 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76313 .5129 m
.76468 .51234 L
s
.75706 .52336 m
.75862 .51982 L
s
0 0 0 r
.004 w
.79748 .45511 Mdot
.53 .8 .95 r
.006 w
.72076 .573 m
.72394 .57103 L
s
.32564 .55271 m
.328 .54918 L
s
.75523 .52704 m
.75706 .52336 L
s
1 .959 0 r
.01 w
.28616 .45444 Mdot
[ .05 .05 ] 0 setdash
.28383 .4528 m
.28616 .45444 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76468 .51234 m
.76613 .51292 L
s
0 0 0 r
.004 w
.7988 .45405 Mdot
.53 .8 .95 r
.006 w
.75343 .53058 m
.75523 .52704 L
s
1 .753 0 r
.01 w
[ .05 .05 ] 0 setdash
.7861 .45385 m
.78777 .45213 L
s
.7861 .45385 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72394 .57103 m
.72685 .56772 L
s
.72685 .56772 m
.72989 .5651 L
s
.75161 .53466 m
.75343 .53058 L
s
.73793 .55371 m
.74055 .55076 L
s
.73553 .55778 m
.73793 .55371 L
s
.73266 .56136 m
.73553 .55778 L
s
.72989 .5651 m
.73266 .56136 L
s
0 0 0 r
.004 w
.80011 .45297 Mdot
.53 .8 .95 r
.006 w
.74055 .55076 m
.74298 .54744 L
s
1 .959 0 r
.01 w
.28383 .4528 Mdot
1 .96 0 r
[ .05 .05 ] 0 setdash
.28176 .45138 m
.28383 .4528 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74962 .53804 m
.75161 .53466 L
s
.74298 .54744 m
.74556 .54454 L
s
.76613 .51292 m
.76771 .51478 L
s
.74758 .54103 m
.74962 .53804 L
s
.74556 .54454 m
.74758 .54103 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.79295 .51921 m
.78777 .45213 L
s
1 .753 0 r
.01 w
[ .05 .05 ] 0 setdash
.78777 .45213 m
.78948 .45054 L
s
.78777 .45213 Mdot
0 0 0 r
.004 w
.80141 .45189 Mdot
1 .96 0 r
.01 w
.28176 .45138 Mdot
1 .961 0 r
.27991 .45008 m
.28176 .45138 L
s
0 0 0 r
.004 w
.80271 .4508 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32319 .55363 m
.32564 .55271 L
s
1 .752 0 r
.01 w
[ .05 .05 ] 0 setdash
.78948 .45054 m
.79102 .44892 L
s
.78948 .45054 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76771 .51478 m
.76934 .51674 L
s
1 .961 0 r
.01 w
.27991 .45008 Mdot
[ .05 .05 ] 0 setdash
.27829 .44891 m
.27991 .45008 L
s
0 0 0 r
.004 w
.80401 .4497 Mdot
1 .751 0 r
.01 w
.79102 .44892 m
.79261 .44729 L
s
.79102 .44892 Mdot
1 .961 0 r
.27829 .44891 Mdot
1 .962 0 r
.27697 .44797 m
.27829 .44891 L
s
0 0 0 r
.004 w
.8053 .44859 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32063 .55463 m
.32319 .55363 L
s
.76934 .51674 m
.77101 .51846 L
s
1 .962 0 r
.01 w
.27697 .44797 Mdot
[ .05 .05 ] 0 setdash
.27589 .44719 m
.27697 .44797 L
s
0 0 0 r
.004 w
.80658 .44746 Mdot
1 .751 0 r
.01 w
.79261 .44729 m
.79419 .44563 L
s
.79261 .44729 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.27369 .47722 m
.27589 .44719 L
s
1 .962 0 r
.01 w
.27589 .44719 Mdot
1 .963 0 r
[ .05 .05 ] 0 setdash
.27509 .44663 m
.27589 .44719 L
s
.27509 .44663 Mdot
1 .964 0 r
.27453 .44623 m
.27509 .44663 L
s
0 0 0 r
.004 w
.80786 .44633 Mdot
1 .964 0 r
.01 w
.27453 .44623 Mdot
.27414 .44596 m
.27453 .44623 L
s
.27414 .44596 Mdot
1 .965 0 r
.2739 .44578 m
.27414 .44596 L
s
.2739 .44578 Mdot
.27378 .44567 m
.2739 .44578 L
s
.27378 .44567 Mdot
1 .966 0 r
.27372 .44558 m
.27378 .44567 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77101 .51846 m
.77279 .52055 L
s
1 .75 0 r
.01 w
[ .05 .05 ] 0 setdash
.79419 .44563 m
.79578 .44399 L
s
.79419 .44563 Mdot
1 .966 0 r
.27372 .44558 Mdot
1 .967 0 r
.27363 .44546 m
.27372 .44558 L
s
.27363 .44546 Mdot
.27342 .44528 m
.27363 .44546 L
s
0 0 0 r
.004 w
.23975 .44533 Mdot
.23975 .44533 Mdot
1 .967 0 r
.01 w
.27342 .44528 Mdot
1 .968 0 r
.27306 .44502 m
.27342 .44528 L
s
0 0 0 r
.004 w
.80913 .44518 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31833 .55494 m
.32063 .55463 L
s
1 .968 0 r
.01 w
.27306 .44502 Mdot
1 .969 0 r
[ .05 .05 ] 0 setdash
.27255 .44461 m
.27306 .44502 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27361 .44707 m
.27365 .44751 L
s
.2734 .44851 m
.27361 .44707 L
s
.27365 .44751 m
.27356 .45042 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.27121 .46278 m
.27255 .44461 L
s
1 .969 0 r
.01 w
.27255 .44461 Mdot
[ .05 .05 ] 0 setdash
.27191 .44405 m
.27255 .44461 L
s
.27191 .44405 Mdot
1 .97 0 r
.27112 .44328 m
.27191 .44405 L
s
0 0 0 r
.004 w
.81039 .44403 Mdot
1 .75 0 r
.01 w
.79578 .44399 m
.79743 .44223 L
s
.79578 .44399 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27294 .45181 m
.2734 .44851 L
s
.27356 .45042 m
.27347 .45512 L
s
1 .97 0 r
.01 w
.27112 .44328 Mdot
[ .05 .05 ] 0 setdash
.27021 .44229 m
.27112 .44328 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77279 .52055 m
.77466 .52342 L
s
.3157 .55337 m
.31833 .55494 L
s
0 0 0 r
.004 w
.81165 .44286 Mdot
1 .97 0 r
.01 w
.27021 .44229 Mdot
1 .971 0 r
[ .05 .05 ] 0 setdash
.26929 .44111 m
.27021 .44229 L
s
1 .749 0 r
.79743 .44223 m
.79894 .44064 L
s
.79743 .44223 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2722 .45662 m
.27294 .45181 L
s
0 0 0 r
.004 w
.81291 .44168 Mdot
.53 .8 .95 r
.006 w
.27347 .45512 m
.27343 .46115 L
s
1 .971 0 r
.01 w
.26929 .44111 Mdot
1 .972 0 r
[ .05 .05 ] 0 setdash
.26833 .43971 m
.26929 .44111 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31343 .55227 m
.3157 .55337 L
s
1 .748 0 r
.01 w
[ .05 .05 ] 0 setdash
.79894 .44064 m
.80055 .43895 L
s
.79894 .44064 Mdot
0 0 0 r
.004 w
.81416 .44049 Mdot
1 .972 0 r
.01 w
.26833 .43971 Mdot
.26754 .43824 m
.26833 .43971 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77466 .52342 m
.77663 .52549 L
s
0 0 0 r
.004 w
.8154 .43929 Mdot
.53 .8 .95 r
.006 w
.3109 .55212 m
.31343 .55227 L
s
.27121 .46278 m
.2722 .45662 L
s
1 .748 0 r
.01 w
[ .05 .05 ] 0 setdash
.80055 .43895 m
.80227 .43721 L
s
.80055 .43895 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27343 .46115 m
.27346 .46895 L
s
1 .972 0 r
.01 w
.26754 .43824 Mdot
1 .973 0 r
[ .05 .05 ] 0 setdash
.26663 .43648 m
.26754 .43824 L
s
0 0 0 r
.004 w
.81663 .43807 Mdot
1 .747 0 r
.01 w
.80227 .43721 m
.80387 .43549 L
s
.80227 .43721 Mdot
0 0 0 r
.004 w
.81786 .43685 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30834 .5507 m
.3109 .55212 L
s
.77663 .52549 m
.77846 .52645 L
s
1 .973 0 r
.01 w
.26663 .43648 Mdot
[ .05 .05 ] 0 setdash
.26587 .43474 m
.26663 .43648 L
s
0 0 0 r
.004 w
.81908 .43561 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.80966 .50572 m
.80387 .43549 L
s
1 .746 0 r
.01 w
[ .05 .05 ] 0 setdash
.80387 .43549 m
.80557 .43375 L
s
.80387 .43549 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27 .4698 m
.27121 .46278 L
s
.27346 .46895 m
.27369 .47722 L
s
.30581 .5499 m
.30834 .5507 L
s
1 .973 0 r
.01 w
.26587 .43474 Mdot
1 .974 0 r
[ .05 .05 ] 0 setdash
.26517 .43292 m
.26587 .43474 L
s
0 0 0 r
.004 w
.8203 .43435 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77846 .52645 m
.78047 .52714 L
s
1 .746 0 r
.01 w
[ .05 .05 ] 0 setdash
.80557 .43375 m
.80726 .43199 L
s
.80557 .43375 Mdot
0 0 0 r
.004 w
.82151 .43309 Mdot
1 .974 0 r
.01 w
.26517 .43292 Mdot
1 .975 0 r
.26465 .43109 m
.26517 .43292 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30328 .54907 m
.30581 .5499 L
s
1 .745 0 r
.01 w
[ .05 .05 ] 0 setdash
.80726 .43199 m
.80901 .43016 L
s
.80726 .43199 Mdot
0 0 0 r
.004 w
.82271 .43181 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27369 .47722 m
.27419 .48616 L
s
.78047 .52714 m
.78243 .52801 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.25956 .49736 m
.26465 .43109 L
s
1 .975 0 r
.01 w
.26465 .43109 Mdot
[ .05 .05 ] 0 setdash
.26446 .42923 m
.26465 .43109 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26861 .47698 m
.27 .4698 L
s
.30056 .54793 m
.30328 .54907 L
s
0 0 0 r
.004 w
.8239 .43052 Mdot
1 .745 0 r
.01 w
[ .05 .05 ] 0 setdash
.80901 .43016 m
.8106 .42846 L
s
.80901 .43016 Mdot
1 .975 0 r
.26446 .42923 Mdot
1 .976 0 r
.26407 .42756 m
.26446 .42923 L
s
0 0 0 r
.004 w
.82509 .42921 Mdot
1 .744 0 r
.01 w
.8106 .42846 m
.81218 .42668 L
s
.8106 .42846 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78243 .52801 m
.78428 .52723 L
s
.27419 .48616 m
.27492 .49556 L
s
.29817 .54718 m
.30056 .54793 L
s
0 0 0 r
.004 w
.82627 .42789 Mdot
1 .976 0 r
.01 w
.26407 .42756 Mdot
1 .977 0 r
[ .05 .05 ] 0 setdash
.26391 .42566 m
.26407 .42756 L
s
0 0 0 r
.004 w
.22158 .42689 Mdot
1 .743 0 r
.01 w
.81218 .42668 m
.81382 .42494 L
s
.81218 .42668 Mdot
0 0 0 r
.004 w
.82744 .42656 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78428 .52723 m
.78606 .52632 L
s
.29538 .54518 m
.29817 .54718 L
s
.2671 .48384 m
.26861 .47698 L
s
1 .977 0 r
.01 w
.26391 .42566 Mdot
[ .05 .05 ] 0 setdash
.26353 .42397 m
.26391 .42566 L
s
0 0 0 r
.004 w
.8286 .42521 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27492 .49556 m
.27594 .50538 L
s
1 .743 0 r
.01 w
[ .05 .05 ] 0 setdash
.81382 .42494 m
.8152 .4233 L
s
.81382 .42494 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78606 .52632 m
.78793 .52556 L
s
.29296 .54474 m
.29538 .54518 L
s
1 .977 0 r
.01 w
.26353 .42397 Mdot
1 .978 0 r
[ .05 .05 ] 0 setdash
.26347 .42217 m
.26353 .42397 L
s
0 0 0 r
.004 w
.82976 .42384 Mdot
1 .742 0 r
.01 w
.8152 .4233 m
.81668 .42166 L
s
.8152 .4233 Mdot
0 0 0 r
.004 w
.83091 .42246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78793 .52556 m
.78958 .52346 L
s
1 .978 0 r
.01 w
.26347 .42217 Mdot
[ .05 .05 ] 0 setdash
.26327 .42054 m
.26347 .42217 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29026 .54275 m
.29296 .54474 L
s
.27594 .50538 m
.27732 .51382 L
s
1 .742 0 r
.01 w
[ .05 .05 ] 0 setdash
.81668 .42166 m
.81813 .42004 L
s
.81668 .42166 Mdot
0 0 0 r
.004 w
.83205 .42107 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78958 .52346 m
.79126 .52099 L
s
.26561 .49008 m
.2671 .48384 L
s
1 .978 0 r
.01 w
.26327 .42054 Mdot
1 .979 0 r
[ .05 .05 ] 0 setdash
.26286 .41887 m
.26327 .42054 L
s
1 .741 0 r
.81813 .42004 m
.81963 .41841 L
s
.81813 .42004 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28774 .54051 m
.29026 .54275 L
s
0 0 0 r
.004 w
.83318 .41966 Mdot
.53 .8 .95 r
.006 w
.79126 .52099 m
.79295 .51921 L
s
.27732 .51382 m
.27897 .52171 L
s
1 .979 0 r
.01 w
.26286 .41887 Mdot
1 .98 0 r
[ .05 .05 ] 0 setdash
.26227 .41724 m
.26286 .41887 L
s
0 0 0 r
.004 w
.21492 .41887 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.82497 .47946 m
.81963 .41841 L
s
1 .74 0 r
.01 w
[ .05 .05 ] 0 setdash
.81963 .41841 m
.82105 .41679 L
s
.81963 .41841 Mdot
0 0 0 r
.004 w
.8343 .41823 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28547 .53793 m
.28774 .54051 L
s
.79295 .51921 m
.79464 .51674 L
s
.27897 .52171 m
.28093 .52925 L
s
1 .98 0 r
.01 w
.26227 .41724 Mdot
[ .05 .05 ] 0 setdash
.26168 .4157 m
.26227 .41724 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.283 .53368 m
.28547 .53793 L
s
1 .74 0 r
.01 w
[ .05 .05 ] 0 setdash
.82105 .41679 m
.82257 .41515 L
s
.82105 .41679 Mdot
0 0 0 r
.004 w
.83541 .41679 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79464 .51674 m
.79614 .51421 L
s
.28093 .52925 m
.283 .53368 L
s
.2641 .49586 m
.26561 .49008 L
s
1 .98 0 r
.01 w
.26168 .4157 Mdot
1 .981 0 r
[ .05 .05 ] 0 setdash
.26101 .41426 m
.26168 .4157 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79614 .51421 m
.79766 .51131 L
s
0 0 0 r
.004 w
.83652 .41533 Mdot
1 .739 0 r
.01 w
[ .05 .05 ] 0 setdash
.82257 .41515 m
.82403 .41351 L
s
.82257 .41515 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79766 .51131 m
.79926 .50948 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.2568 .46804 m
.26101 .41426 L
s
1 .981 0 r
.01 w
.26101 .41426 Mdot
[ .05 .05 ] 0 setdash
.26015 .41282 m
.26101 .41426 L
s
0 0 0 r
.004 w
.83761 .41385 Mdot
1 .738 0 r
.01 w
.82403 .41351 m
.82547 .41185 L
s
.82403 .41351 Mdot
1 .981 0 r
.26015 .41282 Mdot
1 .982 0 r
.25929 .4115 m
.26015 .41282 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79926 .50948 m
.8009 .50808 L
s
0 0 0 r
.004 w
.21017 .41256 Mdot
.8387 .41236 Mdot
1 .738 0 r
.01 w
[ .05 .05 ] 0 setdash
.82547 .41185 m
.82702 .41017 L
s
.82547 .41185 Mdot
1 .982 0 r
.25929 .4115 Mdot
1 .983 0 r
.25843 .41029 m
.25929 .4115 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8009 .50808 m
.80266 .50727 L
s
0 0 0 r
.004 w
.83977 .41084 Mdot
.53 .8 .95 r
.006 w
.26287 .49985 m
.2641 .49586 L
s
1 .983 0 r
.01 w
.25843 .41029 Mdot
[ .05 .05 ] 0 setdash
.25741 .40904 m
.25843 .41029 L
s
1 .737 0 r
.82702 .41017 m
.82846 .4085 L
s
.82702 .41017 Mdot
0 0 0 r
.004 w
.84084 .40931 Mdot
1 .983 0 r
.01 w
.25741 .40904 Mdot
1 .984 0 r
.25642 .40791 m
.25741 .40904 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80266 .50727 m
.80433 .5073 L
s
1 .737 0 r
.01 w
[ .05 .05 ] 0 setdash
.82846 .4085 m
.8299 .40688 L
s
.82846 .4085 Mdot
1 .984 0 r
.25642 .40791 Mdot
1 .985 0 r
.2554 .40688 m
.25642 .40791 L
s
0 0 0 r
.004 w
.84189 .40776 Mdot
.20642 .40714 Mdot
1 .985 0 r
.01 w
.2554 .40688 Mdot
.25438 .40598 m
.2554 .40688 L
s
1 .736 0 r
.8299 .40688 m
.83134 .40527 L
s
.8299 .40688 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26174 .50091 m
.26287 .49985 L
s
.80433 .5073 m
.80609 .50693 L
s
0 0 0 r
.004 w
.84294 .40619 Mdot
1 .985 0 r
.01 w
.25438 .40598 Mdot
1 .986 0 r
[ .05 .05 ] 0 setdash
.25334 .40518 m
.25438 .40598 L
s
1 .735 0 r
.83134 .40527 m
.83267 .40369 L
s
.83134 .40527 Mdot
1 .986 0 r
.25334 .40518 Mdot
.25232 .40452 m
.25334 .40518 L
s
0 0 0 r
.004 w
.84397 .40459 Mdot
1 .986 0 r
.01 w
.25232 .40452 Mdot
1 .987 0 r
.2513 .40396 m
.25232 .40452 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24914 .43056 m
.2513 .40396 L
s
1 .987 0 r
.01 w
.2513 .40396 Mdot
1 .988 0 r
[ .05 .05 ] 0 setdash
.2503 .40351 m
.2513 .40396 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80609 .50693 m
.80798 .507 L
s
1 .735 0 r
.01 w
[ .05 .05 ] 0 setdash
.83267 .40369 m
.83398 .40218 L
s
.83267 .40369 Mdot
1 .988 0 r
.2503 .40351 Mdot
.24931 .40312 m
.2503 .40351 L
s
.24931 .40312 Mdot
1 .989 0 r
.24833 .40285 m
.24931 .40312 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26081 .50101 m
.26174 .50091 L
s
0 0 0 r
.004 w
.84499 .40298 Mdot
1 .989 0 r
.01 w
.24833 .40285 Mdot
1 .99 0 r
[ .05 .05 ] 0 setdash
.24743 .40265 m
.24833 .40285 L
s
1 .997 0 r
.24105 .40277 m
.24128 .40276 L
s
.24105 .40277 Mdot
1 .998 0 r
.24084 .40275 m
.24105 .40277 L
s
1 .996 0 r
.24128 .40276 m
.24153 .40274 L
s
.24128 .40276 Mdot
1 .998 0 r
.24084 .40275 Mdot
.24064 .40272 m
.24084 .40275 L
s
1 .996 0 r
.24153 .40274 m
.24182 .4027 L
s
.24153 .40274 Mdot
1 .998 0 r
.24064 .40272 Mdot
1 .999 0 r
.24049 .40269 m
.24064 .40272 L
s
1 .995 0 r
.24182 .4027 m
.24216 .40265 L
s
.24182 .4027 Mdot
1 .999 0 r
.24049 .40269 Mdot
.24036 .40265 m
.24049 .40269 L
s
1 .99 0 r
.24743 .40265 Mdot
.24655 .40251 m
.24743 .40265 L
s
1 .994 0 r
.24216 .40265 m
.24257 .40259 L
s
.24216 .40265 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24021 .40447 m
.24036 .40265 L
s
1 .999 0 r
.01 w
.24036 .40265 Mdot
1 .994 0 r
[ .05 .05 ] 0 setdash
.24257 .40259 m
.24306 .40253 L
s
.24257 .40259 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24222 .41255 m
.24306 .40253 L
s
1 .993 0 r
.01 w
[ .05 .05 ] 0 setdash
.24306 .40253 m
.24362 .40247 L
s
.24306 .40253 Mdot
1 .99 0 r
.24655 .40251 Mdot
1 .991 0 r
.24575 .40242 m
.24655 .40251 L
s
1 .993 0 r
.24362 .40247 m
.24425 .40242 L
s
.24362 .40247 Mdot
1 .992 0 r
.24425 .40242 m
.24496 .4024 L
s
.24425 .40242 Mdot
1 .991 0 r
.24575 .40242 Mdot
.24496 .4024 m
.24575 .40242 L
s
.24496 .4024 Mdot
0 0 0 r
.004 w
.20331 .4023 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.83907 .45729 m
.83398 .40218 L
s
1 .734 0 r
.01 w
[ .05 .05 ] 0 setdash
.83398 .40218 m
.83527 .40075 L
s
.83398 .40218 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24021 .40447 m
.24027 .40523 L
s
0 0 0 r
.004 w
.846 .40135 Mdot
.53 .8 .95 r
.006 w
.24027 .40523 m
.24035 .40619 L
s
.80798 .507 m
.80966 .50572 L
s
.24035 .40619 m
.24046 .40719 L
s
1 .733 0 r
.01 w
[ .05 .05 ] 0 setdash
.83527 .40075 m
.83635 .39942 L
s
.83527 .40075 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24046 .40719 m
.24061 .408 L
s
.26004 .49998 m
.26081 .50101 L
s
.24061 .408 m
.24079 .40859 L
s
0 0 0 r
.004 w
.84699 .39969 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.23731 .39988 m
.23732 .39967 L
s
1 .001 0 r
.01 w
[ .05 .05 ] 0 setdash
.23722 .39959 m
.23732 .39967 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24079 .40859 m
.24098 .40934 L
s
1 .001 0 r
.01 w
.23722 .39959 Mdot
[ .05 .05 ] 0 setdash
.23695 .39935 m
.23722 .39959 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23689 .4035 m
.23731 .39988 L
s
1 .733 0 r
.01 w
[ .05 .05 ] 0 setdash
.83635 .39942 m
.83736 .39817 L
s
.83635 .39942 Mdot
1 .001 0 r
.23695 .39935 Mdot
1 .002 0 r
.23647 .39893 m
.23695 .39935 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24098 .40934 m
.24122 .4098 L
s
.80966 .50572 m
.81143 .50443 L
s
1 .002 0 r
.01 w
.23647 .39893 Mdot
[ .05 .05 ] 0 setdash
.23577 .39829 m
.23647 .39893 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24122 .4098 m
.2415 .41049 L
s
.2415 .41049 m
.24183 .41143 L
s
1 .002 0 r
.01 w
.23577 .39829 Mdot
1 .003 0 r
[ .05 .05 ] 0 setdash
.23488 .39747 m
.23577 .39829 L
s
1 .732 0 r
.83736 .39817 m
.8382 .39704 L
s
.83736 .39817 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25956 .49736 m
.26004 .49998 L
s
0 0 0 r
.004 w
.84798 .39801 Mdot
.53 .8 .95 r
.006 w
.24183 .41143 m
.24222 .41255 L
s
0 0 0 r
.004 w
.20065 .39786 Mdot
.53 .8 .95 r
.006 w
.23612 .40909 m
.23689 .4035 L
s
1 .003 0 r
.01 w
.23488 .39747 Mdot
1 .004 0 r
[ .05 .05 ] 0 setdash
.23376 .39643 m
.23488 .39747 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24222 .41255 m
.24265 .41405 L
s
1 .732 0 r
.01 w
[ .05 .05 ] 0 setdash
.8382 .39704 m
.83891 .39605 L
s
.8382 .39704 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.81143 .50443 m
.81314 .50237 L
s
.25952 .4936 m
.25956 .49736 L
s
1 .004 0 r
.01 w
.23376 .39643 Mdot
[ .05 .05 ] 0 setdash
.23255 .39527 m
.23376 .39643 L
s
0 0 0 r
.004 w
.84895 .39631 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24265 .41405 m
.24317 .41536 L
s
1 .731 0 r
.01 w
[ .05 .05 ] 0 setdash
.83891 .39605 m
.8395 .3952 L
s
.83891 .39605 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25924 .49027 m
.25952 .4936 L
s
.24317 .41536 m
.24376 .4168 L
s
.81314 .50237 m
.81489 .50009 L
s
1 .004 0 r
.01 w
.23255 .39527 Mdot
1 .005 0 r
[ .05 .05 ] 0 setdash
.23128 .39403 m
.23255 .39527 L
s
1 .73 0 r
.8395 .3952 m
.83997 .39449 L
s
.8395 .3952 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25921 .4867 m
.25924 .49027 L
s
.24376 .4168 m
.24441 .41846 L
s
0 0 0 r
.004 w
.84991 .39458 Mdot
1 .73 0 r
.01 w
[ .05 .05 ] 0 setdash
.83997 .39449 m
.84035 .39392 L
s
.83997 .39449 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23499 .41613 m
.23612 .40909 L
s
1 .005 0 r
.01 w
.23128 .39403 Mdot
1 .006 0 r
[ .05 .05 ] 0 setdash
.2297 .39246 m
.23128 .39403 L
s
1 .729 0 r
.84035 .39392 m
.84066 .39347 L
s
.84035 .39392 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24441 .41846 m
.24506 .42043 L
s
0 0 0 r
.004 w
.19835 .39373 Mdot
.53 .8 .95 r
.006 w
.2589 .48394 m
.25921 .4867 L
s
.81489 .50009 m
.81633 .49622 L
s
1 .729 0 r
.01 w
[ .05 .05 ] 0 setdash
.84066 .39347 m
.84092 .3931 L
s
.84066 .39347 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.84194 .4039 m
.84092 .3931 L
s
1 .728 0 r
.01 w
[ .05 .05 ] 0 setdash
.84092 .3931 m
.84113 .39282 L
s
.84092 .3931 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.81633 .49622 m
.81781 .49283 L
s
.24506 .42043 m
.2458 .42243 L
s
0 0 0 r
.004 w
.85085 .39283 Mdot
1 .727 0 r
.01 w
[ .05 .05 ] 0 setdash
.84113 .39282 m
.8413 .39259 L
s
.84113 .39282 Mdot
.8413 .39259 m
.84141 .3924 L
s
.8413 .39259 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25893 .48087 m
.2589 .48394 L
s
1 .006 0 r
.01 w
.2297 .39246 Mdot
[ .05 .05 ] 0 setdash
.22821 .39091 m
.2297 .39246 L
s
1 .726 0 r
.84141 .3924 m
.84149 .39223 L
s
.84141 .3924 Mdot
1 .725 0 r
.84149 .39223 m
.84153 .39207 L
s
.84149 .39223 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2458 .42243 m
.24652 .42482 L
s
.81781 .49283 m
.81937 .48975 L
s
1 .725 0 r
.01 w
[ .05 .05 ] 0 setdash
.84153 .39207 m
.8415 .39192 L
s
.84153 .39207 Mdot
1 .706 0 r
.84115 .39198 m
.84129 .39195 L
s
.84115 .39198 Mdot
1 .707 0 r
.84109 .39194 m
.84115 .39198 L
s
1 .706 0 r
.84129 .39195 m
.8415 .39186 L
s
.84129 .39195 Mdot
1 .707 0 r
.84109 .39194 Mdot
1 .708 0 r
.8411 .39189 m
.84109 .39194 L
s
1 .724 0 r
.8415 .39192 m
.84144 .39176 L
s
.8415 .39192 Mdot
1 .708 0 r
.8411 .39189 Mdot
.84114 .39185 m
.8411 .39189 L
s
1 .705 0 r
.8415 .39186 m
.84182 .39165 L
s
.8415 .39186 Mdot
1 .708 0 r
.84114 .39185 Mdot
1 .709 0 r
.84119 .39181 m
.84114 .39185 L
s
.84119 .39181 Mdot
.84122 .39178 m
.84119 .39181 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.8413 .39255 m
.84122 .39178 L
s
1 .709 0 r
.01 w
.84122 .39178 Mdot
1 .71 0 r
[ .05 .05 ] 0 setdash
.84122 .39175 m
.84122 .39178 L
s
1 .724 0 r
.84144 .39176 m
.84136 .39157 L
s
.84144 .39176 Mdot
1 .71 0 r
.84122 .39175 Mdot
1 .711 0 r
.84119 .39173 m
.84122 .39175 L
s
.84119 .39173 Mdot
.84114 .39168 m
.84119 .39173 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84123 .39185 m
.8413 .39255 L
s
.84123 .39207 m
.84123 .39185 L
s
1 .711 0 r
.01 w
.84114 .39168 Mdot
1 .712 0 r
[ .05 .05 ] 0 setdash
.84108 .3916 m
.84114 .39168 L
s
1 .705 0 r
.84182 .39165 m
.84211 .39138 L
s
.84182 .39165 Mdot
1 .712 0 r
.84108 .3916 Mdot
1 .713 0 r
.841 .39147 m
.84108 .3916 L
s
1 .723 0 r
.84136 .39157 m
.84126 .39133 L
s
.84136 .39157 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84128 .39307 m
.84123 .39207 L
s
1 .713 0 r
.01 w
.841 .39147 Mdot
[ .05 .05 ] 0 setdash
.84091 .39129 m
.841 .39147 L
s
1 .704 0 r
.84211 .39138 m
.84249 .39094 L
s
.84211 .39138 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8413 .39255 m
.8413 .39298 L
s
.2588 .47831 m
.25893 .48087 L
s
1 .722 0 r
.01 w
[ .05 .05 ] 0 setdash
.84126 .39133 m
.84113 .39106 L
s
.84126 .39133 Mdot
1 .713 0 r
.84091 .39129 Mdot
1 .714 0 r
.84079 .39107 m
.84091 .39129 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8413 .39298 m
.8413 .39353 L
s
.24652 .42482 m
.24738 .42669 L
s
.84131 .39361 m
.8416 .39521 L
s
.84125 .39361 m
.84131 .39361 L
s
1 .714 0 r
.01 w
.84079 .39107 Mdot
[ .05 .05 ] 0 setdash
.8407 .39087 m
.84079 .39107 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.84219 .40218 m
.84113 .39106 L
s
1 .722 0 r
.01 w
[ .05 .05 ] 0 setdash
.84113 .39106 m
.84099 .39078 L
s
.84113 .39106 Mdot
0 0 0 r
.004 w
.85178 .39105 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8413 .39397 m
.84125 .39361 L
s
.81937 .48975 m
.82062 .48623 L
s
.8413 .39353 m
.8413 .39397 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.84418 .40866 m
.84249 .39094 L
s
1 .703 0 r
.01 w
[ .05 .05 ] 0 setdash
.84249 .39094 m
.84289 .39034 L
s
.84249 .39094 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84136 .39456 m
.84128 .39307 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.22249 .45555 m
.22821 .39091 L
s
1 .006 0 r
.01 w
.22821 .39091 Mdot
1 .007 0 r
[ .05 .05 ] 0 setdash
.22662 .3892 m
.22821 .39091 L
s
1 .714 0 r
.8407 .39087 Mdot
1 .715 0 r
.84059 .39066 m
.8407 .39087 L
s
1 .721 0 r
.84099 .39078 m
.84084 .39052 L
s
.84099 .39078 Mdot
1 .715 0 r
.84059 .39066 Mdot
1 .716 0 r
.84046 .39045 m
.84059 .39066 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24738 .42669 m
.24823 .42882 L
s
1 .721 0 r
.01 w
[ .05 .05 ] 0 setdash
.84084 .39052 m
.84066 .39031 L
s
.84084 .39052 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.84122 .39852 m
.84046 .39045 L
s
1 .716 0 r
.01 w
.84046 .39045 Mdot
[ .05 .05 ] 0 setdash
.84035 .39028 m
.84046 .39045 L
s
1 .703 0 r
.84289 .39034 m
.84327 .38956 L
s
.84289 .39034 Mdot
1 .72 0 r
.84066 .39031 m
.84049 .39014 L
s
.84066 .39031 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82062 .48623 m
.82202 .4834 L
s
1 .716 0 r
.01 w
.84035 .39028 Mdot
1 .717 0 r
[ .05 .05 ] 0 setdash
.84026 .39015 m
.84035 .39028 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8416 .39521 m
.84203 .39744 L
s
.25848 .4754 m
.2588 .47831 L
s
1 .717 0 r
.01 w
.84026 .39015 Mdot
[ .05 .05 ] 0 setdash
.84022 .39006 m
.84026 .39015 L
s
1 .719 0 r
.84049 .39014 m
.84035 .39004 L
s
.84049 .39014 Mdot
1 .717 0 r
.84022 .39006 Mdot
1 .718 0 r
.84026 .39002 m
.84022 .39006 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84187 .39627 m
.84191 .39611 L
s
.84185 .39696 m
.84187 .39627 L
s
1 .719 0 r
.01 w
[ .05 .05 ] 0 setdash
.84035 .39004 m
.84026 .39002 L
s
.84035 .39004 Mdot
1 .718 0 r
.84026 .39002 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84145 .39622 m
.84136 .39456 L
s
.24823 .42882 m
.24914 .43056 L
s
.84185 .39849 m
.84185 .39696 L
s
.84191 .39611 m
.842 .39718 L
s
0 0 0 r
.004 w
.19633 .38985 Mdot
.53 .8 .95 r
.006 w
.24914 .43056 m
.25006 .43248 L
s
.23356 .42402 m
.23499 .41613 L
s
.25006 .43248 m
.25092 .43519 L
s
1 .702 0 r
.01 w
[ .05 .05 ] 0 setdash
.84327 .38956 m
.8437 .38857 L
s
.84327 .38956 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84189 .40079 m
.84185 .39849 L
s
0 0 0 r
.004 w
.85269 .38925 Mdot
.53 .8 .95 r
.006 w
.82202 .4834 m
.82343 .48094 L
s
1 .007 0 r
.01 w
.22662 .3892 Mdot
[ .05 .05 ] 0 setdash
.22509 .38748 m
.22662 .3892 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25092 .43519 m
.25173 .439 L
s
.84041 .3916 m
.84052 .39318 L
s
.8407 .39376 m
.84041 .3916 L
s
.25797 .47257 m
.25848 .4754 L
s
.842 .39718 m
.84208 .39851 L
s
.84152 .39774 m
.84145 .39622 L
s
.84203 .39744 m
.84262 .40017 L
s
1 .701 0 r
.01 w
[ .05 .05 ] 0 setdash
.8437 .38857 m
.84411 .38735 L
s
.8437 .38857 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84194 .4039 m
.84189 .40079 L
s
.25173 .439 m
.25251 .443 L
s
.84052 .39318 m
.84076 .39546 L
s
.84208 .39851 m
.84217 .40012 L
s
.25744 .47016 m
.25797 .47257 L
s
.84111 .39663 m
.8407 .39376 L
s
.82343 .48094 m
.82497 .47946 L
s
.84153 .39889 m
.84152 .39774 L
s
.25251 .443 m
.25323 .44793 L
s
1 .007 0 r
.01 w
.22509 .38748 Mdot
1 .008 0 r
[ .05 .05 ] 0 setdash
.22352 .38564 m
.22509 .38748 L
s
0 0 0 r
.004 w
.85359 .38741 Mdot
1 .701 0 r
.01 w
.84411 .38735 m
.84453 .38593 L
s
.84411 .38735 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.842 .40766 m
.84194 .4039 L
s
.84076 .39546 m
.84101 .39728 L
s
.84262 .40017 m
.84331 .40403 L
s
.84217 .40012 m
.84221 .4014 L
s
.2568 .46804 m
.25744 .47016 L
s
.84152 .39958 m
.84153 .39889 L
s
.8415 .39914 m
.84111 .39663 L
s
.25323 .44793 m
.25397 .45249 L
s
.84101 .39728 m
.84122 .39852 L
s
.82497 .47946 m
.82641 .47762 L
s
.84142 .39949 m
.84152 .39958 L
s
0 0 0 r
.004 w
.19454 .38617 Mdot
.53 .8 .95 r
.006 w
.84122 .39852 m
.84142 .39949 L
s
.25397 .45249 m
.25473 .45713 L
s
1 .7 0 r
.01 w
[ .05 .05 ] 0 setdash
.84453 .38593 m
.84492 .38431 L
s
.84453 .38593 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84221 .4014 m
.84219 .40218 L
s
.25608 .46464 m
.2568 .46804 L
s
.84206 .41202 m
.842 .40766 L
s
1 .008 0 r
.01 w
.22352 .38564 Mdot
1 .009 0 r
[ .05 .05 ] 0 setdash
.22223 .38397 m
.22352 .38564 L
s
0 0 0 r
.004 w
.85447 .38555 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84183 .40108 m
.8415 .39914 L
s
.25473 .45713 m
.25538 .46105 L
s
.25538 .46105 m
.25608 .46464 L
s
.84219 .40218 m
.84205 .40193 L
s
.84205 .40193 m
.84183 .40108 L
s
.82641 .47762 m
.82802 .47678 L
s
.84331 .40403 m
.84418 .40866 L
s
.23191 .43185 m
.23356 .42402 L
s
1 .7 0 r
.01 w
[ .05 .05 ] 0 setdash
.84492 .38431 m
.84522 .38244 L
s
.84492 .38431 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84206 .41671 m
.84206 .41202 L
s
1 .009 0 r
.01 w
.22223 .38397 Mdot
[ .05 .05 ] 0 setdash
.22072 .38204 m
.22223 .38397 L
s
0 0 0 r
.004 w
.85533 .38366 Mdot
.19294 .38266 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82802 .47678 m
.82964 .47652 L
s
.84205 .42231 m
.84206 .41671 L
s
1 .699 0 r
.01 w
[ .05 .05 ] 0 setdash
.84522 .38244 m
.84555 .38059 L
s
.84522 .38244 Mdot
1 .009 0 r
.22072 .38204 Mdot
1 .01 0 r
.21952 .38034 m
.22072 .38204 L
s
0 0 0 r
.004 w
.85618 .38174 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84418 .40866 m
.84516 .41418 L
s
.84197 .42865 m
.84205 .42231 L
s
1 .698 0 r
.01 w
[ .05 .05 ] 0 setdash
.84555 .38059 m
.84573 .37852 L
s
.84555 .38059 Mdot
1 .01 0 r
.21952 .38034 Mdot
.21822 .37851 m
.21952 .38034 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82964 .47652 m
.83119 .47583 L
s
0 0 0 r
.004 w
.857 .37978 Mdot
.19151 .37929 Mdot
.53 .8 .95 r
.006 w
.23011 .43853 m
.23191 .43185 L
s
.84172 .43466 m
.84197 .42865 L
s
1 .698 0 r
.01 w
[ .05 .05 ] 0 setdash
.84573 .37852 m
.84577 .37635 L
s
.84573 .37852 Mdot
1 .01 0 r
.21822 .37851 Mdot
1 .011 0 r
.21706 .37673 m
.21822 .37851 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83119 .47583 m
.83278 .47419 L
s
0 0 0 r
.004 w
.85781 .3778 Mdot
.53 .8 .95 r
.006 w
.84516 .41418 m
.84628 .42109 L
s
.84137 .44108 m
.84172 .43466 L
s
1 .011 0 r
.01 w
.21706 .37673 Mdot
1 .012 0 r
[ .05 .05 ] 0 setdash
.21598 .37497 m
.21706 .37673 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.853 .45126 m
.84577 .37635 L
s
1 .697 0 r
.01 w
[ .05 .05 ] 0 setdash
.84577 .37635 m
.84579 .37426 L
s
.84577 .37635 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83278 .47419 m
.8342 .47196 L
s
0 0 0 r
.004 w
.19023 .37605 Mdot
.8586 .37577 Mdot
.53 .8 .95 r
.006 w
.84075 .44674 m
.84137 .44108 L
s
1 .012 0 r
.01 w
.21598 .37497 Mdot
[ .05 .05 ] 0 setdash
.21496 .37313 m
.21598 .37497 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8342 .47196 m
.8356 .46965 L
s
1 .696 0 r
.01 w
[ .05 .05 ] 0 setdash
.84579 .37426 m
.84565 .37211 L
s
.84579 .37426 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84006 .45245 m
.84075 .44674 L
s
.22821 .44507 m
.23011 .43853 L
s
0 0 0 r
.004 w
.85936 .37371 Mdot
.53 .8 .95 r
.006 w
.8356 .46965 m
.83689 .46601 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.209 .43726 m
.21496 .37313 L
s
1 .012 0 r
.01 w
.21496 .37313 Mdot
1 .013 0 r
[ .05 .05 ] 0 setdash
.21396 .37123 m
.21496 .37313 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83907 .45729 m
.84006 .45245 L
s
0 0 0 r
.004 w
.18907 .37292 Mdot
.53 .8 .95 r
.006 w
.83689 .46601 m
.83798 .46149 L
s
.83798 .46149 m
.83907 .45729 L
s
.84628 .42109 m
.84746 .42791 L
s
1 .696 0 r
.01 w
[ .05 .05 ] 0 setdash
.84565 .37211 m
.84545 .37002 L
s
.84565 .37211 Mdot
0 0 0 r
.004 w
.86011 .37161 Mdot
1 .013 0 r
.01 w
.21396 .37123 Mdot
1 .014 0 r
.21299 .36925 m
.21396 .37123 L
s
1 .695 0 r
.84545 .37002 m
.84523 .36806 L
s
.84545 .37002 Mdot
0 0 0 r
.004 w
.18803 .36989 Mdot
.86083 .36947 Mdot
1 .014 0 r
.01 w
.21299 .36925 Mdot
.21217 .36732 m
.21299 .36925 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22635 .45038 m
.22821 .44507 L
s
1 .695 0 r
.01 w
[ .05 .05 ] 0 setdash
.84523 .36806 m
.84496 .36625 L
s
.84523 .36806 Mdot
1 .014 0 r
.21217 .36732 Mdot
1 .015 0 r
.21134 .36527 m
.21217 .36732 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84746 .42791 m
.84856 .43394 L
s
0 0 0 r
.004 w
.86152 .36729 Mdot
.18709 .36694 Mdot
1 .694 0 r
.01 w
[ .05 .05 ] 0 setdash
.84496 .36625 m
.84474 .36466 L
s
.84496 .36625 Mdot
1 .015 0 r
.21134 .36527 Mdot
.2105 .36315 m
.21134 .36527 L
s
0 0 0 r
.004 w
.86219 .36507 Mdot
1 .693 0 r
.01 w
.84474 .36466 m
.84444 .36315 L
s
.84474 .36466 Mdot
0 0 0 r
.004 w
.18625 .36408 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22433 .4535 m
.22635 .45038 L
s
1 .693 0 r
.01 w
[ .05 .05 ] 0 setdash
.84444 .36315 m
.84422 .36196 L
s
.84444 .36315 Mdot
1 .015 0 r
.2105 .36315 Mdot
1 .016 0 r
.20995 .36126 m
.2105 .36315 L
s
0 0 0 r
.004 w
.86283 .3628 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84856 .43394 m
.84966 .4395 L
s
1 .692 0 r
.01 w
[ .05 .05 ] 0 setdash
.84422 .36196 m
.84395 .36083 L
s
.84422 .36196 Mdot
0 0 0 r
.004 w
.18549 .36129 Mdot
1 .016 0 r
.01 w
.20995 .36126 Mdot
1 .017 0 r
.20922 .35898 m
.20995 .36126 L
s
1 .692 0 r
.84395 .36083 m
.84372 .35988 L
s
.84395 .36083 Mdot
0 0 0 r
.004 w
.86344 .36047 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.84656 .38933 m
.84372 .35988 L
s
1 .691 0 r
.01 w
[ .05 .05 ] 0 setdash
.84372 .35988 m
.84347 .359 L
s
.84372 .35988 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22249 .45555 m
.22433 .4535 L
s
1 .69 0 r
.01 w
[ .05 .05 ] 0 setdash
.84347 .359 m
.84321 .35817 L
s
.84347 .359 Mdot
1 .017 0 r
.20922 .35898 Mdot
.2087 .35687 m
.20922 .35898 L
s
0 0 0 r
.004 w
.18481 .35857 Mdot
1 .69 0 r
.01 w
.84321 .35817 m
.84295 .3574 L
s
.84321 .35817 Mdot
0 0 0 r
.004 w
.86402 .3581 Mdot
1 .689 0 r
.01 w
.84295 .3574 m
.84271 .35666 L
s
.84295 .3574 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84966 .4395 m
.85062 .44372 L
s
1 .017 0 r
.01 w
.2087 .35687 Mdot
1 .018 0 r
[ .05 .05 ] 0 setdash
.20829 .35482 m
.2087 .35687 L
s
1 .688 0 r
.84271 .35666 m
.84249 .35585 L
s
.84271 .35666 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22064 .45631 m
.22249 .45555 L
s
0 0 0 r
.004 w
.18421 .35591 Mdot
1 .688 0 r
.01 w
[ .05 .05 ] 0 setdash
.84249 .35585 m
.84226 .35491 L
s
.84249 .35585 Mdot
0 0 0 r
.004 w
.86456 .35567 Mdot
1 .687 0 r
.01 w
.84226 .35491 m
.84205 .35383 L
s
.84226 .35491 Mdot
1 .018 0 r
.20829 .35482 Mdot
1 .019 0 r
.20787 .35254 m
.20829 .35482 L
s
1 .687 0 r
.84205 .35383 m
.84184 .35258 L
s
.84205 .35383 Mdot
0 0 0 r
.004 w
.18367 .3533 Mdot
.86507 .35318 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21908 .45464 m
.22064 .45631 L
s
1 .686 0 r
.01 w
[ .05 .05 ] 0 setdash
.84184 .35258 m
.84153 .35108 L
s
.84184 .35258 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.20093 .42508 m
.20787 .35254 L
s
1 .019 0 r
.01 w
.20787 .35254 Mdot
[ .05 .05 ] 0 setdash
.20755 .35031 m
.20787 .35254 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.85062 .44372 m
.85141 .44684 L
s
.21752 .45224 m
.21908 .45464 L
s
1 .685 0 r
.01 w
[ .05 .05 ] 0 setdash
.84153 .35108 m
.84127 .34943 L
s
.84153 .35108 Mdot
0 0 0 r
.004 w
.1832 .35075 Mdot
.86554 .35063 Mdot
1 .019 0 r
.01 w
.20755 .35031 Mdot
1 .02 0 r
.20729 .34806 m
.20755 .35031 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21639 .44844 m
.21752 .45224 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.84721 .41136 m
.84127 .34943 L
s
1 .685 0 r
.01 w
[ .05 .05 ] 0 setdash
.84127 .34943 m
.8409 .34754 L
s
.84127 .34943 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21501 .4448 m
.21639 .44844 L
s
0 0 0 r
.004 w
.18278 .34825 Mdot
1 .02 0 r
.01 w
.20729 .34806 Mdot
[ .05 .05 ] 0 setdash
.20705 .3458 m
.20729 .34806 L
s
0 0 0 r
.004 w
.86597 .34801 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21384 .44247 m
.21501 .4448 L
s
1 .684 0 r
.01 w
[ .05 .05 ] 0 setdash
.8409 .34754 m
.84057 .34557 L
s
.8409 .34754 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.85141 .44684 m
.85217 .44936 L
s
.2126 .43967 m
.21384 .44247 L
s
1 .02 0 r
.01 w
.20705 .3458 Mdot
1 .021 0 r
[ .05 .05 ] 0 setdash
.20687 .34348 m
.20705 .3458 L
s
0 0 0 r
.004 w
.18243 .34579 Mdot
1 .684 0 r
.01 w
.84057 .34557 m
.84017 .34332 L
s
.84057 .34557 Mdot
0 0 0 r
.004 w
.86636 .34532 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21141 .43802 m
.2126 .43967 L
s
.84551 .38206 m
.8452 .38076 L
s
.84598 .38507 m
.84551 .38206 L
s
.84656 .38933 m
.84598 .38507 L
s
.8452 .38076 m
.84512 .38167 L
s
.84723 .39484 m
.84656 .38933 L
s
1 .021 0 r
.01 w
.20687 .34348 Mdot
1 .022 0 r
[ .05 .05 ] 0 setdash
.20658 .34109 m
.20687 .34348 L
s
0 0 0 r
.004 w
.18212 .34338 Mdot
1 .683 0 r
.01 w
.84017 .34332 m
.83983 .34119 L
s
.84017 .34332 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21024 .43694 m
.21141 .43802 L
s
.85217 .44936 m
.85272 .45098 L
s
.84512 .38167 m
.84527 .38481 L
s
0 0 0 r
.004 w
.86669 .34255 Mdot
.53 .8 .95 r
.006 w
.84804 .40155 m
.84723 .39484 L
s
1 .682 0 r
.01 w
[ .05 .05 ] 0 setdash
.83983 .34119 m
.83953 .33879 L
s
.83983 .34119 Mdot
1 .022 0 r
.20658 .34109 Mdot
.20634 .33877 m
.20658 .34109 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.209 .43726 m
.21024 .43694 L
s
0 0 0 r
.004 w
.18187 .34101 Mdot
.53 .8 .95 r
.006 w
.84889 .40933 m
.84804 .40155 L
s
.84527 .38481 m
.84553 .38892 L
s
0 0 0 r
.004 w
.86698 .33969 Mdot
.53 .8 .95 r
.006 w
.85272 .45098 m
.853 .45126 L
s
1 .682 0 r
.01 w
[ .05 .05 ] 0 setdash
.83953 .33879 m
.83901 .33615 L
s
.83953 .33879 Mdot
1 .022 0 r
.20634 .33877 Mdot
1 .023 0 r
.20617 .33662 m
.20634 .33877 L
s
0 0 0 r
.004 w
.18166 .33868 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20778 .43739 m
.209 .43726 L
s
.84981 .41719 m
.84889 .40933 L
s
0 0 0 r
.004 w
.8672 .33674 Mdot
1 .023 0 r
.01 w
.20617 .33662 Mdot
[ .05 .05 ] 0 setdash
.2058 .33414 m
.20617 .33662 L
s
0 0 0 r
.004 w
.1815 .33638 Mdot
1 .681 0 r
.01 w
.83901 .33615 m
.83863 .33378 L
s
.83901 .33615 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84553 .38892 m
.84597 .3947 L
s
.85069 .42553 m
.84981 .41719 L
s
.853 .45126 m
.85304 .4494 L
s
.20664 .437 m
.20778 .43739 L
s
1 .023 0 r
.01 w
.2058 .33414 Mdot
1 .024 0 r
[ .05 .05 ] 0 setdash
.20554 .33181 m
.2058 .33414 L
s
0 0 0 r
.004 w
.18138 .33412 Mdot
1 .68 0 r
.01 w
.83863 .33378 m
.83823 .33113 L
s
.83863 .33378 Mdot
0 0 0 r
.004 w
.86736 .33369 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.85161 .43418 m
.85069 .42553 L
s
.85304 .4494 m
.8528 .44613 L
s
.20561 .43721 m
.20664 .437 L
s
0 0 0 r
.004 w
.1813 .33189 Mdot
1 .024 0 r
.01 w
.20554 .33181 Mdot
1 .025 0 r
[ .05 .05 ] 0 setdash
.20537 .32956 m
.20554 .33181 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.85232 .44114 m
.85161 .43418 L
s
.8528 .44613 m
.85232 .44114 L
s
1 .68 0 r
.01 w
[ .05 .05 ] 0 setdash
.83823 .33113 m
.8377 .32847 L
s
.83823 .33113 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84597 .3947 m
.84644 .4005 L
s
0 0 0 r
.004 w
.86745 .33053 Mdot
.18126 .3297 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.19791 .40635 m
.20537 .32956 L
s
1 .025 0 r
.01 w
.20537 .32956 Mdot
[ .05 .05 ] 0 setdash
.205 .32712 m
.20537 .32956 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20468 .43584 m
.20561 .43721 L
s
1 .679 0 r
.01 w
[ .05 .05 ] 0 setdash
.8377 .32847 m
.83713 .32564 L
s
.8377 .32847 Mdot
0 0 0 r
.004 w
.18126 .32753 Mdot
.86746 .32724 Mdot
1 .025 0 r
.01 w
.205 .32712 Mdot
1 .026 0 r
.20476 .32483 m
.205 .32712 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20373 .43476 m
.20468 .43584 L
s
.84644 .4005 m
.84682 .40619 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.84574 .41591 m
.83713 .32564 L
s
1 .679 0 r
.01 w
[ .05 .05 ] 0 setdash
.83713 .32564 m
.83664 .32309 L
s
.83713 .32564 Mdot
0 0 0 r
.004 w
.1813 .32539 Mdot
1 .026 0 r
.01 w
.20476 .32483 Mdot
1 .027 0 r
.20452 .32261 m
.20476 .32483 L
s
0 0 0 r
.004 w
.86738 .32381 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20312 .43331 m
.20373 .43476 L
s
0 0 0 r
.004 w
.18137 .32329 Mdot
1 .678 0 r
.01 w
[ .05 .05 ] 0 setdash
.83664 .32309 m
.83606 .32041 L
s
.83664 .32309 Mdot
1 .027 0 r
.20452 .32261 Mdot
.20436 .32034 m
.20452 .32261 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20246 .4301 m
.20312 .43331 L
s
0 0 0 r
.004 w
.18147 .3212 Mdot
1 .677 0 r
.01 w
[ .05 .05 ] 0 setdash
.83606 .32041 m
.83536 .31756 L
s
.83606 .32041 Mdot
1 .027 0 r
.20436 .32034 Mdot
1 .028 0 r
.20431 .31829 m
.20436 .32034 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84682 .40619 m
.84721 .41136 L
s
0 0 0 r
.004 w
.86719 .32022 Mdot
.53 .8 .95 r
.006 w
.20192 .42799 m
.20246 .4301 L
s
0 0 0 r
.004 w
.1816 .31915 Mdot
1 .028 0 r
.01 w
.20431 .31829 Mdot
[ .05 .05 ] 0 setdash
.20394 .3159 m
.20431 .31829 L
s
1 .677 0 r
.83536 .31756 m
.83478 .31515 L
s
.83536 .31756 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20145 .42638 m
.20192 .42799 L
s
0 0 0 r
.004 w
.18177 .31711 Mdot
.86689 .31645 Mdot
1 .028 0 r
.01 w
.20394 .3159 Mdot
1 .029 0 r
[ .05 .05 ] 0 setdash
.2038 .31367 m
.20394 .3159 L
s
1 .676 0 r
.83478 .31515 m
.83413 .31258 L
s
.83478 .31515 Mdot
0 0 0 r
.004 w
.18197 .3151 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20093 .42508 m
.20145 .42638 L
s
.84721 .41136 m
.84737 .415 L
s
1 .029 0 r
.01 w
.2038 .31367 Mdot
1 .03 0 r
[ .05 .05 ] 0 setdash
.20366 .31147 m
.2038 .31367 L
s
0 0 0 r
.004 w
.18219 .31312 Mdot
1 .676 0 r
.01 w
.83413 .31258 m
.8335 .30999 L
s
.83413 .31258 Mdot
0 0 0 r
.004 w
.86645 .31246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20051 .42372 m
.20093 .42508 L
s
1 .03 0 r
.01 w
.20366 .31147 Mdot
[ .05 .05 ] 0 setdash
.20345 .30912 m
.20366 .31147 L
s
0 0 0 r
.004 w
.18245 .31115 Mdot
1 .675 0 r
.01 w
.8335 .30999 m
.83278 .30743 L
s
.8335 .30999 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84737 .415 m
.8474 .41686 L
s
.20017 .42223 m
.20051 .42372 L
s
0 0 0 r
.004 w
.18273 .30921 Mdot
1 .03 0 r
.01 w
.20345 .30912 Mdot
1 .031 0 r
[ .05 .05 ] 0 setdash
.20335 .30677 m
.20345 .30912 L
s
0 0 0 r
.004 w
.86584 .30822 Mdot
1 .674 0 r
.01 w
.83278 .30743 m
.83211 .30486 L
s
.83278 .30743 Mdot
0 0 0 r
.004 w
.18303 .30729 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.19584 .3831 m
.20335 .30677 L
s
1 .031 0 r
.01 w
.20335 .30677 Mdot
[ .05 .05 ] 0 setdash
.20324 .30443 m
.20335 .30677 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19975 .42178 m
.20017 .42223 L
s
.8474 .41686 m
.84736 .41838 L
s
0 0 0 r
.004 w
.18337 .30539 Mdot
1 .674 0 r
.01 w
[ .05 .05 ] 0 setdash
.83211 .30486 m
.83141 .30236 L
s
.83211 .30486 Mdot
1 .031 0 r
.20324 .30443 Mdot
1 .032 0 r
.20306 .30219 m
.20324 .30443 L
s
0 0 0 r
.004 w
.86503 .30367 Mdot
.18373 .3035 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19945 .42046 m
.19975 .42178 L
s
1 .673 0 r
.01 w
[ .05 .05 ] 0 setdash
.83141 .30236 m
.83081 .30004 L
s
.83141 .30236 Mdot
1 .032 0 r
.20306 .30219 Mdot
1 .033 0 r
.20304 .29997 m
.20306 .30219 L
s
0 0 0 r
.004 w
.18411 .30164 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84736 .41838 m
.84736 .41987 L
s
.19909 .41881 m
.19945 .42046 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.83798 .37613 m
.83081 .30004 L
s
1 .672 0 r
.01 w
[ .05 .05 ] 0 setdash
.83081 .30004 m
.83021 .29781 L
s
.83081 .30004 Mdot
1 .033 0 r
.20304 .29997 Mdot
.20294 .29791 m
.20304 .29997 L
s
0 0 0 r
.004 w
.18452 .29979 Mdot
.86396 .29873 Mdot
.18495 .29796 Mdot
1 .033 0 r
.01 w
.20294 .29791 Mdot
1 .034 0 r
.2029 .29606 m
.20294 .29791 L
s
1 .672 0 r
.83021 .29781 m
.82965 .2957 L
s
.83021 .29781 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19877 .41714 m
.19909 .41881 L
s
.84736 .41987 m
.8474 .42105 L
s
0 0 0 r
.004 w
.1854 .29615 Mdot
1 .034 0 r
.01 w
.2029 .29606 Mdot
1 .035 0 r
[ .05 .05 ] 0 setdash
.20284 .29436 m
.2029 .29606 L
s
1 .671 0 r
.82965 .2957 m
.82918 .29383 L
s
.82965 .2957 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19852 .4158 m
.19877 .41714 L
s
1 .035 0 r
.01 w
.20284 .29436 Mdot
[ .05 .05 ] 0 setdash
.20279 .29288 m
.20284 .29436 L
s
0 0 0 r
.004 w
.18587 .29436 Mdot
1 .671 0 r
.01 w
.82918 .29383 m
.82875 .29216 L
s
.82918 .29383 Mdot
0 0 0 r
.004 w
.86255 .29328 Mdot
1 .035 0 r
.01 w
.20279 .29288 Mdot
1 .036 0 r
.2027 .29163 m
.20279 .29288 L
s
0 0 0 r
.004 w
.18637 .29258 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8474 .42105 m
.84722 .42202 L
s
1 .67 0 r
.01 w
[ .05 .05 ] 0 setdash
.82875 .29216 m
.82838 .29068 L
s
.82875 .29216 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19822 .41233 m
.19852 .4158 L
s
1 .036 0 r
.01 w
.2027 .29163 Mdot
[ .05 .05 ] 0 setdash
.20257 .29047 m
.2027 .29163 L
s
0 0 0 r
.004 w
.18689 .29082 Mdot
1 .669 0 r
.01 w
.82838 .29068 m
.82804 .28942 L
s
.82838 .29068 Mdot
1 .036 0 r
.20257 .29047 Mdot
1 .037 0 r
.20241 .28948 m
.20257 .29047 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.198 .40952 m
.19822 .41233 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.19984 .31531 m
.20241 .28948 L
s
1 .037 0 r
.01 w
.20241 .28948 Mdot
1 .038 0 r
[ .05 .05 ] 0 setdash
.20225 .28862 m
.20241 .28948 L
s
1 .669 0 r
.82804 .28942 m
.82779 .28845 L
s
.82804 .28942 Mdot
0 0 0 r
.004 w
.18742 .28907 Mdot
1 .038 0 r
.01 w
.20225 .28862 Mdot
.20211 .28787 m
.20225 .28862 L
s
1 .668 0 r
.82779 .28845 m
.82759 .28771 L
s
.82779 .28845 Mdot
1 .038 0 r
.20211 .28787 Mdot
1 .039 0 r
.20197 .28717 m
.20211 .28787 L
s
1 .661 0 r
.82722 .28774 m
.82722 .28773 L
s
.82722 .28774 Mdot
.82722 .2877 m
.82722 .28774 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19791 .40635 m
.198 .40952 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.82734 .28903 m
.82722 .28773 L
s
1 .66 0 r
.01 w
[ .05 .05 ] 0 setdash
.82722 .28773 m
.82722 .28769 L
s
.82722 .28773 Mdot
1 .667 0 r
.82759 .28771 m
.82742 .2872 L
s
.82759 .28771 Mdot
1 .661 0 r
.82722 .2877 Mdot
1 .662 0 r
.82721 .2876 m
.82722 .2877 L
s
1 .659 0 r
.82722 .28769 m
.82722 .28764 L
s
.82722 .28769 Mdot
.82722 .28764 m
.82721 .28758 L
s
.82722 .28764 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82723 .28782 m
.8273 .28865 L
s
.82739 .28955 m
.82723 .28782 L
s
.84722 .42202 m
.84703 .42166 L
s
1 .662 0 r
.01 w
.82721 .2876 Mdot
1 .663 0 r
[ .05 .05 ] 0 setdash
.8272 .28747 m
.82721 .2876 L
s
1 .658 0 r
.82721 .28758 m
.82719 .28752 L
s
.82721 .28758 Mdot
.82719 .28752 m
.82715 .28747 L
s
.82719 .28752 Mdot
1 .657 0 r
.82715 .28747 m
.8271 .28742 L
s
.82715 .28747 Mdot
1 .663 0 r
.8272 .28747 Mdot
.82719 .28729 m
.8272 .28747 L
s
1 .656 0 r
.8271 .28742 m
.82703 .28737 L
s
.8271 .28742 Mdot
.82703 .28737 m
.82697 .28731 L
s
.82703 .28737 Mdot
0 0 0 r
.004 w
.18798 .28734 Mdot
1 .655 0 r
.01 w
.82697 .28731 m
.82691 .28724 L
s
.82697 .28731 Mdot
1 .663 0 r
.82719 .28729 Mdot
1 .664 0 r
.82718 .2871 m
.82719 .28729 L
s
1 .655 0 r
.82691 .28724 m
.82686 .28714 L
s
.82691 .28724 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8273 .28865 m
.82734 .28903 L
s
1 .667 0 r
.01 w
[ .05 .05 ] 0 setdash
.82742 .2872 m
.8273 .28689 L
s
.82742 .2872 Mdot
1 .039 0 r
.20197 .28717 Mdot
.20186 .28649 m
.20197 .28717 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.82724 .2913 m
.82686 .28714 L
s
1 .654 0 r
.01 w
[ .05 .05 ] 0 setdash
.82686 .28714 m
.82679 .28699 L
s
.82686 .28714 Mdot
0 0 0 r
.004 w
.86066 .28711 Mdot
1 .664 0 r
.01 w
.82718 .2871 Mdot
.82718 .28692 m
.82718 .2871 L
s
1 .653 0 r
.82679 .28699 m
.82672 .28678 L
s
.82679 .28699 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82734 .28903 m
.82735 .28909 L
s
1 .664 0 r
.01 w
.82718 .28692 Mdot
1 .665 0 r
[ .05 .05 ] 0 setdash
.8272 .2868 m
.82718 .28692 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.8276 .29007 m
.8273 .28689 L
s
1 .666 0 r
.01 w
[ .05 .05 ] 0 setdash
.8273 .28689 m
.82723 .28677 L
s
.8273 .28689 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82735 .28909 m
.82735 .28908 L
s
1 .665 0 r
.01 w
.8272 .2868 Mdot
1 .666 0 r
[ .05 .05 ] 0 setdash
.82723 .28677 m
.8272 .2868 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82735 .28908 m
.82736 .28915 L
s
1 .653 0 r
.01 w
[ .05 .05 ] 0 setdash
.82672 .28678 m
.82663 .28653 L
s
.82672 .28678 Mdot
1 .666 0 r
.82723 .28677 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82736 .28915 m
.82735 .28928 L
s
1 .652 0 r
.01 w
[ .05 .05 ] 0 setdash
.82663 .28653 m
.82656 .28623 L
s
.82663 .28653 Mdot
1 .039 0 r
.20186 .28649 Mdot
1 .04 0 r
.20173 .28575 m
.20186 .28649 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82735 .28928 m
.82732 .28937 L
s
.82751 .29073 m
.82739 .28955 L
s
.82732 .28937 m
.82728 .28941 L
s
.82728 .28941 m
.82724 .28955 L
s
1 .651 0 r
.01 w
[ .05 .05 ] 0 setdash
.82656 .28623 m
.82649 .2859 L
s
.82656 .28623 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82724 .28955 m
.82721 .28982 L
s
.19766 .40259 m
.19791 .40635 L
s
1 .651 0 r
.01 w
[ .05 .05 ] 0 setdash
.82649 .2859 m
.82643 .28554 L
s
.82649 .2859 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82721 .28982 m
.8272 .29028 L
s
1 .04 0 r
.01 w
.20173 .28575 Mdot
1 .041 0 r
[ .05 .05 ] 0 setdash
.20168 .28499 m
.20173 .28575 L
s
0 0 0 r
.004 w
.18856 .28563 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82765 .29222 m
.82751 .29073 L
s
1 .65 0 r
.01 w
[ .05 .05 ] 0 setdash
.82643 .28554 m
.82639 .28516 L
s
.82643 .28554 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8272 .29028 m
.82724 .2913 L
s
.82745 .28913 m
.82765 .29168 L
s
.8276 .29007 m
.82745 .28913 L
s
1 .65 0 r
.01 w
[ .05 .05 ] 0 setdash
.82639 .28516 m
.82637 .28478 L
s
.82639 .28516 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82833 .29692 m
.8276 .29007 L
s
1 .041 0 r
.01 w
.20168 .28499 Mdot
[ .05 .05 ] 0 setdash
.20166 .2842 m
.20168 .28499 L
s
1 .649 0 r
.82637 .28478 m
.82636 .2844 L
s
.82637 .28478 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82724 .2913 m
.8273 .29245 L
s
1 .648 0 r
.01 w
[ .05 .05 ] 0 setdash
.82636 .2844 m
.82636 .28402 L
s
.82636 .2844 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82775 .29315 m
.82765 .29222 L
s
1 .041 0 r
.01 w
.20166 .2842 Mdot
1 .042 0 r
[ .05 .05 ] 0 setdash
.20164 .28335 m
.20166 .2842 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19758 .39847 m
.19766 .40259 L
s
.84703 .42166 m
.84676 .42049 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.8275 .29624 m
.82636 .28402 L
s
1 .648 0 r
.01 w
[ .05 .05 ] 0 setdash
.82636 .28402 m
.82636 .28366 L
s
.82636 .28402 Mdot
0 0 0 r
.004 w
.18916 .28393 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82765 .29168 m
.82775 .29304 L
s
.8273 .29245 m
.82736 .29371 L
s
1 .647 0 r
.01 w
[ .05 .05 ] 0 setdash
.82636 .28366 m
.82636 .28332 L
s
.82636 .28366 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82775 .29304 m
.82775 .29315 L
s
1 .042 0 r
.01 w
.20164 .28335 Mdot
1 .043 0 r
[ .05 .05 ] 0 setdash
.2016 .28247 m
.20164 .28335 L
s
1 .647 0 r
.82636 .28332 m
.82635 .28302 L
s
.82636 .28332 Mdot
1 .646 0 r
.82635 .28302 m
.82635 .28276 L
s
.82635 .28302 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19751 .39439 m
.19758 .39847 L
s
1 .645 0 r
.01 w
[ .05 .05 ] 0 setdash
.82635 .28276 m
.82635 .28257 L
s
.82635 .28276 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82736 .29371 m
.82742 .29495 L
s
1 .645 0 r
.01 w
[ .05 .05 ] 0 setdash
.82635 .28257 m
.82636 .28244 L
s
.82635 .28257 Mdot
1 .043 0 r
.2016 .28247 Mdot
.20155 .28159 m
.2016 .28247 L
s
1 .644 0 r
.82636 .28244 m
.82637 .28235 L
s
.82636 .28244 Mdot
1 .633 0 r
.8264 .28236 m
.8264 .28236 L
s
.8264 .28236 Mdot
1 .634 0 r
.8264 .28235 m
.8264 .28236 L
s
1 .632 0 r
.8264 .28236 m
.82638 .28234 L
s
.8264 .28236 Mdot
1 .634 0 r
.8264 .28235 Mdot
.82639 .28234 m
.8264 .28235 L
s
1 .643 0 r
.82637 .28235 m
.82638 .2823 L
s
.82637 .28235 Mdot
1 .634 0 r
.82639 .28234 Mdot
1 .635 0 r
.82638 .28233 m
.82639 .28234 L
s
1 .632 0 r
.82638 .28234 m
.82636 .2823 L
s
.82638 .28234 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8264 .28239 m
.82644 .28289 L
s
.82643 .28266 m
.8264 .28239 L
s
1 .635 0 r
.01 w
.82638 .28233 Mdot
[ .05 .05 ] 0 setdash
.82637 .28232 m
.82638 .28233 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.82638 .28242 m
.82637 .28232 L
s
1 .635 0 r
.01 w
.82637 .28232 Mdot
1 .636 0 r
[ .05 .05 ] 0 setdash
.82636 .28231 m
.82637 .28232 L
s
.82636 .28231 Mdot
1 .637 0 r
.82636 .28231 m
.82636 .28231 L
s
.82636 .28231 Mdot
.82636 .2823 m
.82636 .28231 L
s
1 .631 0 r
.82636 .2823 m
.82632 .28225 L
s
.82636 .2823 Mdot
1 .637 0 r
.82636 .2823 Mdot
1 .638 0 r
.82635 .28229 m
.82636 .2823 L
s
1 .643 0 r
.82638 .2823 m
.82639 .28228 L
s
.82638 .2823 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82637 .28233 m
.82638 .28242 L
s
.82637 .28234 m
.82637 .28233 L
s
1 .638 0 r
.01 w
.82635 .28229 Mdot
[ .05 .05 ] 0 setdash
.82635 .28228 m
.82635 .28229 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82637 .28246 m
.82637 .28234 L
s
1 .638 0 r
.01 w
.82635 .28228 Mdot
1 .639 0 r
[ .05 .05 ] 0 setdash
.82637 .28228 m
.82635 .28228 L
s
.82637 .28228 Mdot
1 .64 0 r
.82638 .28227 m
.82637 .28228 L
s
1 .642 0 r
.82639 .28228 m
.8264 .28226 L
s
.82639 .28228 Mdot
1 .64 0 r
.82638 .28227 Mdot
.82639 .28226 m
.82638 .28227 L
s
.82639 .28226 Mdot
1 .641 0 r
.8264 .28226 m
.82639 .28226 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.82642 .28249 m
.8264 .28226 L
s
1 .642 0 r
.01 w
[ .05 .05 ] 0 setdash
.8264 .28226 m
.8264 .28226 L
s
.8264 .28226 Mdot
1 .641 0 r
.8264 .28226 Mdot
1 .63 0 r
.82632 .28225 m
.82627 .28219 L
s
.82632 .28225 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82638 .28242 m
.8264 .28258 L
s
0 0 0 r
.004 w
.18977 .28224 Mdot
.53 .8 .95 r
.006 w
.82637 .28256 m
.82637 .28246 L
s
1 .63 0 r
.01 w
[ .05 .05 ] 0 setdash
.82627 .28219 m
.82621 .28211 L
s
.82627 .28219 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82644 .28278 m
.82643 .28266 L
s
.8264 .28258 m
.82642 .28273 L
s
.82642 .28247 m
.82642 .28255 L
s
.82642 .28249 m
.82642 .28247 L
s
.82639 .28251 m
.82638 .28255 L
s
.82641 .28255 m
.82639 .28251 L
s
.82638 .28255 m
.82637 .28256 L
s
.82643 .28278 m
.82642 .28249 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.8265 .28516 m
.82621 .28211 L
s
1 .629 0 r
.01 w
[ .05 .05 ] 0 setdash
.82621 .28211 m
.82616 .28204 L
s
.82621 .28211 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82642 .28273 m
.82644 .28278 L
s
.82642 .28255 m
.82641 .28255 L
s
1 .626 0 r
.01 w
[ .05 .05 ] 0 setdash
.82609 .28207 m
.82608 .28204 L
s
.82609 .28207 Mdot
.82609 .28206 m
.82609 .28207 L
s
.82609 .28206 Mdot
1 .627 0 r
.8261 .28204 m
.82609 .28206 L
s
1 .629 0 r
.82616 .28204 m
.82612 .28201 L
s
.82616 .28204 Mdot
1 .625 0 r
.82608 .28204 m
.82604 .28194 L
s
.82608 .28204 Mdot
1 .627 0 r
.8261 .28204 Mdot
.8261 .28201 m
.8261 .28204 L
s
.8261 .28201 Mdot
1 .628 0 r
.82612 .28201 m
.8261 .28201 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82644 .28289 m
.82647 .2835 L
s
1 .628 0 r
.01 w
.82612 .28201 Mdot
.53 .8 .95 r
.006 w
.82647 .28326 m
.82643 .28278 L
s
.82611 .28229 m
.82616 .28294 L
s
.82613 .28241 m
.82611 .28229 L
s
1 .624 0 r
.01 w
[ .05 .05 ] 0 setdash
.82604 .28194 m
.82595 .28174 L
s
.82604 .28194 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82617 .28284 m
.82613 .28241 L
s
1 .624 0 r
.01 w
[ .05 .05 ] 0 setdash
.82595 .28174 m
.82578 .28138 L
s
.82595 .28174 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82652 .28402 m
.82647 .28326 L
s
.82647 .2835 m
.82649 .28413 L
s
.19741 .39151 m
.19751 .39439 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.19851 .31201 m
.20155 .28159 L
s
1 .043 0 r
.01 w
.20155 .28159 Mdot
1 .044 0 r
[ .05 .05 ] 0 setdash
.2015 .28072 m
.20155 .28159 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82742 .29495 m
.82747 .29606 L
s
.82627 .28382 m
.82617 .28284 L
s
.82616 .28294 m
.82633 .28503 L
s
.82926 .30555 m
.82833 .29692 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.82691 .29357 m
.82578 .28138 L
s
1 .623 0 r
.01 w
[ .05 .05 ] 0 setdash
.82578 .28138 m
.82547 .28081 L
s
.82578 .28138 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82661 .2852 m
.82652 .28402 L
s
.82649 .28413 m
.82651 .28472 L
s
.82637 .28465 m
.82627 .28382 L
s
1 .622 0 r
.01 w
[ .05 .05 ] 0 setdash
.82547 .28081 m
.82498 .27998 L
s
.82547 .28081 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82675 .28683 m
.82661 .2852 L
s
1 .044 0 r
.01 w
.2015 .28072 Mdot
[ .05 .05 ] 0 setdash
.20148 .27988 m
.2015 .28072 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82651 .28472 m
.8265 .28516 L
s
0 0 0 r
.004 w
.19041 .28057 Mdot
.53 .8 .95 r
.006 w
.82645 .28523 m
.82637 .28465 L
s
.82747 .29606 m
.82751 .29691 L
s
.84676 .42049 m
.84633 .41886 L
s
.8265 .28516 m
.82645 .28523 L
s
.82633 .28503 m
.82658 .28849 L
s
.82688 .28851 m
.82675 .28683 L
s
1 .622 0 r
.01 w
[ .05 .05 ] 0 setdash
.82498 .27998 m
.82432 .27889 L
s
.82498 .27998 Mdot
1 .044 0 r
.20148 .27988 Mdot
1 .045 0 r
.20149 .27916 m
.20148 .27988 L
s
0 0 0 r
.004 w
.85802 .27983 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19737 .38925 m
.19741 .39151 L
s
.82751 .29691 m
.82754 .29746 L
s
.8271 .29106 m
.82688 .28851 L
s
1 .045 0 r
.01 w
.20149 .27916 Mdot
1 .046 0 r
[ .05 .05 ] 0 setdash
.20152 .27856 m
.20149 .27916 L
s
0 0 0 r
.004 w
.19106 .27891 Mdot
1 .621 0 r
.01 w
.82432 .27889 m
.82353 .27765 L
s
.82432 .27889 Mdot
1 .046 0 r
.20152 .27856 Mdot
.20156 .27812 m
.20152 .27856 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82754 .29746 m
.8276 .2981 L
s
1 .052 0 r
.01 w
[ .05 .05 ] 0 setdash
.20229 .27845 m
.20217 .27844 L
s
.20229 .27845 Mdot
1 .053 0 r
.20238 .27838 m
.20229 .27845 L
s
1 .052 0 r
.20217 .27844 m
.20205 .27835 L
s
.20217 .27844 Mdot
1 .053 0 r
.20238 .27838 Mdot
1 .054 0 r
.20244 .27825 m
.20238 .27838 L
s
1 .051 0 r
.20205 .27835 m
.20194 .2782 L
s
.20205 .27835 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82728 .29315 m
.8271 .29106 L
s
1 .054 0 r
.01 w
.20244 .27825 Mdot
[ .05 .05 ] 0 setdash
.20247 .27803 m
.20244 .27825 L
s
1 .051 0 r
.20194 .2782 m
.20186 .27802 L
s
.20194 .2782 Mdot
1 .046 0 r
.20156 .27812 Mdot
1 .047 0 r
.2016 .27781 m
.20156 .27812 L
s
1 .054 0 r
.20247 .27803 Mdot
1 .055 0 r
.20245 .27774 m
.20247 .27803 L
s
1 .05 0 r
.20186 .27802 m
.20179 .27785 L
s
.20186 .27802 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.20117 .2841 m
.20179 .27785 L
s
1 .049 0 r
.01 w
[ .05 .05 ] 0 setdash
.20179 .27785 m
.20174 .2777 L
s
.20179 .27785 Mdot
1 .047 0 r
.2016 .27781 Mdot
1 .048 0 r
.20164 .27766 m
.2016 .27781 L
s
1 .055 0 r
.20245 .27774 Mdot
1 .056 0 r
.20239 .27741 m
.20245 .27774 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82658 .28849 m
.82691 .29357 L
s
1 .049 0 r
.01 w
[ .05 .05 ] 0 setdash
.20174 .2777 m
.20169 .27763 L
s
.20174 .2777 Mdot
1 .048 0 r
.20164 .27766 Mdot
.20169 .27763 m
.20164 .27766 L
s
1 .621 0 r
.82353 .27765 m
.82258 .2762 L
s
.82353 .27765 Mdot
1 .048 0 r
.20169 .27763 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.197 .38664 m
.19737 .38925 L
s
.8276 .2981 m
.82759 .29789 L
s
.82742 .29504 m
.82728 .29315 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.20115 .28984 m
.20239 .27741 L
s
1 .056 0 r
.01 w
.20239 .27741 Mdot
[ .05 .05 ] 0 setdash
.20229 .27702 m
.20239 .27741 L
s
0 0 0 r
.004 w
.19173 .27726 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8303 .31529 m
.82926 .30555 L
s
.20207 .28065 m
.2018 .28214 L
s
.20206 .28168 m
.20207 .28065 L
s
.84633 .41886 m
.84574 .41591 L
s
.82759 .29789 m
.82756 .29726 L
s
1 .056 0 r
.01 w
.20229 .27702 Mdot
1 .057 0 r
[ .05 .05 ] 0 setdash
.20218 .27661 m
.20229 .27702 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8275 .29624 m
.82742 .29504 L
s
.20157 .27889 m
.20138 .28026 L
s
.20134 .28165 m
.20157 .27889 L
s
.82756 .29726 m
.8275 .29624 L
s
1 .057 0 r
.01 w
.20218 .27661 Mdot
[ .05 .05 ] 0 setdash
.20206 .27618 m
.20218 .27661 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20184 .28431 m
.20206 .28168 L
s
.2018 .28214 m
.20152 .28367 L
s
1 .62 0 r
.01 w
[ .05 .05 ] 0 setdash
.82258 .2762 m
.82145 .27454 L
s
.82258 .2762 Mdot
1 .057 0 r
.20206 .27618 Mdot
1 .058 0 r
.20196 .27575 m
.20206 .27618 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20138 .28026 m
.20087 .2851 L
s
.20011 .3079 m
.20006 .31069 L
s
.20003 .30673 m
.20011 .3079 L
s
1 .058 0 r
.01 w
.20196 .27575 Mdot
1 .059 0 r
[ .05 .05 ] 0 setdash
.20188 .27534 m
.20196 .27575 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19981 .30704 m
.20003 .30673 L
s
.20006 .31069 m
.19984 .31531 L
s
0 0 0 r
.004 w
.19242 .27563 Mdot
.53 .8 .95 r
.006 w
.20117 .2841 m
.20134 .28165 L
s
1 .059 0 r
.01 w
.20188 .27534 Mdot
[ .05 .05 ] 0 setdash
.20183 .27493 m
.20188 .27534 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19676 .38537 m
.197 .38664 L
s
.20152 .28367 m
.20131 .28454 L
s
1 .059 0 r
.01 w
.20183 .27493 Mdot
1 .06 0 r
[ .05 .05 ] 0 setdash
.2018 .27456 m
.20183 .27493 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20158 .28692 m
.20184 .28431 L
s
1 .06 0 r
.01 w
.2018 .27456 Mdot
[ .05 .05 ] 0 setdash
.20178 .2742 m
.2018 .27456 L
s
1 .619 0 r
.82145 .27454 m
.82017 .27271 L
s
.82145 .27454 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20131 .28454 m
.20116 .285 L
s
.19952 .30799 m
.19981 .30704 L
s
.19984 .31531 m
.19947 .32169 L
s
1 .06 0 r
.01 w
.20178 .2742 Mdot
1 .061 0 r
[ .05 .05 ] 0 setdash
.20179 .27389 m
.20178 .2742 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84574 .41591 m
.84521 .41307 L
s
.82691 .29357 m
.8273 .30055 L
s
.20116 .285 m
.20117 .2841 L
s
0 0 0 r
.004 w
.19313 .27401 Mdot
1 .061 0 r
.01 w
.20179 .27389 Mdot
1 .062 0 r
[ .05 .05 ] 0 setdash
.20181 .27364 m
.20179 .27389 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.20099 .28188 m
.20181 .27364 L
s
1 .062 0 r
.01 w
.20181 .27364 Mdot
[ .05 .05 ] 0 setdash
.20183 .27344 m
.20181 .27364 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20087 .2851 m
.20041 .28961 L
s
1 .062 0 r
.01 w
.20183 .27344 Mdot
1 .063 0 r
[ .05 .05 ] 0 setdash
.20187 .27328 m
.20183 .27344 L
s
.20187 .27328 Mdot
1 .064 0 r
.20191 .27315 m
.20187 .27328 L
s
.20191 .27315 Mdot
.20195 .27306 m
.20191 .27315 L
s
.20195 .27306 Mdot
1 .065 0 r
.20198 .27298 m
.20195 .27306 L
s
.20198 .27298 Mdot
.20202 .27288 m
.20198 .27298 L
s
.20202 .27288 Mdot
1 .066 0 r
.20208 .27273 m
.20202 .27288 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20133 .28898 m
.20158 .28692 L
s
1 .066 0 r
.01 w
.20208 .27273 Mdot
1 .067 0 r
[ .05 .05 ] 0 setdash
.20216 .27251 m
.20208 .27273 L
s
1 .619 0 r
.82017 .27271 m
.8188 .27079 L
s
.82017 .27271 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83144 .32571 m
.8303 .31529 L
s
.19918 .31014 m
.19952 .30799 L
s
1 .067 0 r
.01 w
.20216 .27251 Mdot
[ .05 .05 ] 0 setdash
.20227 .27221 m
.20216 .27251 L
s
0 0 0 r
.004 w
.19385 .2724 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.1964 .38541 m
.19676 .38537 L
s
1 .067 0 r
.01 w
.20227 .27221 Mdot
1 .068 0 r
[ .05 .05 ] 0 setdash
.20244 .27182 m
.20227 .27221 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19947 .32169 m
.19896 .32942 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.20117 .28463 m
.20244 .27182 L
s
1 .068 0 r
.01 w
.20244 .27182 Mdot
[ .05 .05 ] 0 setdash
.20268 .27132 m
.20244 .27182 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84521 .41307 m
.84455 .40957 L
s
.20173 .27545 m
.20162 .2763 L
s
.20177 .27544 m
.20173 .27545 L
s
.20172 .27632 m
.20177 .27544 L
s
1 .068 0 r
.01 w
.20268 .27132 Mdot
1 .069 0 r
[ .05 .05 ] 0 setdash
.20298 .27073 m
.20268 .27132 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20041 .28961 m
.19987 .29504 L
s
.20162 .2763 m
.20146 .27762 L
s
.20115 .28984 m
.20133 .28898 L
s
0 0 0 r
.004 w
.19459 .27081 Mdot
1 .618 0 r
.01 w
[ .05 .05 ] 0 setdash
.8188 .27079 m
.81726 .26871 L
s
.8188 .27079 Mdot
1 .069 0 r
.20298 .27073 Mdot
1 .07 0 r
.20337 .27 m
.20298 .27073 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2016 .27814 m
.20172 .27632 L
s
.20146 .27762 m
.2013 .27899 L
s
0 0 0 r
.004 w
.85394 .27041 Mdot
.53 .8 .95 r
.006 w
.19888 .31211 m
.19918 .31014 L
s
.20096 .29038 m
.20115 .28984 L
s
1 .07 0 r
.01 w
.20337 .27 Mdot
[ .05 .05 ] 0 setdash
.20382 .26917 m
.20337 .27 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2013 .27899 m
.2011 .28073 L
s
.19896 .32942 m
.19835 .33771 L
s
.84455 .40957 m
.84384 .40677 L
s
0 0 0 r
.004 w
.19535 .26923 Mdot
1 .07 0 r
.01 w
.20382 .26917 Mdot
1 .071 0 r
[ .05 .05 ] 0 setdash
.20434 .26825 m
.20382 .26917 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2014 .28091 m
.2016 .27814 L
s
.8273 .30055 m
.82768 .30899 L
s
.2011 .28073 m
.20099 .28188 L
s
.20082 .29025 m
.20096 .29038 L
s
.19606 .38423 m
.1964 .38541 L
s
.19987 .29504 m
.19941 .30001 L
s
.20099 .28188 m
.20089 .28296 L
s
1 .618 0 r
.01 w
[ .05 .05 ] 0 setdash
.81726 .26871 m
.81581 .26685 L
s
.81726 .26871 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20073 .28959 m
.20082 .29025 L
s
.20089 .28296 m
.20082 .28389 L
s
.20082 .28389 m
.20073 .28531 L
s
.20073 .28592 m
.20072 .28702 L
s
.20073 .28531 m
.20073 .28592 L
s
.20072 .28702 m
.20068 .28857 L
s
1 .071 0 r
.01 w
.20434 .26825 Mdot
1 .072 0 r
[ .05 .05 ] 0 setdash
.20494 .26724 m
.20434 .26825 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20068 .28857 m
.20073 .28959 L
s
.83259 .33569 m
.83144 .32571 L
s
.1987 .31285 m
.19888 .31211 L
s
0 0 0 r
.004 w
.19612 .26766 Mdot
1 .072 0 r
.01 w
.20494 .26724 Mdot
[ .05 .05 ] 0 setdash
.20577 .26604 m
.20494 .26724 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20117 .28463 m
.2014 .28091 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.82244 .3401 m
.81581 .26685 L
s
1 .617 0 r
.01 w
[ .05 .05 ] 0 setdash
.81581 .26685 m
.81421 .26486 L
s
.81581 .26685 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19941 .30001 m
.19902 .30457 L
s
.19835 .33771 m
.19764 .34687 L
s
.84384 .40677 m
.84311 .40285 L
s
0 0 0 r
.004 w
.19691 .2661 Mdot
1 .072 0 r
.01 w
.20577 .26604 Mdot
1 .073 0 r
[ .05 .05 ] 0 setdash
.20667 .26477 m
.20577 .26604 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19854 .31313 m
.1987 .31285 L
s
.19584 .3831 m
.19606 .38423 L
s
.19902 .30457 m
.19872 .30852 L
s
1 .616 0 r
.01 w
[ .05 .05 ] 0 setdash
.81421 .26486 m
.8126 .26295 L
s
.81421 .26486 Mdot
1 .073 0 r
.20667 .26477 Mdot
.20756 .26348 m
.20667 .26477 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84311 .40285 m
.84232 .3989 L
s
0 0 0 r
.004 w
.19772 .26455 Mdot
.53 .8 .95 r
.006 w
.19851 .31201 m
.19854 .31313 L
s
.19872 .30852 m
.19851 .31201 L
s
.8338 .34601 m
.83259 .33569 L
s
.20093 .28889 m
.20117 .28463 L
s
.19764 .34687 m
.19704 .35525 L
s
1 .073 0 r
.01 w
.20756 .26348 Mdot
1 .074 0 r
[ .05 .05 ] 0 setdash
.20858 .2621 m
.20756 .26348 L
s
0 0 0 r
.004 w
.19854 .26302 Mdot
1 .616 0 r
.01 w
.8126 .26295 m
.81102 .26115 L
s
.8126 .26295 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84232 .3989 m
.84158 .39533 L
s
.82768 .30899 m
.82795 .31801 L
s
.19574 .38051 m
.19584 .3831 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.2039 .30983 m
.20858 .2621 L
s
1 .074 0 r
.01 w
.20858 .2621 Mdot
1 .075 0 r
[ .05 .05 ] 0 setdash
.20965 .26067 m
.20858 .2621 L
s
0 0 0 r
.004 w
.19937 .26149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.19704 .35525 m
.19646 .36343 L
s
1 .615 0 r
.01 w
[ .05 .05 ] 0 setdash
.81102 .26115 m
.80948 .25948 L
s
.81102 .26115 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20073 .29326 m
.20093 .28889 L
s
.84158 .39533 m
.84071 .39132 L
s
1 .075 0 r
.01 w
.20965 .26067 Mdot
[ .05 .05 ] 0 setdash
.21064 .25928 m
.20965 .26067 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83493 .35507 m
.8338 .34601 L
s
.19568 .37706 m
.19574 .38051 L
s
0 0 0 r
.004 w
.20022 .25998 Mdot
.53 .8 .95 r
.006 w
.19646 .36343 m
.19602 .37104 L
s
1 .614 0 r
.01 w
[ .05 .05 ] 0 setdash
.80948 .25948 m
.80785 .25775 L
s
.80948 .25948 Mdot
1 .075 0 r
.21064 .25928 Mdot
1 .076 0 r
.21182 .25776 m
.21064 .25928 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.84071 .39132 m
.83979 .38615 L
s
.19602 .37104 m
.19568 .37706 L
s
0 0 0 r
.004 w
.20109 .25848 Mdot
.53 .8 .95 r
.006 w
.83591 .36237 m
.83493 .35507 L
s
1 .076 0 r
.01 w
.21182 .25776 Mdot
[ .05 .05 ] 0 setdash
.21293 .25627 m
.21182 .25776 L
s
1 .614 0 r
.80785 .25775 m
.80624 .25602 L
s
.80785 .25775 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83979 .38615 m
.83884 .38116 L
s
.20069 .2969 m
.20073 .29326 L
s
0 0 0 r
.004 w
.20197 .25699 Mdot
.53 .8 .95 r
.006 w
.83699 .36987 m
.83591 .36237 L
s
.83884 .38116 m
.83798 .37613 L
s
1 .076 0 r
.01 w
.21293 .25627 Mdot
1 .077 0 r
[ .05 .05 ] 0 setdash
.21405 .25477 m
.21293 .25627 L
s
1 .613 0 r
.80624 .25602 m
.80455 .25421 L
s
.80624 .25602 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.83798 .37613 m
.83699 .36987 L
s
.82795 .31801 m
.82808 .32674 L
s
0 0 0 r
.004 w
.20287 .25551 Mdot
1 .077 0 r
.01 w
.21405 .25477 Mdot
1 .078 0 r
[ .05 .05 ] 0 setdash
.21505 .25327 m
.21405 .25477 L
s
1 .613 0 r
.80455 .25421 m
.80288 .25243 L
s
.80455 .25421 Mdot
0 0 0 r
.004 w
.20377 .25404 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20067 .3008 m
.20069 .2969 L
s
1 .078 0 r
.01 w
.21505 .25327 Mdot
[ .05 .05 ] 0 setdash
.21624 .25168 m
.21505 .25327 L
s
0 0 0 r
.004 w
.2047 .25258 Mdot
1 .612 0 r
.01 w
.80288 .25243 m
.80129 .25071 L
s
.80288 .25243 Mdot
1 .078 0 r
.21624 .25168 Mdot
1 .079 0 r
.21734 .2501 m
.21624 .25168 L
s
0 0 0 r
.004 w
.20564 .25113 Mdot
1 .611 0 r
.01 w
.80129 .25071 m
.79962 .24888 L
s
.80129 .25071 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20078 .30406 m
.20067 .3008 L
s
1 .079 0 r
.01 w
.21734 .2501 Mdot
1 .08 0 r
[ .05 .05 ] 0 setdash
.21846 .24847 m
.21734 .2501 L
s
0 0 0 r
.004 w
.20659 .24969 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.80567 .31928 m
.79962 .24888 L
s
1 .611 0 r
.01 w
[ .05 .05 ] 0 setdash
.79962 .24888 m
.79793 .24694 L
s
.79962 .24888 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82808 .32674 m
.82804 .33534 L
s
1 .08 0 r
.01 w
.21846 .24847 Mdot
[ .05 .05 ] 0 setdash
.21968 .24681 m
.21846 .24847 L
s
0 0 0 r
.004 w
.20755 .24826 Mdot
.84105 .24808 Mdot
.84105 .24808 Mdot
1 .61 0 r
.01 w
.79793 .24694 m
.79648 .24531 L
s
.79793 .24694 Mdot
0 0 0 r
.004 w
.20853 .24684 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2011 .30604 m
.20078 .30406 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.21427 .30372 m
.21968 .24681 L
s
1 .08 0 r
.01 w
.21968 .24681 Mdot
1 .081 0 r
[ .05 .05 ] 0 setdash
.22077 .24515 m
.21968 .24681 L
s
0 0 0 r
.004 w
.20952 .24543 Mdot
1 .61 0 r
.01 w
.79648 .24531 m
.79501 .24355 L
s
.79648 .24531 Mdot
1 .081 0 r
.22077 .24515 Mdot
.22222 .2433 m
.22077 .24515 L
s
0 0 0 r
.004 w
.21053 .24403 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20165 .30768 m
.2011 .30604 L
s
1 .609 0 r
.01 w
[ .05 .05 ] 0 setdash
.79501 .24355 m
.79364 .24192 L
s
.79501 .24355 Mdot
1 .081 0 r
.22222 .2433 Mdot
1 .082 0 r
.22351 .24155 m
.22222 .2433 L
s
0 0 0 r
.004 w
.21154 .24264 Mdot
1 .608 0 r
.01 w
.79364 .24192 m
.79256 .24062 L
s
.79364 .24192 Mdot
1 .082 0 r
.22351 .24155 Mdot
1 .083 0 r
.22496 .23956 m
.22351 .24155 L
s
0 0 0 r
.004 w
.21257 .24126 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2023 .30902 m
.20165 .30768 L
s
.82804 .33534 m
.82758 .3411 L
s
1 .608 0 r
.01 w
[ .05 .05 ] 0 setdash
.79256 .24062 m
.79153 .23935 L
s
.79256 .24062 Mdot
0 0 0 r
.004 w
.21362 .23989 Mdot
1 .083 0 r
.01 w
.22496 .23956 Mdot
.22649 .23757 m
.22496 .23956 L
s
1 .607 0 r
.79153 .23935 m
.79077 .23839 L
s
.79153 .23935 Mdot
0 0 0 r
.004 w
.21467 .23853 Mdot
1 .606 0 r
.01 w
.79077 .23839 m
.79014 .23759 L
s
.79077 .23839 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20298 .31005 m
.2023 .30902 L
s
1 .606 0 r
.01 w
[ .05 .05 ] 0 setdash
.79014 .23759 m
.78965 .23698 L
s
.79014 .23759 Mdot
1 .083 0 r
.22649 .23757 Mdot
1 .084 0 r
.22774 .23565 m
.22649 .23757 L
s
0 0 0 r
.004 w
.21574 .23718 Mdot
1 .605 0 r
.01 w
.78965 .23698 m
.78929 .23659 L
s
.78965 .23698 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.78985 .24334 m
.78929 .23659 L
s
1 .605 0 r
.01 w
[ .05 .05 ] 0 setdash
.78929 .23659 m
.78899 .23632 L
s
.78929 .23659 Mdot
1 .604 0 r
.78899 .23632 m
.78865 .23605 L
s
.78899 .23632 Mdot
1 .603 0 r
.78865 .23605 m
.78821 .23572 L
s
.78865 .23605 Mdot
0 0 0 r
.004 w
.21682 .23583 Mdot
1 .603 0 r
.01 w
.78821 .23572 m
.78762 .23528 L
s
.78821 .23572 Mdot
1 .084 0 r
.22774 .23565 Mdot
1 .085 0 r
.22974 .23345 m
.22774 .23565 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2039 .30983 m
.20298 .31005 L
s
1 .602 0 r
.01 w
[ .05 .05 ] 0 setdash
.78762 .23528 m
.7869 .23468 L
s
.78762 .23528 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82758 .3411 m
.82677 .34473 L
s
1 .601 0 r
.01 w
[ .05 .05 ] 0 setdash
.7869 .23468 m
.78597 .23385 L
s
.7869 .23468 Mdot
0 0 0 r
.004 w
.21792 .2345 Mdot
1 .601 0 r
.01 w
.78597 .23385 m
.78487 .23283 L
s
.78597 .23385 Mdot
1 .085 0 r
.22974 .23345 Mdot
.2313 .23133 m
.22974 .23345 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20479 .3104 m
.2039 .30983 L
s
0 0 0 r
.004 w
.21902 .23317 Mdot
1 .6 0 r
.01 w
[ .05 .05 ] 0 setdash
.78487 .23283 m
.78357 .23155 L
s
.78487 .23283 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78985 .24334 m
.78953 .24284 L
s
.79057 .24803 m
.78985 .24334 L
s
.78953 .24284 m
.7894 .24517 L
s
0 0 0 r
.004 w
.22014 .23185 Mdot
1 .6 0 r
.01 w
[ .05 .05 ] 0 setdash
.78357 .23155 m
.78214 .23007 L
s
.78357 .23155 Mdot
1 .085 0 r
.2313 .23133 Mdot
1 .086 0 r
.23308 .22921 m
.2313 .23133 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2056 .31091 m
.20479 .3104 L
s
0 0 0 r
.004 w
.22127 .23054 Mdot
.53 .8 .95 r
.006 w
.7894 .24517 m
.78936 .24962 L
s
.79168 .25613 m
.79057 .24803 L
s
1 .599 0 r
.01 w
[ .05 .05 ] 0 setdash
.78214 .23007 m
.78065 .22849 L
s
.78214 .23007 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82677 .34473 m
.82565 .34581 L
s
0 0 0 r
.004 w
.22241 .22924 Mdot
1 .086 0 r
.01 w
.23308 .22921 Mdot
[ .05 .05 ] 0 setdash
.23443 .22723 m
.23308 .22921 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.7857 .29115 m
.78065 .22849 L
s
1 .598 0 r
.01 w
[ .05 .05 ] 0 setdash
.78065 .22849 m
.77908 .22676 L
s
.78065 .22849 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20667 .31069 m
.2056 .31091 L
s
0 0 0 r
.004 w
.22356 .22795 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.22764 .30174 m
.23443 .22723 L
s
1 .086 0 r
.01 w
.23443 .22723 Mdot
1 .087 0 r
[ .05 .05 ] 0 setdash
.23624 .22514 m
.23443 .22723 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78936 .24962 m
.78934 .25609 L
s
1 .598 0 r
.01 w
[ .05 .05 ] 0 setdash
.77908 .22676 m
.77746 .22494 L
s
.77908 .22676 Mdot
0 0 0 r
.004 w
.22473 .22667 Mdot
.82388 .22655 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79306 .26579 m
.79168 .25613 L
s
.82565 .34581 m
.82415 .34457 L
s
.20773 .3099 m
.20667 .31069 L
s
0 0 0 r
.004 w
.22591 .2254 Mdot
1 .087 0 r
.01 w
.23624 .22514 Mdot
1 .088 0 r
[ .05 .05 ] 0 setdash
.23765 .22322 m
.23624 .22514 L
s
1 .597 0 r
.77746 .22494 m
.77597 .2233 L
s
.77746 .22494 Mdot
0 0 0 r
.004 w
.22709 .22413 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.20876 .30946 m
.20773 .3099 L
s
.81477 .31915 m
.81302 .31632 L
s
.81662 .32398 m
.81477 .31915 L
s
.82415 .34457 m
.82244 .3401 L
s
.81856 .32955 m
.81662 .32398 L
s
1 .597 0 r
.01 w
[ .05 .05 ] 0 setdash
.77597 .2233 m
.77438 .22149 L
s
.77597 .2233 Mdot
1 .088 0 r
.23765 .22322 Mdot
.23875 .22161 m
.23765 .22322 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.82244 .3401 m
.82055 .33526 L
s
.82055 .33526 m
.81856 .32955 L
s
0 0 0 r
.004 w
.22829 .22287 Mdot
.53 .8 .95 r
.006 w
.78934 .25609 m
.78931 .26403 L
s
.81302 .31632 m
.8115 .31584 L
s
.20978 .30794 m
.20876 .30946 L
s
0 0 0 r
.004 w
.2295 .22162 Mdot
1 .088 0 r
.01 w
.23875 .22161 Mdot
1 .089 0 r
[ .05 .05 ] 0 setdash
.24006 .21993 m
.23875 .22161 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7946 .27602 m
.79306 .26579 L
s
1 .596 0 r
.01 w
[ .05 .05 ] 0 setdash
.77438 .22149 m
.77277 .21966 L
s
.77438 .22149 Mdot
0 0 0 r
.004 w
.23072 .22038 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21094 .30683 m
.20978 .30794 L
s
1 .089 0 r
.01 w
.24006 .21993 Mdot
[ .05 .05 ] 0 setdash
.24107 .2186 m
.24006 .21993 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.8115 .31584 m
.80998 .31641 L
s
1 .595 0 r
.01 w
[ .05 .05 ] 0 setdash
.77277 .21966 m
.77117 .21787 L
s
.77277 .21966 Mdot
0 0 0 r
.004 w
.23196 .21915 Mdot
1 .089 0 r
.01 w
.24107 .2186 Mdot
1 .09 0 r
.24187 .21751 m
.24107 .2186 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21205 .3053 m
.21094 .30683 L
s
0 0 0 r
.004 w
.81552 .21793 Mdot
.2332 .21792 Mdot
1 .595 0 r
.01 w
[ .05 .05 ] 0 setdash
.77117 .21787 m
.76958 .21616 L
s
.77117 .21787 Mdot
1 .09 0 r
.24187 .21751 Mdot
1 .091 0 r
.24254 .21665 m
.24187 .21751 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.79644 .28695 m
.7946 .27602 L
s
0 0 0 r
.004 w
.23445 .21671 Mdot
1 .091 0 r
.01 w
.24254 .21665 Mdot
[ .05 .05 ] 0 setdash
.24305 .21604 m
.24254 .21665 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78931 .26403 m
.7891 .27201 L
s
.21309 .30475 m
.21205 .3053 L
s
1 .101 0 r
.01 w
[ .05 .05 ] 0 setdash
.24472 .21659 m
.24478 .21656 L
s
.24472 .21659 Mdot
.24461 .21658 m
.24472 .21659 L
s
.24461 .21658 Mdot
1 .102 0 r
.24446 .21656 m
.24461 .21658 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80998 .31641 m
.80855 .31769 L
s
1 .102 0 r
.01 w
.24446 .21656 Mdot
[ .05 .05 ] 0 setdash
.24427 .21652 m
.24446 .21656 L
s
1 .1 0 r
.24478 .21656 m
.24479 .2165 L
s
.24478 .21656 Mdot
1 .102 0 r
.24427 .21652 Mdot
1 .103 0 r
.24405 .21645 m
.24427 .21652 L
s
1 .099 0 r
.24479 .2165 m
.24474 .21638 L
s
.24479 .2165 Mdot
1 .103 0 r
.24405 .21645 Mdot
1 .104 0 r
.24382 .21637 m
.24405 .21645 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24449 .2192 m
.24474 .21638 L
s
1 .099 0 r
.01 w
[ .05 .05 ] 0 setdash
.24474 .21638 m
.24466 .21625 L
s
.24474 .21638 Mdot
1 .104 0 r
.24382 .21637 Mdot
.2436 .21627 m
.24382 .21637 L
s
.2436 .21627 Mdot
1 .105 0 r
.24341 .21615 m
.2436 .21627 L
s
1 .098 0 r
.24466 .21625 m
.24455 .21609 L
s
.24466 .21625 Mdot
1 .594 0 r
.76958 .21616 m
.7679 .21438 L
s
.76958 .21616 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24287 .22222 m
.24341 .21615 L
s
1 .105 0 r
.01 w
.24341 .21615 Mdot
[ .05 .05 ] 0 setdash
.24326 .21599 m
.24341 .21615 L
s
1 .097 0 r
.24455 .21609 m
.24444 .21593 L
s
.24455 .21609 Mdot
1 .091 0 r
.24305 .21604 Mdot
1 .092 0 r
.24341 .21561 m
.24305 .21604 L
s
1 .105 0 r
.24326 .21599 Mdot
1 .106 0 r
.24316 .21575 m
.24326 .21599 L
s
1 .097 0 r
.24444 .21593 m
.24432 .21576 L
s
.24444 .21593 Mdot
1 .096 0 r
.24432 .21576 m
.24424 .2156 L
s
.24432 .21576 Mdot
1 .106 0 r
.24316 .21575 Mdot
1 .107 0 r
.24313 .21543 m
.24316 .21575 L
s
1 .092 0 r
.24341 .21561 Mdot
1 .093 0 r
.24368 .21537 m
.24341 .21561 L
s
1 .096 0 r
.24424 .2156 m
.24417 .21544 L
s
.24424 .2156 Mdot
0 0 0 r
.004 w
.23572 .2155 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24462 .21831 m
.24461 .21854 L
s
.24456 .21842 m
.24462 .21831 L
s
.24441 .21882 m
.24456 .21842 L
s
1 .095 0 r
.01 w
[ .05 .05 ] 0 setdash
.24417 .21544 m
.2441 .21531 L
s
.24417 .21544 Mdot
1 .107 0 r
.24313 .21543 Mdot
.24322 .21505 m
.24313 .21543 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.24315 .22142 m
.24368 .21537 L
s
1 .093 0 r
.01 w
.24368 .21537 Mdot
[ .05 .05 ] 0 setdash
.24388 .21525 m
.24368 .21537 L
s
1 .094 0 r
.2441 .21531 m
.24402 .21524 L
s
.2441 .21531 Mdot
1 .093 0 r
.24388 .21525 Mdot
1 .094 0 r
.24402 .21524 m
.24388 .21525 L
s
.24402 .21524 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24461 .21854 m
.24449 .2192 L
s
.2442 .21951 m
.24441 .21882 L
s
1 .107 0 r
.01 w
.24322 .21505 Mdot
1 .108 0 r
[ .05 .05 ] 0 setdash
.2434 .21457 m
.24322 .21505 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24392 .22046 m
.2442 .21951 L
s
.24449 .2192 m
.24437 .21956 L
s
1 .108 0 r
.01 w
.2434 .21457 Mdot
1 .109 0 r
[ .05 .05 ] 0 setdash
.24373 .21405 m
.2434 .21457 L
s
1 .593 0 r
.7679 .21438 m
.76614 .21259 L
s
.7679 .21438 Mdot
0 0 0 r
.004 w
.237 .2143 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21427 .30372 m
.21309 .30475 L
s
.24437 .21956 m
.2442 .2201 L
s
.24361 .22139 m
.24392 .22046 L
s
1 .109 0 r
.01 w
.24373 .21405 Mdot
[ .05 .05 ] 0 setdash
.24416 .21347 m
.24373 .21405 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2442 .2201 m
.24403 .22054 L
s
.24363 .21807 m
.24315 .22142 L
s
.24377 .21808 m
.24363 .21807 L
s
.24376 .21914 m
.24377 .21808 L
s
1 .109 0 r
.01 w
.24416 .21347 Mdot
1 .11 0 r
[ .05 .05 ] 0 setdash
.24475 .21282 m
.24416 .21347 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24332 .22195 m
.24361 .22139 L
s
0 0 0 r
.004 w
.23828 .2131 Mdot
.53 .8 .95 r
.006 w
.24403 .22054 m
.24385 .22113 L
s
.24376 .22014 m
.24376 .21914 L
s
.80855 .31769 m
.80721 .31921 L
s
.24309 .22209 m
.24332 .22195 L
s
1 .11 0 r
.01 w
.24475 .21282 Mdot
[ .05 .05 ] 0 setdash
.24541 .21213 m
.24475 .21282 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24287 .22222 m
.24309 .22209 L
s
1 .593 0 r
.01 w
[ .05 .05 ] 0 setdash
.76614 .21259 m
.76427 .21069 L
s
.76614 .21259 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2438 .22065 m
.24376 .22014 L
s
.24385 .22113 m
.2438 .22065 L
s
.24271 .22227 m
.24287 .22222 L
s
.79834 .29775 m
.79644 .28695 L
s
.21524 .30345 m
.21427 .30372 L
s
1 .11 0 r
.01 w
.24541 .21213 Mdot
1 .111 0 r
[ .05 .05 ] 0 setdash
.24613 .21137 m
.24541 .21213 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24251 .22306 m
.24271 .22227 L
s
0 0 0 r
.004 w
.23958 .21192 Mdot
.53 .8 .95 r
.006 w
.24315 .22142 m
.24242 .22678 L
s
0 0 0 r
.004 w
.80862 .21145 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.2436 .24026 m
.24613 .21137 L
s
1 .111 0 r
.01 w
.24613 .21137 Mdot
1 .112 0 r
[ .05 .05 ] 0 setdash
.2469 .21058 m
.24613 .21137 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24233 .22448 m
.24251 .22306 L
s
0 0 0 r
.004 w
.24089 .21074 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.76919 .27549 m
.76427 .21069 L
s
1 .592 0 r
.01 w
[ .05 .05 ] 0 setdash
.76427 .21069 m
.76263 .20909 L
s
.76427 .21069 Mdot
1 .112 0 r
.2469 .21058 Mdot
.24771 .20979 m
.2469 .21058 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7891 .27201 m
.78869 .27964 L
s
1 .112 0 r
.01 w
.24771 .20979 Mdot
1 .113 0 r
[ .05 .05 ] 0 setdash
.24862 .20894 m
.24771 .20979 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24218 .22675 m
.24233 .22448 L
s
.21646 .30418 m
.21524 .30345 L
s
0 0 0 r
.004 w
.24221 .20957 Mdot
.53 .8 .95 r
.006 w
.80721 .31921 m
.80567 .31928 L
s
1 .592 0 r
.01 w
[ .05 .05 ] 0 setdash
.76263 .20909 m
.76084 .20737 L
s
.76263 .20909 Mdot
1 .113 0 r
.24862 .20894 Mdot
1 .114 0 r
.2495 .20811 m
.24862 .20894 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24242 .22678 m
.24151 .23336 L
s
0 0 0 r
.004 w
.24353 .20841 Mdot
1 .114 0 r
.01 w
.2495 .20811 Mdot
[ .05 .05 ] 0 setdash
.25035 .2073 m
.2495 .20811 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80045 .30785 m
.79834 .29775 L
s
.24212 .22902 m
.24218 .22675 L
s
1 .591 0 r
.01 w
[ .05 .05 ] 0 setdash
.76084 .20737 m
.75907 .20569 L
s
.76084 .20737 Mdot
1 .114 0 r
.25035 .2073 Mdot
1 .115 0 r
.25123 .20649 m
.25035 .2073 L
s
0 0 0 r
.004 w
.24487 .20725 Mdot
1 .115 0 r
.01 w
.25123 .20649 Mdot
.25201 .20573 m
.25123 .20649 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21746 .30582 m
.21646 .30418 L
s
.80567 .31928 m
.804 .31795 L
s
0 0 0 r
.004 w
.24622 .20611 Mdot
.80247 .20609 Mdot
1 .115 0 r
.01 w
.25201 .20573 Mdot
1 .116 0 r
[ .05 .05 ] 0 setdash
.25269 .20504 m
.25201 .20573 L
s
1 .59 0 r
.75907 .20569 m
.75732 .20404 L
s
.75907 .20569 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24216 .23177 m
.24212 .22902 L
s
.24151 .23336 m
.24031 .2417 L
s
1 .116 0 r
.01 w
.25269 .20504 Mdot
1 .117 0 r
[ .05 .05 ] 0 setdash
.25334 .20438 m
.25269 .20504 L
s
0 0 0 r
.004 w
.24758 .20497 Mdot
1 .117 0 r
.01 w
.25334 .20438 Mdot
.2539 .20379 m
.25334 .20438 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.80234 .31414 m
.80045 .30785 L
s
1 .59 0 r
.01 w
[ .05 .05 ] 0 setdash
.75732 .20404 m
.75567 .20251 L
s
.75732 .20404 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78869 .27964 m
.788 .28599 L
s
0 0 0 r
.004 w
.24895 .20384 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.2522 .22361 m
.2539 .20379 L
s
1 .117 0 r
.01 w
.2539 .20379 Mdot
1 .118 0 r
[ .05 .05 ] 0 setdash
.25436 .20329 m
.2539 .20379 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.804 .31795 m
.80234 .31414 L
s
1 .133 0 r
.01 w
[ .05 .05 ] 0 setdash
.25645 .2034 m
.2565 .20336 L
s
.25645 .2034 Mdot
1 .134 0 r
.25635 .20335 m
.25645 .2034 L
s
1 .133 0 r
.2565 .20336 m
.25653 .20323 L
s
.2565 .20336 Mdot
1 .134 0 r
.25635 .20335 Mdot
.25622 .2032 m
.25635 .20335 L
s
1 .118 0 r
.25436 .20329 Mdot
.25473 .20289 m
.25436 .20329 L
s
1 .132 0 r
.25653 .20323 m
.25656 .20306 L
s
.25653 .20323 Mdot
1 .134 0 r
.25622 .2032 Mdot
1 .135 0 r
.25608 .20296 m
.25622 .2032 L
s
1 .131 0 r
.25656 .20306 m
.25657 .20286 L
s
.25656 .20306 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24231 .23445 m
.24216 .23177 L
s
1 .135 0 r
.01 w
.25608 .20296 Mdot
1 .136 0 r
[ .05 .05 ] 0 setdash
.25598 .20265 m
.25608 .20296 L
s
1 .118 0 r
.25473 .20289 Mdot
1 .119 0 r
.25503 .20259 m
.25473 .20289 L
s
1 .131 0 r
.25657 .20286 m
.25659 .20267 L
s
.25657 .20286 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25637 .20431 m
.25628 .20605 L
s
.2561 .20636 m
.25637 .20431 L
s
0 0 0 r
.004 w
.25033 .20271 Mdot
1 .13 0 r
.01 w
[ .05 .05 ] 0 setdash
.25659 .20267 m
.25661 .20252 L
s
.25659 .20267 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25518 .21212 m
.25598 .20265 L
s
1 .136 0 r
.01 w
.25598 .20265 Mdot
[ .05 .05 ] 0 setdash
.25594 .20229 m
.25598 .20265 L
s
1 .119 0 r
.25503 .20259 Mdot
1 .12 0 r
.25528 .20241 m
.25503 .20259 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25616 .2078 m
.25661 .20252 L
s
1 .13 0 r
.01 w
[ .05 .05 ] 0 setdash
.25661 .20252 m
.25662 .20242 L
s
.25661 .20252 Mdot
1 .589 0 r
.75567 .20251 m
.75411 .201 L
s
.75567 .20251 Mdot
1 .129 0 r
.25662 .20242 m
.2566 .20236 L
s
.25662 .20242 Mdot
1 .12 0 r
.25528 .20241 Mdot
.25549 .20229 m
.25528 .20241 L
s
1 .128 0 r
.2566 .20236 m
.25656 .20233 L
s
.2566 .20236 Mdot
.25656 .20233 m
.25649 .2023 L
s
.25656 .20233 Mdot
1 .127 0 r
.25649 .2023 m
.25639 .20224 L
s
.25649 .2023 Mdot
1 .12 0 r
.25549 .20229 Mdot
1 .121 0 r
.25564 .20223 m
.25549 .20229 L
s
1 .136 0 r
.25594 .20229 Mdot
1 .137 0 r
.25596 .20189 m
.25594 .20229 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.21863 .30701 m
.21746 .30582 L
s
1 .126 0 r
.01 w
[ .05 .05 ] 0 setdash
.25639 .20224 m
.25627 .20217 L
s
.25639 .20224 Mdot
1 .121 0 r
.25564 .20223 Mdot
1 .122 0 r
.25573 .20217 m
.25564 .20223 L
s
.25573 .20217 Mdot
.25578 .20213 m
.25573 .20217 L
s
1 .126 0 r
.25627 .20217 m
.25615 .20211 L
s
.25627 .20217 Mdot
1 .122 0 r
.25578 .20213 Mdot
1 .123 0 r
.25582 .20209 m
.25578 .20213 L
s
1 .125 0 r
.25615 .20211 m
.25602 .20207 L
s
.25615 .20211 Mdot
1 .123 0 r
.25582 .20209 Mdot
.25586 .20207 m
.25582 .20209 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25574 .20353 m
.25586 .20207 L
s
1 .123 0 r
.01 w
.25586 .20207 Mdot
1 .124 0 r
[ .05 .05 ] 0 setdash
.25592 .20206 m
.25586 .20207 L
s
1 .125 0 r
.25602 .20207 m
.25592 .20206 L
s
.25602 .20207 Mdot
1 .124 0 r
.25592 .20206 Mdot
1 .137 0 r
.25596 .20189 Mdot
1 .138 0 r
.25606 .20145 m
.25596 .20189 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25628 .20605 m
.25613 .20804 L
s
0 0 0 r
.004 w
.25172 .2016 Mdot
.53 .8 .95 r
.006 w
.25574 .20306 m
.25569 .20319 L
s
.25574 .20353 m
.25574 .20306 L
s
.25569 .20319 m
.25562 .20357 L
s
.25576 .20864 m
.2561 .20636 L
s
1 .138 0 r
.01 w
.25606 .20145 Mdot
[ .05 .05 ] 0 setdash
.25624 .20099 m
.25606 .20145 L
s
0 0 0 r
.004 w
.79681 .20144 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25562 .20357 m
.25549 .20403 L
s
.25578 .20376 m
.25574 .20353 L
s
.2564 .20426 m
.2563 .20448 L
s
.25637 .20507 m
.2564 .20426 L
s
.25549 .20403 m
.25516 .20617 L
s
.24031 .2417 m
.23895 .2504 L
s
1 .589 0 r
.01 w
[ .05 .05 ] 0 setdash
.75411 .201 m
.75273 .19966 L
s
.75411 .201 Mdot
1 .138 0 r
.25624 .20099 Mdot
1 .139 0 r
.25647 .20051 m
.25624 .20099 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25583 .20435 m
.25578 .20376 L
s
.2563 .20448 m
.25617 .20483 L
s
.25629 .20624 m
.25637 .20507 L
s
.25592 .20474 m
.25583 .20435 L
s
.25617 .20483 m
.25603 .20498 L
s
1 .139 0 r
.01 w
.25647 .20051 Mdot
[ .05 .05 ] 0 setdash
.25675 .20006 m
.25647 .20051 L
s
0 0 0 r
.004 w
.25312 .20049 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25603 .20498 m
.25592 .20474 L
s
.24265 .23658 m
.24231 .23445 L
s
.25613 .20804 m
.25604 .20918 L
s
1 .139 0 r
.01 w
.25675 .20006 Mdot
1 .14 0 r
[ .05 .05 ] 0 setdash
.25705 .19962 m
.25675 .20006 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25616 .2078 m
.25629 .20624 L
s
.25516 .20617 m
.25469 .20938 L
s
.25544 .21054 m
.25576 .20864 L
s
1 .588 0 r
.01 w
[ .05 .05 ] 0 setdash
.75273 .19966 m
.75157 .19852 L
s
.75273 .19966 Mdot
1 .14 0 r
.25705 .19962 Mdot
1 .141 0 r
.25736 .19923 m
.25705 .19962 L
s
0 0 0 r
.004 w
.25453 .19939 Mdot
1 .141 0 r
.01 w
.25736 .19923 Mdot
.25771 .19889 m
.25736 .19923 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25604 .20918 m
.25602 .20941 L
s
.25607 .20886 m
.25616 .2078 L
s
1 .141 0 r
.01 w
.25771 .19889 Mdot
1 .142 0 r
[ .05 .05 ] 0 setdash
.25809 .19861 m
.25771 .19889 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25602 .20941 m
.25607 .20886 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.25715 .20972 m
.25809 .19861 L
s
1 .142 0 r
.01 w
.25809 .19861 Mdot
1 .143 0 r
[ .05 .05 ] 0 setdash
.25846 .19839 m
.25809 .19861 L
s
1 .587 0 r
.75157 .19852 m
.75055 .19749 L
s
.75157 .19852 Mdot
1 .158 0 r
.25936 .1984 m
.25946 .1984 L
s
.25936 .1984 Mdot
1 .159 0 r
.25923 .19835 m
.25936 .1984 L
s
1 .157 0 r
.25946 .1984 m
.25952 .19836 L
s
.25946 .1984 Mdot
1 .143 0 r
.25846 .19839 Mdot
.25882 .19824 m
.25846 .19839 L
s
1 .157 0 r
.25952 .19836 m
.25955 .19831 L
s
.25952 .19836 Mdot
1 .159 0 r
.25923 .19835 Mdot
.25909 .19822 m
.25923 .19835 L
s
1 .156 0 r
.25955 .19831 m
.25955 .19825 L
s
.25955 .19831 Mdot
0 0 0 r
.004 w
.25595 .19829 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2199 .30818 m
.21863 .30701 L
s
1 .155 0 r
.01 w
[ .05 .05 ] 0 setdash
.25955 .19825 m
.25955 .19821 L
s
.25955 .19825 Mdot
1 .143 0 r
.25882 .19824 Mdot
1 .144 0 r
.25915 .19813 m
.25882 .19824 L
s
1 .159 0 r
.25909 .19822 Mdot
1 .16 0 r
.25896 .19803 m
.25909 .19822 L
s
1 .155 0 r
.25955 .19821 m
.25954 .19817 L
s
.25955 .19821 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25518 .21212 m
.25544 .21054 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.25952 .19844 m
.25954 .19817 L
s
1 .154 0 r
.01 w
[ .05 .05 ] 0 setdash
.25954 .19817 m
.25954 .19815 L
s
.25954 .19817 Mdot
.25954 .19815 m
.25954 .19815 L
s
.25954 .19815 Mdot
1 .151 0 r
.25954 .19815 m
.25954 .19815 L
s
.25954 .19815 Mdot
.25954 .19815 Mdot
1 .15 0 r
.25954 .19815 m
.25954 .19815 L
s
.25954 .19815 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25954 .19815 m
.25954 .19819 L
s
1 .152 0 r
.01 w
.25954 .19815 Mdot
.25954 .19815 Mdot
1 .153 0 r
.25954 .19815 Mdot
.53 .8 .95 r
.006 w
.25953 .1982 m
.25954 .19815 L
s
1 .149 0 r
.01 w
[ .05 .05 ] 0 setdash
.25954 .19815 m
.25956 .19814 L
s
.25954 .19815 Mdot
.25956 .19814 m
.25961 .19813 L
s
.25956 .19814 Mdot
1 .144 0 r
.25915 .19813 Mdot
.25942 .19807 m
.25915 .19813 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.25955 .1988 m
.25961 .19813 L
s
1 .148 0 r
.01 w
[ .05 .05 ] 0 setdash
.25961 .19813 m
.25968 .1981 L
s
.25961 .19813 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25952 .19844 m
.25953 .1982 L
s
.25954 .19819 m
.25954 .1984 L
s
1 .147 0 r
.01 w
[ .05 .05 ] 0 setdash
.25968 .1981 m
.25974 .19807 L
s
.25968 .1981 Mdot
1 .144 0 r
.25942 .19807 Mdot
1 .145 0 r
.25961 .19804 m
.25942 .19807 L
s
1 .147 0 r
.25974 .19807 m
.25976 .19805 L
s
.25974 .19807 Mdot
1 .146 0 r
.25976 .19805 m
.25972 .19804 L
s
.25976 .19805 Mdot
1 .145 0 r
.25961 .19804 Mdot
1 .146 0 r
.25972 .19804 m
.25961 .19804 L
s
.25972 .19804 Mdot
1 .16 0 r
.25896 .19803 Mdot
.25887 .19774 m
.25896 .19803 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25469 .20938 m
.25409 .2136 L
s
.788 .28599 m
.78695 .28948 L
s
.25949 .19885 m
.25952 .19844 L
s
.25954 .1984 m
.25955 .1988 L
s
.24305 .23881 m
.24265 .23658 L
s
.25947 .19926 m
.25949 .19885 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.25811 .20672 m
.25887 .19774 L
s
1 .16 0 r
.01 w
.25887 .19774 Mdot
1 .161 0 r
[ .05 .05 ] 0 setdash
.25888 .19736 m
.25887 .19774 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25968 .19851 m
.25946 .19985 L
s
.25969 .19891 m
.25968 .19851 L
s
.25955 .1988 m
.25959 .19921 L
s
.25944 .1996 m
.25947 .19926 L
s
.25925 .19974 m
.25934 .19976 L
s
.25905 .20055 m
.25925 .19974 L
s
.25934 .19976 m
.2594 .19978 L
s
.25964 .1993 m
.25969 .19891 L
s
1 .587 0 r
.01 w
[ .05 .05 ] 0 setdash
.75055 .19749 m
.74973 .19663 L
s
.75055 .19749 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2594 .19978 m
.25944 .1996 L
s
.25959 .19921 m
.25964 .1993 L
s
1 .161 0 r
.01 w
.25888 .19736 Mdot
1 .162 0 r
[ .05 .05 ] 0 setdash
.25905 .19685 m
.25888 .19736 L
s
0 0 0 r
.004 w
.79148 .19731 Mdot
.25738 .19721 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23895 .2504 m
.23736 .26013 L
s
.25876 .20218 m
.25905 .20055 L
s
.25946 .19985 m
.25911 .20175 L
s
1 .162 0 r
.01 w
.25905 .19685 Mdot
[ .05 .05 ] 0 setdash
.2594 .19618 m
.25905 .19685 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25499 .21346 m
.25518 .21212 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.75142 .2202 m
.74973 .19663 L
s
1 .586 0 r
.01 w
[ .05 .05 ] 0 setdash
.74973 .19663 m
.74911 .19594 L
s
.74973 .19663 Mdot
1 .162 0 r
.2594 .19618 Mdot
1 .163 0 r
.26 .19535 m
.2594 .19618 L
s
0 0 0 r
.004 w
.25882 .19613 Mdot
1 .585 0 r
.01 w
.74911 .19594 m
.7487 .19544 L
s
.74911 .19594 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25911 .20175 m
.25867 .20384 L
s
.25843 .20425 m
.25876 .20218 L
s
.25409 .2136 m
.2535 .21728 L
s
1 .585 0 r
.01 w
[ .05 .05 ] 0 setdash
.7487 .19544 m
.74849 .19512 L
s
.7487 .19544 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2436 .24026 m
.24305 .23881 L
s
1 .163 0 r
.01 w
.26 .19535 Mdot
[ .05 .05 ] 0 setdash
.26083 .19439 m
.26 .19535 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25489 .21448 m
.25499 .21346 L
s
1 .584 0 r
.01 w
[ .05 .05 ] 0 setdash
.74849 .19512 m
.74839 .19492 L
s
.74849 .19512 Mdot
0 0 0 r
.004 w
.26027 .19506 Mdot
1 .584 0 r
.01 w
.74839 .19492 m
.74837 .19482 L
s
.74839 .19492 Mdot
1 .583 0 r
.74837 .19482 m
.74841 .1948 L
s
.74837 .19482 Mdot
1 .581 0 r
.74848 .19482 m
.74844 .19479 L
s
.74848 .19482 Mdot
1 .582 0 r
.74846 .19481 m
.74848 .19482 L
s
.74846 .19481 Mdot
.74841 .1948 m
.74846 .19481 L
s
.74841 .1948 Mdot
1 .581 0 r
.74844 .19479 m
.7483 .19471 L
s
.74844 .19479 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74852 .19773 m
.7483 .19471 L
s
1 .58 0 r
.01 w
[ .05 .05 ] 0 setdash
.7483 .19471 m
.74807 .19455 L
s
.7483 .19471 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7485 .19505 m
.74851 .19588 L
s
.74849 .19524 m
.7485 .19505 L
s
1 .579 0 r
.01 w
[ .05 .05 ] 0 setdash
.74807 .19455 m
.74775 .19429 L
s
.74807 .19455 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74848 .19574 m
.74849 .19524 L
s
.25867 .20384 m
.25818 .20591 L
s
1 .163 0 r
.01 w
.26083 .19439 Mdot
1 .164 0 r
[ .05 .05 ] 0 setdash
.26209 .19324 m
.26083 .19439 L
s
1 .579 0 r
.74775 .19429 m
.74733 .19395 L
s
.74775 .19429 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22087 .30961 m
.2199 .30818 L
s
.74853 .19705 m
.74848 .19574 L
s
.74851 .19588 m
.74852 .19773 L
s
.25811 .20672 m
.25843 .20425 L
s
0 0 0 r
.004 w
.26172 .19399 Mdot
.53 .8 .95 r
.006 w
.2549 .21511 m
.25489 .21448 L
s
1 .578 0 r
.01 w
[ .05 .05 ] 0 setdash
.74733 .19395 m
.74681 .19349 L
s
.74733 .19395 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2535 .21728 m
.25288 .22064 L
s
0 0 0 r
.004 w
.78642 .19358 Mdot
1 .577 0 r
.01 w
[ .05 .05 ] 0 setdash
.74681 .19349 m
.74624 .19297 L
s
.74681 .19349 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78695 .28948 m
.7857 .29115 L
s
.7487 .19933 m
.74853 .19705 L
s
.25818 .20591 m
.25766 .20787 L
s
.24419 .24153 m
.2436 .24026 L
s
1 .164 0 r
.01 w
.26209 .19324 Mdot
1 .165 0 r
[ .05 .05 ] 0 setdash
.26341 .19201 m
.26209 .19324 L
s
1 .577 0 r
.74624 .19297 m
.74559 .19236 L
s
.74624 .19297 Mdot
0 0 0 r
.004 w
.26319 .19293 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25498 .21575 m
.2549 .21511 L
s
.74852 .19773 m
.7485 .20057 L
s
.23736 .26013 m
.23561 .26958 L
s
.25766 .20787 m
.25715 .20972 L
s
1 .576 0 r
.01 w
[ .05 .05 ] 0 setdash
.74559 .19236 m
.74491 .19171 L
s
.74559 .19236 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25288 .22064 m
.2522 .22361 L
s
.74902 .20262 m
.7487 .19933 L
s
.25784 .20975 m
.25811 .20672 L
s
1 .165 0 r
.01 w
.26341 .19201 Mdot
[ .05 .05 ] 0 setdash
.26517 .19064 m
.26341 .19201 L
s
0 0 0 r
.004 w
.26467 .19188 Mdot
1 .576 0 r
.01 w
.74491 .19171 m
.74427 .19109 L
s
.74491 .19171 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25516 .21598 m
.25498 .21575 L
s
.25715 .20972 m
.25665 .21146 L
s
.2522 .22361 m
.25145 .22639 L
s
.24495 .24134 m
.24419 .24153 L
s
1 .575 0 r
.01 w
[ .05 .05 ] 0 setdash
.74427 .19109 m
.74361 .19043 L
s
.74427 .19109 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25665 .21146 m
.25616 .2134 L
s
0 0 0 r
.004 w
.26616 .19084 Mdot
.53 .8 .95 r
.006 w
.25543 .21555 m
.25516 .21598 L
s
.7485 .20057 m
.74845 .2042 L
s
1 .165 0 r
.01 w
.26517 .19064 Mdot
1 .166 0 r
[ .05 .05 ] 0 setdash
.26698 .18931 m
.26517 .19064 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25145 .22639 m
.25058 .22954 L
s
1 .574 0 r
.01 w
[ .05 .05 ] 0 setdash
.74361 .19043 m
.74301 .18982 L
s
.74361 .19043 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74951 .20678 m
.74902 .20262 L
s
.25616 .2134 m
.25577 .21468 L
s
.25577 .21468 m
.25543 .21555 L
s
.22273 .30928 m
.22087 .30961 L
s
0 0 0 r
.004 w
.78157 .19015 Mdot
.53 .8 .95 r
.006 w
.24586 .24059 m
.24495 .24134 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.74456 .2122 m
.74301 .18982 L
s
1 .574 0 r
.01 w
[ .05 .05 ] 0 setdash
.74301 .18982 m
.74243 .18921 L
s
.74301 .18982 Mdot
0 0 0 r
.004 w
.26765 .18981 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7857 .29115 m
.78429 .29179 L
s
.25058 .22954 m
.24974 .23205 L
s
.25764 .21361 m
.25784 .20975 L
s
1 .166 0 r
.01 w
.26698 .18931 Mdot
1 .167 0 r
[ .05 .05 ] 0 setdash
.26914 .1879 m
.26698 .18931 L
s
1 .573 0 r
.74243 .18921 m
.74193 .18866 L
s
.74243 .18921 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.24974 .23205 m
.2488 .23452 L
s
.2468 .23914 m
.24586 .24059 L
s
.23561 .26958 m
.23354 .27958 L
s
.2488 .23452 m
.2478 .23676 L
s
0 0 0 r
.004 w
.26916 .18878 Mdot
.53 .8 .95 r
.006 w
.2478 .23676 m
.2468 .23914 L
s
1 .572 0 r
.01 w
[ .05 .05 ] 0 setdash
.74193 .18866 m
.74151 .18817 L
s
.74193 .18866 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75032 .21287 m
.74951 .20678 L
s
1 .572 0 r
.01 w
[ .05 .05 ] 0 setdash
.74151 .18817 m
.74121 .18777 L
s
.74151 .18817 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74845 .2042 m
.74834 .20829 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.26396 .2516 m
.26914 .1879 L
s
1 .167 0 r
.01 w
.26914 .1879 Mdot
[ .05 .05 ] 0 setdash
.27152 .18649 m
.26914 .1879 L
s
1 .571 0 r
.74121 .18777 m
.741 .18747 L
s
.74121 .18777 Mdot
0 0 0 r
.004 w
.27068 .18776 Mdot
1 .571 0 r
.01 w
.741 .18747 m
.74087 .18726 L
s
.741 .18747 Mdot
1 .57 0 r
.74087 .18726 m
.74078 .18711 L
s
.74087 .18726 Mdot
1 .569 0 r
.74078 .18711 m
.74071 .18699 L
s
.74078 .18711 Mdot
.74071 .18699 m
.7406 .18685 L
s
.74071 .18699 Mdot
0 0 0 r
.004 w
.77689 .18699 Mdot
1 .568 0 r
.01 w
.7406 .18685 m
.74043 .18666 L
s
.7406 .18685 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22426 .30789 m
.22273 .30928 L
s
0 0 0 r
.004 w
.2722 .18674 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.74101 .19512 m
.74043 .18666 L
s
1 .568 0 r
.01 w
[ .05 .05 ] 0 setdash
.74043 .18666 m
.74015 .18639 L
s
.74043 .18666 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78429 .29179 m
.78268 .29051 L
s
1 .167 0 r
.01 w
.27152 .18649 Mdot
1 .168 0 r
[ .05 .05 ] 0 setdash
.27365 .18526 m
.27152 .18649 L
s
1 .567 0 r
.74015 .18639 m
.73976 .18603 L
s
.74015 .18639 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25757 .21797 m
.25764 .21361 L
s
1 .566 0 r
.01 w
[ .05 .05 ] 0 setdash
.73976 .18603 m
.73925 .18559 L
s
.73976 .18603 Mdot
0 0 0 r
.004 w
.27373 .18574 Mdot
1 .566 0 r
.01 w
.73925 .18559 m
.73862 .18507 L
s
.73925 .18559 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.23354 .27958 m
.23182 .28788 L
s
1 .168 0 r
.01 w
.27365 .18526 Mdot
[ .05 .05 ] 0 setdash
.27611 .18398 m
.27365 .18526 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75142 .2202 m
.75032 .21287 L
s
1 .565 0 r
.01 w
[ .05 .05 ] 0 setdash
.73862 .18507 m
.73788 .18449 L
s
.73862 .18507 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74834 .20829 m
.74815 .21235 L
s
.74104 .19083 m
.74099 .19113 L
s
.74117 .1917 m
.74104 .19083 L
s
0 0 0 r
.004 w
.27528 .18474 Mdot
1 .564 0 r
.01 w
[ .05 .05 ] 0 setdash
.73788 .18449 m
.73708 .1839 L
s
.73788 .18449 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74143 .19373 m
.74117 .1917 L
s
.74099 .19113 m
.74102 .19293 L
s
.78268 .29051 m
.78109 .2879 L
s
.22612 .3053 m
.22426 .30789 L
s
0 0 0 r
.004 w
.77235 .18404 Mdot
1 .168 0 r
.01 w
.27611 .18398 Mdot
1 .169 0 r
[ .05 .05 ] 0 setdash
.27816 .18293 m
.27611 .18398 L
s
1 .564 0 r
.73708 .1839 m
.73621 .18328 L
s
.73708 .1839 Mdot
0 0 0 r
.004 w
.27683 .18374 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74183 .19681 m
.74143 .19373 L
s
1 .563 0 r
.01 w
[ .05 .05 ] 0 setdash
.73621 .18328 m
.73528 .18265 L
s
.73621 .18328 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.78109 .2879 m
.77932 .2842 L
s
.23182 .28788 m
.22989 .29523 L
s
.74102 .19293 m
.74101 .19512 L
s
1 .169 0 r
.01 w
.27816 .18293 Mdot
1 .17 0 r
[ .05 .05 ] 0 setdash
.28026 .18193 m
.27816 .18293 L
s
0 0 0 r
.004 w
.27839 .18276 Mdot
1 .563 0 r
.01 w
.73528 .18265 m
.73433 .18203 L
s
.73528 .18265 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77932 .2842 m
.7776 .28145 L
s
.25763 .22357 m
.25757 .21797 L
s
.22764 .30174 m
.22612 .3053 L
s
1 .562 0 r
.01 w
[ .05 .05 ] 0 setdash
.73433 .18203 m
.73339 .18141 L
s
.73433 .18203 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74237 .2006 m
.74183 .19681 L
s
1 .17 0 r
.01 w
.28026 .18193 Mdot
[ .05 .05 ] 0 setdash
.28198 .18113 m
.28026 .18193 L
s
0 0 0 r
.004 w
.27996 .18178 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.22989 .29523 m
.22764 .30174 L
s
.75277 .22838 m
.75142 .2202 L
s
.74815 .21235 m
.74786 .21599 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.73522 .20881 m
.73339 .18141 L
s
1 .561 0 r
.01 w
[ .05 .05 ] 0 setdash
.73339 .18141 m
.73249 .18083 L
s
.73339 .18141 Mdot
0 0 0 r
.004 w
.76793 .18127 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74101 .19512 m
.74093 .19766 L
s
.7776 .28145 m
.77591 .27872 L
s
1 .17 0 r
.01 w
.28198 .18113 Mdot
1 .171 0 r
[ .05 .05 ] 0 setdash
.28343 .18049 m
.28198 .18113 L
s
1 .561 0 r
.73249 .18083 m
.73165 .18029 L
s
.73249 .18083 Mdot
0 0 0 r
.004 w
.28154 .18081 Mdot
1 .171 0 r
.01 w
.28343 .18049 Mdot
.2847 .17996 m
.28343 .18049 L
s
1 .56 0 r
.73165 .18029 m
.73089 .17981 L
s
.73165 .18029 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74304 .20465 m
.74237 .2006 L
s
1 .171 0 r
.01 w
.2847 .17996 Mdot
1 .172 0 r
[ .05 .05 ] 0 setdash
.28565 .1796 m
.2847 .17996 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77591 .27872 m
.77426 .27667 L
s
1 .511 0 r
.01 w
[ .05 .05 ] 0 setdash
.72296 .1799 m
.72288 .17989 L
s
.72296 .1799 Mdot
1 .512 0 r
.72314 .17986 m
.72296 .1799 L
s
1 .511 0 r
.72288 .17989 m
.72288 .17982 L
s
.72288 .17989 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72348 .18533 m
.72314 .17986 L
s
1 .512 0 r
.01 w
.72314 .17986 Mdot
1 .513 0 r
[ .05 .05 ] 0 setdash
.72343 .17979 m
.72314 .17986 L
s
0 0 0 r
.004 w
.28313 .17985 Mdot
1 .51 0 r
.01 w
.72288 .17982 m
.72294 .17968 L
s
.72288 .17982 Mdot
1 .56 0 r
.73089 .17981 m
.73028 .17943 L
s
.73089 .17981 Mdot
1 .513 0 r
.72343 .17979 Mdot
.72385 .17971 m
.72343 .17979 L
s
.72385 .17971 Mdot
1 .514 0 r
.72438 .17964 m
.72385 .17971 L
s
1 .51 0 r
.72294 .17968 m
.72299 .17947 L
s
.72294 .17968 Mdot
1 .514 0 r
.72438 .17964 Mdot
.72498 .17958 m
.72438 .17964 L
s
1 .172 0 r
.28565 .1796 Mdot
1 .173 0 r
.28632 .17937 m
.28565 .1796 L
s
1 .514 0 r
.72498 .17958 Mdot
1 .515 0 r
.72563 .17952 m
.72498 .17958 L
s
1 .182 0 r
.28653 .17955 m
.28655 .17953 L
s
.28653 .17955 Mdot
1 .183 0 r
.28651 .17954 m
.28653 .17955 L
s
.28651 .17954 Mdot
.2865 .17952 m
.28651 .17954 L
s
1 .181 0 r
.28655 .17953 m
.28656 .17951 L
s
.28655 .17953 Mdot
1 .515 0 r
.72563 .17952 Mdot
1 .516 0 r
.72629 .17949 m
.72563 .17952 L
s
1 .183 0 r
.2865 .17952 Mdot
1 .184 0 r
.2865 .17948 m
.2865 .17952 L
s
1 .181 0 r
.28656 .17951 m
.28657 .17949 L
s
.28656 .17951 Mdot
1 .55 0 r
.72971 .1795 m
.7297 .17948 L
s
.72971 .1795 Mdot
1 .551 0 r
.7297 .17949 m
.72971 .1795 L
s
1 .18 0 r
.28657 .17949 m
.28657 .17948 L
s
.28657 .17949 Mdot
1 .516 0 r
.72629 .17949 Mdot
.7269 .17948 m
.72629 .17949 L
s
1 .551 0 r
.7297 .17949 Mdot
1 .552 0 r
.72967 .17946 m
.7297 .17949 L
s
1 .18 0 r
.28657 .17948 m
.28658 .17948 L
s
.28657 .17948 Mdot
1 .516 0 r
.7269 .17948 Mdot
1 .517 0 r
.72748 .17948 m
.7269 .17948 L
s
1 .55 0 r
.7297 .17948 m
.72968 .17946 L
s
.7297 .17948 Mdot
1 .184 0 r
.2865 .17948 Mdot
.28651 .17943 m
.2865 .17948 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.28657 .17956 m
.28658 .17948 L
s
1 .179 0 r
.01 w
[ .05 .05 ] 0 setdash
.28658 .17948 m
.28662 .17947 L
s
.28658 .17948 Mdot
1 .517 0 r
.72748 .17948 Mdot
1 .518 0 r
.72798 .17947 m
.72748 .17948 L
s
.72798 .17947 Mdot
.72838 .17946 m
.72798 .17947 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72971 .17954 m
.72973 .18006 L
s
.72976 .18046 m
.72971 .17954 L
s
1 .509 0 r
.01 w
[ .05 .05 ] 0 setdash
.72299 .17947 m
.723 .17915 L
s
.72299 .17947 Mdot
1 .178 0 r
.28662 .17947 m
.28669 .17944 L
s
.28662 .17947 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72882 .18622 m
.72838 .17946 L
s
1 .518 0 r
.01 w
.72838 .17946 Mdot
1 .519 0 r
[ .05 .05 ] 0 setdash
.7287 .17945 m
.72838 .17946 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28657 .17951 m
.28657 .17956 L
s
.28656 .17965 m
.28657 .17951 L
s
1 .552 0 r
.01 w
.72967 .17946 Mdot
[ .05 .05 ] 0 setdash
.72961 .17941 m
.72967 .17946 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72977 .18089 m
.72968 .17946 L
s
1 .549 0 r
.01 w
[ .05 .05 ] 0 setdash
.72968 .17946 m
.72965 .17943 L
s
.72968 .17946 Mdot
1 .519 0 r
.7287 .17945 Mdot
.72893 .17942 m
.7287 .17945 L
s
1 .178 0 r
.28669 .17944 m
.2868 .1794 L
s
.28669 .17944 Mdot
1 .559 0 r
.73028 .17943 m
.72979 .17915 L
s
.73028 .17943 Mdot
1 .548 0 r
.72965 .17943 m
.72961 .17938 L
s
.72965 .17943 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28657 .17956 m
.28658 .17992 L
s
1 .184 0 r
.01 w
.28651 .17943 Mdot
1 .185 0 r
[ .05 .05 ] 0 setdash
.28653 .17936 m
.28651 .17943 L
s
1 .519 0 r
.72893 .17942 Mdot
1 .52 0 r
.72912 .17939 m
.72893 .17942 L
s
1 .552 0 r
.72961 .17941 Mdot
1 .553 0 r
.72952 .17933 m
.72961 .17941 L
s
1 .177 0 r
.2868 .1794 m
.28692 .17936 L
s
.2868 .1794 Mdot
1 .52 0 r
.72912 .17939 Mdot
1 .521 0 r
.72924 .17936 m
.72912 .17939 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28653 .1799 m
.28656 .17965 L
s
1 .548 0 r
.01 w
[ .05 .05 ] 0 setdash
.72961 .17938 m
.72956 .17931 L
s
.72961 .17938 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.28557 .18926 m
.28632 .17937 L
s
1 .173 0 r
.01 w
.28632 .17937 Mdot
[ .05 .05 ] 0 setdash
.28675 .17926 m
.28632 .17937 L
s
1 .521 0 r
.72924 .17936 Mdot
.72932 .17932 m
.72924 .17936 L
s
1 .176 0 r
.28692 .17936 m
.28702 .17932 L
s
.28692 .17936 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.28637 .18149 m
.28653 .17936 L
s
1 .185 0 r
.01 w
.28653 .17936 Mdot
1 .186 0 r
[ .05 .05 ] 0 setdash
.28656 .17929 m
.28653 .17936 L
s
1 .553 0 r
.72952 .17933 Mdot
.72941 .17923 m
.72952 .17933 L
s
1 .176 0 r
.28702 .17932 m
.28708 .17929 L
s
.28702 .17932 Mdot
1 .521 0 r
.72932 .17932 Mdot
1 .522 0 r
.72935 .17926 m
.72932 .17932 L
s
1 .547 0 r
.72956 .17931 m
.72949 .17924 L
s
.72956 .17931 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28648 .1799 m
.28649 .18008 L
s
.28647 .17991 m
.28648 .1799 L
s
1 .535 0 r
.01 w
[ .05 .05 ] 0 setdash
.72953 .1793 m
.72952 .1793 L
s
.72953 .1793 Mdot
1 .536 0 r
.72952 .17929 m
.72953 .1793 L
s
1 .535 0 r
.72952 .1793 m
.72951 .17928 L
s
.72952 .1793 Mdot
1 .536 0 r
.72952 .17929 Mdot
1 .537 0 r
.7295 .17927 m
.72952 .17929 L
s
1 .186 0 r
.28656 .17929 Mdot
.28659 .17922 m
.28656 .17929 L
s
1 .175 0 r
.28708 .17929 m
.28709 .17925 L
s
.28708 .17929 Mdot
1 .534 0 r
.72951 .17928 m
.72949 .17926 L
s
.72951 .17928 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72959 .18066 m
.7295 .17927 L
s
1 .537 0 r
.01 w
.7295 .17927 Mdot
[ .05 .05 ] 0 setdash
.72948 .17925 m
.7295 .17927 L
s
1 .173 0 r
.28675 .17926 Mdot
1 .174 0 r
.28699 .17923 m
.28675 .17926 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28651 .18009 m
.28653 .1799 L
s
.28643 .18036 m
.28647 .17991 L
s
1 .522 0 r
.01 w
.72935 .17926 Mdot
1 .523 0 r
[ .05 .05 ] 0 setdash
.72937 .17919 m
.72935 .17926 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72953 .17937 m
.72957 .17995 L
s
.72955 .17981 m
.72953 .17937 L
s
1 .534 0 r
.01 w
[ .05 .05 ] 0 setdash
.72949 .17926 m
.72946 .17922 L
s
.72949 .17926 Mdot
1 .175 0 r
.28709 .17925 m
.28699 .17923 L
s
.28709 .17925 Mdot
1 .537 0 r
.72948 .17925 Mdot
1 .538 0 r
.72945 .17921 m
.72948 .17925 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72295 .1809 m
.72309 .18317 L
s
.72314 .18267 m
.72295 .1809 L
s
1 .547 0 r
.01 w
[ .05 .05 ] 0 setdash
.72949 .17924 m
.72943 .17916 L
s
.72949 .17924 Mdot
1 .174 0 r
.28699 .17923 Mdot
1 .553 0 r
.72941 .17923 Mdot
1 .554 0 r
.72928 .17912 m
.72941 .17923 L
s
1 .533 0 r
.72946 .17922 m
.72943 .17918 L
s
.72946 .17922 Mdot
1 .186 0 r
.28659 .17922 Mdot
1 .187 0 r
.28665 .17915 m
.28659 .17922 L
s
1 .538 0 r
.72945 .17921 Mdot
1 .539 0 r
.72942 .17917 m
.72945 .17921 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28649 .18008 m
.28651 .18009 L
s
.74093 .19766 m
.74074 .20022 L
s
1 .523 0 r
.01 w
.72937 .17919 Mdot
[ .05 .05 ] 0 setdash
.72936 .17911 m
.72937 .17919 L
s
1 .532 0 r
.72943 .17918 m
.72939 .17913 L
s
.72943 .17918 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28658 .17992 m
.28661 .18055 L
s
1 .539 0 r
.01 w
.72942 .17917 Mdot
[ .05 .05 ] 0 setdash
.72938 .17912 m
.72942 .17917 L
s
1 .546 0 r
.72943 .17916 m
.72936 .17909 L
s
.72943 .17916 Mdot
1 .558 0 r
.72979 .17915 m
.72943 .17897 L
s
.72979 .17915 Mdot
1 .187 0 r
.28665 .17915 Mdot
1 .188 0 r
.28675 .17908 m
.28665 .17915 L
s
1 .508 0 r
.723 .17915 m
.7229 .17874 L
s
.723 .17915 Mdot
1 .532 0 r
.72939 .17913 m
.72935 .17909 L
s
.72939 .17913 Mdot
1 .539 0 r
.72938 .17912 Mdot
1 .54 0 r
.72935 .17908 m
.72938 .17912 L
s
1 .554 0 r
.72928 .17912 Mdot
1 .555 0 r
.72915 .179 m
.72928 .17912 L
s
1 .523 0 r
.72936 .17911 Mdot
1 .524 0 r
.72935 .17905 m
.72936 .17911 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72973 .18006 m
.72977 .18089 L
s
1 .545 0 r
.01 w
[ .05 .05 ] 0 setdash
.72936 .17909 m
.72931 .17902 L
s
.72936 .17909 Mdot
1 .531 0 r
.72935 .17909 m
.72932 .17904 L
s
.72935 .17909 Mdot
1 .188 0 r
.28675 .17908 Mdot
.28693 .179 m
.28675 .17908 L
s
1 .54 0 r
.72935 .17908 Mdot
.72931 .17903 m
.72935 .17908 L
s
1 .524 0 r
.72935 .17905 Mdot
.72933 .179 m
.72935 .17905 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72939 .18006 m
.72932 .17904 L
s
1 .531 0 r
.01 w
[ .05 .05 ] 0 setdash
.72932 .17904 m
.72929 .17901 L
s
.72932 .17904 Mdot
1 .54 0 r
.72931 .17903 Mdot
1 .541 0 r
.72928 .17899 m
.72931 .17903 L
s
1 .545 0 r
.72931 .17902 m
.72926 .17897 L
s
.72931 .17902 Mdot
1 .53 0 r
.72929 .17901 m
.72928 .17899 L
s
.72929 .17901 Mdot
1 .555 0 r
.72915 .179 Mdot
.72906 .17891 m
.72915 .179 L
s
1 .188 0 r
.28693 .179 Mdot
1 .189 0 r
.2872 .1789 m
.28693 .179 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72939 .17989 m
.72933 .179 L
s
1 .524 0 r
.01 w
.72933 .179 Mdot
1 .525 0 r
[ .05 .05 ] 0 setdash
.72931 .17896 m
.72933 .179 L
s
1 .541 0 r
.72928 .17899 Mdot
1 .542 0 r
.72924 .17895 m
.72928 .17899 L
s
1 .529 0 r
.72928 .17899 m
.72927 .17898 L
s
.72928 .17899 Mdot
.72927 .17898 m
.72927 .17897 L
s
.72927 .17898 Mdot
1 .528 0 r
.72927 .17897 m
.72927 .17895 L
s
.72927 .17897 Mdot
1 .544 0 r
.72926 .17897 m
.72923 .17893 L
s
.72926 .17897 Mdot
1 .558 0 r
.72943 .17897 m
.7292 .17886 L
s
.72943 .17897 Mdot
1 .525 0 r
.72931 .17896 Mdot
1 .526 0 r
.72929 .17894 m
.72931 .17896 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72959 .18066 m
.72955 .17981 L
s
1 .542 0 r
.01 w
.72924 .17895 Mdot
[ .05 .05 ] 0 setdash
.72922 .17892 m
.72924 .17895 L
s
1 .527 0 r
.72927 .17895 m
.72927 .17894 L
s
.72927 .17895 Mdot
1 .526 0 r
.72929 .17894 Mdot
.72928 .17894 m
.72929 .17894 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72928 .17904 m
.72928 .17909 L
s
.7293 .17926 m
.72928 .17904 L
s
1 .527 0 r
.01 w
[ .05 .05 ] 0 setdash
.72927 .17894 m
.72928 .17894 L
s
.72927 .17894 Mdot
1 .526 0 r
.72928 .17894 Mdot
1 .543 0 r
.72923 .17893 m
.72921 .17892 L
s
.72923 .17893 Mdot
1 .542 0 r
.72922 .17892 Mdot
1 .543 0 r
.72921 .17892 m
.72922 .17892 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72923 .1792 m
.72921 .17892 L
s
1 .543 0 r
.01 w
.72921 .17892 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2864 .18093 m
.28643 .18036 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.72923 .1815 m
.72906 .17891 L
s
1 .555 0 r
.01 w
.72906 .17891 Mdot
1 .556 0 r
[ .05 .05 ] 0 setdash
.72903 .17885 m
.72906 .17891 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28705 .17979 m
.28682 .18152 L
s
.28699 .18058 m
.28705 .17979 L
s
1 .189 0 r
.01 w
.2872 .1789 Mdot
[ .05 .05 ] 0 setdash
.28756 .17878 m
.2872 .1789 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72928 .17909 m
.72928 .17907 L
s
0 0 0 r
.004 w
.28473 .17889 Mdot
.53 .8 .95 r
.006 w
.72928 .17907 m
.72928 .17916 L
s
.72957 .17995 m
.72956 .18009 L
s
1 .557 0 r
.01 w
[ .05 .05 ] 0 setdash
.7292 .17886 m
.72907 .17883 L
s
.7292 .17886 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7298 .18139 m
.72976 .18046 L
s
.7293 .17908 m
.72933 .17932 L
s
.72929 .17922 m
.7293 .17908 L
s
1 .556 0 r
.01 w
.72903 .17885 Mdot
[ .05 .05 ] 0 setdash
.72907 .17883 m
.72903 .17885 L
s
.72907 .17883 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72933 .17963 m
.7293 .17926 L
s
.72928 .17916 m
.72929 .17922 L
s
1 .189 0 r
.01 w
.28756 .17878 Mdot
1 .19 0 r
[ .05 .05 ] 0 setdash
.28804 .17863 m
.28756 .17878 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72956 .18009 m
.72959 .18082 L
s
1 .508 0 r
.01 w
[ .05 .05 ] 0 setdash
.7229 .17874 m
.72266 .17823 L
s
.7229 .17874 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72933 .17932 m
.72939 .17989 L
s
.72923 .1792 m
.72926 .1796 L
s
.72925 .17929 m
.72923 .1792 L
s
.28661 .18055 m
.28667 .18113 L
s
.72932 .17992 m
.72925 .17929 L
s
0 0 0 r
.004 w
.76362 .17867 Mdot
1 .19 0 r
.01 w
.28804 .17863 Mdot
1 .191 0 r
[ .05 .05 ] 0 setdash
.2886 .17847 m
.28804 .17863 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72939 .18006 m
.72933 .17963 L
s
.72977 .18089 m
.72982 .18192 L
s
.72926 .1796 m
.72929 .17972 L
s
.72933 .1798 m
.72938 .18006 L
s
.72929 .17972 m
.72933 .1798 L
s
1 .191 0 r
.01 w
.2886 .17847 Mdot
[ .05 .05 ] 0 setdash
.28922 .17828 m
.2886 .17847 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28637 .18149 m
.2864 .18093 L
s
.28687 .18126 m
.28699 .18058 L
s
.74378 .20862 m
.74304 .20465 L
s
.72939 .17989 m
.72944 .18052 L
s
.72944 .18048 m
.72939 .18006 L
s
.77426 .27667 m
.77263 .27597 L
s
.72958 .1807 m
.72959 .18066 L
s
.72938 .18006 m
.72943 .18044 L
s
.7294 .18049 m
.72932 .17992 L
s
.74786 .21599 m
.74738 .21783 L
s
.72956 .18091 m
.72958 .1807 L
s
.72912 .17965 m
.72911 .18012 L
s
.72938 .18161 m
.72912 .17965 L
s
.28667 .18113 m
.28676 .18143 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.28817 .1923 m
.28922 .17828 L
s
1 .191 0 r
.01 w
.28922 .17828 Mdot
1 .192 0 r
[ .05 .05 ] 0 setdash
.28992 .17808 m
.28922 .17828 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72959 .18082 m
.72958 .18102 L
s
1 .507 0 r
.01 w
[ .05 .05 ] 0 setdash
.72266 .17823 m
.72221 .17761 L
s
.72266 .17823 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72983 .18268 m
.7298 .18139 L
s
.72943 .18044 m
.72949 .18076 L
s
.7295 .18083 m
.72944 .18048 L
s
.72348 .18533 m
.72314 .18267 L
s
.72953 .18093 m
.72956 .18091 L
s
.72944 .18052 m
.72949 .18111 L
s
.72949 .18106 m
.7294 .18049 L
s
1 .192 0 r
.01 w
.28992 .17808 Mdot
[ .05 .05 ] 0 setdash
.29065 .17787 m
.28992 .17808 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28676 .18143 m
.28687 .18126 L
s
.72949 .18076 m
.72953 .18093 L
s
.72958 .18102 m
.72955 .18102 L
s
.72955 .18102 m
.7295 .18083 L
s
.72911 .18012 m
.72923 .1815 L
s
.28636 .18189 m
.28637 .18149 L
s
0 0 0 r
.004 w
.28634 .17794 Mdot
.53 .8 .95 r
.006 w
.75433 .23681 m
.75277 .22838 L
s
1 .192 0 r
.01 w
.29065 .17787 Mdot
1 .193 0 r
[ .05 .05 ] 0 setdash
.2914 .17767 m
.29065 .17787 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7294 .18174 m
.72929 .18213 L
s
.72947 .18165 m
.7294 .18174 L
s
.72949 .18111 m
.72952 .18154 L
s
.72982 .18192 m
.7298 .18231 L
s
.72959 .18168 m
.72949 .18106 L
s
.72951 .18171 m
.72947 .18165 L
s
.28682 .18152 m
.28634 .18472 L
s
.72952 .18154 m
.72951 .18171 L
s
1 .193 0 r
.01 w
.2914 .17767 Mdot
1 .194 0 r
[ .05 .05 ] 0 setdash
.29216 .17745 m
.2914 .17767 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72309 .18317 m
.7233 .18551 L
s
.72929 .18213 m
.72917 .18304 L
s
.28637 .18211 m
.28636 .18189 L
s
1 .506 0 r
.01 w
[ .05 .05 ] 0 setdash
.72221 .17761 m
.72149 .17688 L
s
.72221 .17761 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72968 .18217 m
.72959 .18168 L
s
.7298 .18231 m
.72976 .1824 L
s
1 .194 0 r
.01 w
.29216 .17745 Mdot
[ .05 .05 ] 0 setdash
.29295 .17722 m
.29216 .17745 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25787 .22973 m
.25763 .22357 L
s
.28641 .18231 m
.28637 .18211 L
s
.72976 .1824 m
.72968 .18217 L
s
.72976 .18292 m
.72983 .18268 L
s
.72923 .1815 m
.72938 .18255 L
s
1 .194 0 r
.01 w
.29295 .17722 Mdot
1 .195 0 r
[ .05 .05 ] 0 setdash
.29369 .17696 m
.29295 .17722 L
s
1 .374 0 r
.66553 .17715 m
.66862 .1771 L
s
.66553 .17715 Mdot
.66246 .17713 m
.66553 .17715 L
s
.66246 .17713 Mdot
1 .375 0 r
.65932 .17706 m
.66246 .17713 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28648 .18275 m
.28641 .18231 L
s
1 .373 0 r
.01 w
[ .05 .05 ] 0 setdash
.66862 .1771 m
.67165 .17692 L
s
.66862 .1771 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72979 .18444 m
.72938 .18161 L
s
.72917 .18304 m
.72904 .18466 L
s
1 .375 0 r
.01 w
.65932 .17706 Mdot
1 .376 0 r
[ .05 .05 ] 0 setdash
.65637 .17695 m
.65932 .17706 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72967 .18322 m
.72976 .18292 L
s
0 0 0 r
.004 w
.28795 .177 Mdot
1 .195 0 r
.01 w
.29369 .17696 Mdot
1 .196 0 r
[ .05 .05 ] 0 setdash
.29437 .17668 m
.29369 .17696 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74074 .20022 m
.74042 .20272 L
s
1 .376 0 r
.01 w
.65637 .17695 Mdot
[ .05 .05 ] 0 setdash
.65326 .17678 m
.65637 .17695 L
s
1 .373 0 r
.67165 .17692 m
.67487 .17657 L
s
.67165 .17692 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.72324 .20459 m
.72149 .17688 L
s
1 .506 0 r
.01 w
[ .05 .05 ] 0 setdash
.72149 .17688 m
.72055 .1761 L
s
.72149 .17688 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74456 .2122 m
.74378 .20862 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.65567 .23528 m
.65326 .17678 L
s
1 .376 0 r
.01 w
.65326 .17678 Mdot
1 .377 0 r
[ .05 .05 ] 0 setdash
.65018 .17655 m
.65326 .17678 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72938 .18255 m
.72954 .18311 L
s
.2866 .18334 m
.28648 .18275 L
s
1 .196 0 r
.01 w
.29437 .17668 Mdot
[ .05 .05 ] 0 setdash
.29495 .17638 m
.29437 .17668 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72954 .18311 m
.72967 .18322 L
s
1 .372 0 r
.01 w
[ .05 .05 ] 0 setdash
.67487 .17657 m
.6775 .17629 L
s
.67487 .17657 Mdot
1 .377 0 r
.65018 .17655 Mdot
1 .378 0 r
.64731 .17631 m
.65018 .17655 L
s
1 .196 0 r
.29495 .17638 Mdot
1 .197 0 r
.29539 .17605 m
.29495 .17638 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72395 .18803 m
.72348 .18533 L
s
1 .378 0 r
.01 w
.64731 .17631 Mdot
[ .05 .05 ] 0 setdash
.64441 .17611 m
.64731 .17631 L
s
1 .371 0 r
.6775 .17629 m
.68025 .17582 L
s
.6775 .17629 Mdot
0 0 0 r
.004 w
.7594 .17621 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28676 .18469 m
.2866 .18334 L
s
.74738 .21783 m
.74676 .2181 L
s
1 .378 0 r
.01 w
.64441 .17611 Mdot
1 .379 0 r
[ .05 .05 ] 0 setdash
.6417 .17579 m
.64441 .17611 L
s
1 .505 0 r
.72055 .1761 m
.71934 .17522 L
s
.72055 .1761 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72904 .18466 m
.72882 .18622 L
s
0 0 0 r
.004 w
.28958 .17606 Mdot
1 .197 0 r
.01 w
.29539 .17605 Mdot
[ .05 .05 ] 0 setdash
.29572 .17574 m
.29539 .17605 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7233 .18551 m
.72351 .18771 L
s
.77263 .27597 m
.77095 .27549 L
s
1 .371 0 r
.01 w
[ .05 .05 ] 0 setdash
.68025 .17582 m
.68299 .17525 L
s
.68025 .17582 Mdot
1 .379 0 r
.6417 .17579 Mdot
.63913 .17555 m
.6417 .17579 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28634 .18472 m
.28557 .18926 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.29502 .18527 m
.29572 .17574 L
s
1 .197 0 r
.01 w
.29572 .17574 Mdot
1 .198 0 r
[ .05 .05 ] 0 setdash
.29594 .17548 m
.29572 .17574 L
s
1 .379 0 r
.63913 .17555 Mdot
1 .38 0 r
.63685 .17529 m
.63913 .17555 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74535 .21538 m
.74456 .2122 L
s
1 .198 0 r
.01 w
.29594 .17548 Mdot
1 .199 0 r
[ .05 .05 ] 0 setdash
.29604 .17523 m
.29594 .17548 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73038 .18817 m
.72979 .18444 L
s
1 .38 0 r
.01 w
.63685 .17529 Mdot
1 .381 0 r
[ .05 .05 ] 0 setdash
.63486 .17505 m
.63685 .17529 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.68561 .22685 m
.68299 .17525 L
s
1 .37 0 r
.01 w
[ .05 .05 ] 0 setdash
.68299 .17525 m
.68534 .17472 L
s
.68299 .17525 Mdot
1 .199 0 r
.29604 .17523 Mdot
.29608 .17501 m
.29604 .17523 L
s
1 .505 0 r
.71934 .17522 m
.71781 .17426 L
s
.71934 .17522 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28698 .18644 m
.28676 .18469 L
s
0 0 0 r
.004 w
.29121 .17513 Mdot
.53 .8 .95 r
.006 w
.72882 .18622 m
.72853 .18789 L
s
1 .381 0 r
.01 w
.63486 .17505 Mdot
[ .05 .05 ] 0 setdash
.63318 .17487 m
.63486 .17505 L
s
1 .199 0 r
.29608 .17501 Mdot
1 .2 0 r
.29609 .17481 m
.29608 .17501 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74676 .2181 m
.74611 .21746 L
s
1 .381 0 r
.01 w
.63318 .17487 Mdot
1 .382 0 r
[ .05 .05 ] 0 setdash
.63176 .17472 m
.63318 .17487 L
s
1 .2 0 r
.29609 .17481 Mdot
.29608 .17462 m
.29609 .17481 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.71114 .17718 m
.711 .17476 L
s
1 .339 0 r
.01 w
[ .05 .05 ] 0 setdash
.711 .17476 m
.71111 .17472 L
s
.711 .17476 Mdot
1 .34 0 r
.71088 .17472 m
.711 .17476 L
s
1 .37 0 r
.68534 .17472 m
.68763 .17413 L
s
.68534 .17472 Mdot
1 .34 0 r
.71088 .17472 Mdot
1 .341 0 r
.71079 .17463 m
.71088 .17472 L
s
1 .339 0 r
.71111 .17472 m
.7112 .1746 L
s
.71111 .17472 Mdot
1 .382 0 r
.63176 .17472 Mdot
.63061 .17463 m
.63176 .17472 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.63129 .19486 m
.63061 .17463 L
s
1 .382 0 r
.01 w
.63061 .17463 Mdot
1 .383 0 r
[ .05 .05 ] 0 setdash
.62961 .17457 m
.63061 .17463 L
s
1 .341 0 r
.71079 .17463 Mdot
.71073 .17449 m
.71079 .17463 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74042 .20272 m
.73998 .20511 L
s
1 .2 0 r
.01 w
.29608 .17462 Mdot
1 .201 0 r
[ .05 .05 ] 0 setdash
.29607 .17444 m
.29608 .17462 L
s
1 .338 0 r
.7112 .1746 m
.71124 .17439 L
s
.7112 .1746 Mdot
1 .383 0 r
.62961 .17457 Mdot
1 .384 0 r
.62879 .17453 m
.62961 .17457 L
s
.62879 .17453 Mdot
.62811 .1745 m
.62879 .17453 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.74611 .21746 m
.74535 .21538 L
s
1 .384 0 r
.01 w
.62811 .1745 Mdot
1 .385 0 r
[ .05 .05 ] 0 setdash
.62748 .17449 m
.62811 .1745 L
s
1 .341 0 r
.71073 .17449 Mdot
1 .342 0 r
.7107 .17432 m
.71073 .17449 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72452 .19019 m
.72395 .18803 L
s
1 .385 0 r
.01 w
.62748 .17449 Mdot
1 .386 0 r
[ .05 .05 ] 0 setdash
.62685 .17448 m
.62748 .17449 L
s
.62685 .17448 Mdot
.62616 .17447 m
.62685 .17448 L
s
.62616 .17447 Mdot
1 .387 0 r
.6254 .17446 m
.62616 .17447 L
s
.6254 .17446 Mdot
.62443 .17443 m
.6254 .17446 L
s
1 .201 0 r
.29607 .17444 Mdot
1 .202 0 r
.29605 .17427 m
.29607 .17444 L
s
1 .387 0 r
.62443 .17443 Mdot
1 .388 0 r
.62335 .17439 m
.62443 .17443 L
s
.62335 .17439 Mdot
1 .389 0 r
.62211 .17435 m
.62335 .17439 L
s
1 .337 0 r
.71124 .17439 m
.71123 .17415 L
s
.71124 .17439 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.62294 .20098 m
.62211 .17435 L
s
1 .389 0 r
.01 w
.62211 .17435 Mdot
[ .05 .05 ] 0 setdash
.62069 .17425 m
.62211 .17435 L
s
1 .342 0 r
.7107 .17432 Mdot
.7107 .17414 m
.7107 .17432 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.75603 .2453 m
.75433 .23681 L
s
1 .202 0 r
.01 w
.29605 .17427 Mdot
[ .05 .05 ] 0 setdash
.29602 .17411 m
.29605 .17427 L
s
1 .504 0 r
.71781 .17426 m
.71598 .17321 L
s
.71781 .17426 Mdot
1 .389 0 r
.62069 .17425 Mdot
1 .39 0 r
.61921 .1741 m
.62069 .17425 L
s
0 0 0 r
.004 w
.29285 .17421 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72351 .18771 m
.72368 .18989 L
s
1 .337 0 r
.01 w
[ .05 .05 ] 0 setdash
.71123 .17415 m
.71111 .17386 L
s
.71123 .17415 Mdot
1 .342 0 r
.7107 .17414 Mdot
1 .343 0 r
.71074 .17395 m
.7107 .17414 L
s
1 .369 0 r
.68763 .17413 m
.68972 .17354 L
s
.68763 .17413 Mdot
1 .202 0 r
.29602 .17411 Mdot
1 .203 0 r
.29593 .17399 m
.29602 .17411 L
s
1 .39 0 r
.61921 .1741 Mdot
.61772 .17386 m
.61921 .1741 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72853 .18789 m
.72813 .18954 L
s
1 .203 0 r
.01 w
.29593 .17399 Mdot
1 .204 0 r
[ .05 .05 ] 0 setdash
.29582 .17391 m
.29593 .17399 L
s
1 .343 0 r
.71074 .17395 Mdot
1 .344 0 r
.71082 .17375 m
.71074 .17395 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.29564 .17636 m
.29582 .17391 L
s
1 .204 0 r
.01 w
.29582 .17391 Mdot
[ .05 .05 ] 0 setdash
.29573 .17383 m
.29582 .17391 L
s
0 0 0 r
.004 w
.75527 .17388 Mdot
1 .336 0 r
.01 w
.71111 .17386 m
.71085 .17356 L
s
.71111 .17386 Mdot
1 .39 0 r
.61772 .17386 Mdot
1 .391 0 r
.61613 .17362 m
.61772 .17386 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28729 .18846 m
.28698 .18644 L
s
1 .204 0 r
.01 w
.29573 .17383 Mdot
1 .205 0 r
[ .05 .05 ] 0 setdash
.29571 .17376 m
.29573 .17383 L
s
.29571 .17376 Mdot
.29583 .17368 m
.29571 .17376 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71097 .17621 m
.71114 .17718 L
s
.71096 .1774 m
.71097 .17621 L
s
1 .344 0 r
.01 w
.71082 .17375 Mdot
[ .05 .05 ] 0 setdash
.71095 .17354 m
.71082 .17375 L
s
1 .205 0 r
.29583 .17368 Mdot
1 .206 0 r
.29613 .17357 m
.29583 .17368 L
s
1 .391 0 r
.61613 .17362 Mdot
1 .392 0 r
.61479 .17331 m
.61613 .17362 L
s
1 .206 0 r
.29613 .17357 Mdot
1 .207 0 r
.29663 .17339 m
.29613 .17357 L
s
1 .336 0 r
.71085 .17356 m
.71044 .17322 L
s
.71085 .17356 Mdot
1 .344 0 r
.71095 .17354 Mdot
1 .345 0 r
.71112 .17333 m
.71095 .17354 L
s
1 .368 0 r
.68972 .17354 m
.69162 .17296 L
s
.68972 .17354 Mdot
1 .207 0 r
.29663 .17339 Mdot
.2974 .17312 m
.29663 .17339 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73114 .19262 m
.73038 .18817 L
s
1 .345 0 r
.01 w
.71112 .17333 Mdot
[ .05 .05 ] 0 setdash
.71132 .17313 m
.71112 .17333 L
s
1 .392 0 r
.61479 .17331 Mdot
.61344 .17303 m
.61479 .17331 L
s
0 0 0 r
.004 w
.2945 .1733 Mdot
1 .335 0 r
.01 w
.71044 .17322 m
.70986 .17284 L
s
.71044 .17322 Mdot
1 .503 0 r
.71598 .17321 m
.71389 .17216 L
s
.71598 .17321 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.77095 .27549 m
.76919 .27549 L
s
.71114 .17718 m
.71134 .17859 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71175 .18031 m
.71132 .17313 L
s
1 .345 0 r
.01 w
.71132 .17313 Mdot
1 .346 0 r
[ .05 .05 ] 0 setdash
.71154 .17296 m
.71132 .17313 L
s
1 .207 0 r
.2974 .17312 Mdot
1 .208 0 r
.29845 .17274 m
.2974 .17312 L
s
1 .392 0 r
.61344 .17303 Mdot
1 .393 0 r
.61226 .17277 m
.61344 .17303 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28557 .18926 m
.28446 .19521 L
s
.72813 .18954 m
.72764 .19095 L
s
.72514 .19164 m
.72452 .19019 L
s
1 .368 0 r
.01 w
[ .05 .05 ] 0 setdash
.69162 .17296 m
.69318 .17246 L
s
.69162 .17296 Mdot
1 .346 0 r
.71154 .17296 Mdot
1 .347 0 r
.71174 .17283 m
.71154 .17296 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.711 .17901 m
.71096 .1774 L
s
1 .334 0 r
.01 w
[ .05 .05 ] 0 setdash
.70986 .17284 m
.70909 .17237 L
s
.70986 .17284 Mdot
1 .347 0 r
.71174 .17283 Mdot
.71191 .17276 m
.71174 .17283 L
s
1 .393 0 r
.61226 .17277 Mdot
1 .394 0 r
.6113 .17254 m
.61226 .17277 L
s
1 .347 0 r
.71191 .17276 Mdot
1 .348 0 r
.71202 .17272 m
.71191 .17276 L
s
1 .208 0 r
.29845 .17274 Mdot
1 .209 0 r
.29973 .17226 m
.29845 .17274 L
s
1 .348 0 r
.71202 .17272 Mdot
1 .349 0 r
.71205 .1727 m
.71202 .17272 L
s
.71205 .1727 Mdot
.712 .17266 m
.71205 .1727 L
s
.712 .17266 Mdot
1 .35 0 r
.71186 .1726 m
.712 .17266 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29559 .17569 m
.29564 .17636 L
s
.29558 .17559 m
.29559 .17569 L
s
1 .35 0 r
.01 w
.71186 .1726 Mdot
[ .05 .05 ] 0 setdash
.71164 .17251 m
.71186 .1726 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29558 .17722 m
.29558 .17559 L
s
1 .394 0 r
.01 w
.6113 .17254 Mdot
[ .05 .05 ] 0 setdash
.61053 .17231 m
.6113 .17254 L
s
1 .35 0 r
.71164 .17251 Mdot
1 .351 0 r
.71138 .17237 m
.71164 .17251 L
s
1 .367 0 r
.69318 .17246 m
.69462 .17197 L
s
.69318 .17246 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71208 .17306 m
.71215 .17487 L
s
.71214 .17506 m
.71208 .17306 L
s
0 0 0 r
.004 w
.29617 .17239 Mdot
1 .334 0 r
.01 w
[ .05 .05 ] 0 setdash
.70909 .17237 m
.70812 .1718 L
s
.70909 .17237 Mdot
1 .351 0 r
.71138 .17237 Mdot
1 .352 0 r
.71109 .17218 m
.71138 .17237 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29564 .17636 m
.2957 .17705 L
s
1 .394 0 r
.01 w
.61053 .17231 Mdot
1 .395 0 r
[ .05 .05 ] 0 setdash
.60998 .17213 m
.61053 .17231 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28769 .19048 m
.28729 .18846 L
s
1 .209 0 r
.01 w
.29973 .17226 Mdot
[ .05 .05 ] 0 setdash
.30122 .17172 m
.29973 .17226 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72368 .18989 m
.72382 .19322 L
s
.73998 .20511 m
.73943 .20729 L
s
.71134 .17859 m
.7115 .17974 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.71168 .18205 m
.71109 .17218 L
s
1 .352 0 r
.01 w
.71109 .17218 Mdot
[ .05 .05 ] 0 setdash
.71079 .17196 m
.71109 .17218 L
s
1 .503 0 r
.71389 .17216 m
.71133 .17087 L
s
.71389 .17216 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.61022 .18075 m
.60998 .17213 L
s
1 .395 0 r
.01 w
.60998 .17213 Mdot
[ .05 .05 ] 0 setdash
.60963 .17198 m
.60998 .17213 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72764 .19095 m
.7271 .19209 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.61019 .17427 m
.61013 .17206 L
s
1 .401 0 r
.01 w
[ .05 .05 ] 0 setdash
.61013 .17206 m
.61023 .17206 L
s
.61013 .17206 Mdot
1 .402 0 r
.60986 .17198 m
.61013 .17206 L
s
1 .4 0 r
.61023 .17206 m
.61021 .17199 L
s
.61023 .17206 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2957 .17705 m
.29573 .17802 L
s
1 .4 0 r
.01 w
[ .05 .05 ] 0 setdash
.61021 .17199 m
.6101 .17191 L
s
.61021 .17199 Mdot
1 .402 0 r
.60986 .17198 Mdot
.60938 .1718 m
.60986 .17198 L
s
1 .395 0 r
.60963 .17198 Mdot
1 .396 0 r
.60945 .17187 m
.60963 .17198 L
s
1 .366 0 r
.69462 .17197 m
.69582 .17154 L
s
.69462 .17197 Mdot
1 .352 0 r
.71079 .17196 Mdot
1 .353 0 r
.71047 .17171 m
.71079 .17196 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.25856 .23562 m
.25787 .22973 L
s
.72578 .19216 m
.72514 .19164 L
s
1 .399 0 r
.01 w
[ .05 .05 ] 0 setdash
.6101 .17191 m
.60992 .17183 L
s
.6101 .17191 Mdot
1 .396 0 r
.60945 .17187 Mdot
1 .397 0 r
.60943 .1718 m
.60945 .17187 L
s
1 .399 0 r
.60992 .17183 m
.60972 .17178 L
s
.60992 .17183 Mdot
1 .402 0 r
.60938 .1718 Mdot
1 .403 0 r
.60869 .17155 m
.60938 .1718 L
s
1 .397 0 r
.60943 .1718 Mdot
.60953 .17177 m
.60943 .1718 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70972 .19896 m
.70812 .1718 L
s
1 .333 0 r
.01 w
[ .05 .05 ] 0 setdash
.70812 .1718 m
.70698 .17116 L
s
.70812 .1718 Mdot
1 .398 0 r
.60972 .17178 m
.60953 .17177 L
s
.60972 .17178 Mdot
1 .397 0 r
.60953 .17177 Mdot
1 .209 0 r
.30122 .17172 Mdot
1 .21 0 r
.30323 .17099 m
.30122 .17172 L
s
1 .353 0 r
.71047 .17171 Mdot
.71017 .17145 m
.71047 .17171 L
s
0 0 0 r
.004 w
.75122 .17167 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29573 .17802 m
.29572 .17888 L
s
.71104 .17995 m
.711 .17901 L
s
1 .403 0 r
.01 w
.60869 .17155 Mdot
[ .05 .05 ] 0 setdash
.60767 .17113 m
.60869 .17155 L
s
1 .366 0 r
.69582 .17154 m
.69684 .17116 L
s
.69582 .17154 Mdot
0 0 0 r
.004 w
.29783 .17149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72646 .19239 m
.72578 .19216 L
s
1 .353 0 r
.01 w
.71017 .17145 Mdot
1 .354 0 r
[ .05 .05 ] 0 setdash
.70986 .17117 m
.71017 .17145 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29565 .18006 m
.29558 .17722 L
s
.7271 .19209 m
.72646 .19239 L
s
.71215 .17487 m
.71214 .17648 L
s
.29572 .17888 m
.29569 .17958 L
s
.7115 .17974 m
.71158 .18003 L
s
1 .354 0 r
.01 w
.70986 .17117 Mdot
1 .355 0 r
[ .05 .05 ] 0 setdash
.70955 .17089 m
.70986 .17117 L
s
1 .333 0 r
.70698 .17116 m
.70555 .17036 L
s
.70698 .17116 Mdot
1 .365 0 r
.69684 .17116 m
.69777 .17081 L
s
.69684 .17116 Mdot
1 .403 0 r
.60767 .17113 Mdot
1 .404 0 r
.60641 .17066 m
.60767 .17113 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29569 .17958 m
.29568 .18013 L
s
.61027 .17351 m
.61028 .17459 L
s
.61019 .17427 m
.61027 .17351 L
s
.71216 .17758 m
.71214 .17506 L
s
.29568 .18013 m
.29563 .18103 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.30013 .21481 m
.30323 .17099 L
s
1 .21 0 r
.01 w
.30323 .17099 Mdot
[ .05 .05 ] 0 setdash
.30519 .17031 m
.30323 .17099 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73205 .19736 m
.73114 .19262 L
s
1 .355 0 r
.01 w
.70955 .17089 Mdot
[ .05 .05 ] 0 setdash
.70921 .17063 m
.70955 .17089 L
s
1 .502 0 r
.71133 .17087 m
.70891 .16983 L
s
.71133 .17087 Mdot
1 .365 0 r
.69777 .17081 m
.69861 .17052 L
s
.69777 .17081 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29563 .18103 m
.2956 .18163 L
s
.75791 .25322 m
.75603 .2453 L
s
.71158 .18003 m
.71164 .18098 L
s
.2956 .18163 m
.29552 .18237 L
s
.28817 .1923 m
.28769 .19048 L
s
.71112 .18124 m
.71104 .17995 L
s
1 .404 0 r
.01 w
.60641 .17066 Mdot
1 .405 0 r
[ .05 .05 ] 0 setdash
.60479 .17 m
.60641 .17066 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61002 .17765 m
.61019 .17427 L
s
1 .355 0 r
.01 w
.70921 .17063 Mdot
1 .356 0 r
[ .05 .05 ] 0 setdash
.70881 .17039 m
.70921 .17063 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29552 .18237 m
.29536 .18345 L
s
0 0 0 r
.004 w
.29951 .1706 Mdot
.53 .8 .95 r
.006 w
.60948 .17374 m
.60954 .17497 L
s
.6096 .17423 m
.60948 .17374 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.69945 .18556 m
.69861 .17052 L
s
1 .364 0 r
.01 w
[ .05 .05 ] 0 setdash
.69861 .17052 m
.69943 .17028 L
s
.69861 .17052 Mdot
1 .356 0 r
.70881 .17039 Mdot
1 .357 0 r
.70832 .17019 m
.70881 .17039 L
s
1 .332 0 r
.70555 .17036 m
.70384 .1695 L
s
.70555 .17036 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71214 .17648 m
.71204 .17781 L
s
.29536 .18345 m
.29502 .18527 L
s
.61028 .17459 m
.61019 .17525 L
s
1 .21 0 r
.01 w
.30519 .17031 Mdot
1 .211 0 r
[ .05 .05 ] 0 setdash
.30762 .16947 m
.30519 .17031 L
s
1 .363 0 r
.69943 .17028 m
.70027 .1701 L
s
.69943 .17028 Mdot
1 .357 0 r
.70832 .17019 Mdot
.70776 .17003 m
.70832 .17019 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6098 .17502 m
.6096 .17423 L
s
1 .363 0 r
.01 w
[ .05 .05 ] 0 setdash
.70027 .1701 m
.7011 .16998 L
s
.70027 .1701 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76919 .27549 m
.76758 .27487 L
s
1 .357 0 r
.01 w
.70776 .17003 Mdot
1 .358 0 r
[ .05 .05 ] 0 setdash
.70711 .16991 m
.70776 .17003 L
s
1 .405 0 r
.60479 .17 Mdot
.60296 .16929 m
.60479 .17 L
s
1 .362 0 r
.7011 .16998 m
.70199 .16989 L
s
.7011 .16998 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70791 .18369 m
.70711 .16991 L
s
1 .358 0 r
.01 w
.70711 .16991 Mdot
[ .05 .05 ] 0 setdash
.70635 .16984 m
.70711 .16991 L
s
1 .362 0 r
.70199 .16989 m
.70285 .16985 L
s
.70199 .16989 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73943 .20729 m
.73881 .20933 L
s
.60954 .17497 m
.60978 .17749 L
s
1 .361 0 r
.01 w
[ .05 .05 ] 0 setdash
.70285 .16985 m
.70374 .16981 L
s
.70285 .16985 Mdot
1 .358 0 r
.70635 .16984 Mdot
1 .359 0 r
.70552 .1698 m
.70635 .16984 L
s
1 .502 0 r
.70891 .16983 m
.70609 .16864 L
s
.70891 .16983 Mdot
1 .36 0 r
.70374 .16981 m
.70464 .1698 L
s
.70374 .16981 Mdot
1 .359 0 r
.70552 .1698 Mdot
1 .36 0 r
.70464 .1698 m
.70552 .1698 L
s
.70464 .1698 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61019 .17525 m
.61002 .17539 L
s
.71164 .18098 m
.71159 .18186 L
s
0 0 0 r
.004 w
.3012 .16971 Mdot
.53 .8 .95 r
.006 w
.61002 .17539 m
.6098 .17502 L
s
.71204 .17781 m
.71191 .17926 L
s
.29502 .18527 m
.29456 .18738 L
s
.28446 .19521 m
.28299 .20239 L
s
0 0 0 r
.004 w
.74723 .16956 Mdot
.53 .8 .95 r
.006 w
.7112 .18167 m
.71112 .18124 L
s
1 .331 0 r
.01 w
[ .05 .05 ] 0 setdash
.70384 .1695 m
.70182 .16851 L
s
.70384 .1695 Mdot
1 .211 0 r
.30762 .16947 Mdot
1 .212 0 r
.31022 .16859 m
.30762 .16947 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72382 .19322 m
.7238 .19624 L
s
.71208 .17986 m
.71216 .17758 L
s
.29586 .18396 m
.29565 .18006 L
s
1 .405 0 r
.01 w
.60296 .16929 Mdot
1 .406 0 r
[ .05 .05 ] 0 setdash
.60086 .16846 m
.60296 .16929 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28877 .19348 m
.28817 .1923 L
s
.71127 .18131 m
.7112 .18167 L
s
.71191 .17926 m
.71175 .18031 L
s
.71141 .18129 m
.71127 .18131 L
s
0 0 0 r
.004 w
.30289 .16883 Mdot
.53 .8 .95 r
.006 w
.29456 .18738 m
.29398 .18963 L
s
.71159 .18186 m
.71145 .18357 L
s
1 .501 0 r
.01 w
[ .05 .05 ] 0 setdash
.70609 .16864 m
.70311 .1674 L
s
.70609 .16864 Mdot
1 .212 0 r
.31022 .16859 Mdot
.31291 .16767 m
.31022 .16859 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71158 .18099 m
.71141 .18129 L
s
.73305 .20153 m
.73205 .19736 L
s
1 .331 0 r
.01 w
[ .05 .05 ] 0 setdash
.70182 .16851 m
.69958 .16747 L
s
.70182 .16851 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71175 .18031 m
.71158 .18099 L
s
1 .406 0 r
.01 w
.60086 .16846 Mdot
1 .407 0 r
[ .05 .05 ] 0 setdash
.59869 .16762 m
.60086 .16846 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.60978 .17749 m
.61022 .18075 L
s
.60966 .18218 m
.61002 .17765 L
s
.6278 .18419 m
.62846 .1851 L
s
.62718 .18466 m
.6278 .18419 L
s
.2894 .19454 m
.28877 .19348 L
s
.7599 .26021 m
.75791 .25322 L
s
0 0 0 r
.004 w
.3046 .16796 Mdot
.53 .8 .95 r
.006 w
.62655 .18634 m
.62718 .18466 L
s
.29398 .18963 m
.29325 .19192 L
s
.76758 .27487 m
.76578 .27341 L
s
.71191 .18122 m
.71208 .17986 L
s
1 .212 0 r
.01 w
.31291 .16767 Mdot
1 .213 0 r
[ .05 .05 ] 0 setdash
.31561 .16674 m
.31291 .16767 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62846 .1851 m
.62922 .18728 L
s
1 .407 0 r
.01 w
.59869 .16762 Mdot
[ .05 .05 ] 0 setdash
.59616 .16657 m
.59869 .16762 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73881 .20933 m
.73807 .21082 L
s
0 0 0 r
.004 w
.7433 .16755 Mdot
1 .33 0 r
.01 w
[ .05 .05 ] 0 setdash
.69958 .16747 m
.69704 .16634 L
s
.69958 .16747 Mdot
1 .5 0 r
.70311 .1674 m
.70005 .16608 L
s
.70311 .1674 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2901 .19516 m
.2894 .19454 L
s
0 0 0 r
.004 w
.30631 .1671 Mdot
.53 .8 .95 r
.006 w
.71145 .18357 m
.71122 .18626 L
s
.29325 .19192 m
.29248 .19346 L
s
.62587 .18904 m
.62655 .18634 L
s
1 .213 0 r
.01 w
.31561 .16674 Mdot
[ .05 .05 ] 0 setdash
.31826 .16583 m
.31561 .16674 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71168 .18205 m
.71191 .18122 L
s
.73414 .20562 m
.73305 .20153 L
s
.7238 .19624 m
.72363 .20007 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.5975 .22495 m
.59616 .16657 L
s
1 .407 0 r
.01 w
.59616 .16657 Mdot
1 .408 0 r
[ .05 .05 ] 0 setdash
.59361 .16553 m
.59616 .16657 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29624 .18906 m
.29586 .18396 L
s
.61022 .18075 m
.61087 .18473 L
s
.29088 .1948 m
.2901 .19516 L
s
1 .329 0 r
.01 w
[ .05 .05 ] 0 setdash
.69704 .16634 m
.69446 .16521 L
s
.69704 .16634 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29248 .19346 m
.29168 .1944 L
s
.62922 .18728 m
.63015 .19057 L
s
.25931 .24144 m
.25856 .23562 L
s
.29168 .1944 m
.29088 .1948 L
s
0 0 0 r
.004 w
.30803 .16624 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.70415 .23905 m
.70005 .16608 L
s
1 .5 0 r
.01 w
[ .05 .05 ] 0 setdash
.70005 .16608 m
.69664 .1647 L
s
.70005 .16608 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.76188 .26589 m
.7599 .26021 L
s
.76578 .27341 m
.76391 .27088 L
s
1 .213 0 r
.01 w
.31826 .16583 Mdot
1 .214 0 r
[ .05 .05 ] 0 setdash
.32076 .16496 m
.31826 .16583 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.7114 .18221 m
.71168 .18205 L
s
.73807 .21082 m
.73719 .21103 L
s
0 0 0 r
.004 w
.73943 .16562 Mdot
.53 .8 .95 r
.006 w
.28299 .20239 m
.28111 .21074 L
s
1 .408 0 r
.01 w
.59361 .16553 Mdot
[ .05 .05 ] 0 setdash
.59108 .16452 m
.59361 .16553 L
s
0 0 0 r
.004 w
.30976 .16539 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71109 .18198 m
.7114 .18221 L
s
1 .329 0 r
.01 w
[ .05 .05 ] 0 setdash
.69446 .16521 m
.69174 .1641 L
s
.69446 .16521 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71074 .18114 m
.71109 .18198 L
s
.71041 .18053 m
.71074 .18114 L
s
.71009 .17998 m
.71041 .18053 L
s
.60913 .1878 m
.60966 .18218 L
s
.76391 .27088 m
.76188 .26589 L
s
.62501 .19243 m
.62587 .18904 L
s
.70974 .17961 m
.71009 .17998 L
s
1 .214 0 r
.01 w
.32076 .16496 Mdot
1 .215 0 r
[ .05 .05 ] 0 setdash
.32286 .16424 m
.32076 .16496 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73522 .20881 m
.73414 .20562 L
s
.70935 .17964 m
.70974 .17961 L
s
.71122 .18626 m
.71088 .19005 L
s
1 .499 0 r
.01 w
[ .05 .05 ] 0 setdash
.69664 .1647 m
.69355 .16343 L
s
.69664 .1647 Mdot
0 0 0 r
.004 w
.3115 .16455 Mdot
1 .408 0 r
.01 w
.59108 .16452 Mdot
1 .409 0 r
.58825 .16332 m
.59108 .16452 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73719 .21103 m
.73623 .2104 L
s
.70892 .18034 m
.70935 .17964 L
s
.61087 .18473 m
.61176 .18929 L
s
1 .215 0 r
.01 w
.32286 .16424 Mdot
[ .05 .05 ] 0 setdash
.32486 .16354 m
.32286 .16424 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63015 .19057 m
.63129 .19486 L
s
1 .328 0 r
.01 w
[ .05 .05 ] 0 setdash
.69174 .1641 m
.6891 .163 L
s
.69174 .1641 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.73623 .2104 m
.73522 .20881 L
s
0 0 0 r
.004 w
.73562 .16378 Mdot
.31325 .16371 Mdot
.53 .8 .95 r
.006 w
.70845 .18175 m
.70892 .18034 L
s
1 .215 0 r
.01 w
.32486 .16354 Mdot
1 .216 0 r
[ .05 .05 ] 0 setdash
.32645 .163 m
.32486 .16354 L
s
1 .498 0 r
.69355 .16343 m
.69022 .16213 L
s
.69355 .16343 Mdot
1 .409 0 r
.58825 .16332 Mdot
1 .41 0 r
.58552 .16222 m
.58825 .16332 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72363 .20007 m
.72324 .20459 L
s
1 .328 0 r
.01 w
[ .05 .05 ] 0 setdash
.6891 .163 m
.68659 .16191 L
s
.6891 .163 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.32445 .19437 m
.32645 .163 L
s
1 .216 0 r
.01 w
.32645 .163 Mdot
1 .217 0 r
[ .05 .05 ] 0 setdash
.32766 .16257 m
.32645 .163 L
s
0 0 0 r
.004 w
.315 .16288 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.29682 .19522 m
.29624 .18906 L
s
.62406 .19658 m
.62501 .19243 L
s
1 .217 0 r
.01 w
.32766 .16257 Mdot
[ .05 .05 ] 0 setdash
.32869 .16222 m
.32766 .16257 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70791 .18369 m
.70845 .18175 L
s
1 .41 0 r
.01 w
.58552 .16222 Mdot
[ .05 .05 ] 0 setdash
.58286 .16113 m
.58552 .16222 L
s
1 .217 0 r
.32869 .16222 Mdot
1 .218 0 r
.32948 .16195 m
.32869 .16222 L
s
1 .498 0 r
.69022 .16213 m
.68658 .16069 L
s
.69022 .16213 Mdot
0 0 0 r
.004 w
.31677 .16206 Mdot
.73185 .16201 Mdot
1 .218 0 r
.01 w
.32948 .16195 Mdot
.33014 .16173 m
.32948 .16195 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.68959 .21948 m
.68659 .16191 L
s
1 .327 0 r
.01 w
[ .05 .05 ] 0 setdash
.68659 .16191 m
.68436 .16098 L
s
.68659 .16191 Mdot
1 .218 0 r
.33014 .16173 Mdot
1 .219 0 r
.33077 .16153 m
.33014 .16173 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71088 .19005 m
.71039 .19426 L
s
.61176 .18929 m
.61287 .1942 L
s
.63129 .19486 m
.63264 .20023 L
s
1 .219 0 r
.01 w
.33077 .16153 Mdot
1 .22 0 r
[ .05 .05 ] 0 setdash
.33146 .1613 m
.33077 .16153 L
s
.33146 .1613 Mdot
.33226 .16102 m
.33146 .1613 L
s
0 0 0 r
.004 w
.31854 .16124 Mdot
1 .41 0 r
.01 w
.58286 .16113 Mdot
1 .411 0 r
.58009 .1601 m
.58286 .16113 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.28111 .21074 m
.27897 .21998 L
s
.60828 .19403 m
.60913 .1878 L
s
1 .22 0 r
.01 w
.33226 .16102 Mdot
1 .221 0 r
[ .05 .05 ] 0 setdash
.3332 .16068 m
.33226 .16102 L
s
1 .326 0 r
.68436 .16098 m
.68232 .16013 L
s
.68436 .16098 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70726 .18544 m
.70791 .18369 L
s
.69945 .18556 m
.70026 .1851 L
s
.69866 .18684 m
.69945 .18556 L
s
1 .497 0 r
.01 w
[ .05 .05 ] 0 setdash
.68658 .16069 m
.68341 .15953 L
s
.68658 .16069 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70026 .1851 m
.70113 .18542 L
s
1 .221 0 r
.01 w
.3332 .16068 Mdot
[ .05 .05 ] 0 setdash
.3344 .16021 m
.3332 .16068 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26058 .24626 m
.25931 .24144 L
s
0 0 0 r
.004 w
.32032 .16043 Mdot
.53 .8 .95 r
.006 w
.69786 .18958 m
.69866 .18684 L
s
0 0 0 r
.004 w
.72813 .16031 Mdot
1 .221 0 r
.01 w
.3344 .16021 Mdot
1 .222 0 r
[ .05 .05 ] 0 setdash
.3358 .15966 m
.3344 .16021 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70113 .18542 m
.70203 .18632 L
s
1 .326 0 r
.01 w
[ .05 .05 ] 0 setdash
.68232 .16013 m
.68045 .15932 L
s
.68232 .16013 Mdot
1 .411 0 r
.58009 .1601 Mdot
.57747 .15913 m
.58009 .1601 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62294 .20098 m
.62406 .19658 L
s
.70654 .18728 m
.70726 .18544 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.33365 .19521 m
.3358 .15966 L
s
1 .222 0 r
.01 w
.3358 .15966 Mdot
1 .223 0 r
[ .05 .05 ] 0 setdash
.33739 .15903 m
.3358 .15966 L
s
0 0 0 r
.004 w
.32211 .15963 Mdot
1 .497 0 r
.01 w
.68341 .15953 m
.67997 .15824 L
s
.68341 .15953 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70203 .18632 m
.70298 .1873 L
s
1 .325 0 r
.01 w
[ .05 .05 ] 0 setdash
.68045 .15932 m
.67905 .15874 L
s
.68045 .15932 Mdot
1 .294 0 r
.6721 .15928 m
.67185 .15926 L
s
.6721 .15928 Mdot
1 .295 0 r
.6722 .15923 m
.6721 .15928 L
s
1 .294 0 r
.67185 .15926 m
.67149 .15913 L
s
.67185 .15926 Mdot
1 .295 0 r
.6722 .15923 Mdot
.67221 .15912 m
.6722 .15923 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69702 .19336 m
.69786 .18958 L
s
1 .293 0 r
.01 w
[ .05 .05 ] 0 setdash
.67149 .15913 m
.67095 .15892 L
s
.67149 .15913 Mdot
1 .411 0 r
.57747 .15913 Mdot
1 .412 0 r
.57478 .15811 m
.57747 .15913 L
s
1 .295 0 r
.67221 .15912 Mdot
1 .296 0 r
.67214 .15896 m
.67221 .15912 L
s
1 .223 0 r
.33739 .15903 Mdot
.3396 .15817 m
.33739 .15903 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72324 .20459 m
.72266 .20962 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6724 .16449 m
.67214 .15896 L
s
1 .296 0 r
.01 w
.67214 .15896 Mdot
1 .297 0 r
[ .05 .05 ] 0 setdash
.67202 .15876 m
.67214 .15896 L
s
1 .292 0 r
.67095 .15892 m
.6701 .15867 L
s
.67095 .15892 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.61287 .1942 m
.61416 .19846 L
s
0 0 0 r
.004 w
.32391 .15884 Mdot
1 .297 0 r
.01 w
.67202 .15876 Mdot
[ .05 .05 ] 0 setdash
.67187 .15854 m
.67202 .15876 L
s
1 .324 0 r
.67905 .15874 m
.6779 .15824 L
s
.67905 .15874 Mdot
0 0 0 r
.004 w
.72445 .15868 Mdot
1 .292 0 r
.01 w
.6701 .15867 m
.66923 .15829 L
s
.6701 .15867 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70298 .1873 m
.70391 .18847 L
s
1 .297 0 r
.01 w
.67187 .15854 Mdot
1 .298 0 r
[ .05 .05 ] 0 setdash
.67172 .1583 m
.67187 .15854 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70571 .18837 m
.70654 .18728 L
s
1 .298 0 r
.01 w
.67172 .1583 Mdot
1 .299 0 r
[ .05 .05 ] 0 setdash
.67156 .15807 m
.67172 .1583 L
s
1 .291 0 r
.66923 .15829 m
.66819 .15782 L
s
.66923 .15829 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63264 .20023 m
.63427 .20629 L
s
1 .324 0 r
.01 w
[ .05 .05 ] 0 setdash
.6779 .15824 m
.677 .15781 L
s
.6779 .15824 Mdot
1 .496 0 r
.67997 .15824 m
.67654 .15693 L
s
.67997 .15824 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71039 .19426 m
.70972 .19896 L
s
.29761 .2018 m
.29682 .19522 L
s
1 .223 0 r
.01 w
.3396 .15817 Mdot
1 .224 0 r
[ .05 .05 ] 0 setdash
.3418 .15733 m
.3396 .15817 L
s
1 .412 0 r
.57478 .15811 Mdot
1 .413 0 r
.57214 .15716 m
.57478 .15811 L
s
1 .299 0 r
.67156 .15807 Mdot
.67137 .15784 m
.67156 .15807 L
s
0 0 0 r
.004 w
.32571 .15805 Mdot
1 .299 0 r
.01 w
.67137 .15784 Mdot
1 .3 0 r
.67117 .15763 m
.67137 .15784 L
s
1 .291 0 r
.66819 .15782 m
.66696 .15722 L
s
.66819 .15782 Mdot
1 .323 0 r
.677 .15781 m
.67643 .15753 L
s
.677 .15781 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6723 .16144 m
.67226 .16275 L
s
.67238 .16279 m
.6723 .16144 L
s
.70391 .18847 m
.70482 .18871 L
s
.70482 .18871 m
.70571 .18837 L
s
1 .309 0 r
.01 w
[ .05 .05 ] 0 setdash
.67479 .15768 m
.67411 .15768 L
s
.67479 .15768 Mdot
1 .31 0 r
.67545 .15768 m
.67479 .15768 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67483 .17259 m
.67411 .15768 L
s
1 .308 0 r
.01 w
[ .05 .05 ] 0 setdash
.67411 .15768 m
.67341 .15766 L
s
.67411 .15768 Mdot
1 .31 0 r
.67545 .15768 Mdot
.6761 .15764 m
.67545 .15768 L
s
1 .308 0 r
.67341 .15766 m
.67273 .15764 L
s
.67341 .15766 Mdot
1 .307 0 r
.67273 .15764 m
.67211 .1576 L
s
.67273 .15764 Mdot
1 .31 0 r
.6761 .15764 Mdot
1 .311 0 r
.67668 .15758 m
.6761 .15764 L
s
1 .3 0 r
.67117 .15763 Mdot
.67096 .15744 m
.67117 .15763 L
s
1 .307 0 r
.67211 .1576 m
.67156 .15753 L
s
.67211 .1576 Mdot
1 .311 0 r
.67668 .15758 Mdot
1 .312 0 r
.67718 .15751 m
.67668 .15758 L
s
1 .306 0 r
.67156 .15753 m
.6711 .15744 L
s
.67156 .15753 Mdot
1 .323 0 r
.67643 .15753 m
.67613 .15733 L
s
.67643 .15753 Mdot
1 .312 0 r
.67718 .15751 Mdot
.67757 .15743 m
.67718 .15751 L
s
1 .3 0 r
.67096 .15744 Mdot
1 .301 0 r
.67077 .15728 m
.67096 .15744 L
s
1 .305 0 r
.6711 .15744 m
.67075 .15732 L
s
.6711 .15744 Mdot
1 .312 0 r
.67757 .15743 Mdot
1 .313 0 r
.67785 .15735 m
.67757 .15743 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69602 .19785 m
.69702 .19336 L
s
1 .313 0 r
.01 w
.67785 .15735 Mdot
[ .05 .05 ] 0 setdash
.67802 .15727 m
.67785 .15735 L
s
1 .322 0 r
.67613 .15733 m
.67608 .15722 L
s
.67613 .15733 Mdot
1 .224 0 r
.3418 .15733 Mdot
1 .225 0 r
.34451 .15631 m
.3418 .15733 L
s
1 .305 0 r
.67075 .15732 m
.67051 .15721 L
s
.67075 .15732 Mdot
1 .301 0 r
.67077 .15728 Mdot
1 .302 0 r
.67061 .15715 m
.67077 .15728 L
s
1 .313 0 r
.67802 .15727 Mdot
1 .314 0 r
.6781 .15721 m
.67802 .15727 L
s
0 0 0 r
.004 w
.32753 .15727 Mdot
1 .318 0 r
.01 w
.6776 .15727 m
.67777 .15725 L
s
.6776 .15727 Mdot
.67738 .15725 m
.6776 .15727 L
s
1 .317 0 r
.67777 .15725 m
.67788 .15722 L
s
.67777 .15725 Mdot
1 .318 0 r
.67738 .15725 Mdot
1 .319 0 r
.6771 .15723 m
.67738 .15725 L
s
.6771 .15723 Mdot
1 .32 0 r
.67679 .1572 m
.6771 .15723 L
s
1 .321 0 r
.67608 .15722 m
.67622 .15718 L
s
.67608 .15722 Mdot
1 .316 0 r
.67788 .15722 m
.67798 .15718 L
s
.67788 .15722 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.66837 .18803 m
.66696 .15722 L
s
1 .29 0 r
.01 w
[ .05 .05 ] 0 setdash
.66696 .15722 m
.66559 .15653 L
s
.66696 .15722 Mdot
1 .304 0 r
.67051 .15721 m
.6704 .15712 L
s
.67051 .15721 Mdot
1 .314 0 r
.6781 .15721 Mdot
1 .315 0 r
.67811 .15717 m
.6781 .15721 L
s
1 .32 0 r
.67679 .1572 Mdot
.67648 .15718 m
.67679 .1572 L
s
1 .316 0 r
.67798 .15718 m
.67806 .15716 L
s
.67798 .15718 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67647 .16241 m
.67622 .15718 L
s
1 .321 0 r
.01 w
[ .05 .05 ] 0 setdash
.67622 .15718 m
.67648 .15718 L
s
.67622 .15718 Mdot
1 .32 0 r
.67648 .15718 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67814 .15781 m
.67811 .15717 L
s
1 .315 0 r
.01 w
.67811 .15717 Mdot
[ .05 .05 ] 0 setdash
.67806 .15716 m
.67811 .15717 L
s
.67806 .15716 Mdot
1 .413 0 r
.57214 .15716 Mdot
.56962 .1562 m
.57214 .15716 L
s
1 .302 0 r
.67061 .15715 Mdot
.67047 .15708 m
.67061 .15715 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.62161 .20421 m
.62294 .20098 L
s
1 .304 0 r
.01 w
[ .05 .05 ] 0 setdash
.6704 .15712 m
.67039 .15708 L
s
.6704 .15712 Mdot
0 0 0 r
.004 w
.72081 .15711 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.67057 .1591 m
.67047 .15708 L
s
1 .302 0 r
.01 w
.67047 .15708 Mdot
1 .303 0 r
[ .05 .05 ] 0 setdash
.67039 .15708 m
.67047 .15708 L
s
.67039 .15708 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67226 .16275 m
.67216 .1658 L
s
1 .495 0 r
.01 w
[ .05 .05 ] 0 setdash
.67654 .15693 m
.67307 .15582 L
s
.67654 .15693 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67814 .15781 m
.67814 .15805 L
s
.6781 .15802 m
.67814 .15781 L
s
.6724 .16449 m
.67238 .16279 L
s
.67814 .15805 m
.67811 .15908 L
s
.67803 .15825 m
.6781 .15802 L
s
.61416 .19846 m
.61562 .20211 L
s
1 .289 0 r
.01 w
[ .05 .05 ] 0 setdash
.66559 .15653 m
.66395 .15568 L
s
.66559 .15653 Mdot
0 0 0 r
.004 w
.32935 .1565 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67794 .15842 m
.67803 .15825 L
s
.67044 .158 m
.67057 .1591 L
s
.67048 .15888 m
.67044 .158 L
s
.67784 .1587 m
.67794 .15842 L
s
1 .225 0 r
.01 w
.34451 .15631 Mdot
[ .05 .05 ] 0 setdash
.34708 .15538 m
.34451 .15631 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67771 .15948 m
.67784 .1587 L
s
.6072 .20103 m
.60828 .19403 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.57043 .21176 m
.56962 .1562 L
s
1 .413 0 r
.01 w
.56962 .1562 Mdot
1 .414 0 r
[ .05 .05 ] 0 setdash
.5671 .15523 m
.56962 .1562 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27897 .21998 m
.27665 .22835 L
s
.67811 .15908 m
.67801 .16073 L
s
.67067 .16054 m
.67048 .15888 L
s
1 .495 0 r
.01 w
[ .05 .05 ] 0 setdash
.67307 .15582 m
.66992 .1545 L
s
.67307 .15582 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67755 .16072 m
.67771 .15948 L
s
.67057 .1591 m
.67077 .16059 L
s
0 0 0 r
.004 w
.33118 .15573 Mdot
1 .289 0 r
.01 w
[ .05 .05 ] 0 setdash
.66395 .15568 m
.66222 .15486 L
s
.66395 .15568 Mdot
0 0 0 r
.004 w
.71721 .15559 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67626 .16003 m
.67625 .16069 L
s
.67678 .16459 m
.67626 .16003 L
s
1 .225 0 r
.01 w
.34708 .15538 Mdot
1 .226 0 r
[ .05 .05 ] 0 setdash
.34998 .15434 m
.34708 .15538 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67235 .16576 m
.6724 .16449 L
s
1 .414 0 r
.01 w
.5671 .15523 Mdot
1 .415 0 r
[ .05 .05 ] 0 setdash
.5647 .15435 m
.5671 .15523 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69482 .2028 m
.69602 .19785 L
s
.26201 .25004 m
.26058 .24626 L
s
.67801 .16073 m
.67784 .16288 L
s
.67099 .16241 m
.67067 .16054 L
s
.3295 .17202 m
.32869 .17462 L
s
.33013 .17183 m
.3295 .17202 L
s
.67733 .16192 m
.67755 .16072 L
s
0 0 0 r
.004 w
.33302 .15497 Mdot
.53 .8 .95 r
.006 w
.67216 .1658 m
.67197 .16922 L
s
.67625 .16069 m
.67647 .16241 L
s
.67077 .16059 m
.67099 .16199 L
s
.62019 .20632 m
.62161 .20421 L
s
1 .288 0 r
.01 w
[ .05 .05 ] 0 setdash
.66222 .15486 m
.66022 .15387 L
s
.66222 .15486 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33069 .17383 m
.33013 .17183 L
s
.61562 .20211 m
.61705 .20516 L
s
.63427 .20629 m
.63617 .21206 L
s
1 .494 0 r
.01 w
[ .05 .05 ] 0 setdash
.66992 .1545 m
.66681 .15344 L
s
.66992 .1545 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72266 .20962 m
.72179 .21458 L
s
1 .415 0 r
.01 w
.5647 .15435 Mdot
[ .05 .05 ] 0 setdash
.56228 .15334 m
.5647 .15435 L
s
1 .226 0 r
.34998 .15434 Mdot
.35322 .15319 m
.34998 .15434 L
s
0 0 0 r
.004 w
.33487 .15422 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70972 .19896 m
.70893 .20441 L
s
.67099 .16199 m
.67123 .1632 L
s
.67225 .16656 m
.67235 .16576 L
s
.67707 .16281 m
.67733 .16192 L
s
0 0 0 r
.004 w
.71364 .15414 Mdot
.53 .8 .95 r
.006 w
.67143 .16446 m
.67099 .16241 L
s
1 .287 0 r
.01 w
[ .05 .05 ] 0 setdash
.66022 .15387 m
.65804 .15285 L
s
.66022 .15387 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67784 .16288 m
.67756 .16529 L
s
.67647 .16241 m
.67677 .16315 L
s
.32869 .17462 m
.32762 .17924 L
s
.67123 .1632 m
.67148 .16433 L
s
.67677 .16315 m
.67707 .16281 L
s
0 0 0 r
.004 w
.33673 .15348 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.6699 .22077 m
.66681 .15344 L
s
1 .494 0 r
.01 w
[ .05 .05 ] 0 setdash
.66681 .15344 m
.66381 .15235 L
s
.66681 .15344 Mdot
1 .415 0 r
.56228 .15334 Mdot
1 .416 0 r
.56004 .15247 m
.56228 .15334 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67213 .16686 m
.67225 .16656 L
s
.6187 .20661 m
.62019 .20632 L
s
.61705 .20516 m
.6187 .20661 L
s
.67148 .16433 m
.67172 .1654 L
s
1 .226 0 r
.01 w
.35322 .15319 Mdot
1 .227 0 r
[ .05 .05 ] 0 setdash
.35609 .1522 m
.35322 .15319 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.2986 .20841 m
.29761 .2018 L
s
.33124 .17758 m
.33069 .17383 L
s
.67767 .17155 m
.67678 .16459 L
s
.67172 .1654 m
.67194 .16622 L
s
1 .287 0 r
.01 w
[ .05 .05 ] 0 setdash
.65804 .15285 m
.65562 .15171 L
s
.65804 .15285 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67199 .16668 m
.67143 .16446 L
s
.69352 .20855 m
.69482 .2028 L
s
0 0 0 r
.004 w
.33859 .15274 Mdot
.53 .8 .95 r
.006 w
.67194 .16622 m
.67213 .16686 L
s
0 0 0 r
.004 w
.71011 .15273 Mdot
.53 .8 .95 r
.006 w
.67197 .16922 m
.6716 .17276 L
s
1 .416 0 r
.01 w
.56004 .15247 Mdot
[ .05 .05 ] 0 setdash
.55782 .1515 m
.56004 .15247 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67756 .16529 m
.67718 .16764 L
s
1 .493 0 r
.01 w
[ .05 .05 ] 0 setdash
.66381 .15235 m
.66087 .15138 L
s
.66381 .15235 Mdot
1 .227 0 r
.35609 .1522 Mdot
1 .228 0 r
.3594 .15107 m
.35609 .1522 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27665 .22835 m
.27397 .23637 L
s
0 0 0 r
.004 w
.34046 .15201 Mdot
1 .286 0 r
.01 w
[ .05 .05 ] 0 setdash
.65562 .15171 m
.65311 .1506 L
s
.65562 .15171 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67265 .16891 m
.67199 .16668 L
s
1 .416 0 r
.01 w
.55782 .1515 Mdot
1 .417 0 r
[ .05 .05 ] 0 setdash
.55584 .15063 m
.55782 .1515 L
s
1 .492 0 r
.66087 .15138 m
.65813 .1504 L
s
.66087 .15138 Mdot
0 0 0 r
.004 w
.70661 .15138 Mdot
.34234 .15129 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63617 .21206 m
.63839 .21808 L
s
.32762 .17924 m
.32619 .18584 L
s
1 .228 0 r
.01 w
.3594 .15107 Mdot
[ .05 .05 ] 0 setdash
.36246 .15004 m
.3594 .15107 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67718 .16764 m
.67669 .16971 L
s
.60576 .20748 m
.6072 .20103 L
s
1 .417 0 r
.01 w
.55584 .15063 Mdot
1 .418 0 r
[ .05 .05 ] 0 setdash
.55395 .14984 m
.55584 .15063 L
s
1 .286 0 r
.65311 .1506 m
.65041 .14943 L
s
.65311 .1506 Mdot
0 0 0 r
.004 w
.34423 .15057 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26396 .2516 m
.26201 .25004 L
s
1 .492 0 r
.01 w
[ .05 .05 ] 0 setdash
.65813 .1504 m
.65542 .14944 L
s
.65813 .1504 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33185 .18263 m
.33124 .17758 L
s
.67336 .17086 m
.67265 .16891 L
s
0 0 0 r
.004 w
.70314 .15007 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.359 .21639 m
.36246 .15004 L
s
1 .228 0 r
.01 w
.36246 .15004 Mdot
1 .229 0 r
[ .05 .05 ] 0 setdash
.36557 .14902 m
.36246 .15004 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69186 .21399 m
.69352 .20855 L
s
.6716 .17276 m
.67093 .17645 L
s
0 0 0 r
.004 w
.34613 .14987 Mdot
1 .418 0 r
.01 w
.55395 .14984 Mdot
[ .05 .05 ] 0 setdash
.55234 .14921 m
.55395 .14984 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.72179 .21458 m
.72062 .21961 L
s
.67669 .16971 m
.67611 .1713 L
s
.70893 .20441 m
.70786 .21017 L
s
1 .491 0 r
.01 w
[ .05 .05 ] 0 setdash
.65542 .14944 m
.65279 .14856 L
s
.65542 .14944 Mdot
1 .285 0 r
.65041 .14943 m
.64753 .14817 L
s
.65041 .14943 Mdot
1 .418 0 r
.55234 .14921 Mdot
1 .419 0 r
.55092 .14864 m
.55234 .14921 L
s
0 0 0 r
.004 w
.34804 .14916 Mdot
1 .229 0 r
.01 w
.36557 .14902 Mdot
.36865 .14802 m
.36557 .14902 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.6741 .1719 m
.67336 .17086 L
s
.67894 .17945 m
.67767 .17155 L
s
0 0 0 r
.004 w
.6997 .14881 Mdot
1 .425 0 r
.01 w
[ .05 .05 ] 0 setdash
.54698 .14876 m
.54676 .14874 L
s
.54698 .14876 Mdot
1 .426 0 r
.54728 .14869 m
.54698 .14876 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67611 .1713 m
.67551 .17249 L
s
1 .424 0 r
.01 w
[ .05 .05 ] 0 setdash
.54676 .14874 m
.54665 .14864 L
s
.54676 .14874 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.54733 .15607 m
.54728 .14869 L
s
1 .426 0 r
.01 w
.54728 .14869 Mdot
[ .05 .05 ] 0 setdash
.54764 .14852 m
.54728 .14869 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27397 .23637 m
.27144 .2431 L
s
1 .424 0 r
.01 w
[ .05 .05 ] 0 setdash
.54665 .14864 m
.54666 .1485 L
s
.54665 .14864 Mdot
1 .419 0 r
.55092 .14864 Mdot
.54978 .14829 m
.55092 .14864 L
s
1 .49 0 r
.65279 .14856 m
.65016 .14766 L
s
.65279 .14856 Mdot
1 .426 0 r
.54764 .14852 Mdot
1 .427 0 r
.54802 .14822 m
.54764 .14852 L
s
1 .423 0 r
.54666 .1485 m
.54678 .14831 L
s
.54666 .1485 Mdot
0 0 0 r
.004 w
.34995 .14847 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67483 .17259 m
.6741 .1719 L
s
1 .423 0 r
.01 w
[ .05 .05 ] 0 setdash
.54678 .14831 m
.54705 .14814 L
s
.54678 .14831 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.54997 .17114 m
.54978 .14829 L
s
1 .419 0 r
.01 w
.54978 .14829 Mdot
1 .42 0 r
[ .05 .05 ] 0 setdash
.54881 .14804 m
.54978 .14829 L
s
1 .427 0 r
.54802 .14822 Mdot
1 .428 0 r
.54843 .14778 m
.54802 .14822 L
s
1 .284 0 r
.64753 .14817 m
.64448 .14689 L
s
.64753 .14817 Mdot
1 .422 0 r
.54705 .14814 m
.54746 .14801 L
s
.54705 .14814 Mdot
1 .42 0 r
.54881 .14804 Mdot
1 .421 0 r
.54805 .14796 m
.54881 .14804 L
s
1 .229 0 r
.36865 .14802 Mdot
1 .23 0 r
.37166 .14706 m
.36865 .14802 L
s
1 .421 0 r
.54746 .14801 m
.54805 .14796 L
s
.54746 .14801 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67551 .17249 m
.67483 .17259 L
s
1 .421 0 r
.01 w
.54805 .14796 Mdot
.53 .8 .95 r
.006 w
.30013 .21481 m
.2986 .20841 L
s
0 0 0 r
.004 w
.35187 .14778 Mdot
1 .428 0 r
.01 w
.54843 .14778 Mdot
[ .05 .05 ] 0 setdash
.5489 .14715 m
.54843 .14778 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.63839 .21808 m
.64089 .2237 L
s
1 .49 0 r
.01 w
[ .05 .05 ] 0 setdash
.65016 .14766 m
.64749 .14676 L
s
.65016 .14766 Mdot
0 0 0 r
.004 w
.69629 .14759 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32619 .18584 m
.32445 .19437 L
s
.68997 .21899 m
.69186 .21399 L
s
.26634 .25083 m
.26396 .2516 L
s
1 .428 0 r
.01 w
.5489 .14715 Mdot
1 .429 0 r
[ .05 .05 ] 0 setdash
.54943 .14638 m
.5489 .14715 L
s
0 0 0 r
.004 w
.3538 .14711 Mdot
1 .23 0 r
.01 w
.37166 .14706 Mdot
1 .231 0 r
.37462 .14612 m
.37166 .14706 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67093 .17645 m
.67025 .18017 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.6472 .21703 m
.64448 .14689 L
s
1 .284 0 r
.01 w
[ .05 .05 ] 0 setdash
.64448 .14689 m
.64122 .14561 L
s
.64448 .14689 Mdot
1 .489 0 r
.64749 .14676 m
.64479 .14584 L
s
.64749 .14676 Mdot
0 0 0 r
.004 w
.35574 .14643 Mdot
.6929 .14641 Mdot
1 .429 0 r
.01 w
.54943 .14638 Mdot
.54998 .14549 m
.54943 .14638 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33269 .18839 m
.33185 .18263 L
s
1 .231 0 r
.01 w
.37462 .14612 Mdot
[ .05 .05 ] 0 setdash
.37722 .14531 m
.37462 .14612 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.27144 .2431 m
.26864 .24808 L
s
1 .489 0 r
.01 w
[ .05 .05 ] 0 setdash
.64479 .14584 m
.64203 .14492 L
s
.64479 .14584 Mdot
0 0 0 r
.004 w
.35769 .14577 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54679 .15329 m
.54669 .15516 L
s
.54701 .15337 m
.54679 .15329 L
s
.54733 .15607 m
.54701 .15337 L
s
.60409 .2141 m
.60576 .20748 L
s
1 .283 0 r
.01 w
[ .05 .05 ] 0 setdash
.64122 .14561 m
.6377 .14412 L
s
.64122 .14561 Mdot
1 .429 0 r
.54998 .14549 Mdot
1 .43 0 r
.55057 .14451 m
.54998 .14549 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.26864 .24808 m
.26634 .25083 L
s
1 .231 0 r
.01 w
.37722 .14531 Mdot
1 .232 0 r
[ .05 .05 ] 0 setdash
.38027 .14432 m
.37722 .14531 L
s
0 0 0 r
.004 w
.68954 .14527 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68784 .22322 m
.68997 .21899 L
s
0 0 0 r
.004 w
.35964 .14511 Mdot
.53 .8 .95 r
.006 w
.72062 .21961 m
.71906 .2236 L
s
1 .488 0 r
.01 w
[ .05 .05 ] 0 setdash
.64203 .14492 m
.63907 .14388 L
s
.64203 .14492 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70786 .21017 m
.70647 .2152 L
s
1 .43 0 r
.01 w
.55057 .14451 Mdot
1 .431 0 r
[ .05 .05 ] 0 setdash
.55126 .14347 m
.55057 .14451 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64089 .2237 m
.64365 .22763 L
s
0 0 0 r
.004 w
.36161 .14446 Mdot
.53 .8 .95 r
.006 w
.68051 .18811 m
.67894 .17945 L
s
.54669 .15516 m
.54672 .15696 L
s
1 .232 0 r
.01 w
.38027 .14432 Mdot
1 .233 0 r
[ .05 .05 ] 0 setdash
.38293 .14345 m
.38027 .14432 L
s
0 0 0 r
.004 w
.68621 .14417 Mdot
1 .283 0 r
.01 w
.6377 .14412 m
.63422 .1429 L
s
.6377 .14412 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67025 .18017 m
.6694 .18399 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.64136 .20554 m
.63907 .14388 L
s
1 .487 0 r
.01 w
[ .05 .05 ] 0 setdash
.63907 .14388 m
.6362 .14293 L
s
.63907 .14388 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54772 .15967 m
.54733 .15607 L
s
0 0 0 r
.004 w
.36358 .14382 Mdot
1 .431 0 r
.01 w
.55126 .14347 Mdot
[ .05 .05 ] 0 setdash
.55197 .14242 m
.55126 .14347 L
s
1 .233 0 r
.38293 .14345 Mdot
.38533 .14263 m
.38293 .14345 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68561 .22685 m
.68784 .22322 L
s
0 0 0 r
.004 w
.36556 .14319 Mdot
.6829 .1431 Mdot
1 .487 0 r
.01 w
[ .05 .05 ] 0 setdash
.6362 .14293 m
.63309 .1419 L
s
.6362 .14293 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54672 .15696 m
.54685 .15739 L
s
1 .282 0 r
.01 w
[ .05 .05 ] 0 setdash
.63422 .1429 m
.63039 .14148 L
s
.63422 .1429 Mdot
1 .233 0 r
.38533 .14263 Mdot
1 .234 0 r
.38792 .1417 m
.38533 .14263 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30163 .22104 m
.30013 .21481 L
s
0 0 0 r
.004 w
.36754 .14256 Mdot
.53 .8 .95 r
.006 w
.32445 .19437 m
.32234 .20301 L
s
1 .431 0 r
.01 w
.55197 .14242 Mdot
1 .432 0 r
[ .05 .05 ] 0 setdash
.55275 .1413 m
.55197 .14242 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64365 .22763 m
.64651 .23068 L
s
.54685 .15739 m
.54711 .15717 L
s
.54711 .15717 m
.54753 .15779 L
s
0 0 0 r
.004 w
.67961 .14207 Mdot
.53 .8 .95 r
.006 w
.6829 .22899 m
.68561 .22685 L
s
0 0 0 r
.004 w
.36954 .14194 Mdot
1 .486 0 r
.01 w
[ .05 .05 ] 0 setdash
.63309 .1419 m
.6301 .14101 L
s
.63309 .1419 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33365 .19521 m
.33269 .18839 L
s
1 .234 0 r
.01 w
.38792 .1417 Mdot
[ .05 .05 ] 0 setdash
.39017 .14086 m
.38792 .1417 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54753 .15779 m
.54814 .16077 L
s
.68016 .23065 m
.6829 .22899 L
s
1 .281 0 r
.01 w
[ .05 .05 ] 0 setdash
.63039 .14148 m
.62639 .14004 L
s
.63039 .14148 Mdot
0 0 0 r
.004 w
.37154 .14133 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.55306 .17499 m
.55275 .1413 L
s
1 .432 0 r
.01 w
.55275 .1413 Mdot
[ .05 .05 ] 0 setdash
.55367 .14023 m
.55275 .1413 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67755 .23222 m
.68016 .23065 L
s
.54814 .1633 m
.54772 .15967 L
s
0 0 0 r
.004 w
.67634 .14107 Mdot
1 .486 0 r
.01 w
[ .05 .05 ] 0 setdash
.6301 .14101 m
.62666 .13995 L
s
.6301 .14101 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.64651 .23068 m
.64954 .23326 L
s
1 0 0 r
[ .01 .01 ] 0 setdash
.38799 .19109 m
.39017 .14086 L
s
1 .234 0 r
.01 w
.39017 .14086 Mdot
1 .235 0 r
[ .05 .05 ] 0 setdash
.39238 .14003 m
.39017 .14086 L
s
0 0 0 r
.004 w
.37355 .14072 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.67431 .23333 m
.67755 .23222 L
s
.6694 .18399 m
.66837 .18803 L
s
.71906 .2236 m
.71724 .22749 L
s
.67128 .23473 m
.67431 .23333 L
s
.6021 .21909 m
.60409 .2141 L
s
1 .432 0 r
.01 w
.55367 .14023 Mdot
1 .433 0 r
[ .05 .05 ] 0 setdash
.55467 .13911 m
.55367 .14023 L
s
0 0 0 r
.004 w
.37557 .14012 Mdot
.67309 .14011 Mdot
1 .281 0 r
.01 w
.62639 .14004 m
.62243 .1387 L
s
.62639 .14004 Mdot
1 .235 0 r
.39238 .14003 Mdot
1 .236 0 r
.39456 .13921 m
.39238 .14003 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66816 .23533 m
.67128 .23473 L
s
1 .485 0 r
.01 w
[ .05 .05 ] 0 setdash
.62666 .13995 m
.62341 .13885 L
s
.62666 .13995 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70647 .2152 m
.70476 .22018 L
s
.66508 .23642 m
.66816 .23533 L
s
.64954 .23326 m
.65251 .2345 L
s
.68232 .19674 m
.68051 .18811 L
s
0 0 0 r
.004 w
.3776 .13953 Mdot
.53 .8 .95 r
.006 w
.54814 .16077 m
.54895 .16546 L
s
1 .236 0 r
.01 w
.39456 .13921 Mdot
[ .05 .05 ] 0 setdash
.39654 .13851 m
.39456 .13921 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65251 .2345 m
.65567 .23528 L
s
0 0 0 r
.004 w
.66987 .13917 Mdot
1 .433 0 r
.01 w
.55467 .13911 Mdot
1 .434 0 r
[ .05 .05 ] 0 setdash
.55569 .13801 m
.55467 .13911 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65567 .23528 m
.65888 .23648 L
s
0 0 0 r
.004 w
.37964 .13895 Mdot
.53 .8 .95 r
.006 w
.66189 .23653 m
.66508 .23642 L
s
1 .484 0 r
.01 w
[ .05 .05 ] 0 setdash
.62341 .13885 m
.62011 .13773 L
s
.62341 .13885 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.65888 .23648 m
.66189 .23653 L
s
1 .28 0 r
.01 w
[ .05 .05 ] 0 setdash
.62243 .1387 m
.61832 .13723 L
s
.62243 .1387 Mdot
1 .236 0 r
.39654 .13851 Mdot
1 .237 0 r
.39863 .13782 m
.39654 .13851 L
s
0 0 0 r
.004 w
.38168 .13838 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54857 .16604 m
.54814 .1633 L
s
0 0 0 r
.004 w
.66666 .13827 Mdot
1 .434 0 r
.01 w
.55569 .13801 Mdot
[ .05 .05 ] 0 setdash
.55671 .13695 m
.55569 .13801 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.32234 .20301 m
.3198 .21149 L
s
1 .237 0 r
.01 w
.39863 .13782 Mdot
1 .238 0 r
[ .05 .05 ] 0 setdash
.40069 .13722 m
.39863 .13782 L
s
0 0 0 r
.004 w
.38373 .13781 Mdot
1 .484 0 r
.01 w
.62011 .13773 m
.61694 .13671 L
s
.62011 .13773 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30374 .22536 m
.30163 .22104 L
s
0 0 0 r
.004 w
.66348 .1374 Mdot
.38579 .13725 Mdot
1 .279 0 r
.01 w
[ .05 .05 ] 0 setdash
.61832 .13723 m
.61409 .13576 L
s
.61832 .13723 Mdot
1 .238 0 r
.40069 .13722 Mdot
.40274 .13672 m
.40069 .13722 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66837 .18803 m
.66722 .19253 L
s
1 .434 0 r
.01 w
.55671 .13695 Mdot
1 .435 0 r
[ .05 .05 ] 0 setdash
.55805 .13579 m
.55671 .13695 L
s
1 .238 0 r
.40274 .13672 Mdot
1 .239 0 r
.40498 .13624 m
.40274 .13672 L
s
1 .483 0 r
.61694 .13671 m
.61351 .13558 L
s
.61694 .13671 Mdot
0 0 0 r
.004 w
.38786 .1367 Mdot
.66031 .13655 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54895 .16546 m
.54997 .17114 L
s
.33482 .2019 m
.33365 .19521 L
s
.71724 .22749 m
.71495 .23135 L
s
1 .239 0 r
.01 w
.40498 .13624 Mdot
[ .05 .05 ] 0 setdash
.40722 .13584 m
.40498 .13624 L
s
0 0 0 r
.004 w
.38994 .13615 Mdot
1 .239 0 r
.01 w
.40722 .13584 Mdot
1 .24 0 r
.40967 .13544 m
.40722 .13584 L
s
1 .435 0 r
.55805 .13579 Mdot
1 .436 0 r
.55939 .13467 m
.55805 .13579 L
s
1 .279 0 r
.61409 .13576 m
.60991 .13432 L
s
.61409 .13576 Mdot
0 0 0 r
.004 w
.65716 .13574 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.54907 .16874 m
.54857 .16604 L
s
0 0 0 r
.004 w
.39202 .13562 Mdot
.53 .8 .95 r
.006 w
.60002 .2233 m
.6021 .21909 L
s
1 .482 0 r
.01 w
[ .05 .05 ] 0 setdash
.61351 .13558 m
.61019 .13449 L
s
.61351 .13558 Mdot
1 .24 0 r
.40967 .13544 Mdot
1 .241 0 r
.4122 .13507 m
.40967 .13544 L
s
0 0 0 r
.004 w
.39412 .13509 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.41037 .18559 m
.4122 .13507 L
s
1 .241 0 r
.01 w
.4122 .13507 Mdot
[ .05 .05 ] 0 setdash
.41488 .13475 m
.4122 .13507 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70476 .22018 m
.70277 .22425 L
s
0 0 0 r
.004 w
.65403 .13495 Mdot
.53 .8 .95 r
.006 w
.68459 .20497 m
.68232 .19674 L
s
1 .241 0 r
.01 w
.41488 .13475 Mdot
1 .242 0 r
[ .05 .05 ] 0 setdash
.41784 .1344 m
.41488 .13475 L
s
1 .436 0 r
.55939 .13467 Mdot
.5606 .13359 m
.55939 .13467 L
s
0 0 0 r
.004 w
.39622 .13457 Mdot
1 .482 0 r
.01 w
.61019 .13449 m
.60685 .13342 L
s
.61019 .13449 Mdot
1 .242 0 r
.41784 .1344 Mdot
.42085 .13406 m
.41784 .1344 L
s
1 .278 0 r
.60991 .13432 m
.60586 .133 L
s
.60991 .13432 Mdot
0 0 0 r
.004 w
.65092 .13418 Mdot
1 .242 0 r
.01 w
.42085 .13406 Mdot
1 .243 0 r
.42394 .13381 m
.42085 .13406 L
s
0 0 0 r
.004 w
.39833 .13406 Mdot
1 .243 0 r
.01 w
.42394 .13381 Mdot
1 .244 0 r
.42724 .13351 m
.42394 .13381 L
s
1 .436 0 r
.5606 .13359 Mdot
1 .437 0 r
.56203 .13247 m
.5606 .13359 L
s
0 0 0 r
.004 w
.40044 .13355 Mdot
1 .244 0 r
.01 w
.42724 .13351 Mdot
.43053 .13322 m
.42724 .13351 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.3198 .21149 m
.31725 .21874 L
s
0 0 0 r
.004 w
.64782 .13345 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60868 .20189 m
.60685 .13342 L
s
1 .481 0 r
.01 w
[ .05 .05 ] 0 setdash
.60685 .13342 m
.60365 .13235 L
s
.60685 .13342 Mdot
1 .244 0 r
.43053 .13322 Mdot
1 .245 0 r
.43384 .13295 m
.43053 .13322 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30607 .22909 m
.30374 .22536 L
s
.54997 .17114 m
.55117 .17733 L
s
0 0 0 r
.004 w
.40257 .13306 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.60822 .22259 m
.60586 .133 L
s
1 .278 0 r
.01 w
[ .05 .05 ] 0 setdash
.60586 .133 m
.6015 .13149 L
s
.60586 .133 Mdot
1 .245 0 r
.43384 .13295 Mdot
1 .246 0 r
.43702 .1327 m
.43384 .13295 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66722 .19253 m
.66582 .19738 L
s
.54963 .17097 m
.54907 .16874 L
s
0 0 0 r
.004 w
.64474 .13273 Mdot
1 .246 0 r
.01 w
.43702 .1327 Mdot
[ .05 .05 ] 0 setdash
.4404 .13241 m
.43702 .1327 L
s
0 0 0 r
.004 w
.4047 .13257 Mdot
1 .437 0 r
.01 w
.56203 .13247 Mdot
.56334 .13143 m
.56203 .13247 L
s
1 .246 0 r
.4404 .13241 Mdot
1 .247 0 r
.4435 .13218 m
.4404 .13241 L
s
1 .481 0 r
.60365 .13235 m
.60056 .13136 L
s
.60365 .13235 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.44196 .19107 m
.4435 .13218 L
s
1 .247 0 r
.01 w
.4435 .13218 Mdot
[ .05 .05 ] 0 setdash
.44662 .13189 m
.4435 .13218 L
s
0 0 0 r
.004 w
.40684 .13209 Mdot
.64168 .13204 Mdot
1 .247 0 r
.01 w
.44662 .13189 Mdot
1 .248 0 r
.44945 .13168 m
.44662 .13189 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71495 .23135 m
.71271 .23419 L
s
1 .248 0 r
.01 w
.44945 .13168 Mdot
1 .249 0 r
[ .05 .05 ] 0 setdash
.45223 .13144 m
.44945 .13168 L
s
0 0 0 r
.004 w
.40899 .13161 Mdot
1 .277 0 r
.01 w
.6015 .13149 m
.59762 .13034 L
s
.6015 .13149 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.5975 .22495 m
.60002 .2233 L
s
1 .249 0 r
.01 w
.45223 .13144 Mdot
[ .05 .05 ] 0 setdash
.45476 .13124 m
.45223 .13144 L
s
1 .437 0 r
.56334 .13143 Mdot
1 .438 0 r
.56467 .13043 m
.56334 .13143 L
s
0 0 0 r
.004 w
.63863 .13138 Mdot
1 .48 0 r
.01 w
.60056 .13136 m
.5976 .1304 L
s
.60056 .13136 Mdot
1 .249 0 r
.45476 .13124 Mdot
1 .25 0 r
.45705 .13109 m
.45476 .13124 L
s
0 0 0 r
.004 w
.41115 .13115 Mdot
1 .25 0 r
.01 w
.45705 .13109 Mdot
.45934 .13089 m
.45705 .13109 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33666 .20769 m
.33482 .2019 L
s
1 .25 0 r
.01 w
.45934 .13089 Mdot
1 .251 0 r
[ .05 .05 ] 0 setdash
.46133 .13073 m
.45934 .13089 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68701 .21252 m
.68459 .20497 L
s
0 0 0 r
.004 w
.6356 .13073 Mdot
1 .251 0 r
.01 w
.46133 .13073 Mdot
1 .252 0 r
[ .05 .05 ] 0 setdash
.46338 .13054 m
.46133 .13073 L
s
0 0 0 r
.004 w
.41331 .13069 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70277 .22425 m
.70042 .22744 L
s
1 .252 0 r
.01 w
.46338 .13054 Mdot
[ .05 .05 ] 0 setdash
.46538 .13037 m
.46338 .13054 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.56513 .16551 m
.56467 .13043 L
s
1 .438 0 r
.01 w
.56467 .13043 Mdot
1 .439 0 r
[ .05 .05 ] 0 setdash
.56585 .12954 m
.56467 .13043 L
s
1 .479 0 r
.5976 .1304 m
.59494 .12949 L
s
.5976 .1304 Mdot
1 .252 0 r
.46538 .13037 Mdot
1 .253 0 r
.46737 .13022 m
.46538 .13037 L
s
1 .276 0 r
.59762 .13034 m
.59358 .12914 L
s
.59762 .13034 Mdot
0 0 0 r
.004 w
.41548 .13025 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.46668 .16756 m
.46737 .13022 L
s
1 .253 0 r
.01 w
.46737 .13022 Mdot
1 .254 0 r
[ .05 .05 ] 0 setdash
.46958 .13003 m
.46737 .13022 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55021 .17268 m
.54963 .17097 L
s
0 0 0 r
.004 w
.63258 .13011 Mdot
1 .254 0 r
.01 w
.46958 .13003 Mdot
[ .05 .05 ] 0 setdash
.47188 .12985 m
.46958 .13003 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31725 .21874 m
.31434 .22524 L
s
1 .254 0 r
.01 w
.47188 .12985 Mdot
1 .255 0 r
[ .05 .05 ] 0 setdash
.47427 .12969 m
.47188 .12985 L
s
0 0 0 r
.004 w
.41767 .12981 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55117 .17733 m
.55265 .18364 L
s
1 .255 0 r
.01 w
.47427 .12969 Mdot
[ .05 .05 ] 0 setdash
.47713 .12948 m
.47427 .12969 L
s
1 .439 0 r
.56585 .12954 Mdot
.567 .12868 m
.56585 .12954 L
s
0 0 0 r
.004 w
.62958 .12951 Mdot
1 .479 0 r
.01 w
.59494 .12949 m
.59242 .12867 L
s
.59494 .12949 Mdot
1 .255 0 r
.47713 .12948 Mdot
1 .256 0 r
.48008 .12929 m
.47713 .12948 L
s
0 0 0 r
.004 w
.41986 .12937 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.30866 .23038 m
.30607 .22909 L
s
1 .256 0 r
.01 w
.48008 .12929 Mdot
1 .257 0 r
[ .05 .05 ] 0 setdash
.48312 .12915 m
.48008 .12929 L
s
.48312 .12915 Mdot
.48666 .12886 m
.48312 .12915 L
s
1 .276 0 r
.59358 .12914 m
.58966 .1281 L
s
.59358 .12914 Mdot
0 0 0 r
.004 w
.42205 .12895 Mdot
.62659 .12894 Mdot
1 .257 0 r
.01 w
.48666 .12886 Mdot
1 .258 0 r
.49032 .12865 m
.48666 .12886 L
s
1 .439 0 r
.567 .12868 Mdot
1 .44 0 r
.56805 .12791 m
.567 .12868 L
s
1 .478 0 r
.59242 .12867 m
.59013 .1279 L
s
.59242 .12867 Mdot
1 .258 0 r
.49032 .12865 Mdot
.49416 .12835 m
.49032 .12865 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.59494 .22571 m
.5975 .22495 L
s
0 0 0 r
.004 w
.42426 .12854 Mdot
.62361 .12838 Mdot
1 .258 0 r
.01 w
.49416 .12835 Mdot
1 .259 0 r
[ .05 .05 ] 0 setdash
.49823 .12813 m
.49416 .12835 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.66582 .19738 m
.66428 .20135 L
s
0 0 0 r
.004 w
.42647 .12813 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.49755 .20871 m
.49823 .12813 L
s
1 .259 0 r
.01 w
.49823 .12813 Mdot
1 .26 0 r
[ .05 .05 ] 0 setdash
.50254 .12781 m
.49823 .12813 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.71271 .23419 m
.71002 .23609 L
s
1 .275 0 r
.01 w
[ .05 .05 ] 0 setdash
.58966 .1281 m
.58579 .12726 L
s
.58966 .1281 Mdot
1 .44 0 r
.56805 .12791 Mdot
.5689 .12722 m
.56805 .12791 L
s
1 .477 0 r
.59013 .1279 m
.58812 .12724 L
s
.59013 .1279 Mdot
0 0 0 r
.004 w
.62065 .12784 Mdot
1 .26 0 r
.01 w
.50254 .12781 Mdot
.50698 .12749 m
.50254 .12781 L
s
0 0 0 r
.004 w
.42869 .12773 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55081 .17355 m
.55021 .17268 L
s
1 .26 0 r
.01 w
.50698 .12749 Mdot
1 .261 0 r
[ .05 .05 ] 0 setdash
.51128 .12718 m
.50698 .12749 L
s
0 0 0 r
.004 w
.43092 .12734 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.68959 .21948 m
.68701 .21252 L
s
0 0 0 r
.004 w
.61771 .12733 Mdot
1 .275 0 r
.01 w
[ .05 .05 ] 0 setdash
.58579 .12726 m
.58233 .12655 L
s
.58579 .12726 Mdot
1 .477 0 r
.58812 .12724 m
.58641 .12668 L
s
.58812 .12724 Mdot
1 .44 0 r
.5689 .12722 Mdot
1 .441 0 r
.56959 .12662 m
.5689 .12722 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31434 .22524 m
.31146 .22884 L
s
1 .261 0 r
.01 w
.51128 .12718 Mdot
1 .262 0 r
[ .05 .05 ] 0 setdash
.51596 .12683 m
.51128 .12718 L
s
0 0 0 r
.004 w
.43316 .12696 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.31146 .22884 m
.30866 .23038 L
s
1 .262 0 r
.01 w
.51596 .12683 Mdot
[ .05 .05 ] 0 setdash
.52024 .12657 m
.51596 .12683 L
s
0 0 0 r
.004 w
.61477 .12683 Mdot
1 .476 0 r
.01 w
.58641 .12668 m
.58498 .12622 L
s
.58641 .12668 Mdot
1 .441 0 r
.56959 .12662 Mdot
1 .442 0 r
.57025 .12609 m
.56959 .12662 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.70042 .22744 m
.69788 .22796 L
s
0 0 0 r
.004 w
.43541 .12659 Mdot
1 .262 0 r
.01 w
.52024 .12657 Mdot
1 .263 0 r
[ .05 .05 ] 0 setdash
.52485 .12623 m
.52024 .12657 L
s
1 .274 0 r
.58233 .12655 m
.57891 .126 L
s
.58233 .12655 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.55265 .18364 m
.55432 .1892 L
s
.59239 .22551 m
.59494 .22571 L
s
0 0 0 r
.004 w
.61185 .12635 Mdot
1 .263 0 r
.01 w
.52485 .12623 Mdot
[ .05 .05 ] 0 setdash
.52881 .12608 m
.52485 .12623 L
s
0 0 0 r
.004 w
.43766 .12622 Mdot
1 .476 0 r
.01 w
.58498 .12622 m
.5839 .12587 L
s
.58498 .12622 Mdot
1 .442 0 r
.57025 .12609 Mdot
.57078 .12564 m
.57025 .12609 L
s
1 .263 0 r
.52881 .12608 Mdot
1 .264 0 r
.53326 .12578 m
.52881 .12608 L
s
1 .273 0 r
.57891 .126 m
.57568 .12552 L
s
.57891 .126 Mdot
0 0 0 r
.004 w
.60895 .12589 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58426 .14418 m
.5839 .12587 L
s
1 .475 0 r
.01 w
[ .05 .05 ] 0 setdash
.5839 .12587 m
.58307 .12562 L
s
.5839 .12587 Mdot
0 0 0 r
.004 w
.43993 .12587 Mdot
1 .264 0 r
.01 w
.53326 .12578 Mdot
1 .265 0 r
.53722 .12567 m
.53326 .12578 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.33853 .21314 m
.33666 .20769 L
s
1 .265 0 r
.01 w
.53722 .12567 Mdot
[ .05 .05 ] 0 setdash
.54083 .12557 m
.53722 .12567 L
s
1 .442 0 r
.57078 .12564 Mdot
1 .443 0 r
.57123 .12527 m
.57078 .12564 L
s
1 .474 0 r
.58307 .12562 m
.58247 .12545 L
s
.58307 .12562 Mdot
1 .46 0 r
.58256 .12559 m
.58255 .12558 L
s
.58256 .12559 Mdot
.58254 .12558 m
.58256 .12559 L
s
.58254 .12558 Mdot
1 .461 0 r
.5825 .12557 m
.58254 .12558 L
s
1 .459 0 r
.58255 .12558 m
.58249 .12556 L
s
.58255 .12558 Mdot
1 .461 0 r
.5825 .12557 Mdot
.58246 .12556 m
.5825 .12557 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.5412 .19574 m
.54083 .12557 L
s
1 .265 0 r
.01 w
.54083 .12557 Mdot
1 .266 0 r
[ .05 .05 ] 0 setdash
.54445 .12547 m
.54083 .12557 L
s
1 .458 0 r
.58249 .12556 m
.58239 .12553 L
s
.58249 .12556 Mdot
1 .461 0 r
.58246 .12556 Mdot
1 .462 0 r
.58243 .12555 m
.58246 .12556 L
s
.58243 .12555 Mdot
1 .463 0 r
.58241 .12554 m
.58243 .12555 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58242 .12558 m
.58241 .12554 L
s
1 .463 0 r
.01 w
.58241 .12554 Mdot
[ .05 .05 ] 0 setdash
.58241 .12554 m
.58241 .12554 L
s
.58241 .12554 Mdot
1 .464 0 r
.58241 .12554 m
.58241 .12554 L
s
1 .466 0 r
.58241 .12554 Mdot
1 .465 0 r
.58241 .12554 Mdot
1 .464 0 r
.58241 .12554 Mdot
1 .465 0 r
.58241 .12554 Mdot
1 .467 0 r
.58241 .12554 Mdot
1 .468 0 r
.58241 .12554 m
.58241 .12554 L
s
1 .466 0 r
.58241 .12554 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58241 .1256 m
.58241 .12554 L
s
.58241 .12554 m
.58242 .12558 L
s
1 .468 0 r
.01 w
.58241 .12554 Mdot
[ .05 .05 ] 0 setdash
.58237 .12553 m
.58241 .12554 L
s
.58237 .12553 Mdot
1 .469 0 r
.58231 .12552 m
.58237 .12553 L
s
1 .458 0 r
.58239 .12553 m
.58225 .12548 L
s
.58239 .12553 Mdot
1 .273 0 r
.57568 .12552 m
.57277 .12529 L
s
.57568 .12552 Mdot
0 0 0 r
.004 w
.4422 .12552 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58232 .12633 m
.58231 .12552 L
s
1 .469 0 r
.01 w
.58231 .12552 Mdot
[ .05 .05 ] 0 setdash
.58221 .1255 m
.58231 .12552 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58242 .12558 m
.58243 .12575 L
s
.58255 .12571 m
.58251 .12654 L
s
.58257 .12605 m
.58255 .12571 L
s
.58238 .12587 m
.58241 .1256 L
s
1 .469 0 r
.01 w
.58221 .1255 Mdot
1 .47 0 r
[ .05 .05 ] 0 setdash
.58209 .12546 m
.58221 .1255 L
s
1 .457 0 r
.58225 .12548 m
.58207 .12542 L
s
.58225 .12548 Mdot
1 .266 0 r
.54445 .12547 Mdot
1 .267 0 r
.54764 .12543 m
.54445 .12547 L
s
1 .47 0 r
.58209 .12546 Mdot
1 .471 0 r
.58197 .12542 m
.58209 .12546 L
s
0 0 0 r
.004 w
.60605 .12545 Mdot
1 .474 0 r
.01 w
.58247 .12545 m
.58209 .12536 L
s
.58247 .12545 Mdot
1 .267 0 r
.54764 .12543 Mdot
.55081 .12532 m
.54764 .12543 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.58215 .12959 m
.58207 .12542 L
s
1 .457 0 r
.01 w
[ .05 .05 ] 0 setdash
.58207 .12542 m
.58188 .12534 L
s
.58207 .12542 Mdot
1 .471 0 r
.58197 .12542 Mdot
.58188 .12537 m
.58197 .12542 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58243 .12575 m
.58247 .12603 L
s
1 .471 0 r
.01 w
.58188 .12537 Mdot
1 .472 0 r
[ .05 .05 ] 0 setdash
.58184 .12534 m
.58188 .12537 L
s
1 .473 0 r
.58209 .12536 m
.58189 .12533 L
s
.58209 .12536 Mdot
1 .456 0 r
.58188 .12534 m
.58169 .12524 L
s
.58188 .12534 Mdot
1 .472 0 r
.58184 .12534 Mdot
1 .473 0 r
.58189 .12533 m
.58184 .12534 L
s
.58189 .12533 Mdot
1 .267 0 r
.55081 .12532 Mdot
1 .268 0 r
.55363 .12526 m
.55081 .12532 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58232 .12633 m
.58238 .12587 L
s
.55152 .17432 m
.55081 .17355 L
s
1 .272 0 r
.01 w
[ .05 .05 ] 0 setdash
.57277 .12529 m
.56992 .12513 L
s
.57277 .12529 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58255 .12628 m
.58257 .12605 L
s
1 .443 0 r
.01 w
.57123 .12527 Mdot
1 .444 0 r
[ .05 .05 ] 0 setdash
.57164 .12497 m
.57123 .12527 L
s
1 .268 0 r
.55363 .12526 Mdot
.55649 .12518 m
.55363 .12526 L
s
1 .455 0 r
.58169 .12524 m
.58152 .12514 L
s
.58169 .12524 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58247 .12603 m
.58251 .12624 L
s
0 0 0 r
.004 w
.44448 .12519 Mdot
1 .268 0 r
.01 w
.55649 .12518 Mdot
1 .269 0 r
[ .05 .05 ] 0 setdash
.55914 .12511 m
.55649 .12518 L
s
1 .455 0 r
.58152 .12514 m
.58133 .12503 L
s
.58152 .12514 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57071 .17838 m
.56992 .12513 L
s
1 .271 0 r
.01 w
[ .05 .05 ] 0 setdash
.56992 .12513 m
.56701 .12509 L
s
.56992 .12513 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58251 .12624 m
.58255 .12628 L
s
1 .269 0 r
.01 w
.55914 .12511 Mdot
1 .27 0 r
[ .05 .05 ] 0 setdash
.56183 .12502 m
.55914 .12511 L
s
1 .271 0 r
.56701 .12509 m
.56446 .12502 L
s
.56701 .12509 Mdot
0 0 0 r
.004 w
.60317 .12503 Mdot
1 .454 0 r
.01 w
.58133 .12503 m
.58109 .12492 L
s
.58133 .12503 Mdot
1 .27 0 r
.56446 .12502 m
.56183 .12502 L
s
.56446 .12502 Mdot
.56183 .12502 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58224 .12686 m
.58232 .12633 L
s
1 .444 0 r
.01 w
.57164 .12497 Mdot
[ .05 .05 ] 0 setdash
.5721 .12476 m
.57164 .12497 L
s
1 .453 0 r
.58109 .12492 m
.58077 .1248 L
s
.58109 .12492 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58251 .12654 m
.58243 .12755 L
s
.71002 .23609 m
.70717 .23823 L
s
0 0 0 r
.004 w
.44676 .12486 Mdot
.53 .8 .95 r
.006 w
.58949 .22412 m
.59239 .22551 L
s
1 .453 0 r
.01 w
[ .05 .05 ] 0 setdash
.58077 .1248 m
.58037 .12468 L
s
.58077 .1248 Mdot
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57223 .1331 m
.5721 .12476 L
s
1 .444 0 r
.01 w
.5721 .12476 Mdot
1 .445 0 r
[ .05 .05 ] 0 setdash
.57262 .12461 m
.5721 .12476 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58191 .12625 m
.58186 .1265 L
s
.58216 .12893 m
.58191 .12625 L
s
1 .452 0 r
.01 w
[ .05 .05 ] 0 setdash
.58037 .12468 m
.57989 .12457 L
s
.58037 .12468 Mdot
0 0 0 r
.004 w
.6003 .12463 Mdot
1 .445 0 r
.01 w
.57262 .12461 Mdot
.57324 .12451 m
.57262 .12461 L
s
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58213 .12735 m
.58224 .12686 L
s
1 .452 0 r
.01 w
[ .05 .05 ] 0 setdash
.57989 .12457 m
.57931 .12448 L
s
.57989 .12457 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.58186 .1265 m
.58192 .12733 L
s
0 0 0 r
.004 w
.44906 .12454 Mdot
1 .445 0 r
.01 w
.57324 .12451 Mdot
1 .446 0 r
[ .05 .05 ] 0 setdash
.57392 .12447 m
.57324 .12451 L
s
1 .451 0 r
.57931 .12448 m
.57869 .12444 L
s
.57931 .12448 Mdot
1 .446 0 r
.57392 .12447 Mdot
1 .447 0 r
.57462 .12445 m
.57392 .12447 L
s
1 .448 0 r
.57661 .12446 m
.57598 .12444 L
s
.57661 .12446 Mdot
1 .449 0 r
.57731 .12445 m
.57661 .12446 L
s
1 .447 0 r
.57528 .12445 m
.57462 .12445 L
s
.57528 .12445 Mdot
1 .448 0 r
.57598 .12444 m
.57528 .12445 L
s
1 .447 0 r
.57462 .12445 Mdot
1 .449 0 r
.57731 .12445 Mdot
1 .45 0 r
.57802 .12444 m
.57731 .12445 L
s
1 0 0 r
.006 w
[ .01 .01 ] 0 setdash
.57889 .13568 m
.57869 .12444 L
s
1 .45 0 r
.01 w
[ .05 .05 ] 0 setdash
.57869 .12444 m
.57802 .12444 L
s
.57869 .12444 Mdot
1 .448 0 r
.57598 .12444 Mdot
1 .45 0 r
.57802 .12444 Mdot
.53 .8 .95 r
.006 w
[ ] 0 setdash
.69788 .22796 m
.69511 .22694 L
s
.66428 .20135 m
.66243 .20462 L
s
.69233 .22395 m
.68959 .21948 L
s
0 0 0 r
.004 w
.59745 .12424 Mdot
.45136 .12423 Mdot
.53 .8 .95 r
.006 w
.58201 .12759 m
.58213 .12735 L
s
.58243 .12755 m
.58231 .1286 L
s
.58192 .12733 m
.58201 .12759 L
s
0 0 0 r
.004 w
.45368 .12392 Mdot
.53 .8 .95 r
.006 w
.55432 .1892 m
.55629 .19436 L
s
0 0 0 r
.004 w
.5946 .12387 Mdot
.53 .8 .95 r
.006 w
.5867 .22204 m
.58949 .22412 L
s
0 0 0 r
.004 w
.456 .12363 Mdot
.59177 .12351 Mdot
.53 .8 .95 r
.006 w
.58231 .1286 m
.58215 .12959 L
s
0 0 0 r
.004 w
.45833 .12335 Mdot
.53 .8 .95 r
.006 w
.69511 .22694 m
.69233 .22395 L
s
.58396 .2197 m
.5867 .22204 L
s
0 0 0 r
.004 w
.58895 .12318 Mdot
.46066 .12307 Mdot
.53 .8 .95 r
.006 w
.55226 .17487 m
.55152 .17432 L
s
.58261 .13295 m
.58216 .12893 L
s
.58112 .21806 m
.58396 .2197 L
s
0 0 0 r
.004 w
.58614 .12286 Mdot
.46301 .12281 Mdot
.53 .8 .95 r
.006 w
.58215 .12959 m
.58197 .13032 L
s
0 0 0 r
.004 w
.46536 .12255 Mdot
.58334 .12255 Mdot
.46772 .12231 Mdot
.58055 .12226 Mdot
.53 .8 .95 r
.006 w
.57845 .21655 m
.58112 .21806 L
s
0 0 0 r
.004 w
.4701 .12207 Mdot
.53 .8 .95 r
.006 w
.58197 .13032 m
.58179 .13069 L
s
0 0 0 r
.004 w
.57778 .12199 Mdot
.47247 .12184 Mdot
.53 .8 .95 r
.006 w
.55629 .19436 m
.55834 .19947 L
s
0 0 0 r
.004 w
.57501 .12173 Mdot
.47486 .12163 Mdot
.53 .8 .95 r
.006 w
.58179 .13069 m
.58162 .13072 L
s
.5757 .2147 m
.57845 .21655 L
s
0 0 0 r
.004 w
.57226 .12149 Mdot
.47726 .12142 Mdot
.53 .8 .95 r
.006 w
.58162 .13072 m
.58144 .13106 L
s
.70717 .23823 m
.70415 .23905 L
s
0 0 0 r
.004 w
.56951 .12126 Mdot
.47966 .12122 Mdot
.53 .8 .95 r
.006 w
.57299 .2127 m
.5757 .2147 L
s
0 0 0 r
.004 w
.56678 .12104 Mdot
.48208 .12103 Mdot
.53 .8 .95 r
.006 w
.58144 .13106 m
.58121 .1312 L
s
.55306 .17499 m
.55226 .17487 L
s
0 0 0 r
.004 w
.4845 .12085 Mdot
.56406 .12084 Mdot
.53 .8 .95 r
.006 w
.57043 .21176 m
.57299 .2127 L
s
.34099 .21727 m
.33853 .21314 L
s
.58121 .1312 m
.58089 .13133 L
s
0 0 0 r
.004 w
.48693 .12069 Mdot
.56135 .12066 Mdot
.53 .8 .95 r
.006 w
.66243 .20462 m
.66041 .20789 L
s
0 0 0 r
.004 w
.48937 .12053 Mdot
.55865 .12049 Mdot
.53 .8 .95 r
.006 w
.58331 .13808 m
.58261 .13295 L
s
.58089 .13133 m
.58051 .13237 L
s
0 0 0 r
.004 w
.49181 .12038 Mdot
.55596 .12033 Mdot
.49427 .12024 Mdot
.55328 .12018 Mdot
.49674 .12012 Mdot
.55061 .12005 Mdot
.49921 .12 Mdot
.53 .8 .95 r
.006 w
.55834 .19947 m
.56063 .20359 L
s
0 0 0 r
.004 w
.54795 .11993 Mdot
.50169 .1199 Mdot
.5453 .11983 Mdot
.50418 .1198 Mdot
.53 .8 .95 r
.006 w
.56786 .21028 m
.57043 .21176 L
s
0 0 0 r
.004 w
.54266 .11974 Mdot
.50669 .11972 Mdot
.54003 .11966 Mdot
.50919 .11964 Mdot
.5374 .11959 Mdot
.51171 .11958 Mdot
.53479 .11954 Mdot
.51424 .11953 Mdot
.53 .8 .95 r
.006 w
.58051 .13237 m
.58004 .13333 L
s
0 0 0 r
.004 w
.53219 .11949 Mdot
.51678 .11949 Mdot
.5296 .11946 Mdot
.51932 .11946 Mdot
.52702 .11945 Mdot
.52188 .11944 Mdot
.52444 .11944 Mdot
.53 .8 .95 r
.006 w
.57223 .1331 m
.57178 .13362 L
s
.57276 .13359 m
.57223 .1331 L
s
.57178 .13362 m
.57139 .13595 L
s
.5654 .20844 m
.56786 .21028 L
s
.554 .17522 m
.55306 .17499 L
s
.56063 .20359 m
.56292 .2062 L
s
.56292 .2062 m
.5654 .20844 L
s
.58004 .13333 m
.57949 .13425 L
s
.70415 .23905 m
.70075 .23913 L
s
.57341 .13517 m
.57276 .13359 L
s
.57139 .13595 m
.57098 .13908 L
s
.57949 .13425 m
.57889 .13568 L
s
.57413 .13708 m
.57341 .13517 L
s
.58426 .14418 m
.58331 .13808 L
s
.55502 .17536 m
.554 .17522 L
s
.57889 .13568 m
.57824 .1369 L
s
.66041 .20789 m
.65811 .21064 L
s
.57098 .13908 m
.57051 .143 L
s
.3434 .21989 m
.34099 .21727 L
s
.70075 .23913 m
.69765 .23899 L
s
.57824 .1369 m
.57755 .13805 L
s
.57484 .13849 m
.57413 .13708 L
s
.57755 .13805 m
.57685 .13888 L
s
.55607 .17584 m
.55502 .17536 L
s
.57553 .13928 m
.57484 .13849 L
s
.57685 .13888 m
.57623 .13934 L
s
.57051 .143 m
.5699 .14764 L
s
.57623 .13934 m
.57553 .13928 L
s
.69765 .23899 m
.6943 .23874 L
s
.58547 .15106 m
.58426 .14418 L
s
.3463 .22007 m
.3434 .21989 L
s
.65811 .21064 m
.65565 .21197 L
s
.55711 .17553 m
.55607 .17584 L
s
.5699 .14764 m
.56926 .15223 L
s
.6943 .23874 m
.69062 .23835 L
s
.65783 .20651 m
.65512 .20465 L
s
.66066 .20926 m
.65783 .20651 L
s
.66355 .21236 m
.66066 .20926 L
s
.65512 .20465 m
.65241 .20312 L
s
.55847 .17474 m
.55711 .17553 L
s
.6667 .2167 m
.66355 .21236 L
s
.34955 .21978 m
.3463 .22007 L
s
.65241 .20312 m
.64972 .2028 L
s
.56926 .15223 m
.56845 .15596 L
s
.65565 .21197 m
.65301 .21347 L
s
.6699 .22077 m
.6667 .2167 L
s
.69062 .23835 m
.68735 .23658 L
s
.55983 .17367 m
.55847 .17474 L
s
.39904 .17851 m
.39691 .18011 L
s
.4011 .17839 m
.39904 .17851 L
s
.64972 .2028 m
.64703 .20341 L
s
.39691 .18011 m
.39472 .18247 L
s
.58705 .15809 m
.58547 .15106 L
s
.35244 .21966 m
.34955 .21978 L
s
.39472 .18247 m
.39264 .18487 L
s
.67321 .22487 m
.6699 .22077 L
s
.68735 .23658 m
.68377 .23436 L
s
.56845 .15596 m
.56742 .1593 L
s
.40332 .17932 m
.4011 .17839 L
s
.39264 .18487 m
.39035 .18758 L
s
.56106 .17236 m
.55983 .17367 L
s
.39035 .18758 m
.38799 .19109 L
s
.68377 .23436 m
.68023 .23231 L
s
.67658 .22924 m
.67321 .22487 L
s
.56742 .1593 m
.5663 .16301 L
s
.35586 .21779 m
.35244 .21966 L
s
.64703 .20341 m
.64429 .2043 L
s
.56249 .17034 m
.56106 .17236 L
s
.68023 .23231 m
.67658 .22924 L
s
.4055 .1813 m
.40332 .17932 L
s
.38799 .19109 m
.38564 .19355 L
s
.38564 .19355 m
.38292 .19647 L
s
.65301 .21347 m
.65019 .21526 L
s
.5638 .16787 m
.56249 .17034 L
s
.359 .21639 m
.35586 .21779 L
s
.5663 .16301 m
.56513 .16551 L
s
.56513 .16551 m
.5638 .16787 L
s
.38292 .19647 m
.38039 .1991 L
s
.38039 .1991 m
.37757 .20245 L
s
.36219 .21505 m
.359 .21639 L
s
.46266 .1671 m
.46055 .16865 L
s
.46468 .16691 m
.46266 .1671 L
s
.46668 .16756 m
.46468 .16691 L
s
.37757 .20245 m
.37434 .20603 L
s
.64429 .2043 m
.64136 .20554 L
s
.58892 .16601 m
.58705 .15809 L
s
.40791 .1829 m
.4055 .1813 L
s
.36535 .21386 m
.36219 .21505 L
s
.46055 .16865 m
.45848 .17165 L
s
.46887 .16999 m
.46668 .16756 L
s
.37434 .20603 m
.3716 .2087 L
s
.36851 .21099 m
.36535 .21386 L
s
.3716 .2087 m
.36851 .21099 L
s
.65019 .21526 m
.6472 .21703 L
s
.41037 .18559 m
.40791 .1829 L
s
.45848 .17165 m
.45608 .17538 L
s
.47114 .17343 m
.46887 .16999 L
s
.64136 .20554 m
.63851 .20697 L
s
.45608 .17538 m
.45369 .17866 L
s
.41299 .18816 m
.41037 .18559 L
s
.5911 .17345 m
.58892 .16601 L
s
.47349 .17737 m
.47114 .17343 L
s
.6472 .21703 m
.64398 .21869 L
s
.63851 .20697 m
.63544 .2089 L
s
.45369 .17866 m
.45104 .18211 L
s
.4159 .19065 m
.41299 .18816 L
s
.47634 .18126 m
.47349 .17737 L
s
.45104 .18211 m
.44815 .18518 L
s
.63544 .2089 m
.63244 .20953 L
s
.59356 .18016 m
.5911 .17345 L
s
.64398 .21869 m
.64055 .22193 L
s
.41886 .19329 m
.4159 .19065 L
s
.44815 .18518 m
.44519 .1886 L
s
.63244 .20953 m
.62898 .21006 L
s
.47925 .18655 m
.47634 .18126 L
s
.42191 .19607 m
.41886 .19329 L
s
.59623 .18602 m
.59356 .18016 L
s
.44519 .1886 m
.44196 .19107 L
s
.62898 .21006 m
.6257 .21055 L
s
.5624 .17224 m
.55967 .1728 L
s
.56509 .17367 m
.5624 .17224 L
s
.55967 .1728 m
.557 .17378 L
s
.44196 .19107 m
.43874 .19344 L
s
.64055 .22193 m
.63711 .22445 L
s
.557 .17378 m
.55411 .17632 L
s
.56772 .1759 m
.56509 .17367 L
s
.42524 .197 m
.42191 .19607 L
s
.59905 .19147 m
.59623 .18602 L
s
.43874 .19344 m
.43522 .19616 L
s
.6257 .21055 m
.62234 .20979 L
s
.42857 .19765 m
.42524 .197 L
s
.55411 .17632 m
.55129 .18052 L
s
.57071 .17838 m
.56772 .1759 L
s
.48227 .19252 m
.47925 .18655 L
s
.43522 .19616 m
.43196 .19715 L
s
.43196 .19715 m
.42857 .19765 L
s
.62234 .20979 m
.61907 .208 L
s
.60213 .19506 m
.59905 .19147 L
s
.57366 .18188 m
.57071 .17838 L
s
.61907 .208 m
.61554 .2059 L
s
.63711 .22445 m
.63329 .22618 L
s
.60534 .19846 m
.60213 .19506 L
s
.61554 .2059 m
.61211 .20393 L
s
.55129 .18052 m
.54809 .18526 L
s
.61211 .20393 m
.60868 .20189 L
s
.60868 .20189 m
.60534 .19846 L
s
.57669 .18598 m
.57366 .18188 L
s
.48582 .19742 m
.48227 .19252 L
s
.63329 .22618 m
.62928 .22765 L
s
.54809 .18526 m
.54488 .19089 L
s
.58003 .18941 m
.57669 .18598 L
s
.58361 .1943 m
.58003 .18941 L
s
.48951 .20204 m
.48582 .19742 L
s
.62928 .22765 m
.62528 .22855 L
s
.54488 .19089 m
.5412 .19574 L
s
.58722 .19883 m
.58361 .1943 L
s
.4934 .20546 m
.48951 .20204 L
s
.59128 .20447 m
.58722 .19883 L
s
.62528 .22855 m
.6211 .2287 L
s
.5412 .19574 m
.53753 .20057 L
s
.59539 .20987 m
.59128 .20447 L
s
.49755 .20871 m
.4934 .20546 L
s
.6211 .2287 m
.61674 .22707 L
s
.53753 .20057 m
.53349 .20445 L
s
.59962 .21455 m
.59539 .20987 L
s
.61674 .22707 m
.61244 .22574 L
s
.50196 .2097 m
.49755 .20871 L
s
.6037 .21942 m
.59962 .21455 L
s
.61244 .22574 m
.60822 .22259 L
s
.60822 .22259 m
.6037 .21942 L
s
.53349 .20445 m
.52893 .20829 L
s
.50651 .2108 m
.50196 .2097 L
s
.51092 .21193 m
.50651 .2108 L
s
.52893 .20829 m
.52486 .20976 L
s
.51573 .21141 m
.51092 .21193 L
s
.52486 .20976 m
.52012 .21062 L
s
.52012 .21062 m
.51573 .21141 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{438, 302.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f0001;Q000`40O003h00Oogoo]goo003oOong
Ool00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00
ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOong
Ool00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00
ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOong
Ool00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00
ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOong
Ool00?mookMoo`00e7oo300000=oo`0000003@0000Aoo`0000000<9oo`00bWoo2P0047oo0Wd02goo
0gd01P0000=m`00000000P00]goo0032Ool8000;Ool2O@05OolIO@09OL001GgP00000000Ool00`00
/7oo002mOol50005Ool2O>04OolXO@09OL05ON03Ool300000goo0000002ZOol00;Moo`H000Aoo`Il
h2im00Im`093?P03OL1mh7gP009mh09m00=mh0Eoo`800003Ool000000:Eoo`00/goo100047cP;Wd0
17g000Al04<n@ci3?PEmh003O@1mh7gP00=mh09m00Moo`<00003Ool007oo09moo`00[goo100057cP
7Gd01Woo0W`017oo0WfP17g00d<n00El04<n@ci3?Wd000Emh004O@1mh7gPON04O@000ggPOomoo`08
Ool200000goo001oo`2KOol00:Yoo`D001Qlh0im01Eoo`9l00=oo`=mX0Am`0M3?P05Oomm07d0O@1m
h002O@02ON04O@03ON02O@000ggPOomoo`08Ool3002IOol00:Moo`<001mlh0=oo`9l01aoo`9l009o
o`AmX004OL1l07`0OL07@ch4Ool5ON000gd0ON1m0004ON02O@04ON0;Ool3002EOol00:Aoo`<001Il
h0Eoo`9l00Qoo`9l00Yoo`9l01=oo`ImX09l0003Oom3?T<n00E3?PMoo`=l009m0004ON1m07gPON02
O@05ON000gdPON1oo`0;Ool2002BOol00:1oo`@0015lh09l00]oo`9l00Qoo`9l00Yoo`9l019oo`Im
X004Ooml07`0Ool4@ch00goo@ci3?P07Ool3O0000gooON1m0003ON000gd0ON1mh008ON0<Ool01000
Ool00000SWoo002NOol3000@O>04Ool2O00;Ool2O008Ool2O00:Ool2O00@Ool2O006OJ0017ooO01l
07oo0T<n0goo0d<n1Woo0g`00goo0WgP0Wd017gP00=m87gPON001WgP3Goo00<007oo0000Rgoo002K
Ool300000gcPOomlh00;O>02O007Ool2O00;Ool2O008Ool2O00:Ool2O00@Ool2O007OJ02O0000goo
@ci3?P03Ool3@ch?Ool017dPO@1m07gP0WdP2ggP3Goo00<007oo0000R7oo002IOol2000@O>000goo
O01l000DOol2O008Ool2O00:Ool2O00@Ool2O003OJ02O005OJ02@ch4Ool2@chBOol2OB0@ON0<Ool0
0`00Oomoo`25Ool009Ioo`<0011lh0=oo`9l01Aoo`9l01Aoo`9l011oo`9l0093?P03OJ1l07`000Am
X093?P03O01oogfP009oo`=3?PEoo`=l00aoo`9m80mmh0]oo`03001oo`0008Aoo`00Tgoo0`0000=o
ogcPO>0037cP1goo0W`01goo0W`02goo0W`09Woo0W`00T<n0g`00gfP00Al04<n@cil00AmX003Oom3
?T<n00Eoo`=l00]oo`Al0003OB1mh7gP00imh0]oo`03001oo`00085oo`00TGoo0`003GcP0W`04Woo
0W`057oo0W`07Goo0W`00T<n00=oog`0O0000gfP00Al04<n@ci3?PEmX093?PEoo`=l00]oo`Al0004
Oomm87dPOB09ON000d<nON1mh004ON0;Ool00`00Oomoo`1nOol008moo`80009l`0alh09oo`9l019o
o`9l01Aoo`9l00]oo`9l019oo`=3?P=oo`9mX0=3?P03O01mX7fP00=mX093?P03OommX7oo009oo`=l
00]oo`Al00=oo`=m80Emh0=3?P03OD1mh7gP00Amh0aoo`8007eoo`00SGoo0P0017c02WcP3goo0W`0
1goo0W`02goo0W`01goo0W`02goo0W`04Woo0d<n1Goo0T<n0W`01GfP0T<n17fP00Aoog`0O01l00]o
o`9l00Qoo`03OB1l07`000I3?P03OD1mh7gP00Imh0aoo`03001oogoo07Uoo`00RWoo00=l`0000000
1Wc01gcP27oo00=l07ooOol01goo0W`01goo0W`02goo0W`01goo0T<n2goo0W`04goo0T<n0W`00goo
0d<n00=oogfPOJ000gfP0T<n1GfP0g`02goo0W`02Goo0W`01D<n0We02GgP00=n07ooOol02Goo00<0
07ooOol0N7oo0027Ool2O<020008O<03O>02O009Ool3O008Ool2O007Ool2O00;Ool2O006Ool4@ch:
Ool2O00@Ool2O0000goo@ci3?P02O002Ool3@ch017`0Oomoogoo0gfP0d<n1GfP0gf02Woo17`01goo
0W`014<n1Ge01ggP0gh02goo00<007oo0000MWoo0026Ool00gc000000009O<02O00017c0Ooml07`0
2Goo0W`02Goo0W`01goo0W`02goo0W`01Goo1T<n2Goo0W`047oo0W`000=ood<n@ch00W`000Aood<n
@ci3?P=l00Aoo`04OJ13?T<n@ch6OJ06OH06Ool4O007Ool2O004@ch01GooOF1l07`0OD001ggP1Gh0
37oo00<007ooOol0Lgoo0024Ool>O<0017`0@ci3?T<n0W`02Goo0W`02Goo0W`057oo0W`017oo0d<n
0Woo0T<n2Goo0W`047oo0W`000=ood<n@ch01d<n0W`01Woo0T<n1GfP0W`03Gf00W`00gf017oo0W`0
1D<n00AmH7`0O01mH0=m@004O01mh7gPON06OP0=Ool00`00Oomoo`1aOol008=oo`8000Yl`0=oo`04
O013?T<n@ch2O009Ool2O009Ool2O008Ool00g`0Oomoo`09Ool2O003Ool3@ch3Ool3@chJOol2O000
0goo@ci3?P08@ch00g`0Oomoo`04Ool3@ch017`0OJ1mX7f00W`000=3?Wf0OH002Wf00W`01gf000=m
H7`0@ch014<n00=mH7`0O0000geP00=m@7`0O0000Wh000=mH7h0@ch01Gh00WhP2Woo00<007ooOol0
L7oo0020Ool00gbPO<1l`003O<02@ch017c0O01l`7c01Woo00Al04<n@ci3?P9l00Qoo`=l00eoo`03
@cioogoo009oo`=l00moo`93?PEoo`=3?QUoo`9l009oo`E3?P9oo`=3?PMoo`93?P04O01oogf0OH02
O0000d<nOH1mP008OH04O007OH000gePO013?P04@ch00gePO01l0003OF03O0000gePO013?P03@ch4
OP0014<nOR1n87hP2Woo00<007ooOol0KWoo001mOol4O:05O<02@ch00gc0Oomoo`08Ool3@ch;Ool0
0g`0Oomoo`0;Ool5@ch00gooO01l000?Ool3@ch6Ool2@ch7Ool2O00@Ool2O002Ool4@ch4Ool3@ch6
Ool3@ch3Ool2O0000d<nOH1mP008OH04O007OH001G`0@ci3?T<nOF000d<n0W`00WeP00Eoog`0O01l
07oo00A3?PEn0093?P=n80]oo`03001oogoo06aoo`00O7oo1GbP00=l`4<n@ch00Wc00T<n00=l`7oo
Ool027oo14<n57oo0W`000=ood<n@ch01D<n0W`02Woo0W`00Woo0d<n1goo0d<n1Woo0W`057oo0d<n
1Goo00Al04<n@ci3?PIoo`93?P=oo`9l0004@cioogooOol2O0001Goo@cil07ooOH000W`02Gf000Am
H4<n@cil009mH093?P9l00=oo`9l0003@ciood<n0093?P03Oomn07h0009n00A3?P9n8003OT1oogoo
00Yoo`03001oogoo06Yoo`00NWoo1gbP00Al`4<n@cil`0=3?P9l00Qoo`03O013?T<n0093?QAoo`9l
00=3?P9oo`A3?P03O01oogoo00Qoo`9l0004Oom3?T<n@ch9Ool3@ch5Ool2O00COol3@ch6Ool2O002
@ch6Ool2@ch3Ool2O00014<nOomoogoo0W`00d<n00Al07ooO01l00Yoo`93?P=oo`93?P03O01oogoo
009oo`03O013?T<n00A3?P9oo`03OP1l07`000=3?P=n809n@7Qoo`00NGoo2GbP0T<n00Al04<n@ci3
?P9l00Qoo`E3?PUoo`9l00Uoo`04O013?T<n@ch5Ool4@ch9Ool2O0000goo@ci3?P0;Ool3@ch4Ool2
O00@Ool2O0000goo@ci3?P02@ch5Ool2O004@ch4Ool3@ch3Ool3@ch4Ool4@ch017ooO01l07oo0W`0
00=oog`0O00017oo0T<n0goo0T<n00=l07ooOol00Woo1d<n0goo1D<n0ghP0gi037oo00<007ooOol0
J7oo001hOol:O:06@ch2O008Ool2@ch017oo@ci3?T<n27oo0W`02Goo00=l04<n@ch01goo14<n27oo
00=l04<n@ch00T<n37oo0T<n17oo0W`047oo0W`00T<n0Woo00=3?WooOol00goo0W`000=ood<n@ch0
0T<n17oo0T<n0goo0d<n0goo14<n00El07ooO01l07oo009l0003Ooml07`000Aoo`=3?P9oo`=3?P9l
009oo`M3?P=oo`E3?P03O01n@7i000An@0eoo`03001oogoo06Ioo`00MWoo27bP17oo1T<n0W`027oo
0T<n00=ood<n@ch02Goo0W`02Goo0d<n2Goo0d<n1goo14<n3Woo00=3?WooOol00Woo0W`047oo0W`0
00A3?WooOomoo`93?PAoo`9l00=oo`93?PAoo`A3?P9l0093?P9oo`03O013?T<n00=3?PAoo`9l0003
Ooml07`000=oo`=3?P=oo`93?P03Ooml07`0009oo`M3?P=oo`E3?P04O01n@4<n@ch4OT0>Ool00`00
Oomoo`1TOol007Ioo`ElX003O01lX7bP00Aoo`I3?P9l00Moo`=3?P03Oom3?T<n00Uoo`9l00Qoo`=3
?P]oo`=3?P05Oom3?Woo@cioo`03@ch@Ool2@chEOol00g`0@ci3?P04Ool00d<nOomoo`02Ool2O003
Ool3@ch3Ool00g`0@ci3?P02@ch00g`0@ci3?P02Ool00g`0@ci3?P04@ch00gooO01oo`02O0000goo
O01l0003Ool2@ch017`0Oomoogoo0T<n00Aoog`0O01oo`93?P9l009oo`93?P=oo`I3?P04OT13?T<n
@ch4OT1dOol007Eoo`03O81lX7bP00=lX0Ioo`M3?P9l00Moo`93?P9oo`93?PUoo`9l00Moo`=3?Peo
o`U3?Q5oo`=3?QAoo`=3?PAoo`93?PUoo`=3?P9oo`9l0004Oom3?T<nO003@ch01GooO013?T<nOol0
0T<n00=oog`0O0000g`000=oog`0O0000goo0T<n00Al07ooOomoo`=3?P9l0003Oom3?T<n009l009o
o`93?P=oo`93?P9oo`93?P03Oom3?T<n0093?PAn@0ioo`03001oogoo069oo`00M7oo00<007b0O:00
17bP1Woo14<n00=ood<n@ch02Goo0T<n0Woo0d<n27oo0W`01Woo0d<n3Woo24<n4goo0d<n00=oog`0
O0003goo0d<n1Woo00=3?WooOol027oo0d<n00Aoog`0O01oo`=3?P05Oom3?T<nOoml0002@ch00goo
@ci3?P02Ool4O0000gooO01l0003Ool2@ch017`0Oomoogoo0d<n0W`000=ood<n@ch00W`00Woo0T<n
00=l07ooOol00T<n0Woo0T<n00=l04<n@ch00d<n17i03goo00<007ooOol0H7oo001cOol00`00O81l
P002O:0014<nO:1l07`017oo0T<n17oo0d<n27oo0T<n0goo0T<n47oo0T<n4goo00=3?WooOol05Goo
0d<n0W`03Woo0d<n1goo0T<n0Woo0W`01Woo0T<n00=oog`0O0000Woo1D<n00=ood<n@ch00Woo0T<n
0Woo0W`000E3?WooOomood<n009oo`=3?P03O01oogoo009oo`93?P9l0003Oom3?T<n009l009oo`93
?P=oo`93?P9oo`93?P05O013?T<n@cil0002@ch4OT1aOol0079oo`04001lH7b0O804@ch2O004Ool2
@ch4Ool3@ch00g`0Oomoo`05Ool3@ch2Ool2@ch9Ool00g`0Oomoo`03Ool3@ch/Ool2@ch2O00=Ool3
@ch8Ool3@ch00gooO01l0007Ool014<nOoml07`00Woo00=l04<n@ch01T<n00=ood<n@ch00T<n00=l
04<n@ch024<n0W`017oo0T<n0Woo0T<n17oo0T<n17oo0T<n0Woo0T<n00=l04<n@ch014<n1Gi03goo
00<007ooOol0GWoo001aOol200000gaPO813?P03@ch00gooO01l0004Ool2@ch5Ool2@ch00g`0Oomo
o`05Ool2@ch3Ool2@ch8Ool3O003Ool3@ch]Ool4@ch00goo@cioo`07Ool00d<nOom3?P02@ch:Ool3
@ch2O007Ool2@ch2O002Ool2O0000goo@ci3?P03@ch3Ool=@ch7Ool3@ch00goo@ci3?P04Ool2@ch4
Ool2@ch2Ool9@ch6OT1_Ool0071oo`03001lH7aP009lH0=3?P04O81oog`0O004Ool2@ch5Ool3@ch7
Ool2@ch3Ool2@ch8Ool2O002Ool4@ch_Ool7@ch4Ool6@ch<Ool4@ch8Ool2@ch2O003@ch2Ool4@ch2
Ool6@ch2O0000gooO013?P04@ch6Ool017`0@ci3?W`00T<n0Woo0W`00T<n17oo0T<n0Woo2D<n1gi0
47oo00<007ooOol0Fgoo001_Ool00`00O61lH003O603@ch2Ool2O004Ool3@ch4Ool2@ch00g`0Oomo
o`04Ool3@ch3Ool3@ch7Ool2O0000goo@ci3?P02@chaOol?@ch>Ool4@ch7Ool6@ch5Ool8@ch2Ool2
O0000goo@ci3?P04@ch2O005Ool2@ch00g`0@ci3?P02Ool2O002@ch4Ool2@ch3Ool8@ch00g`0OT1n
@005OT1]Ool006ioo`03001lH7aP00=lH004O013?T<n@ch2Ool2O004Ool2@ch5Ool2@ch00g`0Oomo
o`04Ool2@ch6Ool00d<nOomoo`05Ool00d<nO013?P02@chgOol7@chBOol6@ch6Ool4@ch2O004Ool5
@ch00goo@ci3?P02Ool00g`0@ci3?P03@ch01Goo@ci3?T<nO0001Goo14<n0goo0W`00T<n0goo0T<n
17oo0d<n00=ood<n@ch00d<n27i0K7oo001]Ool00`00O41lH004O60017`0@ci3?T<n27oo0T<n1Goo
0T<n00=l07ooOol00goo0T<n1goo0T<n1Goo1D<nE7oo14<n1Goo0W`00T<n0W`02Woo0T<n0Woo14<n
00Al07ooOomoo`=3?PAoo`9l00=3?P=oo`03O013?T<n00Aoo`93?PQoo`E3?P=oo`En@003OV1oogoo
00eoo`03001oogoo05Uoo`00K7oo00<007a0O4000WaP0W`000=lH4<n@ch00T<n0goo00=l07ooOol0
0Woo0T<n1Goo0d<n17oo0d<n1goo0d<n0goo1D<nEGoo1T<n0goo0W`00d<n00=l07ooOol027oo1d<n
0W`017oo0T<n1Goo00=l04<n@ch017oo00=l04<n@ch017oo0T<n27oo1D<n0goo0W`00Wi00giPJWoo
001[Ool01P00Ooml@7a0O613?P9l0003O413?T<n0093?P9oo`=l009oo`=3?PMoo`03@cioogoo009o
o`93?PUoo`M3?U]oo`E3?P03Ooml07`000A3?PYoo`E3?PQoo`=3?PAoo`04O013?T<n@ch3Ool017`0
@ci3?T<n0goo0d<n1goo1T<n17oo1WiPJGoo001ZOol00`00Ooml@003O402@ch00g`0Oom3?P03@ch2
Ool2O003Ool2@ch8Ool2@ch3Ool2@ch9Ool6@ciLOol6@ch00g`0@ci3?P05@ch7Ool5@ch9Ool017`0
@ci3?T<n0goo00=l04<n@ch00d<n00Aood<n@ci3?P=oo`=3?P]oo`93?PAoo`03O01nH7iP00EnH6Qo
o`00JGoo00<007ooO40017a00T<n0Woo14<n0Woo0W`00goo0T<n27oo0d<n00Aood<n@ci3?Vmoo`E3
?P03Ooml04<n00A3?PAoo`M3?P9oo`9l00Ioo`=3?P9oo`U3?PAoo`93?Paoo`93?P=oo`=l00MnH0mo
o`03001oogoo05Eoo`00J7oo00<007ooO4001Ga00T<n00=l07oo@ch00d<n0Woo0W`00Woo0d<n2Goo
1D<nL7oo14<n1Goo2D<n0goo0d<n00=oog`0O0001goo1T<n0goo0d<n00=l07ooOol00Woo0d<n2goo
0d<n0goo0W`000=oogiPOV001GiPIWoo001WOol200000gooO41l@004O402@ch017`0@ci3?Woo0T<n
00Aoog`0O01l009oo`93?P]oo`=3?W]oo`M3?PEoo`=3?P9l00Moo`E3?PAoo`=3?P04O01oogooOol3
@ch<Ool3@ch3Ool2O0000gooOV1nH006OV1UOol006Ioo`800003Ooml@7a000El@0E3?P06Oom3?T<n
@cioog`00goo0T<n37oo00=3?WooOol0Qgoo0d<n00=l07ooOol017oo1d<n1Goo0W`00Woo0d<n3Woo
0T<n0goo0W`00Woo27iPI7oo001VOol00`00Ooml@004O402O00017oo@ci3?W`00d<n00=ood<n@ch0
17oo0d<nUgoo34<n00=ood<n@ch00d<n0goo0W`014<n3goo0T<n0goo0g`00Woo27iPHgoo001UOol0
0`00Ooml@005O402O0000goo@ci3?P03@ch2Ool2@ch4Ool2@cjHOol:@ch3Ool=@ch@Ool3@ch3Ool0
0g`0Oomoo`02Ool7OV1SOol006Aoo`03001oogoo00El@004Ooml07`0Ool4@ch3Ool2@ch2O002Ool2
@cjXOol8@chBOol2@ch9Ool2O002OV0014<nOV1nH7iPHWoo001SOol200000gooO41l@004O403O004
@ch4Ool2@ch2O00017oo@ci3?T<n`Woo0T<n2Goo0W`000=nH4<n@ch017iPHGoo001SOol00`00Ooml
@006O4000gooO01oo`02@ch6Ool2@ch2O0000goo@ci3?P33Ool3@ch2Ool2O004Ool2O00017oo@ci3
?T<n17iP3goo00<007ooOol0CWoo001ROol00`00Oomoo`06O404Ool2@ch6Ool3@ch017`0@ci3?T<n
`goo0d<n0Woo0W`017oo0W`000Aood<n@ci3?PEnH5moo`00HGoo0P0000=ooga0O40017a00goo00=l
07oo@ch00T<n1Woo1D<naGoo0T<n0Woo0W`017oo0W`000Aood<n@ci3?PInH5ioo`00HGoo00<007oo
O4001Wa00Woo0g`00T<n27oo0d<naWoo0d<n00=oog`0O00017oo0W`000Eood<n@ci3?Woo00InH5eo
o`00H7oo00<007ooO4000ga00W`000Al@7ooOomoo`9l0003Oom3?T<n00Qoo`03O013?Woo0<Moo`93
?P03Ooml07`000Moo`A3?P03Ooml07`000AnH5aoo`00Ggoo0P0000=ooga0O4000Wa00W`017oo0W`0
00=ood<n@ch0dWoo0T<n00=oog`0O0001goo14<n00=oog`0O0001GiPFgoo001OOol00`00Ooml@004
O402O004Ool2O003@ckBOol3@ch7Ool2O004@ch017ooO01l07`01GiPFWoo001NOol20006O402O003
Ool3O002@ckDOol2@ch00gooO01oo`04Ool2O004@ch2Ool00g`0OV1nH005OV1IOol005ioo`03001l
@7a000El@09l00Aoo`04O01ood<n@ckEOol014<nO01l07`017oo0W`01D<n0Woo1giPFGoo001MOol0
0`00Ooml@002O40017`0O41oogoo0W`01Woo0T<neGoo0T<n0W`017oo0W`014<n17oo1giPF7oo001M
Ool00`00O41l@002O402O009Ool3@ckEOol2@ch2O004Ool2O004@ch00gooO01l0003Ool6OV0;Ool0
0`00Oomoo`19Ool005eoo`03001l@7a0009l@09l00=oo`04O01oogooOol2O002@ckFOol3@ch00g`0
@cioo`02Ool2O004@ch00gooO01l0003Ool7OV1FOol005aoo`03001ooga000Al@0=oo`=l009oo`9l
0093?]Ioo`I3?P9oo`9l00A3?P03Ooml07`000=oo`03OV1l07`000AnH5Ioo`00G7oo00<007ooO400
0T<n0Wa00goo0W`00goo0W`00T<negoo1T<n0goo1D<n0W`017oo0W`01GiP2goo00<007ooOol0Agoo
001KOol01000Oomoog`P0T<n0W`00goo0W`00goo00Al04<n@ci3?]]oo`=3?P03Ooml04<n00A3?P9l
00Aoo`9l00EnH003OX1oogoo059oo`00Fgoo00@007ooOoml8093?P9l00=oo`9l00=oo`03O013?T<n
0=aoo`=3?P9l0093?P03Oom3?T<n009l00Aoo`9l00EnH003OX1oogoo059oo`00FWoo0P000Woo00=l
84<n@ch00W`00Woo0g`00goo00=l04<n@ch0g7oo14<n00Al04<n@cioo`93?PQoo`EnH003OX1oogoo
00Uoo`03001oogoo04Ioo`00FWoo00D007ooOomoog`P0093?P9l00=oo`03O01oogoo00=oo`=3?]eo
o`E3?P04Oom3?T<n@ch8Ool01GiP@ci3?WiPOX00E7oo001JOol01@00OomoogooO2000T<n0W`02Goo
0T<ngWoo14<n0goo0T<n0W`017oo0W`000EnP4<n@cinP7`005Aoo`00FWoo00D007ooOomoog`P0093
?P9l00=oo`04O01oogooOol2O002@ckNOol4@ch00g`0Oomoo`02@ch2O004Ool2O00017j0@ci3?T<n
0WjP2goo00<007ooOol0AGoo001IOol00`00Oomoo`03Ool2@ch2O202Ool3O002Ool017`0@ci3?T<n
ggoo0d<n0goo0T<n0W`017oo0W`000=ood<n@ch00T<n00=nX7ooOol0DGoo001IOol00`00Oomoo`03
Ool2@ch017`PO01oogoo0W`00goo00=l04<n@ch0iWoo0d<n00=l07ooOol00Woo0W`000Iood<n@ci3
?W`0OZ0;Ool00`00Oomoo`15Ool005Uoo`03001oogoo009oo`=3?P=l0003Ooml07`000=oo`03O013
?T<n0>Moo`93?P03O01oogoo009oo`9l0004Oom3?T<n@ch2OZ1COol005Uoo`03001oogoo009oo`=3
?P9l009oo`93?P=oo`=3?^Moo`93?P03O01oogoo009oo`9l0004Oom3?T<n@ch3OZ0;Ool00`00Oomo
o`14Ool005Uoo`03001oogoo009oo`=3?P9l0003Oom3?T<n0093?P04Oom3?T<n@ckXOol2@ch8Ool3
@ch3OZ1BOol005Qoo`03001oogoo00=oo`A3?P03O013?T<n00I3?^Uoo`=3?PQoo`=3?P03O01nX7jP
00Yoo`03001oogoo04Aoo`00F7oo00<007ooOol00goo1d<n0Woo14<njGoo0T<n0W`017oo00=l07oo
Ool00d<n00=l07jPOZ00DGoo001HOol00`00Oomoo`03Ool7@ch2Ool4@ckYOol2@ch2O003Ool3O000
1Goo@ci3?T<nO0000WjP2Woo00<007ooOol0A7oo001HOol00`00Oomoo`03Ool3@ch00g`0@cil003`
Ool2@ch2O004Ool2O0001Goo@ci3?T<nO0000gjP2Goo00<007ooOol0A7oo001HOol00`00Oomoo`03
Ool3@ch3O03`Ool7@ch017ooO01l07oo14<n00=l07jPOol0D7oo001HOol00`00Oomoo`04Ool2@ch3
O03aOol6@ch017ooO01l07oo0d<n00Al07jPOZ1nX0Uoo`03001oogoo04Aoo`00F7oo00<007ooOol0
0goo0T<n17`0lGoo1d<n0g`00d<n17jP2Woo00<007ooOol0@goo001HOol00`00Oomoo`03Ool2@ch4
O03gOol014<nOoml07oo0d<n17jPD7oo001HOol00`00Oomoo`03Ool2@ch4O03gOol2@ch2Ool4@ch4
OZ09Ool00`00Oomoo`13Ool005Qoo`03001oogoo00=oo`93?PAl0?Moo`=3?P03Oom3?T<n0093?P=n
X0Yoo`03001oogoo04=oo`00F7oo00<007ooOol00goo0T<n17`0n7oo0T<n00=l04<n@ch00T<n0gjP
2Woo00<007ooOol0@goo001HOol00`00Oomoo`03Ool2@ch5O03gOol2@ch00g`0@ci3?P02@ch2O002
OZ1?Ool005Qoo`03001oogoo00=oo`93?PEl0?Moo`Q3?P03O01nX7jP00Qoo`03001oogoo04Aoo`00
F7oo00<007ooOol00goo0T<n1G`0n7oo1T<n0W`00WjP27oo00<007ooOol0A7oo001HOol00`00Oomo
o`03Ool2@ch5O03hOol6@ch5OZ07Ool00`00Oomoo`14Ool005Qoo`03001oogoo00=oo`93?PEl0?Qo
o`I3?P04OZ1l07jPOZ08Ool00`00Oomoo`14Ool005Qoo`03001oogoo00=oo`=3?PEl0?Moo`M3?P9l
009nX0Moo`03001oogoo04Aoo`00F7oo00<007ooOol00goo0T<n1G`0nWoo00=3?Woo@ch00T<n0W`0
0WjP1goo00<007ooOol0A7oo001IOol00`00Oomoo`02Ool2@ch00gooO01l0002O03mOol2@ch2O002
OZ07Ool00`00Oomoo`14Ool005Uoo`03001oogoo009oo`93?P03Ooml07`000=l0?aoo`93?P9l009n
X0Ioo`03001oogoo04Eoo`00FGoo00@007ooOomoo`=3?PIl0?aoo`=3?P9l0003OZ1oogoo00Aoo`03
001oogoo04Eoo`00GGoo0T<n1g`0o7oo0T<n00EnX7`0OZ1nX7k000Eoo`03001oogoo04Eoo`00FGoo
00@007ooOomoo`93?PQl0?]oo`93?P05OZ1l07`0OZ1n`005Ool00`00Oomoo`15Ool005Yoo`03001o
ogoo0093?PQl0?]oo`93?P03O/1l07`0009n`0Aoo`03001oogoo04Ioo`00FWoo00<007ooOol00T<n
27`0ngoo0T<n0g`00gk00goo00<007ooOol0AWoo001JOol00`00Oomoo`02@ch00gooO01oo`06O03j
Ool2@ch4O0000gk0Oomoo`02Ool00`00Oomoo`16Ool005]oo`04001ood<n@ch3Ool6O03jOol2@ch5
O004Ool00`00Oomoo`16Ool005eoo`93?PAoo`Il0?Uoo`=3?P=l009n`09oo`03001oogoo04Moo`00
Fgoo00@007oo@ci3?P9oo`Ql0?Yoo`93?P9l00=n`09oo`03001oogoo04Moo`00G7oo00<004<n@ch0
17`000=oog`0O00017`0nGoo0T<n00=l07k0O/000Wk000=oo`00Ool0BGoo001LOol00`00@ci3?P04
O0000gooO01l0005O03hOol2@ch00gk0@ci3?P02O/000goo001oo`19Ool005eoo`93?PAl00=oo`El
0?Qoo`E3?P04O01oo`00001:Ool005eoo`93?PAl00=oo`Il0?Qoo`93?P05O013?W`0O/00001;Ool0
05eoo`=3?P=l0003Ooml07`000Ml0?Ioo`08O/13?T<nO013?W`0Ool004]oo`00GGoo14<n0goo0W`0
0Woo1W`0mGoo00Mn`4<n@cil04<nO000001<Ool005ioo`93?PAoo`9l00=oo`Il0?=oo`05O^1n`4<n
@cil0002@ch00g`0Oomoo`1:Ool005ioo`93?P9l009oo`9l00Aoo`Il0?9oo`05O^1n`4<n@cil0002
@ci=Ool005ioo`93?P9l009oo`9l00Aoo`Ml0?1oo`9nh003O/13?T<n00=3?Teoo`00GWoo0T<n0W`0
0Woo0W`017oo27`017oPjWoo17kP1D<nCGoo001NOol2@ch2O009Ool6O007On3WOol5O^05@ci=Ool0
05ioo`93?P9l0003001oogoo00Eoo`=l0004Ooml04<n@ch8On3VOol5O^05@ci=Ool005ioo`93?P9l
0003Ooml07`000Eoo`9l009oo`=3?PUoh>=oo`Anh003O01nh7`000E3?Teoo`00GWoo0T<n0goo0W`0
1Goo0W`000=ood<n@ch00d<n27oPhgoo1GkP0W`01T<nC7oo001NOol2@ch3Ool2O005Ool2O0000goo
@ci3?P03@ch2Ool00g`0On1oh004On3QOol6O^02O0000goo@ci3?P03@ci<Ool005ioo`93?P03O01o
ogoo009l00Aoo`=l0004Oom3?T<nOol2@ch3Ool7On3OOol7O^02O0000goo@ci3?P03@ci<Ool005io
o`93?P03O01oogoo009l0003001oogoo009oo`03O01oogoo00I3?PAoo`Eoh=ioo`Mnh004Ooml07`0
O006@ci;Ool005ioo`=3?P9oo`9l00Qoo`93?P03Oom3?T<n0093?P04O01oogooO004On3MOol6O^02
Ool01000Ooml07oo1D<nC7oo001NOol4@ch;Ool2@ch2Ool3@ch00g`0Oomoo`02O004On3KOol6O^02
Ool20003Ool5@ci<Ool005moo`93?P=oo`05O01oogooOol00003Ool3@ch2Ool4@ch2Ool2O003On3K
Ool6O^02Ool20002Ool00g`0Oom3?P04@ci<Ool005moo`=3?P04Ooml07`0O003Ool2O0000goo@ci3
?P04Ool2@ch00g`0Oomoo`02O003On3JOol7O^000goo00000002Ool3O005@ci<Ool005moo`A3?P9l
00Aoo`9l0003Oom3?T<n00Aoo`=3?P9oo`9l00Aoh=Qoo`Mnh09l0003001oogoo009oo`03O013?T<n
00A3?Taoo`00H7oo0T<n00=oog`0O00017oo0W`000Aood<n@ci3?P=oo`A3?P03Ooml07`000Aoh=Qo
o`Inh003Ooml07`000Eoo`04O013?T<nOol3@ci<Ool0061oo`=3?P9l00Aoo`9l0003Oom3?T<n00Eo
o`93?P=oo`Eoh=Ioo`Qnh003001l07`000Eoo`04O013?T<nOol4@ci;Ool0061oo`E3?PAoo`9l0003
Oom3?T<n00Eoo`=3?P9oo`03O01oh7oP00=oh=Eoo`Inh003Ool00000009l00Eoo`04O013?T<nOol4
@ci;Ool0065oo`E3?P=oo`9l00=3?PIoo`93?P03Ooml07`0009l00=oh==oo`Qnh0800003Ooml07`0
00Ioo`93?P9oo`=3?T]oo`00Hgoo14<n17oo0T<n1goo0T<n00=oog`0O0001WoP00=o`7ooOol0cgoo
17kP00=l07kPO^000P000Woo0W`01Woo0T<n0Woo14<nBWoo001TOol4@ch2Ool3@ch3Ool01000Oomo
ogoo0T<n00=oog`0O0001goP00=o`7ooOol0c7oo00=o07kPO^000gkP0W`00P002goo0T<n0Woo0d<n
Bgoo001UOol2@ch00gooO01l0002@ch8Ool2@ch017ooO01l07`01WoP0Wo0cGoo00=o07kPO^000gkP
0W`000<007ooOol00goo00=l07ooOol00goo00=l04<n@ch00Woo0d<nBgoo001UOol3@ch2O002@ch8
Ool3@ch3O002Ool2On02@ch4Ol39Ool4O`04O^02O005Ool3O004Ool00g`0@ci3?P02Ool4@ci:Ool0
06Eoo`M3?PQoo`A3?P9l009oo`=3?PIo`<Qoo`Eo0004O^1o00000007Ool2O004Ool00g`0@ci3?P03
Ool2@ci;Ool006Ioo`I3?PUoo`93?P03Ooml07`0009oo`=3?P03O01o`7o000Eo`<Aoo`Qo0003001o
ogoo00Moo`9l00Aoo`03O013?T<n00=oo`93?T]oo`00IWoo1D<n2Woo0T<n00=oog`0O0000Woo0d<n
00=l07o0Ol001Wo0`Woo27l000@007ooOomoo`9l00Eoo`9l00Aoo`93?U5oo`00Igoo0d<n2goo0T<n
0g`00Woo0d<n00=oogo0Ol0027o0_goo1Wl00g`017oo0W`01Goo0g`00goo0T<nDGoo001eOol3@ch2
O002Ool3@ch4Ool8Ol2mOol8O`000g`0Oomoo`03Ool2O006Ool00g`0Oomoo`02Ool2@ciAOol007Eo
o`A3?P=oo`=3?PAoo`Uo`;]oo`Qo00Moo`9l00]oo`93?U5oo`00MWoo0T<n17oo0d<n1goo27o0]goo
2Gl027oo0W`01Woo00Al07ooOomoo`93?U9oo`00MWoo0T<n0W`00Woo0d<n1goo2Go0]Goo27l00goo
0W`01Goo0W`01Goo0g`00Woo0d<nDGoo001fOol2@ch2O0000goo@ci3?P02@ch:Ool8Ol2aOol:O`03
Ool2O00=Ool2O00017oo@ci3?T<nDWoo001fOol2@ch2O0000goo@ci3?P02@ch00`00Oomoo`03Ool2
O003Ool8Ol2]Ool:O`000g`0Oomoo`03Ool2O006Ool00g`0Oomoo`04Ool2O004@ciBOol007Ioo`=3
?P03O01ood<n00=3?P=oo`03001oogoo009l00=oo`Yo`:Uoo`]o009l00Eoo`9l00Eoo`=l00Eoo`03
O013?T<n0093?U=oo`00MWoo14<n00=ood<n@ch00T<n1Woo0W`01Woo27o0YGoo3Gl000=oog`0O000
1Goo0W`01Woo0W`01Goo14<nE7oo001gOol2@ch00g`0Oom3?P03@ch5Ool00`00O01l0006Ool9Ol2R
Ool>O`02Ool2O005Ool2O006Ool2O004Ool3@ciFOol007Moo`93?P03Oom3?T<n00=3?PIoo`9l00Uo
o`9o`003O01o`7o000=o`9ioo`]o009l0003O`1oogoo009oo`9l00eoo`9l00=oo`=3?UMoo`00Mgoo
0T<n00Aood<n@cioo`93?PIoo`9l0003Ool007oo00Ioo`9l00Mo`9]oo`eo00Moo`9l00eoo`=l009o
o`93?UQoo`00Mgoo0T<n00Aood<n@cioo`93?P]oo`03001oogoo00=oo`9l00Qo`9Moo`io015oo`03
O01oogoo00Eoo`04O01oogooOol2@ciHOol007Moo`E3?P03Oom3?T<n00eoo`04001oogooOol2O00:
Ol2DOol<O`06Ool2O00;Ool3O009Ool2@ciIOol007Moo`A3?P9oo`93?PIoo`9l00Moo`04001l07`0
O002Ool9Ol000gnPOomoo`2<Ool<O`02O0000`00Oomoo`05Ool2O004Ool2O006Ool2O009Ool3@ciH
Ool007Moo`A3?P9oo`=3?PEoo`9l00Uoo`03O00007oo009oo`Qo`09oX8aoo`eo009l00Qoo`9l00Ao
o`9l00Ioo`9l00Eoo`9l0004Oom3?T<n@ciIOol007Moo`A3?P9oo`=3?PEoo`9l00aoo`04001oogoo
Ool2O004Ol04Oj27Ool>O`0<Ool2O004Ool2O006Ool2O005Ool2O0000goo@ci3?P1JOol007Moo`=3
?PAoo`93?PEoo`9l00ioo`80009l00Ao`0IoX8=oo`eo0003001oogoo00aoo`9l00Aoo`9l00Ioo`=l
00Aoo`9l0093?U]oo`00Mgoo0d<n17oo0T<n1Goo0W`027oo0W`01Woo0W`000@007nPOj1oX093?PEo
X7moo`9o80]o0003001oogoo00Ioo`9l00Moo`9l00Aoo`9l00Moo`03O01oogoo00=oo`9l00=3?UYo
o`00OWoo0d<n17oo0W`027oo0W`01Woo00El04<n@ci3?W`000A3?PIoX7]oo`=o80Yo0003001oogoo
00Qoo`9l00eoo`9l00]oo`03@ciood<n00=3?U]oo`00OWoo0T<n3goo0W`01Woo00Al04<n@ci3?P9l
0093?PUoX003Oh1oogoo07=oo`Io80Mo0003001l07`000]oo`9l01Uoo`I3?Uaoo`00OWoo0T<n3goo
0W`01goo0d<n00Al04<n@ci3?PUoX0MoP003OomoP7oo06Uoo`Yo80Eo009oo`9l00]oo`9l00Moo`9l
00aoo`9l00M3?Ueoo`00OWoo0d<n0goo0W`02Goo0W`01goo0d<n00El04<n@ci3?Woo009l00IoX0ao
P003OomoP7oo069oo`eo8003O`1o87oo00=oo`9l00]oo`9l00Moo`9l00A3?P03Ooml07`000Eoo`9l
00=3?V5oo`00OWoo0d<n0goo0W`02Goo0W`01Woo14<n00Al04<n@ci3?P=oo`9oX093?P9oX15oP09o
H5Yoo`9o@0io80Moo`9l00]oo`9l00Moo`9l00E3?P9l00Eoo`9l00=3?V5oo`00Ogoo0T<n0goo0W`0
4Goo14<n00Al04<n@ci3?PEoo`=3?P03Oj1oP7n0019oP09oH09oo`03Of1oogoo04aoo`9o@09oo`Ao
@0Uo8003O01o87lP00Uoo`9l00]oo`9l00Moo`03O013?T<n00E3?P03O01oogoo00=oo`04O013?T<n
@ciROol007moo`93?P=oo`9l015oo`Q3?P03Ooml07`0009oo`=3?P9ooa=oP0YoH41oo`9o@0=oo`ao
@003Ob13?T<n00Io809l00Yoo`9l01Aoo`=3?P9oo`A3?PEoo`=3?V=oo`00Ogoo0d<n0Woo0W`02Goo
0W`01Woo0T<n00=ood<n@ch00d<n00=oog`0O0000Woo0d<n17oo0W`00Woo3Gn03gmP0Woo00=oH7oo
Ool0:goo0Wm01Goo5Gm000Ao84<n@ci3?P9o80=oo`9l01Qoo`03O01oogoo00Eoo`93?PAoo`A3?P=o
o`=3?VAoo`00P7oo0T<n0Woo0W`02Goo0W`01Woo0T<n00=ood<n@ch00d<n00=oog`0O0000Woo0d<n
17oo0W`01goo27n05gmP00=oogmPOol06Woo0Wm01Goo8Gm00d<n1Goo0W`05goo0g`01Woo0T<n1Goo
00El04<n@ci3?Woo00=3?VEoo`00P7oo0T<n3Goo0W`01Woo0T<n00=ood<n@ch00d<n00=oog`0O000
0Woo0d<n17oo0W`02goo0W`087mP47oo;Gm00Woo0T<n7goo0W`01Goo0d<n1goo1D<nIWoo0020Ool3
@ch2Ool00g`0Oomoo`07Ool2O006Ool00d<nOomoo`03Ool2@ch017ooO01l07oo1D<n0goo0W`02goo
0W`01Goo9WmP;7m000=oog`0O0001Goo0T<n4Woo0W`02goo0W`017oo0d<n27oo1D<nIWoo0020Ool2
@ch2Ool3O008Ool2O005Ool2@ch5Ool2@ch017ooO01l07oo1T<n0Woo0W`02goo0W`02goo87mP8gm0
2Woo0W`01Goo0T<n1Goo0W`02goo0W`02goo0W`017oo0T<nM7oo0020Ool4@ch2O009Ool2O004Ool2
@ch6Ool2@ch4Ool2@ch00goo@ci3?P0@Ool2O00BOol>Of02@ch9Of0FOd02O00:Ool2O009Ool2O005
Ool2@ch00g`0Oomoo`02Ool2O00;Ool2O00;Ool3O003Ool3@cicOol0081oo`E3?P03O01oogoo00Io
o`9l00Eoo`93?PIoo`=3?P=oo`93?P03Oom3?T<n01ioo`9l00]oo`IoH0=3?PUoH0Yo@003O01o@7m0
00Uoo`9l00Yoo`9l00Uoo`9l00Eoo`93?PEoo`9l00]oo`9l00aoo`04O01oogooOol3@cidOol0089o
o`=3?P03O01oogoo00eoo`93?PMoo`93?P04O01ood<n@ch2Ool2@ch3Ool2O00IOol2O00AOol4@ch6
Ool2O00ROol2O00?Ool4@ch4Ool2O00;Ool2O00@Ool2@cieOol0089oo`I3?Peoo`93?PMoo`93?P04
O01ood<n@ch2Ool3@ch2Ool2O00:Ool2O00=Ool2O00AOol3@ch7Ool2O00ROol2O00?Ool4@ch4Ool2
O00;Ool2O00?Ool3@cieOol008Aoo`I3?PAoo`9l00Eoo`03@cioogoo00Ioo`93?P04O01ood<n@ch3
Ool2@ch2Ool2O00:Ool2O00=Ool2O00<Ool2O003Ool3@ch7Ool2O00:Ool2O00:Ool2O00:Ool2O009
Ool2O004Ool4@ch4Ool2O00HOol2O00017oo@ci3?T<nMWoo0025Ool7@ch2Ool2O004Ool2@ch8Ool6
@ch3Ool2@ch2Ool2O00:Ool2O00=Ool2O00<Ool2O003Ool3@ch7Ool2O00:Ool2O00:Ool2O00:Ool2
O009Ool2O004Ool4@chNOol2O003@cigOol008Moo`I3?P03Oom3?W`000=oo`=3?PUoo`A3?PAoo`=3
?P03Ooml07`000Yoo`9l00eoo`9l00aoo`9l00=oo`=3?PMoo`9l00Yoo`9l00Yoo`9l01Eoo`9l00Ao
o`A3?PEoo`03O01oogoo00Uoo`9l00]oo`9l0093?WQoo`00RGoo1d<n0Woo0d<n2Woo00Al04<n@ci3
?PEoo`=3?P9l00Yoo`9l01]oo`9l00=oo`=3?PMoo`9l00Yoo`9l00Yoo`9l01Eoo`9l00Aoo`E3?P=o
o`=l00Yoo`9l00]oo`04O013?T<n@cihOol008]oo`U3?Paoo`93?PMoo`93?Paoo`9l01]oo`9l00=o
o`=3?Q=oo`9l00Yoo`9l00]oo`03O01oogoo00Moo`9l00=oo`93?P=oo`03@cioogoo009oo`9l00Yo
o`9l00]oo`=3?WUoo`00SWoo1D<n5Woo0T<n37oo0W`03Goo0W`037oo0W`00goo0d<n4goo0W`02Woo
0W`02Woo0g`027oo0W`00goo0T<n0goo0T<n0goo0W`02Woo0W`02Woo0d<nNWoo002YOol3@ch00g`0
Oomoo`0GOol2O00AOol3@ch7Ool2O00SOol2O00=Ool2@ch4Ool014<nOomoogoo0W`02Woo0W`02Woo
0T<nNgoo002ZOol2@ch00g`0Oomoo`0GOol2O00AOol4@ch6Ool2O00SOol2O00=Ool2@ch4Ool2@ch2
Ool3O009Ool2O009Ool3@cikOol00:]oo`03@cil07oo00Uoo`9l00eoo`9l011oo`E3?PIoo`9l00Yo
o`9l00Yoo`9l00]oo`9l00Qoo`9l009oo`=3?PEoo`05@cioogooOoml000DOol3@cilOol00:]oo`93
?PYoo`9l00eoo`9l00aoo`9l009oo`93?P03Oom3?T<n00Ioo`9l00Yoo`9l00Yoo`9l00]oo`=l00Mo
o`9l0004Oom3?T<n@ch6Ool2@chFOol3@cimOol00:]oo`03O013?Woo00Uoo`9l00eoo`9l00aoo`9l
009oo`93?P04Oom3?T<n@ch5Ool2O00:Ool2O00:Ool2O00<Ool00g`0Oomoo`06Ool2O003@ch8Ool0
0d<nOomoo`0<Ool2O005Ool3@cinOol00:]oo`03O013?T<n00Uoo`9l01]oo`9l009oo`M3?PAoo`9l
00Yoo`9l00Yoo`9l01Eoo`04O013?T<n@ch9Ool2@ch=Ool2O003Ool4@cioOol00:eoo`03@cioogoo
00Moo`9l00ioo`03O01oogoo00Yoo`9l009oo`93?P=oo`93?Q1oo`9l00Yoo`9l01Aoo`A3?P]oo`03
@cil07`000]oo`9l0003Oom3?T<n00=3?X1oo`00[Goo0T<n27oo0W`03Goo0g`02goo0W`00Woo0T<n
0goo0d<n3goo0W`02Woo0W`02goo0W`017oo00=3?Woo@ch014<n2goo0T<n00=l07ooOol027oo00=3
?W`0O0001D<nPGoo002]Ool3@chFOol2O00<Ool2O00017oo@ci3?T<n17oo0d<n0Woo0W`02Woo0W`0
5goo0W`000=ood<nOol01T<n3Woo00=3?W`0Ool027oo1T<nQ7oo002^Ool3@chEOol2O00?Ool2@ch6
Ool4@ch2O00SOol2O007@ch@Ool2@ch7Ool7@cj5Ool00:moo`=3?PEoo`9l00eoo`9l00ioo`=3?PMo
o`A3?P03O01oogoo01Aoo`9l00]oo`I3?Q=oo`=3?PAoo`E3?XUoo`00/7oo0T<n00=ood<nOol00Woo
0W`037oo0g`037oo0W`00T<n27oo1D<n2Woo0W`02Woo0W`02Goo1D<n5Woo00=l04<n@ch024<nRWoo
002`Ool6@ch00gooO01l000=Ool00g`0Oomoo`0;Ool2O002@ch;Ool3@ch9Ool2O00:Ool2O007Ool6
@chHOol7@cj=Ool00;1oo`Q3?P04O01oogoo@chHOol017`0@ci3?T<n2goo00Al04<n@ci3?PQoo`9l
0003Oom3?Woo00Moo`9l00Ioo`A3?Zmoo`00/goo2T<n5goo00=l04<n@ch03Woo0d<n1goo00=3?W`0
@ch054<n/7oo002fOol8@ch00goo@cioo`04Ool2O00<Ool4@ch?Ool3@ch4OolG@cjbOol00;aoo`E3
?PAoo`9l00]oo`A3?Q5oo`]3?/Aoo`00_7oo24<n00=oog`0O0001goo00=3?WooOol00d<n4goo1d<n
b7oo0030Ool6@ch00g`0Oomoo`03Ool7@ckSOol00<5ooa53?^Aoo`00a7oo2D<njGoo003oOongOol0
0?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo
]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol0
0?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo
]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol0
0?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo
]goo003oOongOol00?mookMoo`00ogoo]goo002ROol70003Ool30002Ool30004Ool50005Ool30000
0goo00000003Ool50004Ool60004Ool70005Ool30005Ool30002Ool30008Ool70004Ool4002UOol0
0:=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol00003Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0XWoo002SOol00`00Oomoo`02Ool00`00Oomoo`03Ool0
1000Oomoo`0017oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0XWoo002SOol01000Oomo
o`0027oo0P001Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo
1@001goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0XWoo002SOol40007Ool01000Oomo
o`0017oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0XWoo002SOol01000Oomoo`001Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P000goo00<007ooOol00Woo00<007oo
Ool00goo0`001Goo00<007ooOol00Woo0P001Woo00<007ooOol01Goo00D007ooOomoo`0000Eoo`80
00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo0:9oo`00Xgoo00<0
07ooOol00Woo00@007ooOomoo`<0009oo`<000Aoo`@00004Ool007ooOol20003Ool20004Ool20002
Ool30003Ool400000goo001oo`03Ool30008Ool30005Ool2000017oo000000003Goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0XWoo002SOol00`00Oomoo`02Ool00`00Oomoo`1JOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`2ROol00:9oo`L005Uoo`800003Ool007oo00Eoo`03
001oogoo009oo`03001oogoo0:9oo`00hGoo00<007ooOol087oo0P001goo1000YGoo003QOol00`00
Oomoo`3BOol00001\
\>"],
  ImageRangeCache->{{{0, 437}, {301.563, 0}} -> {-0.0340736, 0.122111, \
0.00233796, 0.00233796}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["4.",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["Discussion",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["Behavior genetics, behavioral pharmacology, and the study of \
spatial memory rely critically on the relevance, reliability and accuracy of \
behavioral measurements. Tests su",
    FormatType->StandardForm],
  StyleBox["ch as the Morris Water maze, the elevated plus maze, and the \
radial maze provide such measurements for the examination of already \
formulated hypotheses such as the existence and rate of spatial learning, or \
the level of an animal\[CloseCurlyQuote]s anxiety. At the present",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["state of knowledge concerning whole-animal unrestrained behavior, \
however, it is also necessary to broaden and enrich our list of hypotheses \
regarding the structure of behavior. SEE has been constructed with this aim \
in mind. Most of our current research ",
    FormatType->StandardForm],
  StyleBox["o",
    FormatType->StandardForm],
  StyleBox["n exploratory behavior is done using SEE. As illustrated in the \
current paper our methodology includes five steps:\n",
    FormatType->StandardForm],
  StyleBox["(i) Acquiring data, preferably at a rate not lower than ~10hz, ",
    FormatType->StandardForm],
  StyleBox["smoothing (",
    FormatType->StandardForm],
  StyleBox["Robust ",
    FormatType->StandardForm],
  StyleBox["Lo",
    FormatType->StandardForm],
  StyleBox["w",
    FormatType->StandardForm],
  StyleBox["ess, Cleveland, 1977), computation of velocities, and segm",
    FormatType->StandardForm],
  StyleBox["entation of the data time-series into modes of motion (Drai et \
al., 2000).  \n",
    FormatType->StandardForm],
  StyleBox["(ii) Searching for patterns by visualization and preliminary \
analysis of the data on a manageable number of subjects.  For example: do the \
animals have a home base, is there an as",
    FormatType->StandardForm],
  StyleBox["ymmetry between arrivals to and departures from the home base, is \
there an increase in the length of progression segments within and/or across \
sessions). \n",
    FormatType->StandardForm],
  StyleBox["(iii) Defining the quantity that captures the pattern.  For \
example, the proportion of cumulative tim",
    FormatType->StandardForm],
  StyleBox["e spent at the home base, the number of visits to the home base, \
the slope of a regression line measuring the increase in progression segments \
length and excursion length, or the median maximal speed of progression and \
of lingering segments. \n",
    FormatType->StandardForm],
  StyleBox["(iv) Computin",
    FormatType->StandardForm],
  StyleBox["g the values of such measures on various cross-sections of the \
database. For example: early activity, diversity during first half of session \
versus second half.  \n",
    FormatType->StandardForm],
  StyleBox["(v) Assessing the dependency between already established \
measures. For example: what is the e",
    FormatType->StandardForm],
  StyleBox["mpirical relationship between activity and diversity, or between \
movement segment length and excursion length? \n",
    FormatType->StandardForm],
  StyleBox["(vi) Distinguishing between true and false discoveries in the \
context of multiple comparisons (Benjamini and Hochberg, 1995).\n",
    FormatType->StandardForm],
  StyleBox["In a previous stud",
    FormatType->StandardForm],
  StyleBox["y we focused on the segmentation of the data into modes of motion \
(Drai et al., 2000). In this study we focused on the second step of \
visualization and preliminary analysis. In a forthcoming study we treat in \
detail the 4",
    FormatType->StandardForm],
  StyleBox["th",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" - 6",
    FormatType->StandardForm],
  StyleBox["th",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" steps, phenotyping the beh",
    FormatType->StandardForm],
  StyleBox["avior of c57 and Balb mice (Drai, submitted Ph.D. thesis; Drai et \
al., in preparation). This last study provides a list of behavioral endpoints \
that are compared across the two strains. After taking into account the False \
Discovery Rate of Benjamini and H",
    FormatType->StandardForm],
  StyleBox["o",
    FormatType->StandardForm],
  StyleBox["chberg (1995), ",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm],
  StyleBox[" out of ",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm],
  StyleBox["9",
    FormatType->StandardForm],
  StyleBox[" endpoints were found to differ s",
    FormatType->StandardForm],
  StyleBox["ignificantly, controlling for a",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox[".",
    FormatType->StandardForm],
  StyleBox["05 level",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["of significance. These ",
    FormatType->StandardForm],
  StyleBox["we",
    FormatType->StandardForm],
  StyleBox["re: Early (first 5min) activity in movement segments, ",
    FormatType->StandardForm],
  StyleBox["overall ",
    FormatType->StandardForm],
  StyleBox["early activity",
    FormatType->StandardForm],
  StyleBox[" (first 5mi",
    FormatType->StandardForm],
  StyleBox["n",
    FormatType->StandardForm],
  StyleBox[", ",
    FormatType->StandardForm],
  StyleBox["lingering speed, ",
    FormatType->StandardForm],
  StyleBox["number of stops per meter, spatial ",
    FormatType->StandardForm],
  StyleBox["spread of lingering episodes, duration of stops, movement segment \
speed, early minus late diversity, early minus late activity, spatial spread \
of movement segments, and ",
    FormatType->StandardForm],
  StyleBox["overall ",
    FormatType->StandardForm],
  StyleBox["activity. One advantage of this methodology is ",
    FormatType->StandardForm],
  StyleBox["the large number of ethologically r",
    FormatType->StandardForm],
  StyleBox["elevant parameters obtained from ",
    FormatType->StandardForm],
  StyleBox["a single experiment",
    FormatType->StandardForm],
  StyleBox[". \n",
    FormatType->StandardForm],
  StyleBox["A prerequisite for the full applicability of SEE is the validity \
of the segmentation procedure (Drai et al., 2000).  So far, segmentation has \
been validated in several strains of rats and mice in diffe",
    FormatType->StandardForm],
  StyleBox["rent arena sizes (6.5m diameter, 3.20m diameter, 1.40mx1.40m, and \
60cmx60cm), with various tracking systems (our own custom built video \
tracking system, Noldus\[CloseCurlyQuote]s Ethovision",
    FormatType->StandardForm],
  StyleBox["TM",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", AR Cools lab custom designed tracking system, and Photobeam \
tracking (Kafkafi et",
    FormatType->StandardForm],
  StyleBox[" al., 2000)), and in several contexts (e.g., daylight vs. total \
darkness conditions). \n",
    FormatType->StandardForm],
  StyleBox["The mouse study is part of a larger scale project committed to \
the isolation and quantification of patterns of exploratory behavior in 17 of \
the most common wild type mo",
    FormatType->StandardForm],
  StyleBox["use strains. The software developed in the course of this \
process, a standard experimental protocol and endpoint tables, as well as the \
raw data will all be available on the web. The overall aim is to create a \
freely accessible web-based genetic repositor",
    FormatType->StandardForm],
  StyleBox["y",
    FormatType->StandardForm],
  StyleBox[" of analyzed behavior together with tools for the high-throughput \
analysis of behavior in other strains and preparations. The collection of SEE \
functions will be made accessible to all researchers through the web. We \
anticipate that with time, old functio",
    FormatType->StandardForm],
  StyleBox["n",
    FormatType->StandardForm],
  StyleBox["s will be refined, and new functions will be formalized and \
added, especially if other researchers use SEE. In such case, its most \
up-to-date version ",
    FormatType->StandardForm],
  StyleBox["w",
    FormatType->StandardForm],
  StyleBox["ould be placed on the web, including both the old and the new \
functions, each ascribed to its correspondi",
    FormatType->StandardForm],
  StyleBox["ng authors. ",
    FormatType->StandardForm],
  StyleBox["For a",
    FormatType->StandardForm],
  StyleBox[" Mathematica 4.0 version of this paper in the form of a working \
manual including data, a package with all the necessary SEE functions, and \
the commands that generate the visualizations presented in this paper as well \
as  additional visualizati",
    FormatType->StandardForm],
  StyleBox["ons see http://www.tau.ac.il/~ilan99/. \n",
    FormatType->StandardForm],
  StyleBox["Acknowledgments\n",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["This study is part of the project \
\[OpenCurlyDoubleQuote]Phenotyping mouse exploratory behavior\
\[CloseCurlyDoubleQuote] supported by NIH 1 R01 NS40234-01. We thank Tirza \
Stern for her help in data acquisition and analysis.\n",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["Appendix\n",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["1.\t",
    FormatType->StandardForm],
  StyleBox["Prerequisit",
    FormatType->StandardForm],
  StyleBox["e computations and file naming conventions\n",
    FormatType->StandardForm],
  StyleBox["The use of the visualization and quantification functions \
presupposes stages of data acquisition, data smoothing, and data segmentation \
as well as the organization of their output into a structured system of \
files",
    FormatType->StandardForm],
  StyleBox[".\n",
    FormatType->StandardForm],
  StyleBox["1.1. ",
    FormatType->StandardForm],
  StyleBox["Data acquisition",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["For each session, the output of the data acquisition stage should \
be a file consisting of the time series {{t",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",x",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",y",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["},{t",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",x",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",y",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["}...}.\n",
    FormatType->StandardForm],
  StyleBox["i) The time coordinates should be integers, expressing time units \
corresponding to the maximal tem",
    FormatType->StandardForm],
  StyleBox["poral resolution of the system.\n",
    FormatType->StandardForm],
  StyleBox["ii) The coordinates should be real Cartesian coordinates (as \
opposed to screen coordinate), expressed in cm relative to a frame of \
reference having as origin the center of symmetry of the experimental arena.\n\
",
    FormatType->StandardForm],
  StyleBox["iii) The samplin",
    FormatType->StandardForm],
  StyleBox["g rate should be at least 10Hz. Such a sampling rate is necessary \
for computing meaningful velocities.\n",
    FormatType->StandardForm],
  StyleBox["1.2. ",
    FormatType->StandardForm],
  StyleBox["Data smoothing",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox[" \n",
    FormatType->StandardForm],
  StyleBox["The time series of coordinates {{t",
    FormatType->StandardForm],
  StyleBox["i",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",x",
    FormatType->StandardForm],
  StyleBox["i",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",y",
    FormatType->StandardForm],
  StyleBox["i",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["}} is generally noisy, partly arising from the characteristics of \
the data acquisition devi",
    FormatType->StandardForm],
  StyleBox["ce. In automatic tracking of the moving animal from a video \
record, for example, noise may be generated by a mechanical jitter of the \
video equipment, fluctuations of luminosity in the arena, and numerical \
rounding errors of the tracking algorithm.\n",
    FormatType->StandardForm],
  StyleBox["We firs",
    FormatType->StandardForm],
  StyleBox["t de-noise the data by applying a robust smoothing algorithm \
(Robust Lowess; Cleveland, 1977). Once the data are smoothed, velocities can \
be meaningfully computed and a threshold for arrest can be determined. Such \
threshold is necessary for the subsequent",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["segmentation of the data series into modes of motion. \n",
    FormatType->StandardForm],
  StyleBox["Given that there is a trade-off between efficiency and \
resolution, i) the tracking rates we choose range between 10 to 25 frames in \
the European PAL video standard and 10 ",
    FormatType->StandardForm],
  StyleBox["to",
    FormatType->StandardForm],
  StyleBox[" 30fps in the American NTS",
    FormatType->StandardForm],
  StyleBox["C video system), ii) we smooth the data with a ~0.7s to a ~1.3s \
time window, and iii) we use a 3",
    FormatType->StandardForm],
  StyleBox["rd",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" or 4",
    FormatType->StandardForm],
  StyleBox["th",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" polynomial to represent the raw data time series. Simultaneous \
use of the lowest values of these 3 parameters generates too noisy data, \
capturing only",
    FormatType->StandardForm],
  StyleBox[" stops whose duration is 0.5s or more. Simultaneous use of the \
highest values generates a nicely smoothed time series, representing a set of \
events, such as stops, whose duration is 0.2s or more. This might be less \
necessary in the rat and more appropriat",
    FormatType->StandardForm],
  StyleBox["e",
    FormatType->StandardForm],
  StyleBox[" in the mouse. A systematic study of the effects of different \
smoothing methods and parameters on the cutoff of noise level, on the cutoff \
between lingering and movement ",
    FormatType->StandardForm],
  StyleBox["segments",
    FormatType->StandardForm],
  StyleBox[" and on other results is under way.  \n",
    FormatType->StandardForm],
  StyleBox["1.3. ",
    FormatType->StandardForm],
  StyleBox["Data segmentation",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["1.3.1. ",
    FormatType->StandardForm],
  StyleBox["Episodes ",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["of  Motion",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["The input to this phase should be the smoothed data time series, \
whereas the output is a sequence {{m",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",n",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["},{m",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",n",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["},...} where each m",
    FormatType->StandardForm],
  StyleBox["i",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the index of the beginning of a motion episode, and n",
    FormatType->StandardForm],
  StyleBox["i",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" the index of its end. ",
    FormatType->StandardForm],
  StyleBox["Determining a threshold for absolute arrest (zero velocity) and \
defining episodes of motion as interva",
    FormatType->StandardForm],
  StyleBox["ls where no arrest occurs does this",
    FormatType->StandardForm],
  StyleBox[". For example, {102,150} designates an episode of motion starting \
at the 102",
    FormatType->StandardForm],
  StyleBox["th",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" data point in the original time series, and ending at the 150",
    FormatType->StandardForm],
  StyleBox[" th",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["data point. \n",
    FormatType->StandardForm],
  StyleBox["1.3.2. ",
    FormatType->StandardForm],
  StyleBox["Lingering and progression segments",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["Each episode of motion is characterized by its maximal velocity. \
The population of maximal velocities is then analyzed for multi-modality, and \
thresholds for the transition from one mode to the next ca",
    FormatType->StandardForm],
  StyleBox["n then be rigorously determined and used to characterize each of \
the components (Drai et al., 2000).\n",
    FormatType->StandardForm],
  StyleBox["1.3.3. Gaussian model and EM algorithm\n",
    FormatType->StandardForm],
  StyleBox["The Gaussian mixture model is used for recognizing distinct \
components within a population. In analogy, in electroph",
    FormatType->StandardForm],
  StyleBox["oresis, a mixture of distinct proteins ideally yields a perfect \
separation of the mixture into its components, i.e., all the molecules of \
each component lie precisely at a distance determined by their specific mass. \
In practice, however, the distance a pa",
    FormatType->StandardForm],
  StyleBox["r",
    FormatType->StandardForm],
  StyleBox["ticular molecule travels is affected by, e.g., convection. As a \
result, the distances traveled by each type of molecule form a Gaussian. When \
plotting concentration against distance from origin, one gets a single curve \
showing peaks corresponding to the m",
    FormatType->StandardForm],
  StyleBox["e",
    FormatType->StandardForm],
  StyleBox["dians of each Gaussian. Given a mixture, be it of proteins or of \
distinct components of speed maxima in a frequency distribution curve, the \
number of peaks in the curve corresponds to the number of components. The \
actual proportion of each component can b",
    FormatType->StandardForm],
  StyleBox["e",
    FormatType->StandardForm],
  StyleBox[" estimated by fitting a Gaussian mixture model to the empirical \
curve. This model consists of a sum of distinct Gaussians weighted by their \
corresponding proportions. The proportions of the components in the mixture \
are then calculated by determining the ",
    FormatType->StandardForm],
  StyleBox["v",
    FormatType->StandardForm],
  StyleBox["alues of the proportions that give maximum likelihood to the \
model. The ",
    FormatType->StandardForm],
  StyleBox["Expectation-Maximization (EM) algorithm (Everitt, 1981) estimates \
the maximum likelihood parameters (proportions, means, and standard \
deviations) of a mixture with a given number of Ga",
    FormatType->StandardForm],
  StyleBox["ussians. EM is an iterative algorithm that starts with user-given \
initial values, and incrementally improves the likelihood function until \
further iterations yield only a negligible improvement. The actual number of \
components of the model",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox["is determined by",
    FormatType->StandardForm],
  StyleBox[" comparing the maximum likelihood value of a n-components mixture \
with that of a (n-1)-component mixture until the increased number of \
components increases the likelihood only marginally. (For further details see \
Drai et al., 2000). ",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["1.4. ",
    FormatType->StandardForm],
  StyleBox["File System and ",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["Naming Conventions",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["A good choice of naming conventions for the diverse files we need \
for visualization and analysis is necessary in order to produce graphs and \
compute endpoints for any subset of the database (e.g., all the sessions of a \
given animal, all ",
    FormatType->StandardForm],
  StyleBox["the second sessions of all animals in a given project etc...). We \
therefore adopted the following conventions: all data files are stored in a \
directory C:\\See data C:\\Seedata , each session",
    FormatType->StandardForm],
  StyleBox["\[CloseCurlyQuote]",
    FormatType->StandardForm],
  StyleBox["s",
    FormatType->StandardForm],
  StyleBox[" data (i.e. the time series issuing from the data acquisition \
proce",
    FormatType->StandardForm],
  StyleBox["ss) is stored as:\n",
    FormatType->StandardForm],
  StyleBox["projectname_ratname_session number.dat\n",
    FormatType->StandardForm],
  StyleBox["The episodes of motion are stored as:\n",
    FormatType->StandardForm],
  StyleBox["projectname_ratname_session number.",
    FormatType->StandardForm],
  StyleBox["mot",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["The velocities are stored as: \n",
    FormatType->StandardForm],
  StyleBox["projectname_ratname_session number.",
    FormatType->StandardForm],
  StyleBox["spd",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["The maximal values ",
    FormatType->StandardForm],
  StyleBox["of the velocities",
    FormatType->StandardForm],
  StyleBox[" within each epi",
    FormatType->StandardForm],
  StyleBox["sode of motion are stored as: \n",
    FormatType->StandardForm],
  StyleBox["projectname_ratname_session number.",
    FormatType->StandardForm],
  StyleBox["max",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["The thresholds obtained in the classification process are saved \
as: \n",
    FormatType->StandardForm],
  StyleBox["projectname_ratname_session number.",
    FormatType->StandardForm],
  StyleBox["thr",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["Thanks to these conventions all the files pertaining to a given \
animal are eas",
    FormatType->StandardForm],
  StyleBox["ily definable. This is exploited in the implementation of the \
function \[OpenCurlyDoubleQuote]Load[name]\[CloseCurlyDoubleQuote], which \
loads in memory all the files computed for a given animal. The Mathematica \
pattern matching facilities are further used in the function \n",
    FormatType->StandardForm],
  StyleBox[" Script[list of computations",
    FormatType->StandardForm],
  StyleBox[", list of files]; this function computes a user defined list of \
quantities computable from the files pertaining to an animal, across a list \
of files",
    FormatType->StandardForm],
  StyleBox[". ",
    FormatType->StandardForm],
  StyleBox["Thus: \n",
    FormatType->StandardForm],
  StyleBox["Script[\[OpenCurlyDoubleQuote]{Diversity[TimeSlice[lingering,300]]\
,   \n",
    FormatType->StandardForm],
  StyleBox["              Median[SpatialSpread[movesegments]]}",
    FormatType->StandardForm],
  StyleBox["\[CloseCurlyDoubleQuote],\n",
    FormatType->StandardForm],
  StyleBox["             FileNames[\[OpenCurlyDoubleQuote]hooded 99_*_3\
\[CloseCurlyDoubleQuote]]]\n",
    FormatType->StandardForm],
  StyleBox["Would compute the ",
    FormatType->StandardForm],
  StyleBox["dynamics",
    FormatType->StandardForm],
  StyleBox[" of diversity by five-minute slices and the median of the spatial \
spread of progression segments, for all the files corresponding to the ",
    FormatType->StandardForm],
  StyleBox["third",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox[" session of any animal in the project called",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["hooded 99",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox[".\n",
    FormatType->StandardForm],
  StyleBox["2. ",
    FormatType->StandardForm],
  StyleBox["A formal description of SEE",
    FormatType->StandardForm],
  StyleBox[" \n",
    FormatType->StandardForm],
  StyleBox[" The following is a collection of the data objects and functions \
that constitute SEE.  A full practical guide to the operation of the \
software, as well as the implemented code is available upon request from the \
a",
    FormatType->StandardForm],
  StyleBox["uthors (note that one needs a working copy of Mathematica ",
    FormatType->StandardForm],
  StyleBox["4 ",
    FormatType->StandardForm],
  StyleBox["in order to use the software).\n",
    FormatType->StandardForm],
  StyleBox["2.1. ",
    FormatType->StandardForm],
  StyleBox["Elementary data objects",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["Once a data set has been loaded through use of the Load function, \
all the ",
    FormatType->StandardForm],
  StyleBox["variables",
    FormatType->StandardForm],
  StyleBox[" \n",
    FormatType->StandardForm],
  StyleBox["refer implicitly to that data set.\n",
    FormatType->StandardForm],
  StyleBox[" data",
    FormatType->StandardForm],
  StyleBox[" consists of ",
    FormatType->StandardForm],
  StyleBox["a time series of the form {t,x,y,v} where t is the time, x,y are \
the Cartesian coordinates and v is the absolute velocity.\n",
    FormatType->StandardForm],
  StyleBox["contour2d ",
    FormatType->StandardForm],
  StyleBox["represents the contour of the experimental arena viewed in two \
dimensions.\n",
    FormatType->StandardForm],
  StyleBox["contour3d ",
    FormatType->StandardForm],
  StyleBox["represents the contour of the experime",
    FormatType->StandardForm],
  StyleBox["ntal arena viewed in three dimensions (this is used to display \
phase plots).\n",
    FormatType->StandardForm],
  StyleBox["motions",
    FormatType->StandardForm],
  StyleBox[" consist of a list of couples {m,n,}. m,n are the indexes of the \
beginning and end of an episode of motion.\n",
    FormatType->StandardForm],
  StyleBox["maxima",
    FormatType->StandardForm],
  StyleBox[" consists of a list of the maxima of speed for the  episod",
    FormatType->StandardForm],
  StyleBox["es of motion\n",
    FormatType->StandardForm],
  StyleBox["thresholds",
    FormatType->StandardForm],
  StyleBox[" consists of a list {t",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",t",
    FormatType->StandardForm],
  StyleBox["2",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["...}, where t",
    FormatType->StandardForm],
  StyleBox["1",
    FormatType->StandardForm,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the noise level, and each subsequent ti is the threshold \
separating the i-th component from the i+1-th in the multi- modal analysis of \
the maxima.\n",
    FormatType->StandardForm],
  StyleBox["movesegments",
    FormatType->StandardForm],
  StyleBox["  consists of couples {m,n}, t",
    FormatType->StandardForm],
  StyleBox["he indexes of the beginning and end of progression segments which \
 are not of the lingering  type .\n",
    FormatType->StandardForm],
  StyleBox["lingering",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox[" consists of couples {m,n}, the indexes of the beginning and end \
of a lingering segment. ",
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["real",
    FormatType->StandardForm],
  StyleBox["lingering",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox[" consists of couples {m,n}, the indexes of the beginning and end \
of a lingering segment",
    FormatType->StandardForm],
  StyleBox[" longer than 0.2s",
    FormatType->StandardForm],
  StyleBox[".  ",
    FormatType->StandardForm],
  StyleBox[" \n",
    FormatType->StandardForm],
  StyleBox["highspeedsegments",
    FormatType->StandardForm],
  StyleBox[" consists of couples {m,n} , the index",
    FormatType->StandardForm],
  StyleBox["es of the beginning and end of a segment whose maximal value of \
speed is above the third threshold  (if there is one).\n",
    FormatType->StandardForm],
  StyleBox["midspeedsegments",
    FormatType->StandardForm],
  StyleBox[" consists of couples {m,n},  the indexes of the  beginning and \
end of a segment whose maximal value of speed is above the",
    FormatType->StandardForm],
  StyleBox[" second threshold and below the third  (if there is one).\n",
    FormatType->StandardForm],
  StyleBox["stopindex",
    FormatType->StandardForm],
  StyleBox[" consists of the indices of beginnings of arrests or lingering \
episodes.\n",
    FormatType->StandardForm],
  StyleBox["startingpoints",
    FormatType->StandardForm],
  StyleBox[" consists of the indices of beginnings of movesegments.\n",
    FormatType->StandardForm],
  StyleBox["endingpoints",
    FormatType->StandardForm],
  StyleBox[" consists of the indices of ends o",
    FormatType->StandardForm],
  StyleBox["f movesegments.\n",
    FormatType->StandardForm],
  StyleBox["These data objects reflect our choice of fundamental units of \
analysis. Different \n",
    FormatType->StandardForm],
  StyleBox["constructs defined in terms of these elementary objects will be \
visualized and/or \n",
    FormatType->StandardForm],
  StyleBox["computed with the help of the elementary operators.\n",
    FormatType->StandardForm],
  StyleBox["2.2. ",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["Elementary operat",
    FormatType->StandardForm,
    FontWeight->"Plain",
    FontVariations->{"Underline"->True}],
  StyleBox["ors",
    FormatType->StandardForm,
    FontWeight->"Plain",
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["Besides data objects pertaining to the loaded session, SEE loads \
a list of definitions of ",
    FormatType->StandardForm],
  StyleBox["operators that",
    FormatType->StandardForm],
  StyleBox[" permit the definition of various aspects of the data. Most of \
them have been illustrated in the previous sections of the paper. For the \
sake of ",
    FormatType->StandardForm],
  StyleBox["c",
    FormatType->StandardForm],
  StyleBox["ompleteness we will list all the operators ",
    FormatType->StandardForm],
  StyleBox["with",
    FormatType->StandardForm],
  StyleBox[" a brief description of their \n",
    FormatType->StandardForm],
  StyleBox["function.\n",
    FormatType->StandardForm],
  StyleBox["Distance",
    FormatType->StandardForm],
  StyleBox["[{x,y},{u,v}] gives the Euclidian distance between the points \
{x,y} and {u,v}.\n",
    FormatType->StandardForm],
  StyleBox["CarttoPolar",
    FormatType->StandardForm],
  StyleBox["[{x,y}] translates the Cartesian coordinates {x,y} to polar ones \
({radi",
    FormatType->StandardForm],
  StyleBox["us,angle}) . \n",
    FormatType->StandardForm],
  StyleBox["SpatialSpread",
    FormatType->StandardForm],
  StyleBox["[{m,n}] gives the maximal distance between any two points \
belonging to the segment {m,n}.\n",
    FormatType->StandardForm],
  StyleBox["Activity",
    FormatType->StandardForm],
  StyleBox["[{m,n} ] gives the total mileage in  the segment {m,n}.\n",
    FormatType->StandardForm],
  StyleBox["MaxSpeed",
    FormatType->StandardForm],
  StyleBox["[{m,n}] gives the maximal speed in  the segment {m,n} .\n",
    FormatType->StandardForm],
  StyleBox["AverageSpee",
    FormatType->StandardForm],
  StyleBox["d",
    FormatType->StandardForm],
  StyleBox["[{m,n}] gives the average speed  in  the segment {m,n} .\n",
    FormatType->StandardForm],
  StyleBox["Balisticity",
    FormatType->StandardForm],
  StyleBox["[{m,n}] is a number between 0 and 1 computed from the \
oscillations of speed within the segment {m,n}. This number expresses the \
magnitude of changes of sign in the acceleration profile as",
    FormatType->StandardForm],
  StyleBox[" compared to that of a maximally smooth trajectory (which has \
balisticity value 1 by convention). We use this as an indicator of the \
pre-planned nature of a  ",
    FormatType->StandardForm],
  StyleBox["s",
    FormatType->StandardForm],
  StyleBox["egment.\n",
    FormatType->StandardForm],
  StyleBox["From",
    FormatType->StandardForm],
  StyleBox["[{x,y},d]  gives the list of segments ",
    FormatType->StandardForm],
  StyleBox["which",
    FormatType->StandardForm],
  StyleBox[" start from a point within a distance d fro",
    FormatType->StandardForm],
  StyleBox["m {x,y}.\n",
    FormatType->StandardForm],
  StyleBox["To",
    FormatType->StandardForm],
  StyleBox["[{x,y},d]  gives the list of segments which end at  a point \
within a distance d from {x,y}.\n",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["StrictlyFrom",
    FormatType->StandardForm],
  StyleBox["[{x,y},d]  gives the list of segments which start  from a point \
within a distance d from {x,y}, but do not end there.\n",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["StrictlyTo",
    FormatType->StandardForm],
  StyleBox["[{x,y},d]  ",
    FormatType->StandardForm],
  StyleBox["gives the list of segments which end at a point within a distance \
d from {x,y} but do not start there.\n",
    FormatType->StandardForm],
  StyleBox["PolarFrom",
    FormatType->StandardForm],
  StyleBox["[{ro,teta},dro,dteta]  gives the list of segments which start \
from the sector of angle 2*dteta and radii ro - dro,  ro + dro, centered at \
the po",
    FormatType->StandardForm],
  StyleBox["int {ro,teta} .\n",
    FormatType->StandardForm],
  StyleBox["PolarTo",
    FormatType->StandardForm],
  StyleBox["[{ro,teta},dro,dteta]  gives the list of segments which end in  \
the sector of angle 2*dteta and radii ro - dro, ro + dro centered at the \
point {ro,teta} . \n",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["PolarStrictlyFrom",
    FormatType->StandardForm],
  StyleBox["[{ro,teta},dro,dteta]  gives the list of segments which sta",
    FormatType->StandardForm],
  StyleBox["rt from the sector of angle 2*dteta  and radii ro - dro, ro + \
dro,  centered at the point {ro,teta}  but do not end there.\n",
    FormatType->StandardForm],
  StyleBox["  ",
    FormatType->StandardForm],
  StyleBox["PolarStrictlyTo",
    FormatType->StandardForm],
  StyleBox["[{ro,teta},dro,dteta]  gives the list of segments which end in  \
the sector of angle 2*dteta and radii ro - dro, ro +",
    FormatType->StandardForm],
  StyleBox[" dro, centered at the point {ro,teta}  but do not start there.\n",
    
    FormatType->StandardForm],
  StyleBox["Excursions",
    FormatType->StandardForm],
  StyleBox["[{x,y},d] computes the excursions relative to a home base \
centered at {x,y} and of radius d. In other words,  it computes the \
decomposition of the path of the animal into units consis",
    FormatType->StandardForm],
  StyleBox["ting of round trips from the home base. The result is a list of \
lists of segments, and in each list of segments the first segment starts \
within the defined area of reference and the last segment ends in the same \
area, with no intervening stops at the area",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["of reference.\n",
    FormatType->StandardForm],
  StyleBox["TimeSlice",
    FormatType->StandardForm],
  StyleBox["[list of segments,dt]",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["partitions the ",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["list of segments",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox[" into segments which occur in successive time slices of duration \
dt (",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["i.e.",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox[" the first sub-list consists of those segments in",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox[" ",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["list of segments which occur between 0 and dt, the second ",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["- of those between dt and 2*dt, etc\[Ellipsis]).\n",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["2.3\t",
    FormatType->StandardForm,
    FontSize->10],
  StyleBox[". ",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["Graphical Operators",
    FormatType->StandardForm,
    FontWeight->"Plain",
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  StyleBox["The graphical functions of SEE compute graphical objects through \
the use of the elementary data objects and the elementary operators. Any of \
these graphical objects, or combination of them, is di",
    FormatType->StandardForm],
  StyleBox["splayed on the screen by applying the main function See.\n",
    FormatType->StandardForm],
  StyleBox["PathPlot",
    FormatType->StandardForm],
  StyleBox["[{m,n}] returns a graphics object  which represents the path \
traced through the segment {m,n}.\n",
    FormatType->StandardForm],
  StyleBox["PointPlot",
    FormatType->StandardForm],
  StyleBox["[{m1,m2,...mk}] returns a graphics object which represents the \
locations of the data po",
    FormatType->StandardForm],
  StyleBox["ints m1,...mk.\n",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["TimePlot",
    FormatType->StandardForm],
  StyleBox["[list of segments, display factor:50] returns a graphics object  \
which represents the dwell time in each of the segments of the list by a \
circle. The circle is centered at the beginning of each segment, its area is \
proportional to t",
    FormatType->StandardForm],
  StyleBox["he relative dwell time in the segment  (relative to the sum of \
the dwell times over all the list of segments). The display factor controls \
the total area of the circles; it can be increased or decreased to make the \
visual display clearer, its default valu",
    FormatType->StandardForm],
  StyleBox["e",
    FormatType->StandardForm],
  StyleBox[" is set to 50.\n",
    FormatType->StandardForm],
  StyleBox["PairPlot",
    FormatType->StandardForm],
  StyleBox["[list of segments] returns a graphics object which represents the \
graph formed by the lines connecting the extremities of each segment in the \
list .\n",
    FormatType->StandardForm],
  StyleBox["SpeedPairPlot",
    FormatType->StandardForm],
  StyleBox["[list of segments] returns a graphics object which represents the \
graph",
    FormatType->StandardForm],
  StyleBox[" formed by the lines connecting the extremities of each segment \
in the list, with a color coding designating the maximal speed in each \
segment . The color-coding is relative to the maximal speed obtaining within \
all the segments (the redder the faster...)",
    FormatType->StandardForm],
  StyleBox[",",
    FormatType->StandardForm],
  StyleBox[" or, as in SpeedPairPlot2, relative to a cutoff velocity \
distinguishing between the upper quartile velocities (in red) and the lower 3 \
quartiles (in black) .\n",
    FormatType->StandardForm],
  StyleBox["PhasePlot",
    FormatType->StandardForm],
  StyleBox["[{m,n}] returns a graphics object which represents the graph \
formed by the path between d",
    FormatType->StandardForm],
  StyleBox["ata point m and n, together with the velocity plotted in the \
third dimension. The time course of the path is color-coded (from yellow = \
beginning to red = end). The velocity is represented in ",
    FormatType->StandardForm],
  StyleBox["azure",
    FormatType->StandardForm],
  StyleBox[", with red dotted lines projecting on the position plane to ",
    FormatType->StandardForm],
  StyleBox["facilitate visualization.\n",
    FormatType->StandardForm],
  StyleBox["AnimSeg",
    FormatType->StandardForm],
  StyleBox["[k, list of  segments]  returns a graphics object which \
represents the path formed by the  k-th  segment of the list of segments, on \
the background of the preceding ones. The path of the k-th segment is colored \
to code time",
    FormatType->StandardForm],
  StyleBox[" (from yellow = beginning, to red = end). The paths of the \
segments up to the k-th are represented in gray. This function is mainly \
useful for creating animations of successive segments within a given list.\n",
    
    FormatType->StandardForm],
  StyleBox["See",
    FormatType->StandardForm],
  StyleBox["[x], where x is a graphics object, displays x ",
    FormatType->StandardForm],
  StyleBox["on the screen, within the context of  contour2d or contour3d. \
This is the function used for displaying graphics objects computed by the \
preceding functions, or a combination of any number of them.\n",
    FormatType->StandardForm],
  StyleBox["2.4.",
    FormatType->StandardForm],
  StyleBox[" ",
    FormatType->StandardForm],
  StyleBox["Taking advantage of the Mathematica context",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["Since SEE ",
    FormatType->StandardForm],
  StyleBox["is implemented within a complete programming environment, it is \
particularly easy to add new operators to the list. We ignored here \
considerations of computational efficiency to emphasize the ease of obtaining \
a working implementation of a numerical measu",
    FormatType->StandardForm],
  StyleBox["r",
    FormatType->StandardForm],
  StyleBox["e. Transforming such straightforward implementations into \
efficient code takes some extra work and possibly some programming skills.\n",
    
    FormatType->StandardForm],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["(i)\t",
    FormatType->StandardForm,
    FontSize->10],
  StyleBox["Consider for example the measure of diversity - a relatively \
complex operator (section 2.2):\n",
    FormatType->StandardForm],
  StyleBox["\:f35f",
    FormatType->StandardForm],
  StyleBox["",
    FormatType->StandardForm]
}], "Text",
  PageWidth->WindowWidth,
  FontSize->14],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007T`0@0006@00000000000000740000d0000
00000000000Z2`00g0@00215CDH00040<7T000l000010000000000000000000000D0000400100@00
l000000000000000000004H0000/?00083`004M4BD<1002000<00>?:^=/0000023`000402@000`@N
00000>0M000000@000030@P01@0000/2000000D0000<0Rl0K00500001`440000h1d004<?803<0000
;`1/0000000_06`0000002P0001/0000;`00004060000000O3/000000000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000000000000000003oool000000000000000000000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooool0000000000000003oooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooool00000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool00000
0000003oooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool00000
0000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0000000000000003ooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003oooooooooooooooooool000000000003o
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003oooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003oooooooooooooooooool0000000000000
00000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003oooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
ooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooool00000003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003oooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
0000003oooooooooool00000000000000000003oooooooooool00000000000000000003ooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
0000003oooooool0003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003oooooooooooooooooooooooooool0003ooooooooooooooooo
ooooool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003oooooooooooooooooooooooooooooooooooooooooooooool00000003oool00000003ooooo
ooooooooool0003oooooooooooooooooooooool00000003oool00000003oooooooooooooool0003o
ooooooooooooooooooooooooool00000003oool000000000003oooooool0003ooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
ooooool000000000003oool00000003oool000000000003oooooooooooooooooooooool000000000
003oool00000003oool000000000003oooooooooooooooooooooool00000003oool000000000003o
ool000000000003oooooooooooooooooooooooooool000000000003ooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
ooooooooooooooooooooooooooooooooooooool00000003oooooool00000003ooooooooooooooooo
ooooooooooooooooooooool00000003oooooool00000003ooooooooooooooooooooooooooooooooo
ooooool00000003oooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooooooooooooooooooool00000003o
ooooool00000003oooooooooool0003oooooooooooooooooooooool00000003oooooool00000003o
ooooool0003oooooooooooooooooooooooooool00000003oooooool00000003oooooooooool0003o
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
ooooooooooooooooooooool000000000003oool00000003ooooooooooooooooooooooooooooooooo
ooooool000000000003oool00000003oooooooooooooooooooooooooooooooooooooool00000003o
ool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003oooooooooooooooooooooooooooooooooooooooooooooool000000000003oool00000003ooooo
ooooooooooooooooooooooooooooooooool000000000003oool00000003ooooooooooooooooooooo
ooooooooooooooooooooooooool00000003oool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000003o
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003oooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooool0000000000000000000000000
000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003oooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
ool000000000003oool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
00000000003oooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooooooooooooooooooool0003oooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0000000000000000000000000000000000000000000000000
000000000000000000000000003oooooooooooooooooooooooooooooooooooooooooool0003ooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000003o
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool500001`4100000`000000
4@0000`0000800002`000100001b0000=@0000T0000@0000LP0003D0000:00004000000000000000
2@000100001/0000;`0001D0000<000010000540003d>`0000000000001a0000=000000000000000
00000000001/0000;`000500000X0000N00007`k00000000803<06`0000_0000:00006`0000_0000
0@0H0000001l>`00000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000000000000000?ooo`00000000000000000000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooo`000000000000000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00000000000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooo`00000000000000000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooo`000000000000000?ooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooooooooooooooo`00000000000?ooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`00000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?ooooooooooooooooooo`00000000000000000000000000000000000000000000000000
000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooo`000000000000000000
0?ooooooooooo`0000000000000000000?ooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000?ooooooo`000?ooooooooooooooo`00
0?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?ooo`0000000?ooooooooooooooo`000?oooooooooooooooooooooo
o`0000000?ooo`0000000?ooooooooooooooo`000?ooooooooooooooooooooooooooo`0000000?oo
o`00000000000?ooooooo`000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooooooooooooooo`00000000000?ooo`0000000?ooo`00
000000000?ooooooooooooooooooooooo`00000000000?ooo`0000000?ooo`00000000000?oooooo
ooooooooooooooooo`0000000?ooo`00000000000?ooo`00000000000?oooooooooooooooooooooo
ooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
o`0000000?ooooooo`0000000?ooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
o`0000000?ooooooooooooooooooooooooooooooooooooooo`0000000?ooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooooooooooooooo`0000000?ooooooo`0000000?ooooooooooo`000?oooooo
ooooooooooooooooo`0000000?ooooooo`0000000?ooooooo`000?oooooooooooooooooooooooooo
o`0000000?ooooooo`0000000?ooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oo
o`0000000?ooooooooooooooooooooooooooooooooooooooo`00000000000?ooo`0000000?oooooo
ooooooooooooooooooooooooooooooooo`0000000?ooo`00000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`00000000000?ooo`0000000?ooooooooooooooooooooooooooooooooooooooo`00
000000000?ooo`0000000?ooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooo`00
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooo`000000000000000000000000000000000000000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00000000000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooooooooooo`00000000000?ooo`0000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000?ooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooaD0000<00000@0002D0000<00001`00P2D0000<00000000P300000<0000
3`00P4/0000@0000000000D0000>000050000000000@00005000
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{113, 52}],

Cell[TextData[{
  StyleBox["\n \n\n",
    FormatType->StandardForm],
  StyleBox["Where p",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["i",
    FormatType->StandardForm,
    FontSize->14,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the proportion of time spent at stopping place i and d",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["ij",
    FormatType->StandardForm,
    FontSize->14,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" is the distance between the location of the i-th and j-th \
episodes. This function can be programmed in Mathematica by just following \
the logic of the formula. The list of stops is a list of pairs of indexes \
{m,n} indicating the beginning and the end of the stop, we can thus define \
auxiliary functions :\n\nduration[{m_,n_}]:=data[[m,1]]-data[[n,1]] \n\
totalduration[list_]:=Apply[Plus, Map[duration, list]];\n\
coordinates[n_]:={data[[n,2]], data[[n,3]]};\npos \
[{m_,n_}]:=Mean[Map[coordinates, Range[m,n]]];\np \
[i_,list_]:=duration[list[[i]]]/totalduration[list];\n\nThese functions \
define the relative durations of arrests and the distances between them, so \
that we can now define\n Diversity[list_]:=Apply[Plus,\n Table[p [i, list]*p \
[j, list]*Distance[pos[list[[i]], pos[list[[j]]]]]];\nand add these \
definitions to our repertoire of SEE functions. The details of the syntax can \
be found in [Wolfram 1996] and are easy to master even for an amateur \
programmer. \n",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["\n",
    FormatType->StandardForm],
  StyleBox["References:\n",
    FormatType->StandardForm,
    FontSize->14],
  StyleBox["Barnett SA, Cowan PE (1976) Activity, exploration, curiosity and \
fear: an ethological study. ",
    FormatType->StandardForm],
  StyleBox["Int. Sci.Rev.,",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 1, 43-59.\nBenjamini Y, Hochberg Y (1995) Controlling the False \
Discovery Rate: a practical and powerful approach to multiple testing. ",
    FormatType->StandardForm],
  StyleBox["Journal of the Royal Statistical Society",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", Series B, 57, 1, 289-300.\nChance MRA, Mead AP (1955) \
Competition between feeding and investigation in the rat. ",
    FormatType->StandardForm],
  StyleBox["Behaviour",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", 8 174-182.\nCleveland, W.S. (1977) Robust locally weighted \
regression and smoothing scatterplots. ",
    FormatType->StandardForm],
  StyleBox["J Am Stat Assoc",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 74:829-836\nCools AR, Brachten R, Heeren D, Willemen D, \
Ellenbroek B (1989) Search after neurobiological profile of \
individual-specific features of wistar rats. ",
    FormatType->StandardForm],
  StyleBox["Brain Research Bulletin",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", Vol 24,49-69.\nCools AR, Ellenbroek BA, Gingras MA, Engbersen \
A, Heeren D (1997) Differences in vulnerability and susceptibility to \
dexamphetamine in Nijmegen high and low responders to novelty: a dose-effect \
analysis of spatio-temporal programming of behavior. ",
    FormatType->StandardForm],
  StyleBox["Psychopharmacology",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[",132:181-187\nCrabbe JC, Wahlsten D, Dudek BC (1999) Genetics of \
mouse behavior: Interactions with laboratory environment. ",
    FormatType->StandardForm],
  StyleBox["Science,",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 284: (5420) 1670-1672 \nDrai D, Benjamini Y, Golani I (2000) \
Statistical discrimination of natural modes of motion in rat exploratory \
behavior. ",
    FormatType->StandardForm],
  StyleBox["Journal of Neuroscience methods",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 96 119-131.\nEilam D, Golani I (1989) Home base behavior of rats \
(",
    FormatType->StandardForm],
  StyleBox["Rattus norvegicus",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox[") exploring a novel environment. ",
    FormatType->StandardForm],
  StyleBox["Behavioral Brain Research",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", 34, 199-211.\nEilam D, Golani I (1990) Home base behavior in \
amphetamine-treated tame wild rats (Rattus norvegicus). ",
    FormatType->StandardForm],
  StyleBox["Behavioral Brain Research",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", 36, 161-170.\nEilam D, Golani I (1994) Amphetamine-induced \
stereotypy in rats: its morphogenesis in locale space from normal \
exploration.  In: S. J. Cooper and C.A. Hendrie, ",
    FormatType->StandardForm],
  StyleBox["Ethology and Psychopharmacology",
    FormatType->StandardForm,
    FontVariations->{"Underline"->True}],
  StyleBox[", John Wiley & Sons Ltd.. 241-265.  \n",
    FormatType->StandardForm],
  StyleBox["  \n",
    FormatType->StandardForm,
    FontSize->10],
  StyleBox["Eilam D, Golani I, Szechtman H (1989) D2 Agonist quinripole \
induces perseveration of routes and hyperactivity but no perseveration of \
movements. ",
    FormatType->StandardForm],
  StyleBox["Brain Research",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", ",
    FormatType->StandardForm],
  StyleBox["460,",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 255-267.\nFile SE (1985) What can be learned from the effects of \
benzodiazepines on \n            exploratory behavior?  ",
    FormatType->StandardForm],
  StyleBox["Neurosci Biobehav Rev",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox["  9(1):45-54\nGerlai R (1996) Molecular genetic analysis of \
mammalian behavior and brain processes: caveats and perspectives. ",
    FormatType->StandardForm],
  StyleBox["The Neurosciences",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", Vol 8, pp153-161.\nGeyer MA, Russo PV, Masten VL (1986)  \
Multivariate assessments of locomotor   \n            behavior:  \
pharmacological and behavioral analysis, ",
    FormatType->StandardForm],
  StyleBox["Pharmacol.     \nBiochem. Behav",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox["., 25 277-288.\nGingras MA, Cools AR (1997) Different behavioral \
effects of daily or intermittent dexamphetamine administration in Nijmegen \
high and low responders ",
    FormatType->StandardForm],
  StyleBox["Psychopharmacology",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 132:188-194.\nGolani I, (1992) A mobility gradient in the \
organization of vertebrate movement: The perception of movement through \
symbolic language. ",
    FormatType->StandardForm],
  StyleBox["The Behavioral and Brain Sciences",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[",  ",
    FormatType->StandardForm],
  StyleBox["15",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox["(2),  249-266.\nGolani I, Benjamini Y, Eilam D (1993) Stopping \
behavior: Constraints on exploration in rats (Rattus  norvegicus). ",
    FormatType->StandardForm],
  StyleBox["Behavioral Brain Research",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[", 53, 21-33.\nGolani I, Kafkafi N Drai D (1999) Phenotyping \
stereotypic behavior: Collective Variables, range of variation and \
predictability. ",
    FormatType->StandardForm],
  StyleBox["Applied Animal Behavior Science, ",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox["65:191-220.\nKafkafi N, Mayo C, Drai D, Golani I, Elmer G (2000) \
SEE analysis of photo-beam raw data. Paper presented at Measuring Behavior \
2000 conference in Nijmegen, Holland.\nLorenz K (1937) Uber die Bildung des \
Instinktbegriffes. Naturwissenschaften 25: 289-331.  \nMenzel ME (1978) \
Cognitive mapping in chimpanzees. In S. H. Hulse, H. Fowler and W.K. Honig \
(Eds.), Cognitive processes in animal behavior, Hillsdale, New Jersey. \
375-422.\nNolan PM, Kapfhamer D, Bucan M (1997) Random mutagenesis screen for \
dominant behavioral mutations in mice. ",
    FormatType->StandardForm],
  StyleBox["Methods",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 13: 379-95\nPatil,GP & TaillieC (1982) Diversity as a concept \
and its measurement.    \n            J.Am.Statis.Ass 77,p.548-560\nPaulus \
MP, Dulawa SC, Ralph RJ, Geyer MA (1999) Behavioral organization is \
independent of locomotor activity in 129 and C57 mouse strains. ",
    FormatType->StandardForm],
  StyleBox["Brain Res.",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" Jul 17; 835 (1):27-36.\nTchernichovski, O. and Golani, I. (1995) \
A phase plane representation of rat exploratory behavior.  ",
    FormatType->StandardForm],
  StyleBox["Journal of Neuroscience Methods,",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 62, 21-27.  \nTchernichovski O, Benjamini Y, Golani I (1996) \
Constraints and the emergence of freedom in the ontogeny of rat exploratory \
behavior.  ",
    FormatType->StandardForm],
  StyleBox["Behaviour",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 133, 519-539. \nTchernichovski O, Benjamini Y, Golani I (1998) \
The dynamics of long-term exploration in the rat. Part I. A phase-plane \
analysis of the relationship between location and velocity. ",
    FormatType->StandardForm],
  StyleBox["Biol. Cybern.",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 78, 423-432.\nTchernichovski O, Benjamini Y. (1998) The dynamics \
of long term exploration in the rat - Part II. An analytical model of the  \
kinematic structure of rat exploratory behavior. ",
    FormatType->StandardForm],
  StyleBox["Biol Cybern",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 78: (6) 433-440. \nVan de Rijt-Plooij HH, Plooij, FX (1987). \
Growing independence, conflict and learning in mother-infant relations in \
free-ranging chimpanzees. ",
    FormatType->StandardForm],
  StyleBox["Behaviour",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" 101(1-3):1-86.\nWhishaw I.Q, Cassel JC, Majchrzak M, Cassel S, \
Will B (1994) \[OpenCurlyDoubleQuote]Short-stops\[CloseCurlyDoubleQuote] in \
rats with fimbria-fornix lesions: evidence for change in the mobility \
gradient. ",
    FormatType->StandardForm],
  StyleBox["Hippocampus",
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" Vol. 4 No 5, 577-582. \nWolfram S (1996) The Mathematica Book, \
3rd ed. Wolfram Media/Cambridge  \n            University Press.",
    FormatType->StandardForm],
  StyleBox["\n\n\n\n",
    FormatType->StandardForm,
    FontSize->10]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{406, Inherited}]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{"EditBar", "LinksBar"},
CellGrouping->Manual,
WindowSize->{1016, 668},
WindowMargins->{{4, Automatic}, {Automatic, 22}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1,
StyleDefinitions -> "DemoText.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 150, 5, 112, "Text"],
Cell[1870, 56, 352, 14, 383, "Text"],
Cell[2225, 72, 16875, 243, 2922, "Text"],
Cell[19103, 317, 194, 5, 29, "Text"],
Cell[19300, 324, 170, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[19495, 333, 383, 6, 340, "Input"],
Cell[19881, 341, 79, 2, 49, "Output"],
Cell[19963, 345, 71, 1, 49, "Output"],
Cell[20037, 348, 72, 1, 49, "Output"],
Cell[20112, 351, 36, 1, 49, "Output"],
Cell[20151, 354, 116, 2, 49, "Output"],
Cell[20270, 358, 116, 2, 49, "Output"]
}, Open  ]],
Cell[20401, 363, 748, 13, 122, "Text"],
Cell[21152, 378, 836, 28, 40, "Input"],

Cell[CellGroupData[{
Cell[22013, 410, 109, 2, 40, "Input"],
Cell[22125, 414, 784050, 48475, 304, 750833, 48060, "GraphicsData", \
"PostScript", "Graphics"],
Cell[806178, 48891, 130, 3, 49, "Output"]
}, Open  ]],
Cell[806323, 48897, 1187, 21, 182, "Text"],
Cell[807513, 48920, 73, 1, 60, "Input"],
Cell[807589, 48923, 375, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[807989, 48935, 684, 16, 140, "Input"],
Cell[808676, 48953, 1532334, 94501, 310, 1466216, 93680, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2341013, 143456, 135, 3, 49, "Output"]
}, Open  ]],
Cell[2341163, 143462, 223, 6, 50, "Text"],
Cell[2341389, 143470, 222, 9, 62, "Text"],

Cell[CellGroupData[{
Cell[2341636, 143483, 89, 1, 40, "Input"],
Cell[2341728, 143486, 97, 2, 49, "Output"]
}, Open  ]],
Cell[2341840, 143491, 125, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[2341990, 143498, 142, 3, 40, "Input"],
Cell[2342135, 143503, 280, 4, 49, "Output"]
}, Open  ]],
Cell[2342430, 143510, 136, 4, 30, "Text"],
Cell[2342569, 143516, 189, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[2342783, 143525, 71, 1, 40, "Input"],
Cell[2342857, 143528, 270, 4, 49, "Output"]
}, Open  ]],
Cell[2343142, 143535, 255, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[2343422, 143546, 144, 2, 40, "Input"],
Cell[2343569, 143550, 15184, 548, 194, 4994, 418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2358756, 144100, 130, 3, 49, "Output"]
}, Open  ]],
Cell[2358901, 144106, 144, 5, 30, "Text"],
Cell[2359048, 144113, 165, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[2359238, 144122, 50, 1, 40, "Input"],
Cell[2359291, 144125, 920, 15, 144, "Output"]
}, Open  ]],
Cell[2360226, 144143, 187, 5, 30, "Text"],
Cell[2360416, 144150, 57, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[2360498, 144155, 1018, 21, 120, "Input"],
Cell[2361519, 144178, 30805, 812, 295, 11411, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2392327, 144992, 130, 3, 49, "Output"]
}, Open  ]],
Cell[2392472, 144998, 67, 1, 40, "Input"],
Cell[2392542, 145001, 56, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[2392623, 145006, 1252, 26, 120, "Input"],
Cell[2393878, 145034, 28149, 774, 276, 11370, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2422064, 145813, 70, 1, 40, "Input"],
Cell[2422137, 145816, 32526, 819, 370, 10995, 549, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2454666, 146637, 130, 3, 49, "Output"]
}, Open  ]],
Cell[2454811, 146643, 58, 1, 40, "Input"],
Cell[2454872, 146646, 184, 5, 30, "Text"],
Cell[2455059, 146653, 295, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[2455379, 146664, 195, 3, 80, "Input"],
Cell[2455577, 146669, 643984, 38988, 161, 601193, 38455, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3099564, 185659, 630970, 38837, 161, 600367, 38455, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3730537, 224498, 440, 14, 49, "Output"]
}, Open  ]],
Cell[3730992, 224515, 714, 14, 102, "Text"],

Cell[CellGroupData[{
Cell[3731731, 224533, 247, 6, 120, "Input"],
Cell[3731981, 224541, 39304, 1131, 267, 15685, 835, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3771288, 225674, 135, 3, 49, "Output"]
}, Open  ]],
Cell[3771438, 225680, 342, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[3771805, 225692, 254, 6, 140, "Input"],
Cell[3772062, 225700, 892276, 55990, 269, 865962, 55661, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4664341, 281692, 135, 3, 49, "Output"]
}, Open  ]],
Cell[4664491, 281698, 137, 3, 30, "Text"],
Cell[4664631, 281703, 280, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[4664936, 281714, 254, 6, 140, "Input"],
Cell[4665193, 281722, 36, 1, 25, "Print"],
Cell[4665232, 281725, 38, 1, 25, "Print"],
Cell[4665273, 281728, 36, 1, 25, "Print"],
Cell[4665312, 281731, 38, 1, 25, "Print"],
Cell[4665353, 281734, 104178, 3526, 303, 58342, 2956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4769534, 285262, 135, 3, 49, "Output"]
}, Open  ]],
Cell[4769684, 285268, 577, 12, 70, "Text"],
Cell[4770264, 285282, 216, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[4770505, 285292, 257, 6, 140, "Input"],
Cell[4770765, 285300, 90244, 3352, 256, 58520, 2956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4861012, 288654, 135, 3, 49, "Output"]
}, Open  ]],
Cell[4861162, 288660, 286, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[4861473, 288671, 93, 2, 40, "Input"],
Cell[4861569, 288675, 45, 1, 49, "Output"]
}, Open  ]],
Cell[4861629, 288679, 184, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[4861838, 288689, 240, 3, 80, "Input"],
Cell[4862081, 288694, 47, 1, 25, "Print"],
Cell[4862131, 288697, 48338, 1691, 112, 27119, 1425, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4910472, 290390, 47, 1, 25, "Print"],
Cell[4910522, 290393, 55024, 2046, 112, 34282, 1785, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4965561, 292442, 6200, 127, 1128, "Text"],
Cell[4971764, 292571, 868, 17, 180, "Input"],
Cell[4972635, 292590, 315, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[4972975, 292601, 112, 2, 40, "Input"],
Cell[4973090, 292605, 490, 8, 68, "Output"]
}, Open  ]],
Cell[4973595, 292616, 682, 12, 90, "Text"],

Cell[CellGroupData[{
Cell[4974302, 292632, 136, 2, 40, "Input"],
Cell[4974441, 292636, 403, 6, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4974881, 292647, 148, 2, 40, "Input"],
Cell[4975032, 292651, 557, 9, 87, "Output"]
}, Open  ]],
Cell[4975604, 292663, 877, 15, 142, "Text"],
Cell[4976484, 292680, 996, 15, 130, "Text"],
Cell[4977483, 292697, 56, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[4977564, 292702, 199, 4, 40, "Input"],
Cell[4977766, 292708, 69089, 1608, 304, 10322, 878, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5046870, 294319, 1612, 30, 418, "Text"],

Cell[CellGroupData[{
Cell[5048507, 294353, 390, 11, 40, "Input"],
Cell[5048900, 294366, 22967, 613, 304, 5432, 392, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5071904, 294984, 450, 12, 80, "Input"],
Cell[5072357, 294998, 37835, 823, 304, 5663, 421, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5110207, 295824, 448, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[5110680, 295836, 186, 3, 60, "Input"],
Cell[5110869, 295841, 21904, 409, 304, 2563, 166, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5132776, 296252, 130, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5132943, 296260, 183, 3, 60, "Input"],
Cell[5133129, 296265, 16919, 349, 304, 2583, 167, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5150051, 296616, 130, 3, 49, "Output"]
}, Open  ]],
Cell[5150196, 296622, 132, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[5150353, 296630, 121, 3, 40, "Input"],
Cell[5150477, 296635, 107251, 3014, 221, 26365, 2010, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5257743, 299652, 754, 12, 110, "Text"],
Cell[5258500, 299666, 81, 1, 30, "Text"],
Cell[5258584, 299669, 58, 1, 40, "Input"],
Cell[5258645, 299672, 56, 1, 40, "Input"],
Cell[5258704, 299675, 495, 10, 102, "Text"],

Cell[CellGroupData[{
Cell[5259224, 299689, 54, 1, 40, "Input"],
Cell[5259281, 299692, 37, 1, 49, "Output"]
}, Open  ]],
Cell[5259333, 299696, 345, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[5259703, 299706, 112, 2, 40, "Input"],
Cell[5259818, 299710, 435656, 27401, 304, 421006, 27215, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5695477, 327113, 471718, 30623, 304, 457008, 30437, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6167198, 357738, 445315, 28036, 304, 430649, 27850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6612516, 385776, 445711, 28051, 304, 431053, 27865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7058230, 413829, 445696, 28024, 304, 430994, 27838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7503929, 441855, 453263, 28693, 304, 438557, 28507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7957195, 470550, 448740, 28229, 304, 434030, 28043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8405938, 498781, 446977, 28050, 304, 432242, 27863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8852918, 526833, 448468, 28181, 304, 433737, 27994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9301389, 555016, 448305, 28154, 304, 433530, 27967, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9749697, 583172, 454717, 28716, 304, 439788, 28527, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[10204451, 611893, 57, 1, 42, "Input"],
Cell[10204511, 611896, 37, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10204585, 611902, 113, 2, 40, "Input"],
Cell[10204701, 611906, 15471, 563, 304, 5003, 429, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10220175, 612471, 13854, 394, 304, 3382, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10234032, 612867, 16132, 591, 304, 5636, 457, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10250167, 613460, 18536, 786, 304, 7983, 651, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10268706, 614248, 15568, 497, 304, 5112, 363, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10284277, 614747, 17331, 647, 304, 6835, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10301611, 615396, 18493, 733, 304, 7936, 598, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10320107, 616131, 23006, 1114, 304, 12303, 977, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10343116, 617247, 21653, 954, 304, 10974, 817, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10364772, 618203, 23506, 1088, 304, 12694, 950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10388281, 619293, 23115, 1028, 304, 12360, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10411399, 620323, 21847, 901, 304, 11168, 764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10433249, 621226, 22982, 994, 304, 12283, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10456234, 622222, 24815, 1153, 304, 14128, 1016, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10481052, 623377, 24227, 1072, 304, 13508, 935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10505282, 624451, 23960, 1040, 304, 13318, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10529245, 625493, 33392, 1853, 304, 22292, 1711, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10562640, 627348, 47253, 3011, 304, 35667, 2863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10609896, 630361, 32289, 1575, 304, 21193, 1433, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10642188, 631938, 33995, 1715, 304, 22891, 1573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10676186, 633655, 36365, 1899, 304, 25132, 1756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10712554, 635556, 36594, 1898, 304, 25450, 1756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10749151, 637456, 44008, 2522, 304, 32544, 2376, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10793162, 639980, 45128, 2559, 304, 33587, 2412, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10838293, 642541, 42688, 2292, 304, 31236, 2146, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10880984, 644835, 43138, 2317, 304, 31836, 2173, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10924125, 647154, 41163, 2120, 304, 29970, 1977, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10965291, 649276, 41219, 2117, 304, 30022, 1974, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11006513, 651395, 43451, 2288, 304, 31987, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11049967, 653685, 42428, 2195, 304, 31162, 2051, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11092398, 655882, 66173, 4248, 304, 53757, 4090, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11158574, 660132, 49257, 2638, 304, 37562, 2489, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11207834, 662772, 53260, 2977, 304, 41464, 2827, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11261097, 665751, 55826, 3177, 304, 44042, 3027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11316926, 668930, 61416, 3634, 304, 49502, 3482, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11378345, 672566, 53936, 2919, 304, 42362, 2771, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11432284, 675487, 56582, 3141, 304, 44907, 2992, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11488869, 678630, 75311, 4776, 304, 63106, 4621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11564183, 683408, 63262, 3592, 304, 51413, 3441, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11627448, 687002, 62776, 3540, 304, 51162, 3392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11690227, 690544, 62084, 3453, 304, 50454, 3305, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11752314, 693999, 61261, 3372, 304, 49700, 3225, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11813578, 697373, 63029, 3522, 304, 51415, 3374, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11876610, 700897, 64299, 3626, 304, 52738, 3479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11940912, 704525, 65236, 3681, 304, 53492, 3531, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12006151, 708208, 63707, 3536, 304, 52129, 3388, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12069861, 711746, 72997, 4319, 304, 60747, 4163, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12142861, 716067, 69264, 3960, 304, 57439, 3809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12212128, 720029, 70042, 4005, 304, 58205, 3854, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12282173, 724036, 82450, 5069, 304, 70135, 4912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12364626, 729107, 98852, 6407, 304, 85792, 6241, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12463481, 735516, 99264, 6285, 304, 86135, 6118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12562748, 741803, 85733, 4972, 304, 73001, 4810, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12648484, 746777, 89667, 5294, 304, 76850, 5131, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12738154, 752073, 88069, 5124, 304, 75483, 4964, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12826226, 757199, 88658, 5151, 304, 76011, 4990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12914887, 762352, 88569, 5128, 304, 76052, 4969, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13003459, 767482, 87109, 4983, 304, 74636, 4824, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13090571, 772467, 88622, 5112, 304, 76141, 4953, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13179196, 777581, 93550, 5514, 304, 80652, 5350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13272749, 783097, 92305, 5399, 304, 79840, 5240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13365057, 788498, 81943, 5400, 304, 81824, 5396, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13447003, 793900, 90721, 6165, 304, 90602, 6161, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13537727, 800067, 101085, 6036, 304, 88207, 5872, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13638815, 806105, 94999, 5478, 304, 82599, 5320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13733817, 811585, 99232, 5853, 304, 86743, 5694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13833052, 817440, 85544, 5551, 304, 85425, 5547, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13918599, 822993, 88042, 5765, 304, 87923, 5761, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14006644, 828760, 88475, 5782, 304, 88356, 5778, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14095122, 834544, 104402, 7200, 304, 104283, 7196, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14199527, 841746, 113780, 7948, 304, 113661, 7944, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14313310, 849696, 97846, 6368, 304, 97727, 6364, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14411159, 856066, 96852, 6260, 304, 96733, 6256, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14508014, 862328, 97745, 6333, 304, 97626, 6329, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14605762, 868663, 100259, 6546, 304, 100140, 6542, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14706024, 875211, 104406, 6912, 304, 104287, 6908, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14810433, 882125, 103667, 6791, 304, 103548, 6787, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14914103, 888918, 100746, 6497, 304, 100627, 6493, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15014852, 895417, 104243, 6808, 304, 104124, 6804, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15119098, 902227, 112765, 7554, 304, 112646, 7550, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15231866, 909783, 123774, 8484, 304, 123655, 8480, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15355643, 918269, 122819, 7267, 304, 109638, 7100, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15478465, 925538, 126884, 7627, 304, 113775, 7460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15605352, 933167, 125453, 7473, 304, 112434, 7308, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15730808, 940642, 125884, 7485, 304, 112747, 7318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15856695, 948129, 124840, 7383, 304, 111833, 7218, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15981538, 955514, 135849, 8340, 304, 122396, 8169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16117390, 963856, 130743, 7822, 304, 117416, 7653, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16248136, 971680, 129091, 7655, 304, 115845, 7487, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16377230, 979337, 138329, 8448, 304, 124662, 8275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16515562, 987787, 134145, 8041, 304, 120838, 7872, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16649710, 995830, 137909, 8322, 304, 124136, 8147, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16787622, 1004154, 151447, 9431, 304, 136686, 9244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16939072, 1013587, 149777, 9274, 304, 136187, 9102, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17088852, 1022863, 143348, 8634, 304, 129968, 8464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17232203, 1031499, 142828, 8557, 304, 129367, 8386, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17375034, 1040058, 153967, 9483, 304, 139656, 9302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17529004, 1049543, 147111, 8840, 304, 133379, 8666, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17676118, 1058385, 145974, 8734, 304, 132546, 8564, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[17822107, 1067122, 71, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[17822203, 1067127, 79, 1, 40, "Input"],
Cell[17822285, 1067130, 114, 2, 25, "Message"],
Cell[17822402, 1067134, 204, 4, 25, "Message"],
Cell[17822609, 1067140, 204, 4, 25, "Message"],
Cell[17822816, 1067146, 204, 4, 25, "Message"],
Cell[17823023, 1067152, 163, 3, 25, "Message"],
Cell[17823189, 1067157, 114, 2, 25, "Message"],
Cell[17823306, 1067161, 114, 2, 25, "Message"],
Cell[17823423, 1067165, 163, 3, 25, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17823623, 1067173, 67, 1, 40, "Input"],
Cell[17823693, 1067176, 36, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17823766, 1067182, 214, 4, 60, "Input"],
Cell[17823983, 1067188, 46512, 3150, 304, 33132, 2980, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17870498, 1070340, 28212, 1336, 304, 15148, 1170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17898713, 1071678, 50654, 3270, 304, 36906, 3096, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17949370, 1074950, 210848, 17464, 304, 196096, 17277, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18160221, 1092416, 153115, 11158, 304, 137386, 10959, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18313339, 1103576, 234814, 17904, 304, 217408, 17684, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18548156, 1121482, 288332, 21766, 304, 269428, 21528, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18836491, 1143250, 166508, 10262, 304, 152994, 10090, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19003002, 1153514, 348698, 26010, 304, 327554, 25744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19351703, 1179526, 326973, 22869, 304, 304319, 22585, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19678679, 1202397, 568429, 43605, 304, 541745, 43271, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20247111, 1246004, 681387, 51476, 304, 651106, 51097, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[20928513, 1297483, 123, 4, 29, "Text"],
Cell[20928639, 1297489, 461, 10, 102, "Text"],

Cell[CellGroupData[{
Cell[20929125, 1297503, 49, 1, 40, "Input"],
Cell[20929177, 1297506, 48, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20929262, 1297512, 178, 3, 40, "Input"],
Cell[20929443, 1297517, 638924, 49927, 325, 602092, 49468, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21568370, 1347446, 132, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21568539, 1347454, 178, 3, 40, "Input"],
Cell[21568720, 1347459, 266730, 20147, 319, 239252, 19803, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21835453, 1367608, 132, 3, 49, "Output"]
}, Open  ]],
Cell[21835600, 1367614, 44310, 1121, 5418, "Text"],
Cell[21879913, 1368737, 42029, 521, 68, 41982, 519, "GraphicsData", \
"Metafile", "Graphics"],
Cell[21921945, 1369260, 10955, 254, 2066, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

